Case study: Classification of shapes
====================================

This notebook explains how to use ``giotto-tda`` to be able to classify
topologically different high-dimensional spaces.

If you are looking at a static version of this notebook and would like
to run its contents, head over to
`github <https://github.com/giotto-ai/giotto-tda/blob/master/examples/classifying_shapes.ipynb>`__.

**License: AGPLv3**

Import libraries
----------------

The first step consists in importing relevant ``giotto-tda`` components
and other useful libraries or modules.

.. code:: ipython3

    # Importing libraries
    from gtda.homology import VietorisRipsPersistence
    from gtda.diagrams import PersistenceEntropy
    
    import numpy as np
    
    from gtda.pipeline import Pipeline
    from sklearn.linear_model import LogisticRegression
    
    # Plotting functions
    from gtda.plotting import plot_diagram, plot_point_cloud, plot_heatmap

Sampling orientable surfaces
----------------------------

We are going to consider three classical topological spaces: the circle,
the 2-torus and the 2-sphere. The purpose of this tutorial is to go
through the most famous topological spaces and compute their homology
groups.

Each of the topological spaces we are going to encounter will be
sampled. The resulting point cloud will be the input of the *persistent
homology pipeline*. The first step is to apply the Vietoris–Rips
technique to the point cloud. Finally, the persistent homology groups
will be computed.

.. code:: ipython3

    # Representing the circle in 3d with parametric equations.
    circle = np.asarray([[np.sin(t),np.cos(t),0] for t in range(400)])
    plot_point_cloud(circle)



.. raw:: html

            <script type="text/javascript">
            window.PlotlyConfig = {MathJaxConfig: 'local'};
            if (window.MathJax) {MathJax.Hub.Config({SVG: {font: "STIX-Web"}});}
            if (typeof require !== 'undefined') {
            require.undef("plotly");
            define('plotly', function(require, exports, module) {
                /**
    * plotly.js v1.51.2
    * Copyright 2012-2019, Plotly, Inc.
    * All rights reserved.
    * Licensed under the MIT license
    */
    !function(t){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=t();else if("function"==typeof define&&define.amd)define([],t);else{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:this).Plotly=t()}}(function(){return function(){return function t(e,r,n){function a(o,s){if(!r[o]){if(!e[o]){var l="function"==typeof require&&require;if(!s&&l)return l(o,!0);if(i)return i(o,!0);var c=new Error("Cannot find module '"+o+"'");throw c.code="MODULE_NOT_FOUND",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,function(t){return a(e[o][1][t]||t)},u,u.exports,t,e,r,n)}return r[o].exports}for(var i="function"==typeof require&&require,o=0;o<n.length;o++)a(n[o]);return a}}()({1:[function(t,e,r){"use strict";var n=t("../src/lib"),a={"X,X div":"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;","X input,X button":"font-family:'Open Sans', verdana, arial, sans-serif;","X input:focus,X button:focus":"outline:none;","X a":"text-decoration:none;","X a:hover":"text-decoration:none;","X .crisp":"shape-rendering:crispEdges;","X .user-select-none":"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;","X svg":"overflow:hidden;","X svg a":"fill:#447adb;","X svg a:hover":"fill:#3c6dc5;","X .main-svg":"position:absolute;top:0;left:0;pointer-events:none;","X .main-svg .draglayer":"pointer-events:all;","X .cursor-default":"cursor:default;","X .cursor-pointer":"cursor:pointer;","X .cursor-crosshair":"cursor:crosshair;","X .cursor-move":"cursor:move;","X .cursor-col-resize":"cursor:col-resize;","X .cursor-row-resize":"cursor:row-resize;","X .cursor-ns-resize":"cursor:ns-resize;","X .cursor-ew-resize":"cursor:ew-resize;","X .cursor-sw-resize":"cursor:sw-resize;","X .cursor-s-resize":"cursor:s-resize;","X .cursor-se-resize":"cursor:se-resize;","X .cursor-w-resize":"cursor:w-resize;","X .cursor-e-resize":"cursor:e-resize;","X .cursor-nw-resize":"cursor:nw-resize;","X .cursor-n-resize":"cursor:n-resize;","X .cursor-ne-resize":"cursor:ne-resize;","X .cursor-grab":"cursor:-webkit-grab;cursor:grab;","X .modebar":"position:absolute;top:2px;right:2px;","X .ease-bg":"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;","X .modebar--hover>:not(.watermark)":"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;","X:hover .modebar--hover .modebar-group":"opacity:1;","X .modebar-group":"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;","X .modebar-btn":"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;","X .modebar-btn svg":"position:relative;top:2px;","X .modebar.vertical":"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;","X .modebar.vertical svg":"top:-1px;","X .modebar.vertical .modebar-group":"display:block;float:none;padding-left:0px;padding-bottom:8px;","X .modebar.vertical .modebar-group .modebar-btn":"display:block;text-align:center;","X [data-title]:before,X [data-title]:after":"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;","X [data-title]:hover:before,X [data-title]:hover:after":"display:block;opacity:1;","X [data-title]:before":"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;","X [data-title]:after":"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;","X .vertical [data-title]:before,X .vertical [data-title]:after":"top:0%;right:200%;","X .vertical [data-title]:before":"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;","X .select-outline":"fill:none;stroke-width:1;shape-rendering:crispEdges;","X .select-outline-1":"stroke:white;","X .select-outline-2":"stroke:black;stroke-dasharray:2px 2px;",Y:"font-family:'Open Sans';position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;","Y p":"margin:0;","Y .notifier-note":"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;","Y .notifier-close":"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;","Y .notifier-close:hover":"color:#444;text-decoration:none;cursor:pointer;"};for(var i in a){var o=i.replace(/^,/," ,").replace(/X/g,".js-plotly-plot .plotly").replace(/Y/g,".plotly-notifier");n.addStyleRule(o,a[i])}},{"../src/lib":716}],2:[function(t,e,r){"use strict";e.exports=t("../src/transforms/aggregate")},{"../src/transforms/aggregate":1294}],3:[function(t,e,r){"use strict";e.exports=t("../src/traces/bar")},{"../src/traces/bar":863}],4:[function(t,e,r){"use strict";e.exports=t("../src/traces/barpolar")},{"../src/traces/barpolar":875}],5:[function(t,e,r){"use strict";e.exports=t("../src/traces/box")},{"../src/traces/box":885}],6:[function(t,e,r){"use strict";e.exports=t("../src/components/calendars")},{"../src/components/calendars":589}],7:[function(t,e,r){"use strict";e.exports=t("../src/traces/candlestick")},{"../src/traces/candlestick":894}],8:[function(t,e,r){"use strict";e.exports=t("../src/traces/carpet")},{"../src/traces/carpet":913}],9:[function(t,e,r){"use strict";e.exports=t("../src/traces/choropleth")},{"../src/traces/choropleth":927}],10:[function(t,e,r){"use strict";e.exports=t("../src/traces/choroplethmapbox")},{"../src/traces/choroplethmapbox":934}],11:[function(t,e,r){"use strict";e.exports=t("../src/traces/cone")},{"../src/traces/cone":940}],12:[function(t,e,r){"use strict";e.exports=t("../src/traces/contour")},{"../src/traces/contour":955}],13:[function(t,e,r){"use strict";e.exports=t("../src/traces/contourcarpet")},{"../src/traces/contourcarpet":966}],14:[function(t,e,r){"use strict";e.exports=t("../src/core")},{"../src/core":694}],15:[function(t,e,r){"use strict";e.exports=t("../src/traces/densitymapbox")},{"../src/traces/densitymapbox":974}],16:[function(t,e,r){"use strict";e.exports=t("../src/transforms/filter")},{"../src/transforms/filter":1295}],17:[function(t,e,r){"use strict";e.exports=t("../src/traces/funnel")},{"../src/traces/funnel":984}],18:[function(t,e,r){"use strict";e.exports=t("../src/traces/funnelarea")},{"../src/traces/funnelarea":993}],19:[function(t,e,r){"use strict";e.exports=t("../src/transforms/groupby")},{"../src/transforms/groupby":1296}],20:[function(t,e,r){"use strict";e.exports=t("../src/traces/heatmap")},{"../src/traces/heatmap":1006}],21:[function(t,e,r){"use strict";e.exports=t("../src/traces/heatmapgl")},{"../src/traces/heatmapgl":1015}],22:[function(t,e,r){"use strict";e.exports=t("../src/traces/histogram")},{"../src/traces/histogram":1027}],23:[function(t,e,r){"use strict";e.exports=t("../src/traces/histogram2d")},{"../src/traces/histogram2d":1033}],24:[function(t,e,r){"use strict";e.exports=t("../src/traces/histogram2dcontour")},{"../src/traces/histogram2dcontour":1037}],25:[function(t,e,r){"use strict";e.exports=t("../src/traces/image")},{"../src/traces/image":1044}],26:[function(t,e,r){"use strict";var n=t("./core");n.register([t("./bar"),t("./box"),t("./heatmap"),t("./histogram"),t("./histogram2d"),t("./histogram2dcontour"),t("./contour"),t("./scatterternary"),t("./violin"),t("./funnel"),t("./waterfall"),t("./image"),t("./pie"),t("./sunburst"),t("./treemap"),t("./funnelarea"),t("./scatter3d"),t("./surface"),t("./isosurface"),t("./volume"),t("./mesh3d"),t("./cone"),t("./streamtube"),t("./scattergeo"),t("./choropleth"),t("./scattergl"),t("./splom"),t("./pointcloud"),t("./heatmapgl"),t("./parcoords"),t("./parcats"),t("./scattermapbox"),t("./choroplethmapbox"),t("./densitymapbox"),t("./sankey"),t("./indicator"),t("./table"),t("./carpet"),t("./scattercarpet"),t("./contourcarpet"),t("./ohlc"),t("./candlestick"),t("./scatterpolar"),t("./scatterpolargl"),t("./barpolar")]),n.register([t("./aggregate"),t("./filter"),t("./groupby"),t("./sort")]),n.register([t("./calendars")]),e.exports=n},{"./aggregate":2,"./bar":3,"./barpolar":4,"./box":5,"./calendars":6,"./candlestick":7,"./carpet":8,"./choropleth":9,"./choroplethmapbox":10,"./cone":11,"./contour":12,"./contourcarpet":13,"./core":14,"./densitymapbox":15,"./filter":16,"./funnel":17,"./funnelarea":18,"./groupby":19,"./heatmap":20,"./heatmapgl":21,"./histogram":22,"./histogram2d":23,"./histogram2dcontour":24,"./image":25,"./indicator":27,"./isosurface":28,"./mesh3d":29,"./ohlc":30,"./parcats":31,"./parcoords":32,"./pie":33,"./pointcloud":34,"./sankey":35,"./scatter3d":36,"./scattercarpet":37,"./scattergeo":38,"./scattergl":39,"./scattermapbox":40,"./scatterpolar":41,"./scatterpolargl":42,"./scatterternary":43,"./sort":44,"./splom":45,"./streamtube":46,"./sunburst":47,"./surface":48,"./table":49,"./treemap":50,"./violin":51,"./volume":52,"./waterfall":53}],27:[function(t,e,r){"use strict";e.exports=t("../src/traces/indicator")},{"../src/traces/indicator":1052}],28:[function(t,e,r){"use strict";e.exports=t("../src/traces/isosurface")},{"../src/traces/isosurface":1058}],29:[function(t,e,r){"use strict";e.exports=t("../src/traces/mesh3d")},{"../src/traces/mesh3d":1063}],30:[function(t,e,r){"use strict";e.exports=t("../src/traces/ohlc")},{"../src/traces/ohlc":1068}],31:[function(t,e,r){"use strict";e.exports=t("../src/traces/parcats")},{"../src/traces/parcats":1077}],32:[function(t,e,r){"use strict";e.exports=t("../src/traces/parcoords")},{"../src/traces/parcoords":1087}],33:[function(t,e,r){"use strict";e.exports=t("../src/traces/pie")},{"../src/traces/pie":1098}],34:[function(t,e,r){"use strict";e.exports=t("../src/traces/pointcloud")},{"../src/traces/pointcloud":1107}],35:[function(t,e,r){"use strict";e.exports=t("../src/traces/sankey")},{"../src/traces/sankey":1113}],36:[function(t,e,r){"use strict";e.exports=t("../src/traces/scatter3d")},{"../src/traces/scatter3d":1150}],37:[function(t,e,r){"use strict";e.exports=t("../src/traces/scattercarpet")},{"../src/traces/scattercarpet":1157}],38:[function(t,e,r){"use strict";e.exports=t("../src/traces/scattergeo")},{"../src/traces/scattergeo":1165}],39:[function(t,e,r){"use strict";e.exports=t("../src/traces/scattergl")},{"../src/traces/scattergl":1177}],40:[function(t,e,r){"use strict";e.exports=t("../src/traces/scattermapbox")},{"../src/traces/scattermapbox":1187}],41:[function(t,e,r){"use strict";e.exports=t("../src/traces/scatterpolar")},{"../src/traces/scatterpolar":1195}],42:[function(t,e,r){"use strict";e.exports=t("../src/traces/scatterpolargl")},{"../src/traces/scatterpolargl":1202}],43:[function(t,e,r){"use strict";e.exports=t("../src/traces/scatterternary")},{"../src/traces/scatterternary":1210}],44:[function(t,e,r){"use strict";e.exports=t("../src/transforms/sort")},{"../src/transforms/sort":1298}],45:[function(t,e,r){"use strict";e.exports=t("../src/traces/splom")},{"../src/traces/splom":1219}],46:[function(t,e,r){"use strict";e.exports=t("../src/traces/streamtube")},{"../src/traces/streamtube":1227}],47:[function(t,e,r){"use strict";e.exports=t("../src/traces/sunburst")},{"../src/traces/sunburst":1235}],48:[function(t,e,r){"use strict";e.exports=t("../src/traces/surface")},{"../src/traces/surface":1244}],49:[function(t,e,r){"use strict";e.exports=t("../src/traces/table")},{"../src/traces/table":1252}],50:[function(t,e,r){"use strict";e.exports=t("../src/traces/treemap")},{"../src/traces/treemap":1261}],51:[function(t,e,r){"use strict";e.exports=t("../src/traces/violin")},{"../src/traces/violin":1273}],52:[function(t,e,r){"use strict";e.exports=t("../src/traces/volume")},{"../src/traces/volume":1281}],53:[function(t,e,r){"use strict";e.exports=t("../src/traces/waterfall")},{"../src/traces/waterfall":1289}],54:[function(t,e,r){"use strict";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||"turntable",u=n(),h=a(),f=i();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=t("turntable-camera-controller"),a=t("orbit-camera-controller"),i=t("matrix-camera-controller");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map(function(e){return t[e]}),this._mode=e,this._active=t[e],this._active||(this._mode="turntable",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[["flush",1],["idle",1],["lookAt",4],["rotate",4],["pan",4],["translate",4],["setMatrix",2],["setDistanceLimits",2],["setDistance",2]].forEach(function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push("a"+n);var a="var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i]."+t[0]+"("+r.join()+")}";s[e]=Function.apply(null,r.concat(a))}),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],a=Math.max(r.lastT(),n.lastT());r.recalcMatrix(a),n.setMatrix(a,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{"matrix-camera-controller":434,"orbit-camera-controller":457,"turntable-camera-controller":540}],55:[function(t,e,r){var n,a;n=this,a=function(t,e,r,n,a){"use strict";function i(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}a=a&&a.hasOwnProperty("default")?a.default:a;var l="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t};function c(t,e){return h(t.source,e.source)||t.index-e.index}function u(t,e){return h(t.target,e.target)||t.index-e.index}function h(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:"top"===t.circularLinkType||"bottom"===e.circularLinkType?-1:1}function f(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function v(t){return t.index}function m(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error("missing: "+e);return r}function b(t,e){return e(t)}var _=25,w=10,k=.3;function T(t,e){var r=0,n=0;t.links.forEach(function(a){a.circular&&(a.source.circularLinkType||a.target.circularLinkType?a.circularLinkType=a.source.circularLinkType?a.source.circularLinkType:a.target.circularLinkType:a.circularLinkType=r<n?"top":"bottom","top"==a.circularLinkType?r+=1:n+=1,t.nodes.forEach(function(t){b(t,e)!=b(a.source,e)&&b(t,e)!=b(a.target,e)||(t.circularLinkType=a.circularLinkType)}))}),t.links.forEach(function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),Y(t,e)&&(t.circularLinkType=t.source.circularLinkType))})}function A(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function M(t,e){var r=0;t.sourceLinks.forEach(function(t){r=t.circular&&!Y(t,e)?r+1:r});var n=0;return t.targetLinks.forEach(function(t){n=t.circular&&!Y(t,e)?n+1:n}),r+n}function S(t){var e=t.source.sourceLinks,r=0;e.forEach(function(t){r=t.circular?r+1:r});var n=t.target.targetLinks,a=0;return n.forEach(function(t){a=t.circular?a+1:a}),!(r>1||a>1)}function E(t,e,r){return t.sort(C),t.forEach(function(n,a){var i,o,s=0;if(Y(n,r)&&S(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<a;l++)if(i=t[a],o=t[l],!(i.source.column<o.target.column||i.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}}),t}function L(t,r,a,i){var o=e.min(t.links,function(t){return t.source.y0});t.links.forEach(function(t){t.circular&&(t.circularPathData={})}),E(t.links.filter(function(t){return"top"==t.circularLinkType}),r,i),E(t.links.filter(function(t){return"bottom"==t.circularLinkType}),r,i),t.links.forEach(function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+w,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,Y(e,i)&&S(e))e.circularPathData.leftSmallArcRadius=w+e.width/2,e.circularPathData.leftLargeArcRadius=w+e.width/2,e.circularPathData.rightSmallArcRadius=w+e.width/2,e.circularPathData.rightLargeArcRadius=w+e.width/2,"bottom"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter(function(t){return t.source.column==s&&t.circularLinkType==l});"bottom"==e.circularLinkType?c.sort(O):c.sort(P);var u=0;c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=w+e.width/2+u,e.circularPathData.leftLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),s=e.target.column,c=t.links.filter(function(t){return t.target.column==s&&t.circularLinkType==l}),"bottom"==e.circularLinkType?c.sort(I):c.sort(z),u=0,c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=w+e.width/2+u,e.circularPathData.rightLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),"bottom"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(a,e.source.y1,e.target.y1)+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e="";e="top"==t.circularLinkType?"M"+t.circularPathData.sourceX+" "+t.circularPathData.sourceY+" L"+t.circularPathData.leftInnerExtent+" "+t.circularPathData.sourceY+" A"+t.circularPathData.leftLargeArcRadius+" "+t.circularPathData.leftSmallArcRadius+" 0 0 0 "+t.circularPathData.leftFullExtent+" "+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+" L"+t.circularPathData.leftFullExtent+" "+t.circularPathData.verticalLeftInnerExtent+" A"+t.circularPathData.leftLargeArcRadius+" "+t.circularPathData.leftLargeArcRadius+" 0 0 0 "+t.circularPathData.leftInnerExtent+" "+t.circularPathData.verticalFullExtent+" L"+t.circularPathData.rightInnerExtent+" "+t.circularPathData.verticalFullExtent+" A"+t.circularPathData.rightLargeArcRadius+" "+t.circularPathData.rightLargeArcRadius+" 0 0 0 "+t.circularPathData.rightFullExtent+" "+t.circularPathData.verticalRightInnerExtent+" L"+t.circularPathData.rightFullExtent+" "+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+" A"+t.circularPathData.rightLargeArcRadius+" "+t.circularPathData.rightSmallArcRadius+" 0 0 0 "+t.circularPathData.rightInnerExtent+" "+t.circularPathData.targetY+" L"+t.circularPathData.targetX+" "+t.circularPathData.targetY:"M"+t.circularPathData.sourceX+" "+t.circularPathData.sourceY+" L"+t.circularPathData.leftInnerExtent+" "+t.circularPathData.sourceY+" A"+t.circularPathData.leftLargeArcRadius+" "+t.circularPathData.leftSmallArcRadius+" 0 0 1 "+t.circularPathData.leftFullExtent+" "+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+" L"+t.circularPathData.leftFullExtent+" "+t.circularPathData.verticalLeftInnerExtent+" A"+t.circularPathData.leftLargeArcRadius+" "+t.circularPathData.leftLargeArcRadius+" 0 0 1 "+t.circularPathData.leftInnerExtent+" "+t.circularPathData.verticalFullExtent+" L"+t.circularPathData.rightInnerExtent+" "+t.circularPathData.verticalFullExtent+" A"+t.circularPathData.rightLargeArcRadius+" "+t.circularPathData.rightLargeArcRadius+" 0 0 1 "+t.circularPathData.rightFullExtent+" "+t.circularPathData.verticalRightInnerExtent+" L"+t.circularPathData.rightFullExtent+" "+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+" A"+t.circularPathData.rightLargeArcRadius+" "+t.circularPathData.rightSmallArcRadius+" 0 0 1 "+t.circularPathData.rightInnerExtent+" "+t.circularPathData.targetY+" L"+t.circularPathData.targetX+" "+t.circularPathData.targetY;return e}(e);else{var h=n.linkHorizontal().source(function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]}).target(function(t){return[t.target.x0,t.y1]});e.path=h(e)}})}function C(t,e){return D(t)==D(e)?"bottom"==t.circularLinkType?O(t,e):P(t,e):D(e)-D(t)}function P(t,e){return t.y0-e.y0}function O(t,e){return e.y0-t.y0}function z(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function D(t){return t.target.column-t.source.column}function R(t){return t.target.x0-t.source.x1}function F(t,e){var r=A(t),n=R(e)/Math.tan(r);return"up"==G(t)?t.y1+n:t.y1-n}function B(t,e){var r=A(t),n=R(e)/Math.tan(r);return"up"==G(t)?t.y1-n:t.y1+n}function N(t,e,r,n){t.links.forEach(function(a){if(!a.circular&&a.target.column-a.source.column>1){var i=a.source.column+1,o=a.target.column-1,s=1,l=o-i+1;for(s=1;i<=o;i++,s++)t.nodes.forEach(function(o){if(o.column==i){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=h*a.y0+f*a.y0+p*a.y1+d*a.y1,v=g-a.width/2,m=g+a.width/2;v>o.y0&&v<o.y1?(c=o.y1-v+10,c="bottom"==o.circularLinkType?c:-c,o=V(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&j(o,t)&&V(t,c,e,r)})):m>o.y0&&m<o.y1?(c=m-o.y0+10,o=V(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&V(t,c,e,r)})):v<o.y0&&m>o.y1&&(c=m-o.y0+10,o=V(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&V(t,c,e,r)}))}})}})}function j(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function V(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach(function(t){t.y1=t.y1+e}),t.sourceLinks.forEach(function(t){t.y0=t.y0+e})),t}function U(t,e,r,n){t.nodes.forEach(function(a){n&&a.y+(a.y1-a.y0)>e&&(a.y=a.y-(a.y+(a.y1-a.y0)-e));var i=t.links.filter(function(t){return b(t.source,r)==b(a,r)}),o=i.length;o>1&&i.sort(function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!H(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=B(e,t);return t.y1-r}if(e.target.column>t.target.column)return B(t,e)-e.y1}return t.circular&&!e.circular?"top"==t.circularLinkType?-1:1:e.circular&&!t.circular?"top"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&"top"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&"bottom"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:"top"==t.circularLinkType?-1:1:void 0});var s=a.y0;i.forEach(function(t){t.y0=s+t.width/2,s+=t.width}),i.forEach(function(t,e){if("bottom"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=i[r].width;t.y0=a.y1-n-t.width/2}})})}function q(t,e,r){t.nodes.forEach(function(e){var n=t.links.filter(function(t){return b(t.target,r)==b(e,r)}),a=n.length;a>1&&n.sort(function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!H(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=F(e,t);return t.y0-r}if(t.source.column<e.source.column)return F(t,e)-e.y0}return t.circular&&!e.circular?"top"==t.circularLinkType?-1:1:e.circular&&!t.circular?"top"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&"top"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&"bottom"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:"top"==t.circularLinkType?-1:1:void 0});var i=e.y0;n.forEach(function(t){t.y1=i+t.width/2,i+=t.width}),n.forEach(function(t,r){if("bottom"==t.circularLinkType){for(var i=r+1,o=0;i<a;i++)o+=n[i].width;t.y1=e.y1-o-t.width/2}})})}function H(t,e){return G(t)==G(e)}function G(t){return t.y0-t.y1>0?"up":"down"}function Y(t,e){return b(t.source,e)==b(t.target,e)}t.sankeyCircular=function(){var t,n,i=0,b=0,A=1,S=1,E=24,C=v,P=o,O=m,z=y,I=32,D=2,R=null;function F(){var o={nodes:O.apply(null,arguments),links:z.apply(null,arguments)};!function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,C);t.links.forEach(function(t,r){t.index=r;var n=t.source,a=t.target;"object"!==("undefined"==typeof n?"undefined":l(n))&&(n=t.source=x(e,n)),"object"!==("undefined"==typeof a?"undefined":l(a))&&(a=t.target=x(e,a)),n.sourceLinks.push(t),a.targetLinks.push(t)})}(o),function(t,e,r){var n=0;if(null===r){for(var i=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;i[l]||(i[l]=[]),i[c]||(i[c]=[]),-1===i[l].indexOf(c)&&i[l].push(c)}var u=a(i);u.sort(function(t,e){return t.length-e.length});var h={};for(o=0;o<u.length;o++){var f=u[o],p=f.slice(-2);h[p[0]]||(h[p[0]]={}),h[p[0]][p[1]]=!0}t.links.forEach(function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1})}else t.links.forEach(function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)})}(o,0,R),function(t){t.nodes.forEach(function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,f),e.sum(t.targetLinks,f)),t.sourceLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}),t.targetLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})})}(o),function(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.depth=n,t.sourceLinks.forEach(function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)})});for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.height=n,t.targetLinks.forEach(function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)})});t.nodes.forEach(function(t){t.column=Math.floor(P.call(null,t,n))})}(o),T(o,C),function(a,o,s){var l=r.nest().key(function(t){return t.column}).sortKeys(e.ascending).entries(a.nodes).map(function(t){return t.values});(function(r){if(n){var o=1/0;l.forEach(function(t){var e=S*n/(t.length+1);o=e<o?e:o}),t=o}var s=e.min(l,function(r){return(S-b-(r.length-1)*t)/e.sum(r,f)});s*=k,a.links.forEach(function(t){t.width=t.value*s});var c=function(t){var r=0,n=0,a=0,i=0,o=e.max(t.nodes,function(t){return t.column});return t.links.forEach(function(t){t.circular&&("top"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(i+=t.width),t.source.column==o&&(a+=t.width))}),{top:r=r>0?r+_+w:r,bottom:n=n>0?n+_+w:n,left:i=i>0?i+_+w:i,right:a=a>0?a+_+w:a}}(a),u=function(t,r){var n=e.max(t.nodes,function(t){return t.column}),a=A-i,o=S-b,s=a+r.right+r.left,l=o+r.top+r.bottom,c=a/s,u=o/l;return i=i*c+r.left,A=0==r.right?A:A*c,b=b*u+r.top,S*=u,t.nodes.forEach(function(t){t.x0=i+t.column*((A-i-E)/n),t.x1=t.x0+E}),u}(a,c);s*=u,a.links.forEach(function(t){t.width=t.value*s}),l.forEach(function(t){var e=t.length;t.forEach(function(t,n){t.depth==l.length-1&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):0==t.depth&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):t.partOfCycle?0==M(t,r)?(t.y0=S/2+n,t.y1=t.y0+t.value*s):"top"==t.circularLinkType?(t.y0=b+n,t.y1=t.y0+t.value*s):(t.y0=S-t.value*s-n,t.y1=t.y0+t.value*s):0==c.top||0==c.bottom?(t.y0=(S-b)/e*n,t.y1=t.y0+t.value*s):(t.y0=(S-b)/2-e/2+n,t.y1=t.y0+t.value*s)})})})(s),m();for(var c=1,u=o;u>0;--u)v(c*=.99,s),m();function v(t,r){var n=l.length;l.forEach(function(a){var i=a.length,o=a[0].depth;a.forEach(function(a){var s;if(a.sourceLinks.length||a.targetLinks.length)if(a.partOfCycle&&M(a,r)>0);else if(0==o&&1==i)s=a.y1-a.y0,a.y0=S/2-s/2,a.y1=S/2+s/2;else if(o==n-1&&1==i)s=a.y1-a.y0,a.y0=S/2-s/2,a.y1=S/2+s/2;else{var l=e.mean(a.sourceLinks,g),c=e.mean(a.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(a))*t;a.y0+=u,a.y1+=u}})})}function m(){l.forEach(function(e){var r,n,a,i=b,o=e.length;for(e.sort(h),a=0;a<o;++a)r=e[a],(n=i-r.y0)>0&&(r.y0+=n,r.y1+=n),i=r.y1+t;if((n=i-t-S)>0)for(i=r.y0-=n,r.y1-=n,a=o-2;a>=0;--a)r=e[a],(n=r.y1+t-i)>0&&(r.y0-=n,r.y1-=n),i=r.y0})}}(o,I,C),B(o);for(var s=0;s<4;s++)U(o,S,C),q(o,0,C),N(o,b,S,C),U(o,S,C),q(o,0,C);return function(t,r,n){var a=t.nodes,i=t.links,o=!1,s=!1;if(i.forEach(function(t){"top"==t.circularLinkType?o=!0:"bottom"==t.circularLinkType&&(s=!0)}),0==o||0==s){var l=e.min(a,function(t){return t.y0}),c=e.max(a,function(t){return t.y1}),u=c-l,h=n-r,f=h/u;a.forEach(function(t){var e=(t.y1-t.y0)*f;t.y0=(t.y0-l)*f,t.y1=t.y0+e}),i.forEach(function(t){t.y0=(t.y0-l)*f,t.y1=(t.y1-l)*f,t.width=t.width*f})}}(o,b,S),L(o,D,S,C),o}function B(t){t.nodes.forEach(function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)}),t.nodes.forEach(function(t){var e=t.y0,r=e,n=t.y1,a=n;t.sourceLinks.forEach(function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)}),t.targetLinks.forEach(function(t){t.circular?(t.y1=a-t.width/2,a-=t.width):(t.y1=r+t.width/2,r+=t.width)})})}return F.nodeId=function(t){return arguments.length?(C="function"==typeof t?t:s(t),F):C},F.nodeAlign=function(t){return arguments.length?(P="function"==typeof t?t:s(t),F):P},F.nodeWidth=function(t){return arguments.length?(E=+t,F):E},F.nodePadding=function(e){return arguments.length?(t=+e,F):t},F.nodes=function(t){return arguments.length?(O="function"==typeof t?t:s(t),F):O},F.links=function(t){return arguments.length?(z="function"==typeof t?t:s(t),F):z},F.size=function(t){return arguments.length?(i=b=0,A=+t[0],S=+t[1],F):[A-i,S-b]},F.extent=function(t){return arguments.length?(i=+t[0][0],A=+t[1][0],b=+t[0][1],S=+t[1][1],F):[[i,b],[A,S]]},F.iterations=function(t){return arguments.length?(I=+t,F):I},F.circularLinkGap=function(t){return arguments.length?(D=+t,F):D},F.nodePaddingRatio=function(t){return arguments.length?(n=+t,F):n},F.sortNodes=function(t){return arguments.length?(R=t,F):R},F.update=function(t){return T(t,C),B(t),t.links.forEach(function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<S?"top":"bottom",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)}),U(t,S,C,!1),q(t,0,C),L(t,D,S,C),t},F},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,"__esModule",{value:!0})},"object"==typeof r&&"undefined"!=typeof e?a(r,t("d3-array"),t("d3-collection"),t("d3-shape"),t("elementary-circuits-directed-graph")):a(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)},{"d3-array":153,"d3-collection":154,"d3-shape":162,"elementary-circuits-directed-graph":174}],56:[function(t,e,r){var n,a;n=this,a=function(t,e,r,n){"use strict";function a(t){return t.target.depth}function i(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function h(t){return(t.y0+t.y1)/2}function f(t){return h(t.source)*t.value}function p(t){return h(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function v(t){return t.links}function m(t,e){var r=t.get(e);if(!r)throw new Error("missing: "+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,a=1,y=1,x=24,b=8,_=d,w=i,k=g,T=v,A=32,M=2/3;function S(){var i={nodes:k.apply(null,arguments),links:T.apply(null,arguments)};return function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,_);t.links.forEach(function(t,r){t.index=r;var n=t.source,a=t.target;"object"!=typeof n&&(n=t.source=m(e,n)),"object"!=typeof a&&(a=t.target=m(e,a)),n.sourceLinks.push(t),a.targetLinks.push(t)})}(i),function(t){t.nodes.forEach(function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))})}(i),function(e){var r,n,i;for(r=e.nodes,n=[],i=0;r.length;++i,r=n,n=[])r.forEach(function(t){t.depth=i,t.sourceLinks.forEach(function(t){n.indexOf(t.target)<0&&n.push(t.target)})});for(r=e.nodes,n=[],i=0;r.length;++i,r=n,n=[])r.forEach(function(t){t.height=i,t.targetLinks.forEach(function(t){n.indexOf(t.source)<0&&n.push(t.source)})});var o=(a-t-x)/(i-1);e.nodes.forEach(function(e){e.x1=(e.x0=t+Math.max(0,Math.min(i-1,Math.floor(w.call(null,e,i))))*o)+x})}(i),function(t){var a=r.nest().key(function(t){return t.x0}).sortKeys(e.ascending).entries(t.nodes).map(function(t){return t.values});(function(){var r=e.max(a,function(t){return t.length}),i=M*(y-n)/(r-1);b>i&&(b=i);var o=e.min(a,function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)});a.forEach(function(t){t.forEach(function(t,e){t.y1=(t.y0=e)+t.value*o})}),t.links.forEach(function(t){t.width=t.value*o})})(),d();for(var i=1,o=A;o>0;--o)l(i*=.99),d(),s(i),d();function s(t){a.forEach(function(r){r.forEach(function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,f)/e.sum(r.targetLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function l(t){a.slice().reverse().forEach(function(r){r.forEach(function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function d(){a.forEach(function(t){var e,r,a,i=n,o=t.length;for(t.sort(c),a=0;a<o;++a)e=t[a],(r=i-e.y0)>0&&(e.y0+=r,e.y1+=r),i=e.y1+b;if((r=i-b-y)>0)for(i=e.y0-=r,e.y1-=r,a=o-2;a>=0;--a)e=t[a],(r=e.y1+b-i)>0&&(e.y0-=r,e.y1-=r),i=e.y0})}}(i),E(i),i}function E(t){t.nodes.forEach(function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)}),t.nodes.forEach(function(t){var e=t.y0,r=e;t.sourceLinks.forEach(function(t){t.y0=e+t.width/2,e+=t.width}),t.targetLinks.forEach(function(t){t.y1=r+t.width/2,r+=t.width})})}return S.update=function(t){return E(t),t},S.nodeId=function(t){return arguments.length?(_="function"==typeof t?t:o(t),S):_},S.nodeAlign=function(t){return arguments.length?(w="function"==typeof t?t:o(t),S):w},S.nodeWidth=function(t){return arguments.length?(x=+t,S):x},S.nodePadding=function(t){return arguments.length?(b=+t,S):b},S.nodes=function(t){return arguments.length?(k="function"==typeof t?t:o(t),S):k},S.links=function(t){return arguments.length?(T="function"==typeof t?t:o(t),S):T},S.size=function(e){return arguments.length?(t=n=0,a=+e[0],y=+e[1],S):[a-t,y-n]},S.extent=function(e){return arguments.length?(t=+e[0][0],a=+e[1][0],n=+e[0][1],y=+e[1][1],S):[[t,n],[a,y]]},S.iterations=function(t){return arguments.length?(A=+t,S):A},S},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=i,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,"__esModule",{value:!0})},"object"==typeof r&&"undefined"!=typeof e?a(r,t("d3-array"),t("d3-collection"),t("d3-shape")):a(n.d3=n.d3||{},n.d3,n.d3,n.d3)},{"d3-array":153,"d3-collection":154,"d3-shape":162}],57:[function(t,e,r){"use strict";Object.defineProperty(r,"__esModule",{value:!0});var n=t("@turf/meta"),a=6378137;function i(t){var e=0;if(t&&t.length>0){e+=Math.abs(o(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(o(t[r]))}return e}function o(t){var e,r,n,i,o,l,c=0,u=t.length;if(u>2){for(l=0;l<u;l++)l===u-2?(n=u-2,i=u-1,o=0):l===u-1?(n=u-1,i=0,o=1):(n=l,i=l+1,o=l+2),e=t[n],r=t[i],c+=(s(t[o][0])-s(e[0]))*Math.sin(s(r[1]));c=c*a*a/2}return c}function s(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,function(t,e){return t+function(t){var e,r=0;switch(t.type){case"Polygon":return i(t.coordinates);case"MultiPolygon":for(e=0;e<t.coordinates.length;e++)r+=i(t.coordinates[e]);return r;case"Point":case"MultiPoint":case"LineString":case"MultiLineString":return 0}return 0}(e)},0)}},{"@turf/meta":60}],58:[function(t,e,r){"use strict";Object.defineProperty(r,"__esModule",{value:!0});var n=t("@turf/meta"),a=t("@turf/helpers");r.default=function(t,e){void 0===e&&(e={});var r=0,i=0,o=0;return n.coordEach(t,function(t){r+=t[0],i+=t[1],o++}),a.point([r/o,i/o],e.properties)}},{"@turf/helpers":59,"@turf/meta":60}],59:[function(t,e,r){"use strict";function n(t,e,r){void 0===r&&(r={});var n={type:"Feature"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function a(t,e,r){return void 0===r&&(r={}),n({type:"Point",coordinates:t},e,r)}function i(t,e,r){void 0===r&&(r={});for(var a=0,i=t;a<i.length;a++){var o=i[a];if(o.length<4)throw new Error("Each LinearRing of a Polygon must have 4 or more Positions.");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error("First and last Position are not equivalent.")}return n({type:"Polygon",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error("coordinates must be an array of two or more positions");return n({type:"LineString",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:"FeatureCollection"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:"MultiLineString",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:"MultiPoint",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:"MultiPolygon",coordinates:t},e,r)}function h(t,e){void 0===e&&(e="kilometers");var n=r.factors[e];if(!n)throw new Error(e+" units is invalid");return t*n}function f(t,e){void 0===e&&(e="kilometers");var n=r.factors[e];if(!n)throw new Error(e+" units is invalid");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\s*$/.test(t)}Object.defineProperty(r,"__esModule",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:3.86e-7,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case"Point":return a(e).geometry;case"LineString":return o(e).geometry;case"Polygon":return i(e).geometry;case"MultiPoint":return c(e).geometry;case"MultiLineString":return l(e).geometry;case"MultiPolygon":return u(e).geometry;default:throw new Error(t+" is invalid")}},r.point=a,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return a(t,e)}),r)},r.polygon=i,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return i(t,e)}),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return o(t,e)}),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:"GeometryCollection",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error("precision must be a positive number");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=h,r.lengthToRadians=f,r.lengthToDegrees=function(t,e){return p(f(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e="kilometers"),void 0===r&&(r="kilometers"),!(t>=0))throw new Error("length must be a positive number");return h(f(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e="meters"),void 0===n&&(n="kilometers"),!(t>=0))throw new Error("area must be a positive number");var a=r.areaFactors[e];if(!a)throw new Error("invalid original units");var i=r.areaFactors[n];if(!i)throw new Error("invalid final units");return t/a*i},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error("bbox is required");if(!Array.isArray(t))throw new Error("bbox must be an Array");if(4!==t.length&&6!==t.length)throw new Error("bbox must be an Array of 4 or 6 numbers");t.forEach(function(t){if(!d(t))throw new Error("bbox must only contain numbers")})},r.validateId=function(t){if(!t)throw new Error("id is required");if(-1===["string","number"].indexOf(typeof t))throw new Error("id must be a number or a string")},r.radians2degrees=function(){throw new Error("method has been renamed to `radiansToDegrees`")},r.degrees2radians=function(){throw new Error("method has been renamed to `degreesToRadians`")},r.distanceToDegrees=function(){throw new Error("method has been renamed to `lengthToDegrees`")},r.distanceToRadians=function(){throw new Error("method has been renamed to `lengthToRadians`")},r.radiansToDistance=function(){throw new Error("method has been renamed to `radiansToLength`")},r.bearingToAngle=function(){throw new Error("method has been renamed to `bearingToAzimuth`")},r.convertDistance=function(){throw new Error("method has been renamed to `convertLength`")}},{}],60:[function(t,e,r){"use strict";Object.defineProperty(r,"__esModule",{value:!0});var n=t("@turf/helpers");function a(t,e,r){if(null!==t)for(var n,i,o,s,l,c,u,h,f=0,p=0,d=t.type,g="FeatureCollection"===d,v="Feature"===d,m=g?t.features.length:1,y=0;y<m;y++){l=(h=!!(u=g?t.features[y].geometry:v?t.geometry:t)&&"GeometryCollection"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||"Polygon"!==w&&"MultiPolygon"!==w?0:1,w){case null:break;case"Point":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case"LineString":case"MultiPoint":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,"MultiPoint"===w&&b++}"LineString"===w&&b++;break;case"Polygon":case"MultiLineString":for(n=0;n<c.length;n++){for(i=0;i<c[n].length-f;i++){if(!1===e(c[n][i],p,y,b,_))return!1;p++}"MultiLineString"===w&&b++,"Polygon"===w&&_++}"Polygon"===w&&b++;break;case"MultiPolygon":for(n=0;n<c.length;n++){for(_=0,i=0;i<c[n].length;i++){for(o=0;o<c[n][i].length-f;o++){if(!1===e(c[n][i][o],p,y,b,_))return!1;p++}_++}b++}break;case"GeometryCollection":for(n=0;n<s.geometries.length;n++)if(!1===a(s.geometries[n],e,r))return!1;break;default:throw new Error("Unknown Geometry Type")}}}}}function i(t,e){var r;switch(t.type){case"FeatureCollection":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case"Feature":e(t.properties,0)}}function o(t,e){if("Feature"===t.type)e(t,0);else if("FeatureCollection"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,a,i,o,s,l,c,u,h,f=0,p="FeatureCollection"===t.type,d="Feature"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&"GeometryCollection"===s.type)?s.geometries.length:1,a=0;a<o;a++)if(null!==(i=l?s.geometries[a]:s))switch(i.type){case"Point":case"LineString":case"MultiPoint":case"Polygon":case"MultiLineString":case"MultiPolygon":if(!1===e(i,f,c,u,h))return!1;break;case"GeometryCollection":for(n=0;n<i.geometries.length;n++)if(!1===e(i.geometries[n],f,c,u,h))return!1;break;default:throw new Error("Unknown Geometry Type")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,function(t,r,a,i,o){var s,l=null===t?null:t.type;switch(l){case null:case"Point":case"LineString":case"Polygon":return!1!==e(n.feature(t,a,{bbox:i,id:o}),r,0)&&void 0}switch(l){case"MultiPoint":s="Point";break;case"MultiLineString":s="LineString";break;case"MultiPolygon":s="Polygon"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,a),r,c))return!1}})}function c(t,e){l(t,function(t,r,i){var o=0;if(t.geometry){var s=t.geometry.type;if("Point"!==s&&"MultiPoint"!==s){var l,c=0,u=0,h=0;return!1!==a(t,function(a,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=a,c=r,u=p,h=d,void(o=0);var g=n.lineString([l,a],t.properties);if(!1===e(g,r,i,d,o))return!1;o++,l=a})&&void 0}}})}function u(t,e){if(!t)throw new Error("geojson is required");l(t,function(t,r,a){if(null!==t.geometry){var i=t.geometry.type,o=t.geometry.coordinates;switch(i){case"LineString":if(!1===e(t,r,a,0,0))return!1;break;case"Polygon":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,a,s))return!1}}})}r.coordEach=a,r.coordReduce=function(t,e,r,n){var i=r;return a(t,function(t,n,a,o,s){i=0===n&&void 0===r?t:e(i,t,n,a,o,s)},n),i},r.propEach=i,r.propReduce=function(t,e,r){var n=r;return i(t,function(t,a){n=0===a&&void 0===r?t:e(n,t,a)}),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,function(t,a){n=0===a&&void 0===r?t:e(n,t,a)}),n},r.coordAll=function(t){var e=[];return a(t,function(t){e.push(t)}),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,function(t,a,i,o,s){n=0===a&&void 0===r?t:e(n,t,a,i,o,s)}),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,function(t,a,i){n=0===a&&0===i&&void 0===r?t:e(n,t,a,i)}),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,a=!1;return c(t,function(t,i,o,s,l){n=!1===a&&void 0===r?t:e(n,t,i,o,s,l),a=!0}),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,function(t,a,i,o){n=0===a&&void 0===r?t:e(n,t,a,i,o)}),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error("options is invalid");var r,a=e.featureIndex||0,i=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case"FeatureCollection":a<0&&(a=t.features.length+a),l=l||t.features[a].properties,r=t.features[a].geometry;break;case"Feature":l=l||t.properties,r=t.geometry;break;case"Point":case"MultiPoint":return null;case"LineString":case"Polygon":case"MultiLineString":case"MultiPolygon":r=t;break;default:throw new Error("geojson is invalid")}if(null===r)return null;var c=r.coordinates;switch(r.type){case"Point":case"MultiPoint":return null;case"LineString":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case"Polygon":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case"MultiLineString":return i<0&&(i=c.length+i),s<0&&(s=c[i].length+s-1),n.lineString([c[i][s],c[i][s+1]],l,e);case"MultiPolygon":return i<0&&(i=c.length+i),o<0&&(o=c[i].length+o),s<0&&(s=c[i][o].length-s-1),n.lineString([c[i][o][s],c[i][o][s+1]],l,e)}throw new Error("geojson is invalid")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error("options is invalid");var r,a=e.featureIndex||0,i=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case"FeatureCollection":a<0&&(a=t.features.length+a),l=l||t.features[a].properties,r=t.features[a].geometry;break;case"Feature":l=l||t.properties,r=t.geometry;break;case"Point":case"MultiPoint":return null;case"LineString":case"Polygon":case"MultiLineString":case"MultiPolygon":r=t;break;default:throw new Error("geojson is invalid")}if(null===r)return null;var c=r.coordinates;switch(r.type){case"Point":return n.point(c,l,e);case"MultiPoint":return i<0&&(i=c.length+i),n.point(c[i],l,e);case"LineString":return s<0&&(s=c.length+s),n.point(c[s],l,e);case"Polygon":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case"MultiLineString":return i<0&&(i=c.length+i),s<0&&(s=c[i].length+s),n.point(c[i][s],l,e);case"MultiPolygon":return i<0&&(i=c.length+i),o<0&&(o=c[i].length+o),s<0&&(s=c[i][o].length-s),n.point(c[i][o][s],l,e)}throw new Error("geojson is invalid")}},{"@turf/helpers":59}],61:[function(t,e,r){"use strict";var n="undefined"==typeof WeakMap?t("weak-map"):WeakMap,a=t("gl-buffer"),i=t("gl-vao"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=a(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=i(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{"gl-buffer":243,"gl-vao":328,"weak-map":550}],62:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,a=0;return t.map(function(t){var i=(t=t.slice())[0],o=i.toUpperCase();if(i!=o)switch(t[0]=o,i){case"a":t[6]+=n,t[7]+=a;break;case"v":t[1]+=a;break;case"h":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=a}switch(o){case"Z":n=e,a=r;break;case"H":n=t[1];break;case"V":a=t[1];break;case"M":n=e=t[1],a=r=t[2];break;default:n=t[t.length-2],a=t[t.length-1]}return t})}},{}],63:[function(t,e,r){var n=t("pad-left");e.exports=function(t,e,r){e="number"==typeof e?e:1,r=r||": ";var a=t.split(/\r?\n/),i=String(a.length+e-1).length;return a.map(function(t,a){var o=a+e,s=String(o).length,l=n(o,i-s);return l+r+t}).join("\n")}},{"pad-left":458}],64:[function(t,e,r){"use strict";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],i=[0],o=1;o<e;++o)if(n.push(t[o]),a(n,r)){if(i.push(o),i.length===r+1)return i}else n.pop();return i};var n=t("robust-orientation");function a(t,e){for(var r=new Array(e+1),a=0;a<t.length;++a)r[a]=t[a];for(a=0;a<=t.length;++a){for(var i=t.length;i<=e;++i){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(i+1-a,s);r[i]=o}if(n.apply(void 0,r))return!0}return!1}},{"robust-orientation":508}],65:[function(t,e,r){"use strict";e.exports=function(t,e){return n(e).filter(function(r){for(var n=new Array(r.length),i=0;i<r.length;++i)n[i]=e[r[i]];return a(n)*t<1})};var n=t("delaunay-triangulate"),a=t("circumradius")},{circumradius:115,"delaunay-triangulate":166}],66:[function(t,e,r){e.exports=function(t,e){return a(n(t,e))};var n=t("alpha-complex"),a=t("simplicial-complex-boundary")},{"alpha-complex":65,"simplicial-complex-boundary":515}],67:[function(t,e,r){"use strict";e.exports=function(t,e){if(!t||null==t.length)throw Error("Argument should be an array");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var a=-1/0,i=1/0,o=n,s=t.length;o<s;o+=e)t[o]>a&&(a=t[o]),t[o]<i&&(i=t[o]);r[n]=i,r[e+n]=a}return r}},{}],68:[function(t,e,r){e.exports=function(t,e){var r="number"==typeof t,n="number"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var a=(e|=0)-(t|=0);if(a<0)throw new Error("array length must be positive");for(var i=new Array(a),o=0,s=t;o<a;o++,s++)i[o]=s;return i}},{}],69:[function(t,e,r){(function(r){"use strict";var n=t("object-assign");function a(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,a=0,i=Math.min(r,n);a<i;++a)if(t[a]!==e[a]){r=t[a],n=e[a];break}return r<n?-1:n<r?1:0}function i(t){return r.Buffer&&"function"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t("util/"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c="foo"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function h(t){return!i(t)&&("function"==typeof r.ArrayBuffer&&("function"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=y,p=/\s*function\s+([^\(\s]*)\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return"string"==typeof t?t.length<e?t:t.slice(0,e):t}function v(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return"[Function"+(e?": "+e:"")+"]"}function m(t,e,r,n,a){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:a})}function y(t,e){t||m(t,!0,e,"==",f.ok)}function x(t,e,r,n){if(t===e)return!0;if(i(t)&&i(e))return 0===a(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&"object"==typeof t||null!==e&&"object"==typeof e){if(h(t)&&h(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===a(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(i(t)!==i(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var a=b(t),i=b(e);if(a&&!i||!a&&i)return!1;if(a)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=k(t),h=k(e);if(u.length!==h.length)return!1;for(u.sort(),h.sort(),c=u.length-1;c>=0;c--)if(u[c]!==h[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return"[object Arguments]"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if("[object RegExp]"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var a;if("function"!=typeof e)throw new TypeError('"block" argument must be a function');"string"==typeof r&&(n=r,r=null),a=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?" ("+r.name+").":".")+(n?" "+n:"."),t&&!a&&m(a,r,"Missing expected exception"+n);var i="string"==typeof n,s=!t&&a&&!r;if((!t&&o.isError(a)&&i&&_(a,r)||s)&&m(a,r,"Got unwanted exception"+n),t&&a&&r&&!_(a,r)||!t&&a)throw a}f.AssertionError=function(t){var e;this.name="AssertionError",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=g(v((e=this).actual),128)+" "+e.operator+" "+g(v(e.expected),128),this.generatedMessage=!0);var r=t.stackStartFunction||m;if(Error.captureStackTrace)Error.captureStackTrace(this,r);else{var n=new Error;if(n.stack){var a=n.stack,i=d(r),o=a.indexOf("\n"+i);if(o>=0){var s=a.indexOf("\n",o+1);a=a.substring(s+1)}this.stack=a}}},o.inherits(f.AssertionError,Error),f.fail=m,f.ok=y,f.equal=function(t,e,r){t!=e&&m(t,e,r,"==",f.equal)},f.notEqual=function(t,e,r){t==e&&m(t,e,r,"!=",f.notEqual)},f.deepEqual=function(t,e,r){x(t,e,!1)||m(t,e,r,"deepEqual",f.deepEqual)},f.deepStrictEqual=function(t,e,r){x(t,e,!0)||m(t,e,r,"deepStrictEqual",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){x(t,e,!1)&&m(t,e,r,"notDeepEqual",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&m(e,r,n,"notDeepStrictEqual",t)},f.strictEqual=function(t,e,r){t!==e&&m(t,e,r,"===",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&m(t,e,r,"!==",f.notStrictEqual)},f.throws=function(t,e,r){w(!0,t,e,r)},f.doesNotThrow=function(t,e,r){w(!1,t,e,r)},f.ifError=function(t){if(t)throw t},f.strict=n(function t(e,r){e||m(e,!0,r,"==",t)},f,{equal:f.strictEqual,deepEqual:f.deepStrictEqual,notEqual:f.notStrictEqual,notDeepEqual:f.notDeepStrictEqual}),f.strict.strict=f.strict;var k=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"object-assign":455,"util/":72}],70:[function(t,e,r){"function"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],71:[function(t,e,r){e.exports=function(t){return t&&"object"==typeof t&&"function"==typeof t.copy&&"function"==typeof t.fill&&"function"==typeof t.readUInt8}},{}],72:[function(t,e,r){(function(e,n){var a=/%[sdj%]/g;r.format=function(t){if(!m(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(" ")}r=1;for(var n=arguments,i=n.length,o=String(t).replace(a,function(t){if("%%"===t)return"%";if(r>=i)return t;switch(t){case"%s":return String(n[r++]);case"%d":return Number(n[r++]);case"%j":try{return JSON.stringify(n[r++])}catch(t){return"[Circular]"}default:return t}}),l=n[r];r<i;l=n[++r])g(l)||!b(l)?o+=" "+l:o+=" "+s(l);return o},r.deprecate=function(t,a){if(y(n.process))return function(){return r.deprecate(t,a).apply(this,arguments)};if(!0===e.noDeprecation)return t;var i=!1;return function(){if(!i){if(e.throwDeprecation)throw new Error(a);e.traceDeprecation?console.trace(a):console.error(a),i=!0}return t.apply(this,arguments)}};var i,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?"\x1b["+s.colors[r][0]+"m"+t+"\x1b["+s.colors[r][1]+"m":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&k(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var a=e.inspect(n,t);return m(a)||(a=u(t,a,n)),a}var i=function(t,e){if(y(e))return t.stylize("undefined","undefined");if(m(e)){var r="'"+JSON.stringify(e).replace(/^"|"$/g,"").replace(/'/g,"\\'").replace(/\\"/g,'"')+"'";return t.stylize(r,"string")}if(v(e))return t.stylize(""+e,"number");if(d(e))return t.stylize(""+e,"boolean");if(g(e))return t.stylize("null","null")}(t,e);if(i)return i;var o=Object.keys(e),s=function(t){var e={};return t.forEach(function(t,r){e[t]=!0}),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf("message")>=0||o.indexOf("description")>=0))return h(e);if(0===o.length){if(k(e)){var l=e.name?": "+e.name:"";return t.stylize("[Function"+l+"]","special")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),"regexp");if(_(e))return t.stylize(Date.prototype.toString.call(e),"date");if(w(e))return h(e)}var c,b="",T=!1,A=["{","}"];(p(e)&&(T=!0,A=["[","]"]),k(e))&&(b=" [Function"+(e.name?": "+e.name:"")+"]");return x(e)&&(b=" "+RegExp.prototype.toString.call(e)),_(e)&&(b=" "+Date.prototype.toUTCString.call(e)),w(e)&&(b=" "+h(e)),0!==o.length||T&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),"regexp"):t.stylize("[Object]","special"):(t.seen.push(e),c=T?function(t,e,r,n,a){for(var i=[],o=0,s=e.length;o<s;++o)S(e,String(o))?i.push(f(t,e,r,n,String(o),!0)):i.push("");return a.forEach(function(a){a.match(/^\d+$/)||i.push(f(t,e,r,n,a,!0))}),i}(t,e,n,s,o):o.map(function(r){return f(t,e,n,s,r,T)}),t.seen.pop(),function(t,e,r){if(t.reduce(function(t,e){return 0,e.indexOf("\n")>=0&&0,t+e.replace(/\u001b\[\d\d?m/g,"").length+1},0)>60)return r[0]+(""===e?"":e+"\n ")+" "+t.join(",\n  ")+" "+r[1];return r[0]+e+" "+t.join(", ")+" "+r[1]}(c,b,A)):A[0]+b+A[1]}function h(t){return"["+Error.prototype.toString.call(t)+"]"}function f(t,e,r,n,a,i){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,a)||{value:e[a]}).get?s=l.set?t.stylize("[Getter/Setter]","special"):t.stylize("[Getter]","special"):l.set&&(s=t.stylize("[Setter]","special")),S(n,a)||(o="["+a+"]"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf("\n")>-1&&(s=i?s.split("\n").map(function(t){return"  "+t}).join("\n").substr(2):"\n"+s.split("\n").map(function(t){return"   "+t}).join("\n")):s=t.stylize("[Circular]","special")),y(o)){if(i&&a.match(/^\d+$/))return s;(o=JSON.stringify(""+a)).match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,"name")):(o=o.replace(/'/g,"\\'").replace(/\\"/g,'"').replace(/(^"|"$)/g,"'"),o=t.stylize(o,"string"))}return o+": "+s}function p(t){return Array.isArray(t)}function d(t){return"boolean"==typeof t}function g(t){return null===t}function v(t){return"number"==typeof t}function m(t){return"string"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&"[object RegExp]"===T(t)}function b(t){return"object"==typeof t&&null!==t}function _(t){return b(t)&&"[object Date]"===T(t)}function w(t){return b(t)&&("[object Error]"===T(t)||t instanceof Error)}function k(t){return"function"==typeof t}function T(t){return Object.prototype.toString.call(t)}function A(t){return t<10?"0"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(i)&&(i=e.env.NODE_DEBUG||""),t=t.toUpperCase(),!o[t])if(new RegExp("\\b"+t+"\\b","i").test(i)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error("%s %d: %s",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:"cyan",number:"yellow",boolean:"yellow",undefined:"grey",null:"bold",string:"green",date:"magenta",regexp:"red"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=v,r.isString=m,r.isSymbol=function(t){return"symbol"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=k,r.isPrimitive=function(t){return null===t||"boolean"==typeof t||"number"==typeof t||"string"==typeof t||"symbol"==typeof t||"undefined"==typeof t},r.isBuffer=t("./support/isBuffer");var M=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"];function S(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){var t,e;console.log("%s - %s",(t=new Date,e=[A(t.getHours()),A(t.getMinutes()),A(t.getSeconds())].join(":"),[t.getDate(),M[t.getMonth()],e].join(" ")),r.format.apply(r,arguments))},r.inherits=t("inherits"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t("_process"),"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./support/isBuffer":71,_process:483,inherits:70}],73:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],74:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r=e.length,i=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];i[o]=s}i[r]=new Array(r+1);for(var o=0;o<=r;++o)i[r][o]=1;for(var c=new Array(r+1),o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(i,c),h=a(u[r+1]);0===h&&(h=1);for(var f=new Array(r+1),o=0;o<=r;++o)f[o]=a(u[o])/h;return f};var n=t("robust-linear-solve");function a(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{"robust-linear-solve":507}],75:[function(t,e,r){"use strict";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){var e,r,n=c(t),o=n[0],s=n[1],l=new i(function(t,e,r){return 3*(e+r)/4-r}(0,o,s)),u=0,h=s>0?o-4:o;for(r=0;r<h;r+=4)e=a[t.charCodeAt(r)]<<18|a[t.charCodeAt(r+1)]<<12|a[t.charCodeAt(r+2)]<<6|a[t.charCodeAt(r+3)],l[u++]=e>>16&255,l[u++]=e>>8&255,l[u++]=255&e;2===s&&(e=a[t.charCodeAt(r)]<<2|a[t.charCodeAt(r+1)]>>4,l[u++]=255&e);1===s&&(e=a[t.charCodeAt(r)]<<10|a[t.charCodeAt(r+1)]<<4|a[t.charCodeAt(r+2)]>>2,l[u++]=e>>8&255,l[u++]=255&e);return l},r.fromByteArray=function(t){for(var e,r=t.length,a=r%3,i=[],o=0,s=r-a;o<s;o+=16383)i.push(u(t,o,o+16383>s?s:o+16383));1===a?(e=t[r-1],i.push(n[e>>2]+n[e<<4&63]+"==")):2===a&&(e=(t[r-2]<<8)+t[r-1],i.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+"="));return i.join("")};for(var n=[],a=[],i="undefined"!=typeof Uint8Array?Uint8Array:Array,o="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",s=0,l=o.length;s<l;++s)n[s]=o[s],a[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error("Invalid string. Length must be a multiple of 4");var r=t.indexOf("=");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var a,i,o=[],s=e;s<r;s+=3)a=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(i=a)>>18&63]+n[i>>12&63]+n[i>>6&63]+n[63&i]);return o.join("")}a["-".charCodeAt(0)]=62,a["_".charCodeAt(0)]=63},{}],76:[function(t,e,r){"use strict";var n=t("./lib/rationalize");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{"./lib/rationalize":86}],77:[function(t,e,r){"use strict";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],78:[function(t,e,r){"use strict";var n=t("./lib/rationalize");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{"./lib/rationalize":86}],79:[function(t,e,r){"use strict";var n=t("./is-rat"),a=t("./lib/is-bn"),i=t("./lib/num-to-bn"),o=t("./lib/str-to-bn"),s=t("./lib/rationalize"),l=t("./div");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c=0;var u,h;if(a(e))u=e.clone();else if("string"==typeof e)u=o(e);else{if(0===e)return[i(0),i(1)];if(e===Math.floor(e))u=i(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),c-=256;u=i(e)}}if(n(r))u.mul(r[1]),h=r[0].clone();else if(a(r))h=r.clone();else if("string"==typeof r)h=o(r);else if(r)if(r===Math.floor(r))h=i(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),c+=256;h=i(r)}else h=i(1);c>0?u=u.ushln(c):c<0&&(h=h.ushln(-c));return s(u,h)}},{"./div":78,"./is-rat":80,"./lib/is-bn":84,"./lib/num-to-bn":85,"./lib/rationalize":86,"./lib/str-to-bn":87}],80:[function(t,e,r){"use strict";var n=t("./lib/is-bn");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{"./lib/is-bn":84}],81:[function(t,e,r){"use strict";var n=t("bn.js");e.exports=function(t){return t.cmp(new n(0))}},{"bn.js":95}],82:[function(t,e,r){"use strict";var n=t("./bn-sign");e.exports=function(t){var e=t.length,r=t.words,a=0;if(1===e)a=r[0];else if(2===e)a=r[0]+67108864*r[1];else for(var i=0;i<e;i++){var o=r[i];a+=o*Math.pow(67108864,i)}return n(t)*a}},{"./bn-sign":81}],83:[function(t,e,r){"use strict";var n=t("double-bits"),a=t("bit-twiddle").countTrailingZeros;e.exports=function(t){var e=a(n.lo(t));if(e<32)return e;var r=a(n.hi(t));if(r>20)return 52;return r+32}},{"bit-twiddle":93,"double-bits":168}],84:[function(t,e,r){"use strict";t("bn.js");e.exports=function(t){return t&&"object"==typeof t&&Boolean(t.words)}},{"bn.js":95}],85:[function(t,e,r){"use strict";var n=t("bn.js"),a=t("double-bits");e.exports=function(t){var e=a.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{"bn.js":95,"double-bits":168}],86:[function(t,e,r){"use strict";var n=t("./num-to-bn"),a=t("./bn-sign");e.exports=function(t,e){var r=a(t),i=a(e);if(0===r)return[n(0),n(1)];if(0===i)return[n(0),n(0)];i<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{"./bn-sign":81,"./num-to-bn":85}],87:[function(t,e,r){"use strict";var n=t("bn.js");e.exports=function(t){return new n(t)}},{"bn.js":95}],88:[function(t,e,r){"use strict";var n=t("./lib/rationalize");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{"./lib/rationalize":86}],89:[function(t,e,r){"use strict";var n=t("./lib/bn-sign");e.exports=function(t){return n(t[0])*n(t[1])}},{"./lib/bn-sign":81}],90:[function(t,e,r){"use strict";var n=t("./lib/rationalize");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{"./lib/rationalize":86}],91:[function(t,e,r){"use strict";var n=t("./lib/bn-to-num"),a=t("./lib/ctz");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var i=e.abs().divmod(r.abs()),o=i.div,s=n(o),l=i.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=a(s)+4,h=n(l.ushln(u).divRound(r));return c*(s+h*Math.pow(2,-u))}var f=r.bitLength()-l.bitLength()+53,h=n(l.ushln(f).divRound(r));return f<1023?c*h*Math.pow(2,-f):(h*=Math.pow(2,-1023),c*h*Math.pow(2,1023-f))}},{"./lib/bn-to-num":82,"./lib/ctz":83}],92:[function(t,e,r){"use strict";function n(t,e,r,n,a,i){var o=["function ",t,"(a,l,h,",n.join(","),"){",i?"":"var i=",r?"l-1":"h+1",";while(l<=h){var m=(l+h)>>>1,x=a",a?".get(m)":"[m]"];return i?e.indexOf("c")<0?o.push(";if(x===y){return m}else if(x<=y){"):o.push(";var p=c(x,y);if(p===0){return m}else if(p<=0){"):o.push(";if(",e,"){i=m;"),r?o.push("l=m+1}else{h=m-1}"):o.push("h=m-1}else{l=m+1}"),o.push("}"),i?o.push("return -1};"):o.push("return i};"),o.join("")}function a(t,e,r,a){return new Function([n("A","x"+t+"y",e,["y"],!1,a),n("B","x"+t+"y",e,["y"],!0,a),n("P","c(x,y)"+t+"0",e,["y","c"],!1,a),n("Q","c(x,y)"+t+"0",e,["y","c"],!0,a),"function dispatchBsearch",r,"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch",r].join(""))()}e.exports={ge:a(">=",!1,"GE"),gt:a(">",!1,"GT"),lt:a("<",!0,"LT"),le:a("<=",!0,"LE"),eq:a("-",!0,"EQ",!0)}},{}],93:[function(t,e,r){"use strict";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var a=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,a=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--a;t[e]=n<<a&255}}(a),r.reverse=function(t){return a[255&t]<<24|a[t>>>8&255]<<16|a[t>>>16&255]<<8|a[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],94:[function(t,e,r){"use strict";var n=t("clamp");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,g,v=null==e.cutoff?.25:e.cutoff,m=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error("For raw data width and height should be provided by options");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext("2d"),r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(f=t.canvas,h=t,r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error("Raw data can have only 1 value per pixel");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),k=Array(s+1),T=Array(s);for(d=0,g=r*o;d<g;d++){var A=l[d];x[d]=1===A?0:0===A?a:Math.pow(Math.max(0,.5-A),2),b[d]=1===A?a:0===A?0:Math.pow(Math.max(0,A-.5),2)}i(x,r,o,_,w,T,k),i(b,r,o,_,w,T,k);var M=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)M[d]=n(1-((x[d]-b[d])/m+v),0,1);return M};var a=1e20;function i(t,e,r,n,a,i,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,a,i,s,r),c=0;c<r;c++)t[c*e+l]=a[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,a,i,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(a[l])}}function o(t,e,r,n,i){r[0]=0,n[0]=-a,n[1]=+a;for(var o=1,s=0;o<i;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+a}for(o=0,s=0;o<i;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:116}],95:[function(t,e,r){!function(e,r){"use strict";function n(t,e){if(!t)throw new Error(e||"Assertion failed")}function a(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function i(t,e,r){if(i.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&("le"!==e&&"be"!==e||(r=e,e=10),this._init(t||0,e||10,r||"be"))}var o;"object"==typeof e?e.exports=i:r.BN=i,i.BN=i,i.wordSize=26;try{o=t("buffer").Buffer}catch(t){}function s(t,e,r){for(var n=0,a=Math.min(t.length,r),i=e;i<a;i++){var o=t.charCodeAt(i)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var a=0,i=Math.min(t.length,r),o=e;o<i;o++){var s=t.charCodeAt(o)-48;a*=n,a+=s>=49?s-49+10:s>=17?s-17+10:s}return a}i.isBN=function(t){return t instanceof i||null!==t&&"object"==typeof t&&t.constructor.wordSize===i.wordSize&&Array.isArray(t.words)},i.max=function(t,e){return t.cmp(e)>0?t:e},i.min=function(t,e){return t.cmp(e)<0?t:e},i.prototype._init=function(t,e,r){if("number"==typeof t)return this._initNumber(t,e,r);if("object"==typeof t)return this._initArray(t,e,r);"hex"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var a=0;"-"===(t=t.toString().replace(/\s+/g,""))[0]&&a++,16===e?this._parseHex(t,a):this._parseBase(t,e,a),"-"===t[0]&&(this.negative=1),this.strip(),"le"===r&&this._initArray(this.toArray(),e,r)},i.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),"le"===r&&this._initArray(this.toArray(),e,r)},i.prototype._initArray=function(t,e,r){if(n("number"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var a=0;a<this.length;a++)this.words[a]=0;var i,o,s=0;if("be"===r)for(a=t.length-1,i=0;a>=0;a-=3)o=t[a]|t[a-1]<<8|t[a-2]<<16,this.words[i]|=o<<s&67108863,this.words[i+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,i++);else if("le"===r)for(a=0,i=0;a<t.length;a+=3)o=t[a]|t[a+1]<<8|t[a+2]<<16,this.words[i]|=o<<s&67108863,this.words[i+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,i++);return this.strip()},i.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,a,i=0;for(r=t.length-6,n=0;r>=e;r-=6)a=s(t,r,r+6),this.words[n]|=a<<i&67108863,this.words[n+1]|=a>>>26-i&4194303,(i+=24)>=26&&(i-=26,n++);r+6!==e&&(a=s(t,e,r+6),this.words[n]|=a<<i&67108863,this.words[n+1]|=a>>>26-i&4194303),this.strip()},i.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,a=1;a<=67108863;a*=e)n++;n--,a=a/e|0;for(var i=t.length-r,o=i%n,s=Math.min(i,i-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(a),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var h=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},i.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},i.prototype.clone=function(){var t=new i(null);return this.copy(t),t},i.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},i.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},i.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},i.prototype.inspect=function(){return(this.red?"<BN-R: ":"<BN: ")+this.toString(16)+">"};var c=["","0","00","000","0000","00000","000000","0000000","00000000","000000000","0000000000","00000000000","000000000000","0000000000000","00000000000000","000000000000000","0000000000000000","00000000000000000","000000000000000000","0000000000000000000","00000000000000000000","000000000000000000000","0000000000000000000000","00000000000000000000000","000000000000000000000000","0000000000000000000000000"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function f(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var a=0|t.words[0],i=0|e.words[0],o=a*i,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(a=0|t.words[d])*(i=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}i.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||"hex"===t){r="";for(var a=0,i=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<a|i)).toString(16);r=0!==(i=s>>>24-a&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(a+=2)>=26&&(a-=26,o--)}for(0!==i&&(r=i.toString(16)+r);r.length%e!=0;)r="0"+r;return 0!==this.negative&&(r="-"+r),r}if(t===(0|t)&&t>=2&&t<=36){var f=u[t],p=h[t];r="";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[f-g.length]+g+r}for(this.isZero()&&(r="0"+r);r.length%e!=0;)r="0"+r;return 0!==this.negative&&(r="-"+r),r}n(!1,"Base should be between 2 and 36")},i.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,"Number can only safely store up to 53 bits"),0!==this.negative?-t:t},i.prototype.toJSON=function(){return this.toString(16)},i.prototype.toBuffer=function(t,e){return n("undefined"!=typeof o),this.toArrayLike(o,t,e)},i.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},i.prototype.toArrayLike=function(t,e,r){var a=this.byteLength(),i=r||Math.max(1,a);n(a<=i,"byte array longer than desired length"),n(i>0,"Requested array length <= 0"),this.strip();var o,s,l="le"===e,c=new t(i),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<i;s++)c[s]=0}else{for(s=0;s<i-a;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[i-s-1]=o}return c},Math.clz32?i.prototype._countBits=function(t){return 32-Math.clz32(t)}:i.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},i.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},i.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},i.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},i.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},i.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},i.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},i.prototype.isNeg=function(){return 0!==this.negative},i.prototype.neg=function(){return this.clone().ineg()},i.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},i.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},i.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},i.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},i.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},i.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},i.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},i.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},i.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},i.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},i.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},i.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},i.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},i.prototype.inotn=function(t){n("number"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var a=0;a<e;a++)this.words[a]=67108863&~this.words[a];return r>0&&(this.words[a]=~this.words[a]&67108863>>26-r),this.strip()},i.prototype.notn=function(t){return this.clone().inotn(t)},i.prototype.setn=function(t,e){n("number"==typeof t&&t>=0);var r=t/26|0,a=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<a:this.words[r]&~(1<<a),this.strip()},i.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var a=0,i=0;i<n.length;i++)e=(0|r.words[i])+(0|n.words[i])+a,this.words[i]=67108863&e,a=e>>>26;for(;0!==a&&i<r.length;i++)e=(0|r.words[i])+a,this.words[i]=67108863&e,a=e>>>26;if(this.length=r.length,0!==a)this.words[this.length]=a,this.length++;else if(r!==this)for(;i<r.length;i++)this.words[i]=r.words[i];return this},i.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},i.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,a=this.cmp(t);if(0===a)return this.negative=0,this.length=1,this.words[0]=0,this;a>0?(r=this,n=t):(r=t,n=this);for(var i=0,o=0;o<n.length;o++)i=(e=(0|r.words[o])-(0|n.words[o])+i)>>26,this.words[o]=67108863&e;for(;0!==i&&o<r.length;o++)i=(e=(0|r.words[o])+i)>>26,this.words[o]=67108863&e;if(0===i&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},i.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,a,i,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,v=0|o[2],m=8191&v,y=v>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],k=8191&w,T=w>>>13,A=0|o[5],M=8191&A,S=A>>>13,E=0|o[6],L=8191&E,C=E>>>13,P=0|o[7],O=8191&P,z=P>>>13,I=0|o[8],D=8191&I,R=I>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],V=8191&j,U=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,Q=0|s[4],$=8191&Q,tt=Q>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,at=0|s[6],it=8191&at,ot=at>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var vt=(c+(n=Math.imul(h,V))|0)+((8191&(a=(a=Math.imul(h,U))+Math.imul(f,V)|0))<<13)|0;c=((i=Math.imul(f,U))+(a>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(d,V),a=(a=Math.imul(d,U))+Math.imul(g,V)|0,i=Math.imul(g,U);var mt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(a=(a=a+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((i=i+Math.imul(f,G)|0)+(a>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(m,V),a=(a=Math.imul(m,U))+Math.imul(y,V)|0,i=Math.imul(y,U),n=n+Math.imul(d,H)|0,a=(a=a+Math.imul(d,G)|0)+Math.imul(g,H)|0,i=i+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(a=(a=a+Math.imul(h,X)|0)+Math.imul(f,W)|0))<<13)|0;c=((i=i+Math.imul(f,X)|0)+(a>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,V),a=(a=Math.imul(b,U))+Math.imul(_,V)|0,i=Math.imul(_,U),n=n+Math.imul(m,H)|0,a=(a=a+Math.imul(m,G)|0)+Math.imul(y,H)|0,i=i+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,a=(a=a+Math.imul(d,X)|0)+Math.imul(g,W)|0,i=i+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(h,J)|0)|0)+((8191&(a=(a=a+Math.imul(h,K)|0)+Math.imul(f,J)|0))<<13)|0;c=((i=i+Math.imul(f,K)|0)+(a>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(k,V),a=(a=Math.imul(k,U))+Math.imul(T,V)|0,i=Math.imul(T,U),n=n+Math.imul(b,H)|0,a=(a=a+Math.imul(b,G)|0)+Math.imul(_,H)|0,i=i+Math.imul(_,G)|0,n=n+Math.imul(m,W)|0,a=(a=a+Math.imul(m,X)|0)+Math.imul(y,W)|0,i=i+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,a=(a=a+Math.imul(d,K)|0)+Math.imul(g,J)|0,i=i+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(h,$)|0)|0)+((8191&(a=(a=a+Math.imul(h,tt)|0)+Math.imul(f,$)|0))<<13)|0;c=((i=i+Math.imul(f,tt)|0)+(a>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(M,V),a=(a=Math.imul(M,U))+Math.imul(S,V)|0,i=Math.imul(S,U),n=n+Math.imul(k,H)|0,a=(a=a+Math.imul(k,G)|0)+Math.imul(T,H)|0,i=i+Math.imul(T,G)|0,n=n+Math.imul(b,W)|0,a=(a=a+Math.imul(b,X)|0)+Math.imul(_,W)|0,i=i+Math.imul(_,X)|0,n=n+Math.imul(m,J)|0,a=(a=a+Math.imul(m,K)|0)+Math.imul(y,J)|0,i=i+Math.imul(y,K)|0,n=n+Math.imul(d,$)|0,a=(a=a+Math.imul(d,tt)|0)+Math.imul(g,$)|0,i=i+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(a=(a=a+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((i=i+Math.imul(f,nt)|0)+(a>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(L,V),a=(a=Math.imul(L,U))+Math.imul(C,V)|0,i=Math.imul(C,U),n=n+Math.imul(M,H)|0,a=(a=a+Math.imul(M,G)|0)+Math.imul(S,H)|0,i=i+Math.imul(S,G)|0,n=n+Math.imul(k,W)|0,a=(a=a+Math.imul(k,X)|0)+Math.imul(T,W)|0,i=i+Math.imul(T,X)|0,n=n+Math.imul(b,J)|0,a=(a=a+Math.imul(b,K)|0)+Math.imul(_,J)|0,i=i+Math.imul(_,K)|0,n=n+Math.imul(m,$)|0,a=(a=a+Math.imul(m,tt)|0)+Math.imul(y,$)|0,i=i+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,a=(a=a+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,i=i+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(h,it)|0)|0)+((8191&(a=(a=a+Math.imul(h,ot)|0)+Math.imul(f,it)|0))<<13)|0;c=((i=i+Math.imul(f,ot)|0)+(a>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(O,V),a=(a=Math.imul(O,U))+Math.imul(z,V)|0,i=Math.imul(z,U),n=n+Math.imul(L,H)|0,a=(a=a+Math.imul(L,G)|0)+Math.imul(C,H)|0,i=i+Math.imul(C,G)|0,n=n+Math.imul(M,W)|0,a=(a=a+Math.imul(M,X)|0)+Math.imul(S,W)|0,i=i+Math.imul(S,X)|0,n=n+Math.imul(k,J)|0,a=(a=a+Math.imul(k,K)|0)+Math.imul(T,J)|0,i=i+Math.imul(T,K)|0,n=n+Math.imul(b,$)|0,a=(a=a+Math.imul(b,tt)|0)+Math.imul(_,$)|0,i=i+Math.imul(_,tt)|0,n=n+Math.imul(m,rt)|0,a=(a=a+Math.imul(m,nt)|0)+Math.imul(y,rt)|0,i=i+Math.imul(y,nt)|0,n=n+Math.imul(d,it)|0,a=(a=a+Math.imul(d,ot)|0)+Math.imul(g,it)|0,i=i+Math.imul(g,ot)|0;var kt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(a=(a=a+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((i=i+Math.imul(f,ct)|0)+(a>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(D,V),a=(a=Math.imul(D,U))+Math.imul(R,V)|0,i=Math.imul(R,U),n=n+Math.imul(O,H)|0,a=(a=a+Math.imul(O,G)|0)+Math.imul(z,H)|0,i=i+Math.imul(z,G)|0,n=n+Math.imul(L,W)|0,a=(a=a+Math.imul(L,X)|0)+Math.imul(C,W)|0,i=i+Math.imul(C,X)|0,n=n+Math.imul(M,J)|0,a=(a=a+Math.imul(M,K)|0)+Math.imul(S,J)|0,i=i+Math.imul(S,K)|0,n=n+Math.imul(k,$)|0,a=(a=a+Math.imul(k,tt)|0)+Math.imul(T,$)|0,i=i+Math.imul(T,tt)|0,n=n+Math.imul(b,rt)|0,a=(a=a+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,i=i+Math.imul(_,nt)|0,n=n+Math.imul(m,it)|0,a=(a=a+Math.imul(m,ot)|0)+Math.imul(y,it)|0,i=i+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,a=(a=a+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,i=i+Math.imul(g,ct)|0;var Tt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(a=(a=a+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((i=i+Math.imul(f,ft)|0)+(a>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(B,V),a=(a=Math.imul(B,U))+Math.imul(N,V)|0,i=Math.imul(N,U),n=n+Math.imul(D,H)|0,a=(a=a+Math.imul(D,G)|0)+Math.imul(R,H)|0,i=i+Math.imul(R,G)|0,n=n+Math.imul(O,W)|0,a=(a=a+Math.imul(O,X)|0)+Math.imul(z,W)|0,i=i+Math.imul(z,X)|0,n=n+Math.imul(L,J)|0,a=(a=a+Math.imul(L,K)|0)+Math.imul(C,J)|0,i=i+Math.imul(C,K)|0,n=n+Math.imul(M,$)|0,a=(a=a+Math.imul(M,tt)|0)+Math.imul(S,$)|0,i=i+Math.imul(S,tt)|0,n=n+Math.imul(k,rt)|0,a=(a=a+Math.imul(k,nt)|0)+Math.imul(T,rt)|0,i=i+Math.imul(T,nt)|0,n=n+Math.imul(b,it)|0,a=(a=a+Math.imul(b,ot)|0)+Math.imul(_,it)|0,i=i+Math.imul(_,ot)|0,n=n+Math.imul(m,lt)|0,a=(a=a+Math.imul(m,ct)|0)+Math.imul(y,lt)|0,i=i+Math.imul(y,ct)|0,n=n+Math.imul(d,ht)|0,a=(a=a+Math.imul(d,ft)|0)+Math.imul(g,ht)|0,i=i+Math.imul(g,ft)|0;var At=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(a=(a=a+Math.imul(h,gt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((i=i+Math.imul(f,gt)|0)+(a>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,H),a=(a=Math.imul(B,G))+Math.imul(N,H)|0,i=Math.imul(N,G),n=n+Math.imul(D,W)|0,a=(a=a+Math.imul(D,X)|0)+Math.imul(R,W)|0,i=i+Math.imul(R,X)|0,n=n+Math.imul(O,J)|0,a=(a=a+Math.imul(O,K)|0)+Math.imul(z,J)|0,i=i+Math.imul(z,K)|0,n=n+Math.imul(L,$)|0,a=(a=a+Math.imul(L,tt)|0)+Math.imul(C,$)|0,i=i+Math.imul(C,tt)|0,n=n+Math.imul(M,rt)|0,a=(a=a+Math.imul(M,nt)|0)+Math.imul(S,rt)|0,i=i+Math.imul(S,nt)|0,n=n+Math.imul(k,it)|0,a=(a=a+Math.imul(k,ot)|0)+Math.imul(T,it)|0,i=i+Math.imul(T,ot)|0,n=n+Math.imul(b,lt)|0,a=(a=a+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,i=i+Math.imul(_,ct)|0,n=n+Math.imul(m,ht)|0,a=(a=a+Math.imul(m,ft)|0)+Math.imul(y,ht)|0,i=i+Math.imul(y,ft)|0;var Mt=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(a=(a=a+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((i=i+Math.imul(g,gt)|0)+(a>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,W),a=(a=Math.imul(B,X))+Math.imul(N,W)|0,i=Math.imul(N,X),n=n+Math.imul(D,J)|0,a=(a=a+Math.imul(D,K)|0)+Math.imul(R,J)|0,i=i+Math.imul(R,K)|0,n=n+Math.imul(O,$)|0,a=(a=a+Math.imul(O,tt)|0)+Math.imul(z,$)|0,i=i+Math.imul(z,tt)|0,n=n+Math.imul(L,rt)|0,a=(a=a+Math.imul(L,nt)|0)+Math.imul(C,rt)|0,i=i+Math.imul(C,nt)|0,n=n+Math.imul(M,it)|0,a=(a=a+Math.imul(M,ot)|0)+Math.imul(S,it)|0,i=i+Math.imul(S,ot)|0,n=n+Math.imul(k,lt)|0,a=(a=a+Math.imul(k,ct)|0)+Math.imul(T,lt)|0,i=i+Math.imul(T,ct)|0,n=n+Math.imul(b,ht)|0,a=(a=a+Math.imul(b,ft)|0)+Math.imul(_,ht)|0,i=i+Math.imul(_,ft)|0;var St=(c+(n=n+Math.imul(m,dt)|0)|0)+((8191&(a=(a=a+Math.imul(m,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((i=i+Math.imul(y,gt)|0)+(a>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),a=(a=Math.imul(B,K))+Math.imul(N,J)|0,i=Math.imul(N,K),n=n+Math.imul(D,$)|0,a=(a=a+Math.imul(D,tt)|0)+Math.imul(R,$)|0,i=i+Math.imul(R,tt)|0,n=n+Math.imul(O,rt)|0,a=(a=a+Math.imul(O,nt)|0)+Math.imul(z,rt)|0,i=i+Math.imul(z,nt)|0,n=n+Math.imul(L,it)|0,a=(a=a+Math.imul(L,ot)|0)+Math.imul(C,it)|0,i=i+Math.imul(C,ot)|0,n=n+Math.imul(M,lt)|0,a=(a=a+Math.imul(M,ct)|0)+Math.imul(S,lt)|0,i=i+Math.imul(S,ct)|0,n=n+Math.imul(k,ht)|0,a=(a=a+Math.imul(k,ft)|0)+Math.imul(T,ht)|0,i=i+Math.imul(T,ft)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(a=(a=a+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((i=i+Math.imul(_,gt)|0)+(a>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,$),a=(a=Math.imul(B,tt))+Math.imul(N,$)|0,i=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,a=(a=a+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,i=i+Math.imul(R,nt)|0,n=n+Math.imul(O,it)|0,a=(a=a+Math.imul(O,ot)|0)+Math.imul(z,it)|0,i=i+Math.imul(z,ot)|0,n=n+Math.imul(L,lt)|0,a=(a=a+Math.imul(L,ct)|0)+Math.imul(C,lt)|0,i=i+Math.imul(C,ct)|0,n=n+Math.imul(M,ht)|0,a=(a=a+Math.imul(M,ft)|0)+Math.imul(S,ht)|0,i=i+Math.imul(S,ft)|0;var Lt=(c+(n=n+Math.imul(k,dt)|0)|0)+((8191&(a=(a=a+Math.imul(k,gt)|0)+Math.imul(T,dt)|0))<<13)|0;c=((i=i+Math.imul(T,gt)|0)+(a>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,rt),a=(a=Math.imul(B,nt))+Math.imul(N,rt)|0,i=Math.imul(N,nt),n=n+Math.imul(D,it)|0,a=(a=a+Math.imul(D,ot)|0)+Math.imul(R,it)|0,i=i+Math.imul(R,ot)|0,n=n+Math.imul(O,lt)|0,a=(a=a+Math.imul(O,ct)|0)+Math.imul(z,lt)|0,i=i+Math.imul(z,ct)|0,n=n+Math.imul(L,ht)|0,a=(a=a+Math.imul(L,ft)|0)+Math.imul(C,ht)|0,i=i+Math.imul(C,ft)|0;var Ct=(c+(n=n+Math.imul(M,dt)|0)|0)+((8191&(a=(a=a+Math.imul(M,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((i=i+Math.imul(S,gt)|0)+(a>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,it),a=(a=Math.imul(B,ot))+Math.imul(N,it)|0,i=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,a=(a=a+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,i=i+Math.imul(R,ct)|0,n=n+Math.imul(O,ht)|0,a=(a=a+Math.imul(O,ft)|0)+Math.imul(z,ht)|0,i=i+Math.imul(z,ft)|0;var Pt=(c+(n=n+Math.imul(L,dt)|0)|0)+((8191&(a=(a=a+Math.imul(L,gt)|0)+Math.imul(C,dt)|0))<<13)|0;c=((i=i+Math.imul(C,gt)|0)+(a>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),a=(a=Math.imul(B,ct))+Math.imul(N,lt)|0,i=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,a=(a=a+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,i=i+Math.imul(R,ft)|0;var Ot=(c+(n=n+Math.imul(O,dt)|0)|0)+((8191&(a=(a=a+Math.imul(O,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((i=i+Math.imul(z,gt)|0)+(a>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,n=Math.imul(B,ht),a=(a=Math.imul(B,ft))+Math.imul(N,ht)|0,i=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(a=(a=a+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((i=i+Math.imul(R,gt)|0)+(a>>>13)|0)+(zt>>>26)|0,zt&=67108863;var It=(c+(n=Math.imul(B,dt))|0)+((8191&(a=(a=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((i=Math.imul(N,gt))+(a>>>13)|0)+(It>>>26)|0,It&=67108863,l[0]=vt,l[1]=mt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=kt,l[8]=Tt,l[9]=At,l[10]=Mt,l[11]=St,l[12]=Et,l[13]=Lt,l[14]=Ct,l[15]=Pt,l[16]=Ot,l[17]=zt,l[18]=It,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=f),i.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?f(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,a=0,i=0;i<r.length-1;i++){var o=a;a=0;for(var s=67108863&n,l=Math.min(i,e.length-1),c=Math.max(0,i-t.length+1);c<=l;c++){var u=i-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),a+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[i]=s,n=o,o=a}return 0!==n?r.words[i]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=i.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,a=0;a<e;a++)n|=(1&t)<<e-a-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,a,i){for(var o=0;o<i;o++)n[o]=e[t[o]],a[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,a,i){this.permute(i,t,e,r,n,a);for(var o=1;o<a;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<a;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],v=r[u+p+o],m=n[u+p+o],y=h*v-f*m;m=h*m+f*v,v=y,r[u+p]=d+v,n[u+p]=g+m,r[u+p+o]=d-v,n[u+p+o]=g-m,p!==s&&(y=l*h-c*f,f=l*f+c*h,h=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,a=0;for(r=r/2|0;r;r>>>=1)a++;return 1<<a+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var a=t[n];t[n]=t[r-n-1],t[r-n-1]=a,a=e[n],e[n]=-e[r-n-1],e[r-n-1]=-a}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var a=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&a,r=a<67108864?0:a/67108864|0}return t},g.prototype.convert13b=function(t,e,r,a){for(var i=0,o=0;o<e;o++)i+=0|t[o],r[2*o]=8191&i,i>>>=13,r[2*o+1]=8191&i,i>>>=13;for(o=2*e;o<a;++o)r[o]=0;n(0===i),n(0==(-8192&i))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),a=this.makeRBT(n),i=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,i,s,l,n,a),this.transform(c,i,u,h,n,a);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,i,n,a),this.conjugate(f,i,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},i.prototype.mul=function(t){var e=new i(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},i.prototype.mulf=function(t){var e=new i(null);return e.words=new Array(this.length+t.length),d(this,t,e)},i.prototype.imul=function(t){return this.clone().mulTo(t,this)},i.prototype.imuln=function(t){n("number"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var a=(0|this.words[r])*t,i=(67108863&a)+(67108863&e);e>>=26,e+=a/67108864|0,e+=i>>>26,this.words[r]=67108863&i}return 0!==e&&(this.words[r]=e,this.length++),this},i.prototype.muln=function(t){return this.clone().imuln(t)},i.prototype.sqr=function(){return this.mul(this)},i.prototype.isqr=function(){return this.imul(this.clone())},i.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,a=r%26;e[r]=(t.words[n]&1<<a)>>>a}return e}(t);if(0===e.length)return new i(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var a=r.sqr();n<e.length;n++,a=a.sqr())0!==e[n]&&(r=r.mul(a));return r},i.prototype.iushln=function(t){n("number"==typeof t&&t>=0);var e,r=t%26,a=(t-r)/26,i=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&i,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==a){for(e=this.length-1;e>=0;e--)this.words[e+a]=this.words[e];for(e=0;e<a;e++)this.words[e]=0;this.length+=a}return this.strip()},i.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},i.prototype.iushrn=function(t,e,r){var a;n("number"==typeof t&&t>=0),a=e?(e-e%26)/26:0;var i=t%26,o=Math.min((t-i)/26,this.length),s=67108863^67108863>>>i<<i,l=r;if(a-=o,a=Math.max(0,a),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=a);c--){var h=0|this.words[c];this.words[c]=u<<26-i|h>>>i,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},i.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},i.prototype.shln=function(t){return this.clone().ishln(t)},i.prototype.ushln=function(t){return this.clone().iushln(t)},i.prototype.shrn=function(t){return this.clone().ishrn(t)},i.prototype.ushrn=function(t){return this.clone().iushrn(t)},i.prototype.testn=function(t){n("number"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,a=1<<e;return!(this.length<=r)&&!!(this.words[r]&a)},i.prototype.imaskn=function(t){n("number"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,"imaskn works only with positive numbers"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var a=67108863^67108863>>>e<<e;this.words[this.length-1]&=a}return this.strip()},i.prototype.maskn=function(t){return this.clone().imaskn(t)},i.prototype.iaddn=function(t){return n("number"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},i.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},i.prototype.isubn=function(t){if(n("number"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},i.prototype.addn=function(t){return this.clone().iaddn(t)},i.prototype.subn=function(t){return this.clone().isubn(t)},i.prototype.iabs=function(){return this.negative=0,this},i.prototype.abs=function(){return this.clone().iabs()},i.prototype._ishlnsubmul=function(t,e,r){var a,i,o=t.length+r;this._expand(o);var s=0;for(a=0;a<t.length;a++){i=(0|this.words[a+r])+s;var l=(0|t.words[a])*e;s=((i-=67108863&l)>>26)-(l/67108864|0),this.words[a+r]=67108863&i}for(;a<this.length-r;a++)s=(i=(0|this.words[a+r])+s)>>26,this.words[a+r]=67108863&i;if(0===s)return this.strip();for(n(-1===s),s=0,a=0;a<this.length;a++)s=(i=-(0|this.words[a])+s)>>26,this.words[a]=67108863&i;return this.negative=1,this.strip()},i.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),a=t,o=0|a.words[a.length-1];0!==(r=26-this._countBits(o))&&(a=a.ushln(r),n.iushln(r),o=0|a.words[a.length-1]);var s,l=n.length-a.length;if("mod"!==e){(s=new i(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(a,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[a.length+h])+(0|n.words[a.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(a,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(a,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),"div"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},i.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new i(0),mod:new i(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),"mod"!==e&&(a=s.div.neg()),"div"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:a,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),"mod"!==e&&(a=s.div.neg()),{div:a,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),"div"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new i(0),mod:this}:1===t.length?"div"===e?{div:this.divn(t.words[0]),mod:null}:"mod"===e?{div:null,mod:new i(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new i(this.modn(t.words[0]))}:this._wordDiv(t,e);var a,o,s},i.prototype.div=function(t){return this.divmod(t,"div",!1).div},i.prototype.mod=function(t){return this.divmod(t,"mod",!1).mod},i.prototype.umod=function(t){return this.divmod(t,"mod",!0).mod},i.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),a=t.andln(1),i=r.cmp(n);return i<0||1===a&&0===i?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},i.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,a=this.length-1;a>=0;a--)r=(e*r+(0|this.words[a]))%t;return r},i.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var a=(0|this.words[r])+67108864*e;this.words[r]=a/t|0,e=a%t}return this.strip()},i.prototype.divn=function(t){return this.clone().idivn(t)},i.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var a=new i(1),o=new i(0),s=new i(0),l=new i(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(a.isOdd()||o.isOdd())&&(a.iadd(u),o.isub(h)),a.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),a.isub(s),o.isub(l)):(r.isub(e),s.isub(a),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},i.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var a,o=new i(1),s=new i(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(a=0===e.cmpn(1)?o:s).cmpn(0)<0&&a.iadd(t),a},i.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var a=e.cmp(r);if(a<0){var i=e;e=r,r=i}else if(0===a||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},i.prototype.invm=function(t){return this.egcd(t).a.umod(t)},i.prototype.isEven=function(){return 0==(1&this.words[0])},i.prototype.isOdd=function(){return 1==(1&this.words[0])},i.prototype.andln=function(t){return this.words[0]&t},i.prototype.bincn=function(t){n("number"==typeof t);var e=t%26,r=(t-e)/26,a=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=a,this;for(var i=a,o=r;0!==i&&o<this.length;o++){var s=0|this.words[o];i=(s+=i)>>>26,s&=67108863,this.words[o]=s}return 0!==i&&(this.words[o]=i,this.length++),this},i.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},i.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,"Number is too big");var a=0|this.words[0];e=a===t?0:a<t?-1:1}return 0!==this.negative?0|-e:e},i.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},i.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],a=0|t.words[r];if(n!==a){n<a?e=-1:n>a&&(e=1);break}}return e},i.prototype.gtn=function(t){return 1===this.cmpn(t)},i.prototype.gt=function(t){return 1===this.cmp(t)},i.prototype.gten=function(t){return this.cmpn(t)>=0},i.prototype.gte=function(t){return this.cmp(t)>=0},i.prototype.ltn=function(t){return-1===this.cmpn(t)},i.prototype.lt=function(t){return-1===this.cmp(t)},i.prototype.lten=function(t){return this.cmpn(t)<=0},i.prototype.lte=function(t){return this.cmp(t)<=0},i.prototype.eqn=function(t){return 0===this.cmpn(t)},i.prototype.eq=function(t){return 0===this.cmp(t)},i.red=function(t){return new w(t)},i.prototype.toRed=function(t){return n(!this.red,"Already a number in reduction context"),n(0===this.negative,"red works only with positives"),t.convertTo(this)._forceRed(t)},i.prototype.fromRed=function(){return n(this.red,"fromRed works only with numbers in reduction context"),this.red.convertFrom(this)},i.prototype._forceRed=function(t){return this.red=t,this},i.prototype.forceRed=function(t){return n(!this.red,"Already a number in reduction context"),this._forceRed(t)},i.prototype.redAdd=function(t){return n(this.red,"redAdd works only with red numbers"),this.red.add(this,t)},i.prototype.redIAdd=function(t){return n(this.red,"redIAdd works only with red numbers"),this.red.iadd(this,t)},i.prototype.redSub=function(t){return n(this.red,"redSub works only with red numbers"),this.red.sub(this,t)},i.prototype.redISub=function(t){return n(this.red,"redISub works only with red numbers"),this.red.isub(this,t)},i.prototype.redShl=function(t){return n(this.red,"redShl works only with red numbers"),this.red.shl(this,t)},i.prototype.redMul=function(t){return n(this.red,"redMul works only with red numbers"),this.red._verify2(this,t),this.red.mul(this,t)},i.prototype.redIMul=function(t){return n(this.red,"redMul works only with red numbers"),this.red._verify2(this,t),this.red.imul(this,t)},i.prototype.redSqr=function(){return n(this.red,"redSqr works only with red numbers"),this.red._verify1(this),this.red.sqr(this)},i.prototype.redISqr=function(){return n(this.red,"redISqr works only with red numbers"),this.red._verify1(this),this.red.isqr(this)},i.prototype.redSqrt=function(){return n(this.red,"redSqrt works only with red numbers"),this.red._verify1(this),this.red.sqrt(this)},i.prototype.redInvm=function(){return n(this.red,"redInvm works only with red numbers"),this.red._verify1(this),this.red.invm(this)},i.prototype.redNeg=function(){return n(this.red,"redNeg works only with red numbers"),this.red._verify1(this),this.red.neg(this)},i.prototype.redPow=function(t){return n(this.red&&!t.red,"redPow(normalNum)"),this.red._verify1(this),this.red.pow(this,t)};var v={k256:null,p224:null,p192:null,p25519:null};function m(t,e){this.name=t,this.p=new i(e,16),this.n=this.p.bitLength(),this.k=new i(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){m.call(this,"k256","ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f")}function x(){m.call(this,"p224","ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001")}function b(){m.call(this,"p192","ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff")}function _(){m.call(this,"25519","7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed")}function w(t){if("string"==typeof t){var e=i._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),"modulus must be greater than 1"),this.m=t,this.prime=null}function k(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new i(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}m.prototype._tmp=function(){var t=new i(null);return t.words=new Array(Math.ceil(this.n/13)),t},m.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},m.prototype.split=function(t,e){t.iushrn(this.n,0,e)},m.prototype.imulK=function(t){return t.imul(this.k)},a(y,m),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var a=t.words[9];for(e.words[e.length++]=4194303&a,n=10;n<t.length;n++){var i=0|t.words[n];t.words[n-10]=(4194303&i)<<4|a>>>22,a=i}a>>>=22,t.words[n-10]=a,0===a&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},a(x,m),a(b,m),a(_,m),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,a=67108863&n;n>>>=26,t.words[r]=a,e=n}return 0!==e&&(t.words[t.length++]=e),t},i._prime=function(t){if(v[t])return v[t];var e;if("k256"===t)e=new y;else if("p224"===t)e=new x;else if("p192"===t)e=new b;else{if("p25519"!==t)throw new Error("Unknown prime "+t);e=new _}return v[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,"red works only with positives"),n(t.red,"red works only with red numbers")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),"red works only with positives"),n(t.red&&t.red===e.red,"red works only with red numbers")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new i(1)).iushrn(2);return this.pow(t,r)}for(var a=this.m.subn(1),o=0;!a.isZero()&&0===a.andln(1);)o++,a.iushrn(1);n(!a.isZero());var s=new i(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new i(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,a),f=this.pow(t,a.addn(1).iushrn(1)),p=this.pow(t,a),d=o;0!==p.cmp(s);){for(var g=p,v=0;0!==g.cmp(s);v++)g=g.redSqr();n(v<d);var m=this.pow(h,new i(1).iushln(d-v-1));f=f.redMul(m),h=m.redSqr(),p=p.redMul(h),d=v}return f},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new i(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new i(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var a=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;a!==r[0]&&(a=this.sqr(a)),0!==h||0!==o?(o<<=1,o|=h,(4===++s||0===n&&0===u)&&(a=this.mul(a,r[o]),s=0,o=0)):s=0}l=26}return a},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},i.mont=function(t){return new k(t)},a(k,w),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),a=r.isub(n).iushrn(this.shift),i=a;return a.cmp(this.m)>=0?i=a.isub(this.m):a.cmpn(0)<0&&(i=a.iadd(this.m)),i._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new i(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),a=r.isub(n).iushrn(this.shift),o=a;return a.cmp(this.m)>=0?o=a.isub(this.m):a.cmpn(0)<0&&(o=a.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}("undefined"==typeof e||e,this)},{buffer:104}],96:[function(t,e,r){"use strict";e.exports=function(t){var e,r,n,a=t.length,i=0;for(e=0;e<a;++e)i+=t[e].length;var o=new Array(i),s=0;for(e=0;e<a;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},{}],97:[function(t,e,r){"use strict";e.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(a=t,a,u,!0),n;case 2:return"function"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error("box-intersect: Invalid arguments")}var a};var n,a=t("typedarray-pool"),i=t("./lib/sweep"),o=t("./lib/intersect");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var a=0,i=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[a++]=c[u];n[i++]=o}}return i}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=a.mallocDouble(2*u*s),p=a.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)i.init(s),h=i.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=a.mallocDouble(2*u*c),g=a.mallocInt32(c);(c=l(e,u,d,g))>0&&(i.init(s+c),h=1===u?i.sweepBipartite(u,r,0,s,f,p,0,c,d,g):o(u,r,n,s,f,p,c,d,g),a.free(d),a.free(g))}a.free(f),a.free(p)}return h}}}function u(t,e){n.push([t,e])}},{"./lib/intersect":99,"./lib/sweep":103,"typedarray-pool":543}],98:[function(t,e,r){"use strict";var n="d",a="ax",i="vv",o="fp",s="es",l="rs",c="re",u="rb",h="ri",f="rp",p="bs",d="be",g="bb",v="bi",m="bp",y="rv",x="Q",b=[n,a,i,l,c,u,h,p,d,g,v];function _(t){var e="bruteForce"+(t?"Full":"Partial"),r=[],_=b.slice();t||_.splice(3,0,o);var w=["function "+e+"("+_.join()+"){"];function k(e,o){var _=function(t,e,r){var o="bruteForce"+(t?"Red":"Blue")+(e?"Flip":"")+(r?"Full":""),_=["function ",o,"(",b.join(),"){","var ",s,"=2*",n,";"],w="for(var i="+l+","+f+"="+s+"*"+l+";i<"+c+";++i,"+f+"+="+s+"){var x0="+u+"["+a+"+"+f+"],x1="+u+"["+a+"+"+f+"+"+n+"],xi="+h+"[i];",k="for(var j="+p+","+m+"="+s+"*"+p+";j<"+d+";++j,"+m+"+="+s+"){var y0="+g+"["+a+"+"+m+"],"+(r?"y1="+g+"["+a+"+"+m+"+"+n+"],":"")+"yi="+v+"[j];";return t?_.push(w,x,":",k):_.push(k,x,":",w),r?_.push("if(y1<x0||x1<y0)continue;"):e?_.push("if(y0<=x0||x1<y0)continue;"):_.push("if(y0<x0||x1<y0)continue;"),_.push("for(var k="+a+"+1;k<"+n+";++k){var r0="+u+"[k+"+f+"],r1="+u+"[k+"+n+"+"+f+"],b0="+g+"[k+"+m+"],b1="+g+"[k+"+n+"+"+m+"];if(r1<b0||b1<r0)continue "+x+";}var "+y+"="+i+"("),e?_.push("yi,xi"):_.push("xi,yi"),_.push(");if("+y+"!==void 0)return "+y+";}}}"),{name:o,code:_.join("")}}(e,o,t);r.push(_.code),w.push("return "+_.name+"("+b.join()+");")}w.push("if("+c+"-"+l+">"+d+"-"+p+"){"),t?(k(!0,!1),w.push("}else{"),k(!1,!1)):(w.push("if("+o+"){"),k(!0,!0),w.push("}else{"),k(!0,!1),w.push("}}else{if("+o+"){"),k(!1,!0),w.push("}else{"),k(!1,!1),w.push("}")),w.push("}}return "+e);var T=r.join("")+w.join("");return new Function(T)()}r.partial=_(!1),r.full=_(!0)},{}],99:[function(t,e,r){"use strict";e.exports=function(t,e,r,i,u,S,E,L,C){!function(t,e){var r=8*a.log2(e+1)*(t+1)|0,i=a.nextPow2(b*r);w.length<i&&(n.free(w),w=n.mallocInt32(i));var o=a.nextPow2(_*r);k<o&&(n.free(k),k=n.mallocDouble(o))}(t,i+E);var P,O=0,z=2*t;T(O++,0,0,i,0,E,r?16:0,-1/0,1/0),r||T(O++,0,0,E,0,i,1,-1/0,1/0);for(;O>0;){var I=(O-=1)*b,D=w[I],R=w[I+1],F=w[I+2],B=w[I+3],N=w[I+4],j=w[I+5],V=O*_,U=k[V],q=k[V+1],H=1&j,G=!!(16&j),Y=u,W=S,X=L,Z=C;if(H&&(Y=L,W=C,X=u,Z=S),!(2&j&&(F=v(t,D,R,F,Y,W,q),R>=F)||4&j&&(R=m(t,D,R,F,Y,W,U))>=F)){var J=F-R,K=N-B;if(G){if(t*J*(J+K)<p){if(void 0!==(P=l.scanComplete(t,D,e,R,F,Y,W,B,N,X,Z)))return P;continue}}else{if(t*Math.min(J,K)<h){if(void 0!==(P=o(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}if(t*J*K<f){if(void 0!==(P=l.scanBipartite(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}}var Q=d(t,D,R,F,Y,W,U,q);if(R<Q)if(t*(Q-R)<h){if(void 0!==(P=s(t,D+1,e,R,Q,Y,W,B,N,X,Z)))return P}else if(D===t-2){if(void 0!==(P=H?l.sweepBipartite(t,e,B,N,X,Z,R,Q,Y,W):l.sweepBipartite(t,e,R,Q,Y,W,B,N,X,Z)))return P}else T(O++,D+1,R,Q,B,N,H,-1/0,1/0),T(O++,D+1,B,N,R,Q,1^H,-1/0,1/0);if(Q<F){var $=c(t,D,B,N,X,Z),tt=X[z*$+D],et=g(t,D,$,N,X,Z,tt);if(et<N&&T(O++,D,Q,F,et,N,(4|H)+(G?16:0),tt,q),B<$&&T(O++,D,Q,F,B,$,(2|H)+(G?16:0),U,tt),$+1===et){if(void 0!==(P=G?M(t,D,e,Q,F,Y,W,$,X,Z[$]):A(t,D,e,H,Q,F,Y,W,$,X,Z[$])))return P}else if($<et){var rt;if(G){if(rt=y(t,D,Q,F,Y,W,tt),Q<rt){var nt=g(t,D,Q,rt,Y,W,tt);if(D===t-2){if(Q<nt&&void 0!==(P=l.sweepComplete(t,e,Q,nt,Y,W,$,et,X,Z)))return P;if(nt<rt&&void 0!==(P=l.sweepBipartite(t,e,nt,rt,Y,W,$,et,X,Z)))return P}else Q<nt&&T(O++,D+1,Q,nt,$,et,16,-1/0,1/0),nt<rt&&(T(O++,D+1,nt,rt,$,et,0,-1/0,1/0),T(O++,D+1,$,et,nt,rt,1,-1/0,1/0))}}else rt=H?x(t,D,Q,F,Y,W,tt):y(t,D,Q,F,Y,W,tt),Q<rt&&(D===t-2?P=H?l.sweepBipartite(t,e,$,et,X,Z,Q,rt,Y,W):l.sweepBipartite(t,e,Q,rt,Y,W,$,et,X,Z):(T(O++,D+1,Q,rt,$,et,H,-1/0,1/0),T(O++,D+1,$,et,Q,rt,1^H,-1/0,1/0)))}}}}};var n=t("typedarray-pool"),a=t("bit-twiddle"),i=t("./brute"),o=i.partial,s=i.full,l=t("./sweep"),c=t("./median"),u=t("./partition"),h=128,f=1<<22,p=1<<22,d=u("!(lo>=p0)&&!(p1>=hi)",["p0","p1"]),g=u("lo===p0",["p0"]),v=u("lo<p0",["p0"]),m=u("hi<=p0",["p0"]),y=u("lo<=p0&&p0<=hi",["p0"]),x=u("lo<p0&&p0<=hi",["p0"]),b=6,_=2,w=n.mallocInt32(1024),k=n.mallocDouble(1024);function T(t,e,r,n,a,i,o,s,l){var c=b*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=a,w[c+4]=i,w[c+5]=o;var u=_*t;k[u]=s,k[u+1]=l}function A(t,e,r,n,a,i,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=a,g=a*h;d<i;++d,g+=h){var v=o[g+e],m=o[g+e+t];if(!(p<v||m<p)&&(!n||p!==v)){for(var y,x=s[d],b=e+1;b<t;++b){v=o[g+b],m=o[g+b+t];var _=c[f+b],w=c[f+b+t];if(m<_||w<v)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function M(t,e,r,n,a,i,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<a;++p,d+=u){var g=o[p];if(g!==c){var v=i[d+e],m=i[d+e+t];if(!(f<v||m<f)){for(var y=e+1;y<t;++y){v=i[d+y],m=i[d+y+t];var x=l[h+y],b=l[h+y+t];if(m<x||b<v)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{"./brute":98,"./median":100,"./partition":101,"./sweep":103,"bit-twiddle":93,"typedarray-pool":543}],100:[function(t,e,r){"use strict";e.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;var c=r,u=o,h=o+r>>>1,f=2*t,p=h,d=s[f*h+e];for(;c<u;){if(u-c<a){i(t,e,c,u,s,l),d=s[f*h+e];break}var g=u-c,v=Math.random()*g+c|0,m=s[f*v+e],y=Math.random()*g+c|0,x=s[f*y+e],b=Math.random()*g+c|0,_=s[f*b+e];m<=x?_>=x?(p=y,d=x):m>=_?(p=v,d=m):(p=b,d=_):x>=_?(p=y,d=x):_>=m?(p=v,d=m):(p=b,d=_);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];l[u-1]=l[p],l[p]=M,p=n(t,e,c,u-1,s,l,d);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];if(l[u-1]=l[p],l[p]=M,h<p){for(u=p-1;c<u&&s[f*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<h))break;for(c=p+1;c<u&&s[f*c+e]===d;)c+=1}}return n(t,e,r,h,s,l,s[f*h+e])};var n=t("./partition")("lo<p0",["p0"]),a=8;function i(t,e,r,n,a,i){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=a[s],u=l,h=o*(l-1);u>r&&a[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var g=a[f];a[f]=a[p],a[p]=g}var v=i[u];i[u]=i[u-1],i[u-1]=v}}},{"./partition":101}],101:[function(t,e,r){"use strict";e.exports=function(t,e){var r="abcdef".split("").concat(e),a=[];t.indexOf("lo")>=0&&a.push("lo=e[k+n]");t.indexOf("hi")>=0&&a.push("hi=e[k+o]");return r.push(n.replace("_",a.join()).replace("$",t)),Function.apply(void 0,r)};var n="for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m"},{}],102:[function(t,e,r){"use strict";e.exports=function(t,e){e<=4*n?a(0,e-1,t):function t(e,r,h){var f=(r-e+1)/6|0,p=e+f,d=r-f,g=e+r>>1,v=g-f,m=g+f,y=p,x=v,b=g,_=m,w=d,k=e+1,T=r-1,A=0;c(y,x,h)&&(A=y,y=x,x=A);c(_,w,h)&&(A=_,_=w,w=A);c(y,b,h)&&(A=y,y=b,b=A);c(x,b,h)&&(A=x,x=b,b=A);c(y,_,h)&&(A=y,y=_,_=A);c(b,_,h)&&(A=b,b=_,_=A);c(x,w,h)&&(A=x,x=w,w=A);c(x,b,h)&&(A=x,x=b,b=A);c(_,w,h)&&(A=_,_=w,w=A);var M=h[2*x];var S=h[2*x+1];var E=h[2*_];var L=h[2*_+1];var C=2*y;var P=2*b;var O=2*w;var z=2*p;var I=2*g;var D=2*d;for(var R=0;R<2;++R){var F=h[C+R],B=h[P+R],N=h[O+R];h[z+R]=F,h[I+R]=B,h[D+R]=N}o(v,e,h);o(m,r,h);for(var j=k;j<=T;++j)if(u(j,M,S,h))j!==k&&i(j,k,h),++k;else if(!u(j,E,L,h))for(;;){if(u(T,E,L,h)){u(T,M,S,h)?(s(j,k,T,h),++k,--T):(i(j,T,h),--T);break}if(--T<j)break}l(e,k-1,M,S,h);l(r,T+1,E,L,h);k-2-e<=n?a(e,k-2,h):t(e,k-2,h);r-(T+2)<=n?a(T+2,r,h):t(T+2,r,h);T-k<=n?a(k,T,h):t(k,T,h)}(0,e-1,t)};var n=32;function a(t,e,r){for(var n=2*(t+1),a=t+1;a<=e;++a){for(var i=r[n++],o=r[n++],s=a,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<i)break;if(c===i&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=i,r[l+1]=o}}function i(t,e,r){e*=2;var n=r[t*=2],a=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=a}function o(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function s(t,e,r,n){e*=2,r*=2;var a=n[t*=2],i=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=a,n[r+1]=i}function l(t,e,r,n,a){e*=2,a[t*=2]=a[e],a[e]=r,a[t+1]=a[e+1],a[e+1]=n}function c(t,e,r){e*=2;var n=r[t*=2],a=r[e];return!(n<a)&&(n!==a||r[t+1]>r[e+1])}function u(t,e,r,n){var a=n[t*=2];return a<e||a===e&&n[t+1]<r}},{}],103:[function(t,e,r){"use strict";e.exports={init:function(t){var e=a.nextPow2(t);s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;p.length<r&&(n.free(p),p=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,a,h,f,v,m,y){for(var x=0,b=2*t,_=t-1,w=b-1,k=r;k<n;++k){var T=h[k],A=b*k;p[x++]=a[A+_],p[x++]=-(T+1),p[x++]=a[A+w],p[x++]=T}for(var k=f;k<v;++k){var T=y[k]+o,M=b*k;p[x++]=m[M+_],p[x++]=-T,p[x++]=m[M+w],p[x++]=T}var S=x>>>1;i(p,S);for(var E=0,L=0,k=0;k<S;++k){var C=0|p[2*k+1];if(C>=o)d(c,u,L--,C=C-o|0);else if(C>=0)d(s,l,E--,C);else if(C<=-o){C=-C-o|0;for(var P=0;P<E;++P){var O=e(s[P],C);if(void 0!==O)return O}g(c,u,L++,C)}else{C=-C-1|0;for(var P=0;P<L;++P){var O=e(C,c[P]);if(void 0!==O)return O}g(s,l,E++,C)}}},sweepComplete:function(t,e,r,n,a,o,v,m,y,x){for(var b=0,_=2*t,w=t-1,k=_-1,T=r;T<n;++T){var A=o[T]+1<<1,M=_*T;p[b++]=a[M+w],p[b++]=-A,p[b++]=a[M+k],p[b++]=A}for(var T=v;T<m;++T){var A=x[T]+1<<1,S=_*T;p[b++]=y[S+w],p[b++]=1|-A,p[b++]=y[S+k],p[b++]=1|A}var E=b>>>1;i(p,E);for(var L=0,C=0,P=0,T=0;T<E;++T){var O=0|p[2*T+1],z=1&O;if(T<E-1&&O>>1==p[2*T+3]>>1&&(z=2,T+=1),O<0){for(var I=-(O>>1)-1,D=0;D<P;++D){var R=e(h[D],I);if(void 0!==R)return R}if(0!==z)for(var D=0;D<L;++D){var R=e(s[D],I);if(void 0!==R)return R}if(1!==z)for(var D=0;D<C;++D){var R=e(c[D],I);if(void 0!==R)return R}0===z?g(s,l,L++,I):1===z?g(c,u,C++,I):2===z&&g(h,f,P++,I)}else{var I=(O>>1)-1;0===z?d(s,l,L--,I):1===z?d(c,u,C--,I):2===z&&d(h,f,P--,I)}}},scanBipartite:function(t,e,r,n,a,c,u,h,f,v,m,y){var x=0,b=2*t,_=e,w=e+t,k=1,T=1;n?T=o:k=o;for(var A=a;A<c;++A){var M=A+k,S=b*A;p[x++]=u[S+_],p[x++]=-M,p[x++]=u[S+w],p[x++]=M}for(var A=f;A<v;++A){var M=A+T,E=b*A;p[x++]=m[E+_],p[x++]=-M}var L=x>>>1;i(p,L);for(var C=0,A=0;A<L;++A){var P=0|p[2*A+1];if(P<0){var M=-P,O=!1;if(M>=o?(O=!n,M-=o):(O=!!n,M-=1),O)g(s,l,C++,M);else{var z=y[M],I=b*M,D=m[I+e+1],R=m[I+e+1+t];t:for(var F=0;F<C;++F){var B=s[F],N=b*B;if(!(R<u[N+e+1]||u[N+e+1+t]<D)){for(var j=e+2;j<t;++j)if(m[I+j+t]<u[N+j]||u[N+j+t]<m[I+j])continue t;var V,U=h[B];if(void 0!==(V=n?r(z,U):r(U,z)))return V}}}}else d(s,l,C--,P-k)}},scanComplete:function(t,e,r,n,a,l,c,u,h,f,d){for(var g=0,v=2*t,m=e,y=e+t,x=n;x<a;++x){var b=x+o,_=v*x;p[g++]=l[_+m],p[g++]=-b,p[g++]=l[_+y],p[g++]=b}for(var x=u;x<h;++x){var b=x+1,w=v*x;p[g++]=f[w+m],p[g++]=-b}var k=g>>>1;i(p,k);for(var T=0,x=0;x<k;++x){var A=0|p[2*x+1];if(A<0){var b=-A;if(b>=o)s[T++]=b-o;else{var M=d[b-=1],S=v*b,E=f[S+e+1],L=f[S+e+1+t];t:for(var C=0;C<T;++C){var P=s[C],O=c[P];if(O===M)break;var z=v*P;if(!(L<l[z+e+1]||l[z+e+1+t]<E)){for(var I=e+2;I<t;++I)if(f[S+I+t]<l[z+I]||l[z+I+t]<f[S+I])continue t;var D=r(O,M);if(void 0!==D)return D}}}}else{for(var b=A-o,C=T-1;C>=0;--C)if(s[C]===b){for(var I=C+1;I<T;++I)s[I-1]=s[I];break}--T}}}};var n=t("typedarray-pool"),a=t("bit-twiddle"),i=t("./sort"),o=1<<28,s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),h=n.mallocInt32(1024),f=n.mallocInt32(1024),p=n.mallocDouble(8192);function d(t,e,r,n){var a=e[n],i=t[r-1];t[a]=i,e[i]=a}function g(t,e,r,n){t[r]=n,e[n]=r}},{"./sort":102,"bit-twiddle":93,"typedarray-pool":543}],104:[function(t,e,r){},{}],105:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},a=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},i=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,"_events")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,"x",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function h(t,e,r,a){var i,o,s;if("function"!=typeof r)throw new TypeError('"listener" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit("newListener",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if("function"==typeof s?s=o[e]=a?[r,s]:[s,r]:a?s.unshift(r):s.push(r),!s.warned&&(i=u(t))&&i>0&&s.length>i){s.warned=!0;var l=new Error("Possible EventEmitter memory leak detected. "+s.length+' "'+String(e)+'" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name="MaxListenersExceededWarning",l.emitter=t,l.type=e,l.count=s.length,"object"==typeof console&&console.warn&&console.warn("%s: %s",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function f(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},a=i.call(f,n);return a.listener=r,n.wrapFn=a,a}function d(t,e,r){var n=t._events;if(!n)return[];var a=n[e];return a?"function"==typeof a?r?[a.listener||a]:[a]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(a):v(a,a.length):[]}function g(t){var e=this._events;if(e){var r=e[t];if("function"==typeof r)return 1;if(r)return r.length}return 0}function v(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,"defaultMaxListeners",{enumerable:!0,get:function(){return l},set:function(t){if("number"!=typeof t||t<0||t!=t)throw new TypeError('"defaultMaxListeners" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if("number"!=typeof t||t<0||isNaN(t))throw new TypeError('"n" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,a,i,o,s="error"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled "error" event. ('+e+")");throw l.context=e,l}if(!(r=o[t]))return!1;var c="function"==typeof r;switch(n=arguments.length){case 1:!function(t,e,r){if(e)t.call(r);else for(var n=t.length,a=v(t,n),i=0;i<n;++i)a[i].call(r)}(r,c,this);break;case 2:!function(t,e,r,n){if(e)t.call(r,n);else for(var a=t.length,i=v(t,a),o=0;o<a;++o)i[o].call(r,n)}(r,c,this,arguments[1]);break;case 3:!function(t,e,r,n,a){if(e)t.call(r,n,a);else for(var i=t.length,o=v(t,i),s=0;s<i;++s)o[s].call(r,n,a)}(r,c,this,arguments[1],arguments[2]);break;case 4:!function(t,e,r,n,a,i){if(e)t.call(r,n,a,i);else for(var o=t.length,s=v(t,o),l=0;l<o;++l)s[l].call(r,n,a,i)}(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(a=new Array(n-1),i=1;i<n;i++)a[i-1]=arguments[i];!function(t,e,r,n){if(e)t.apply(r,n);else for(var a=t.length,i=v(t,a),o=0;o<a;++o)i[o].apply(r,n)}(r,c,this,a)}return!0},o.prototype.addListener=function(t,e){return h(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return h(this,t,e,!0)},o.prototype.once=function(t,e){if("function"!=typeof e)throw new TypeError('"listener" argument must be a function');return this.on(t,p(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if("function"!=typeof e)throw new TypeError('"listener" argument must be a function');return this.prependListener(t,p(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,a,i,o,s;if("function"!=typeof e)throw new TypeError('"listener" argument must be a function');if(!(a=this._events))return this;if(!(r=a[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete a[t],a.removeListener&&this.emit("removeListener",t,r.listener||e));else if("function"!=typeof r){for(i=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,i=o;break}if(i<0)return this;0===i?r.shift():function(t,e){for(var r=e,n=r+1,a=t.length;n<a;r+=1,n+=1)t[r]=t[n];t.pop()}(r,i),1===r.length&&(a[t]=r[0]),a.removeListener&&this.emit("removeListener",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,i;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=a(r);for(i=0;i<s.length;++i)"removeListener"!==(o=s[i])&&this.removeAllListeners(o);return this.removeAllListeners("removeListener"),this._events=n(null),this._eventsCount=0,this}if("function"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(i=e.length-1;i>=0;i--)this.removeListener(t,e[i]);return this},o.prototype.listeners=function(t){return d(this,t,!0)},o.prototype.rawListeners=function(t){return d(this,t,!1)},o.listenerCount=function(t,e){return"function"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},o.prototype.listenerCount=g,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],106:[function(t,e,r){(function(e){"use strict";var n=t("base64-js"),a=t("ieee754"),i="function"==typeof Symbol&&"function"==typeof Symbol.for?Symbol.for("nodejs.util.inspect.custom"):null;r.Buffer=e,r.SlowBuffer=function(t){+t!=t&&(t=0);return e.alloc(+t)},r.INSPECT_MAX_BYTES=50;var o=2147483647;function s(t){if(t>o)throw new RangeError('The value "'+t+'" is invalid for option "size"');var r=new Uint8Array(t);return Object.setPrototypeOf(r,e.prototype),r}function e(t,e,r){if("number"==typeof t){if("string"==typeof e)throw new TypeError('The "string" argument must be of type string. Received type number');return u(t)}return l(t,e,r)}function l(t,r,n){if("string"==typeof t)return function(t,r){"string"==typeof r&&""!==r||(r="utf8");if(!e.isEncoding(r))throw new TypeError("Unknown encoding: "+r);var n=0|p(t,r),a=s(n),i=a.write(t,r);i!==n&&(a=a.slice(0,i));return a}(t,r);if(ArrayBuffer.isView(t))return h(t);if(null==t)throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof t);if(j(t,ArrayBuffer)||t&&j(t.buffer,ArrayBuffer))return function(t,r,n){if(r<0||t.byteLength<r)throw new RangeError('"offset" is outside of buffer bounds');if(t.byteLength<r+(n||0))throw new RangeError('"length" is outside of buffer bounds');var a;a=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);return Object.setPrototypeOf(a,e.prototype),a}(t,r,n);if("number"==typeof t)throw new TypeError('The "value" argument must not be of type number. Received type number');var a=t.valueOf&&t.valueOf();if(null!=a&&a!==t)return e.from(a,r,n);var i=function(t){if(e.isBuffer(t)){var r=0|f(t.length),n=s(r);return 0===n.length?n:(t.copy(n,0,0,r),n)}if(void 0!==t.length)return"number"!=typeof t.length||V(t.length)?s(0):h(t);if("Buffer"===t.type&&Array.isArray(t.data))return h(t.data)}(t);if(i)return i;if("undefined"!=typeof Symbol&&null!=Symbol.toPrimitive&&"function"==typeof t[Symbol.toPrimitive])return e.from(t[Symbol.toPrimitive]("string"),r,n);throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof t)}function c(t){if("number"!=typeof t)throw new TypeError('"size" argument must be of type number');if(t<0)throw new RangeError('The value "'+t+'" is invalid for option "size"')}function u(t){return c(t),s(t<0?0:0|f(t))}function h(t){for(var e=t.length<0?0:0|f(t.length),r=s(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function f(t){if(t>=o)throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+o.toString(16)+" bytes");return 0|t}function p(t,r){if(e.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||j(t,ArrayBuffer))return t.byteLength;if("string"!=typeof t)throw new TypeError('The "string" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var n=t.length,a=arguments.length>2&&!0===arguments[2];if(!a&&0===n)return 0;for(var i=!1;;)switch(r){case"ascii":case"latin1":case"binary":return n;case"utf8":case"utf-8":return F(t).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return 2*n;case"hex":return n>>>1;case"base64":return B(t).length;default:if(i)return a?-1:F(t).length;r=(""+r).toLowerCase(),i=!0}}function d(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function g(t,r,n,a,i){if(0===t.length)return-1;if("string"==typeof n?(a=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),V(n=+n)&&(n=i?0:t.length-1),n<0&&(n=t.length+n),n>=t.length){if(i)return-1;n=t.length-1}else if(n<0){if(!i)return-1;n=0}if("string"==typeof r&&(r=e.from(r,a)),e.isBuffer(r))return 0===r.length?-1:v(t,r,n,a,i);if("number"==typeof r)return r&=255,"function"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(t,r,n):Uint8Array.prototype.lastIndexOf.call(t,r,n):v(t,[r],n,a,i);throw new TypeError("val must be string, number or Buffer")}function v(t,e,r,n,a){var i,o=1,s=t.length,l=e.length;if(void 0!==n&&("ucs2"===(n=String(n).toLowerCase())||"ucs-2"===n||"utf16le"===n||"utf-16le"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(a){var u=-1;for(i=r;i<s;i++)if(c(t,i)===c(e,-1===u?0:i-u)){if(-1===u&&(u=i),i-u+1===l)return u*o}else-1!==u&&(i-=i-u),u=-1}else for(r+l>s&&(r=s-l),i=r;i>=0;i--){for(var h=!0,f=0;f<l;f++)if(c(t,i+f)!==c(e,f)){h=!1;break}if(h)return i}return-1}function m(t,e,r,n){r=Number(r)||0;var a=t.length-r;n?(n=Number(n))>a&&(n=a):n=a;var i=e.length;n>i/2&&(n=i/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(V(s))return o;t[r+o]=s}return o}function y(t,e,r,n){return N(F(e,t.length-r),t,r,n)}function x(t,e,r,n){return N(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function b(t,e,r,n){return x(t,e,r,n)}function _(t,e,r,n){return N(B(e),t,r,n)}function w(t,e,r,n){return N(function(t,e){for(var r,n,a,i=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,a=r%256,i.push(a),i.push(n);return i}(e,t.length-r),t,r,n)}function k(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function T(t,e,r){r=Math.min(t.length,r);for(var n=[],a=e;a<r;){var i,o,s,l,c=t[a],u=null,h=c>239?4:c>223?3:c>191?2:1;if(a+h<=r)switch(h){case 1:c<128&&(u=c);break;case 2:128==(192&(i=t[a+1]))&&(l=(31&c)<<6|63&i)>127&&(u=l);break;case 3:i=t[a+1],o=t[a+2],128==(192&i)&&128==(192&o)&&(l=(15&c)<<12|(63&i)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:i=t[a+1],o=t[a+2],s=t[a+3],128==(192&i)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&i)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,h=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),a+=h}return function(t){var e=t.length;if(e<=A)return String.fromCharCode.apply(String,t);var r="",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=A));return r}(n)}r.kMaxLength=o,e.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1),e={foo:function(){return 42}};return Object.setPrototypeOf(e,Uint8Array.prototype),Object.setPrototypeOf(t,e),42===t.foo()}catch(t){return!1}}(),e.TYPED_ARRAY_SUPPORT||"undefined"==typeof console||"function"!=typeof console.error||console.error("This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support."),Object.defineProperty(e.prototype,"parent",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.buffer}}),Object.defineProperty(e.prototype,"offset",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.byteOffset}}),"undefined"!=typeof Symbol&&null!=Symbol.species&&e[Symbol.species]===e&&Object.defineProperty(e,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),e.poolSize=8192,e.from=function(t,e,r){return l(t,e,r)},Object.setPrototypeOf(e.prototype,Uint8Array.prototype),Object.setPrototypeOf(e,Uint8Array),e.alloc=function(t,e,r){return function(t,e,r){return c(t),t<=0?s(t):void 0!==e?"string"==typeof r?s(t).fill(e,r):s(t).fill(e):s(t)}(t,e,r)},e.allocUnsafe=function(t){return u(t)},e.allocUnsafeSlow=function(t){return u(t)},e.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==e.prototype},e.compare=function(t,r){if(j(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),j(r,Uint8Array)&&(r=e.from(r,r.offset,r.byteLength)),!e.isBuffer(t)||!e.isBuffer(r))throw new TypeError('The "buf1", "buf2" arguments must be one of type Buffer or Uint8Array');if(t===r)return 0;for(var n=t.length,a=r.length,i=0,o=Math.min(n,a);i<o;++i)if(t[i]!==r[i]){n=t[i],a=r[i];break}return n<a?-1:a<n?1:0},e.isEncoding=function(t){switch(String(t).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return!0;default:return!1}},e.concat=function(t,r){if(!Array.isArray(t))throw new TypeError('"list" argument must be an Array of Buffers');if(0===t.length)return e.alloc(0);var n;if(void 0===r)for(r=0,n=0;n<t.length;++n)r+=t[n].length;var a=e.allocUnsafe(r),i=0;for(n=0;n<t.length;++n){var o=t[n];if(j(o,Uint8Array)&&(o=e.from(o)),!e.isBuffer(o))throw new TypeError('"list" argument must be an Array of Buffers');o.copy(a,i),i+=o.length}return a},e.byteLength=p,e.prototype._isBuffer=!0,e.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var e=0;e<t;e+=2)d(this,e,e+1);return this},e.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var e=0;e<t;e+=4)d(this,e,e+3),d(this,e+1,e+2);return this},e.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var e=0;e<t;e+=8)d(this,e,e+7),d(this,e+1,e+6),d(this,e+2,e+5),d(this,e+3,e+4);return this},e.prototype.toString=function(){var t=this.length;return 0===t?"":0===arguments.length?T(this,0,t):function(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return"";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return"";if((r>>>=0)<=(e>>>=0))return"";for(t||(t="utf8");;)switch(t){case"hex":return E(this,e,r);case"utf8":case"utf-8":return T(this,e,r);case"ascii":return M(this,e,r);case"latin1":case"binary":return S(this,e,r);case"base64":return k(this,e,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return L(this,e,r);default:if(n)throw new TypeError("Unknown encoding: "+t);t=(t+"").toLowerCase(),n=!0}}.apply(this,arguments)},e.prototype.toLocaleString=e.prototype.toString,e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError("Argument must be a Buffer");return this===t||0===e.compare(this,t)},e.prototype.inspect=function(){var t="",e=r.INSPECT_MAX_BYTES;return t=this.toString("hex",0,e).replace(/(.{2})/g,"$1 ").trim(),this.length>e&&(t+=" ... "),"<Buffer "+t+">"},i&&(e.prototype[i]=e.prototype.inspect),e.prototype.compare=function(t,r,n,a,i){if(j(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),!e.isBuffer(t))throw new TypeError('The "target" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===r&&(r=0),void 0===n&&(n=t?t.length:0),void 0===a&&(a=0),void 0===i&&(i=this.length),r<0||n>t.length||a<0||i>this.length)throw new RangeError("out of range index");if(a>=i&&r>=n)return 0;if(a>=i)return-1;if(r>=n)return 1;if(this===t)return 0;for(var o=(i>>>=0)-(a>>>=0),s=(n>>>=0)-(r>>>=0),l=Math.min(o,s),c=this.slice(a,i),u=t.slice(r,n),h=0;h<l;++h)if(c[h]!==u[h]){o=c[h],s=u[h];break}return o<s?-1:s<o?1:0},e.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},e.prototype.indexOf=function(t,e,r){return g(this,t,e,r,!0)},e.prototype.lastIndexOf=function(t,e,r){return g(this,t,e,r,!1)},e.prototype.write=function(t,e,r,n){if(void 0===e)n="utf8",r=this.length,e=0;else if(void 0===r&&"string"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n="utf8")):(n=r,r=void 0)}var a=this.length-e;if((void 0===r||r>a)&&(r=a),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError("Attempt to write outside buffer bounds");n||(n="utf8");for(var i=!1;;)switch(n){case"hex":return m(this,t,e,r);case"utf8":case"utf-8":return y(this,t,e,r);case"ascii":return x(this,t,e,r);case"latin1":case"binary":return b(this,t,e,r);case"base64":return _(this,t,e,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return w(this,t,e,r);default:if(i)throw new TypeError("Unknown encoding: "+n);n=(""+n).toLowerCase(),i=!0}},e.prototype.toJSON=function(){return{type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};var A=4096;function M(t,e,r){var n="";r=Math.min(t.length,r);for(var a=e;a<r;++a)n+=String.fromCharCode(127&t[a]);return n}function S(t,e,r){var n="";r=Math.min(t.length,r);for(var a=e;a<r;++a)n+=String.fromCharCode(t[a]);return n}function E(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var a="",i=e;i<r;++i)a+=R(t[i]);return a}function L(t,e,r){for(var n=t.slice(e,r),a="",i=0;i<n.length;i+=2)a+=String.fromCharCode(n[i]+256*n[i+1]);return a}function C(t,e,r){if(t%1!=0||t<0)throw new RangeError("offset is not uint");if(t+e>r)throw new RangeError("Trying to access beyond buffer length")}function P(t,r,n,a,i,o){if(!e.isBuffer(t))throw new TypeError('"buffer" argument must be a Buffer instance');if(r>i||r<o)throw new RangeError('"value" argument is out of bounds');if(n+a>t.length)throw new RangeError("Index out of range")}function O(t,e,r,n,a,i){if(r+n>t.length)throw new RangeError("Index out of range");if(r<0)throw new RangeError("Index out of range")}function z(t,e,r,n,i){return e=+e,r>>>=0,i||O(t,0,r,4),a.write(t,e,r,n,23,4),r+4}function I(t,e,r,n,i){return e=+e,r>>>=0,i||O(t,0,r,8),a.write(t,e,r,n,52,8),r+8}e.prototype.slice=function(t,r){var n=this.length;(t=~~t)<0?(t+=n)<0&&(t=0):t>n&&(t=n),(r=void 0===r?n:~~r)<0?(r+=n)<0&&(r=0):r>n&&(r=n),r<t&&(r=t);var a=this.subarray(t,r);return Object.setPrototypeOf(a,e.prototype),a},e.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],a=1,i=0;++i<e&&(a*=256);)n+=this[t+i]*a;return n},e.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t+--e],a=1;e>0&&(a*=256);)n+=this[t+--e]*a;return n},e.prototype.readUInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),this[t]},e.prototype.readUInt16LE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]|this[t+1]<<8},e.prototype.readUInt16BE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]<<8|this[t+1]},e.prototype.readUInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},e.prototype.readUInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},e.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],a=1,i=0;++i<e&&(a*=256);)n+=this[t+i]*a;return n>=(a*=128)&&(n-=Math.pow(2,8*e)),n},e.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=e,a=1,i=this[t+--n];n>0&&(a*=256);)i+=this[t+--n]*a;return i>=(a*=128)&&(i-=Math.pow(2,8*e)),i},e.prototype.readInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},e.prototype.readInt16LE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt16BE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},e.prototype.readInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},e.prototype.readFloatLE=function(t,e){return t>>>=0,e||C(t,4,this.length),a.read(this,t,!0,23,4)},e.prototype.readFloatBE=function(t,e){return t>>>=0,e||C(t,4,this.length),a.read(this,t,!1,23,4)},e.prototype.readDoubleLE=function(t,e){return t>>>=0,e||C(t,8,this.length),a.read(this,t,!0,52,8)},e.prototype.readDoubleBE=function(t,e){return t>>>=0,e||C(t,8,this.length),a.read(this,t,!1,52,8)},e.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||P(this,t,e,r,Math.pow(2,8*r)-1,0);var a=1,i=0;for(this[e]=255&t;++i<r&&(a*=256);)this[e+i]=t/a&255;return e+r},e.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||P(this,t,e,r,Math.pow(2,8*r)-1,0);var a=r-1,i=1;for(this[e+a]=255&t;--a>=0&&(i*=256);)this[e+a]=t/i&255;return e+r},e.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,1,255,0),this[e]=255&t,e+1},e.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},e.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var a=Math.pow(2,8*r-1);P(this,t,e,r,a-1,-a)}var i=0,o=1,s=0;for(this[e]=255&t;++i<r&&(o*=256);)t<0&&0===s&&0!==this[e+i-1]&&(s=1),this[e+i]=(t/o>>0)-s&255;return e+r},e.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var a=Math.pow(2,8*r-1);P(this,t,e,r,a-1,-a)}var i=r-1,o=1,s=0;for(this[e+i]=255&t;--i>=0&&(o*=256);)t<0&&0===s&&0!==this[e+i+1]&&(s=1),this[e+i]=(t/o>>0)-s&255;return e+r},e.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},e.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},e.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||P(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeFloatLE=function(t,e,r){return z(this,t,e,!0,r)},e.prototype.writeFloatBE=function(t,e,r){return z(this,t,e,!1,r)},e.prototype.writeDoubleLE=function(t,e,r){return I(this,t,e,!0,r)},e.prototype.writeDoubleBE=function(t,e,r){return I(this,t,e,!1,r)},e.prototype.copy=function(t,r,n,a){if(!e.isBuffer(t))throw new TypeError("argument should be a Buffer");if(n||(n=0),a||0===a||(a=this.length),r>=t.length&&(r=t.length),r||(r=0),a>0&&a<n&&(a=n),a===n)return 0;if(0===t.length||0===this.length)return 0;if(r<0)throw new RangeError("targetStart out of bounds");if(n<0||n>=this.length)throw new RangeError("Index out of range");if(a<0)throw new RangeError("sourceEnd out of bounds");a>this.length&&(a=this.length),t.length-r<a-n&&(a=t.length-r+n);var i=a-n;if(this===t&&"function"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(r,n,a);else if(this===t&&n<r&&r<a)for(var o=i-1;o>=0;--o)t[o+r]=this[o+n];else Uint8Array.prototype.set.call(t,this.subarray(n,a),r);return i},e.prototype.fill=function(t,r,n,a){if("string"==typeof t){if("string"==typeof r?(a=r,r=0,n=this.length):"string"==typeof n&&(a=n,n=this.length),void 0!==a&&"string"!=typeof a)throw new TypeError("encoding must be a string");if("string"==typeof a&&!e.isEncoding(a))throw new TypeError("Unknown encoding: "+a);if(1===t.length){var i=t.charCodeAt(0);("utf8"===a&&i<128||"latin1"===a)&&(t=i)}}else"number"==typeof t?t&=255:"boolean"==typeof t&&(t=Number(t));if(r<0||this.length<r||this.length<n)throw new RangeError("Out of range index");if(n<=r)return this;var o;if(r>>>=0,n=void 0===n?this.length:n>>>0,t||(t=0),"number"==typeof t)for(o=r;o<n;++o)this[o]=t;else{var s=e.isBuffer(t)?t:e.from(t,a),l=s.length;if(0===l)throw new TypeError('The value "'+t+'" is invalid for argument "value"');for(o=0;o<n-r;++o)this[o+r]=s[o%l]}return this};var D=/[^+/0-9A-Za-z-_]/g;function R(t){return t<16?"0"+t.toString(16):t.toString(16)}function F(t,e){var r;e=e||1/0;for(var n=t.length,a=null,i=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!a){if(r>56319){(e-=3)>-1&&i.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&i.push(239,191,189);continue}a=r;continue}if(r<56320){(e-=3)>-1&&i.push(239,191,189),a=r;continue}r=65536+(a-55296<<10|r-56320)}else a&&(e-=3)>-1&&i.push(239,191,189);if(a=null,r<128){if((e-=1)<0)break;i.push(r)}else if(r<2048){if((e-=2)<0)break;i.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;i.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error("Invalid code point");if((e-=4)<0)break;i.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return i}function B(t){return n.toByteArray(function(t){if((t=(t=t.split("=")[0]).trim().replace(D,"")).length<2)return"";for(;t.length%4!=0;)t+="=";return t}(t))}function N(t,e,r,n){for(var a=0;a<n&&!(a+r>=e.length||a>=t.length);++a)e[a+r]=t[a];return a}function j(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function V(t){return t!=t}}).call(this,t("buffer").Buffer)},{"base64-js":75,buffer:106,ieee754:413}],107:[function(t,e,r){"use strict";var n=t("./lib/monotone"),a=t("./lib/triangulation"),i=t("./lib/delaunay"),o=t("./lib/filter");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,"delaunay",!0),h=!!c(r,"interior",!0),f=!!c(r,"exterior",!0),p=!!c(r,"infinity",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var g=a(t.length,function(t){return t.map(s).sort(l)}(e)),v=0;v<d.length;++v){var m=d[v];g.addTriangle(m[0],m[1],m[2])}return u&&i(t,g),f?h?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{"./lib/delaunay":108,"./lib/filter":109,"./lib/monotone":110,"./lib/triangulation":111}],108:[function(t,e,r){"use strict";var n=t("robust-in-sphere")[4];t("binary-search-bounds");function a(t,e,r,a,i,o){var s=e.opposite(a,i);if(!(s<0)){if(i<a){var l=a;a=i,i=l,l=o,o=s,s=l}e.isConstraint(a,i)||n(t[a],t[i],t[o],t[s])<0&&r.push(a,i)}}e.exports=function(t,e){for(var r=[],i=t.length,o=e.stars,s=0;s<i;++s)for(var l=o[s],c=1;c<l.length;c+=2){var u=l[c];if(!(u<s)&&!e.isConstraint(s,u)){for(var h=l[c-1],f=-1,p=1;p<l.length;p+=2)if(l[p-1]===u){f=l[p];break}f<0||n(t[s],t[u],t[h],t[f])<0&&r.push(s,u)}}for(;r.length>0;){for(var u=r.pop(),s=r.pop(),h=-1,f=-1,l=o[s],d=1;d<l.length;d+=2){var g=l[d-1],v=l[d];g===u?f=v:v===u&&(h=g)}h<0||f<0||(n(t[s],t[u],t[h],t[f])>=0||(e.flip(s,u),a(t,e,r,h,s,f),a(t,e,r,s,f,h),a(t,e,r,f,u,h),a(t,e,r,u,h,f)))}}},{"binary-search-bounds":112,"robust-in-sphere":506}],109:[function(t,e,r){"use strict";var n,a=t("binary-search-bounds");function i(t,e,r,n,a,i,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=a,this.next=i,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,a=0;a<n;++a){var s=r[a],l=s[0],c=s[1],u=s[2];c<u?c<l&&(s[0]=c,s[1]=u,s[2]=l):u<l&&(s[0]=u,s[1]=l,s[2]=c)}r.sort(o);for(var h=new Array(n),a=0;a<h.length;++a)h[a]=0;var f=[],p=[],d=new Array(3*n),g=new Array(3*n),v=null;e&&(v=[]);for(var m=new i(r,d,g,h,f,p,v),a=0;a<n;++a)for(var s=r[a],y=0;y<3;++y){var l=s[y],c=s[(y+1)%3],x=d[3*a+y]=m.locate(c,l,t.opposite(c,l)),b=g[3*a+y]=t.isConstraint(l,c);x<0&&(b?p.push(a):(f.push(a),h[a]=1),e&&v.push([c,l,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var a=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-a){c[p]=a;u[p];for(var d=0;d<3;++d){var g=f[3*p+d];g>=0&&0===c[g]&&(h[3*p+d]?l.push(g):(s.push(g),c[g]=a))}}}var v=l;l=s,s=v,l.length=0,a=-a}var m=function(t,e,r){for(var n=0,a=0;a<t.length;++a)e[a]===r&&(t[n++]=t[a]);return t.length=n,t}(u,c,e);if(r)return m.concat(n.boundary);return m},i.prototype.locate=(n=[0,0,0],function(t,e,r){var i=t,s=e,l=r;return e<r?e<t&&(i=e,s=r,l=t):r<t&&(i=r,s=t,l=e),i<0?-1:(n[0]=i,n[1]=s,n[2]=l,a.eq(this.cells,n,o))})},{"binary-search-bounds":112}],110:[function(t,e,r){"use strict";var n=t("binary-search-bounds"),a=t("robust-orientation")[3],i=0,o=1,s=2;function l(t,e,r,n,a){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=a}function c(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function u(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(t.type!==i&&(r=a(t.a,t.b,e.b))?r:t.idx-e.idx)}function h(t,e){return a(t.a,t.b,e)}function f(t,e,r,i,o){for(var s=n.lt(e,i,h),l=n.gt(e,i,h),c=s;c<l;++c){for(var u=e[c],f=u.lowerIds,p=f.length;p>1&&a(r[f[p-2]],r[f[p-1]],i)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=u.upperIds;for(p=d.length;p>1&&a(r[d[p-2]],r[d[p-1]],i)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function p(t,e){var r;return(r=t.a[0]<e.a[0]?a(t.a,t.b,e.a):a(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?a(t.a,t.b,e.b):a(e.b,e.a,t.b))||t.idx-e.idx}function d(t,e,r){var a=n.le(t,r,p),i=t[a],o=i.upperIds,s=o[o.length-1];i.upperIds=[s],t.splice(a+1,0,new l(r.a,r.b,r.idx,[s],o))}function g(t,e,r){var a=r.a;r.a=r.b,r.b=a;var i=n.eq(t,r,p),o=t[i];t[i-1].upperIds=o.upperIds,t.splice(i,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,a=[],h=0;h<r;++h)a.push(new c(t[h],null,i,h));for(var h=0;h<n;++h){var p=e[h],v=t[p[0]],m=t[p[1]];v[0]<m[0]?a.push(new c(v,m,s,h),new c(m,v,o,h)):v[0]>m[0]&&a.push(new c(m,v,s,h),new c(v,m,o,h))}a.sort(u);for(var y=a[0].a[0]-(1+Math.abs(a[0].a[0]))*Math.pow(2,-52),x=[new l([y,1],[y,0],-1,[],[],[],[])],b=[],h=0,_=a.length;h<_;++h){var w=a[h],k=w.type;k===i?f(b,x,t,w.a,w.idx):k===s?d(x,t,w):g(x,t,w)}return b}},{"binary-search-bounds":112,"robust-orientation":508}],111:[function(t,e,r){"use strict";var n=t("binary-search-bounds");function a(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new a(r,e)};var i=a.prototype;function o(t,e,r){for(var n=1,a=t.length;n<a;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[a-2],t[n]=t[a-1],void(t.length=a-2)}i.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,a){return t[0]=Math.min(r,a),t[1]=Math.max(r,a),n.eq(this.edges,t,e)>=0}}(),i.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},i.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},i.opposite=function(t,e){for(var r=this.stars[e],n=1,a=r.length;n<a;n+=2)if(r[n]===t)return r[n-1];return-1},i.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},i.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0,o=a.length;i<o;i+=2)e.push([a[i],a[i+1]]);return e},i.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0,o=a.length;i<o;i+=2){var s=a[i],l=a[i+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{"binary-search-bounds":112}],112:[function(t,e,r){"use strict";function n(t,e,r,n,a){var i=["function ",t,"(a,l,h,",n.join(","),"){",a?"":"var i=",r?"l-1":"h+1",";while(l<=h){var m=(l+h)>>>1,x=a[m]"];return a?e.indexOf("c")<0?i.push(";if(x===y){return m}else if(x<=y){"):i.push(";var p=c(x,y);if(p===0){return m}else if(p<=0){"):i.push(";if(",e,"){i=m;"),r?i.push("l=m+1}else{h=m-1}"):i.push("h=m-1}else{l=m+1}"),i.push("}"),a?i.push("return -1};"):i.push("return i};"),i.join("")}function a(t,e,r,a){return new Function([n("A","x"+t+"y",e,["y"],a),n("P","c(x,y)"+t+"0",e,["y","c"],a),"function dispatchBsearch",r,"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch",r].join(""))()}e.exports={ge:a(">=",!1,"GE"),gt:a(">",!1,"GT"),lt:a("<",!0,"LT"),le:a("<=",!0,"LE"),eq:a("-",!0,"EQ",!0)}},{}],113:[function(t,e,r){"use strict";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],114:[function(t,e,r){"use strict";var n=t("dup"),a=t("robust-linear-solve");function i(t,e){for(var r=0,n=t.length,a=0;a<n;++a)r+=t[a]*e[a];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*i(t[s],t[l]);o[s]=i(t[s],t[s])}var c=a(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),a=o(t),i=0;i<t.length;++i)for(var s=0;s<e;++s)r[s]+=t[i][s]*a[i];return r}s.barycenetric=o,e.exports=s},{dup:171,"robust-linear-solve":507}],115:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,a=0;a<t.length;++a)for(var i=t[a],o=0;o<e.length;++o)r+=Math.pow(i[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t("circumcenter")},{circumcenter:114}],116:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],117:[function(t,e,r){"use strict";e.exports=function(t,e,r){var n;if(r){n=e;for(var a=new Array(e.length),i=0;i<e.length;++i){var o=e[i];a[i]=[o[0],o[1],r[i]]}e=a}var s=function(t,e,r){var n=d(t,[],p(t));return m(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(var i=0;i<e.length;++i){var o=e[i];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t("union-find"),a=t("box-intersect"),i=t("robust-segment-intersect"),o=t("big-rat"),s=t("big-rat/cmp"),l=t("big-rat/to-float"),c=t("rat-vec"),u=t("nextafter"),h=t("./lib/rat-seg-intersect");function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var i=e.length,o=new n(i),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}a(s,function(t,e){o.link(t,e)});var d=!0,g=new Array(i);for(l=0;l<i;++l){(m=o.find(l))!==l&&(d=!1,t[m]=[Math.min(t[l][0],t[m][0]),Math.min(t[l][1],t[m][1])])}if(d)return null;var v=0;for(l=0;l<i;++l){var m;(m=o.find(l))===l?(g[l]=v,t[v++]=t[l]):g[l]=-1}t.length=v;for(l=0;l<i;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function v(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function m(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var a=e[(o=t[n])[0]],i=e[o[1]];o[0]=Math.min(a,i),o[1]=Math.max(a,i)}else for(n=0;n<t.length;++n){var o;a=(o=t[n])[0],i=o[1];o[0]=Math.min(a,i),o[1]=Math.max(a,i)}r?t.sort(v):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var a=e[n],i=t[a[0]],o=t[a[1]];r[n]=[u(Math.min(i[0],o[0]),-1/0),u(Math.min(i[1],o[1]),-1/0),u(Math.max(i[0],o[0]),1/0),u(Math.max(i[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return a(r,function(r,a){var o=e[r],s=e[a];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];i(l,c,u,h)&&n.push([r,a])}}),n}(t,e,n),g=p(t),v=function(t,e,r,n){var o=[];return a(r,n,function(r,n){var a=e[r];if(a[0]!==n&&a[1]!==n){var s=t[n],l=t[a[0]],c=t[a[1]];i(l,c,s,s)&&o.push([r,n])}}),o}(t,e,n,g),y=d(t,function(t,e,r,n,a){var i,u,f=t.map(function(t){return[o(t[0]),o(t[1])]});for(i=0;i<r.length;++i){var p=r[i];u=p[0];var d=p[1],g=e[u],v=e[d],m=h(c(t[g[0]]),c(t[g[1]]),c(t[v[0]]),c(t[v[1]]));if(m){var y=t.length;t.push([l(m[0]),l(m[1])]),f.push(m),n.push([u,y],[d,y])}}for(n.sort(function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])}),i=n.length-1;i>=0;--i){var x=e[u=(S=n[i])[0]],b=x[0],_=x[1],w=t[b],k=t[_];if((w[0]-k[0]||w[1]-k[1])<0){var T=b;b=_,_=T}x[0]=b;var A,M=x[1]=S[1];for(a&&(A=x[2]);i>0&&n[i-1][0]===u;){var S,E=(S=n[--i])[1];a?e.push([M,E,A]):e.push([M,E]),M=E}a?e.push([M,_,A]):e.push([M,_])}return f}(t,e,f,v,r));return m(e,y,r),!!y||(f.length>0||v.length>0)}},{"./lib/rat-seg-intersect":118,"big-rat":79,"big-rat/cmp":77,"big-rat/to-float":91,"box-intersect":97,nextafter:452,"rat-vec":487,"robust-segment-intersect":511,"union-find":544}],118:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){var i=s(e,t),h=s(n,r),f=u(i,h);if(0===o(f))return null;var p=s(t,r),d=u(h,p),g=a(d,f),v=c(i,g);return l(t,v)};var n=t("big-rat/mul"),a=t("big-rat/div"),i=t("big-rat/sub"),o=t("big-rat/sign"),s=t("rat-vec/sub"),l=t("rat-vec/add"),c=t("rat-vec/muls");function u(t,e){return i(n(t[0],e[1]),n(t[1],e[0]))}},{"big-rat/div":78,"big-rat/mul":88,"big-rat/sign":89,"big-rat/sub":90,"rat-vec/add":486,"rat-vec/muls":488,"rat-vec/sub":489}],119:[function(t,e,r){"use strict";var n=t("clamp");function a(t,e){null==e&&(e=!0);var r=t[0],a=t[1],i=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,a*=255,i*=255,o*=255),16777216*(r=255&n(r,0,255))+((a=255&n(a,0,255))<<16)+((i=255&n(i,0,255))<<8)+(o=255&n(o,0,255))}e.exports=a,e.exports.to=a,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,a=(65280&t)>>>8,i=255&t;return!1===e?[r,n,a,i]:[r/255,n/255,a/255,i/255]}},{clamp:116}],120:[function(t,e,r){"use strict";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],121:[function(t,e,r){"use strict";var n=t("color-rgba"),a=t("clamp"),i=t("dtype");e.exports=function(t,e){"float"!==e&&e||(e="array"),"uint"===e&&(e="uint8"),"uint_clamped"===e&&(e="uint8_clamped");var r=new(i(e))(4),o="uint8"!==e&&"uint8_clamped"!==e;return t.length&&"string"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=a(Math.floor(255*t[0]),0,255),r[1]=a(Math.floor(255*t[1]),0,255),r[2]=a(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:a(Math.floor(255*t[3]),0,255)),r)}},{clamp:116,"color-rgba":123,dtype:170}],122:[function(t,e,r){(function(r){"use strict";var n=t("color-name"),a=t("is-plain-obj"),i=t("defined");e.exports=function(t){var e,s,l=[],c=1;if("string"==typeof t)if(n[t])l=n[t].slice(),s="rgb";else if("transparent"===t)c=0,s="rgb",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=t.slice(1),h=u.length,f=h<=4;c=1,f?(l=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===h&&(c=parseInt(u[3]+u[3],16)/255)):(l=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===h&&(c=parseInt(u[6]+u[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s="rgb"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\s*\(([^\)]*)\)/.exec(t)){var p=e[1],d="rgb"===p,u=p.replace(/a$/,"");s=u;var h="cmyk"===u?4:"gray"===u?1:3;l=e[2].trim().split(/\s*,\s*/).map(function(t,e){if(/%$/.test(t))return e===h?parseFloat(t)/100:"rgb"===u?255*parseFloat(t)/100:parseFloat(t);if("h"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)}),p===u&&l.push(1),c=d?1:void 0===l[h]?1:l[h],l=l.slice(0,h)}else t.length>10&&/[0-9](?:\s|\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map(function(t){return parseFloat(t)}),s=t.match(/([a-z])/gi).join("").toLowerCase());else if(isNaN(t))if(a(t)){var g=i(t.r,t.red,t.R,null);null!==g?(s="rgb",l=[g,i(t.g,t.green,t.G),i(t.b,t.blue,t.B)]):(s="hsl",l=[i(t.h,t.hue,t.H),i(t.s,t.saturation,t.S),i(t.l,t.lightness,t.L,t.b,t.brightness)]),c=i(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s="rgb",c=4===t.length?t[3]:1);else s="rgb",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"color-name":120,defined:165,"is-plain-obj":423}],123:[function(t,e,r){"use strict";var n=t("color-parse"),a=t("color-space/hsl"),i=t("clamp");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=i(r.values[0],0,255),e[1]=i(r.values[1],0,255),e[2]=i(r.values[2],0,255),"h"===r.space[0]&&(e=a.rgb(e)),e.push(i(r.alpha,0,1)),e):[]}},{clamp:116,"color-parse":122,"color-space/hsl":124}],124:[function(t,e,r){"use strict";var n=t("./rgb");e.exports={name:"hsl",min:[0,0,0],max:[360,100,100],channel:["hue","saturation","lightness"],alias:["HSL"],rgb:function(t){var e,r,n,a,i,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[i=255*l,i,i];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),a=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,i=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,a[c]=255*i;return a}},n.hsl=function(t){var e,r,n=t[0]/255,a=t[1]/255,i=t[2]/255,o=Math.min(n,a,i),s=Math.max(n,a,i),l=s-o;return s===o?e=0:n===s?e=(a-i)/l:a===s?e=2+(i-n)/l:i===s&&(e=4+(n-a)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{"./rgb":125}],125:[function(t,e,r){"use strict";e.exports={name:"rgb",min:[0,0,0],max:[255,255,255],channel:["red","green","blue"],alias:["RGB"]}},{}],126:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],"rainbow-soft":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],"freesurface-blue":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],"freesurface-red":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],"velocity-blue":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],"velocity-green":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],127:[function(t,e,r){"use strict";var n=t("./colorScale"),a=t("lerp");function i(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r="#",n=0;n<3;++n)r+=("00"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return"rgba("+t.join(",")+")"}e.exports=function(t){var e,r,l,c,u,h,f,p,d,g;t||(t={});p=(t.nshades||72)-1,f=t.format||"hex",(h=t.colormap)||(h="jet");if("string"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+" not a supported colorscale");u=n[h]}else{if(!Array.isArray(h))throw Error("unsupported colormap option",h);u=h.slice()}if(u.length>p+1)throw new Error(h+" map requires nshades to be at least size "+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():"number"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map(function(t){return Math.round(t.index*p)}),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var v=u.map(function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1?n:(n[3]=d[0]+(d[1]-d[0])*r,n)}),m=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=v[g],l=v[g+1];for(var y=0;y<c;y++){var x=y/c;m.push([Math.round(a(r[0],l[0],x)),Math.round(a(r[1],l[1],x)),Math.round(a(r[2],l[2],x)),a(r[3],l[3],x)])}}m.push(u[u.length-1].rgb.concat(d[1])),"hex"===f?m=m.map(o):"rgbaString"===f?m=m.map(s):"float"===f&&(m=m.map(i));return m}},{"./colorScale":126,lerp:426}],128:[function(t,e,r){"use strict";e.exports=function(t,e,r,i){var o=n(e,r,i);if(0===o){var s=a(n(t,e,r)),c=a(n(t,e,i));if(s===c){if(0===s){var u=l(t,e,r),h=l(t,e,i);return u===h?0:u?1:-1}return 0}return 0===c?s>0?-1:l(t,e,i)?-1:1:0===s?c>0?1:l(t,e,r)?1:-1:a(c-s)}var f=n(t,e,r);if(f>0)return o>0&&n(t,e,i)>0?1:-1;if(f<0)return o>0||n(t,e,i)>0?1:-1;var p=n(t,e,i);return p>0?1:l(t,e,r)?1:-1};var n=t("robust-orientation"),a=t("signum"),i=t("two-sum"),o=t("robust-product"),s=t("robust-sum");function l(t,e,r){var n=i(t[0],-e[0]),a=i(t[1],-e[1]),l=i(r[0],-e[0]),c=i(r[1],-e[1]),u=s(o(n,l),o(a,c));return u[u.length-1]>=0}},{"robust-orientation":508,"robust-product":509,"robust-sum":513,signum:514,"two-sum":542}],129:[function(t,e,r){e.exports=function(t,e){var r=t.length,i=t.length-e.length;if(i)return i;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(i=o+t[2]-(s+e[2]))return i;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=e[0],g=e[1],v=e[2],m=e[3];return u+h+f+p-(d+g+v+m)||n(u,h,f,p)-n(d,g,v,m,d)||n(u+h,u+f,u+p,h+f,h+p,f+p)-n(d+g,d+v,d+m,g+v,g+m,v+m)||n(u+h+f,u+h+p,u+f+p,h+f+p)-n(d+g+v,d+g+m,d+v+m,g+v+m);default:for(var y=t.slice().sort(a),x=e.slice().sort(a),b=0;b<r;++b)if(i=y[b]-x[b])return i;return 0}};var n=Math.min;function a(t,e){return t-e}},{}],130:[function(t,e,r){"use strict";var n=t("compare-cell"),a=t("cell-orientation");e.exports=function(t,e){return n(t,e)||a(t)-a(e)}},{"cell-orientation":113,"compare-cell":129}],131:[function(t,e,r){"use strict";var n=t("./lib/ch1d"),a=t("./lib/ch2d"),i=t("./lib/chnd");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return a(t);return i(t,r)}},{"./lib/ch1d":132,"./lib/ch2d":133,"./lib/chnd":134}],132:[function(t,e,r){"use strict";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],133:[function(t,e,r){"use strict";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var a=new Array(r),i=e[r-1],o=0;o<r;++o){var s=e[o];a[o]=[i,s],i=s}return a};var n=t("monotone-convex-hull-2d")},{"monotone-convex-hull-2d":435}],134:[function(t,e,r){"use strict";e.exports=function(t,e){try{return n(t,!0)}catch(s){var r=a(t);if(r.length<=e)return[];var i=function(t,e){for(var r=t.length,n=new Array(r),a=0;a<e.length;++a)n[a]=t[e[a]];for(var i=e.length,a=0;a<r;++a)e.indexOf(a)<0&&(n[i++]=t[a]);return n}(t,r),o=n(i,!0);return function(t,e){for(var r=t.length,n=e.length,a=0;a<r;++a)for(var i=t[a],o=0;o<i.length;++o){var s=i[o];if(s<n)i[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);i[o]=s}}return t}(o,r)}};var n=t("incremental-convex-hull"),a=t("affine-hull")},{"affine-hull":64,"incremental-convex-hull":414}],135:[function(t,e,r){e.exports={AFG:"afghan",ALA:"\\b\\wland",ALB:"albania",DZA:"algeria",ASM:"^(?=.*americ).*samoa",AND:"andorra",AGO:"angola",AIA:"anguill?a",ATA:"antarctica",ATG:"antigua",ARG:"argentin",ARM:"armenia",ABW:"^(?!.*bonaire).*\\baruba",AUS:"australia",AUT:"^(?!.*hungary).*austria|\\baustri.*\\bemp",AZE:"azerbaijan",BHS:"bahamas",BHR:"bahrain",BGD:"bangladesh|^(?=.*east).*paki?stan",BRB:"barbados",BLR:"belarus|byelo",BEL:"^(?!.*luxem).*belgium",BLZ:"belize|^(?=.*british).*honduras",BEN:"benin|dahome",BMU:"bermuda",BTN:"bhutan",BOL:"bolivia",BES:"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\bbes.?islands",BIH:"herzegovina|bosnia",BWA:"botswana|bechuana",BVT:"bouvet",BRA:"brazil",IOT:"british.?indian.?ocean",BRN:"brunei",BGR:"bulgaria",BFA:"burkina|\\bfaso|upper.?volta",BDI:"burundi",CPV:"verde",KHM:"cambodia|kampuchea|khmer",CMR:"cameroon",CAN:"canada",CYM:"cayman",CAF:"\\bcentral.african.republic",TCD:"\\bchad",CHL:"\\bchile",CHN:"^(?!.*\\bmac)(?!.*\\bhong)(?!.*\\btai)(?!.*\\brep).*china|^(?=.*peo)(?=.*rep).*china",CXR:"christmas",CCK:"\\bcocos|keeling",COL:"colombia",COM:"comoro",COG:"^(?!.*\\bdem)(?!.*\\bd[\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\bcongo",COK:"\\bcook",CRI:"costa.?rica",CIV:"ivoire|ivory",HRV:"croatia",CUB:"\\bcuba",CUW:"^(?!.*bonaire).*\\bcura(c|\xe7)ao",CYP:"cyprus",CSK:"czechoslovakia",CZE:"^(?=.*rep).*czech|czechia|bohemia",COD:"\\bdem.*congo|congo.*\\bdem|congo.*\\bd[\\.]?r|\\bd[\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc",DNK:"denmark",DJI:"djibouti",DMA:"dominica(?!n)",DOM:"dominican.rep",ECU:"ecuador",EGY:"egypt",SLV:"el.?salvador",GNQ:"guine.*eq|eq.*guine|^(?=.*span).*guinea",ERI:"eritrea",EST:"estonia",ETH:"ethiopia|abyssinia",FLK:"falkland|malvinas",FRO:"faroe|faeroe",FJI:"fiji",FIN:"finland",FRA:"^(?!.*\\bdep)(?!.*martinique).*france|french.?republic|\\bgaul",GUF:"^(?=.*french).*guiana",PYF:"french.?polynesia|tahiti",ATF:"french.?southern",GAB:"gabon",GMB:"gambia",GEO:"^(?!.*south).*georgia",DDR:"german.?democratic.?republic|democratic.?republic.*germany|east.germany",DEU:"^(?!.*east).*germany|^(?=.*\\bfed.*\\brep).*german",GHA:"ghana|gold.?coast",GIB:"gibraltar",GRC:"greece|hellenic|hellas",GRL:"greenland",GRD:"grenada",GLP:"guadeloupe",GUM:"\\bguam",GTM:"guatemala",GGY:"guernsey",GIN:"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea",GNB:"bissau|^(?=.*portu).*guinea",GUY:"guyana|british.?guiana",HTI:"haiti",HMD:"heard.*mcdonald",VAT:"holy.?see|vatican|papal.?st",HND:"^(?!.*brit).*honduras",HKG:"hong.?kong",HUN:"^(?!.*austr).*hungary",ISL:"iceland",IND:"india(?!.*ocea)",IDN:"indonesia",IRN:"\\biran|persia",IRQ:"\\biraq|mesopotamia",IRL:"(^ireland)|(^republic.*ireland)",IMN:"^(?=.*isle).*\\bman",ISR:"israel",ITA:"italy",JAM:"jamaica",JPN:"japan",JEY:"jersey",JOR:"jordan",KAZ:"kazak",KEN:"kenya|british.?east.?africa|east.?africa.?prot",KIR:"kiribati",PRK:"^(?=.*democrat|people|north|d.*p.*.r).*\\bkorea|dprk|korea.*(d.*p.*r)",KWT:"kuwait",KGZ:"kyrgyz|kirghiz",LAO:"\\blaos?\\b",LVA:"latvia",LBN:"lebanon",LSO:"lesotho|basuto",LBR:"liberia",LBY:"libya",LIE:"liechtenstein",LTU:"lithuania",LUX:"^(?!.*belg).*luxem",MAC:"maca(o|u)",MDG:"madagascar|malagasy",MWI:"malawi|nyasa",MYS:"malaysia",MDV:"maldive",MLI:"\\bmali\\b",MLT:"\\bmalta",MHL:"marshall",MTQ:"martinique",MRT:"mauritania",MUS:"mauritius",MYT:"\\bmayotte",MEX:"\\bmexic",FSM:"fed.*micronesia|micronesia.*fed",MCO:"monaco",MNG:"mongolia",MNE:"^(?!.*serbia).*montenegro",MSR:"montserrat",MAR:"morocco|\\bmaroc",MOZ:"mozambique",MMR:"myanmar|burma",NAM:"namibia",NRU:"nauru",NPL:"nepal",NLD:"^(?!.*\\bant)(?!.*\\bcarib).*netherlands",ANT:"^(?=.*\\bant).*(nether|dutch)",NCL:"new.?caledonia",NZL:"new.?zealand",NIC:"nicaragua",NER:"\\bniger(?!ia)",NGA:"nigeria",NIU:"niue",NFK:"norfolk",MNP:"mariana",NOR:"norway",OMN:"\\boman|trucial",PAK:"^(?!.*east).*paki?stan",PLW:"palau",PSE:"palestin|\\bgaza|west.?bank",PAN:"panama",PNG:"papua|new.?guinea",PRY:"paraguay",PER:"peru",PHL:"philippines",PCN:"pitcairn",POL:"poland",PRT:"portugal",PRI:"puerto.?rico",QAT:"qatar",KOR:"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\bkorea(?!.*d.*p.*r)",MDA:"moldov|b(a|e)ssarabia",REU:"r(e|\xe9)union",ROU:"r(o|u|ou)mania",RUS:"\\brussia|soviet.?union|u\\.?s\\.?s\\.?r|socialist.?republics",RWA:"rwanda",BLM:"barth(e|\xe9)lemy",SHN:"helena",KNA:"kitts|\\bnevis",LCA:"\\blucia",MAF:"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)",SPM:"miquelon",VCT:"vincent",WSM:"^(?!.*amer).*samoa",SMR:"san.?marino",STP:"\\bs(a|\xe3)o.?tom(e|\xe9)",SAU:"\\bsa\\w*.?arabia",SEN:"senegal",SRB:"^(?!.*monte).*serbia",SYC:"seychell",SLE:"sierra",SGP:"singapore",SXM:"^(?!.*martin)(?!.*saba).*maarten",SVK:"^(?!.*cze).*slovak",SVN:"slovenia",SLB:"solomon",SOM:"somali",ZAF:"south.africa|s\\\\..?africa",SGS:"south.?georgia|sandwich",SSD:"\\bs\\w*.?sudan",ESP:"spain",LKA:"sri.?lanka|ceylon",SDN:"^(?!.*\\bs(?!u)).*sudan",SUR:"surinam|dutch.?guiana",SJM:"svalbard",SWZ:"swaziland",SWE:"sweden",CHE:"switz|swiss",SYR:"syria",TWN:"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china",TJK:"tajik",THA:"thailand|\\bsiam",MKD:"macedonia|fyrom",TLS:"^(?=.*leste).*timor|^(?=.*east).*timor",TGO:"togo",TKL:"tokelau",TON:"tonga",TTO:"trinidad|tobago",TUN:"tunisia",TUR:"turkey",TKM:"turkmen",TCA:"turks",TUV:"tuvalu",UGA:"uganda",UKR:"ukrain",ARE:"emirates|^u\\.?a\\.?e\\.?$|united.?arab.?em",GBR:"united.?kingdom|britain|^u\\.?k\\.?$",TZA:"tanzania",USA:"united.?states\\b(?!.*islands)|\\bu\\.?s\\.?a\\.?\\b|^\\s*u\\.?s\\.?\\b(?!.*islands)",UMI:"minor.?outlying.?is",URY:"uruguay",UZB:"uzbek",VUT:"vanuatu|new.?hebrides",VEN:"venezuela",VNM:"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam",VGB:"^(?=.*\\bu\\.?\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin",VIR:"^(?=.*\\bu\\.?\\s?s).*virgin|^(?=.*states).*virgin",WLF:"futuna|wallis",ESH:"western.sahara",YEM:"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\bp\\.?d\\.?r).*yemen",YMD:"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\bp\\.?d\\.?r).*yemen",YUG:"yugoslavia",ZMB:"zambia|northern.?rhodesia",EAZ:"zanzibar",ZWE:"zimbabwe|^(?!.*northern).*rhodesia"}},{}],136:[function(t,e,r){e.exports=["xx-small","x-small","small","medium","large","x-large","xx-large","larger","smaller"]},{}],137:[function(t,e,r){e.exports=["normal","condensed","semi-condensed","extra-condensed","ultra-condensed","expanded","semi-expanded","extra-expanded","ultra-expanded"]},{}],138:[function(t,e,r){e.exports=["normal","italic","oblique"]},{}],139:[function(t,e,r){e.exports=["normal","bold","bolder","lighter","100","200","300","400","500","600","700","800","900"]},{}],140:[function(t,e,r){"use strict";e.exports={parse:t("./parse"),stringify:t("./stringify")}},{"./parse":142,"./stringify":143}],141:[function(t,e,r){"use strict";var n=t("css-font-size-keywords");e.exports={isSize:function(t){return/^[\d\.]/.test(t)||-1!==t.indexOf("/")||-1!==n.indexOf(t)}}},{"css-font-size-keywords":136}],142:[function(t,e,r){"use strict";var n=t("unquote"),a=t("css-global-keywords"),i=t("css-system-font-keywords"),o=t("css-font-weight-keywords"),s=t("css-font-style-keywords"),l=t("css-font-stretch-keywords"),c=t("string-split-by"),u=t("./lib/util").isSize;e.exports=f;var h=f.cache={};function f(t){if("string"!=typeof t)throw new Error("Font argument must be a string.");if(h[t])return h[t];if(""===t)throw new Error("Cannot parse an empty string.");if(-1!==i.indexOf(t))return h[t]={system:t};for(var e,r={style:"normal",variant:"normal",weight:"normal",stretch:"normal",lineHeight:"normal",size:"1rem",family:["serif"]},f=c(t,/\s+/);e=f.shift();){if(-1!==a.indexOf(e))return["style","variant","weight","stretch"].forEach(function(t){r[t]=e}),h[t]=r;if(-1===s.indexOf(e))if("normal"!==e&&"small-caps"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,"/");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):"/"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error("Missing required font-family.");return r.family=c(f.join(" "),/\s*,\s*/).map(n),h[t]=r}throw new Error("Unknown or unsupported font token: "+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error("Missing required font-size.")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{"./lib/util":141,"css-font-stretch-keywords":137,"css-font-style-keywords":138,"css-font-weight-keywords":139,"css-global-keywords":144,"css-system-font-keywords":145,"string-split-by":527,unquote:546}],143:[function(t,e,r){"use strict";var n=t("pick-by-alias"),a=t("./lib/util").isSize,i=g(t("css-global-keywords")),o=g(t("css-system-font-keywords")),s=g(t("css-font-weight-keywords")),l=g(t("css-font-style-keywords")),c=g(t("css-font-stretch-keywords")),u={normal:1,"small-caps":1},h={serif:1,"sans-serif":1,monospace:1,cursive:1,fantasy:1,"system-ui":1},f="1rem",p="serif";function d(t,e){if(t&&!e[t]&&!i[t])throw Error("Unknown keyword `"+t+"`");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:"style fontstyle fontStyle font-style slope distinction",variant:"variant font-variant fontVariant fontvariant var capitalization",weight:"weight w font-weight fontWeight fontweight",stretch:"stretch font-stretch fontStretch fontstretch width",size:"size s font-size fontSize fontsize height em emSize",lineHeight:"lh line-height lineHeight lineheight leading",family:"font family fontFamily font-family fontfamily type typeface face",system:"system reserved default global"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=f),"number"==typeof t.size&&(t.size+="px"),!a)throw Error("Bad size value `"+t.size+"`");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map(function(t){return h[t]?t:'"'+t+'"'}).join(", "));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||"normal"===t.lineHeight||t.lineHeight+""=="1"?"":"/"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(" ")}},{"./lib/util":141,"css-font-stretch-keywords":137,"css-font-style-keywords":138,"css-font-weight-keywords":139,"css-global-keywords":144,"css-system-font-keywords":145,"pick-by-alias":466}],144:[function(t,e,r){e.exports=["inherit","initial","unset"]},{}],145:[function(t,e,r){e.exports=["caption","icon","menu","message-box","small-caption","status-bar"]},{}],146:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a,i){var o=a-1,s=a*a,l=o*o,c=(1+2*a)*l,u=a*l,h=s*(3-2*a),f=s*o;if(t.length){i||(i=new Array(t.length));for(var p=t.length-1;p>=0;--p)i[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return i}return c*t+u*e+h*r+f*n},e.exports.derivative=function(t,e,r,n,a,i){var o=6*a*a-6*a,s=3*a*a-4*a+1,l=-6*a*a+6*a,c=3*a*a-2*a;if(t.length){i||(i=new Array(t.length));for(var u=t.length-1;u>=0;--u)i[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return i}return o*t+s*e+l*r[u]+c*n}},{}],147:[function(t,e,r){"use strict";var n=t("./lib/thunk.js");function a(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName="",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new a;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var i=0;i<r.length;++i){var o=r[i];if("array"===o||"object"==typeof o&&o.blockIndices){if(e.argTypes[i]="array",e.arrayArgs.push(i),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push("array"+i),i<e.pre.args.length&&e.pre.args[i].count>0)throw new Error("cwise: pre() block may not reference array args");if(i<e.post.args.length&&e.post.args[i].count>0)throw new Error("cwise: post() block may not reference array args")}else if("scalar"===o)e.scalarArgs.push(i),e.shimArgs.push("scalar"+i);else if("index"===o){if(e.indexArgs.push(i),i<e.pre.args.length&&e.pre.args[i].count>0)throw new Error("cwise: pre() block may not reference array index");if(i<e.body.args.length&&e.body.args[i].lvalue)throw new Error("cwise: body() block may not write to array index");if(i<e.post.args.length&&e.post.args[i].count>0)throw new Error("cwise: post() block may not reference array index")}else if("shape"===o){if(e.shapeArgs.push(i),i<e.pre.args.length&&e.pre.args[i].lvalue)throw new Error("cwise: pre() block may not write to array shape");if(i<e.body.args.length&&e.body.args[i].lvalue)throw new Error("cwise: body() block may not write to array shape");if(i<e.post.args.length&&e.post.args[i].lvalue)throw new Error("cwise: post() block may not write to array shape")}else{if("object"!=typeof o||!o.offset)throw new Error("cwise: Unknown argument type "+r[i]);e.argTypes[i]="offset",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(i)}}if(e.arrayArgs.length<=0)throw new Error("cwise: No array arguments specified");if(e.pre.args.length>r.length)throw new Error("cwise: Too many arguments in pre() block");if(e.body.args.length>r.length)throw new Error("cwise: Too many arguments in body() block");if(e.post.args.length>r.length)throw new Error("cwise: Too many arguments in post() block");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||"cwise",e.blockSize=t.blockSize||64,n(e)}},{"./lib/thunk.js":149}],148:[function(t,e,r){"use strict";var n=t("uniq");function a(t,e,r){var n,a,i=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,h=0;for(n=0;n<i;++n)c.push(["i",n,"=0"].join(""));for(a=0;a<o;++a)for(n=0;n<i;++n)h=u,u=t[n],0===n?c.push(["d",a,"s",n,"=t",a,"p",u].join("")):c.push(["d",a,"s",n,"=(t",a,"p",u,"-s",h,"*t",a,"p",h,")"].join(""));for(c.length>0&&l.push("var "+c.join(",")),n=i-1;n>=0;--n)u=t[n],l.push(["for(i",n,"=0;i",n,"<s",u,";++i",n,"){"].join(""));for(l.push(r),n=0;n<i;++n){for(h=u,u=t[n],a=0;a<o;++a)l.push(["p",a,"+=d",a,"s",n].join(""));s&&(n>0&&l.push(["index[",h,"]-=s",h].join("")),l.push(["++index[",u,"]"].join(""))),l.push("}")}return l.join("\n")}function i(t,e,r){for(var n=t.body,a=[],i=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,"g"),c="",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case"offset":var h=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[h].array,c="+q"+h;case"array":c="p"+u+c;var f="l"+o,p="a"+u;if(0===e.arrayBlockIndices[u])1===s.count?"generic"===r[u]?s.lvalue?(a.push(["var ",f,"=",p,".get(",c,")"].join("")),n=n.replace(l,f),i.push([p,".set(",c,",",f,")"].join(""))):n=n.replace(l,[p,".get(",c,")"].join("")):n=n.replace(l,[p,"[",c,"]"].join("")):"generic"===r[u]?(a.push(["var ",f,"=",p,".get(",c,")"].join("")),n=n.replace(l,f),s.lvalue&&i.push([p,".set(",c,",",f,")"].join(""))):(a.push(["var ",f,"=",p,"[",c,"]"].join("")),n=n.replace(l,f),s.lvalue&&i.push([p,"[",c,"]=",f].join("")));else{for(var d=[s.name],g=[c],v=0;v<Math.abs(e.arrayBlockIndices[u]);v++)d.push("\\s*\\[([^\\]]+)\\]"),g.push("$"+(v+1)+"*t"+u+"b"+v);if(l=new RegExp(d.join(""),"g"),c=g.join("+"),"generic"===r[u])throw new Error("cwise: Generic arrays not supported in combination with blocks!");n=n.replace(l,[p,"[",c,"]"].join(""))}break;case"scalar":n=n.replace(l,"Y"+e.scalarArgs.indexOf(o));break;case"index":n=n.replace(l,"index");break;case"shape":n=n.replace(l,"shape")}}}return[a.join("\n"),n,i.join("\n")].join("\n").trim()}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,o=new Array(t.arrayArgs.length),s=new Array(t.arrayArgs.length),l=0;l<t.arrayArgs.length;++l)s[l]=e[2*l],o[l]=e[2*l+1];var c=[],u=[],h=[],f=[],p=[];for(l=0;l<t.arrayArgs.length;++l){t.arrayBlockIndices[l]<0?(h.push(0),f.push(r),c.push(r),u.push(r+t.arrayBlockIndices[l])):(h.push(t.arrayBlockIndices[l]),f.push(t.arrayBlockIndices[l]+r),c.push(0),u.push(t.arrayBlockIndices[l]));for(var d=[],g=0;g<o[l].length;g++)h[l]<=o[l][g]&&o[l][g]<f[l]&&d.push(o[l][g]-h[l]);p.push(d)}var v=["SS"],m=["'use strict'"],y=[];for(g=0;g<r;++g)y.push(["s",g,"=SS[",g,"]"].join(""));for(l=0;l<t.arrayArgs.length;++l){for(v.push("a"+l),v.push("t"+l),v.push("p"+l),g=0;g<r;++g)y.push(["t",l,"p",g,"=t",l,"[",h[l]+g,"]"].join(""));for(g=0;g<Math.abs(t.arrayBlockIndices[l]);++g)y.push(["t",l,"b",g,"=t",l,"[",c[l]+g,"]"].join(""))}for(l=0;l<t.scalarArgs.length;++l)v.push("Y"+l);if(t.shapeArgs.length>0&&y.push("shape=SS.slice(0)"),t.indexArgs.length>0){var x=new Array(r);for(l=0;l<r;++l)x[l]="0";y.push(["index=[",x.join(","),"]"].join(""))}for(l=0;l<t.offsetArgs.length;++l){var b=t.offsetArgs[l],_=[];for(g=0;g<b.offset.length;++g)0!==b.offset[g]&&(1===b.offset[g]?_.push(["t",b.array,"p",g].join("")):_.push([b.offset[g],"*t",b.array,"p",g].join("")));0===_.length?y.push("q"+l+"=0"):y.push(["q",l,"=",_.join("+")].join(""))}var w=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((y=y.concat(w)).length>0&&m.push("var "+y.join(",")),l=0;l<t.arrayArgs.length;++l)m.push("p"+l+"|=0");t.pre.body.length>3&&m.push(i(t.pre,t,s));var k=i(t.body,t,s),T=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(p);T<r?m.push(function(t,e,r,n){for(var i=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push(["var offset",u,"=p",u].join(""));for(u=t;u<i;++u)c.push(["for(var j"+u+"=SS[",e[u],"]|0;j",u,">0;){"].join("")),c.push(["if(j",u,"<",s,"){"].join("")),c.push(["s",e[u],"=j",u].join("")),c.push(["j",u,"=0"].join("")),c.push(["}else{s",e[u],"=",s].join("")),c.push(["j",u,"-=",s,"}"].join("")),l&&c.push(["index[",e[u],"]=j",u].join(""));for(u=0;u<o;++u){for(var h=["offset"+u],f=t;f<i;++f)h.push(["j",f,"*t",u,"p",e[f]].join(""));c.push(["p",u,"=(",h.join("+"),")"].join(""))}for(c.push(a(e,r,n)),u=t;u<i;++u)c.push("}");return c.join("\n")}(T,p[0],t,k)):m.push(a(p[0],t,k)),t.post.body.length>3&&m.push(i(t.post,t,s)),t.debug&&console.log("-----Generated cwise routine for ",e,":\n"+m.join("\n")+"\n----------");var A=[t.funcName||"unnamed","_cwise_loop_",o[0].join("s"),"m",T,function(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var a=t[n],i=a.match(/\d+/);i=i?i[0]:"",0===a.charAt(0)?e[n]="u"+a.charAt(1)+i:e[n]=a.charAt(0)+i,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join("")}(s)].join("");return new Function(["function ",A,"(",v.join(","),"){",m.join("\n"),"} return ",A].join(""))()}},{uniq:545}],149:[function(t,e,r){"use strict";var n=t("./compile.js");e.exports=function(t){var e=["'use strict'","var CACHED={}"],r=[],a=t.funcName+"_cwise_thunk";e.push(["return function ",a,"(",t.shimArgs.join(","),"){"].join(""));for(var i=[],o=[],s=[["array",t.arrayArgs[0],".shape.slice(",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?","+t.arrayBlockIndices[0]+")":")"].join("")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var h=t.arrayArgs[u];r.push(["t",h,"=array",h,".dtype,","r",h,"=array",h,".order"].join("")),i.push("t"+h),i.push("r"+h),o.push("t"+h),o.push("r"+h+".join()"),s.push("array"+h+".data"),s.push("array"+h+".stride"),s.push("array"+h+".offset|0"),u>0&&(l.push("array"+t.arrayArgs[0]+".shape.length===array"+h+".shape.length+"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push("array"+t.arrayArgs[0]+".shape[shapeIndex+"+Math.max(0,t.arrayBlockIndices[0])+"]===array"+h+".shape[shapeIndex+"+Math.max(0,t.arrayBlockIndices[u])+"]"))}for(t.arrayArgs.length>1&&(e.push("if (!("+l.join(" && ")+")) throw new Error('cwise: Arrays do not all have the same dimensionality!')"),e.push("for(var shapeIndex=array"+t.arrayArgs[0]+".shape.length-"+Math.abs(t.arrayBlockIndices[0])+"; shapeIndex--\x3e0;) {"),e.push("if (!("+c.join(" && ")+")) throw new Error('cwise: Arrays do not all have the same shape!')"),e.push("}")),u=0;u<t.scalarArgs.length;++u)s.push("scalar"+t.scalarArgs[u]);return r.push(["type=[",o.join(","),"].join()"].join("")),r.push("proc=CACHED[type]"),e.push("var "+r.join(",")),e.push(["if(!proc){","CACHED[type]=proc=compile([",i.join(","),"])}","return proc(",s.join(","),")}"].join("")),t.debug&&console.log("-----Generated thunk:\n"+e.join("\n")+"\n----------"),new Function("compile",e.join("\n"))(n.bind(void 0,t))}},{"./compile.js":148}],150:[function(t,e,r){e.exports=t("cwise-compiler")},{"cwise-compiler":147}],151:[function(t,e,r){"use strict";var n,a=t("es5-ext/object/copy"),i=t("es5-ext/object/normalize-options"),o=t("es5-ext/object/valid-callable"),s=t("es5-ext/object/map"),l=t("es5-ext/object/valid-callable"),c=t("es5-ext/object/valid-value"),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,i=c(e)&&l(e.value);return delete(n=a(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?i:(e.value=u.call(i,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},e.exports=function(t){var e=i(arguments[1]);return null!=e.resolveContext&&o(e.resolveContext),s(t,function(t,r){return n(r,t,e)})}},{"es5-ext/object/copy":191,"es5-ext/object/map":200,"es5-ext/object/normalize-options":201,"es5-ext/object/valid-callable":205,"es5-ext/object/valid-value":207}],152:[function(t,e,r){"use strict";var n=t("es5-ext/object/assign"),a=t("es5-ext/object/normalize-options"),i=t("es5-ext/object/is-callable"),o=t("es5-ext/string/#/contains");(e.exports=function(t,e){var r,i,s,l,c;return arguments.length<2||"string"!=typeof t?(l=e,e=t,t=null):l=arguments[2],null==t?(r=s=!0,i=!1):(r=o.call(t,"c"),i=o.call(t,"e"),s=o.call(t,"w")),c={value:e,configurable:r,enumerable:i,writable:s},l?n(a(l),c):c}).gs=function(t,e,r){var s,l,c,u;return"string"!=typeof t?(c=r,r=e,e=t,t=null):c=arguments[3],null==e?e=void 0:i(e)?null==r?r=void 0:i(r)||(c=r,r=void 0):(c=e,e=r=void 0),null==t?(s=!0,l=!1):(s=o.call(t,"c"),l=o.call(t,"e")),u={get:e,set:r,configurable:s,enumerable:l},c?n(a(c),u):u}},{"es5-ext/object/assign":188,"es5-ext/object/is-callable":194,"es5-ext/object/normalize-options":201,"es5-ext/string/#/contains":208}],153:[function(t,e,r){var n;n=this,function(t){"use strict";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,a){for(null==n&&(n=0),null==a&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)<0?n=i+1:a=i}return n},right:function(e,r,n,a){for(null==n&&(n=0),null==a&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)>0?a=i:n=i+1}return n}}}var n=r(e),a=n.right,i=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,a=t.length,i=0,o=-1,l=0,c=0;if(null==e)for(;++o<a;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++i)));else for(;++o<a;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++i)));if(i>1)return c/(i-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,a,i=t.length,o=-1;if(null==e){for(;++o<i;)if(null!=(r=t[o])&&r>=r)for(n=a=r;++o<i;)null!=(r=t[o])&&(n>r&&(n=r),a<r&&(a=r))}else for(;++o<i;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=a=r;++o<i;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),a<r&&(a=r));return[n,a]}var h=Array.prototype,f=h.slice,p=h.map;function d(t){return function(){return t}}function g(t){return t}function v(t,e,r){t=+t,e=+e,r=(a=arguments.length)<2?(e=t,t=0,1):a<3?1:+r;for(var n=-1,a=0|Math.max(0,Math.ceil((e-t)/r)),i=new Array(a);++n<a;)i[n]=t+n*r;return i}var m=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),a=Math.floor(Math.log(n)/Math.LN10),i=n/Math.pow(10,a);return a>=0?(i>=m?10:i>=y?5:i>=x?2:1)*Math.pow(10,a):-Math.pow(10,-a)/(i>=m?10:i>=y?5:i>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),a=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),i=n/a;return i>=m?a*=10:i>=y?a*=5:i>=x&&(a*=2),e<t?-a:a}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function k(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,a=(n-1)*e,i=Math.floor(a),o=+r(t[i],i,t);return o+(+r(t[i+1],i+1,t)-o)*(a-i)}}function T(t,e){var r,n,a=t.length,i=-1;if(null==e){for(;++i<a;)if(null!=(r=t[i])&&r>=r)for(n=r;++i<a;)null!=(r=t[i])&&n>r&&(n=r)}else for(;++i<a;)if(null!=(r=e(t[i],i,t))&&r>=r)for(n=r;++i<a;)null!=(r=e(t[i],i,t))&&n>r&&(n=r);return n}function A(t){if(!(a=t.length))return[];for(var e=-1,r=T(t,M),n=new Array(r);++e<r;)for(var a,i=-1,o=n[e]=new Array(a);++i<a;)o[i]=t[i][e];return n}function M(t){return t.length}t.bisect=a,t.bisectRight=a,t.bisectLeft=i,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,a,i,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=i=0;n<l;++n)for(s=t[n],a=0;a<c;++a,++i)u[i]=r(s,e[a]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var i,o,s=n.length,l=new Array(s);for(i=0;i<s;++i)l[i]=t(n[i],i,n);var c=e(l),u=c[0],h=c[1],f=r(l,u,h);Array.isArray(f)||(f=_(u,h,f),f=v(Math.ceil(u/f)*f,h,f));for(var p=f.length;f[0]<=u;)f.shift(),--p;for(;f[p-1]>h;)f.pop(),--p;var d,g=new Array(p+1);for(i=0;i<=p;++i)(d=g[i]=[]).x0=i>0?f[i-1]:u,d.x1=i<p?f[i]:h;for(i=0;i<s;++i)u<=(o=l[i])&&o<=h&&g[a(f,o,0,p)].push(n[i]);return g}return n.value=function(e){return arguments.length?(t="function"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e="function"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r="function"==typeof t?t:Array.isArray(t)?d(f.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(k(t,.75)-k(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,a=t.length,i=-1;if(null==e){for(;++i<a;)if(null!=(r=t[i])&&r>=r)for(n=r;++i<a;)null!=(r=t[i])&&r>n&&(n=r)}else for(;++i<a;)if(null!=(r=e(t[i],i,t))&&r>=r)for(n=r;++i<a;)null!=(r=e(t[i],i,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,a=n,i=-1,o=0;if(null==e)for(;++i<n;)isNaN(r=s(t[i]))?--a:o+=r;else for(;++i<n;)isNaN(r=s(e(t[i],i,t)))?--a:o+=r;if(a)return o/a},t.median=function(t,r){var n,a=t.length,i=-1,o=[];if(null==r)for(;++i<a;)isNaN(n=s(t[i]))||o.push(n);else for(;++i<a;)isNaN(n=s(r(t[i],i,t)))||o.push(n);return k(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,a=t.length,i=-1,o=0;++i<a;)o+=t[i].length;for(r=new Array(o);--a>=0;)for(e=(n=t[a]).length;--e>=0;)r[--o]=n[e];return r},t.min=T,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,a=t[0],i=new Array(n<0?0:n);r<n;)i[r]=e(a,a=t[++r]);return i},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=k,t.range=v,t.scan=function(t,r){if(n=t.length){var n,a,i=0,o=0,s=t[o];for(null==r&&(r=e);++i<n;)(r(a=t[i],s)<0||0!==r(s,s))&&(s=a,o=i);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,a,i=(null==r?t.length:r)-(e=null==e?0:+e);i;)a=Math.random()*i--|0,n=t[i+e],t[i+e]=t[a+e],t[a+e]=n;return t},t.sum=function(t,e){var r,n=t.length,a=-1,i=0;if(null==e)for(;++a<n;)(r=+t[a])&&(i+=r);else for(;++a<n;)(r=+e(t[a],a,t))&&(i+=r);return i},t.ticks=function(t,e,r){var n,a,i,o,s=-1;if(r=+r,(t=+t)==(e=+e)&&r>0)return[t];if((n=e<t)&&(a=t,t=e,e=a),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),i=new Array(a=Math.ceil(e-t+1));++s<a;)i[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),i=new Array(a=Math.ceil(t-e+1));++s<a;)i[s]=(t-s)/o;return n&&i.reverse(),i},t.tickIncrement=b,t.tickStep=_,t.transpose=A,t.variance=l,t.zip=function(){return A(arguments)},Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],154:[function(t,e,r){var n;n=this,function(t){"use strict";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var a,i=-1,o=t.length;if(null==r)for(;++i<o;)n.set(i,t[i]);else for(;++i<o;)n.set(r(a=t[i],i,t),a)}else if(t)for(var s in t)n.set(s,t[s]);return n}e.prototype=r.prototype={constructor:e,has:function(t){return"$"+t in this},get:function(t){return this["$"+t]},set:function(t,e){return this["$"+t]=e,this},remove:function(t){var e="$"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)"$"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)"$"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)"$"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)"$"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)"$"===e[0]&&++t;return t},empty:function(){for(var t in this)if("$"===t[0])return!1;return!0},each:function(t){for(var e in this)"$"===e[0]&&t(this[e],e.slice(1),this)}};function n(){return{}}function a(t,e,r){t[e]=r}function i(){return r()}function o(t,e,r){t.set(e,r)}function s(){}var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each(function(t){r.add(t)});else if(t){var n=-1,a=t.length;if(null==e)for(;++n<a;)r.add(t[n]);else for(;++n<a;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this["$"+(t+="")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each};t.nest=function(){var t,e,s,l=[],c=[];function u(n,a,i,o){if(a>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,h,f=-1,p=n.length,d=l[a++],g=r(),v=i();++f<p;)(h=g.get(s=d(c=n[f])+""))?h.push(c):g.set(s,[c]);return g.each(function(t,e){o(v,e,u(t,a,i,o))}),v}return s={object:function(t){return u(t,0,n,a)},map:function(t){return u(t,0,i,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var a,i=c[n-1];return null!=e&&n>=l.length?a=r.entries():(a=[],r.each(function(e,r){a.push({key:r,values:t(e,n)})})),null!=i?a.sort(function(t,e){return i(t.key,e.key)}):a}(u(t,0,i,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],155:[function(t,e,r){var n;n=this,function(t){"use strict";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var a="\\s*([+-]?\\d+)\\s*",i="\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)\\s*",o="\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*",s=/^#([0-9a-f]{3})$/,l=/^#([0-9a-f]{6})$/,c=new RegExp("^rgb\\("+[a,a,a]+"\\)$"),u=new RegExp("^rgb\\("+[o,o,o]+"\\)$"),h=new RegExp("^rgba\\("+[a,a,a,i]+"\\)$"),f=new RegExp("^rgba\\("+[o,o,o,i]+"\\)$"),p=new RegExp("^hsl\\("+[i,o,o]+"\\)$"),d=new RegExp("^hsla\\("+[i,o,o,i]+"\\)$"),g={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function v(t){var e;return t=(t+"").trim().toLowerCase(),(e=s.exec(t))?new _((e=parseInt(e[1],16))>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):(e=l.exec(t))?m(parseInt(e[1],16)):(e=c.exec(t))?new _(e[1],e[2],e[3],1):(e=u.exec(t))?new _(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=h.exec(t))?y(e[1],e[2],e[3],e[4]):(e=f.exec(t))?y(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=p.exec(t))?k(e[1],e[2]/100,e[3]/100,1):(e=d.exec(t))?k(e[1],e[2]/100,e[3]/100,e[4]):g.hasOwnProperty(t)?m(g[t]):"transparent"===t?new _(NaN,NaN,NaN,0):null}function m(t){return new _(t>>16&255,t>>8&255,255&t,1)}function y(t,e,r,n){return n<=0&&(t=e=r=NaN),new _(t,e,r,n)}function x(t){return t instanceof n||(t=v(t)),t?new _((t=t.rgb()).r,t.g,t.b,t.opacity):new _}function b(t,e,r,n){return 1===arguments.length?x(t):new _(t,e,r,null==n?1:n)}function _(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function w(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?"0":"")+t.toString(16)}function k(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new A(t,e,r,n)}function T(t,e,r,a){return 1===arguments.length?function(t){if(t instanceof A)return new A(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new A;if(t instanceof A)return t;var e=(t=t.rgb()).r/255,r=t.g/255,a=t.b/255,i=Math.min(e,r,a),o=Math.max(e,r,a),s=NaN,l=o-i,c=(o+i)/2;return l?(s=e===o?(r-a)/l+6*(r<a):r===o?(a-e)/l+2:(e-r)/l+4,l/=c<.5?o+i:2-o-i,s*=60):l=c>0&&c<1?0:s,new A(s,l,c,t.opacity)}(t):new A(t,e,r,null==a?1:a)}function A(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function M(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{displayable:function(){return this.rgb().displayable()},hex:function(){return this.rgb().hex()},toString:function(){return this.rgb()+""}}),e(_,b,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return 0<=this.r&&this.r<=255&&0<=this.g&&this.g<=255&&0<=this.b&&this.b<=255&&0<=this.opacity&&this.opacity<=1},hex:function(){return"#"+w(this.r)+w(this.g)+w(this.b)},toString:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?"rgb(":"rgba(")+Math.max(0,Math.min(255,Math.round(this.r)||0))+", "+Math.max(0,Math.min(255,Math.round(this.g)||0))+", "+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?")":", "+t+")")}})),e(A,T,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new A(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new A(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,a=2*r-n;return new _(M(t>=240?t-240:t+120,a,n),M(t,a,n),M(t<120?t+240:t-120,a,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1}}));var S=Math.PI/180,E=180/Math.PI,L=.96422,C=1,P=.82521,O=4/29,z=6/29,I=3*z*z,D=z*z*z;function R(t){if(t instanceof B)return new B(t.l,t.a,t.b,t.opacity);if(t instanceof G){if(isNaN(t.h))return new B(t.l,0,0,t.opacity);var e=t.h*S;return new B(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}t instanceof _||(t=x(t));var r,n,a=U(t.r),i=U(t.g),o=U(t.b),s=N((.2225045*a+.7168786*i+.0606169*o)/C);return a===i&&i===o?r=n=s:(r=N((.4360747*a+.3850649*i+.1430804*o)/L),n=N((.0139322*a+.0971045*i+.7141733*o)/P)),new B(116*s-16,500*(r-s),200*(s-n),t.opacity)}function F(t,e,r,n){return 1===arguments.length?R(t):new B(t,e,r,null==n?1:n)}function B(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function N(t){return t>D?Math.pow(t,1/3):t/I+O}function j(t){return t>z?t*t*t:I*(t-O)}function V(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function U(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function q(t){if(t instanceof G)return new G(t.h,t.c,t.l,t.opacity);if(t instanceof B||(t=R(t)),0===t.a&&0===t.b)return new G(NaN,0,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*E;return new G(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function H(t,e,r,n){return 1===arguments.length?q(t):new G(t,e,r,null==n?1:n)}function G(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}e(B,F,r(n,{brighter:function(t){return new B(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new B(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new _(V(3.1338561*(e=L*j(e))-1.6168667*(t=C*j(t))-.4906146*(r=P*j(r))),V(-.9787684*e+1.9161415*t+.033454*r),V(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(G,H,r(n,{brighter:function(t){return new G(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new G(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return R(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,Q=J*W,$=W*X-Z*Y;function tt(t,e,r,n){return 1===arguments.length?function(t){if(t instanceof et)return new et(t.h,t.s,t.l,t.opacity);t instanceof _||(t=x(t));var e=t.r/255,r=t.g/255,n=t.b/255,a=($*n+K*e-Q*r)/($+K-Q),i=n-a,o=(J*(r-a)-X*i)/Z,s=Math.sqrt(o*o+i*i)/(J*a*(1-a)),l=s?Math.atan2(o,i)*E-120:NaN;return new et(l<0?l+360:l,s,a,t.opacity)}(t):new et(t,e,r,null==n?1:n)}function et(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(et,tt,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new et(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new et(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*S,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),a=Math.sin(t);return new _(255*(e+r*(Y*n+W*a)),255*(e+r*(X*n+Z*a)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.rgb=b,t.hsl=T,t.lab=F,t.hcl=H,t.lch=function(t,e,r,n){return 1===arguments.length?q(t):new G(r,e,t,null==n?1:n)},t.gray=function(t,e){return new B(t,0,0,null==e?1:e)},t.cubehelix=tt,Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],156:[function(t,e,r){var n;n=this,function(t){"use strict";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,a={};e<r;++e){if(!(t=arguments[e]+"")||t in a)throw new Error("illegal type: "+t);a[t]=[]}return new n(a)}function n(t){this._=t}function a(t,e){for(var r,n=0,a=t.length;n<a;++n)if((r=t[n]).name===e)return r.value}function i(t,r,n){for(var a=0,i=t.length;a<i;++a)if(t[a].name===r){t[a]=e,t=t.slice(0,a).concat(t.slice(a+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n,o=this._,s=(n=o,(t+"").trim().split(/^|\s+/).map(function(t){var e="",r=t.indexOf(".");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error("unknown type: "+t);return{type:t,name:e}})),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&"function"!=typeof e)throw new Error("invalid callback: "+e);for(;++l<c;)if(r=(t=s[l]).type)o[r]=i(o[r],t.name,e);else if(null==e)for(r in o)o[r]=i(o[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=a(o[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,a=new Array(r),i=0;i<r;++i)a[i]=arguments[i+2];if(!this._.hasOwnProperty(t))throw new Error("unknown type: "+t);for(i=0,r=(n=this._[t]).length;i<r;++i)n[i].value.apply(e,a)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error("unknown type: "+t);for(var n=this._[t],a=0,i=n.length;a<i;++a)n[a].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],157:[function(t,e,r){var n,a;n=this,a=function(t,e,r,n,a){"use strict";var i=function(t){return function(){return t}},o=function(){return 1e-6*(Math.random()-.5)};function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error("missing: "+e);return r}function h(t){return t.x}function f(t){return t.y}var p=10,d=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,a,i=r.length,o=0,s=0;for(n=0;n<i;++n)o+=(a=r[n]).x,s+=a.y;for(o=o/i-t,s=s/i-e,n=0;n<i;++n)(a=r[n]).x-=o,a.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,a=1,c=1;function u(){for(var t,i,u,f,p,d,g,v=r.length,m=0;m<c;++m)for(i=e.quadtree(r,s,l).visitAfter(h),t=0;t<v;++t)u=r[t],d=n[u.index],g=d*d,f=u.x+u.vx,p=u.y+u.vy,i.visit(y);function y(t,e,r,n,i){var s=t.data,l=t.r,c=d+l;if(!s)return e>f+c||n<f-c||r>p+c||i<p-c;if(s.index>u.index){var h=f-s.x-s.vx,v=p-s.y-s.vy,m=h*h+v*v;m<c*c&&(0===h&&(m+=(h=o())*h),0===v&&(m+=(v=o())*v),m=(c-(m=Math.sqrt(m)))/m*a,u.vx+=(h*=m)*(c=(l*=l)/(g+l)),u.vy+=(v*=m)*c,s.vx-=h*(c=1-c),s.vy-=v*c)}}}function h(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function f(){if(r){var e,a,i=r.length;for(n=new Array(i),e=0;e<i;++e)a=r[e],n[a.index]=+t(a,e,r)}}return"function"!=typeof t&&(t=i(null==t?1:+t)),u.initialize=function(t){r=t,f()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(a=+t,u):a},u.radius=function(e){return arguments.length?(t="function"==typeof e?e:i(+e),f(),u):t},u},t.forceLink=function(t){var e,n,a,s,l,h=c,f=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=i(30),d=1;function g(r){for(var a=0,i=t.length;a<d;++a)for(var s,c,u,h,f,p,g,v=0;v<i;++v)c=(s=t[v]).source,h=(u=s.target).x+u.vx-c.x-c.vx||o(),f=u.y+u.vy-c.y-c.vy||o(),h*=p=((p=Math.sqrt(h*h+f*f))-n[v])/p*r*e[v],f*=p,u.vx-=h*(g=l[v]),u.vy-=f*g,c.vx+=h*(g=1-g),c.vy+=f*g}function v(){if(a){var i,o,c=a.length,f=t.length,p=r.map(a,h);for(i=0,s=new Array(c);i<f;++i)(o=t[i]).index=i,"object"!=typeof o.source&&(o.source=u(p,o.source)),"object"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(i=0,l=new Array(f);i<f;++i)o=t[i],l[i]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(f),m(),n=new Array(f),y()}}function m(){if(a)for(var r=0,n=t.length;r<n;++r)e[r]=+f(t[r],r,t)}function y(){if(a)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){a=t,v()},g.links=function(e){return arguments.length?(t=e,v(),g):t},g.id=function(t){return arguments.length?(h=t,g):h},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(f="function"==typeof t?t:i(+t),m(),g):f},g.distance=function(t){return arguments.length?(p="function"==typeof t?t:i(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,a,s=i(-30),l=1,c=1/0,u=.81;function p(a){var i,o=t.length,s=e.quadtree(t,h,f).visitAfter(g);for(n=a,i=0;i<o;++i)r=t[i],s.visit(v)}function d(){if(t){var e,r,n=t.length;for(a=new Array(n),e=0;e<n;++e)r=t[e],a[r.index]=+s(r,e,t)}}function g(t){var e,r,n,i,o,s=0,l=0;if(t.length){for(n=i=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,i+=r*e.y);t.x=n/l,t.y=i/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=a[e.data.index]}while(e=e.next)}t.value=s}function v(t,e,i,s){if(!t.value)return!0;var h=t.x-r.x,f=t.y-r.y,p=s-e,d=h*h+f*f;if(p*p/u<d)return d<c&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)),r.vx+=h*t.value*n/d,r.vy+=f*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=a[t.data.index]*n/d,r.vx+=h*p,r.vy+=f*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s="function"==typeof t?t:i(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,a,o,s=i(.1);function l(t){for(var i=0,s=n.length;i<s;++i){var l=n[i],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[i]-h)*a[i]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(a=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),a[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return"function"!=typeof t&&(t=i(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s="function"==typeof t?t:i(+t),c(),l):s},l.radius=function(e){return arguments.length?(t="function"==typeof e?e:i(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,i=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),h=a.timer(g),f=n.dispatch("tick","end");function g(){v(),f.call("tick",e),i<o&&(h.stop(),f.call("end",e))}function v(){var e,r,n=t.length;for(i+=(l-i)*s,u.each(function(t){t(i)}),e=0;e<n;++e)null==(r=t[e]).fx?r.x+=r.vx*=c:(r.x=r.fx,r.vx=0),null==r.fy?r.y+=r.vy*=c:(r.y=r.fy,r.vy=0)}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,isNaN(e.x)||isNaN(e.y)){var a=p*Math.sqrt(r),i=r*d;e.x=a*Math.cos(i),e.y=a*Math.sin(i)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function y(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:v,restart:function(){return h.restart(g),e},stop:function(){return h.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(y),e):t},alpha:function(t){return arguments.length?(i=+t,e):i},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,y(r)),e):u.get(t)},find:function(e,r,n){var a,i,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(a=e-(s=t[c]).x)*a+(i=r-s.y)*i)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(f.on(t,r),e):f.on(t)}}},t.forceX=function(t){var e,r,n,a=i(.1);function o(t){for(var a,i=0,o=e.length;i<o;++i)(a=e[i]).vx+=(n[i]-a.x)*r[i]*t}function s(){if(e){var i,o=e.length;for(r=new Array(o),n=new Array(o),i=0;i<o;++i)r[i]=isNaN(n[i]=+t(e[i],i,e))?0:+a(e[i],i,e)}}return"function"!=typeof t&&(t=i(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(a="function"==typeof t?t:i(+t),s(),o):a},o.x=function(e){return arguments.length?(t="function"==typeof e?e:i(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,a=i(.1);function o(t){for(var a,i=0,o=e.length;i<o;++i)(a=e[i]).vy+=(n[i]-a.y)*r[i]*t}function s(){if(e){var i,o=e.length;for(r=new Array(o),n=new Array(o),i=0;i<o;++i)r[i]=isNaN(n[i]=+t(e[i],i,e))?0:+a(e[i],i,e)}}return"function"!=typeof t&&(t=i(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(a="function"==typeof t?t:i(+t),s(),o):a},o.y=function(e){return arguments.length?(t="function"==typeof e?e:i(+e),s(),o):t},o},Object.defineProperty(t,"__esModule",{value:!0})},"object"==typeof r&&"undefined"!=typeof e?a(r,t("d3-quadtree"),t("d3-collection"),t("d3-dispatch"),t("d3-timer")):a(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)},{"d3-collection":154,"d3-dispatch":156,"d3-quadtree":161,"d3-timer":163}],158:[function(t,e,r){var n;n=this,function(t){"use strict";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function a(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function i(t,e){var r,n,a,i,s,u=new c(t),h=+t.value&&(u.value=t.value),f=[u];for(null==e&&(e=o);r=f.pop();)if(h&&(r.value=+r.data.value),(a=e(r.data))&&(s=a.length))for(r.children=new Array(s),i=s-1;i>=0;--i)f.push(n=r.children[i]=new c(a[i])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=i.prototype={constructor:c,count:function(){return this.eachAfter(a)},each:function(t){var e,r,n,a,i=this,o=[i];do{for(e=o.reverse(),o=[];i=e.pop();)if(t(i),r=i.children)for(n=0,a=r.length;n<a;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,a=this,i=[a],o=[];a=i.pop();)if(o.push(a),e=a.children)for(r=0,n=e.length;r<n;++r)i.push(e[r]);for(;a=o.pop();)t(a);return this},eachBefore:function(t){for(var e,r,n=this,a=[n];n=a.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)a.push(e[r]);return this},sum:function(t){return this.eachAfter(function(e){for(var r=+t(e.data)||0,n=e.children,a=n&&n.length;--a>=0;)r+=n[a].value;e.value=r})},sort:function(t){return this.eachBefore(function(e){e.children&&e.children.sort(t)})},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),a=null;for(t=r.pop(),e=n.pop();t===e;)a=t,t=r.pop(),e=n.pop();return a}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var a=n.length;t!==r;)n.splice(a,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each(function(e){t.push(e)}),t},leaves:function(){var t=[];return this.eachBefore(function(e){e.children||t.push(e)}),t},links:function(){var t=this,e=[];return t.each(function(r){r!==t&&e.push({source:r.parent,target:r})}),e},copy:function(){return i(this).eachBefore(s)}};var u=Array.prototype.slice;function h(t){for(var e,r,n=0,a=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,i=[];n<a;)e=t[n],r&&d(r,e)?++n:(r=v(i=f(i,e)),n=0);return r}function f(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(m(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(m(t[r],t[n]),e)&&p(m(t[r],e),t[n])&&p(m(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,a=e.y-t.y;return r<0||r*r<n*n+a*a}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,a=e.y-t.y;return r>0&&r*r>n*n+a*a}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function v(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return m(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function m(t,e){var r=t.x,n=t.y,a=t.r,i=e.x,o=e.y,s=e.r,l=i-r,c=o-n,u=s-a,h=Math.sqrt(l*l+c*c);return{x:(r+i+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+a+s)/2}}function y(t,e,r){var n=t.x,a=t.y,i=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=a-s,g=a-u,v=l-i,m=h-i,y=n*n+a*a-i*i,x=y-o*o-s*s+l*l,b=y-c*c-u*u+h*h,_=p*d-f*g,w=(d*b-g*x)/(2*_)-n,k=(g*v-d*m)/_,T=(p*x-f*b)/(2*_)-a,A=(f*m-p*v)/_,M=k*k+A*A-1,S=2*(i+w*k+T*A),E=w*w+T*T-i*i,L=-(M?(S+Math.sqrt(S*S-4*M*E))/(2*M):E/S);return{x:n+w+k*L,y:a+T+A*L,r:L}}function x(t,e,r){var n,a,i,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(a=e.r+r.r,a*=a,o=t.r+r.r,a>(o*=o)?(n=(c+o-a)/(2*c),i=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-i*l,r.y=t.y-n*l+i*s):(n=(c+a-o)/(2*c),i=Math.sqrt(Math.max(0,a/c-n*n)),r.x=e.x+n*s-i*l,r.y=e.y+n*l+i*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,a=e.y-t.y;return r>0&&r*r>n*n+a*a}function _(t){var e=t._,r=t.next._,n=e.r+r.r,a=(e.x*r.r+r.x*e.r)/n,i=(e.y*r.r+r.y*e.r)/n;return a*a+i*i}function w(t){this._=t,this.next=null,this.previous=null}function k(t){if(!(a=t.length))return 0;var e,r,n,a,i,o,s,l,c,u,f;if((e=t[0]).x=0,e.y=0,!(a>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(a>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<a;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,f=e._.r;do{if(u<=f){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}f+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,i=_(e);(n=n.next)!==r;)(o=_(n))<i&&(e=n,i=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=h(e),s=0;s<a;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function T(t){if("function"!=typeof t)throw new Error;return t}function A(){return 0}function M(t){return function(){return t}}function S(t){return Math.sqrt(t.value)}function E(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function L(t,e){return function(r){if(n=r.children){var n,a,i,o=n.length,s=t(r)*e||0;if(s)for(a=0;a<o;++a)n[a].r+=s;if(i=k(n),s)for(a=0;a<o;++a)n[a].r-=s;r.r=i+s}}}function C(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function O(t,e,r,n,a){for(var i,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(i=o[s]).y0=r,i.y1=a,i.x0=e,i.x1=e+=i.value*c}var z="$",I={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function V(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function U(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,a){for(var i,o=t.children,s=-1,l=o.length,c=t.value&&(a-r)/t.value;++s<l;)(i=o[s]).x0=e,i.x1=n,i.y0=r,i.y1=r+=i.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,a,i){for(var o,s,l,c,u,h,f,p,d,g,v,m=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=a-r,c=i-n;do{u=y[b++].value}while(!u&&b<_);for(h=f=u,v=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/v,v/h);b<_;++b){if(u+=s=y[b].value,s<h&&(h=s),s>f&&(f=s),v=u*u*g,(p=Math.max(f/v,v/h))>d){u-=s;break}d=p}m.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?O(o,r,n,a,w?n+=c*u/w:i):H(o,r,n,w?r+=l*u/w:a,i),w-=u,x=b}return m}var W=function t(e){function r(t,r,n,a,i){Y(e,t,r,n,a,i)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,a,i){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?O(s,r,n,a,n+=(i-n)*s.value/p):H(s,r,n,r+=(a-r)*s.value/p,i),p-=s.value}else t._squarify=o=Y(e,t,r,n,a,i),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,a=1,i=1,o=!1;function s(e){var s,l=0;e.eachAfter(function(e){var a=e.children;a?(e.x=function(t){return t.reduce(r,0)/t.length}(a),e.y=function(t){return 1+t.reduce(n,0)}(a)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)});var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*a,t.y=(e.y-t.y)*i}:function(t){t.x=(t.x-h)/(f-h)*a,t.y=(1-(e.y?t.y/e.y:1))*i})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,a=+t[0],i=+t[1],s):o?null:[a,i]},s.nodeSize=function(t){return arguments.length?(o=!0,a=+t[0],i=+t[1],s):o?[a,i]:null},s},t.hierarchy=i,t.pack=function(){var t=null,e=1,r=1,n=A;function a(a){return a.x=e/2,a.y=r/2,t?a.eachBefore(E(t)).eachAfter(L(n,.5)).eachBefore(C(1)):a.eachBefore(E(S)).eachAfter(L(A,1)).eachAfter(L(n,a.r/Math.min(e,r))).eachBefore(C(Math.min(e,r)/(2*a.r))),a}return a.radius=function(e){return arguments.length?(t=null==(r=e)?null:T(r),a):t;var r},a.size=function(t){return arguments.length?(e=+t[0],r=+t[1],a):[e,r]},a.padding=function(t){return arguments.length?(n="function"==typeof t?t:M(+t),a):n},a},t.packSiblings=function(t){return k(t),t},t.packEnclose=h,t.partition=function(){var t=1,e=1,r=0,n=!1;function a(a){var i=a.height+1;return a.x0=a.y0=r,a.x1=t,a.y1=e/i,a.eachBefore(function(t,e){return function(n){n.children&&O(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var a=n.x0,i=n.y0,o=n.x1-r,s=n.y1-r;o<a&&(a=o=(a+o)/2),s<i&&(i=s=(i+s)/2),n.x0=a,n.y0=i,n.x1=o,n.y1=s}}(e,i)),n&&a.eachBefore(P),a}return a.round=function(t){return arguments.length?(n=!!t,a):n},a.size=function(r){return arguments.length?(t=+r[0],e=+r[1],a):[t,e]},a.padding=function(t){return arguments.length?(r=+t,a):r},a},t.stratify=function(){var t=R,e=F;function r(r){var n,a,i,o,s,u,h,f=r.length,p=new Array(f),d={};for(a=0;a<f;++a)n=r[a],s=p[a]=new c(n),null!=(u=t(n,a,r))&&(u+="")&&(d[h=z+(s.id=u)]=h in d?D:s);for(a=0;a<f;++a)if(s=p[a],null!=(u=e(r[a],a,r))&&(u+="")){if(!(o=d[z+u]))throw new Error("missing: "+u);if(o===D)throw new Error("ambiguous: "+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(i)throw new Error("multiple roots");i=s}if(!i)throw new Error("no root");if(i.parent=I,i.eachBefore(function(t){t.depth=t.parent.depth+1,--f}).eachBefore(l),i.parent=null,f>0)throw new Error("cycle");return i}return r.id=function(e){return arguments.length?(t=T(e),r):t},r.parentId=function(t){return arguments.length?(e=T(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function a(a){var l=function(t){for(var e,r,n,a,i,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(i=n.length),a=i-1;a>=0;--a)s.push(r=e.children[a]=new q(n[a],a)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(a);if(l.eachAfter(i),l.parent.m=-l.z,l.eachBefore(o),n)a.eachBefore(s);else{var c=a,u=a,h=a;a.eachBefore(function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)});var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),g=r/(h.depth||1);a.eachBefore(function(t){t.x=(t.x+p)*d,t.y=t.depth*g})}return a}function i(e){var r=e.children,n=e.parent.children,a=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,a=t.children,i=a.length;--i>=0;)(e=a[i]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var i=(r[0].z+r[r.length-1].z)/2;a?(e.z=a.z+t(e._,a._),e.m=e.z-i):e.z=i}else a&&(e.z=a.z+t(e._,a._));e.parent.A=function(e,r,n){if(r){for(var a,i=e,o=e,s=r,l=i.parent.children[0],c=i.m,u=o.m,h=s.m,f=l.m;s=j(s),i=N(i),s&&i;)l=N(l),(o=j(o)).a=e,(a=s.z+h-i.z-c+t(s._,i._))>0&&(V(U(s,e,n),e,a),c+=a,u+=a),h+=s.m,c+=i.m,f+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=h-u),i&&!N(l)&&(l.t=i,l.m+=c-f,n=e)}return n}(e,a,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return a.separation=function(e){return arguments.length?(t=e,a):t},a.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],a):n?null:[e,r]},a.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],a):n?[e,r]:null},a},t.treemap=function(){var t=W,e=!1,r=1,n=1,a=[0],i=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),a=[0],e&&t.eachBefore(P),t}function h(e){var r=a[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=a[e.depth+1]=i(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=T(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(i="function"==typeof t?t:M(+t),u):i},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o="function"==typeof t?t:M(+t),u):o},u.paddingRight=function(t){return arguments.length?(s="function"==typeof t?t:M(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l="function"==typeof t?t:M(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c="function"==typeof t?t:M(+t),u):c},u},t.treemapBinary=function(t,e,r,n,a){var i,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=i=0;i<l;++i)c[i+1]=o+=s[i].value;!function t(e,r,n,a,i,o,l){if(e>=r-1){var u=s[e];return u.x0=a,u.y0=i,u.x1=o,void(u.y1=l)}for(var h=c[e],f=n/2+h,p=e+1,d=r-1;p<d;){var g=p+d>>>1;c[g]<f?p=g+1:d=g}f-c[p-1]<c[p]-f&&e+1<p&&--p;var v=c[p]-h,m=n-v;if(o-a>l-i){var y=(a*m+o*v)/n;t(e,p,v,a,i,y,l),t(p,r,m,y,i,o,l)}else{var x=(i*m+l*v)/n;t(e,p,v,a,i,o,x),t(p,r,m,a,x,o,l)}}(0,l,t.value,e,r,n,a)},t.treemapDice=O,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,a){(1&t.depth?H:O)(t,e,r,n,a)},t.treemapSquarify=W,t.treemapResquarify=X,Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],159:[function(t,e,r){var n,a;n=this,a=function(t,e){"use strict";function r(t,e,r,n,a){var i=t*t,o=i*t;return((1-3*t+3*i-o)*e+(4-6*i+3*o)*r+(1+3*t+3*i-3*o)*n+o*a)/6}function n(t){var e=t.length-1;return function(n){var a=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),i=t[a],o=t[a+1],s=a>0?t[a-1]:2*i-o,l=a<e-1?t[a+2]:2*o-i;return r((n-a/e)*e,s,i,o,l)}}function a(t){var e=t.length;return function(n){var a=Math.floor(((n%=1)<0?++n:n)*e),i=t[(a+e-1)%e],o=t[a%e],s=t[(a+1)%e],l=t[(a+2)%e];return r((n-a/e)*e,i,o,s,l)}}function i(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):i(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):i(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):i(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function a(t,r){var a=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),i=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=a(e),t.g=i(e),t.b=o(e),t.opacity=s(e),t+""}}return a.gamma=t,a}(1);function h(t){return function(r){var n,a,i=r.length,o=new Array(i),s=new Array(i),l=new Array(i);for(n=0;n<i;++n)a=e.rgb(r[n]),o[n]=a.r||0,s[n]=a.g||0,l[n]=a.b||0;return o=t(o),s=t(s),l=t(l),a.opacity=1,function(t){return a.r=o(t),a.g=s(t),a.b=l(t),a+""}}}var f=h(n),p=h(a);function d(t,e){var r,n=e?e.length:0,a=t?Math.min(n,t.length):0,i=new Array(a),o=new Array(n);for(r=0;r<a;++r)i[r]=_(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<a;++r)o[r]=i[r](t);return o}}function g(t,e){var r=new Date;return e-=t=+t,function(n){return r.setTime(t+e*n),r}}function v(t,e){return e-=t=+t,function(r){return t+e*r}}function m(t,e){var r,n={},a={};for(r in null!==t&&"object"==typeof t||(t={}),null!==e&&"object"==typeof e||(e={}),e)r in t?n[r]=_(t[r],e[r]):a[r]=e[r];return function(t){for(r in n)a[r]=n[r](t);return a}}var y=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,x=new RegExp(y.source,"g");function b(t,e){var r,n,a,i=y.lastIndex=x.lastIndex=0,o=-1,s=[],l=[];for(t+="",e+="";(r=y.exec(t))&&(n=x.exec(e));)(a=n.index)>i&&(a=e.slice(i,a),s[o]?s[o]+=a:s[++o]=a),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:v(r,n)})),i=x.lastIndex;return i<e.length&&(a=e.slice(i),s[o]?s[o]+=a:s[++o]=a),s.length<2?l[0]?function(t){return function(e){return t(e)+""}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join("")})}function _(t,r){var n,a=typeof r;return null==r||"boolean"===a?i(r):("number"===a?v:"string"===a?(n=e.color(r))?(r=n,u):b:r instanceof e.color?u:r instanceof Date?g:Array.isArray(r)?d:"function"!=typeof r.valueOf&&"function"!=typeof r.toString||isNaN(r)?m:v)(t,r)}var w,k,T,A,M=180/Math.PI,S={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function E(t,e,r,n,a,i){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:a,translateY:i,rotate:Math.atan2(e,t)*M,skewX:Math.atan(l)*M,scaleX:o,scaleY:s}}function L(t,e,r,n){function a(t){return t.length?t.pop()+" ":""}return function(i,o){var s=[],l=[];return i=t(i),o=t(o),function(t,n,a,i,o,s){if(t!==a||n!==i){var l=o.push("translate(",null,e,null,r);s.push({i:l-4,x:v(t,a)},{i:l-2,x:v(n,i)})}else(a||i)&&o.push("translate("+a+e+i+r)}(i.translateX,i.translateY,o.translateX,o.translateY,s,l),function(t,e,r,i){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),i.push({i:r.push(a(r)+"rotate(",null,n)-2,x:v(t,e)})):e&&r.push(a(r)+"rotate("+e+n)}(i.rotate,o.rotate,s,l),function(t,e,r,i){t!==e?i.push({i:r.push(a(r)+"skewX(",null,n)-2,x:v(t,e)}):e&&r.push(a(r)+"skewX("+e+n)}(i.skewX,o.skewX,s,l),function(t,e,r,n,i,o){if(t!==r||e!==n){var s=i.push(a(i)+"scale(",null,",",null,")");o.push({i:s-4,x:v(t,r)},{i:s-2,x:v(e,n)})}else 1===r&&1===n||i.push(a(i)+"scale("+r+","+n+")")}(i.scaleX,i.scaleY,o.scaleX,o.scaleY,s,l),i=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join("")}}}var C=L(function(t){return"none"===t?S:(w||(w=document.createElement("DIV"),k=document.documentElement,T=document.defaultView),w.style.transform=t,t=T.getComputedStyle(k.appendChild(w),null).getPropertyValue("transform"),k.removeChild(w),E(+(t=t.slice(7,-1).split(","))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))},"px, ","px)","deg)"),P=L(function(t){return null==t?S:(A||(A=document.createElementNS("http://www.w3.org/2000/svg","g")),A.setAttribute("transform",t),(t=A.transform.baseVal.consolidate())?E((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):S)},", ",")",")"),O=Math.SQRT2,z=2,I=4,D=1e-12;function R(t){return((t=Math.exp(t))+1/t)/2}function F(t){return function(r,n){var a=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),i=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=a(t),r.s=i(t),r.l=o(t),r.opacity=s(t),r+""}}}var B=F(s),N=F(c);function j(t){return function(r,n){var a=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),i=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=a(t),r.c=i(t),r.l=o(t),r.opacity=s(t),r+""}}}var V=j(s),U=j(c);function q(t){return function r(n){function a(r,a){var i=t((r=e.cubehelix(r)).h,(a=e.cubehelix(a)).h),o=c(r.s,a.s),s=c(r.l,a.l),l=c(r.opacity,a.opacity);return function(t){return r.h=i(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+""}}return n=+n,a.gamma=r,a}(1)}var H=q(s),G=q(c);t.interpolate=_,t.interpolateArray=d,t.interpolateBasis=n,t.interpolateBasisClosed=a,t.interpolateDate=g,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateNumber=v,t.interpolateObject=m,t.interpolateRound=function(t,e){return e-=t=+t,function(r){return Math.round(t+e*r)}},t.interpolateString=b,t.interpolateTransformCss=C,t.interpolateTransformSvg=P,t.interpolateZoom=function(t,e){var r,n,a=t[0],i=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-a,h=l-i,f=u*u+h*h;if(f<D)n=Math.log(c/o)/O,r=function(t){return[a+t*u,i+t*h,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+I*f)/(2*o*z*p),g=(c*c-o*o-I*f)/(2*c*z*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/O,r=function(t){var e,r=t*n,s=R(v),l=o/(z*p)*(s*(e=O*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[a+l*u,i+l*h,o*s/R(O*r+v)]}}return r.duration=1e3*n,r},t.interpolateRgb=u,t.interpolateRgbBasis=f,t.interpolateRgbBasisClosed=p,t.interpolateHsl=B,t.interpolateHslLong=N,t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),a=c(t.a,r.a),i=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=a(e),t.b=i(e),t.opacity=o(e),t+""}},t.interpolateHcl=V,t.interpolateHclLong=U,t.interpolateCubehelix=H,t.interpolateCubehelixLong=G,t.piecewise=function(t,e){for(var r=0,n=e.length-1,a=e[0],i=new Array(n<0?0:n);r<n;)i[r]=t(a,a=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return i[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,"__esModule",{value:!0})},"object"==typeof r&&"undefined"!=typeof e?a(r,t("d3-color")):a(n.d3=n.d3||{},n.d3)},{"d3-color":155}],160:[function(t,e,r){var n;n=this,function(t){"use strict";var e=Math.PI,r=2*e,n=r-1e-6;function a(){this._x0=this._y0=this._x1=this._y1=null,this._=""}function i(){return new a}a.prototype=i.prototype={constructor:a,moveTo:function(t,e){this._+="M"+(this._x0=this._x1=+t)+","+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+="Z")},lineTo:function(t,e){this._+="L"+(this._x1=+t)+","+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+="Q"+ +t+","+ +e+","+(this._x1=+r)+","+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,a,i){this._+="C"+ +t+","+ +e+","+ +r+","+ +n+","+(this._x1=+a)+","+(this._y1=+i)},arcTo:function(t,r,n,a,i){t=+t,r=+r,n=+n,a=+a,i=+i;var o=this._x1,s=this._y1,l=n-t,c=a-r,u=o-t,h=s-r,f=u*u+h*h;if(i<0)throw new Error("negative radius: "+i);if(null===this._x1)this._+="M"+(this._x1=t)+","+(this._y1=r);else if(f>1e-6)if(Math.abs(h*l-c*u)>1e-6&&i){var p=n-o,d=a-s,g=l*l+c*c,v=p*p+d*d,m=Math.sqrt(g),y=Math.sqrt(f),x=i*Math.tan((e-Math.acos((g+f-v)/(2*m*y)))/2),b=x/y,_=x/m;Math.abs(b-1)>1e-6&&(this._+="L"+(t+b*u)+","+(r+b*h)),this._+="A"+i+","+i+",0,0,"+ +(h*p>u*d)+","+(this._x1=t+_*l)+","+(this._y1=r+_*c)}else this._+="L"+(this._x1=t)+","+(this._y1=r);else;},arc:function(t,a,i,o,s,l){t=+t,a=+a;var c=(i=+i)*Math.cos(o),u=i*Math.sin(o),h=t+c,f=a+u,p=1^l,d=l?o-s:s-o;if(i<0)throw new Error("negative radius: "+i);null===this._x1?this._+="M"+h+","+f:(Math.abs(this._x1-h)>1e-6||Math.abs(this._y1-f)>1e-6)&&(this._+="L"+h+","+f),i&&(d<0&&(d=d%r+r),d>n?this._+="A"+i+","+i+",0,1,"+p+","+(t-c)+","+(a-u)+"A"+i+","+i+",0,1,"+p+","+(this._x1=h)+","+(this._y1=f):d>1e-6&&(this._+="A"+i+","+i+",0,"+ +(d>=e)+","+p+","+(this._x1=t+i*Math.cos(s))+","+(this._y1=a+i*Math.sin(s))))},rect:function(t,e,r,n){this._+="M"+(this._x0=this._x1=+t)+","+(this._y0=this._y1=+e)+"h"+ +r+"v"+ +n+"h"+-r+"Z"},toString:function(){return this._}},t.path=i,Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],161:[function(t,e,r){var n;n=this,function(t){"use strict";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var a,i,o,s,l,c,u,h,f,p=t._root,d={data:n},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(i=(g+m)/2))?g=i:m=i,(u=r>=(o=(v+y)/2))?v=o:y=o,a=p,!(p=p[h=u<<1|c]))return a[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,a?a[h]=d:t._root=d,t;do{a=a?a[h]=new Array(4):t._root=new Array(4),(c=e>=(i=(g+m)/2))?g=i:m=i,(u=r>=(o=(v+y)/2))?v=o:y=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=i));return a[f]=p,a[h]=d,t}var r=function(t,e,r,n,a){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=a};function n(t){return t[0]}function a(t){return t[1]}function i(t,e,r){var i=new o(null==e?n:e,null==r?a:r,NaN,NaN,NaN,NaN);return null==t?i:i.addAll(t)}function o(t,e,r,n,a,i){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=a,this._y1=i,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=i.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var a=0;a<4;++a)(e=n.source[a])&&(e.length?t.push({source:e,target:n.target[a]=new Array(4)}):n.target[a]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,a,i,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,h=-1/0,f=-1/0;for(n=0;n<o;++n)isNaN(a=+this._x.call(null,r=t[n]))||isNaN(i=+this._y.call(null,r))||(s[n]=a,l[n]=i,a<c&&(c=a),a>h&&(h=a),i<u&&(u=i),i>f&&(f=i));for(h<c&&(c=this._x0,h=this._x1),f<u&&(u=this._y0,f=this._y1),this.cover(c,u).cover(h,f),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,a=this._x1,i=this._y1;if(isNaN(r))a=(r=Math.floor(t))+1,i=(n=Math.floor(e))+1;else{if(!(r>t||t>a||n>e||e>i))return this;var o,s,l=a-r,c=this._root;switch(s=(e<(n+i)/2)<<1|t<(r+a)/2){case 0:do{(o=new Array(4))[s]=c,c=o}while(i=n+(l*=2),t>(a=r+l)||e>i);break;case 1:do{(o=new Array(4))[s]=c,c=o}while(i=n+(l*=2),(r=a-l)>t||e>i);break;case 2:do{(o=new Array(4))[s]=c,c=o}while(n=i-(l*=2),t>(a=r+l)||n>e);break;case 3:do{(o=new Array(4))[s]=c,c=o}while(n=i-(l*=2),(r=a-l)>t||n>e)}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=a,this._y1=i,this},l.data=function(){var t=[];return this.visit(function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)}),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var a,i,o,s,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,g=[],v=this._root;for(v&&g.push(new r(v,h,f,p,d)),null==n?n=1/0:(h=t-n,f=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(v=c.node)||(i=c.x0)>p||(o=c.y0)>d||(s=c.x1)<h||(l=c.y1)<f))if(v.length){var m=(i+s)/2,y=(o+l)/2;g.push(new r(v[3],m,y,s,l),new r(v[2],i,y,m,l),new r(v[1],m,o,s,y),new r(v[0],i,o,m,y)),(u=(e>=y)<<1|t>=m)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,v.data),b=e-+this._y.call(null,v.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);h=t-w,f=e-w,p=t+w,d=e+w,a=v.data}}return a},l.remove=function(t){if(isNaN(i=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,a,i,o,s,l,c,u,h,f,p=this._root,d=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((c=i>=(s=(d+v)/2))?d=s:v=s,(u=o>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(a=p.next)&&delete p.next,n?(a?n.next=a:delete n.next,this):e?(a?e[h]=a:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=a,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit(function(e){if(!e.length)do{++t}while(e=e.next)}),t},l.visit=function(t){var e,n,a,i,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,a=e.x0,i=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(a+o)/2,h=(i+s)/2;(n=c[3])&&l.push(new r(n,u,h,o,s)),(n=c[2])&&l.push(new r(n,a,h,u,s)),(n=c[1])&&l.push(new r(n,u,i,o,h)),(n=c[0])&&l.push(new r(n,a,i,u,h))}return this},l.visitAfter=function(t){var e,n=[],a=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var i=e.node;if(i.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(s+c)/2,f=(l+u)/2;(o=i[0])&&n.push(new r(o,s,l,h,f)),(o=i[1])&&n.push(new r(o,h,l,c,f)),(o=i[2])&&n.push(new r(o,s,f,h,u)),(o=i[3])&&n.push(new r(o,h,f,c,u))}a.push(e)}for(;e=a.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=i,Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],162:[function(t,e,r){var n,a;n=this,a=function(t,e){"use strict";function r(t){return function(){return t}}var n=Math.abs,a=Math.atan2,i=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=1e-12,h=Math.PI,f=h/2,p=2*h;function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function v(t){return t.outerRadius}function m(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,a,i,s){var l=t-r,u=e-n,h=(s?i:-i)/c(l*l+u*u),f=h*u,p=-h*l,d=t+f,g=e+p,v=r+f,m=n+p,y=(d+v)/2,x=(g+m)/2,b=v-d,_=m-g,w=b*b+_*_,k=a-i,T=d*m-v*g,A=(_<0?-1:1)*c(o(0,k*k*w-T*T)),M=(T*_-b*A)/w,S=(-T*b-_*A)/w,E=(T*_+b*A)/w,L=(-T*b+_*A)/w,C=M-y,P=S-x,O=E-y,z=L-x;return C*C+P*P>O*O+z*z&&(M=E,S=L),{cx:M,cy:S,x01:-f,y01:-p,x11:M*(a/k-1),y11:S*(a/k-1)}}function _(t){this._context=t}function w(t){return new _(t)}function k(t){return t[0]}function T(t){return t[1]}function A(){var t=k,n=T,a=r(!0),i=null,o=w,s=null;function l(r){var l,c,u,h=r.length,f=!1;for(null==i&&(s=o(u=e.path())),l=0;l<=h;++l)!(l<h&&a(c=r[l],l,r))===f&&((f=!f)?s.lineStart():s.lineEnd()),f&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+""||null}return l.x=function(e){return arguments.length?(t="function"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n="function"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(a="function"==typeof t?t:r(!!t),l):a},l.curve=function(t){return arguments.length?(o=t,null!=i&&(s=o(i)),l):o},l.context=function(t){return arguments.length?(null==t?i=s=null:s=o(i=t),l):i},l}function M(){var t=k,n=null,a=r(0),i=T,o=r(!0),s=null,l=w,c=null;function u(r){var u,h,f,p,d,g=r.length,v=!1,m=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===v)if(v=!v)h=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),f=u-1;f>=h;--f)c.point(m[f],y[f]);c.lineEnd(),c.areaEnd()}v&&(m[u]=+t(p,u,r),y[u]=+a(p,u,r),c.point(n?+n(p,u,r):m[u],i?+i(p,u,r):y[u]))}if(d)return c=null,d+""||null}function h(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t="function"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t="function"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:"function"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(a="function"==typeof t?t:r(+t),i=null,u):a},u.y0=function(t){return arguments.length?(a="function"==typeof t?t:r(+t),u):a},u.y1=function(t){return arguments.length?(i=null==t?null:"function"==typeof t?t:r(+t),u):i},u.lineX0=u.lineY0=function(){return h().x(t).y(a)},u.lineY1=function(){return h().x(t).y(i)},u.lineX1=function(){return h().x(n).y(a)},u.defined=function(t){return arguments.length?(o="function"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function S(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function E(t){return t}_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var L=P(w);function C(t){this._curve=t}function P(t){function e(e){return new C(t(e))}return e._curve=t,e}function O(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function z(){return O(A().curve(L))}function I(){var t=M().curve(L),e=t.curve,r=t.lineX0,n=t.lineX1,a=t.lineY0,i=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return O(r())},delete t.lineX0,t.lineEndAngle=function(){return O(n())},delete t.lineX1,t.lineInnerRadius=function(){return O(a())},delete t.lineY0,t.lineOuterRadius=function(){return O(i())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function D(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}C.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var R=Array.prototype.slice;function F(t){return t.source}function B(t){return t.target}function N(t){var n=F,a=B,i=k,o=T,s=null;function l(){var r,l=R.call(arguments),c=n.apply(this,l),u=a.apply(this,l);if(s||(s=r=e.path()),t(s,+i.apply(this,(l[0]=c,l)),+o.apply(this,l),+i.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+""||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(a=t,l):a},l.x=function(t){return arguments.length?(i="function"==typeof t?t:r(+t),l):i},l.y=function(t){return arguments.length?(o="function"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function j(t,e,r,n,a){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,a,n,a)}function V(t,e,r,n,a){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+a)/2,n,r,n,a)}function U(t,e,r,n,a){var i=D(e,r),o=D(e,r=(r+a)/2),s=D(n,r),l=D(n,a);t.moveTo(i[0],i[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var q={draw:function(t,e){var r=Math.sqrt(e/h);t.moveTo(r,0),t.arc(0,0,r,0,p)}},H={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},G=Math.sqrt(1/3),Y=2*G,W={draw:function(t,e){var r=Math.sqrt(e/Y),n=r*G;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},X=Math.sin(h/10)/Math.sin(7*h/10),Z=Math.sin(p/10)*X,J=-Math.cos(p/10)*X,K={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=Z*r,a=J*r;t.moveTo(0,-r),t.lineTo(n,a);for(var i=1;i<5;++i){var o=p*i/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*a,l*n+s*a)}t.closePath()}},Q={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},$=Math.sqrt(3),tt={draw:function(t,e){var r=-Math.sqrt(e/(3*$));t.moveTo(0,2*r),t.lineTo(-$*r,-r),t.lineTo($*r,-r),t.closePath()}},et=-.5,rt=Math.sqrt(3)/2,nt=1/Math.sqrt(12),at=3*(nt/2+1),it={draw:function(t,e){var r=Math.sqrt(e/at),n=r/2,a=r*nt,i=n,o=r*nt+r,s=-i,l=o;t.moveTo(n,a),t.lineTo(i,o),t.lineTo(s,l),t.lineTo(et*n-rt*a,rt*n+et*a),t.lineTo(et*i-rt*o,rt*i+et*o),t.lineTo(et*s-rt*l,rt*s+et*l),t.lineTo(et*n+rt*a,et*a-rt*n),t.lineTo(et*i+rt*o,et*o-rt*i),t.lineTo(et*s+rt*l,et*l-rt*s),t.closePath()}},ot=[q,H,W,Q,K,tt,it];function st(){}function lt(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ct(t){this._context=t}function ut(t){this._context=t}function ht(t){this._context=t}function ft(t,e){this._basis=new ct(t),this._beta=e}ct.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:lt(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ut.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,a=t[0],i=e[0],o=t[r]-a,s=e[r]-i,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(a+n*o),this._beta*e[l]+(1-this._beta)*(i+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var pt=function t(e){function r(t){return 1===e?new ct(t):new ft(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function dt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function gt(t,e){this._context=t,this._k=(1-e)/6}gt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:dt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new gt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var yt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function xt(t,e){this._context=t,this._k=(1-e)/6}xt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var bt=function t(e){function r(t){return new xt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function _t(t,e,r){var n=t._x1,a=t._y1,i=t._x2,o=t._y2;if(t._l01_a>u){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,a=(a*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>u){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,h=3*t._l23_a*(t._l23_a+t._l12_a);i=(i*c+t._x1*t._l23_2a-e*t._l12_2a)/h,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/h}t._context.bezierCurveTo(n,a,i,o,t._x2,t._y2)}function wt(t,e){this._context=t,this._alpha=e}wt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new wt(t,e):new gt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var St=function t(e){function r(t){return e?new Mt(t,e):new xt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Et(t){this._context=t}function Lt(t){return t<0?-1:1}function Ct(t,e,r){var n=t._x1-t._x0,a=e-t._x1,i=(t._y1-t._y0)/(n||a<0&&-0),o=(r-t._y1)/(a||n<0&&-0),s=(i*a+o*n)/(n+a);return(Lt(i)+Lt(o))*Math.min(Math.abs(i),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function Ot(t,e,r){var n=t._x0,a=t._y0,i=t._x1,o=t._y1,s=(i-n)/3;t._context.bezierCurveTo(n+s,a+s*e,i-s,o-s*r,i,o)}function zt(t){this._context=t}function It(t){this._context=new Dt(t)}function Dt(t){this._context=t}function Rt(t){this._context=t}function Ft(t){var e,r,n=t.length-1,a=new Array(n),i=new Array(n),o=new Array(n);for(a[0]=0,i[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)a[e]=1,i[e]=4,o[e]=4*t[e]+2*t[e+1];for(a[n-1]=2,i[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=a[e]/i[e-1],i[e]-=r,o[e]-=r*o[e-1];for(a[n-1]=o[n-1]/i[n-1],e=n-2;e>=0;--e)a[e]=(o[e]-a[e+1])/i[e];for(i[n-1]=(t[n]+a[n-1])/2,e=0;e<n-1;++e)i[e]=2*t[e+1]-a[e+1];return[a,i]}function Bt(t,e){this._context=t,this._t=e}function Nt(t,e){if((a=t.length)>1)for(var r,n,a,i=1,o=t[e[0]],s=o.length;i<a;++i)for(n=o,o=t[e[i]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function jt(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Vt(t,e){return t[e]}function Ut(t){var e=t.map(qt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function qt(t){for(var e,r=-1,n=0,a=t.length,i=-1/0;++r<a;)(e=+t[r][1])>i&&(i=e,n=r);return n}function Ht(t){var e=t.map(Gt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function Gt(t){for(var e,r=0,n=-1,a=t.length;++n<a;)(e=+t[n][1])&&(r+=e);return r}Et.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},zt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Ot(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Ot(this,Pt(this,r=Ct(this,t,e)),r);break;default:Ot(this,this._t0,r=Ct(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(It.prototype=Object.create(zt.prototype)).point=function(t,e){zt.prototype.point.call(this,e,t)},Dt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,a,i){this._context.bezierCurveTo(e,t,n,r,i,a)}},Rt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Ft(t),a=Ft(e),i=0,o=1;o<r;++i,++o)this._context.bezierCurveTo(n[0][i],a[0][i],n[1][i],a[1][i],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=v,_=r(0),w=null,k=m,T=y,A=x,M=null;function S(){var r,g,v,m=+t.apply(this,arguments),y=+o.apply(this,arguments),x=k.apply(this,arguments)-f,S=T.apply(this,arguments)-f,E=n(S-x),L=S>x;if(M||(M=r=e.path()),y<m&&(g=y,y=m,m=g),y>u)if(E>p-u)M.moveTo(y*i(x),y*l(x)),M.arc(0,0,y,x,S,!L),m>u&&(M.moveTo(m*i(S),m*l(S)),M.arc(0,0,m,S,x,L));else{var C,P,O=x,z=S,I=x,D=S,R=E,F=E,B=A.apply(this,arguments)/2,N=B>u&&(w?+w.apply(this,arguments):c(m*m+y*y)),j=s(n(y-m)/2,+_.apply(this,arguments)),V=j,U=j;if(N>u){var q=d(N/m*l(B)),H=d(N/y*l(B));(R-=2*q)>u?(I+=q*=L?1:-1,D-=q):(R=0,I=D=(x+S)/2),(F-=2*H)>u?(O+=H*=L?1:-1,z-=H):(F=0,O=z=(x+S)/2)}var G=y*i(O),Y=y*l(O),W=m*i(D),X=m*l(D);if(j>u){var Z,J=y*i(z),K=y*l(z),Q=m*i(I),$=m*l(I);if(E<h&&(Z=function(t,e,r,n,a,i,o,s){var l=r-t,c=n-e,h=o-a,f=s-i,p=f*l-h*c;if(!(p*p<u))return[t+(p=(h*(e-i)-f*(t-a))/p)*l,e+p*c]}(G,Y,Q,$,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],at=1/l(((v=(tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))>1?0:v<-1?h:Math.acos(v))/2),it=c(Z[0]*Z[0]+Z[1]*Z[1]);V=s(j,(m-it)/(at-1)),U=s(j,(y-it)/(at+1))}}F>u?U>u?(C=b(Q,$,G,Y,y,U,L),P=b(J,K,W,X,y,U,L),M.moveTo(C.cx+C.x01,C.cy+C.y01),U<j?M.arc(C.cx,C.cy,U,a(C.y01,C.x01),a(P.y01,P.x01),!L):(M.arc(C.cx,C.cy,U,a(C.y01,C.x01),a(C.y11,C.x11),!L),M.arc(0,0,y,a(C.cy+C.y11,C.cx+C.x11),a(P.cy+P.y11,P.cx+P.x11),!L),M.arc(P.cx,P.cy,U,a(P.y11,P.x11),a(P.y01,P.x01),!L))):(M.moveTo(G,Y),M.arc(0,0,y,O,z,!L)):M.moveTo(G,Y),m>u&&R>u?V>u?(C=b(W,X,J,K,m,-V,L),P=b(G,Y,Q,$,m,-V,L),M.lineTo(C.cx+C.x01,C.cy+C.y01),V<j?M.arc(C.cx,C.cy,V,a(C.y01,C.x01),a(P.y01,P.x01),!L):(M.arc(C.cx,C.cy,V,a(C.y01,C.x01),a(C.y11,C.x11),!L),M.arc(0,0,m,a(C.cy+C.y11,C.cx+C.x11),a(P.cy+P.y11,P.cx+P.x11),L),M.arc(P.cx,P.cy,V,a(P.y11,P.x11),a(P.y01,P.x01),!L))):M.arc(0,0,m,D,I,L):M.lineTo(W,X)}else M.moveTo(0,0);if(M.closePath(),r)return M=null,r+""||null}return S.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +T.apply(this,arguments))/2-h/2;return[i(r)*e,l(r)*e]},S.innerRadius=function(e){return arguments.length?(t="function"==typeof e?e:r(+e),S):t},S.outerRadius=function(t){return arguments.length?(o="function"==typeof t?t:r(+t),S):o},S.cornerRadius=function(t){return arguments.length?(_="function"==typeof t?t:r(+t),S):_},S.padRadius=function(t){return arguments.length?(w=null==t?null:"function"==typeof t?t:r(+t),S):w},S.startAngle=function(t){return arguments.length?(k="function"==typeof t?t:r(+t),S):k},S.endAngle=function(t){return arguments.length?(T="function"==typeof t?t:r(+t),S):T},S.padAngle=function(t){return arguments.length?(A="function"==typeof t?t:r(+t),S):A},S.context=function(t){return arguments.length?(M=null==t?null:t,S):M},S},t.area=M,t.line=A,t.pie=function(){var t=E,e=S,n=null,a=r(0),i=r(p),o=r(0);function s(r){var s,l,c,u,h,f=r.length,d=0,g=new Array(f),v=new Array(f),m=+a.apply(this,arguments),y=Math.min(p,Math.max(-p,i.apply(this,arguments)-m)),x=Math.min(Math.abs(y)/f,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<f;++s)(h=v[g[s]=s]=+t(r[s],s,r))>0&&(d+=h);for(null!=e?g.sort(function(t,r){return e(v[t],v[r])}):null!=n&&g.sort(function(t,e){return n(r[t],r[e])}),s=0,c=d?(y-f*b)/d:0;s<f;++s,m=u)l=g[s],u=m+((h=v[l])>0?h*c:0)+b,v[l]={data:r[l],index:s,value:h,startAngle:m,endAngle:u,padAngle:x};return v}return s.value=function(e){return arguments.length?(t="function"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(a="function"==typeof t?t:r(+t),s):a},s.endAngle=function(t){return arguments.length?(i="function"==typeof t?t:r(+t),s):i},s.padAngle=function(t){return arguments.length?(o="function"==typeof t?t:r(+t),s):o},s},t.areaRadial=I,t.radialArea=I,t.lineRadial=z,t.radialLine=z,t.pointRadial=D,t.linkHorizontal=function(){return N(j)},t.linkVertical=function(){return N(V)},t.linkRadial=function(){var t=N(U);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.symbol=function(){var t=r(q),n=r(64),a=null;function i(){var r;if(a||(a=r=e.path()),t.apply(this,arguments).draw(a,+n.apply(this,arguments)),r)return a=null,r+""||null}return i.type=function(e){return arguments.length?(t="function"==typeof e?e:r(e),i):t},i.size=function(t){return arguments.length?(n="function"==typeof t?t:r(+t),i):n},i.context=function(t){return arguments.length?(a=null==t?null:t,i):a},i},t.symbols=ot,t.symbolCircle=q,t.symbolCross=H,t.symbolDiamond=W,t.symbolSquare=Q,t.symbolStar=K,t.symbolTriangle=tt,t.symbolWye=it,t.curveBasisClosed=function(t){return new ut(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBasis=function(t){return new ct(t)},t.curveBundle=pt,t.curveCardinalClosed=yt,t.curveCardinalOpen=bt,t.curveCardinal=vt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=St,t.curveCatmullRom=kt,t.curveLinearClosed=function(t){return new Et(t)},t.curveLinear=w,t.curveMonotoneX=function(t){return new zt(t)},t.curveMonotoneY=function(t){return new It(t)},t.curveNatural=function(t){return new Rt(t)},t.curveStep=function(t){return new Bt(t,.5)},t.curveStepAfter=function(t){return new Bt(t,1)},t.curveStepBefore=function(t){return new Bt(t,0)},t.stack=function(){var t=r([]),e=jt,n=Nt,a=Vt;function i(r){var i,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(i=0;i<c;++i){for(var h,f=s[i],p=u[i]=new Array(l),d=0;d<l;++d)p[d]=h=[0,+a(r[d],f,d,r)],h.data=r[d];p.key=f}for(i=0,o=e(u);i<c;++i)u[o[i]].index=i;return n(u,o),u}return i.keys=function(e){return arguments.length?(t="function"==typeof e?e:r(R.call(e)),i):t},i.value=function(t){return arguments.length?(a="function"==typeof t?t:r(+t),i):a},i.order=function(t){return arguments.length?(e=null==t?jt:"function"==typeof t?t:r(R.call(t)),i):e},i.offset=function(t){return arguments.length?(n=null==t?Nt:t,i):n},i},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,a,i=0,o=t[0].length;i<o;++i){for(a=r=0;r<n;++r)a+=t[r][i][1]||0;if(a)for(r=0;r<n;++r)t[r][i][1]/=a}Nt(t,e)}},t.stackOffsetDiverging=function(t,e){if((s=t.length)>1)for(var r,n,a,i,o,s,l=0,c=t[e[0]].length;l<c;++l)for(i=o=0,r=0;r<s;++r)(a=(n=t[e[r]][l])[1]-n[0])>=0?(n[0]=i,n[1]=i+=a):a<0?(n[1]=o,n[0]=o+=a):n[0]=i},t.stackOffsetNone=Nt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,a=t[e[0]],i=a.length;n<i;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;a[n][1]+=a[n][0]=-s/2}Nt(t,e)}},t.stackOffsetWiggle=function(t,e){if((a=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,a,i=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<a;++s){for(var u=t[e[s]],h=u[o][1]||0,f=(h-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];f+=(d[o][1]||0)-(d[o-1][1]||0)}l+=h,c+=f*h}r[o-1][1]+=r[o-1][0]=i,l&&(i-=c/l)}r[o-1][1]+=r[o-1][0]=i,Nt(t,e)}},t.stackOrderAppearance=Ut,t.stackOrderAscending=Ht,t.stackOrderDescending=function(t){return Ht(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,a=t.map(Gt),i=Ut(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=i[e],o<s?(o+=a[r],l.push(r)):(s+=a[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=jt,t.stackOrderReverse=function(t){return jt(t).reverse()},Object.defineProperty(t,"__esModule",{value:!0})},"object"==typeof r&&"undefined"!=typeof e?a(r,t("d3-path")):a(n.d3=n.d3||{},n.d3)},{"d3-path":160}],163:[function(t,e,r){var n;n=this,function(t){"use strict";var e,r,n=0,a=0,i=0,o=1e3,s=0,l=0,c=0,u="object"==typeof performance&&performance.now?performance:Date,h="object"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return l||(h(p),l=u.now()+c)}function p(){l=0}function d(){this._call=this._time=this._next=null}function g(t,e,r){var n=new d;return n.restart(t,e,r),n}function v(){f(),++n;for(var t,r=e;r;)(t=l-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){l=(s=u.now())+c,n=a=0;try{v()}finally{n=0,function(){var t,n,a=e,i=1/0;for(;a;)a._call?(i>a._time&&(i=a._time),t=a,a=a._next):(n=a._next,a._next=null,a=t?t._next=n:e=n);r=t,x(i)}(),l=0}}function y(){var t=u.now(),e=t-s;e>o&&(c-=e,s=t)}function x(t){n||(a&&(a=clearTimeout(a)),t-l>24?(t<1/0&&(a=setTimeout(m,t-u.now()-c)),i&&(i=clearInterval(i))):(i||(s=u.now(),i=setInterval(y,o)),n=1,h(m)))}d.prototype=g.prototype={constructor:d,restart:function(t,n,a){if("function"!=typeof t)throw new TypeError("callback is not a function");a=(null==a?f():+a)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=a,x()},stop:function(){this._call&&(this._call=null,this._time=1/0,x())}};t.now=f,t.timer=g,t.timerFlush=v,t.timeout=function(t,e,r){var n=new d;return e=null==e?0:+e,n.restart(function(r){n.stop(),t(r+e)},e,r),n},t.interval=function(t,e,r){var n=new d,a=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart(function i(o){o+=a,n.restart(i,a+=e,r),t(o)},e,r),n)},Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.d3=n.d3||{})},{}],164:[function(t,e,r){!function(){var t={version:"3.5.17"},r=[].slice,n=function(t){return r.call(t)},a=this.document;function i(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(a)try{n(a.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),a)try{a.createElement("DIV").style.setProperty("opacity",0,"")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,h=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+"")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+"")},u.setProperty=function(t,e,r){h.call(this,t,e+"",r)}}function f(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,a){for(arguments.length<3&&(n=0),arguments.length<4&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)<0?n=i+1:a=i}return n},right:function(e,r,n,a){for(arguments.length<3&&(n=0),arguments.length<4&&(a=e.length);n<a;){var i=n+a>>>1;t(e[i],r)>0?a=i:n=i+1}return n}}}t.ascending=f,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,a=-1,i=t.length;if(1===arguments.length){for(;++a<i;)if(null!=(n=t[a])&&n>=n){r=n;break}for(;++a<i;)null!=(n=t[a])&&r>n&&(r=n)}else{for(;++a<i;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=n;break}for(;++a<i;)null!=(n=e.call(t,t[a],a))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,a=-1,i=t.length;if(1===arguments.length){for(;++a<i;)if(null!=(n=t[a])&&n>=n){r=n;break}for(;++a<i;)null!=(n=t[a])&&n>r&&(r=n)}else{for(;++a<i;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=n;break}for(;++a<i;)null!=(n=e.call(t,t[a],a))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,a,i=-1,o=t.length;if(1===arguments.length){for(;++i<o;)if(null!=(n=t[i])&&n>=n){r=a=n;break}for(;++i<o;)null!=(n=t[i])&&(r>n&&(r=n),a<n&&(a=n))}else{for(;++i<o;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=a=n;break}for(;++i<o;)null!=(n=e.call(t,t[i],i))&&(r>n&&(r=n),a<n&&(a=n))}return[r,a]},t.sum=function(t,e){var r,n=0,a=t.length,i=-1;if(1===arguments.length)for(;++i<a;)d(r=+t[i])&&(n+=r);else for(;++i<a;)d(r=+e.call(t,t[i],i))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,a=t.length,i=-1,o=a;if(1===arguments.length)for(;++i<a;)d(r=p(t[i]))?n+=r:--o;else for(;++i<a;)d(r=p(e.call(t,t[i],i)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),a=+t[n-1],i=r-n;return i?a+i*(t[n]-a):a},t.median=function(e,r){var n,a=[],i=e.length,o=-1;if(1===arguments.length)for(;++o<i;)d(n=p(e[o]))&&a.push(n);else for(;++o<i;)d(n=p(r.call(e,e[o],o)))&&a.push(n);if(a.length)return t.quantile(a.sort(f),.5)},t.variance=function(t,e){var r,n,a=t.length,i=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<a;)d(r=p(t[s]))&&(o+=(n=r-i)*(r-(i+=n/++l)));else for(;++s<a;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-i)*(r-(i+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var v=g(f);function m(t){return t.length}t.bisectLeft=v.left,t.bisect=t.bisectRight=v.right,t.bisector=function(t){return g(1===t.length?function(e,r){return f(t(e),r)}:t)},t.shuffle=function(t,e,r){(i=arguments.length)<3&&(r=t.length,i<2&&(e=0));for(var n,a,i=r-e;i;)a=Math.random()*i--|0,n=t[i+e],t[i+e]=t[a+e],t[a+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],a=new Array(r<0?0:r);e<r;)a[e]=[n,n=t[++e]];return a},t.transpose=function(e){if(!(i=e.length))return[];for(var r=-1,n=t.min(e,m),a=new Array(n);++r<n;)for(var i,o=-1,s=a[r]=new Array(i);++o<i;)s[o]=e[o][r];return a},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,a=t.length,i=-1,o=0;++i<a;)o+=t[i].length;for(r=new Array(o);--a>=0;)for(e=(n=t[a]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function b(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error("infinite range");var n,a=[],i=function(t){var e=1;for(;t*e%1;)e*=10;return e}(y(r)),o=-1;if(t*=i,e*=i,(r*=i)<0)for(;(n=t+r*++o)>e;)a.push(n/i);else for(;(n=t+r*++o)<e;)a.push(n/i);return a},t.map=function(t,e){var r=new b;if(t instanceof b)t.forEach(function(t,e){r.set(t,e)});else if(Array.isArray(t)){var n,a=-1,i=t.length;if(1===arguments.length)for(;++a<i;)r.set(a,t[a]);else for(;++a<i;)r.set(e.call(t,n=t[a],a),n)}else for(var o in t)r.set(o,t[o]);return r};var _="__proto__",w="\0";function k(t){return(t+="")===_||t[0]===w?w+t:t}function T(t){return(t+="")[0]===w?t.slice(1):t}function A(t){return k(t)in this._}function M(t){return(t=k(t))in this._&&delete this._[t]}function S(){var t=[];for(var e in this._)t.push(T(e));return t}function E(){var t=0;for(var e in this._)++t;return t}function L(){for(var t in this._)return!1;return!0}function C(){this._=Object.create(null)}function P(t){return t}function O(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function z(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=I.length;r<n;++r){var a=I[r]+e;if(a in t)return a}}x(b,{has:A,get:function(t){return this._[k(t)]},set:function(t,e){return this._[k(t)]=e},remove:M,keys:S,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:E,empty:L,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},a=[],i=[];function o(t,i,s){if(s>=a.length)return r?r.call(n,i):e?i.sort(e):i;for(var l,c,u,h,f=-1,p=i.length,d=a[s++],g=new b;++f<p;)(h=g.get(l=d(c=i[f])))?h.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=a.length)return e;var n=[],o=i[r++];return e.forEach(function(e,a){n.push({key:e,values:t(a,r)})}),o?n.sort(function(t,e){return o(t.key,e.key)}):n}(o(t.map,e,0),0)},n.key=function(t){return a.push(t),n},n.sortKeys=function(t){return i[a.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new C;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},x(C,{has:A,add:function(t){return this._[k(t+="")]=!0,t},remove:M,values:S,size:E,empty:L,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,a=arguments.length;++n<a;)t[r=arguments[n]]=O(t,e,e[r]);return t};var I=["webkit","ms","moz","Moz","o","O"];function D(){}function R(){}function F(t){var e=[],r=new b;function n(){for(var r,n=e,a=-1,i=n.length;++a<i;)(r=n[a].on)&&r.apply(this,arguments);return t}return n.on=function(n,a){var i,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,i=e.indexOf(o)).concat(e.slice(i+1)),r.remove(n)),a&&e.push(r.set(n,{on:a})),t)},n}function B(){t.event.preventDefault()}function N(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function j(e){for(var r=new R,n=0,a=arguments.length;++n<a;)r[arguments[n]]=F(r);return r.of=function(n,a){return function(i){try{var o=i.sourceEvent=t.event;i.target=e,t.event=i,r[i.type].apply(n,a)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new R,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=F(t);return t},R.prototype.on=function(t,e){var r=t.indexOf("."),n="";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(V,"\\$&")};var V=/[\\\^\$\*\+\?\|\[\]\(\)\.\{\}]/g,U={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function q(t){return U(t,W),t}var H=function(t,e){return e.querySelector(t)},G=function(t,e){return e.querySelectorAll(t)},Y=function(t,e){var r=t.matches||t[z(t,"matchesSelector")];return(Y=function(t,e){return r.call(t,e)})(t,e)};"function"==typeof Sizzle&&(H=function(t,e){return Sizzle(t,e)[0]||null},G=Sizzle,Y=Sizzle.matchesSelector),t.selection=function(){return t.select(a.documentElement)};var W=t.selection.prototype=[];function X(t){return"function"==typeof t?t:function(){return H(t,this)}}function Z(t){return"function"==typeof t?t:function(){return G(t,this)}}W.select=function(t){var e,r,n,a,i=[];t=X(t);for(var o=-1,s=this.length;++o<s;){i.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(a=n[l])?(e.push(r=t.call(a,a.__data__,l,o)),r&&"__data__"in a&&(r.__data__=a.__data__)):e.push(null)}return q(i)},W.selectAll=function(t){var e,r,a=[];t=Z(t);for(var i=-1,o=this.length;++i<o;)for(var s=this[i],l=-1,c=s.length;++l<c;)(r=s[l])&&(a.push(e=n(t.call(r,r.__data__,l,i))),e.parentNode=r);return q(a)};var J="http://www.w3.org/1999/xhtml",K={svg:"http://www.w3.org/2000/svg",xhtml:J,xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"};function Q(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:"function"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function $(t){return t.trim().replace(/\s+/g," ")}function tt(e){return new RegExp("(?:^|\\s+)"+t.requote(e)+"(?:\\s+|$)","g")}function et(t){return(t+"").trim().split(/^|\s+/)}function rt(t,e){var r=(t=et(t).map(nt)).length;return"function"==typeof e?function(){for(var n=-1,a=e.apply(this,arguments);++n<r;)t[n](this,a)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function nt(t){var e=tt(t);return function(r,n){if(a=r.classList)return n?a.add(t):a.remove(t);var a=r.getAttribute("class")||"";n?(e.lastIndex=0,e.test(a)||r.setAttribute("class",$(a+" "+t))):r.setAttribute("class",$(a.replace(e," ")))}}function at(t,e,r){return null==e?function(){this.style.removeProperty(t)}:"function"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function it(t,e){return null==e?function(){delete this[t]}:"function"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ot(e){return"function"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===J&&t.documentElement.namespaceURI===J?t.createElement(e):t.createElementNS(r,e)}}function st(){var t=this.parentNode;t&&t.removeChild(this)}function lt(t){return{__data__:t}}function ct(t){return function(){return Y(this,t)}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var a,i=t[r],o=0,s=i.length;o<s;o++)(a=i[o])&&e(a,o,r);return t}function ht(t){return U(t,ft),t}t.ns={prefix:K,qualify:function(t){var e=t.indexOf(":"),r=t;return e>=0&&"xmlns"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),K.hasOwnProperty(r)?{space:K[r],local:t}:t}},W.attr=function(e,r){if(arguments.length<2){if("string"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each(Q(r,e[r]));return this}return this.each(Q(e,r))},W.classed=function(t,e){if(arguments.length<2){if("string"==typeof t){var r=this.node(),n=(t=et(t)).length,a=-1;if(e=r.classList){for(;++a<n;)if(!e.contains(t[a]))return!1}else for(e=r.getAttribute("class");++a<n;)if(!tt(t[a]).test(e))return!1;return!0}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},W.style=function(t,e,r){var n=arguments.length;if(n<3){if("string"!=typeof t){for(r in n<2&&(e=""),t)this.each(at(r,t[r],e));return this}if(n<2){var a=this.node();return o(a).getComputedStyle(a,null).getPropertyValue(t)}r=""}return this.each(at(t,e,r))},W.property=function(t,e){if(arguments.length<2){if("string"==typeof t)return this.node()[t];for(e in t)this.each(it(e,t[e]));return this}return this.each(it(t,e))},W.text=function(t){return arguments.length?this.each("function"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?"":e}:null==t?function(){this.textContent=""}:function(){this.textContent=t}):this.node().textContent},W.html=function(t){return arguments.length?this.each("function"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?"":e}:null==t?function(){this.innerHTML=""}:function(){this.innerHTML=t}):this.node().innerHTML},W.append=function(t){return t=ot(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},W.insert=function(t,e){return t=ot(t),e=X(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},W.remove=function(){return this.each(st)},W.data=function(t,e){var r,n,a=-1,i=this.length;if(!arguments.length){for(t=new Array(i=(r=this[0]).length);++a<i;)(n=r[a])&&(t[a]=n.__data__);return t}function o(t,r){var n,a,i,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,v=new b,m=new Array(o);for(n=-1;++n<o;)(a=t[n])&&(v.has(g=e.call(a,a.__data__,n))?d[n]=a:v.set(g,a),m[n]=g);for(n=-1;++n<u;)(a=v.get(g=e.call(r,i=r[n],n)))?!0!==a&&(f[n]=a,a.__data__=i):p[n]=lt(i),v.set(g,!0);for(n=-1;++n<o;)n in m&&!0!==v.get(m[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)a=t[n],i=r[n],a?(a.__data__=i,f[n]=a):p[n]=lt(i);for(;n<u;++n)p[n]=lt(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=ht([]),l=q([]),c=q([]);if("function"==typeof t)for(;++a<i;)o(r=this[a],t.call(r,r.parentNode.__data__,a));else for(;++a<i;)o(r=this[a],t);return l.enter=function(){return s},l.exit=function(){return c},l},W.datum=function(t){return arguments.length?this.property("__data__",t):this.property("__data__")},W.filter=function(t){var e,r,n,a=[];"function"!=typeof t&&(t=ct(t));for(var i=0,o=this.length;i<o;i++){a.push(e=[]),e.parentNode=(r=this[i]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,i)&&e.push(n)}return q(a)},W.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],a=n.length-1,i=n[a];--a>=0;)(r=n[a])&&(i&&i!==r.nextSibling&&i.parentNode.insertBefore(r,i),i=r);return this},W.sort=function(t){t=function(t){arguments.length||(t=f);return function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},W.each=function(t){return ut(this,function(e,r,n){t.call(e,e.__data__,r,n)})},W.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},W.empty=function(){return!this.node()},W.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,a=r.length;n<a;n++){var i=r[n];if(i)return i}return null},W.size=function(){var t=0;return ut(this,function(){++t}),t};var ft=[];function pt(e,r,a){var i="__on"+e,o=e.indexOf("."),s=gt;o>0&&(e=e.slice(0,o));var l=dt.get(e);function c(){var t=this[i];t&&(this.removeEventListener(e,t,t.$),delete this[i])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[i]=t,t.$=a),t._=r}:c:r?D:function(){var r,n=new RegExp("^__on([^.]+)"+t.requote(e)+"$");for(var a in this)if(r=a.match(n)){var i=this[a];this.removeEventListener(r[1],i,i.$),delete this[a]}}}t.selection.enter=ht,t.selection.enter.prototype=ft,ft.append=W.append,ft.empty=W.empty,ft.node=W.node,ft.call=W.call,ft.size=W.size,ft.select=function(t){for(var e,r,n,a,i,o=[],s=-1,l=this.length;++s<l;){n=(a=this[s]).update,o.push(e=[]),e.parentNode=a.parentNode;for(var c=-1,u=a.length;++c<u;)(i=a[c])?(e.push(n[c]=r=t.call(a.parentNode,i.__data__,c,s)),r.__data__=i.__data__):e.push(null)}return q(o)},ft.insert=function(t,e){var r,n,a;return arguments.length<2&&(r=this,e=function(t,e,i){var o,s=r[i].update,l=s.length;for(i!=a&&(a=i,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),W.insert.call(this,t,e)},t.select=function(t){var e;return"string"==typeof t?(e=[H(t,a)]).parentNode=a.documentElement:(e=[t]).parentNode=i(t),q([e])},t.selectAll=function(t){var e;return"string"==typeof t?(e=n(G(t,a))).parentNode=a.documentElement:(e=n(t)).parentNode=null,q([e])},W.on=function(t,e,r){var n=arguments.length;if(n<3){if("string"!=typeof t){for(r in n<2&&(e=!1),t)this.each(pt(r,t[r],e));return this}if(n<2)return(n=this.node()["__on"+t])&&n._;r=!1}return this.each(pt(t,e,r))};var dt=t.map({mouseenter:"mouseover",mouseleave:"mouseout"});function gt(e,r){return function(n){var a=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=a}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}a&&dt.forEach(function(t){"on"+t in a&&dt.remove(t)});var mt,yt=0;function xt(e){var r=".dragsuppress-"+ ++yt,n="click"+r,a=t.select(o(e)).on("touchmove"+r,B).on("dragstart"+r,B).on("selectstart"+r,B);if(null==mt&&(mt=!("onselectstart"in e)&&z(e.style,"userSelect")),mt){var s=i(e).style,l=s[mt];s[mt]="none"}return function(t){if(a.on(r,null),mt&&(s[mt]=l),t){var e=function(){a.on(n,null)};a.on(n,function(){B(),e()},!0),setTimeout(e,0)}}}t.mouse=function(t){return _t(t,N())};var bt=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function _t(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var a=n.createSVGPoint();if(bt<0){var i=o(e);if(i.scrollX||i.scrollY){var s=(n=t.select("body").append("svg").style({position:"absolute",top:0,left:0,margin:0,padding:0,border:"none"},"important"))[0][0].getScreenCTM();bt=!(s.f||s.e),n.remove()}}return bt?(a.x=r.pageX,a.y=r.pageY):(a.x=r.clientX,a.y=r.clientY),[(a=a.matrixTransform(e.getScreenCTM().inverse())).x,a.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function wt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=N().changedTouches),e)for(var n,a=0,i=e.length;a<i;++a)if((n=e[a]).identifier===r)return _t(t,n)},t.behavior.drag=function(){var e=j(i,"drag","dragstart","dragend"),r=null,n=s(D,t.mouse,o,"mousemove","mouseup"),a=s(wt,t.touch,P,"touchmove","touchend");function i(){this.on("mousedown.drag",n).on("touchstart.drag",a)}function s(n,a,i,o,s){return function(){var l,c=t.event.target.correspondingElement||t.event.target,u=this.parentNode,h=e.of(this,arguments),f=0,p=n(),d=".drag"+(null==p?"":"-"+p),g=t.select(i(c)).on(o+d,function(){var t,e,r=a(u,p);if(!r)return;t=r[0]-m[0],e=r[1]-m[1],f|=t|e,m=r,h({type:"drag",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e})}).on(s+d,function(){if(!a(u,p))return;g.on(o+d,null).on(s+d,null),v(f),h({type:"dragend"})}),v=xt(c),m=a(u,p);l=r?[(l=r.apply(this,arguments)).x-m[0],l.y-m[1]]:[0,0],h({type:"dragstart"})}}return i.origin=function(t){return arguments.length?(r=t,i):r},t.rebind(i,e,"on")},t.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?n(e).map(function(e){var r=_t(t,e);return r.identifier=e.identifier,r}):[]};var kt=1e-6,Tt=kt*kt,At=Math.PI,Mt=2*At,St=Mt-kt,Et=At/2,Lt=At/180,Ct=180/At;function Pt(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function zt(t){return t>1?0:t<-1?At:Math.acos(t)}function It(t){return t>1?Et:t<-1?-Et:Math.asin(t)}function Dt(t){return((t=Math.exp(t))+1/t)/2}function Rt(t){return(t=Math.sin(t/2))*t}var Ft=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,a=t[0],i=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-a,h=l-i,f=u*u+h*h;if(f<Tt)n=Math.log(c/o)/Ft,r=function(t){return[a+t*u,i+t*h,o*Math.exp(Ft*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/Ft,r=function(t){var e,r=t*n,s=Dt(v),l=o/(2*p)*(s*(e=Ft*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[a+l*u,i+l*h,o*s/Dt(Ft*r+v)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,i,s,l,c,u,h,f={x:0,y:0,k:1},p=[960,500],d=jt,g=250,v=0,m="mousedown.zoom",y="mousemove.zoom",x="mouseup.zoom",b="touchstart.zoom",_=j(w,"zoomstart","zoom","zoomend");function w(t){t.on(m,P).on(Nt+".zoom",z).on("dblclick.zoom",I).on(b,O)}function k(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function T(t){f.k=Math.max(d[0],Math.min(d[1],t))}function A(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function M(e,n,a,i){e.__chart__={x:f.x,y:f.y,k:f.k},T(Math.pow(2,i)),A(r=n,a),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map(function(t){return(t-f.x)/f.k}).map(l.invert)),h&&h.domain(u.range().map(function(t){return(t-f.y)/f.k}).map(u.invert))}function E(t){v++||t({type:"zoomstart"})}function L(t){S(),t({type:"zoom",scale:f.k,translate:[f.x,f.y]})}function C(t){--v||(t({type:"zoomend"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,a=t.select(o(e)).on(y,function(){n=1,A(t.mouse(e),i),L(r)}).on(x,function(){a.on(y,null).on(x,null),s(n),C(r)}),i=k(t.mouse(e)),s=xt(e);hs.call(e),E(r)}function O(){var e,r=this,n=_.of(r,arguments),a={},i=0,o=".zoom-"+t.event.changedTouches[0].identifier,l="touchmove"+o,c="touchend"+o,u=[],h=t.select(r),p=xt(r);function d(){var n=t.touches(r);return e=f.k,n.forEach(function(t){t.identifier in a&&(a[t.identifier]=k(t))}),n}function g(){var e=t.event.target;t.select(e).on(l,v).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,h=n.length;o<h;++o)a[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var m=p[0];M(r,m,a[m.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),B()}s=g}else if(p.length>1){m=p[0];var x=p[1],b=m[0]-x[0],_=m[1]-x[1];i=b*b+_*_}}function v(){var o,l,c,u,h=t.touches(r);hs.call(r);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=a[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=i&&Math.sqrt(d/i);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],T(g*e)}s=null,A(o,l),L(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,i=e.length;r<i;++r)delete a[e[r].identifier];for(var s in a)return void d()}t.selectAll(u).on(o,null),h.on(m,P).on(b,O),p(),C(n)}g(),E(n),h.on(m,null).on(b,g)}function z(){var a=_.of(this,arguments);i?clearTimeout(i):(hs.call(this),e=k(r=n||t.mouse(this)),E(a)),i=setTimeout(function(){i=null,C(a)},50),B(),T(Math.pow(2,.002*Bt())*f.k),A(r,e),L(a)}function I(){var e=t.mouse(this),r=Math.log(f.k)/Math.LN2;M(this,e,k(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return Nt||(Nt="onwheel"in a?(Bt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},"wheel"):"onmousewheel"in a?(Bt=function(){return t.event.wheelDelta},"mousewheel"):(Bt=function(){return-t.event.detail},"MozMousePixelScroll")),w.event=function(e){e.each(function(){var e=_.of(this,arguments),n=f;ds?t.select(this).transition().each("start.zoom",function(){f=this.__chart__||{x:0,y:0,k:1},E(e)}).tween("zoom:zoom",function(){var a=p[0],i=p[1],o=r?r[0]:a/2,s=r?r[1]:i/2,l=t.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,a/f.k],[(o-n.x)/n.k,(s-n.y)/n.k,a/n.k]);return function(t){var r=l(t),n=a/r[2];this.__chart__=f={x:o-r[0]*n,y:s-r[1]*n,k:n},L(e)}}).each("interrupt.zoom",function(){C(e)}).each("end.zoom",function(){C(e)}):(this.__chart__=f,E(e),L(e),C(e))})},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},T(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?jt:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),f={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(h=t,u=t.copy(),f={x:0,y:0,k:1},w):h},t.rebind(w,_,"on")};var Bt,Nt,jt=[0,1/0];function Vt(){}function Ut(t,e,r){return this instanceof Ut?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof Ut?new Ut(t.h,t.s,t.l):ue(""+t,he,Ut):new Ut(t,e,r)}t.color=Vt,Vt.prototype.toString=function(){return this.rgb()+""},t.hsl=Ut;var qt=Ut.prototype=new Vt;function Ht(t,e,r){var n,a;function i(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(a-n)*t/60:t<180?a:t<240?n+(a-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(a=r<=.5?r*(1+e):r+e-r*e),new ie(i(t+120),i(t),i(t-120))}function Gt(e,r,n){return this instanceof Gt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Gt?new Gt(e.h,e.c,e.l):ee(e instanceof Xt?e.l:(e=fe((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Gt(e,r,n)}qt.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new Ut(this.h,this.s,this.l/t)},qt.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Ut(this.h,this.s,t*this.l)},qt.rgb=function(){return Ht(this.h,this.s,this.l)},t.hcl=Gt;var Yt=Gt.prototype=new Vt;function Wt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Lt)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Gt?Wt(t.h,t.c,t.l):fe((t=ie(t)).r,t.g,t.b):new Xt(t,e,r)}Yt.brighter=function(t){return new Gt(this.h,this.c,Math.min(100,this.l+Zt*(arguments.length?t:1)))},Yt.darker=function(t){return new Gt(this.h,this.c,Math.max(0,this.l-Zt*(arguments.length?t:1)))},Yt.rgb=function(){return Wt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Zt=18,Jt=.95047,Kt=1,Qt=1.08883,$t=Xt.prototype=new Vt;function te(t,e,r){var n=(t+16)/116,a=n+e/500,i=n-r/200;return new ie(ae(3.2404542*(a=re(a)*Jt)-1.5371385*(n=re(n)*Kt)-.4985314*(i=re(i)*Qt)),ae(-.969266*a+1.8760108*n+.041556*i),ae(.0556434*a-.2040259*n+1.0572252*i))}function ee(t,e,r){return t>0?new Gt(Math.atan2(r,e)*Ct,Math.sqrt(e*e+r*r),t):new Gt(NaN,NaN,t)}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ae(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ie(t,e,r){return this instanceof ie?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ie?new ie(t.r,t.g,t.b):ue(""+t,ie,Ht):new ie(t,e,r)}function oe(t){return new ie(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+""}$t.brighter=function(t){return new Xt(Math.min(100,this.l+Zt*(arguments.length?t:1)),this.a,this.b)},$t.darker=function(t){return new Xt(Math.max(0,this.l-Zt*(arguments.length?t:1)),this.a,this.b)},$t.rgb=function(){return te(this.l,this.a,this.b)},t.rgb=ie;var le=ie.prototype=new Vt;function ce(t){return t<16?"0"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,a,i,o=0,s=0,l=0;if(n=/([a-z]+)\((.*)\)/.exec(t=t.toLowerCase()))switch(a=n[2].split(","),n[1]){case"hsl":return r(parseFloat(a[0]),parseFloat(a[1])/100,parseFloat(a[2])/100);case"rgb":return e(de(a[0]),de(a[1]),de(a[2]))}return(i=ge.get(t))?e(i.r,i.g,i.b):(null==t||"#"!==t.charAt(0)||isNaN(i=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&i)>>4,o|=o>>4,s=240&i,s|=s>>4,l=15&i,l|=l<<4):7===t.length&&(o=(16711680&i)>>16,s=(65280&i)>>8,l=255&i)),e(o,s,l))}function he(t,e,r){var n,a,i=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-i,l=(o+i)/2;return s?(a=l<.5?s/(o+i):s/(2-o-i),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,a=l>0&&l<1?0:n),new Ut(n,a,l)}function fe(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/Jt),a=ne((.2126729*t+.7151522*e+.072175*r)/Kt);return Xt(116*a-16,500*(n-a),200*(a-ne((.0193339*t+.119192*e+.9503041*r)/Qt)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return"%"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,a=30;return e||r||n?(e&&e<a&&(e=a),r&&r<a&&(r=a),n&&n<a&&(n=a),new ie(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ie(a,a,a)},le.darker=function(t){return new ie((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return he(this.r,this.g,this.b)},le.toString=function(){return"#"+ce(this.r)+ce(this.g)+ce(this.b)};var ge=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ve(t){return"function"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&"function"==typeof r&&(n=r,r=null),ye(e,r,t,n)}}function ye(e,r,a,i){var o={},s=t.dispatch("beforesend","progress","load","error"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&"text"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=a.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return!this.XDomainRequest||"withCredentials"in c||!/^(http(s)?:)?\/\//.test(e)||(c=new XDomainRequest),"onload"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+"").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+"",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+"",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return a=t,o},["get","post"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}}),o.send=function(t,n,a){if(2===arguments.length&&"function"==typeof n&&(a=n,n=null),c.open(t,e,!0),null==r||"accept"in l||(l.accept=r+",*/*"),c.setRequestHeader)for(var i in l)c.setRequestHeader(i,l[i]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=a&&o.on("error",a).on("load",function(t){a(null,t)}),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,"on"),null==i?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(i))}ge.forEach(function(t,e){ge.set(t,oe(e))}),t.functor=ve,t.xhr=me(P),t.dsv=function(t,e){var r=new RegExp('["'+t+"\n]"),n=t.charCodeAt(0);function a(t,r,n){arguments.length<3&&(n=r,r=null);var a=ye(t,e,null==r?i:o(r),n);return a.row=function(t){return arguments.length?a.response(null==(r=t)?i:o(t)):r},a}function i(t){return a.parse(t.responseText)}function o(t){return function(e){return a.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'"'+t.replace(/\"/g,'""')+'"':t}return a.parse=function(t,e){var r;return a.parseRows(t,function(t,n){if(r)return r(t,n-1);var a=new Function("d","return {"+t.map(function(t,e){return JSON.stringify(t)+": d["+e+"]"}).join(",")+"}");r=e?function(t,r){return e(a(t),r)}:a})},a.parseRows=function(t,e){var r,a,i={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(a)return a=!1,i;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(a=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(a=!0),t.slice(e+1,r).replace(/""/g,'"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))a=!0;else if(13===s)a=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==i&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},a.format=function(e){if(Array.isArray(e[0]))return a.formatRows(e);var r=new C,n=[];return e.forEach(function(t){for(var e in t)r.has(e)||n.push(r.add(e))}),[n.map(l).join(t)].concat(e.map(function(e){return n.map(function(t){return l(e[t])}).join(t)})).join("\n")},a.formatRows=function(t){return t.map(s).join("\n")},a},t.csv=t.dsv(",","text/csv"),t.tsv=t.dsv("\t","text/tab-separated-values");var xe,be,_e,we,ke=this[z(this,"requestAnimationFrame")]||function(t){setTimeout(t,17)};function Te(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var a={c:t,t:r+e,n:null};return be?be.n=a:xe=a,be=a,_e||(we=clearTimeout(we),_e=1,ke(Ae)),a}function Ae(){var t=Me(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Ae,e)),_e=0):(_e=1,ke(Ae))}function Me(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return be=t,r}function Ee(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){Te.apply(this,arguments)},t.timer.flush=function(){Me(),Se()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Le=["y","z","a","f","p","n","\xb5","m","","k","M","G","T","P","E","Z","Y"].map(function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}});t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ee(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Le[8+n/3]};var Ce=/(?:([^{])?([<>=^]))?([+\- ])?([$#])?(0)?(\d+)?(,)?(\.-?\d+)?([a-z%])?/i,Pe=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ee(e,r))).toFixed(Math.max(0,Math.min(20,Ee(e*(1+1e-15),r))))}});function Oe(t){return t+""}var ze=t.time={},Ie=Date;function De(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}De.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){Re.setUTCDate.apply(this._,arguments)},setDay:function(){Re.setUTCDay.apply(this._,arguments)},setFullYear:function(){Re.setUTCFullYear.apply(this._,arguments)},setHours:function(){Re.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){Re.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){Re.setUTCMinutes.apply(this._,arguments)},setMonth:function(){Re.setUTCMonth.apply(this._,arguments)},setSeconds:function(){Re.setUTCSeconds.apply(this._,arguments)},setTime:function(){Re.setTime.apply(this._,arguments)}};var Re=Date.prototype;function Fe(t,e,r){function n(e){var r=t(e),n=i(r,1);return e-r<n-e?r:n}function a(r){return e(r=t(new Ie(r-1)),1),r}function i(t,r){return e(t=new Ie(+t),r),t}function o(t,n,i){var o=a(t),s=[];if(i>1)for(;o<n;)r(o)%i||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=a,t.offset=i,t.range=o;var s=t.utc=Be(t);return s.floor=s,s.round=Be(n),s.ceil=Be(a),s.offset=Be(i),s.range=function(t,e,r){try{Ie=De;var n=new De;return n._=t,o(n,e,r)}finally{Ie=Date}},t}function Be(t){return function(e,r){try{Ie=De;var n=new De;return n._=e,t(n,r)._}finally{Ie=Date}}}ze.year=Fe(function(t){return(t=ze.day(t)).setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ze.years=ze.year.range,ze.years.utc=ze.year.utc.range,ze.day=Fe(function(t){var e=new Ie(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ze.days=ze.day.range,ze.days.utc=ze.day.utc.range,ze.dayOfYear=function(t){var e=ze.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},["sunday","monday","tuesday","wednesday","thursday","friday","saturday"].forEach(function(t,e){e=7-e;var r=ze[t]=Fe(function(t){return(t=ze.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)-(r!==e)});ze[t+"s"]=r.range,ze[t+"s"].utc=r.utc.range,ze[t+"OfYear"]=function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)}}),ze.week=ze.sunday,ze.weeks=ze.sunday.range,ze.weeks.utc=ze.sunday.utc.range,ze.weekOfYear=ze.sundayOfYear;var Ne={"-":"",_:" ",0:"0"},je=/^\s*\d+/,Ve=/^%/;function Ue(t,e,r){var n=t<0?"-":"",a=(n?-t:t)+"",i=a.length;return n+(i<r?new Array(r-i+1).join(e)+a:a)}function qe(e){return new RegExp("^(?:"+e.map(t.requote).join("|")+")","i")}function He(t){for(var e=new b,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,a=je.exec(e.slice(r,r+2));return a?(t.y=(n=+a[0])+(n>68?1900:2e3),r+a[0].length):-1}function Je(t,e,r){return/^[+-]\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ar(t){var e=t.getTimezoneOffset(),r=e>0?"-":"+",n=y(e)/60|0,a=y(e)%60;return r+Ue(n,"0",2)+Ue(a,"0",2)}function ir(t,e,r){Ve.lastIndex=0;var n=Ve.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(e){return{numberFormat:function(e){var r=e.decimal,n=e.thousands,a=e.grouping,i=e.currency,o=a&&n?function(t,e){for(var r=t.length,i=[],o=0,s=a[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),i.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=a[o=(o+1)%a.length];return i.reverse().join(n)}:P;return function(e){var n=Ce.exec(e),a=n[1]||" ",s=n[2]||">",l=n[3]||"-",c=n[4]||"",u=n[5],h=+n[6],f=n[7],p=n[8],d=n[9],g=1,v="",m="",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||"0"===a&&"="===s)&&(u=a="0",s="="),d){case"n":f=!0,d="g";break;case"%":g=100,m="%",d="f";break;case"p":g=100,m="%",d="r";break;case"b":case"o":case"x":case"X":"#"===c&&(v="0"+d.toLowerCase());case"c":x=!1;case"d":y=!0,p=0;break;case"s":g=-1,d="r"}"$"===c&&(v=i[0],m=i[1]),"r"!=d||p||(d="g"),null!=p&&("g"==d?p=Math.max(1,Math.min(21,p)):"e"!=d&&"f"!=d||(p=Math.max(0,Math.min(20,p)))),d=Pe.get(d)||Oe;var b=u&&f;return function(e){var n=m;if(y&&e%1)return"";var i=e<0||0===e&&1/e<0?(e=-e,"-"):"-"===l?"":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+m}else e*=g;var _,w,k=(e=d(e,p)).lastIndexOf(".");if(k<0){var T=x?e.lastIndexOf("e"):-1;T<0?(_=e,w=""):(_=e.substring(0,T),w=e.substring(T))}else _=e.substring(0,k),w=r+e.substring(k+1);!u&&f&&(_=o(_,1/0));var A=v.length+_.length+w.length+(b?0:i.length),M=A<h?new Array(A=h-A+1).join(a):"";return b&&(_=o(M+_,M.length?h-w.length:1/0)),i+=v,e=_+w,("<"===s?i+e+M:">"===s?M+i+e:"^"===s?M.substring(0,A>>=1)+i+e+M.substring(A):i+(b?e:M+e))+n}}}(e),timeFormat:function(e){var r=e.dateTime,n=e.date,a=e.time,i=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,a,i,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(a=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(i=_[n])&&(n=i(r,null==a?"e"===n?" ":"0":a)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join("")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(h(r,t,e,0)!=e.length)return null;"p"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&Ie!==De,a=new(n?De:Ie);return"j"in r?a.setFullYear(r.y,0,r.j):"W"in r||"U"in r?("w"in r||(r.w="W"in r?1:0),a.setFullYear(r.y,0,1),a.setFullYear(r.y,0,"W"in r?(r.w+6)%7+7*r.W-(a.getDay()+5)%7:r.w+7*r.U-(a.getDay()+6)%7)):a.setFullYear(r.y,r.m,r.d),a.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?a._:a},r.toString=function(){return t},r}function h(t,e,r,n){for(var a,i,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(a=e.charCodeAt(s++))){if(o=e.charAt(s++),!(i=w[o in Ne?e.charAt(s++):o])||(n=i(t,r,n))<0)return-1}else if(a!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(Ie=De);return r._=t,e(r)}finally{Ie=Date}}return r.parse=function(t){try{Ie=De;var r=e.parse(t);return r&&r._}finally{Ie=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var f=t.map(),p=qe(o),d=He(o),g=qe(s),v=He(s),m=qe(l),y=He(l),x=qe(c),b=He(c);i.forEach(function(t,e){f.set(t.toLowerCase(),e)});var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ue(t.getDate(),e,2)},e:function(t,e){return Ue(t.getDate(),e,2)},H:function(t,e){return Ue(t.getHours(),e,2)},I:function(t,e){return Ue(t.getHours()%12||12,e,2)},j:function(t,e){return Ue(1+ze.dayOfYear(t),e,3)},L:function(t,e){return Ue(t.getMilliseconds(),e,3)},m:function(t,e){return Ue(t.getMonth()+1,e,2)},M:function(t,e){return Ue(t.getMinutes(),e,2)},p:function(t){return i[+(t.getHours()>=12)]},S:function(t,e){return Ue(t.getSeconds(),e,2)},U:function(t,e){return Ue(ze.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ue(ze.mondayOfYear(t),e,2)},x:u(n),X:u(a),y:function(t,e){return Ue(t.getFullYear()%100,e,2)},Y:function(t,e){return Ue(t.getFullYear()%1e4,e,4)},Z:ar,"%":function(){return"%"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=v.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return h(t,_.c.toString(),e,r)},d:Qe,e:Qe,H:tr,I:tr,j:$e,L:nr,m:Ke,M:er,p:function(t,e,r){var n=f.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return h(t,_.x.toString(),e,r)},X:function(t,e,r){return h(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,"%":ir};return u}(e)}};var sr=t.locale({decimal:".",thousands:",",grouping:[3],currency:["$",""],dateTime:"%a %b %e %X %Y",date:"%m/%d/%Y",time:"%H:%M:%S",periods:["AM","PM"],days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],shortDays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],months:["January","February","March","April","May","June","July","August","September","October","November","December"],shortMonths:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,a=n-t,i=n-a;r.t=t-i+(e-a)}function hr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&fr.hasOwnProperty(t.type)?fr[t.type](t,e):hr(t,e)};var fr={Feature:function(t,e){hr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,a=r.length;++n<a;)hr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,a=r.length;++n<a;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,a=r.length;++n<a;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,a=r.length;++n<a;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,a=r.length;++n<a;)hr(r[n],e)}};function dr(t,e,r){var n,a=-1,i=t.length-r;for(e.lineStart();++a<i;)n=t[a],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return vr=0,t.geo.stream(e,Lr),vr};var vr,mr,yr,xr,br,_r,wr,kr,Tr,Ar,Mr,Sr,Er=new lr,Lr={sphere:function(){vr+=4*At},point:D,lineStart:D,lineEnd:D,polygonStart:function(){Er.reset(),Lr.lineStart=Cr},polygonEnd:function(){var t=2*Er;vr+=t<0?4*At+t:t,Lr.lineStart=Lr.lineEnd=Lr.point=D}};function Cr(){var t,e,r,n,a;function i(t,e){e=e*Lt/2+At/4;var i=(t*=Lt)-r,o=i>=0?1:-1,s=o*i,l=Math.cos(e),c=Math.sin(e),u=a*c,h=n*l+u*Math.cos(s),f=u*o*Math.sin(s);Er.add(Math.atan2(f,h)),r=t,n=l,a=c}Lr.point=function(o,s){Lr.point=i,r=(t=o)*Lt,n=Math.cos(s=(e=s)*Lt/2+At/4),a=Math.sin(s)},Lr.lineEnd=function(){i(t,e)}}function Pr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Or(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Ir(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),It(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,a,i,o,s,l,c,u,h,f={point:p,lineStart:g,lineEnd:v,polygonStart:function(){f.point=m,f.lineStart=x,f.lineEnd=b,c=0,Lr.polygonStart()},polygonEnd:function(){Lr.polygonEnd(),f.point=p,f.lineStart=g,f.lineEnd=v,Er<0?(e=-(n=180),r=-(a=90)):c>kt?a=90:c<-kt&&(r=-90),h[0]=e,h[1]=n}};function p(t,i){u.push(h=[e=t,n=t]),i<r&&(r=i),i>a&&(a=i)}function d(t,o){var s=Pr([t*Lt,o*Lt]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var h=t-i,f=h>0?1:-1,d=u[0]*Ct*f,g=y(h)>180;if(g^(f*i<d&&d<f*t))(v=u[1]*Ct)>a&&(a=v);else if(g^(f*i<(d=(d+360)%360-180)&&d<f*t)){var v;(v=-u[1]*Ct)<r&&(r=v)}else o<r&&(r=o),o>a&&(a=o);g?t<i?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>i?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,i=t}function g(){f.point=d}function v(){h[0]=e,h[1]=n,f.point=p,l=null}function m(t,e){if(l){var r=t-i;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Lr.point(t,e),d(t,e)}function x(){Lr.lineStart()}function b(){m(o,s),Lr.lineEnd(),y(c)>kt&&(e=-(n=180)),h[0]=e,h[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function k(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(i){if(a=n=-(e=r=1/0),u=[],t.geo.stream(i,f),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)k((p=u[o])[0],g)||k(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=h=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,a]]}}(),t.geo.centroid=function(e){mr=yr=xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,Nr);var r=Ar,n=Mr,a=Sr,i=r*r+n*n+a*a;return i<Tt&&(r=wr,n=kr,a=Tr,yr<kt&&(r=xr,n=br,a=_r),(i=r*r+n*n+a*a)<Tt)?[NaN,NaN]:[Math.atan2(n,r)*Ct,It(a/Math.sqrt(i))*Ct]};var Nr={sphere:D,point:jr,lineStart:Ur,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Ur}};function jr(t,e){t*=Lt;var r=Math.cos(e*=Lt);Vr(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Vr(t,e,r){xr+=(t-xr)/++mr,br+=(e-br)/mr,_r+=(r-_r)/mr}function Ur(){var t,e,r;function n(n,a){n*=Lt;var i=Math.cos(a*=Lt),o=i*Math.cos(n),s=i*Math.sin(n),l=Math.sin(a),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),kr+=c*(e+(e=s)),Tr+=c*(r+(r=l)),Vr(t,e,r)}Nr.point=function(a,i){a*=Lt;var o=Math.cos(i*=Lt);t=o*Math.cos(a),e=o*Math.sin(a),r=Math.sin(i),Nr.point=n,Vr(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,a;function i(t,e){t*=Lt;var i=Math.cos(e*=Lt),o=i*Math.cos(t),s=i*Math.sin(t),l=Math.sin(e),c=n*l-a*s,u=a*o-r*l,h=r*s-n*o,f=Math.sqrt(c*c+u*u+h*h),p=r*o+n*s+a*l,d=f&&-zt(p)/f,g=Math.atan2(f,p);Ar+=d*c,Mr+=d*u,Sr+=d*h,yr+=g,wr+=g*(r+(r=o)),kr+=g*(n+(n=s)),Tr+=g*(a+(a=l)),Vr(r,n,a)}Nr.point=function(o,s){t=o,e=s,Nr.point=i,o*=Lt;var l=Math.cos(s*=Lt);r=l*Math.cos(o),n=l*Math.sin(o),a=Math.sin(s),Vr(r,n,a)},Nr.lineEnd=function(){i(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,a){var i=[],o=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){a.lineStart();for(var s=0;s<e;++s)a.point((r=t[s])[0],r[1]);a.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,i.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,i.push(l),o.push(c)}}}),o.sort(e),Xr(i),Xr(o),i.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,h,f=i[0];;){for(var p=f,d=!0;p.v;)if((p=p.n)===f)return;u=p.z,a.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)a.point((h=u[s])[0],h[1]);else n(p.x,p.n.x,1,a);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)a.point((h=u[s])[0],h[1]);else n(p.x,p.p.x,-1,a);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);a.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,a=t[0];++n<e;)a.n=r=t[n],r.p=a,a=r;a.n=r=t[0],r.p=a}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,a){return function(i,o){var s,l=r(o),c=i.invert(a[0],a[1]),u={point:h,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=h,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],a=[Math.sin(r),-Math.cos(r),0],i=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var h=c[0],f=h[0],p=h[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===u&&(v=0);var m=(t=c[v])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=m-f,w=_>=0?1:-1,k=w*_,T=k>At,A=d*x;if(Er.add(Math.atan2(A*w*Math.sin(k),g*b+A*Math.cos(k))),i+=T?_+w*Mt:_,T^f>=r^m>=r){var M=zr(Pr(h),Pr(t));Rr(M);var S=zr(a,M);Rr(S);var E=(T^_>=0?-1:1)*It(S[2]);(n>E||n===E&&(M[0]||M[1]))&&(o+=T^_>=0?1:-1)}if(!v++)break;f=m,d=x,g=b,h=t}}return(i<-kt||i<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,$r,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function h(t,r){var n=i(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function f(t,e){var r=i(t,e);l.point(r[0],r[1])}function p(){u.point=f,l.lineStart()}function d(){u.point=h,l.lineEnd()}var g,v,m=Qr(),y=r(m),x=!1;function b(t,e){v.push([t,e]);var r=i(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),v=[]}function w(){b(v[0][0],v[0][1]),y.lineEnd();var t,e=y.clean(),r=m.buffer(),n=r.length;if(v.pop(),g.push(v),v=null,n)if(1&e){var a,i=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++i<n;)o.point((a=t[i])[0],a[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function Qr(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:D,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function $r(t,e){return((t=t.x)[0]<0?t[1]-Et-kt:Et-t[1])-((e=e.x)[0]<0?e[1]-Et-kt:Et-e[1])}var tn=Jr(Yr,function(t){var e,r=NaN,n=NaN,a=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(i,o){var s=i>0?At:-At,l=y(i-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Et:-Et),t.point(a,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(i,n),e=0):a!==s&&l>=At&&(y(r-a)<kt&&(r-=a*kt),y(i-s)<kt&&(i-=s*kt),n=function(t,e,r,n){var a,i,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(i=Math.cos(n))*Math.sin(r)-Math.sin(n)*(a=Math.cos(e))*Math.sin(t))/(a*i*o)):(e+n)/2}(r,n,i,o),t.point(a,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=i,n=o),a=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}},function(t,e,r,n){var a;if(null==t)a=r*Et,n.point(-At,a),n.point(0,a),n.point(At,a),n.point(At,0),n.point(At,-a),n.point(0,-a),n.point(-At,-a),n.point(-At,0),n.point(-At,a);else if(y(t[0]-e[0])>kt){var i=t[0]<e[0]?At:-At;a=r*i/2,n.point(-i,a),n.point(0,a),n.point(i,a)}else n.point(e[0],e[1])},[-At,-At/2]);function en(t,e,r,n){return function(a){var i,o=a.a,s=a.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(i=t-l,f||!(i>0)){if(i/=f,f<0){if(i<u)return;i<h&&(h=i)}else if(f>0){if(i>h)return;i>u&&(u=i)}if(i=r-l,f||!(i<0)){if(i/=f,f<0){if(i>h)return;i>u&&(u=i)}else if(f>0){if(i<u)return;i<h&&(h=i)}if(i=e-c,p||!(i>0)){if(i/=p,p<0){if(i<u)return;i<h&&(h=i)}else if(p>0){if(i>h)return;i>u&&(u=i)}if(i=n-c,p||!(i<0)){if(i/=p,p<0){if(i>h)return;i>u&&(u=i)}else if(p>0){if(i<u)return;i<h&&(h=i)}return u>0&&(a.a={x:l+u*f,y:c+u*p}),h<1&&(a.b={x:l+h*f,y:c+h*p}),a}}}}}}var rn=1e9;function nn(e,r,n,a){return function(l){var c,u,h,f,p,d,g,v,m,y,x,b=l,_=Qr(),w=en(e,r,n,a),k={point:M,lineStart:function(){k.point=S,u&&u.push(h=[]);y=!0,m=!1,g=v=NaN},lineEnd:function(){c&&(S(f,p),d&&m&&_.rejoin(),c.push(_.buffer()));k.point=M,m&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],a=0;a<r;++a)for(var i,o=1,s=u[a],l=s.length,c=s[0];o<l;++o)i=s[o],c[1]<=n?i[1]>n&&Ot(c,i,t)>0&&++e:i[1]<=n&&Ot(c,i,t)<0&&--e,c=i;return 0!==e}([e,a]),n=x&&r,i=c.length;(n||i)&&(l.polygonStart(),n&&(l.lineStart(),T(null,null,1,l),l.lineEnd()),i&&Wr(c,o,r,T,l),l.polygonEnd()),c=u=h=null}};function T(t,o,l,c){var u=0,h=0;if(null==t||(u=i(t,l))!==(h=i(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?a:r)}while((u=(u+l+4)%4)!==h);else c.point(o[0],o[1])}function A(t,i){return e<=t&&t<=n&&r<=i&&i<=a}function M(t,e){A(t,e)&&l.point(t,e)}function S(t,e){var r=A(t=Math.max(-rn,Math.min(rn,t)),e=Math.max(-rn,Math.min(rn,e)));if(u&&h.push([t,e]),y)f=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&m)l.point(t,e);else{var n={a:{x:g,y:v},b:{x:t,y:e}};w(n)?(m||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,v=e,m=r}return k};function i(t,a){return y(t[0]-e)<kt?a>0?0:3:y(t[0]-n)<kt?a>0?2:1:y(t[1]-r)<kt?a>0?1:0:a>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=i(t,1),n=i(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Ln(t),a=n(e,r);return a.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},a}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,a=1+r*(2*n-r),i=Math.sqrt(a)/n;function o(t,e){var r=Math.sqrt(a-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),i-r*Math.cos(t)]}return o.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,It((a-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,a,i,o={stream:function(t){return a&&(a.valid=!1),(a=i(t)).valid=!0,a},extent:function(s){return arguments.length?(i=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),a&&(a.valid=!1,a=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,a,i=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var i=t[0],o=t[1];return e=null,r(i,o),e||(n(i,o),e)||a(i,o),e}return c.invert=function(t){var e=i.scale(),r=i.translate(),n=(t[0]-r[0])/e,a=(t[1]-r[1])/e;return(a>=.12&&a<.234&&n>=-.425&&n<-.214?o:a>=.166&&a<.234&&n>=-.214&&n<-.115?s:i).invert(t)},c.stream=function(t){var e=i.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,a){e.point(t,a),r.point(t,a),n.point(t,a)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(i.precision(t),o.precision(t),s.precision(t),c):i.precision()},c.scale=function(t){return arguments.length?(i.scale(t),o.scale(.35*t),s.scale(t),c.translate(i.translate())):i.scale()},c.translate=function(t){if(!arguments.length)return i.translate();var e=i.scale(),u=+t[0],h=+t[1];return r=i.translate(t).clipExtent([[u-.455*e,h-.238*e],[u+.455*e,h+.238*e]]).stream(l).point,n=o.translate([u-.307*e,h+.201*e]).clipExtent([[u-.425*e+kt,h+.12*e+kt],[u-.214*e-kt,h+.234*e-kt]]).stream(l).point,a=s.translate([u-.205*e,h+.212*e]).clipExtent([[u-.214*e+kt,h+.166*e+kt],[u-.115*e-kt,h+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,hn,fn,pn={point:D,lineStart:D,lineEnd:D,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=D,sn+=y(ln/2)}};function dn(){var t,e,r,n;function a(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(i,o){pn.point=a,t=r=i,e=n=o},pn.lineEnd=function(){a(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>hn&&(hn=t);e<un&&(un=e);e>fn&&(fn=e)},lineStart:D,lineEnd:D,polygonStart:D,polygonEnd:D};function vn(){var t=mn(4.5),e=[],r={point:n,lineStart:function(){r.point=a},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=mn(e),r},result:function(){if(e.length){var t=e.join("");return e=[],t}}};function n(r,n){e.push("M",r,",",n,t)}function a(t,n){e.push("M",t,",",n),r.point=i}function i(t,r){e.push("L",t,",",r)}function o(){r.point=n}function s(){e.push("Z")}return r}function mn(t){return"m0,"+t+"a"+t+","+t+" 0 1,1 0,"+-2*t+"a"+t+","+t+" 0 1,1 0,"+2*t+"z"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=kn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var a=r-t,i=n-e,o=Math.sqrt(a*a+i*i);wr+=o*(t+r)/2,kr+=o*(e+n)/2,Tr+=o,bn(t=r,e=n)}xn.point=function(n,a){xn.point=r,bn(t=n,e=a)}}function wn(){xn.point=bn}function kn(){var t,e,r,n;function a(t,e){var a=t-r,i=e-n,o=Math.sqrt(a*a+i*i);wr+=o*(r+t)/2,kr+=o*(n+e)/2,Tr+=o,Ar+=(o=n*t-r*e)*(r+t),Mr+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(i,o){xn.point=a,bn(t=r=i,e=n=o)},xn.lineEnd=function(){a(t,e)}}function Tn(t){var e=4.5,r={point:n,lineStart:function(){r.point=a},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:D};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,Mt)}function a(e,n){t.moveTo(e,n),r.point=i}function i(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function An(t){var e=.5,r=Math.cos(30*Lt),n=16;function a(e){return(n?function(e){var r,a,o,s,l,c,u,h,f,p,d,g,v={point:m,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),v.lineStart=_},polygonEnd:function(){e.polygonEnd(),v.lineStart=y}};function m(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){h=NaN,v.point=x,e.lineStart()}function x(r,a){var o=Pr([r,a]),s=t(r,a);i(h,f,u,p,d,g,h=s[0],f=s[1],u=r,p=o[0],d=o[1],g=o[2],n,e),e.point(h,f)}function b(){v.point=m,e.lineEnd()}function _(){y(),v.point=w,v.lineEnd=k}function w(t,e){x(r=t,e),a=h,o=f,s=p,l=d,c=g,v.point=x}function k(){i(h,f,u,p,d,g,a,o,r,s,l,c,n,e),v.lineEnd=b,b()}return v}:function(e){return Sn(e,function(r,n){r=t(r,n),e.point(r[0],r[1])})})(e)}function i(n,a,o,s,l,c,u,h,f,p,d,g,v,m){var x=u-n,b=h-a,_=x*x+b*b;if(_>4*e&&v--){var w=s+p,k=l+d,T=c+g,A=Math.sqrt(w*w+k*k+T*T),M=Math.asin(T/=A),S=y(y(T)-1)<kt||y(o-f)<kt?(o+f)/2:Math.atan2(k,w),E=t(S,M),L=E[0],C=E[1],P=L-n,O=C-a,z=b*P-x*O;(z*z/_>e||y((x*P+b*O)/_-.5)>.3||s*p+l*d+c*g<r)&&(i(n,a,o,s,l,c,L,C,S,w/=A,k/=A,T,v,m),m.point(L,C),i(L,C,S,w,k,T,u,h,f,p,d,g,v,m))}}return a.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,a):Math.sqrt(e)},a}function Mn(t){this.stream=t}function Sn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function En(t){return Ln(function(){return t})()}function Ln(e){var r,n,a,i,o,s,l=An(function(t,e){return[(t=r(t,e))[0]*c+i,o-t[1]*c]}),c=150,u=480,h=250,f=0,p=0,d=0,g=0,v=0,m=tn,x=P,b=null,_=null;function w(t){return[(t=a(t[0]*Lt,t[1]*Lt))[0]*c+i,o-t[1]*c]}function k(t){return(t=a.invert((t[0]-i)/c,(o-t[1])/c))&&[t[0]*Ct,t[1]*Ct]}function T(){a=Gr(n=zn(d,g,v),r);var t=r(f,p);return i=u-t[0]*c,o=h+t[1]*c,A()}function A(){return s&&(s.valid=!1,s=null),w}return w.stream=function(t){return s&&(s.valid=!1),(s=Cn(m(n,l(x(t))))).valid=!0,s},w.clipAngle=function(t){return arguments.length?(m=null==t?(b=t,tn):function(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(a,function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(h,f){var p,d=[h,f],g=a(h,f),v=r?g?0:o(h,f):g?o(h+(h<0?At:-At),f):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=i(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=a(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=i(d,e),t.point(p[0],p[1])):(p=i(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var m;v&s||!(m=i(d,e,!0))||(u=0,r?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=v},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}},Fn(t,6*Lt),r?[0,-t]:[-At,t-At]);function a(t,r){return Math.cos(t)*Math.cos(r)>e}function i(t,r,n){var a=[1,0,0],i=zr(Pr(t),Pr(r)),o=Or(i,i),s=i[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,h=zr(a,i),f=Dr(a,c);Ir(f,Dr(i,u));var p=h,d=Or(f,p),g=Or(p,p),v=d*d-g*(Or(f,f)-1);if(!(v<0)){var m=Math.sqrt(v),x=Dr(p,(-d-m)/g);if(Ir(x,f),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],k=t[1],T=r[1];w<_&&(b=_,_=w,w=b);var A=w-_,M=y(A-At)<kt;if(!M&&T<k&&(b=k,k=T,T=b),M||A<kt?M?k+T>0^x[1]<(y(x[0]-_)<kt?k:T):k<=x[1]&&x[1]<=T:A>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+m)/g);return Ir(S,f),[x,Fr(S)]}}}function o(e,n){var a=r?t:At-t,i=0;return e<-a?i|=1:e>a&&(i|=2),n<-a?i|=4:n>a&&(i|=8),i}}((b=+t)*Lt),A()):b},w.clipExtent=function(t){return arguments.length?(_=t,x=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):P,A()):_},w.scale=function(t){return arguments.length?(c=+t,T()):c},w.translate=function(t){return arguments.length?(u=+t[0],h=+t[1],T()):[u,h]},w.center=function(t){return arguments.length?(f=t[0]%360*Lt,p=t[1]%360*Lt,T()):[f*Ct,p*Ct]},w.rotate=function(t){return arguments.length?(d=t[0]%360*Lt,g=t[1]%360*Lt,v=t.length>2?t[2]%360*Lt:0,T()):[d*Ct,g*Ct,v*Ct]},t.rebind(w,l,"precision"),function(){return r=e.apply(this,arguments),w.invert=r.invert&&k,T()}}function Cn(t){return Sn(t,function(e,r){t.point(e*Lt,r*Lt)})}function Pn(t,e){return[t,e]}function On(t,e){return[t>At?t-Mt:t<-At?t+Mt:t,e]}function zn(t,e,r){return t?e||r?Gr(Dn(t),Rn(e,r)):Dn(t):e||r?Rn(e,r):On}function In(t){return function(e,r){return[(e+=t)>At?e-Mt:e<-At?e+Mt:e,r]}}function Dn(t){var e=In(t);return e.invert=In(-t),e}function Rn(t,e){var r=Math.cos(t),n=Math.sin(t),a=Math.cos(e),i=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*a-u*i,s*r-c*n),It(u*a+l*i)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*a-l*i;return[Math.atan2(l*a+c*i,s*r+u*n),It(u*r-s*n)]},o}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(a,i,o,s){var l=o*e;null!=a?(a=Bn(r,a),i=Bn(r,i),(o>0?a<i:a>i)&&(a+=o*Mt)):(a=t+o*Mt,i=t-.5*l);for(var c,u=a;o>0?u>i:u<i;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Bn(t,e){var r=Pr(e);r[0]-=t,Rr(r);var n=zt(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function Nn(e,r,n){var a=t.range(e,r-kt,n).concat(r);return function(t){return a.map(function(e){return[t,e]})}}function jn(e,r,n){var a=t.range(e,r-kt,n).concat(r);return function(t){return a.map(function(e){return[e,t]})}}function Vn(t){return t.source}function Un(t){return t.target}t.geo.path=function(){var e,r,n,a,i,o=4.5;function s(e){return e&&("function"==typeof o&&a.pointRadius(+o.apply(this,arguments)),i&&i.valid||(i=n(a)),t.geo.stream(e,i)),a.result()}function l(){return i=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,n(xn)),Sr?[Ar/Sr,Mr/Sr]:Tr?[wr/Tr,kr/Tr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return hn=fn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[hn,fn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||(r=t,a=An(function(t,e){return r([t*Ct,e*Ct])}),function(t){return Cn(a(t))}):P,l()):e;var r,a},s.context=function(t){return arguments.length?(a=null==(r=t)?new vn:new Tn(t),"function"!=typeof o&&a.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o="function"==typeof t?t:(a.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Mn(e);for(var n in t)r[n]=t[n];return r}}},Mn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=En,t.geo.projectionMutator=Ln,(t.geo.equirectangular=function(){return En(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Lt,e[1]*Lt))[0]*=Ct,e[1]*=Ct,e}return t=zn(t[0]%360*Lt,t[1]*Lt,t.length>2?t[2]*Lt:0),e.invert=function(e){return(e=t.invert(e[0]*Lt,e[1]*Lt))[0]*=Ct,e[1]*=Ct,e},e},On.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function a(){var t="function"==typeof r?r.apply(this,arguments):r,n=zn(-t[0]*Lt,-t[1]*Lt,0).invert,a=[];return e(null,null,1,{point:function(t,e){a.push(t=n(t,e)),t[0]*=Ct,t[1]*=Ct}}),{type:"Polygon",coordinates:[a]}}return a.origin=function(t){return arguments.length?(r=t,a):r},a.angle=function(r){return arguments.length?(e=Fn((t=+r)*Lt,n*Lt),a):t},a.precision=function(r){return arguments.length?(e=Fn(t*Lt,(n=+r)*Lt),a):n},a.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Lt,a=t[1]*Lt,i=e[1]*Lt,o=Math.sin(n),s=Math.cos(n),l=Math.sin(a),c=Math.cos(a),u=Math.sin(i),h=Math.cos(i);return Math.atan2(Math.sqrt((r=h*o)*r+(r=c*u-l*h*s)*r),l*u+c*h*s)},t.geo.graticule=function(){var e,r,n,a,i,o,s,l,c,u,h,f,p=10,d=p,g=90,v=360,m=2.5;function x(){return{type:"MultiLineString",coordinates:b()}}function b(){return t.range(Math.ceil(a/g)*g,n,g).map(h).concat(t.range(Math.ceil(l/v)*v,s,v).map(f)).concat(t.range(Math.ceil(r/p)*p,e,p).filter(function(t){return y(t%g)>kt}).map(c)).concat(t.range(Math.ceil(o/d)*d,i,d).filter(function(t){return y(t%v)>kt}).map(u))}return x.lines=function(){return b().map(function(t){return{type:"LineString",coordinates:t}})},x.outline=function(){return{type:"Polygon",coordinates:[h(a).concat(f(s).slice(1),h(n).reverse().slice(1),f(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(a=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],a>n&&(t=a,a=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(m)):[[a,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],i=+t[1][1],r>e&&(t=r,r=e,e=t),o>i&&(t=o,o=i,i=t),x.precision(m)):[[r,o],[e,i]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],v=+t[1],x):[g,v]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(m=+t,c=Nn(o,i,90),u=jn(r,e,m),h=Nn(l,s,90),f=jn(a,n,m),x):m},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Vn,a=Un;function i(){return{type:"LineString",coordinates:[e||n.apply(this,arguments),r||a.apply(this,arguments)]}}return i.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||a.apply(this,arguments))},i.source=function(t){return arguments.length?(n=t,e="function"==typeof t?null:t,i):n},i.target=function(t){return arguments.length?(a=t,r="function"==typeof t?null:t,i):a},i.precision=function(){return arguments.length?i:0},i},t.geo.interpolate=function(t,e){return r=t[0]*Lt,n=t[1]*Lt,a=e[0]*Lt,i=e[1]*Lt,o=Math.cos(n),s=Math.sin(n),l=Math.cos(i),c=Math.sin(i),u=o*Math.cos(r),h=o*Math.sin(r),f=l*Math.cos(a),p=l*Math.sin(a),d=2*Math.asin(Math.sqrt(Rt(i-n)+o*l*Rt(a-r))),g=1/Math.sin(d),(v=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*f,a=r*h+e*p,i=r*s+e*c;return[Math.atan2(a,n)*Ct,Math.atan2(i,Math.sqrt(n*n+a*a))*Ct]}:function(){return[r*Ct,n*Ct]}).distance=d,v;var r,n,a,i,o,s,l,c,u,h,f,p,d,g,v},t.geo.length=function(e){return yn=0,t.geo.stream(e,qn),yn};var qn={sphere:D,point:D,lineStart:function(){var t,e,r;function n(n,a){var i=Math.sin(a*=Lt),o=Math.cos(a),s=y((n*=Lt)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*i-e*o*l)*s),e*i+r*o*l),t=n,e=i,r=o}qn.point=function(a,i){t=a*Lt,e=Math.sin(i*=Lt),r=Math.cos(i),qn.point=n},qn.lineEnd=function(){qn.point=qn.lineEnd=D}},lineEnd:D,polygonStart:D,polygonEnd:D};function Hn(t,e){function r(e,r){var n=Math.cos(e),a=Math.cos(r),i=t(n*a);return[i*a*Math.sin(e),i*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),a=e(n),i=Math.sin(a),o=Math.cos(a);return[Math.atan2(t*i,n*o),Math.asin(n&&r*i/n)]},r}var Gn=Hn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(t.geo.azimuthalEqualArea=function(){return En(Gn)}).raw=Gn;var Yn=Hn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},P);function Wn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},a=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),i=r*Math.pow(n(t),a)/a;if(!a)return Jn;function o(t,e){i>0?e<-Et+kt&&(e=-Et+kt):e>Et-kt&&(e=Et-kt);var r=i/Math.pow(n(e),a);return[r*Math.sin(a*t),i-r*Math.cos(a*t)]}return o.invert=function(t,e){var r=i-e,n=Pt(a)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/a,2*Math.atan(Math.pow(i/n,1/a))-Et]},o}function Xn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),a=r/n+t;if(y(n)<kt)return Pn;function i(t,e){var r=a-e;return[r*Math.sin(n*t),a-r*Math.cos(n*t)]}return i.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,a-Pt(n)*Math.sqrt(t*t+r*r)]},i}(t.geo.azimuthalEquidistant=function(){return En(Yn)}).raw=Yn,(t.geo.conicConformal=function(){return an(Wn)}).raw=Wn,(t.geo.conicEquidistant=function(){return an(Xn)}).raw=Xn;var Zn=Hn(function(t){return 1/t},Math.atan);function Jn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Kn(t){var e,r=En(t),n=r.scale,a=r.translate,i=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=a.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=i.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=a();i([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return En(Zn)}).raw=Zn,Jn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Et]},(t.geo.mercator=function(){return Kn(Jn)}).raw=Jn;var Qn=Hn(function(){return 1},Math.asin);(t.geo.orthographic=function(){return En(Qn)}).raw=Qn;var $n=Hn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});function ta(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ea(t){return t[0]}function ra(t){return t[1]}function na(t){for(var e=t.length,r=[0,1],n=2,a=2;a<e;a++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[a])<=0;)--n;r[n++]=a}return r.slice(0,n)}function aa(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return En($n)}).raw=$n,ta.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Et]},(t.geo.transverseMercator=function(){var t=Kn(ta),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ta,t.geom={},t.geom.hull=function(t){var e=ea,r=ra;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,a=ve(e),i=ve(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+a.call(this,t[n],n),+i.call(this,t[n],n),n]);for(s.sort(aa),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=na(s),u=na(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return U(t,ia),t};var ia=t.geom.polygon.prototype=[];function oa(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function sa(t,e,r,n){var a=t[0],i=r[0],o=e[0]-a,s=n[0]-i,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(a-i))/(h*o-s*u);return[a+f*o,l+f*u]}function la(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}ia.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],a=0;++e<r;)t=n,n=this[e],a+=t[1]*n[0]-t[0]*n[1];return.5*a},ia.centroid=function(t){var e,r,n=-1,a=this.length,i=0,o=0,s=this[a-1];for(arguments.length||(t=-1/(6*this.area()));++n<a;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],i+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[i*t,o*t]},ia.clip=function(t){for(var e,r,n,a,i,o,s=la(t),l=-1,c=this.length-la(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,a=this[l],i=e[(n=e.length-s)-1],r=-1;++r<n;)oa(o=e[r],u,a)?(oa(i,u,a)||t.push(sa(i,o,u,a)),t.push(o)):oa(i,u,a)&&t.push(sa(i,o,u,a)),i=o;s&&t.push(t[0]),u=a}return t};var ca,ua,ha,fa,pa,da=[],ga=[];function va(){Ia(this),this.edge=this.site=this.circle=null}function ma(t){var e=da.pop()||new va;return e.site=t,e}function ya(t){Sa(t),ha.remove(t),da.push(t),Ia(t)}function xa(t){var e=t.circle,r=e.x,n=e.cy,a={x:r,y:n},i=t.P,o=t.N,s=[t];ya(t);for(var l=i;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)i=l.P,s.unshift(l),ya(l),l=i;s.unshift(l),Sa(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),ya(c),c=o;s.push(c),Sa(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],Pa(c.edge,l.site,c.site,a);l=s[0],(c=s[h-1]).edge=Ca(l.site,c.site,null,a),Ma(l),Ma(c)}function ba(t){for(var e,r,n,a,i=t.x,o=t.y,s=ha._;s;)if((n=_a(s,o)-i)>kt)s=s.L;else{if(!((a=i-wa(s,o))>kt)){n>-kt?(e=s.P,r=s):a>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=ma(t);if(ha.insert(e,l),e||r){if(e===r)return Sa(e),r=ma(e.site),ha.insert(l,r),l.edge=r.edge=Ca(e.site,l.site),Ma(e),void Ma(r);if(r){Sa(e),Sa(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,g=d.x-u,v=d.y-h,m=2*(f*v-p*g),y=f*f+p*p,x=g*g+v*v,b={x:(v*y-p*x)/m+u,y:(f*x-g*y)/m+h};Pa(r.edge,c,d,b),l.edge=Ca(c,t,null,b),r.edge=Ca(t,d,null,b),Ma(e),Ma(r)}else l.edge=Ca(e.site,l.site)}}function _a(t,e){var r=t.site,n=r.x,a=r.y,i=a-e;if(!i)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/i-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+a-i/2)))/h+n:(n+s)/2}function wa(t,e){var r=t.N;if(r)return _a(r,e);var n=t.site;return n.y===e?n.x:1/0}function ka(t){this.site=t,this.edges=[]}function Ta(t,e){return e.angle-t.angle}function Aa(){Ia(this),this.x=this.y=this.arc=this.site=this.cy=null}function Ma(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,a=t.site,i=r.site;if(n!==i){var o=a.x,s=a.y,l=n.x-o,c=n.y-s,u=i.x-o,h=2*(l*(v=i.y-s)-c*u);if(!(h>=-Tt)){var f=l*l+c*c,p=u*u+v*v,d=(v*f-c*p)/h,g=(l*p-u*f)/h,v=g+s,m=ga.pop()||new Aa;m.arc=t,m.site=a,m.x=d+o,m.y=v+Math.sqrt(d*d+g*g),m.cy=v,t.circle=m;for(var y=null,x=pa._;x;)if(m.y<x.y||m.y===x.y&&m.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}pa.insert(y,m),y||(fa=m)}}}}function Sa(t){var e=t.circle;e&&(e.P||(fa=e.N),pa.remove(e),ga.push(e),Ia(e),t.circle=null)}function Ea(t,e){var r=t.b;if(r)return!0;var n,a,i=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,g=h.y,v=(f+d)/2,m=(p+g)/2;if(g===p){if(v<o||v>=s)return;if(f>d){if(i){if(i.y>=c)return}else i={x:v,y:l};r={x:v,y:c}}else{if(i){if(i.y<l)return}else i={x:v,y:c};r={x:v,y:l}}}else if(a=m-(n=(f-d)/(g-p))*v,n<-1||n>1)if(f>d){if(i){if(i.y>=c)return}else i={x:(l-a)/n,y:l};r={x:(c-a)/n,y:c}}else{if(i){if(i.y<l)return}else i={x:(c-a)/n,y:c};r={x:(l-a)/n,y:l}}else if(p<g){if(i){if(i.x>=s)return}else i={x:o,y:n*o+a};r={x:s,y:n*s+a}}else{if(i){if(i.x<o)return}else i={x:s,y:n*s+a};r={x:o,y:n*o+a}}return t.a=i,t.b=r,!0}function La(t,e){this.l=t,this.r=e,this.a=this.b=null}function Ca(t,e,r,n){var a=new La(t,e);return ca.push(a),r&&Pa(a,t,e,r),n&&Pa(a,e,t,n),ua[t.i].edges.push(new Oa(a,t,e)),ua[e.i].edges.push(new Oa(a,e,t)),a}function Pa(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oa(t,e,r){var n=t.a,a=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(a.x-n.x,n.y-a.y):Math.atan2(n.x-a.x,a.y-n.y)}function za(){this._=null}function Ia(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Da(t,e){var r=e,n=e.R,a=r.U;a?a.L===r?a.L=n:a.R=n:t._=n,n.U=a,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ra(t,e){var r=e,n=e.L,a=r.U;a?a.L===r?a.L=n:a.R=n:t._=n,n.U=a,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Fa(t){for(;t.L;)t=t.L;return t}function Ba(t,e){var r,n,a,i=t.sort(Na).pop();for(ca=[],ua=new Array(t.length),ha=new za,pa=new za;;)if(a=fa,i&&(!a||i.y<a.y||i.y===a.y&&i.x<a.x))i.x===r&&i.y===n||(ua[i.i]=new ka(i),ba(i),r=i.x,n=i.y),i=t.pop();else{if(!a)break;xa(a.arc)}e&&(function(t){for(var e,r=ca,n=en(t[0][0],t[0][1],t[1][0],t[1][1]),a=r.length;a--;)(!Ea(e=r[a],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(a,1))}(e),function(t){for(var e,r,n,a,i,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],g=ua,v=g.length;v--;)if((i=g[v])&&i.prepare())for(l=(s=i.edges).length,o=0;o<l;)n=(u=s[o].end()).x,a=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(a-r)>kt)&&(s.splice(o,0,new Oa((m=i.site,x=u,b=y(n-h)<kt&&d-a>kt?{x:h,y:y(e-h)<kt?r:d}:y(a-d)<kt&&f-n>kt?{x:y(r-d)<kt?e:f,y:d}:y(n-f)<kt&&a-p>kt?{x:f,y:y(e-f)<kt?r:p}:y(a-p)<kt&&n-h>kt?{x:y(r-p)<kt?e:h,y:p}:null,_=void 0,_=new La(m,null),_.a=x,_.b=b,ca.push(_),_),i.site,null)),++l);var m,x,b,_}(e));var o={cells:ua,edges:ca};return ha=pa=ca=ua=null,o}function Na(t,e){return e.y-t.y||e.x-t.x}ka.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Ta),e.length},Oa.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},za.prototype={insert:function(t,e){var r,n,a;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Fa(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(a=n.R)&&a.C?(r.C=a.C=!1,n.C=!0,t=n):(t===r.R&&(Da(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ra(this,n)):(a=n.L)&&a.C?(r.C=a.C=!1,n.C=!0,t=n):(t===r.L&&(Ra(this,r),r=(t=r).U),r.C=!1,n.C=!0,Da(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,a=t.U,i=t.L,o=t.R;if(r=i?o?Fa(o):i:o,a?a.L===t?a.L=r:a.R=r:this._=r,i&&o?(n=r.C,r.C=t.C,r.L=i,i.U=r,r!==o?(a=r.U,r.U=t.U,t=r.R,a.L=t,r.R=o,o.U=r):(r.U=a,a=r,t=r.R)):(n=t.C,t=r),t&&(t.U=a),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===a.L){if((e=a.R).C&&(e.C=!1,a.C=!0,Da(this,a),e=a.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ra(this,e),e=a.R),e.C=a.C,a.C=e.R.C=!1,Da(this,a),t=this._;break}}else if((e=a.L).C&&(e.C=!1,a.C=!0,Ra(this,a),e=a.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Da(this,e),e=a.L),e.C=a.C,a.C=e.L.C=!1,Ra(this,a),t=this._;break}e.C=!0,t=a,a=a.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ea,r=ra,n=e,a=r,i=ja;if(t)return o(t);function o(t){var e=new Array(t.length),r=i[0][0],n=i[0][1],a=i[1][0],o=i[1][1];return Ba(s(t),i).cells.forEach(function(i,s){var l=i.edges,c=i.site;(e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):c.x>=r&&c.x<=a&&c.y>=n&&c.y<=o?[[r,o],[a,o],[a,n],[r,n]]:[]).point=t[s]}),e}function s(t){return t.map(function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(a(t,e)/kt)*kt,i:e}})}return o.links=function(t){return Ba(s(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},o.triangles=function(t){var e=[];return Ba(s(t)).cells.forEach(function(r,n){for(var a,i,o,s,l=r.site,c=r.edges.sort(Ta),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)f,a=p,p=(f=c[u].edge).l===l?f.r:f.l,n<a.i&&n<p.i&&(o=a,s=p,((i=l).x-s.x)*(o.y-i.y)-(i.x-o.x)*(s.y-i.y)<0)&&e.push([t[n],t[a.i],t[p.i]])}),e},o.x=function(t){return arguments.length?(n=ve(e=t),o):e},o.y=function(t){return arguments.length?(a=ve(r=t),o):r},o.clipExtent=function(t){return arguments.length?(i=null==t?ja:t,o):i===ja?null:i},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):i===ja?null:i&&i[1]},o};var ja=[[-1e6,-1e6],[1e6,1e6]];function Va(t){return t.x}function Ua(t){return t.y}function qa(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,a=e.g,i=e.b,o=r.r-n,s=r.g-a,l=r.b-i;return function(t){return"#"+ce(Math.round(n+o*t))+ce(Math.round(a+s*t))+ce(Math.round(i+l*t))}}function Ha(t,e){var r,n={},a={};for(r in t)r in e?n[r]=Za(t[r],e[r]):a[r]=t[r];for(r in e)r in t||(a[r]=e[r]);return function(t){for(r in n)a[r]=n[r](t);return a}}function Ga(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Ya(t,e){var r,n,a,i=Wa.lastIndex=Xa.lastIndex=0,o=-1,s=[],l=[];for(t+="",e+="";(r=Wa.exec(t))&&(n=Xa.exec(e));)(a=n.index)>i&&(a=e.slice(i,a),s[o]?s[o]+=a:s[++o]=a),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Ga(r,n)})),i=Xa.lastIndex;return i<e.length&&(a=e.slice(i),s[o]?s[o]+=a:s[++o]=a),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+""}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join("")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,a){var i,o=ea,s=ra;if(i=arguments.length)return o=Va,s=Ua,3===i&&(a=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,g,v,m=ve(o),x=ve(s);if(null!=e)p=e,d=r,g=n,v=a;else if(g=v=-(p=d=1/0),c=[],u=[],f=t.length,i)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>v&&(v=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var b=+m(l=t[h],h),_=+x(l,h);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>v&&(v=_),c.push(b),u.push(_)}var w=g-p,k=v-d;function T(t,e,r,n,a,i,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)A(t,e,r,n,a,i,o,s);else{var u=t.point;t.x=t.y=t.point=null,A(t,u,l,c,a,i,o,s),A(t,e,r,n,a,i,o,s)}else t.x=r,t.y=n,t.point=e}else A(t,e,r,n,a,i,o,s)}function A(t,e,r,n,a,i,o,s){var l=.5*(a+o),c=.5*(i+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?a=l:o=l,h?i=c:s=c,T(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}}),e,r,n,a,i,o,s)}w>k?v=d+w:g=p+k;var M={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}};if(M.visit=function(t){!function t(e,r,n,a,i,o){if(!e(r,n,a,i,o)){var s=.5*(n+i),l=.5*(a+o),c=r.nodes;c[0]&&t(e,c[0],n,a,s,l),c[1]&&t(e,c[1],s,a,i,l),c[2]&&t(e,c[2],n,l,s,o),c[3]&&t(e,c[3],s,l,i,o)}}(t,M,p,d,g,v)},M.find=function(t){return function(t,e,r,n,a,i,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>i||h>o||f<n||p<a)){if(d=c.point){var d,g=e-c.x,v=r-c.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);n=e-y,a=r-y,i=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+f),_=.5*(h+p),w=(r>=_)<<1|e>=b,k=w+4;w<k;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,b,_);break;case 1:t(c,b,h,f,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,f,p)}}}(t,n,a,i,o),s}(M,t[0],t[1],p,d,g,v)},h=-1,null==e){for(;++h<f;)T(M,t[h],c[h],u[h],p,d,g,v);--h}else t.forEach(M.add);return c=u=t=l=null,M}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=a=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],a=+t[1][1]),l):null==e?null:[[e,r],[n,a]]},l.size=function(t){return arguments.length?(null==t?e=r=n=a=null:(e=r=0,n=+t[0],a=+t[1]),l):null==e?null:[n-e,a-r]},l},t.interpolateRgb=qa,t.interpolateObject=Ha,t.interpolateNumber=Ga,t.interpolateString=Ya;var Wa=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,Xa=new RegExp(Wa.source,"g");function Za(e,r){for(var n,a=t.interpolators.length;--a>=0&&!(n=t.interpolators[a](e,r)););return n}function Ja(t,e){var r,n=[],a=[],i=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Za(t[r],e[r]));for(;r<i;++r)a[r]=t[r];for(;r<o;++r)a[r]=e[r];return function(t){for(r=0;r<s;++r)a[r]=n[r](t);return a}}t.interpolate=Za,t.interpolators=[function(t,e){var r=typeof e;return("string"===r?ge.has(e.toLowerCase())||/^(#|rgb\(|hsl\()/i.test(e)?qa:Ya:e instanceof Vt?qa:Array.isArray(e)?Ja:"object"===r&&isNaN(e)?Ha:Ga)(t,e)}],t.interpolateArray=Ja;var Ka=function(){return P},Qa=t.map({linear:Ka,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return ri},cubic:function(){return ni},sin:function(){return ii},exp:function(){return oi},circle:function(){return si},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/Mt*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*Mt/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return li}}),$a=t.map({in:P,out:ti,"in-out":ei,"out-in":function(t){return ei(ti(t))}});function ti(t){return function(e){return 1-t(1-e)}}function ei(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function ri(t){return t*t}function ni(t){return t*t*t}function ai(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function ii(t){return 1-Math.cos(t*Et)}function oi(t){return Math.pow(2,10*(t-1))}function si(t){return 1-Math.sqrt(1-t*t)}function li(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function ci(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ui(t){var e,r,n,a=[t.a,t.b],i=[t.c,t.d],o=fi(a),s=hi(a,i),l=fi(((e=i)[0]+=(n=-s)*(r=a)[0],e[1]+=n*r[1],e))||0;a[0]*i[1]<i[0]*a[1]&&(a[0]*=-1,a[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(a[1],a[0]):Math.atan2(-i[0],i[1]))*Ct,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Ct:0}function hi(t,e){return t[0]*e[0]+t[1]*e[1]}function fi(t){var e=Math.sqrt(hi(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e,n=t.indexOf("-"),a=n>=0?t.slice(0,n):t,i=n>=0?t.slice(n+1):"in";return a=Qa.get(a)||Ka,i=$a.get(i)||P,e=i(a.apply(null,r.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,a=e.c,i=e.l,o=r.h-n,s=r.c-a,l=r.l-i;isNaN(s)&&(s=0,a=isNaN(a)?r.c:a);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Wt(n+o*t,a+s*t,i+l*t)+""}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,a=e.s,i=e.l,o=r.h-n,s=r.s-a,l=r.l-i;isNaN(s)&&(s=0,a=isNaN(a)?r.s:a);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Ht(n+o*t,a+s*t,i+l*t)+""}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,a=e.a,i=e.b,o=r.l-n,s=r.a-a,l=r.b-i;return function(t){return te(n+o*t,a+s*t,i+l*t)+""}},t.interpolateRound=ci,t.transform=function(e){var r=a.createElementNS(t.ns.prefix.svg,"g");return(t.transform=function(t){if(null!=t){r.setAttribute("transform",t);var e=r.transform.baseVal.consolidate()}return new ui(e?e.matrix:pi)})(e)},ui.prototype.toString=function(){return"translate("+this.translate+")rotate("+this.rotate+")skewX("+this.skew+")scale("+this.scale+")"};var pi={a:1,b:0,c:0,d:1,e:0,f:0};function di(t){return t.length?t.pop()+",":""}function gi(e,r){var n=[],a=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var a=r.push("translate(",null,",",null,")");n.push({i:a-4,x:Ga(t[0],e[0])},{i:a-2,x:Ga(t[1],e[1])})}else(e[0]||e[1])&&r.push("translate("+e+")")}(e.translate,r.translate,n,a),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(di(r)+"rotate(",null,")")-2,x:Ga(t,e)})):e&&r.push(di(r)+"rotate("+e+")")}(e.rotate,r.rotate,n,a),function(t,e,r,n){t!==e?n.push({i:r.push(di(r)+"skewX(",null,")")-2,x:Ga(t,e)}):e&&r.push(di(r)+"skewX("+e+")")}(e.skew,r.skew,n,a),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var a=r.push(di(r)+"scale(",null,",",null,")");n.push({i:a-4,x:Ga(t[0],e[0])},{i:a-2,x:Ga(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(di(r)+"scale("+e+")")}(e.scale,r.scale,n,a),e=r=null,function(t){for(var e,r=-1,i=a.length;++r<i;)n[(e=a[r]).i]=e.x(t);return n.join("")}}function vi(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function mi(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function yi(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=xi(t),n=xi(e),a=r.pop(),i=n.pop(),o=null;for(;a===i;)o=a,a=r.pop(),i=n.pop();return o}(e,r),a=[e];e!==n;)e=e.parent,a.push(e);for(var i=a.length;r!==n;)a.splice(i,0,r),r=r.parent;return a}function xi(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function bi(t){t.fixed|=2}function _i(t){t.fixed&=-7}function wi(t){t.fixed|=4,t.px=t.x,t.py=t.y}function ki(t){t.fixed&=-5}t.interpolateTransform=gi,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(yi(t[r]));return e}},t.layout.chord=function(){var e,r,n,a,i,o,s,l={},c=0;function u(){var l,u,f,p,d,g={},v=[],m=t.range(a),y=[];for(e=[],r=[],l=0,p=-1;++p<a;){for(u=0,d=-1;++d<a;)u+=n[p][d];v.push(u),y.push(t.range(a)),l+=u}for(i&&m.sort(function(t,e){return i(v[t],v[e])}),o&&y.forEach(function(t,e){t.sort(function(t,r){return o(n[e][t],n[e][r])})}),l=(Mt-c*a)/l,u=0,p=-1;++p<a;){for(f=u,d=-1;++d<a;){var x=m[p],b=y[x][d],_=n[x][b],w=u,k=u+=_*l;g[x+"-"+b]={index:x,subindex:b,startAngle:w,endAngle:k,value:_}}r[x]={index:x,startAngle:f,endAngle:u,value:v[x]},u+=c}for(p=-1;++p<a;)for(d=p-1;++d<a;){var T=g[p+"-"+d],A=g[d+"-"+p];(T.value||A.value)&&e.push(T.value<A.value?{source:A,target:T}:{source:T,target:A})}s&&h()}function h(){e.sort(function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}return l.matrix=function(t){return arguments.length?(a=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(i=t,e=r=null,l):i},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&h(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,a,i,o,s={},l=t.dispatch("start","tick","end"),c=[1,1],u=.9,h=Ti,f=Ai,p=-30,d=Mi,g=.1,v=.64,m=[],y=[];function x(t){return function(e,r,n,a){if(e.point!==t){var i=e.cx-t.x,o=e.cy-t.y,s=a-r,l=i*i+o*o;if(s*s/v<l){if(l<d){var c=e.charge/l;t.px-=i*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=i*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:"end",alpha:n=0}),!0;var r,s,h,f,d,v,b,_,w,k=m.length,T=y.length;for(s=0;s<T;++s)f=(h=y[s]).source,(v=(_=(d=h.target).x-f.x)*_+(w=d.y-f.y)*w)&&(_*=v=n*i[s]*((v=Math.sqrt(v))-a[s])/v,w*=v,d.x-=_*(b=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*b,f.x+=_*(b=1-b),f.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<k;)(h=m[s]).x+=(_-h.x)*b,h.y+=(w-h.y)*b;if(p)for(!function t(e,r,n){var a=0,i=0;e.charge=0;if(!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,a+=o.charge*o.cx,i+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,a+=u*e.point.x,i+=u*e.point.y}e.cx=a/e.charge;e.cy=i/e.charge}(r=t.geom.quadtree(m),n,o),s=-1;++s<k;)(h=m[s]).fixed||r.visit(x(h));for(s=-1;++s<k;)(h=m[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:"tick",alpha:n})},s.nodes=function(t){return arguments.length?(m=t,s):m},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h="function"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f="function"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p="function"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(v=t*t,s):Math.sqrt(v)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:"end",alpha:n=0})):t>0&&(l.start({type:"start",alpha:n=t}),e=Te(s.tick)),s):n},s.start=function(){var t,e,r,n=m.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=m[t]).index=t,r.weight=0;for(t=0;t<l;++t)"number"==typeof(r=y[t]).source&&(r.source=m[r.source]),"number"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=m[t],isNaN(r.x)&&(r.x=g("x",u)),isNaN(r.y)&&(r.y=g("y",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(a=[],"function"==typeof h)for(t=0;t<l;++t)a[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=h;if(i=[],"function"==typeof f)for(t=0;t<l;++t)i[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=f;if(o=[],"function"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,m[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,a){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var i=y[c];e[i.source.index].push(i.target),e[i.target.index].push(i.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*a}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(P).on("dragstart.force",bi).on("drag.force",b).on("dragend.force",_i)),!arguments.length)return r;this.on("mouseover.force",wi).on("mouseout.force",ki).call(r)},t.rebind(s,l,"on")};var Ti=20,Ai=1,Mi=1/0;function Si(e,r){return t.rebind(e,r,"sort","children","value"),e.nodes=e,e.links=zi,e}function Ei(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(a=t.children)&&(n=a.length))for(var n,a;--n>=0;)r.push(a[n])}function Li(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(i=t.children)&&(a=i.length))for(var a,i,o=-1;++o<a;)r.push(i[o]);for(;null!=(t=n.pop());)e(t)}function Ci(t){return t.children}function Pi(t){return t.value}function Oi(t,e){return e.value-t.value}function zi(e){return t.merge(e.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}t.layout.hierarchy=function(){var t=Oi,e=Ci,r=Pi;function n(a){var i,o=[a],s=[];for(a.depth=0;null!=(i=o.pop());)if(s.push(i),(c=e.call(n,i,i.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=i,u.depth=i.depth+1;r&&(i.value=0),i.children=c}else r&&(i.value=+r.call(n,i,i.depth)||0),delete i.children;return Li(a,function(e){var n,a;t&&(n=e.children)&&n.sort(t),r&&(a=e.parent)&&(a.value+=e.value)}),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Ei(t,function(t){t.children&&(t.value=0)}),Li(t,function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)})),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var a=e.call(this,t,n);return function t(e,r,n,a){var i=e.children;if(e.x=r,e.y=e.depth*a,e.dx=n,e.dy=a,i&&(o=i.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=i[c],r,l=s.value*n,a),r+=l}}(a[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(a=r.length))for(var a,i=-1;++i<a;)n=Math.max(n,t(r[i]));return 1+n}(a[0])),a}return n.size=function(t){return arguments.length?(r=t,n):r},Si(n,e)},t.layout.pie=function(){var e=Number,r=Ii,n=0,a=Mt,i=0;function o(s){var l,c=s.length,u=s.map(function(t,r){return+e.call(o,t,r)}),h=+("function"==typeof n?n.apply(this,arguments):n),f=("function"==typeof a?a.apply(this,arguments):a)-h,p=Math.min(Math.abs(f)/c,+("function"==typeof i?i.apply(this,arguments):i)),d=p*(f<0?-1:1),g=t.sum(u),v=g?(f-c*d)/g:0,m=t.range(c),y=[];return null!=r&&m.sort(r===Ii?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),m.forEach(function(t){y[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*v+d,padAngle:p}}),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(a=t,o):a},o.padAngle=function(t){return arguments.length?(i=t,o):i},o};var Ii={};function Di(t){return t.x}function Ri(t){return t.y}function Fi(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=P,r=ji,n=Vi,a=Fi,i=Di,o=Ri;function s(l,c){if(!(p=l.length))return l;var u=l.map(function(t,r){return e.call(s,t,r)}),h=u.map(function(t){return t.map(function(t,e){return[i.call(s,t,e),o.call(s,t,e)]})}),f=r.call(s,h,c);u=t.permute(u,f),h=t.permute(h,f);var p,d,g,v,m=n.call(s,h,c),y=u[0].length;for(g=0;g<y;++g)for(a.call(s,u[0][g],v=m[g],h[0][g][1]),d=1;d<p;++d)a.call(s,u[d][g],v+=h[d-1][g][1],h[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r="function"==typeof t?t:Bi.get(t)||ji,s):r},s.offset=function(t){return arguments.length?(n="function"==typeof t?t:Ni.get(t)||Vi,s):n},s.x=function(t){return arguments.length?(i=t,s):i},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(a=t,s):a},s};var Bi=t.map({"inside-out":function(e){var r,n,a=e.length,i=e.map(Ui),o=e.map(qi),s=t.range(a).sort(function(t,e){return i[t]-i[e]}),l=0,c=0,u=[],h=[];for(r=0;r<a;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],h.push(n));return h.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:ji}),Ni=t.map({silhouette:function(t){var e,r,n,a=t.length,i=t[0].length,o=[],s=0,l=[];for(r=0;r<i;++r){for(e=0,n=0;e<a;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<i;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,a,i,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,a=0;e<u;++e)a+=t[e][r][1];for(e=0,i=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;i+=o*t[e][r][1]}p[r]=l-=a?i/a*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,a=t.length,i=t[0].length,o=1/a,s=[];for(r=0;r<i;++r){for(e=0,n=0;e<a;e++)n+=t[e][r][1];if(n)for(e=0;e<a;e++)t[e][r][1]/=n;else for(e=0;e<a;e++)t[e][r][1]=o}for(r=0;r<i;++r)s[r]=0;return s},zero:Vi});function ji(e){return t.range(e.length)}function Vi(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Ui(t){for(var e,r=1,n=0,a=t[0][1],i=t.length;r<i;++r)(e=t[r][1])>a&&(n=r,a=e);return n}function qi(t){return t.reduce(Hi,0)}function Hi(t,e){return t+e[1]}function Gi(t,e){return Yi(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Yi(t,e){for(var r=-1,n=+t[0],a=(t[1]-n)/e,i=[];++r<=e;)i[r]=a*r+n;return i}function Wi(e){return[t.min(e),t.max(e)]}function Xi(t,e){return t.value-e.value}function Zi(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function Ji(t,e){t._pack_next=e,e._pack_prev=t}function Ki(t,e){var r=e.x-t.x,n=e.y-t.y,a=t.r+e.r;return.999*a*a>r*r+n*n}function Qi(t){if((e=t.children)&&(l=e.length)){var e,r,n,a,i,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach($i),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(eo(r,n,a=e[2]),x(a),Zi(r,a),r._pack_prev=a,Zi(a,n),n=r._pack_next,i=3;i<l;i++){eo(r,n,a=e[i]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(Ki(o,a)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!Ki(s,a);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?Ji(r,n=o):Ji(r=s,n),i--):(Zi(r,a),n=a,x(a))}var v=(c+u)/2,m=(h+f)/2,y=0;for(i=0;i<l;i++)(a=e[i]).x-=v,a.y-=m,y=Math.max(y,a.r+Math.sqrt(a.x*a.x+a.y*a.y));t.r=y,e.forEach(to)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function $i(t){t._pack_next=t._pack_prev=t}function to(t){delete t._pack_next,delete t._pack_prev}function eo(t,e,r){var n=t.r+r.r,a=e.x-t.x,i=e.y-t.y;if(n&&(a||i)){var o=e.r+r.r,s=a*a+i*i,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*a+c*i,r.y=t.y+l*i-c*a}else r.x=t.x+n,r.y=t.y}function ro(t,e){return t.parent==e.parent?1:2}function no(t){var e=t.children;return e.length?e[0]:t.t}function ao(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function io(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function oo(t,e,r){return t.a.parent===e.parent?t.a:r}function so(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function lo(t,e){var r=t.x+e[3],n=t.y+e[0],a=t.dx-e[1]-e[3],i=t.dy-e[0]-e[2];return a<0&&(r+=a/2,a=0),i<0&&(n+=i/2,i=0),{x:r,y:n,dx:a,dy:i}}function co(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function uo(t){return t.rangeExtent?t.rangeExtent():co(t.range())}function ho(t,e,r,n){var a=r(t[0],t[1]),i=n(e[0],e[1]);return function(t){return i(a(t))}}function fo(t,e){var r,n=0,a=t.length-1,i=t[n],o=t[a];return o<i&&(r=n,n=a,a=r,r=i,i=o,o=r),t[n]=e.floor(i),t[a]=e.ceil(o),t}function po(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:go}t.layout.histogram=function(){var e=!0,r=Number,n=Wi,a=Gi;function i(i,o){for(var s,l,c=[],u=i.map(r,this),h=n.call(this,u,o),f=a.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[t.bisect(f,l,1,d)-1]).y+=g,s.push(i[o]));return c}return i.value=function(t){return arguments.length?(r=t,i):r},i.range=function(t){return arguments.length?(n=ve(t),i):n},i.bins=function(t){return arguments.length?(a="number"==typeof t?function(e){return Yi(e,t)}:ve(t),i):a},i.frequency=function(t){return arguments.length?(e=!!t,i):e},i},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort(Xi),n=0,a=[1,1];function i(t,i){var o=r.call(this,t,i),s=o[0],l=a[0],c=a[1],u=null==e?Math.sqrt:"function"==typeof e?e:function(){return e};if(s.x=s.y=0,Li(s,function(t){t.r=+u(t.value)}),Li(s,Qi),n){var h=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Li(s,function(t){t.r+=h}),Li(s,Qi),Li(s,function(t){t.r-=h})}return function t(e,r,n,a){var i=e.children;e.x=r+=a*e.x;e.y=n+=a*e.y;e.r*=a;if(i)for(var o=-1,s=i.length;++o<s;)t(i[o],r,n,a)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return i.size=function(t){return arguments.length?(a=t,i):a},i.radius=function(t){return arguments.length?(e=null==t||"function"==typeof t?t:+t,i):e},i.padding=function(t){return arguments.length?(n=+t,i):n},Si(i,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],a=null;function i(t,i){var c=e.call(this,t,i),u=c[0],h=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var a,i=e.children,o=0,s=i.length;o<s;++o)n.push((i[o]=a={_:i[o],parent:e,children:(a=i[o].children)&&a.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=a);return r.children[0]}(u);if(Li(h,o),h.parent.m=-h.z,Ei(h,s),a)Ei(u,l);else{var f=u,p=u,d=u;Ei(u,function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)});var g=r(f,p)/2-f.x,v=n[0]/(p.x+r(p,f)/2+g),m=n[1]/(d.depth||1);Ei(u,function(t){t.x=(t.x+g)*v,t.y=t.depth*m})}return c}function o(t){var e=t.children,n=t.parent.children,a=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,a=t.children,i=a.length;for(;--i>=0;)(e=a[i]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var i=(e[0].z+e[e.length-1].z)/2;a?(t.z=a.z+r(t._,a._),t.m=t.z-i):t.z=i}else a&&(t.z=a.z+r(t._,a._));t.parent.A=function(t,e,n){if(e){for(var a,i=t,o=t,s=e,l=i.parent.children[0],c=i.m,u=o.m,h=s.m,f=l.m;s=ao(s),i=no(i),s&&i;)l=no(l),(o=ao(o)).a=t,(a=s.z+h-i.z-c+r(s._,i._))>0&&(io(oo(s,t,n),t,a),c+=a,u+=a),h+=s.m,c+=i.m,f+=l.m,u+=o.m;s&&!ao(o)&&(o.t=s,o.m+=h-u),i&&!no(l)&&(l.t=i,l.m+=c-f,n=t)}return n}(t,a,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return i.separation=function(t){return arguments.length?(r=t,i):r},i.size=function(t){return arguments.length?(a=null==(n=t)?l:null,i):a?null:n},i.nodeSize=function(t){return arguments.length?(a=null==(n=t)?null:l,i):a?n:null},Si(i,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],a=!1;function i(i,o){var s,l=e.call(this,i,o),c=l[0],u=0;Li(c,function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}(n),e.y=function(e){return 1+t.max(e,function(t){return t.y})}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)});var h=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),f=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=h.x-r(h,f)/2,d=f.x+r(f,h)/2;return Li(c,a?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return i.separation=function(t){return arguments.length?(r=t,i):r},i.size=function(t){return arguments.length?(a=null==(n=t),i):a?null:n},i.nodeSize=function(t){return arguments.length?(a=null!=(n=t),i):a?n:null},Si(i,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,a=[1,1],i=null,o=so,s=!1,l="squarify",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,a=-1,i=t.length;++a<i;)n=(r=t[a]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,a,i=o(t),s=[],c=e.slice(),f=1/0,g="slice"===l?i.dx:"dice"===l?i.dy:"slice-dice"===l?1&t.depth?i.dy:i.dx:Math.min(i.dx,i.dy);for(u(c,i.dx*i.dy/t.value),s.area=0;(a=c.length)>0;)s.push(r=c[a-1]),s.area+=r.area,"squarify"!==l||(n=p(s,g))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,g,i,!1),g=Math.min(i.dx,i.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,g,i,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),a=e.slice(),i=[];for(u(a,n.dx*n.dy/t.value),i.area=0;r=a.pop();)i.push(r),i.area+=r.area,null!=r.z&&(d(i,r.z?n.dx:n.dy,n,!a.length),i.length=i.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,a=0,i=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<i&&(i=r),r>a&&(a=r));return e*=e,(n*=n)?Math.max(e*a*c/n,n/(e*i*c)):1/0}function d(t,e,r,a){var i,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((a||u>r.dy)&&(u=r.dy);++o<s;)(i=t[o]).x=l,i.y=c,i.dy=u,l+=i.dx=Math.min(r.x+r.dx-l,u?n(i.area/u):0);i.z=!0,i.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((a||u>r.dx)&&(u=r.dx);++o<s;)(i=t[o]).x=l,i.y=c,i.dx=u,c+=i.dy=Math.min(r.y+r.dy-c,u?n(i.area/u):0);i.z=!1,i.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),i=n[0];return i.x=i.y=0,i.value?(i.dx=a[0],i.dy=a[1]):i.dx=i.dy=0,e&&r.revalue(i),u([i],i.dx*i.dy/i.value),(e?f:h)(i),s&&(e=n),n}return g.size=function(t){return arguments.length?(a=t,g):a},g.padding=function(t){if(!arguments.length)return i;function e(e){return lo(e,t)}var r;return o=null==(i=t)?so:"function"==(r=typeof t)?function(e){var r=t.call(g,e,e.depth);return null==r?so(e):lo(e,"number"==typeof r?[r,r,r,r]:r)}:"number"===r?(t=[t,t,t,t],e):e,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+"",g):l},Si(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,a;do{a=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!a||a>1);return t+e*r*Math.sqrt(-2*Math.log(a)/a)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var go={floor:P,ceil:P};function vo(e,r,n,a){var i=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)i.push(n(e[s-1],e[s])),o.push(a(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](i[n](r))}}function mo(e,r){return t.rebind(e,r,"range","rangeRound","interpolate","clamp")}function yo(t,e){return fo(t,po(xo(t,e)[2])),fo(t,po(xo(t,e)[2])),t}function xo(t,e){null==e&&(e=10);var r=co(t),n=r[1]-r[0],a=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),i=e/n*a;return i<=.15?a*=10:i<=.35?a*=5:i<=.75&&(a*=2),r[0]=Math.ceil(r[0]/a)*a,r[1]=Math.floor(r[1]/a)*a+.5*a,r[2]=a,r}function bo(e,r){return t.range.apply(t,xo(e,r))}function _o(e,r,n){var a=xo(e,r);if(n){var i=Ce.exec(n);if(i.shift(),"s"===i[8]){var o=t.formatPrefix(Math.max(y(a[0]),y(a[1])));return i[7]||(i[7]="."+ko(o.scale(a[2]))),i[8]="f",n=t.format(i.join("")),function(t){return n(o.scale(t))+o.symbol}}i[7]||(i[7]="."+function(t,e){var r=ko(e[2]);return t in wo?Math.abs(r-ko(Math.max(y(e[0]),y(e[1]))))+ +("e"!==t):r-2*("%"===t)}(i[8],a)),n=i.join("")}else n=",."+ko(a[2])+"f";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,a){var i,o;function s(){var t=Math.min(e.length,r.length)>2?vo:ho,s=a?mi:vi;return i=t(e,r,s,n),o=t(r,e,s,Za),l}function l(t){return i(t)}l.invert=function(t){return o(t)};l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e};l.range=function(t){return arguments.length?(r=t,s()):r};l.rangeRound=function(t){return l.range(t).interpolate(ci)};l.clamp=function(t){return arguments.length?(a=t,s()):a};l.interpolate=function(t){return arguments.length?(n=t,s()):n};l.ticks=function(t){return bo(e,t)};l.tickFormat=function(t,r){return _o(e,t,r)};l.nice=function(t){return yo(e,t),s()};l.copy=function(){return t(e,r,n,a)};return s()}([0,1],[0,1],Za,!1)};var wo={s:1,g:1,p:1,r:1,e:1};function ko(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,a,i){function o(t){return(a?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return a?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}l.invert=function(t){return s(r.invert(t))};l.domain=function(t){return arguments.length?(a=t[0]>=0,r.domain((i=t.map(Number)).map(o)),l):i};l.base=function(t){return arguments.length?(n=+t,r.domain(i.map(o)),l):n};l.nice=function(){var t=fo(i.map(o),a?Math:Ao);return r.domain(t),i=t.map(s),l};l.ticks=function(){var t=co(i),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),h=n%1?2:n;if(isFinite(u-c)){if(a){for(;c<u;c++)for(var f=1;f<h;f++)e.push(s(c)*f);e.push(s(c))}else for(e.push(s(c));c++<u;)for(var f=h-1;f>0;f--)e.push(s(c)*f);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e};l.tickFormat=function(e,r){if(!arguments.length)return To;arguments.length<2?r=To:"function"!=typeof r&&(r=t.format(r));var a=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=a?r(t):""}};l.copy=function(){return e(r.copy(),n,a,i)};return mo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var To=t.format(".0e"),Ao={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Mo(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var a=Mo(r),i=Mo(1/r);function o(t){return e(a(t))}o.invert=function(t){return i(e.invert(t))};o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(a)),o):n};o.ticks=function(t){return bo(n,t)};o.tickFormat=function(t,e){return _o(n,t,e)};o.nice=function(t){return o.domain(yo(n,t))};o.exponent=function(t){return arguments.length?(a=Mo(r=t),i=Mo(1/r),e.domain(n.map(a)),o):r};o.copy=function(){return t(e.copy(),r,n)};return mo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var a,i,o;function s(t){return i[((a.get(t)||("range"===n.t?a.set(t,r.push(t)):NaN))-1)%i.length]}function l(e,n){return t.range(r.length).map(function(t){return e+n*t})}s.domain=function(t){if(!arguments.length)return r;r=[],a=new b;for(var e,i=-1,o=t.length;++i<o;)a.has(e=t[i])||a.set(e,r.push(e));return s[n.t].apply(s,n.a)};s.range=function(t){return arguments.length?(i=t,o=0,n={t:"range",a:arguments},s):i};s.rangePoints=function(t,e){arguments.length<2&&(e=0);var a=t[0],c=t[1],u=r.length<2?(a=(a+c)/2,0):(c-a)/(r.length-1+e);return i=l(a+u*e/2,u),o=0,n={t:"rangePoints",a:arguments},s};s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var a=t[0],c=t[1],u=r.length<2?(a=c=Math.round((a+c)/2),0):(c-a)/(r.length-1+e)|0;return i=l(a+Math.round(u*e/2+(c-a-(r.length-1+e)*u)/2),u),o=0,n={t:"rangeRoundPoints",a:arguments},s};s.rangeBands=function(t,e,a){arguments.length<2&&(e=0),arguments.length<3&&(a=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=(h-u)/(r.length-e+2*a);return i=l(u+f*a,f),c&&i.reverse(),o=f*(1-e),n={t:"rangeBands",a:arguments},s};s.rangeRoundBands=function(t,e,a){arguments.length<2&&(e=0),arguments.length<3&&(a=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=Math.floor((h-u)/(r.length-e+2*a));return i=l(u+Math.round((h-u-(r.length-e)*f)/2),f),c&&i.reverse(),o=Math.round(f*(1-e)),n={t:"rangeRoundBands",a:arguments},s};s.rangeBand=function(){return o};s.rangeExtent=function(){return co(n.a[0])};s.copy=function(){return e(r,n)};return s.domain(r)}([],{t:"range",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(So)},t.scale.category20=function(){return t.scale.ordinal().range(Eo)},t.scale.category20b=function(){return t.scale.ordinal().range(Lo)},t.scale.category20c=function(){return t.scale.ordinal().range(Co)};var So=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),Eo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),Lo=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),Co=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function Po(){return 0}t.scale.quantile=function(){return function e(r,n){var a;function i(){var e=0,i=n.length;for(a=[];++e<i;)a[e-1]=t.quantile(r,e/i);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(a,e)]}o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(f),i()):r};o.range=function(t){return arguments.length?(n=t,i()):n};o.quantiles=function(){return a};o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?a[t-1]:r[0],t<a.length?a[t]:r[r.length-1]]};o.copy=function(){return e(r,n)};return i()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var a,i;function o(t){return n[Math.max(0,Math.min(i,Math.floor(a*(t-e))))]}function s(){return a=n.length/(r-e),i=n.length-1,o}o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]};o.range=function(t){return arguments.length?(n=t,s()):n};o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/a+e,t+1/a]};o.copy=function(){return t(e,r,n)};return s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function a(e){if(e<=e)return n[t.bisect(r,e)]}a.domain=function(t){return arguments.length?(r=t,a):r};a.range=function(t){return arguments.length?(n=t,a):n};a.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]};a.copy=function(){return e(r,n)};return a}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}r.invert=r;r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e};r.ticks=function(t){return bo(e,t)};r.tickFormat=function(t,r){return _o(e,t,r)};r.copy=function(){return t(e)};return r}([0,1])},t.svg={},t.svg.arc=function(){var t=zo,e=Io,r=Po,n=Oo,a=Do,i=Ro,o=Fo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=a.apply(this,arguments)-Et,h=i.apply(this,arguments)-Et,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=St)return l(c,p)+(s?l(s,1-p):"")+"Z";var d,g,v,m,y,x,b,_,w,k,T,A,M=0,S=0,E=[];if((m=(+o.apply(this,arguments)||0)/2)&&(v=n===Oo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=It(v/c*Math.sin(m))),s&&(M=It(v/s*Math.sin(m)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(h-S),_=c*Math.sin(h-S);var L=Math.abs(h-u-2*S)<=At?0:1;if(S&&Bo(y,x,b,_)===p^L){var C=(u+h)/2;y=c*Math.cos(C),x=c*Math.sin(C),b=_=null}}else y=x=0;if(s){w=s*Math.cos(h-M),k=s*Math.sin(h-M),T=s*Math.cos(u+M),A=s*Math.sin(u+M);var P=Math.abs(u-h+2*M)<=At?0:1;if(M&&Bo(w,k,T,A)===1-p^P){var O=(u+h)/2;w=s*Math.cos(O),k=s*Math.sin(O),T=A=null}}else w=k=0;if(f>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,I=d;if(f<At){var D=null==T?[w,k]:null==b?[y,x]:sa([y,x],[T,A],[b,_],[w,k]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),V=Math.sqrt(D[0]*D[0]+D[1]*D[1]);I=Math.min(d,(s-V)/(j-1)),z=Math.min(d,(c-V)/(j+1))}if(null!=b){var U=No(null==T?[w,k]:[T,A],[y,x],c,z,p),q=No([b,_],[w,k],c,z,p);d===z?E.push("M",U[0],"A",z,",",z," 0 0,",g," ",U[1],"A",c,",",c," 0 ",1-p^Bo(U[1][0],U[1][1],q[1][0],q[1][1]),",",p," ",q[1],"A",z,",",z," 0 0,",g," ",q[0]):E.push("M",U[0],"A",z,",",z," 0 1,",g," ",q[0])}else E.push("M",y,",",x);if(null!=T){var H=No([y,x],[T,A],s,-I,p),G=No([w,k],null==b?[y,x]:[b,_],s,-I,p);d===I?E.push("L",G[0],"A",I,",",I," 0 0,",g," ",G[1],"A",s,",",s," 0 ",p^Bo(G[1][0],G[1][1],H[1][0],H[1][1]),",",1-p," ",H[1],"A",I,",",I," 0 0,",g," ",H[0]):E.push("L",G[0],"A",I,",",I," 0 0,",g," ",H[0])}else E.push("L",w,",",k)}else E.push("M",y,",",x),null!=b&&E.push("A",c,",",c," 0 ",L,",",p," ",b,",",_),E.push("L",w,",",k),null!=T&&E.push("A",s,",",s," 0 ",P,",",1-p," ",T,",",A);return E.push("Z"),E.join("")}function l(t,e){return"M0,"+t+"A"+t+","+t+" 0 1,"+e+" 0,"+-t+"A"+t+","+t+" 0 1,"+e+" 0,"+t}return s.innerRadius=function(e){return arguments.length?(t=ve(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ve(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ve(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Oo?Oo:ve(t),s):n},s.startAngle=function(t){return arguments.length?(a=ve(t),s):a},s.endAngle=function(t){return arguments.length?(i=ve(t),s):i},s.padAngle=function(t){return arguments.length?(o=ve(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+a.apply(this,arguments)+ +i.apply(this,arguments))/2-Et;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Oo="auto";function zo(t){return t.innerRadius}function Io(t){return t.outerRadius}function Do(t){return t.startAngle}function Ro(t){return t.endAngle}function Fo(t){return t&&t.padAngle}function Bo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function No(t,e,r,n,a){var i=t[0]-e[0],o=t[1]-e[1],s=(a?n:-n)/Math.sqrt(i*i+o*o),l=s*o,c=-s*i,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,g=(h+p)/2,v=f-u,m=p-h,y=v*v+m*m,x=r-n,b=u*p-f*h,_=(m<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*m-v*_)/y,k=(-b*v-m*_)/y,T=(b*m+v*_)/y,A=(-b*v+m*_)/y,M=w-d,S=k-g,E=T-d,L=A-g;return M*M+S*S>E*E+L*L&&(w=T,k=A),[[w-l,k-c],[w*r/x,k*r/x]]}function jo(t){var e=ea,r=ra,n=Yr,a=Uo,i=a.key,o=.7;function s(i){var s,l=[],c=[],u=-1,h=i.length,f=ve(e),p=ve(r);function d(){l.push("M",a(t(c),o))}for(;++u<h;)n.call(this,s=i[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(""):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(i="function"==typeof t?a=t:(a=Vo.get(t)||Uo).key,s):i},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return jo(P)};var Vo=t.map({linear:Uo,"linear-closed":qo,step:function(t){var e=0,r=t.length,n=t[0],a=[n[0],",",n[1]];for(;++e<r;)a.push("H",(n[0]+(n=t[e])[0])/2,"V",n[1]);r>1&&a.push("H",n[0]);return a.join("")},"step-before":Ho,"step-after":Go,basis:Xo,"basis-open":function(t){if(t.length<4)return Uo(t);var e,r=[],n=-1,a=t.length,i=[0],o=[0];for(;++n<3;)e=t[n],i.push(e[0]),o.push(e[1]);r.push(Zo(Qo,i)+","+Zo(Qo,o)),--n;for(;++n<a;)e=t[n],i.shift(),i.push(e[0]),o.shift(),o.push(e[1]),$o(r,i,o);return r.join("")},"basis-closed":function(t){var e,r,n=-1,a=t.length,i=a+4,o=[],s=[];for(;++n<4;)r=t[n%a],o.push(r[0]),s.push(r[1]);e=[Zo(Qo,o),",",Zo(Qo,s)],--n;for(;++n<i;)r=t[n%a],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),$o(e,o,s);return e.join("")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,a,i=t[0][0],o=t[0][1],s=t[r][0]-i,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],a=c/r,n[0]=e*n[0]+(1-e)*(i+a*s),n[1]=e*n[1]+(1-e)*(o+a*l);return Xo(t)},cardinal:function(t,e){return t.length<3?Uo(t):t[0]+Yo(t,Wo(t,e))},"cardinal-open":function(t,e){return t.length<4?Uo(t):t[1]+Yo(t.slice(1,-1),Wo(t,e))},"cardinal-closed":function(t,e){return t.length<3?qo(t):t[0]+Yo((t.push(t[0]),t),Wo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Uo(t):t[0]+Yo(t,function(t){var e,r,n,a,i=[],o=function(t){var e=0,r=t.length-1,n=[],a=t[0],i=t[1],o=n[0]=ts(a,i);for(;++e<r;)n[e]=(o+(o=ts(a=i,i=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=ts(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(a=r*r+n*n)>9&&(a=3*e/Math.sqrt(a),o[s]=a*r,o[s+1]=a*n));s=-1;for(;++s<=l;)a=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),i.push([a||0,o[s]*a||0]);return i}(t))}});function Uo(t){return t.length>1?t.join("L"):t+"Z"}function qo(t){return t.join("L")+"Z"}function Ho(t){for(var e=0,r=t.length,n=t[0],a=[n[0],",",n[1]];++e<r;)a.push("V",(n=t[e])[1],"H",n[0]);return a.join("")}function Go(t){for(var e=0,r=t.length,n=t[0],a=[n[0],",",n[1]];++e<r;)a.push("H",(n=t[e])[0],"V",n[1]);return a.join("")}function Yo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Uo(t);var r=t.length!=e.length,n="",a=t[0],i=t[1],o=e[0],s=o,l=1;if(r&&(n+="Q"+(i[0]-2*o[0]/3)+","+(i[1]-2*o[1]/3)+","+i[0]+","+i[1],a=t[1],l=2),e.length>1){s=e[1],i=t[l],l++,n+="C"+(a[0]+o[0])+","+(a[1]+o[1])+","+(i[0]-s[0])+","+(i[1]-s[1])+","+i[0]+","+i[1];for(var c=2;c<e.length;c++,l++)i=t[l],s=e[c],n+="S"+(i[0]-s[0])+","+(i[1]-s[1])+","+i[0]+","+i[1]}if(r){var u=t[l];n+="Q"+(i[0]+2*s[0]/3)+","+(i[1]+2*s[1]/3)+","+u[0]+","+u[1]}return n}function Wo(t,e){for(var r,n=[],a=(1-e)/2,i=t[0],o=t[1],s=1,l=t.length;++s<l;)r=i,i=o,o=t[s],n.push([a*(o[0]-r[0]),a*(o[1]-r[1])]);return n}function Xo(t){if(t.length<3)return Uo(t);var e=1,r=t.length,n=t[0],a=n[0],i=n[1],o=[a,a,a,(n=t[1])[0]],s=[i,i,i,n[1]],l=[a,",",i,"L",Zo(Qo,o),",",Zo(Qo,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),$o(l,o,s);return t.pop(),l.push("L",n),l.join("")}function Zo(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Vo.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Jo=[0,2/3,1/3,0],Ko=[0,1/3,2/3,0],Qo=[0,1/6,2/3,1/6];function $o(t,e,r){t.push("C",Zo(Jo,e),",",Zo(Jo,r),",",Zo(Ko,e),",",Zo(Ko,r),",",Zo(Qo,e),",",Zo(Qo,r))}function ts(t,e){return(e[1]-t[1])/(e[0]-t[0])}function es(t){for(var e,r,n,a=-1,i=t.length;++a<i;)r=(e=t[a])[0],n=e[1]-Et,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function rs(t){var e=ea,r=ea,n=0,a=ra,i=Yr,o=Uo,s=o.key,l=o,c="L",u=.7;function h(s){var h,f,p,d=[],g=[],v=[],m=-1,y=s.length,x=ve(e),b=ve(n),_=e===r?function(){return f}:ve(r),w=n===a?function(){return p}:ve(a);function k(){d.push("M",o(t(v),u),c,l(t(g.reverse()),u),"Z")}for(;++m<y;)i.call(this,h=s[m],m)?(g.push([f=+x.call(this,h,m),p=+b.call(this,h,m)]),v.push([+_.call(this,h,m),+w.call(this,h,m)])):g.length&&(k(),g=[],v=[]);return g.length&&k(),d.length?d.join(""):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=a=t,h):a},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(a=t,h):a},h.defined=function(t){return arguments.length?(i=t,h):i},h.interpolate=function(t){return arguments.length?(s="function"==typeof t?o=t:(o=Vo.get(t)||Uo).key,l=o.reverse||o,c=o.closed?"M":"L",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function ns(t){return t.radius}function as(t){return[t.x,t.y]}function is(){return 64}function os(){return"circle"}function ss(t){var e=Math.sqrt(t/At);return"M0,"+e+"A"+e+","+e+" 0 1,1 0,"+-e+"A"+e+","+e+" 0 1,1 0,"+e+"Z"}t.svg.line.radial=function(){var t=jo(es);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Ho.reverse=Go,Go.reverse=Ho,t.svg.area=function(){return rs(P)},t.svg.area.radial=function(){var t=rs(es);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Vn,e=Un,r=ns,n=Do,a=Ro;function i(r,n){var a,i,c=o(this,t,r,n),u=o(this,e,r,n);return"M"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(i=u,(a=c).a0==i.a0&&a.a1==i.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+"Z"}function o(t,e,i,o){var s=e.call(t,i,o),l=r.call(t,s,o),c=n.call(t,s,o)-Et,u=a.call(t,s,o)-Et;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return"A"+t+","+t+" 0 "+ +(r>At)+",1 "+e}function l(t,e,r,n){return"Q 0,0 "+n}return i.radius=function(t){return arguments.length?(r=ve(t),i):r},i.source=function(e){return arguments.length?(t=ve(e),i):t},i.target=function(t){return arguments.length?(e=ve(t),i):e},i.startAngle=function(t){return arguments.length?(n=ve(t),i):n},i.endAngle=function(t){return arguments.length?(a=ve(t),i):a},i},t.svg.diagonal=function(){var t=Vn,e=Un,r=as;function n(n,a){var i=t.call(this,n,a),o=e.call(this,n,a),s=(i.y+o.y)/2,l=[i,{x:i.x,y:s},{x:o.x,y:s},o];return"M"+(l=l.map(r))[0]+"C"+l[1]+" "+l[2]+" "+l[3]}return n.source=function(e){return arguments.length?(t=ve(e),n):t},n.target=function(t){return arguments.length?(e=ve(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=as,n=e.projection;return e.projection=function(t){return arguments.length?n(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Et;return[r*Math.cos(n),r*Math.sin(n)]}}(r=t)):r},e},t.svg.symbol=function(){var t=os,e=is;function r(r,n){return(ls.get(t.call(this,r,n))||ss)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ve(e),r):t},r.size=function(t){return arguments.length?(e=ve(t),r):e},r};var ls=t.map({circle:ss,cross:function(t){var e=Math.sqrt(t/5)/2;return"M"+-3*e+","+-e+"H"+-e+"V"+-3*e+"H"+e+"V"+-e+"H"+3*e+"V"+e+"H"+e+"V"+3*e+"H"+-e+"V"+e+"H"+-3*e+"Z"},diamond:function(t){var e=Math.sqrt(t/(2*us)),r=e*us;return"M0,"+-e+"L"+r+",0 0,"+e+" "+-r+",0Z"},square:function(t){var e=Math.sqrt(t)/2;return"M"+-e+","+-e+"L"+e+","+-e+" "+e+","+e+" "+-e+","+e+"Z"},"triangle-down":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return"M0,"+r+"L"+e+","+-r+" "+-e+","+-r+"Z"},"triangle-up":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return"M0,"+-r+"L"+e+","+r+" "+-e+","+r+"Z"}});t.svg.symbolTypes=ls.keys();var cs=Math.sqrt(3),us=Math.tan(30*Lt);W.transition=function(t){for(var e,r,n=ds||++ms,a=bs(t),i=[],o=gs||{time:Date.now(),ease:ai,delay:0,duration:250},s=-1,l=this.length;++s<l;){i.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&_s(r,u,a,n,o),e.push(r)}return ps(i,a,n)},W.interrupt=function(t){return this.each(null==t?hs:fs(bs(t)))};var hs=fs(bs());function fs(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function ps(t,e,r){return U(t,vs),t.namespace=e,t.id=r,t}var ds,gs,vs=[],ms=0;function ys(t,e,r,n){var a=t.id,i=t.namespace;return ut(t,"function"==typeof r?function(t,o,s){t[i][a].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[i][a].tween.set(e,r)}))}function xs(t){return null==t&&(t=""),function(){this.textContent=t}}function bs(t){return null==t?"__transition__":"__transition_"+t+"__"}function _s(t,e,r,n,a){var i,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var a=u.active,f=u[a];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[a],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,Te(function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1},0,i),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach(function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)}),l=h.ease,s=h.duration}function p(a){for(var i=a/s,o=l(i),f=c.length;f>0;)c[--f].call(t,o);if(i>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(i=a.time,o=Te(function(t){var e=h.delay;if(o.t=e+i,e<=t)return f(t-e);o.c=f},0,i),h=u[n]={tween:new b,time:i,timer:o,delay:a.delay,duration:a.duration,ease:a.ease,index:e},a=null,++u.count)}vs.call=W.call,vs.empty=W.empty,vs.node=W.node,vs.size=W.size,t.transition=function(e,r){return e&&e.transition?ds?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=vs,vs.select=function(t){var e,r,n,a=this.id,i=this.namespace,o=[];t=X(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?("__data__"in n&&(r.__data__=n.__data__),_s(r,u,i,a,n[i][a]),e.push(r)):e.push(null)}return ps(o,i,a)},vs.selectAll=function(t){var e,r,n,a,i,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){i=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(a=r[d])&&_s(a,d,s,o,i),e.push(a)}return ps(l,s,o)},vs.filter=function(t){var e,r,n=[];"function"!=typeof t&&(t=ct(t));for(var a=0,i=this.length;a<i;a++){n.push(e=[]);for(var o,s=0,l=(o=this[a]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,a)&&e.push(r)}return ps(n,this.namespace,this.id)},vs.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(a){a[n][r].tween.set(t,e)})},vs.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n="transform"==e?gi:Za,a=t.ns.qualify(e);function i(){this.removeAttribute(a)}function o(){this.removeAttributeNS(a.space,a.local)}return ys(this,"attr."+e,r,a.local?function(t){return null==t?o:(t+="",function(){var e,r=this.getAttributeNS(a.space,a.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(a.space,a.local,e(t))})})}:function(t){return null==t?i:(t+="",function(){var e,r=this.getAttribute(a);return r!==t&&(e=n(r,t),function(t){this.setAttribute(a,e(t))})})})},vs.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween("attr."+e,n.local?function(t,e){var a=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return a&&function(t){this.setAttributeNS(n.space,n.local,a(t))}}:function(t,e){var a=r.call(this,t,e,this.getAttribute(n));return a&&function(t){this.setAttribute(n,a(t))}})},vs.style=function(t,e,r){var n=arguments.length;if(n<3){if("string"!=typeof t){for(r in n<2&&(e=""),t)this.style(r,t[r],e);return this}r=""}function a(){this.style.removeProperty(t)}return ys(this,"style."+t,e,function(e){return null==e?a:(e+="",function(){var n,a=o(this).getComputedStyle(this,null).getPropertyValue(t);return a!==e&&(n=Za(a,e),function(e){this.style.setProperty(t,n(e),r)})})})},vs.styleTween=function(t,e,r){return arguments.length<3&&(r=""),this.tween("style."+t,function(n,a){var i=e.call(this,n,a,o(this).getComputedStyle(this,null).getPropertyValue(t));return i&&function(e){this.style.setProperty(t,i(e),r)}})},vs.text=function(t){return ys(this,"text",t,xs)},vs.remove=function(){var t=this.namespace;return this.each("end.transition",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},vs.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:("function"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,function(t){t[n][r].ease=e}))},vs.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,"function"==typeof t?function(n,a,i){n[r][e].delay=+t.call(n,n.__data__,a,i)}:(t=+t,function(n){n[r][e].delay=t}))},vs.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,"function"==typeof t?function(n,a,i){n[r][e].duration=Math.max(1,t.call(n,n.__data__,a,i))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},vs.each=function(e,r){var n=this.id,a=this.namespace;if(arguments.length<2){var i=gs,o=ds;try{ds=n,ut(this,function(t,r,i){gs=t[a][n],e.call(t,t.__data__,r,i)})}finally{gs=i,ds=o}}else ut(this,function(i){var o=i[a][n];(o.event||(o.event=t.dispatch("start","end","interrupt"))).on(e,r)});return this},vs.transition=function(){for(var t,e,r,n=this.id,a=++ms,i=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&_s(e,u,i,a,{time:(r=e[i][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return ps(o,i,a)},t.svg.axis=function(){var e,r=t.scale.linear(),a=ws,i=6,o=6,s=3,l=[10],c=null;function u(n){n.each(function(){var n,u=t.select(this),h=this.__chart__||r,f=this.__chart__=r.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==e?f.tickFormat?f.tickFormat.apply(f,l):P:e,g=u.selectAll(".tick").data(p,f),v=g.enter().insert("g",".domain").attr("class","tick").style("opacity",kt),m=t.transition(g.exit()).style("opacity",kt).remove(),y=t.transition(g.order()).style("opacity",1),x=Math.max(i,0)+s,b=uo(f),_=u.selectAll(".domain").data([0]),w=(_.enter().append("path").attr("class","domain"),t.transition(_));v.append("line"),v.append("text");var k,T,A,M,S=v.select("line"),E=y.select("line"),L=g.select("text").text(d),C=v.select("text"),O=y.select("text"),z="top"===a||"left"===a?-1:1;if("bottom"===a||"top"===a?(n=Ts,k="x",A="y",T="x2",M="y2",L.attr("dy",z<0?"0em":".71em").style("text-anchor","middle"),w.attr("d","M"+b[0]+","+z*o+"V0H"+b[1]+"V"+z*o)):(n=As,k="y",A="x",T="y2",M="x2",L.attr("dy",".32em").style("text-anchor",z<0?"end":"start"),w.attr("d","M"+z*o+","+b[0]+"H0V"+b[1]+"H"+z*o)),S.attr(M,z*i),C.attr(A,z*x),E.attr(T,0).attr(M,z*i),O.attr(k,0).attr(A,z*x),f.rangeBand){var I=f,D=I.rangeBand()/2;h=f=function(t){return I(t)+D}}else h.rangeBand?h=f:m.call(n,f,h);v.call(n,h,f),y.call(n,f,f)})}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(a=t in ks?t+"":ws,u):a},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(i=+t,o=+arguments[e-1],u):i},u.innerTickSize=function(t){return arguments.length?(i=+t,u):i},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var ws="bottom",ks={top:1,right:1,bottom:1,left:1};function Ts(t,e,r){t.attr("transform",function(t){var n=e(t);return"translate("+(isFinite(n)?n:r(t))+",0)"})}function As(t,e,r){t.attr("transform",function(t){var n=e(t);return"translate(0,"+(isFinite(n)?n:r(t))+")"})}t.svg.brush=function(){var e,r,n=j(f,"brushstart","brush","brushend"),a=null,i=null,s=[0,0],l=[0,0],c=!0,u=!0,h=Ss[0];function f(e){e.each(function(){var e=t.select(this).style("pointer-events","all").style("-webkit-tap-highlight-color","rgba(0,0,0,0)").on("mousedown.brush",v).on("touchstart.brush",v),r=e.selectAll(".background").data([0]);r.enter().append("rect").attr("class","background").style("visibility","hidden").style("cursor","crosshair"),e.selectAll(".extent").data([0]).enter().append("rect").attr("class","extent").style("cursor","move");var n=e.selectAll(".resize").data(h,P);n.exit().remove(),n.enter().append("g").attr("class",function(t){return"resize "+t}).style("cursor",function(t){return Ms[t]}).append("rect").attr("x",function(t){return/[ew]$/.test(t)?-3:null}).attr("y",function(t){return/^[ns]/.test(t)?-3:null}).attr("width",6).attr("height",6).style("visibility","hidden"),n.style("display",f.empty()?"none":null);var o,s=t.transition(e),l=t.transition(r);a&&(o=uo(a),l.attr("x",o[0]).attr("width",o[1]-o[0]),d(s)),i&&(o=uo(i),l.attr("y",o[0]).attr("height",o[1]-o[0]),g(s)),p(s)})}function p(t){t.selectAll(".resize").attr("transform",function(t){return"translate("+s[+/e$/.test(t)]+","+l[+/^s/.test(t)]+")"})}function d(t){t.select(".extent").attr("x",s[0]),t.selectAll(".extent,.n>rect,.s>rect").attr("width",s[1]-s[0])}function g(t){t.select(".extent").attr("y",l[0]),t.selectAll(".extent,.e>rect,.w>rect").attr("height",l[1]-l[0])}function v(){var h,v,m=this,y=t.select(t.event.target),x=n.of(m,arguments),b=t.select(m),_=y.datum(),w=!/^(n|s)$/.test(_)&&a,k=!/^(e|w)$/.test(_)&&i,T=y.classed("extent"),A=xt(m),M=t.mouse(m),S=t.select(o(m)).on("keydown.brush",function(){32==t.event.keyCode&&(T||(h=null,M[0]-=s[1],M[1]-=l[1],T=2),B())}).on("keyup.brush",function(){32==t.event.keyCode&&2==T&&(M[0]+=s[1],M[1]+=l[1],T=0,B())});if(t.event.changedTouches?S.on("touchmove.brush",C).on("touchend.brush",O):S.on("mousemove.brush",C).on("mouseup.brush",O),b.interrupt().selectAll("*").interrupt(),T)M[0]=s[0]-M[0],M[1]=l[0]-M[1];else if(_){var E=+/w$/.test(_),L=+/^n/.test(_);v=[s[1-E]-M[0],l[1-L]-M[1]],M[0]=s[E],M[1]=l[L]}else t.event.altKey&&(h=M.slice());function C(){var e=t.mouse(m),r=!1;v&&(e[0]+=v[0],e[1]+=v[1]),T||(t.event.altKey?(h||(h=[(s[0]+s[1])/2,(l[0]+l[1])/2]),M[0]=s[+(e[0]<h[0])],M[1]=l[+(e[1]<h[1])]):h=null),w&&P(e,a,0)&&(d(b),r=!0),k&&P(e,i,1)&&(g(b),r=!0),r&&(p(b),x({type:"brush",mode:T?"move":"resize"}))}function P(t,n,a){var i,o,f=uo(n),p=f[0],d=f[1],g=M[a],v=a?l:s,m=v[1]-v[0];if(T&&(p-=g,d-=m+g),i=(a?u:c)?Math.max(p,Math.min(d,t[a])):t[a],T?o=(i+=g)+m:(h&&(g=Math.max(p,Math.min(d,2*h[a]-i))),g<i?(o=i,i=g):o=g),v[0]!=i||v[1]!=o)return a?r=null:e=null,v[0]=i,v[1]=o,!0}function O(){C(),b.style("pointer-events","all").selectAll(".resize").style("display",f.empty()?"none":null),t.select("body").style("cursor",null),S.on("mousemove.brush",null).on("mouseup.brush",null).on("touchmove.brush",null).on("touchend.brush",null).on("keydown.brush",null).on("keyup.brush",null),A(),x({type:"brushend"})}b.style("pointer-events","none").selectAll(".resize").style("display",null),t.select("body").style("cursor",y.style("cursor")),x({type:"brushstart"}),C()}return f.event=function(a){a.each(function(){var a=n.of(this,arguments),i={x:s,y:l,i:e,j:r},o=this.__chart__||i;this.__chart__=i,ds?t.select(this).transition().each("start.brush",function(){e=o.i,r=o.j,s=o.x,l=o.y,a({type:"brushstart"})}).tween("brush:brush",function(){var t=Ja(s,i.x),n=Ja(l,i.y);return e=r=null,function(e){s=i.x=t(e),l=i.y=n(e),a({type:"brush",mode:"resize"})}}).each("end.brush",function(){e=i.i,r=i.j,a({type:"brush",mode:"resize"}),a({type:"brushend"})}):(a({type:"brushstart"}),a({type:"brush",mode:"resize"}),a({type:"brushend"}))})},f.x=function(t){return arguments.length?(h=Ss[!(a=t)<<1|!i],f):a},f.y=function(t){return arguments.length?(h=Ss[!a<<1|!(i=t)],f):i},f.clamp=function(t){return arguments.length?(a&&i?(c=!!t[0],u=!!t[1]):a?c=!!t:i&&(u=!!t),f):a&&i?[c,u]:a?c:i?u:null},f.extent=function(t){var n,o,c,u,h;return arguments.length?(a&&(n=t[0],o=t[1],i&&(n=n[0],o=o[0]),e=[n,o],a.invert&&(n=a(n),o=a(o)),o<n&&(h=n,n=o,o=h),n==s[0]&&o==s[1]||(s=[n,o])),i&&(c=t[0],u=t[1],a&&(c=c[1],u=u[1]),r=[c,u],i.invert&&(c=i(c),u=i(u)),u<c&&(h=c,c=u,u=h),c==l[0]&&u==l[1]||(l=[c,u])),f):(a&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],a.invert&&(n=a.invert(n),o=a.invert(o)),o<n&&(h=n,n=o,o=h))),i&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],i.invert&&(c=i.invert(c),u=i.invert(u)),u<c&&(h=c,c=u,u=h))),a&&i?[[n,c],[o,u]]:a?[n,o]:i&&[c,u])},f.clear=function(){return f.empty()||(s=[0,0],l=[0,0],e=r=null),f},f.empty=function(){return!!a&&s[0]==s[1]||!!i&&l[0]==l[1]},t.rebind(f,n,"on")};var Ms={n:"ns-resize",e:"ew-resize",s:"ns-resize",w:"ew-resize",nw:"nwse-resize",ne:"nesw-resize",se:"nwse-resize",sw:"nesw-resize"},Ss=[["n","e","s","w","nw","ne","se","sw"],["e","w"],["n","s"],[]],Es=ze.format=sr.timeFormat,Ls=Es.utc,Cs=Ls("%Y-%m-%dT%H:%M:%S.%LZ");function Ps(t){return t.toISOString()}function Os(e,r,n){function a(t){return e(t)}function i(e,n){var a=(e[1]-e[0])/n,i=t.bisect(Is,a);return i==Is.length?[r.year,xo(e.map(function(t){return t/31536e6}),n)[2]]:i?r[a/Is[i-1]<Is[i]/a?i-1:i]:[Fs,xo(e,n)[2]]}return a.invert=function(t){return zs(e.invert(t))},a.domain=function(t){return arguments.length?(e.domain(t),a):e.domain().map(zs)},a.nice=function(t,e){var r=a.domain(),n=co(r),o=null==t?i(n,10):"number"==typeof t&&i(n,t);function s(r){return!isNaN(r)&&!t.range(r,zs(+r+1),e).length}return o&&(t=o[0],e=o[1]),a.domain(fo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=zs(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=zs(+e+1);return e}}:t))},a.ticks=function(t,e){var r=co(a.domain()),n=null==t?i(r,10):"number"==typeof t?i(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],zs(+r[1]+1),e<1?1:e)},a.tickFormat=function(){return n},a.copy=function(){return Os(e.copy(),r,n)},mo(a,e)}function zs(t){return new Date(t)}Es.iso=Date.prototype.toISOString&&+new Date("2000-01-01T00:00:00.000Z")?Ps:Cs,Ps.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Ps.toString=Cs.toString,ze.second=Fe(function(t){return new Ie(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ze.seconds=ze.second.range,ze.seconds.utc=ze.second.utc.range,ze.minute=Fe(function(t){return new Ie(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ze.minutes=ze.minute.range,ze.minutes.utc=ze.minute.utc.range,ze.hour=Fe(function(t){var e=t.getTimezoneOffset()/60;return new Ie(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ze.hours=ze.hour.range,ze.hours.utc=ze.hour.utc.range,ze.month=Fe(function(t){return(t=ze.day(t)).setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ze.months=ze.month.range,ze.months.utc=ze.month.utc.range;var Is=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Ds=[[ze.second,1],[ze.second,5],[ze.second,15],[ze.second,30],[ze.minute,1],[ze.minute,5],[ze.minute,15],[ze.minute,30],[ze.hour,1],[ze.hour,3],[ze.hour,6],[ze.hour,12],[ze.day,1],[ze.day,2],[ze.week,1],[ze.month,1],[ze.month,3],[ze.year,1]],Rs=Es.multi([[".%L",function(t){return t.getMilliseconds()}],[":%S",function(t){return t.getSeconds()}],["%I:%M",function(t){return t.getMinutes()}],["%I %p",function(t){return t.getHours()}],["%a %d",function(t){return t.getDay()&&1!=t.getDate()}],["%b %d",function(t){return 1!=t.getDate()}],["%B",function(t){return t.getMonth()}],["%Y",Yr]]),Fs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(zs)},floor:P,ceil:P};Ds.year=ze.year,ze.scale=function(){return Os(t.scale.linear(),Ds,Rs)};var Bs=Ds.map(function(t){return[t[0].utc,t[1]]}),Ns=Ls.multi([[".%L",function(t){return t.getUTCMilliseconds()}],[":%S",function(t){return t.getUTCSeconds()}],["%I:%M",function(t){return t.getUTCMinutes()}],["%I %p",function(t){return t.getUTCHours()}],["%a %d",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],["%b %d",function(t){return 1!=t.getUTCDate()}],["%B",function(t){return t.getUTCMonth()}],["%Y",Yr]]);function js(t){return JSON.parse(t.responseText)}function Vs(t){var e=a.createRange();return e.selectNode(a.body),e.createContextualFragment(t.responseText)}Bs.year=ze.year.utc,ze.scale.utc=function(){return Os(t.scale.linear(),Bs,Ns)},t.text=me(function(t){return t.responseText}),t.json=function(t,e){return ye(t,"application/json",js,e)},t.html=function(t,e){return ye(t,"text/html",Vs,e)},t.xml=me(function(t){return t.responseXML}),"object"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],165:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],166:[function(t,e,r){"use strict";var n=t("incremental-convex-hull"),a=t("uniq");function i(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,a=r.length,i=0;i<a;++i){var o=n[i]-r[i];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map(function(t,e){return[t[0],e]});n.sort(function(t,e){return t[0]-e[0]});for(var a=new Array(t-1),i=1;i<t;++i){var o=n[i-1],s=n[i];a[i-1]=[o[1],s[1]]}r&&a.push([-1,a[0][1]],[a[t-1][1],-1]);return a}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var g=h[d];f[d]=g,p+=g*g}f[s]=p,l[u]=new i(f,u),c=Math.max(p,c)}a(l,o),r=l.length;for(var v=new Array(r+s+1),m=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1),u=0;u<=s;++u)x[u]=0;x[s]=y,v[0]=x.slice(),m[0]=-1;for(var u=0;u<=s;++u){var f=x.slice();f[u]=1,v[u+1]=f,m[u+1]=-1}for(var u=0;u<r;++u){var b=l[u];v[u+s+1]=b.point,m[u+s+1]=b.index}var _=n(v,!1);_=e?_.filter(function(t){for(var e=0,r=0;r<=s;++r){var n=m[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0}):_.filter(function(t){for(var e=0;e<=s;++e){var r=m[t[e]];if(r<0)return!1;t[e]=r}return!0});if(1&s)for(var u=0;u<_.length;++u){var b=_[u],f=b[0];b[0]=b[1],b[1]=f}return _}},{"incremental-convex-hull":414,uniq:545}],167:[function(t,e,r){"use strict";e.exports=i;var n=(i.canvas=document.createElement("canvas")).getContext("2d"),a=o([32,126]);function i(t,e){Array.isArray(t)&&(t=t.join(", "));var r,i={},s=16,l=.05;e&&(2===e.length&&"number"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=a),n.font=s+"px "+t;for(var c=0;c<r.length;c++){var u=r[c],h=n.measureText(u[0]).width+n.measureText(u[1]).width,f=n.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;i[u]=1e3*p}}return i}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),a=t[0];a<t[1];a++){var i=n+String.fromCharCode(a);e.push(i)}return e}i.createPairs=o,i.ascii=a},{}],168:[function(t,e,r){(function(t){var r=!1;if("undefined"!=typeof Float64Array){var n=new Float64Array(1),a=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===a[1]){e.exports=function(t){return n[0]=t,[a[0],a[1]]},e.exports.pack=function(t,e){return a[0]=t,a[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,a[0]},e.exports.hi=function(t){return n[0]=t,a[1]}}else if(1072693248===a[0]){e.exports=function(t){return n[0]=t,[a[1],a[0]]},e.exports.pack=function(t,e){return a[1]=t,a[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,a[1]},e.exports.hi=function(t){return n[0]=t,a[0]}}else r=!1}if(!r){var i=new t(8);e.exports=function(t){return i.writeDoubleLE(t,0,!0),[i.readUInt32LE(0,!0),i.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return i.writeUInt32LE(t,0,!0),i.writeUInt32LE(e,4,!0),i.readDoubleLE(0,!0)},e.exports.lo=function(t){return i.writeDoubleLE(t,0,!0),i.readUInt32LE(0,!0)},e.exports.hi=function(t){return i.writeDoubleLE(t,0,!0),i.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),a=1048575&n;return 2146435072&n&&(a+=1<<20),[r,a]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t("buffer").Buffer)},{buffer:106}],169:[function(t,e,r){var n=t("abs-svg-path"),a=t("normalize-svg-path"),i={M:"moveTo",C:"bezierCurveTo"};e.exports=function(t,e){t.beginPath(),a(n(e)).forEach(function(e){var r=e[0],n=e.slice(1);t[i[r]].apply(t,n)}),t.closePath()}},{"abs-svg-path":62,"normalize-svg-path":453}],170:[function(t,e,r){e.exports=function(t){switch(t){case"int8":return Int8Array;case"int16":return Int16Array;case"int32":return Int32Array;case"uint8":return Uint8Array;case"uint16":return Uint16Array;case"uint32":return Uint32Array;case"float32":return Float32Array;case"float64":return Float64Array;case"array":return Array;case"uint8_clamped":return Uint8ClampedArray}}},{}],171:[function(t,e,r){"use strict";e.exports=function(t,e){switch("undefined"==typeof e&&(e=0),typeof t){case"number":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case"object":if("number"==typeof t.length)return function t(e,r,n){var a=0|e[n];if(a<=0)return[];var i,o=new Array(a);if(n===e.length-1)for(i=0;i<a;++i)o[i]=r;else for(i=0;i<a;++i)o[i]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],172:[function(t,e,r){"use strict";function n(t,e,r){r=r||2;var n,s,l,c,u,p,d,v=e&&e.length,m=v?e[0]*r:t.length,y=a(t,0,m,r,!0),x=[];if(!y||y.next===y.prev)return x;if(v&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=a(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(g(u));for(p.sort(h),o=0;o<p.length;o++)f(p[o],r),r=i(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<m;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);d=0!==(d=Math.max(l-n,c-s))?1/d:0}return o(y,x,r,n,s,d),x}function a(t,e,r,n,a){var i,o;if(a===E(t,e,r,n)>0)for(i=e;i<r;i+=n)o=A(i,t[i],t[i+1],o);else for(i=r-n;i>=e;i-=n)o=A(i,t[i],t[i+1],o);return o&&x(o,o.next)&&(M(o),o=o.next),o}function i(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!x(n,n.next)&&0!==y(n.prev,n,n.next))n=n.next;else{if(M(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,a,h,f){if(t){!f&&h&&function(t,e,r,n){var a=t;do{null===a.z&&(a.z=d(a.x,a.y,e,r,n)),a.prevZ=a.prev,a.nextZ=a.next,a=a.next}while(a!==t);a.prevZ.nextZ=null,a.prevZ=null,function(t){var e,r,n,a,i,o,s,l,c=1;do{for(r=t,t=null,i=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(a=r,r=r.nextZ,s--):(a=n,n=n.nextZ,l--),i?i.nextZ=a:t=a,a.prevZ=i,i=a;r=n}i.nextZ=null,c*=2}while(o>1)}(a)}(t,n,a,h);for(var p,g,v=t;t.prev!==t.next;)if(p=t.prev,g=t.next,h?l(t,n,a,h):s(t))e.push(p.i/r),e.push(t.i/r),e.push(g.i/r),M(t),t=g.next,v=g.next;else if((t=g)===v){f?1===f?o(t=c(i(t),e,r),e,r,n,a,h,2):2===f&&u(t,e,r,n,a,h):o(i(t),e,r,n,a,h,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(y(e,r,n)>=0)return!1;for(var a=t.next.next;a!==t.prev;){if(v(e.x,e.y,r.x,r.y,n.x,n.y,a.x,a.y)&&y(a.prev,a,a.next)>=0)return!1;a=a.next}return!0}function l(t,e,r,n){var a=t.prev,i=t,o=t.next;if(y(a,i,o)>=0)return!1;for(var s=a.x<i.x?a.x<o.x?a.x:o.x:i.x<o.x?i.x:o.x,l=a.y<i.y?a.y<o.y?a.y:o.y:i.y<o.y?i.y:o.y,c=a.x>i.x?a.x>o.x?a.x:o.x:i.x>o.x?i.x:o.x,u=a.y>i.y?a.y>o.y?a.y:o.y:i.y>o.y?i.y:o.y,h=d(s,l,e,r,n),f=d(c,u,e,r,n),p=t.prevZ,g=t.nextZ;p&&p.z>=h&&g&&g.z<=f;){if(p!==t.prev&&p!==t.next&&v(a.x,a.y,i.x,i.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,g!==t.prev&&g!==t.next&&v(a.x,a.y,i.x,i.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&v(a.x,a.y,i.x,i.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;g&&g.z<=f;){if(g!==t.prev&&g!==t.next&&v(a.x,a.y,i.x,i.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}return!0}function c(t,e,r){var n=t;do{var a=n.prev,o=n.next.next;!x(a,o)&&b(a,n,n.next,o)&&k(a,o)&&k(o,a)&&(e.push(a.i/r),e.push(n.i/r),e.push(o.i/r),M(n),M(n.next),n=t=o),n=n.next}while(n!==t);return i(n)}function u(t,e,r,n,a,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&m(l,c)){var u=T(l,c);return l=i(l,l.next),u=i(u,u.next),o(l,e,r,n,a,s),void o(u,e,r,n,a,s)}c=c.next}l=l.next}while(l!==t)}function h(t,e){return t.x-e.x}function f(t,e){if(e=function(t,e){var r,n=e,a=t.x,i=t.y,o=-1/0;do{if(i<=n.y&&i>=n.next.y&&n.next.y!==n.y){var s=n.x+(i-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=a&&s>o){if(o=s,s===a){if(i===n.y)return n;if(i===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(a===o)return r;var l,c=r,u=r.x,h=r.y,f=1/0;n=r;do{a>=n.x&&n.x>=u&&a!==n.x&&v(i<h?a:o,i,u,h,i<h?o:a,i,n.x,n.y)&&(l=Math.abs(i-n.y)/(a-n.x),k(n,t)&&(l<f||l===f&&(n.x>r.x||n.x===r.x&&p(r,n)))&&(r=n,f=l)),n=n.next}while(n!==c);return r}(t,e)){var r=T(e,t);i(r,r.next)}}function p(t,e){return y(t.prev,t,e.prev)<0&&y(e.next,t,t.next)<0}function d(t,e,r,n,a){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*a)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*a)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function g(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function v(t,e,r,n,a,i,o,s){return(a-o)*(e-s)-(t-o)*(i-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(i-s)-(a-o)*(n-s)>=0}function m(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&b(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(k(t,e)&&k(e,t)&&function(t,e){var r=t,n=!1,a=(t.x+e.x)/2,i=(t.y+e.y)/2;do{r.y>i!=r.next.y>i&&r.next.y!==r.y&&a<(r.next.x-r.x)*(i-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(y(t.prev,t,e.prev)||y(t,e.prev,e))||x(t,e)&&y(t.prev,t,t.next)>0&&y(e.prev,e,e.next)>0)}function y(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function x(t,e){return t.x===e.x&&t.y===e.y}function b(t,e,r,n){var a=w(y(t,e,r)),i=w(y(t,e,n)),o=w(y(r,n,t)),s=w(y(r,n,e));return a!==i&&o!==s||(!(0!==a||!_(t,r,e))||(!(0!==i||!_(t,n,e))||(!(0!==o||!_(r,t,n))||!(0!==s||!_(r,e,n)))))}function _(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function w(t){return t>0?1:t<0?-1:0}function k(t,e){return y(t.prev,t,t.next)<0?y(t,e,t.next)>=0&&y(t,t.prev,e)>=0:y(t,e,t.prev)<0||y(t,t.next,e)<0}function T(t,e){var r=new S(t.i,t.x,t.y),n=new S(e.i,e.x,e.y),a=t.next,i=e.prev;return t.next=e,e.prev=t,r.next=a,a.prev=r,n.next=r,r.prev=n,i.next=n,n.prev=i,n}function A(t,e,r,n){var a=new S(t,e,r);return n?(a.next=n.next,a.prev=n,n.next.prev=a,n.next=a):(a.prev=a,a.next=a),a}function M(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function S(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function E(t,e,r,n){for(var a=0,i=e,o=r-n;i<r;i+=n)a+=(t[o]-t[i])*(t[i+1]+t[o+1]),o=i;return a}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var a=e&&e.length,i=a?e[0]*r:t.length,o=Math.abs(E(t,0,i,r));if(a)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(E(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,a=0;a<t.length;a++){for(var i=0;i<t[a].length;i++)for(var o=0;o<e;o++)r.vertices.push(t[a][i][o]);a>0&&(n+=t[a-1].length,r.holes.push(n))}return r}},{}],173:[function(t,e,r){"use strict";e.exports=function(t,e){var r=t.length;if("number"!=typeof e){e=0;for(var a=0;a<r;++a){var i=t[a];e=Math.max(e,i[0],i[1])}e=1+(0|e)}e|=0;for(var o=new Array(e),a=0;a<e;++a)o[a]=[];for(var a=0;a<r;++a){var i=t[a];o[i[0]].push(i[1]),o[i[1]].push(i[0])}for(var s=0;s<e;++s)n(o[s],function(t,e){return t-e});return o};var n=t("uniq")},{uniq:545}],174:[function(t,e,r){var n=t("strongly-connected-components");e.exports=function(t){var e,r=[],a=[],i=[],o={},s=[];function l(t){var r,n,u=!1;for(a.push(t),i[t]=!0,r=0;r<s[t].length;r++)(n=s[t][r])===e?(c(e,a),u=!0):i[n]||(u=l(n));if(u)!function t(e){i[e]=!1,o.hasOwnProperty(e)&&Object.keys(o[e]).forEach(function(r){delete o[e][r],i[r]&&t(r)})}(t);else for(r=0;r<s[t].length;r++){n=s[t][r];var h=o[n];h||(h={},o[n]=h),h[n]=!0}return a.pop(),u}function c(t,e){var n=[].concat(e).concat(t);r.push(n)}function u(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter(function(t){return t>=e})}(e);for(var r,a=n(t).components.filter(function(t){return t.length>1}),i=1/0,o=0;o<a.length;o++)for(var s=0;s<a[o].length;s++)a[o][s]<i&&(i=a[o][s],r=o);var l=a[r];return!!l&&{leastVertex:i,adjList:t.map(function(t,e){return-1===l.indexOf(e)?[]:t.filter(function(t){return-1!==l.indexOf(t)})})}}e=0;for(var h=t.length;e<h;){var f=u(e);if(e=f.leastVertex,s=f.adjList){for(var p=0;p<s.length;p++)for(var d=0;d<s[p].length;d++){var g=s[p][d];i[+g]=!1,o[g]={}}l(e),e+=1}else e=h}return r}},{"strongly-connected-components":528}],175:[function(t,e,r){"use strict";var n=t("../../object/valid-value");e.exports=function(){return n(this).length=0,this}},{"../../object/valid-value":207}],176:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Array.from:t("./shim")},{"./is-implemented":177,"./shim":178}],177:[function(t,e,r){"use strict";e.exports=function(){var t,e,r=Array.from;return"function"==typeof r&&(e=r(t=["raz","dwa"]),Boolean(e&&e!==t&&"dwa"===e[1]))}},{}],178:[function(t,e,r){"use strict";var n=t("es6-symbol").iterator,a=t("../../function/is-arguments"),i=t("../../function/is-function"),o=t("../../number/to-pos-integer"),s=t("../../object/valid-callable"),l=t("../../object/valid-value"),c=t("../../object/is-value"),u=t("../../string/is-string"),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,v,m,y,x,b,_,w,k=arguments[1],T=arguments[2];if(t=Object(l(t)),c(k)&&s(k),this&&this!==Array&&i(this))e=this;else{if(!k){if(a(t))return 1!==(m=t.length)?Array.apply(null,t):((v=new Array(1))[0]=t[0],v);if(h(t)){for(v=new Array(m=t.length),r=0;r<m;++r)v[r]=t[r];return v}}v=[]}if(!h(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(v=new e),b=x.next(),r=0;!b.done;)w=k?f.call(k,T,b.value,r):b.value,e?(p.value=w,d(v,r,p)):v[r]=w,b=x.next(),++r;m=r}else if(u(t)){for(m=t.length,e&&(v=new e),r=0,g=0;r<m;++r)w=t[r],r+1<m&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=k?f.call(k,T,w,g):w,e?(p.value=w,d(v,g,p)):v[g]=w,++g;m=g}if(void 0===m)for(m=o(t.length),e&&(v=new e(m)),r=0;r<m;++r)w=k?f.call(k,T,t[r],r):t[r],e?(p.value=w,d(v,r,p)):v[r]=w;return e&&(p.value=null,v.length=m),v}},{"../../function/is-arguments":179,"../../function/is-function":180,"../../number/to-pos-integer":186,"../../object/is-value":196,"../../object/valid-callable":205,"../../object/valid-value":207,"../../string/is-string":211,"es6-symbol":221}],179:[function(t,e,r){"use strict";var n=Object.prototype.toString,a=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===a}},{}],180:[function(t,e,r){"use strict";var n=Object.prototype.toString,a=n.call(t("./noop"));e.exports=function(t){return"function"==typeof t&&n.call(t)===a}},{"./noop":181}],181:[function(t,e,r){"use strict";e.exports=function(){}},{}],182:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Math.sign:t("./shim")},{"./is-implemented":183,"./shim":184}],183:[function(t,e,r){"use strict";e.exports=function(){var t=Math.sign;return"function"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],184:[function(t,e,r){"use strict";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],185:[function(t,e,r){"use strict";var n=t("../math/sign"),a=Math.abs,i=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*i(a(t)):t}},{"../math/sign":182}],186:[function(t,e,r){"use strict";var n=t("./to-integer"),a=Math.max;e.exports=function(t){return a(0,n(t))}},{"./to-integer":185}],187:[function(t,e,r){"use strict";var n=t("./valid-callable"),a=t("./valid-value"),i=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(a(r)),n(c),u=s(r),f&&u.sort("function"==typeof f?i.call(f,r):void 0),"function"!=typeof t&&(t=u[t]),o.call(t,u,function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e})}}},{"./valid-callable":205,"./valid-value":207}],188:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Object.assign:t("./shim")},{"./is-implemented":189,"./shim":190}],189:[function(t,e,r){"use strict";e.exports=function(){var t,e=Object.assign;return"function"==typeof e&&(e(t={foo:"raz"},{bar:"dwa"},{trzy:"trzy"}),t.foo+t.bar+t.trzy==="razdwatrzy")}},{}],190:[function(t,e,r){"use strict";var n=t("../keys"),a=t("../valid-value"),i=Math.max;e.exports=function(t,e){var r,o,s,l=i(arguments.length,2);for(t=Object(a(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)e=arguments[o],n(e).forEach(s);if(void 0!==r)throw r;return t}},{"../keys":197,"../valid-value":207}],191:[function(t,e,r){"use strict";var n=t("../array/from"),a=t("./assign"),i=t("./valid-value");e.exports=function(t){var e=Object(i(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,function(e){(o.ensure||e in t)&&(s[e]=t[e])}):a(s,t),s}},{"../array/from":176,"./assign":188,"./valid-value":207}],192:[function(t,e,r){"use strict";var n,a,i,o,s=Object.create;t("./set-prototype-of/is-implemented")()||(n=t("./set-prototype-of/shim")),e.exports=n?1!==n.level?s:(a={},i={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach(function(t){i[t]="__proto__"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}}),Object.defineProperties(a,i),Object.defineProperty(n,"nullPolyfill",{configurable:!1,enumerable:!1,writable:!1,value:a}),function(t,e){return s(null===t?a:t,e)}):s},{"./set-prototype-of/is-implemented":203,"./set-prototype-of/shim":204}],193:[function(t,e,r){"use strict";e.exports=t("./_iterate")("forEach")},{"./_iterate":187}],194:[function(t,e,r){"use strict";e.exports=function(t){return"function"==typeof t}},{}],195:[function(t,e,r){"use strict";var n=t("./is-value"),a={function:!0,object:!0};e.exports=function(t){return n(t)&&a[typeof t]||!1}},{"./is-value":196}],196:[function(t,e,r){"use strict";var n=t("../function/noop")();e.exports=function(t){return t!==n&&null!==t}},{"../function/noop":181}],197:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Object.keys:t("./shim")},{"./is-implemented":198,"./shim":199}],198:[function(t,e,r){"use strict";e.exports=function(){try{return Object.keys("primitive"),!0}catch(t){return!1}}},{}],199:[function(t,e,r){"use strict";var n=t("../is-value"),a=Object.keys;e.exports=function(t){return a(n(t)?Object(t):t)}},{"../is-value":196}],200:[function(t,e,r){"use strict";var n=t("./valid-callable"),a=t("./for-each"),i=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),a(t,function(t,n,a,s){r[n]=i.call(e,o,t,n,a,s)}),r}},{"./for-each":193,"./valid-callable":205}],201:[function(t,e,r){"use strict";var n=t("./is-value"),a=Array.prototype.forEach,i=Object.create;e.exports=function(t){var e=i(null);return a.call(arguments,function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)}),e}},{"./is-value":196}],202:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Object.setPrototypeOf:t("./shim")},{"./is-implemented":203,"./shim":204}],203:[function(t,e,r){"use strict";var n=Object.create,a=Object.getPrototypeOf,i={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return"function"==typeof t&&a(t(e(null),i))===i}},{}],204:[function(t,e,r){"use strict";var n,a,i,o,s=t("../is-object"),l=t("../valid-value"),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,h={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError("Prototype must be null or an object")},e.exports=(a=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,"__proto__");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}())?(2===a.level?a.set?(o=a.set,i=function(t,e){return o.call(n(t,e),e),t}):i=function(t,e){return n(t,e).__proto__=e,t}:i=function t(e,r){var a;return n(e,r),(a=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,a&&u(t.nullPolyfill,"__proto__",h),e},Object.defineProperty(i,"level",{configurable:!1,enumerable:!1,writable:!1,value:a.level})):null,t("../create")},{"../create":192,"../is-object":195,"../valid-value":207}],205:[function(t,e,r){"use strict";e.exports=function(t){if("function"!=typeof t)throw new TypeError(t+" is not a function");return t}},{}],206:[function(t,e,r){"use strict";var n=t("./is-object");e.exports=function(t){if(!n(t))throw new TypeError(t+" is not an Object");return t}},{"./is-object":195}],207:[function(t,e,r){"use strict";var n=t("./is-value");e.exports=function(t){if(!n(t))throw new TypeError("Cannot use null or undefined");return t}},{"./is-value":196}],208:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?String.prototype.contains:t("./shim")},{"./is-implemented":209,"./shim":210}],209:[function(t,e,r){"use strict";var n="razdwatrzy";e.exports=function(){return"function"==typeof n.contains&&(!0===n.contains("dwa")&&!1===n.contains("foo"))}},{}],210:[function(t,e,r){"use strict";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],211:[function(t,e,r){"use strict";var n=Object.prototype.toString,a=n.call("");e.exports=function(t){return"string"==typeof t||t&&"object"==typeof t&&(t instanceof String||n.call(t)===a)||!1}},{}],212:[function(t,e,r){"use strict";var n=Object.create(null),a=Math.random;e.exports=function(){var t;do{t=a().toString(36).slice(2)}while(n[t]);return t}},{}],213:[function(t,e,r){"use strict";var n,a=t("es5-ext/object/set-prototype-of"),i=t("es5-ext/string/#/contains"),o=t("d"),s=t("es6-symbol"),l=t("./"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError("Constructor requires 'new'");l.call(this,t),e=e?i.call(e,"key+value")?"key+value":i.call(e,"key")?"key":"value":"value",c(this,"__kind__",o("",e))},a&&a(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o(function(t){return"value"===this.__kind__?this.__list__[t]:"key+value"===this.__kind__?[t,this.__list__[t]]:t})}),c(n.prototype,s.toStringTag,o("c","Array Iterator"))},{"./":216,d:152,"es5-ext/object/set-prototype-of":202,"es5-ext/string/#/contains":208,"es6-symbol":221}],214:[function(t,e,r){"use strict";var n=t("es5-ext/function/is-arguments"),a=t("es5-ext/object/valid-callable"),i=t("es5-ext/string/is-string"),o=t("./get"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,h,f,p,d,g,v,m=arguments[2];if(s(t)||n(t)?r="array":i(t)?r="string":t=o(t),a(e),h=function(){f=!0},"array"!==r)if("string"!==r)for(u=t.next();!u.done;){if(l.call(e,m,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(v=g.charCodeAt(0))>=55296&&v<=56319&&(g+=t[++p]),l.call(e,m,g,h),!f);++p);else c.call(t,function(t){return l.call(e,m,t,h),f})}},{"./get":215,"es5-ext/function/is-arguments":179,"es5-ext/object/valid-callable":205,"es5-ext/string/is-string":211}],215:[function(t,e,r){"use strict";var n=t("es5-ext/function/is-arguments"),a=t("es5-ext/string/is-string"),i=t("./array"),o=t("./string"),s=t("./valid-iterable"),l=t("es6-symbol").iterator;e.exports=function(t){return"function"==typeof s(t)[l]?t[l]():n(t)?new i(t):a(t)?new o(t):new i(t)}},{"./array":213,"./string":218,"./valid-iterable":219,"es5-ext/function/is-arguments":179,"es5-ext/string/is-string":211,"es6-symbol":221}],216:[function(t,e,r){"use strict";var n,a=t("es5-ext/array/#/clear"),i=t("es5-ext/object/assign"),o=t("es5-ext/object/valid-callable"),s=t("es5-ext/object/valid-value"),l=t("d"),c=t("d/auto-bind"),u=t("es6-symbol"),h=Object.defineProperty,f=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError("Constructor requires 'new'");f(this,{__list__:l("w",s(t)),__context__:l("w",e),__nextIndex__:l("w",0)}),e&&(o(e.on),e.on("_add",this._onAdd),e.on("_delete",this._onDelete),e.on("_clear",this._onClear))},delete n.prototype.constructor,f(n.prototype,i({_next:l(function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()}),next:l(function(){return this._createResult(this._next())}),_createResult:l(function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}}),_resolve:l(function(t){return this.__list__[t]}),_unBind:l(function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off("_add",this._onAdd),this.__context__.off("_delete",this._onDelete),this.__context__.off("_clear",this._onClear),this.__context__=null)}),toString:l(function(){return"[object "+(this[u.toStringTag]||"Object")+"]"})},c({_onAdd:l(function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach(function(e,r){e>=t&&(this.__redo__[r]=++e)},this),this.__redo__.push(t)):h(this,"__redo__",l("c",[t])))}),_onDelete:l(function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach(function(e,r){e>t&&(this.__redo__[r]=--e)},this)))}),_onClear:l(function(){this.__redo__&&a.call(this.__redo__),this.__nextIndex__=0})}))),h(n.prototype,u.iterator,l(function(){return this}))},{d:152,"d/auto-bind":151,"es5-ext/array/#/clear":175,"es5-ext/object/assign":188,"es5-ext/object/valid-callable":205,"es5-ext/object/valid-value":207,"es6-symbol":221}],217:[function(t,e,r){"use strict";var n=t("es5-ext/function/is-arguments"),a=t("es5-ext/object/is-value"),i=t("es5-ext/string/is-string"),o=t("es6-symbol").iterator,s=Array.isArray;e.exports=function(t){return!!a(t)&&(!!s(t)||(!!i(t)||(!!n(t)||"function"==typeof t[o])))}},{"es5-ext/function/is-arguments":179,"es5-ext/object/is-value":196,"es5-ext/string/is-string":211,"es6-symbol":221}],218:[function(t,e,r){"use strict";var n,a=t("es5-ext/object/set-prototype-of"),i=t("d"),o=t("es6-symbol"),s=t("./"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError("Constructor requires 'new'");t=String(t),s.call(this,t),l(this,"__length__",i("",t.length))},a&&a(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:i(function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()}),_resolve:i(function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r})}),l(n.prototype,o.toStringTag,i("c","String Iterator"))},{"./":216,d:152,"es5-ext/object/set-prototype-of":202,"es6-symbol":221}],219:[function(t,e,r){"use strict";var n=t("./is-iterable");e.exports=function(t){if(!n(t))throw new TypeError(t+" is not iterable");return t}},{"./is-iterable":217}],220:[function(t,e,r){(function(n,a){!function(t,n){"object"==typeof r&&"undefined"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,function(){"use strict";function e(t){return"function"==typeof t}var r=Array.isArray?Array.isArray:function(t){return"[object Array]"===Object.prototype.toString.call(t)},i=0,o=void 0,s=void 0,l=function(t,e){g[i]=t,g[i+1]=e,2===(i+=2)&&(s?s(v):_())};var c="undefined"!=typeof window?window:void 0,u=c||{},h=u.MutationObserver||u.WebKitMutationObserver,f="undefined"==typeof self&&"undefined"!=typeof n&&"[object process]"==={}.toString.call(n),p="undefined"!=typeof Uint8ClampedArray&&"undefined"!=typeof importScripts&&"undefined"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(v,1)}}var g=new Array(1e3);function v(){for(var t=0;t<i;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}i=0}var m,y,x,b,_=void 0;function w(t,e){var r=arguments,n=this,a=new this.constructor(A);void 0===a[T]&&U(a);var i,o=n._state;return o?(i=r[o-1],l(function(){return j(o,a,i,n._result)})):R(n,a,t,e),a}function k(t){if(t&&"object"==typeof t&&t.constructor===this)return t;var e=new this(A);return O(e,t),e}f?_=function(){return n.nextTick(v)}:h?(y=0,x=new h(v),b=document.createTextNode(""),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((m=new MessageChannel).port1.onmessage=v,_=function(){return m.port2.postMessage(0)}):_=void 0===c&&"function"==typeof t?function(){try{var e=t("vertx");return o=e.runOnLoop||e.runOnContext,function(){o(v)}}catch(t){return d()}}():d();var T=Math.random().toString(36).substring(16);function A(){}var M=void 0,S=1,E=2,L=new B;function C(t){try{return t.then}catch(t){return L.error=t,L}}function P(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===k?function(t,e){e._state===S?I(t,e._result):e._state===E?D(t,e._result):R(e,void 0,function(e){return O(t,e)},function(e){return D(t,e)})}(t,r):n===L?D(t,L.error):void 0===n?I(t,r):e(n)?function(t,e,r){l(function(t){var n=!1,a=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,function(r){n||(n=!0,e!==r?O(t,r):I(t,r))},function(e){n||(n=!0,D(t,e))},t._label);!n&&a&&(n=!0,D(t,a))},t)}(t,r,n):I(t,r)}function O(t,e){var r;t===e?D(t,new TypeError("You cannot resolve a promise with itself")):"function"==typeof(r=e)||"object"==typeof r&&null!==r?P(t,e,C(e)):I(t,e)}function z(t){t._onerror&&t._onerror(t._result),F(t)}function I(t,e){t._state===M&&(t._result=e,t._state=S,0!==t._subscribers.length&&l(F,t))}function D(t,e){t._state===M&&(t._state=E,t._result=e,l(z,t))}function R(t,e,r,n){var a=t._subscribers,i=a.length;t._onerror=null,a[i]=e,a[i+S]=r,a[i+E]=n,0===i&&t._state&&l(F,t)}function F(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,a=void 0,i=t._result,o=0;o<e.length;o+=3)n=e[o],a=e[o+r],n?j(r,n,a,i):a(i);t._subscribers.length=0}}function B(){this.error=null}var N=new B;function j(t,r,n,a){var i=e(n),o=void 0,s=void 0,l=void 0,c=void 0;if(i){if((o=function(t,e){try{return t(e)}catch(t){return N.error=t,N}}(n,a))===N?(c=!0,s=o.error,o=null):l=!0,r===o)return void D(r,new TypeError("A promises callback cannot return that same promise."))}else o=a,l=!0;r._state!==M||(i&&l?O(r,o):c?D(r,s):t===S?I(r,o):t===E&&D(r,o))}var V=0;function U(t){t[T]=V++,t._state=void 0,t._result=void 0,t._subscribers=[]}function q(t,e){this._instanceConstructor=t,this.promise=new t(A),this.promise[T]||U(this.promise),r(e)?(this._input=e,this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?I(this.promise,this._result):(this.length=this.length||0,this._enumerate(),0===this._remaining&&I(this.promise,this._result))):D(this.promise,new Error("Array Methods must be provided an Array"))}function H(t){this[T]=V++,this._result=this._state=void 0,this._subscribers=[],A!==t&&("function"!=typeof t&&function(){throw new TypeError("You must pass a resolver function as the first argument to the promise constructor")}(),this instanceof H?function(t,e){try{e(function(e){O(t,e)},function(e){D(t,e)})}catch(e){D(t,e)}}(this,t):function(){throw new TypeError("Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.")}())}function G(){var t=void 0;if("undefined"!=typeof a)t=a;else if("undefined"!=typeof self)t=self;else try{t=Function("return this")()}catch(t){throw new Error("polyfill failed because global object is unavailable in this environment")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if("[object Promise]"===r&&!e.cast)return}t.Promise=H}return q.prototype._enumerate=function(){for(var t=this.length,e=this._input,r=0;this._state===M&&r<t;r++)this._eachEntry(e[r],r)},q.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===k){var a=C(t);if(a===w&&t._state!==M)this._settledAt(t._state,e,t._result);else if("function"!=typeof a)this._remaining--,this._result[e]=t;else if(r===H){var i=new r(A);P(i,t,a),this._willSettleAt(i,e)}else this._willSettleAt(new r(function(e){return e(t)}),e)}else this._willSettleAt(n(t),e)},q.prototype._settledAt=function(t,e,r){var n=this.promise;n._state===M&&(this._remaining--,t===E?D(n,r):this._result[e]=r),0===this._remaining&&I(n,this._result)},q.prototype._willSettleAt=function(t,e){var r=this;R(t,void 0,function(t){return r._settledAt(S,e,t)},function(t){return r._settledAt(E,e,t)})},H.all=function(t){return new q(this,t).promise},H.race=function(t){var e=this;return r(t)?new e(function(r,n){for(var a=t.length,i=0;i<a;i++)e.resolve(t[i]).then(r,n)}):new e(function(t,e){return e(new TypeError("You must pass an array to race."))})},H.resolve=k,H.reject=function(t){var e=new this(A);return D(e,t),e},H._setScheduler=function(t){s=t},H._setAsap=function(t){l=t},H._asap=l,H.prototype={constructor:H,then:w,catch:function(t){return this.then(null,t)}},G(),H.polyfill=G,H.Promise=H,H})}).call(this,t("_process"),"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{_process:483}],221:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?Symbol:t("./polyfill")},{"./is-implemented":222,"./polyfill":224}],222:[function(t,e,r){"use strict";var n={object:!0,symbol:!0};e.exports=function(){var t;if("function"!=typeof Symbol)return!1;t=Symbol("test symbol");try{String(t)}catch(t){return!1}return!!n[typeof Symbol.iterator]&&(!!n[typeof Symbol.toPrimitive]&&!!n[typeof Symbol.toStringTag])}},{}],223:[function(t,e,r){"use strict";e.exports=function(t){return!!t&&("symbol"==typeof t||!!t.constructor&&("Symbol"===t.constructor.name&&"Symbol"===t[t.constructor.toStringTag]))}},{}],224:[function(t,e,r){"use strict";var n,a,i,o,s=t("d"),l=t("./validate-symbol"),c=Object.create,u=Object.defineProperties,h=Object.defineProperty,f=Object.prototype,p=c(null);if("function"==typeof Symbol){n=Symbol;try{String(n()),o=!0}catch(t){}}var d,g=(d=c(null),function(t){for(var e,r,n=0;d[t+(n||"")];)++n;return d[t+=n||""]=!0,h(f,e="@@"+t,s.gs(null,function(t){r||(r=!0,h(this,e,s(t)),r=!1)})),e});i=function(t){if(this instanceof i)throw new TypeError("Symbol is not a constructor");return a(t)},e.exports=a=function t(e){var r;if(this instanceof t)throw new TypeError("Symbol is not a constructor");return o?n(e):(r=c(i.prototype),e=void 0===e?"":String(e),u(r,{__description__:s("",e),__name__:s("",g(e))}))},u(a,{for:s(function(t){return p[t]?p[t]:p[t]=a(String(t))}),keyFor:s(function(t){var e;for(e in l(t),p)if(p[e]===t)return e}),hasInstance:s("",n&&n.hasInstance||a("hasInstance")),isConcatSpreadable:s("",n&&n.isConcatSpreadable||a("isConcatSpreadable")),iterator:s("",n&&n.iterator||a("iterator")),match:s("",n&&n.match||a("match")),replace:s("",n&&n.replace||a("replace")),search:s("",n&&n.search||a("search")),species:s("",n&&n.species||a("species")),split:s("",n&&n.split||a("split")),toPrimitive:s("",n&&n.toPrimitive||a("toPrimitive")),toStringTag:s("",n&&n.toStringTag||a("toStringTag")),unscopables:s("",n&&n.unscopables||a("unscopables"))}),u(i.prototype,{constructor:s(a),toString:s("",function(){return this.__name__})}),u(a.prototype,{toString:s(function(){return"Symbol ("+l(this).__description__+")"}),valueOf:s(function(){return l(this)})}),h(a.prototype,a.toPrimitive,s("",function(){var t=l(this);return"symbol"==typeof t?t:t.toString()})),h(a.prototype,a.toStringTag,s("c","Symbol")),h(i.prototype,a.toStringTag,s("c",a.prototype[a.toStringTag])),h(i.prototype,a.toPrimitive,s("c",a.prototype[a.toPrimitive]))},{"./validate-symbol":225,d:152}],225:[function(t,e,r){"use strict";var n=t("./is-symbol");e.exports=function(t){if(!n(t))throw new TypeError(t+" is not a symbol");return t}},{"./is-symbol":223}],226:[function(t,e,r){"use strict";e.exports=function(t,e,r){var n=e||0,a=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[a*t[12]-t[8],a*t[13]-t[9],a*t[14]-t[10],a*t[15]-t[11]]]}},{}],227:[function(t,e,r){"use strict";var n=t("is-string-blank");e.exports=function(t){var e=typeof t;if("string"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if("number"!==e)return!1;return t-t<1}},{"is-string-blank":424}],228:[function(t,e,r){"use strict";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:if("number"==typeof t){var n=l(t);return new o(n,n,0)}return new o(t,l(t.length),0);case 2:if("number"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error("state and velocity lengths must match");return new o(t,e,r)}};var n=t("cubic-hermite"),a=t("binary-search-bounds");function i(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=a.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=a.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var g=e[o],v=e[o+1]-g||1,m=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--f)m[p]=l[f],x[p]=c[f]*v,y[p]=l[f+u],b[p]=c[f+u]*v,_=_&&m[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=m[p];else n(m,x,y,b,(t-g)/v,s)}var w=h[0],k=h[1];for(p=0;p<u;++p)s[p]=i(w[p],k[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,i=a.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(i>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(i+1)-1;var f=e[i],p=e[i+1]-f||1,d=this._scratch[1],g=this._scratch[2],v=this._scratch[3],m=this._scratch[4],y=!0;for(h=0;h<c;++h,--u)d[h]=s[u],v[h]=l[u]*p,g[h]=s[u+c],m[h]=l[u+c]*p,y=y&&d[h]===g[h]&&v[h]===m[h]&&0===v[h];if(y)for(h=0;h<c;++h)o[h]=0;else{n.derivative(d,v,g,m,(t-f)/p,o);for(h=0;h<c;++h)o[h]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,a=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),a.push(0);this._time.push(t);for(h=r;h>0;--h)n.push(i(l[h-1],c[h-1],arguments[h])),a.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,a=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=i(c[f-1],u[f-1],arguments[f]);n.push(p),a.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,a=this.bounds,o=a[0],s=a[1];this._time.push(t);for(var l=e;l>0;--l)r.push(i(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,a=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(i(l[f-1],c[f-1],n[o++]+p)),a.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,a=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(i(l[h],c[h],n[o]+u*a[o])),a.push(0),o+=1}}},{"binary-search-bounds":92,"cubic-hermite":146}],229:[function(t,e,r){var n=t("dtype");e.exports=function(t,e,r){if(!t)throw new TypeError("must specify data as first parameter");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&"number"==typeof t[0][0]){var a,i,o,s,l=t[0].length,c=t.length*l;e&&"string"!=typeof e||(e=new(n(e||"float32"))(c+r));var u=e.length-r;if(c!==u)throw new Error("source length "+c+" ("+l+"x"+t.length+") does not match destination length "+u);for(a=0,o=r;a<t.length;a++)for(i=0;i<l;i++)e[o++]=null===t[a][i]?NaN:t[a][i]}else if(e&&"string"!=typeof e)e.set(t,r);else{var h=n(e||"float32");if(Array.isArray(t)||"array"===e)for(e=new h(t.length+r),a=0,o=r,s=e.length;o<s;o++,a++)e[o]=null===t[a]?NaN:t[a];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},{dtype:170}],230:[function(t,e,r){"use strict";var n=t("css-font/stringify"),a=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement("canvas"),i=t.font,o="number"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||a;i&&"string"!=typeof i&&(i=n(i));if(Array.isArray(s)){if(2===s.length&&"number"==typeof s[0]&&"number"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split("");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext("2d");h.fillStyle="#000",h.fillRect(0,0,r.width,r.height),h.font=i,h.textAlign="center",h.textBaseline="middle",h.fillStyle="#fff";for(var f=o[0]/2,p=o[1]/2,c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},{"css-font/stringify":143}],231:[function(t,e,r){"use strict";function n(t,e){e||(e={}),("string"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(", "):e.family;if(!r)throw Error("`family` must be defined");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||"",c=(t=[e.style||e.fontStyle||"",l,s].join(" ")+"px "+r,e.origin||"top");if(n.cache[r]&&s<=n.cache[r].em)return a(n.cache[r],c);var u=e.canvas||n.canvas,h=u.getContext("2d"),f={upper:void 0!==e.upper?e.upper:"H",lower:void 0!==e.lower?e.lower:"x",descent:void 0!==e.descent?e.descent:"p",ascent:void 0!==e.ascent?e.ascent:"h",tittle:void 0!==e.tittle?e.tittle:"i",overshoot:void 0!==e.overshoot?e.overshoot:"O"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d={top:0};h.clearRect(0,0,p,p),h.textBaseline="top",h.fillStyle="black",h.fillText("H",0,0);var g=i(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline="bottom",h.fillText("H",0,p);var v=i(h.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-v+g,h.clearRect(0,0,p,p),h.textBaseline="alphabetic",h.fillText("H",0,p);var m=p-i(h.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=m,h.clearRect(0,0,p,p),h.textBaseline="middle",h.fillText("H",0,.5*p);var y=i(h.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline="hanging",h.fillText("H",0,.5*p);var x=i(h.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline="ideographic",h.fillText("H",0,p);var b=i(h.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.upper,0,0),d.upper=i(h.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.lower,0,0),d.lower=i(h.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.tittle,0,0),d.tittle=i(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.ascent,0,0),d.ascent=i(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.descent,0,0),d.descent=o(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline="top",h.fillText(f.overshoot,0,0);var _=o(h.getImageData(0,0,p,p));d.overshoot=_-m}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,a(d,c)}function a(t,e){var r={};for(var n in"string"==typeof e&&(e=t[e]),t)"em"!==n&&(r[n]=t[n]-e);return r}function i(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement("canvas"),n.cache={}},{}],232:[function(t,e,r){"use strict";e.exports=function(t){return new c(t||d,null)};var n=0,a=1;function i(t,e,r,n,a,i){this._color=t,this.key=e,this.value=r,this.left=n,this.right=a,this._count=i}function o(t){return new i(t._color,t.key,t.value,t.left,t.right,t._count)}function s(t,e){return new i(t,e.key,e.value,e.left,e.right,e._count)}function l(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function c(t,e){this._compare=t,this.root=e}var u=c.prototype;function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(u,"keys",{get:function(){var t=[];return this.forEach(function(e,r){t.push(e)}),t}}),Object.defineProperty(u,"values",{get:function(){var t=[];return this.forEach(function(e,r){t.push(r)}),t}}),Object.defineProperty(u,"length",{get:function(){return this.root?this.root._count:0}}),u.insert=function(t,e){for(var r=this._compare,o=this.root,u=[],h=[];o;){var f=r(t,o.key);u.push(o),h.push(f),o=f<=0?o.left:o.right}u.push(new i(n,t,e,null,null,1));for(var p=u.length-2;p>=0;--p){o=u[p];h[p]<=0?u[p]=new i(o._color,o.key,o.value,u[p+1],o.right,o._count+1):u[p]=new i(o._color,o.key,o.value,o.left,u[p+1],o._count+1)}for(p=u.length-1;p>1;--p){var d=u[p-1];o=u[p];if(d._color===a||o._color===a)break;var g=u[p-2];if(g.left===d)if(d.left===o){if(!(v=g.right)||v._color!==n){if(g._color=n,g.left=d.right,d._color=a,d.right=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).left===g?m.left=d:m.right=d;break}d._color=a,g.right=s(a,v),g._color=n,p-=1}else{if(!(v=g.right)||v._color!==n){if(d.right=o.left,g._color=n,g.left=o.right,o._color=a,o.left=d,o.right=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).left===g?m.left=o:m.right=o;break}d._color=a,g.right=s(a,v),g._color=n,p-=1}else if(d.right===o){if(!(v=g.left)||v._color!==n){if(g._color=n,g.right=d.left,d._color=a,d.left=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).right===g?m.right=d:m.left=d;break}d._color=a,g.left=s(a,v),g._color=n,p-=1}else{var v;if(!(v=g.left)||v._color!==n){var m;if(d.left=o.right,g._color=n,g.right=o.left,o._color=a,o.right=d,o.left=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).right===g?m.right=o:m.left=o;break}d._color=a,g.left=s(a,v),g._color=n,p-=1}}return u[0]._color=a,new c(r,u[0])},u.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return function t(e,r){var n;if(r.left&&(n=t(e,r.left)))return n;return(n=e(r.key,r.value))||(r.right?t(e,r.right):void 0)}(t,this.root);case 2:return function t(e,r,n,a){if(r(e,a.key)<=0){var i;if(a.left&&(i=t(e,r,n,a.left)))return i;if(i=n(a.key,a.value))return i}if(a.right)return t(e,r,n,a.right)}(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return function t(e,r,n,a,i){var o,s=n(e,i.key),l=n(r,i.key);if(s<=0){if(i.left&&(o=t(e,r,n,a,i.left)))return o;if(l>0&&(o=a(i.key,i.value)))return o}if(l>0&&i.right)return t(e,r,n,a,i.right)}(e,r,this._compare,t,this.root)}},Object.defineProperty(u,"begin",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(u,"end",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),u.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},u.ge=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i<=0&&(a=n.length),r=i<=0?r.left:r.right}return n.length=a,new h(this,n)},u.gt=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i<0&&(a=n.length),r=i<0?r.left:r.right}return n.length=a,new h(this,n)},u.lt=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i>0&&(a=n.length),r=i<=0?r.left:r.right}return n.length=a,new h(this,n)},u.le=function(t){for(var e=this._compare,r=this.root,n=[],a=0;r;){var i=e(t,r.key);n.push(r),i>=0&&(a=n.length),r=i<0?r.left:r.right}return n.length=a,new h(this,n)},u.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var a=e(t,r.key);if(n.push(r),0===a)return new h(this,n);r=a<=0?r.left:r.right}return new h(this,[])},u.remove=function(t){var e=this.find(t);return e?e.remove():this},u.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var f=h.prototype;function p(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function d(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(f,"valid",{get:function(){return this._stack.length>0}}),Object.defineProperty(f,"node",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),f.clone=function(){return new h(this.tree,this._stack.slice())},f.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new i(r._color,r.key,r.value,r.left,r.right,r._count);for(var u=t.length-2;u>=0;--u){(r=t[u]).left===t[u+1]?e[u]=new i(r._color,r.key,r.value,e[u+1],r.right,r._count):e[u]=new i(r._color,r.key,r.value,r.left,e[u+1],r._count)}if((r=e[e.length-1]).left&&r.right){var h=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var f=e[h-1];e.push(new i(r._color,f.key,f.value,r.left,r.right,r._count)),e[h-1].key=r.key,e[h-1].value=r.value;for(u=e.length-2;u>=h;--u)r=e[u],e[u]=new i(r._color,r.key,r.value,r.left,e[u+1],r._count);e[h-1].left=e[h]}if((r=e[e.length-1])._color===n){var d=e[e.length-2];d.left===r?d.left=null:d.right===r&&(d.right=null),e.pop();for(u=0;u<e.length;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(r.left||r.right){r.left?p(r,r.left):r.right&&p(r,r.right),r._color=a;for(u=0;u<e.length-1;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(1===e.length)return new c(this.tree._compare,null);for(u=0;u<e.length;++u)e[u]._count--;var g=e[e.length-2];return function(t){for(var e,r,i,c,u=t.length-1;u>=0;--u){if(e=t[u],0===u)return void(e._color=a);if((r=t[u-1]).left===e){if((i=r.right).right&&i.right._color===n)return c=(i=r.right=o(i)).right=o(i.right),r.right=i.left,i.left=r,i.right=c,i._color=r._color,e._color=a,r._color=a,c._color=a,l(r),l(i),u>1&&((h=t[u-2]).left===r?h.left=i:h.right=i),void(t[u-1]=i);if(i.left&&i.left._color===n)return c=(i=r.right=o(i)).left=o(i.left),r.right=c.left,i.left=c.right,c.left=r,c.right=i,c._color=r._color,r._color=a,i._color=a,e._color=a,l(r),l(i),l(c),u>1&&((h=t[u-2]).left===r?h.left=c:h.right=c),void(t[u-1]=c);if(i._color===a){if(r._color===n)return r._color=a,void(r.right=s(n,i));r.right=s(n,i);continue}i=o(i),r.right=i.left,i.left=r,i._color=r._color,r._color=n,l(r),l(i),u>1&&((h=t[u-2]).left===r?h.left=i:h.right=i),t[u-1]=i,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}else{if((i=r.left).left&&i.left._color===n)return c=(i=r.left=o(i)).left=o(i.left),r.left=i.right,i.right=r,i.left=c,i._color=r._color,e._color=a,r._color=a,c._color=a,l(r),l(i),u>1&&((h=t[u-2]).right===r?h.right=i:h.left=i),void(t[u-1]=i);if(i.right&&i.right._color===n)return c=(i=r.left=o(i)).right=o(i.right),r.left=c.right,i.right=c.left,c.right=r,c.left=i,c._color=r._color,r._color=a,i._color=a,e._color=a,l(r),l(i),l(c),u>1&&((h=t[u-2]).right===r?h.right=c:h.left=c),void(t[u-1]=c);if(i._color===a){if(r._color===n)return r._color=a,void(r.left=s(n,i));r.left=s(n,i);continue}var h;i=o(i),r.left=i.right,i.right=r,i._color=r._color,r._color=n,l(r),l(i),u>1&&((h=t[u-2]).right===r?h.right=i:h.left=i),t[u-1]=i,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}}}(e),g.left===r?g.left=null:g.right=null,new c(this.tree._compare,e[0])},Object.defineProperty(f,"key",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(f,"value",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(f,"index",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),f.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,"hasNext",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),f.update=function(t){var e=this._stack;if(0===e.length)throw new Error("Can't update empty node!");var r=new Array(e.length),n=e[e.length-1];r[r.length-1]=new i(n._color,n.key,t,n.left,n.right,n._count);for(var a=e.length-2;a>=0;--a)(n=e[a]).left===e[a+1]?r[a]=new i(n._color,n.key,n.value,r[a+1],n.right,n._count):r[a]=new i(n._color,n.key,n.value,n.left,r[a+1],n._count);return new c(this.tree._compare,r[0])},f.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,"hasPrev",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],233:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],a=607/128,i=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function o(t){if(t<0)return Number("0/0");for(var e=i[0],r=i.length-1;r>0;--r)e+=i[r]/(t+r);var n=t+a+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(o(e));e-=1;for(var r=n[0],a=1;a<9;a++)r+=n[a]/(e+a);var i=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(i,e+.5)*Math.exp(-i)*r},e.exports.log=o},{}],234:[function(t,e,r){e.exports=function(t,e){if("string"!=typeof t)throw new TypeError("must specify type string");if(e=e||{},"undefined"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement("canvas");"number"==typeof e.width&&(r.width=e.width);"number"==typeof e.height&&(r.height=e.height);var n,a=e;try{var i=[t];0===t.indexOf("webgl")&&i.push("experimental-"+t);for(var o=0;o<i.length;o++)if(n=r.getContext(i[o],a))return n}catch(t){n=null}return n||null}},{}],235:[function(t,e,r){"use strict";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t("./lib/text.js"),a=t("./lib/lines.js"),i=t("./lib/background.js"),o=t("./lib/cube.js"),s=t("./lib/ticks.js"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=["sans-serif","sans-serif","sans-serif"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=["auto","auto","auto"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=["x","y","z"],this.labelEnable=[!0,!0,!0],this.labelFont="sans-serif",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=["auto","auto","auto"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=i(t)}var h=u.prototype;function f(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}h.update=function(t){function e(e,r,n){if(n in t){var a,i=t[n],o=this[n];(e?Array.isArray(i)&&Array.isArray(i[0]):Array.isArray(i))?this[n]=a=[r(i[0]),r(i[1]),r(i[2])]:this[n]=a=[r(i),r(i),r(i)];for(var s=0;s<3;++s)if(a[s]!==o[s])return!0}return!1}t=t||{};var r,i=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]}),u=!1,h=!1;if("bounds"in t)for(var f=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)f[p][d]!==this.bounds[p][d]&&(h=!0),this.bounds[p][d]=f[p][d];if("ticks"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else i("tickSpacing")&&(this.autoTicks=!0,h=!0);if(this._firstInit&&("ticks"in t||"tickSpacing"in t||(this.autoTicks=!0),h=!0,u=!0,this._firstInit=!1),h&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort(function(t,e){return t.x-e.x});s.equal(r,this.ticks)?u=!1:this.ticks=r}o("tickEnable"),l("tickFont")&&(u=!0),i("tickSize"),i("tickAngle"),i("tickPad"),c("tickColor");var g=l("labels");l("labelFont")&&(g=!0),o("labelEnable"),i("labelSize"),i("labelPad"),c("labelColor"),o("lineEnable"),o("lineMirror"),i("lineWidth"),c("lineColor"),o("lineTickEnable"),o("lineTickMirror"),i("lineTickLength"),i("lineTickWidth"),c("lineTickColor"),o("gridEnable"),i("gridWidth"),c("gridColor"),o("zeroEnable"),c("zeroLineColor"),i("zeroLineWidth"),o("backgroundEnable"),c("backgroundColor"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=a(this.gl,this.bounds,this.ticks))};var p=[new f,new f,new f];function d(t,e,r,n,a){for(var i=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=i,f=s,p=o,d=l;c&1<<u&&(h=s,f=i,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],a[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],v={model:l,view:l,projection:l,_ortho:!1};h.isOpaque=function(){return!0},h.isTransparent=function(){return!1},h.drawTransparent=function(t){};var m=[0,0,0],y=[0,0,0],x=[0,0,0];h.draw=function(t){t=t||v;for(var e=this.gl,r=t.model||l,n=t.view||l,a=t.projection||l,i=this.bounds,s=t._ortho||!1,u=o(r,n,a,i,s),h=u.cubeEdges,f=u.axis,b=n[12],_=n[13],w=n[14],k=n[15],T=(s?2:1)*this.pixelRatio*(a[3]*b+a[7]*_+a[11]*w+a[15]*k)/e.drawingBufferHeight,A=0;A<3;++A)this.lastCubeProps.cubeEdges[A]=h[A],this.lastCubeProps.axis[A]=f[A];var M=p;for(A=0;A<3;++A)d(p[A],A,this.bounds,h,f);e=this.gl;var S,E=g;for(A=0;A<3;++A)this.backgroundEnable[A]?E[A]=f[A]:E[A]=0;this._background.draw(r,n,a,i,E,this.backgroundColor),this._lines.bind(r,n,a,this);for(A=0;A<3;++A){var L=[0,0,0];f[A]>0?L[A]=i[1][A]:L[A]=i[0][A];for(var C=0;C<2;++C){var P=(A+1+C)%3,O=(A+1+(1^C))%3;this.gridEnable[P]&&this._lines.drawGrid(P,O,this.bounds,L,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(C=0;C<2;++C){P=(A+1+C)%3,O=(A+1+(1^C))%3;this.zeroEnable[O]&&Math.min(i[0][O],i[1][O])<=0&&Math.max(i[0][O],i[1][O])>=0&&this._lines.drawZero(P,O,this.bounds,L,this.zeroLineColor[O],this.zeroLineWidth[O]*this.pixelRatio)}}for(A=0;A<3;++A){this.lineEnable[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].primalOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio),this.lineMirror[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].mirrorOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio);var z=c(m,M[A].primalMinor),I=c(y,M[A].mirrorMinor),D=this.lineTickLength;for(C=0;C<3;++C){var R=T/r[5*C];z[C]*=D[C]*R,I[C]*=D[C]*R}this.lineTickEnable[A]&&this._lines.drawAxisTicks(A,M[A].primalOffset,z,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio),this.lineTickMirror[A]&&this._lines.drawAxisTicks(A,M[A].mirrorOffset,I,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,a,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,a=(t+2)%3,i=e[n],o=e[a],s=r[n],l=r[a];i>0&&l>0?N(n):i>0&&l<0?N(n):i<0&&l>0?N(n):i<0&&l<0?N(n):o>0&&s>0?N(a):o>0&&s<0?N(a):o<0&&s>0?N(a):o<0&&s<0&&N(a)}for(A=0;A<3;++A){var V=M[A].primalMinor,U=M[A].mirrorMinor,q=c(x,M[A].primalOffset);for(C=0;C<3;++C)this.lineTickEnable[A]&&(q[C]+=T*V[C]*Math.max(this.lineTickLength[C],0)/r[5*C]);var H=[0,0,0];if(H[A]=1,this.tickEnable[A]){-3600===this.tickAngle[A]?(this.tickAngle[A]=0,this.tickAlign[A]="auto"):this.tickAlign[A]=-1,F=1,"auto"===(S=[this.tickAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(""+S[0]),B=[0,0,0],j(A,V,U);for(C=0;C<3;++C)q[C]+=T*V[C]*this.tickPad[C]/r[5*C];this._text.drawTicks(A,this.tickSize[A],this.tickAngle[A],q,this.tickColor[A],H,B,S)}if(this.labelEnable[A]){F=0,B=[0,0,0],this.labels[A].length>4&&(N(A),F=1),"auto"===(S=[this.labelAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(""+S[0]);for(C=0;C<3;++C)q[C]+=T*V[C]*this.labelPad[C]/r[5*C];q[A]+=.5*(i[0][A]+i[1][A]),this._text.drawLabel(A,this.labelSize[A],this.labelAngle[A],q,this.labelColor[A],[0,0,0],B,S)}}this._text.unbind()},h.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{"./lib/background.js":236,"./lib/cube.js":237,"./lib/lines.js":238,"./lib/text.js":240,"./lib/ticks.js":241}],236:[function(t,e,r){"use strict";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var g=-1;g<=1;g+=2)h[u]=g,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var v=c;c=u,u=v}var m=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=a(t,[{buffer:m,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:m,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=i(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,m,x,b)};var n=t("gl-buffer"),a=t("gl-vao"),i=t("./shaders").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,a,i){for(var o=!1,s=0;s<3;++s)o=o||a[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:a,colors:i},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{"./shaders":239,"gl-buffer":243,"gl-vao":328}],237:[function(t,e,r){"use strict";e.exports=function(t,e,r,i,p){a(s,e,t),a(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=i[x][2];for(var b=0;b<2;++b){u[1]=i[b][1];for(var _=0;_<2;++_)u[0]=i[_][0],f(l[y],u,s),y+=1}}for(var w=-1,x=0;x<8;++x){for(var k=l[x][3],T=0;T<3;++T)c[x][T]=l[x][T]/k;p&&(c[x][2]*=-1),k<0&&(w<0?w=x:c[x][2]<c[w][2]&&(w=x))}if(w<0){w=0;for(var A=0;A<3;++A){for(var M=(A+2)%3,S=(A+1)%3,E=-1,L=-1,C=0;C<2;++C){var P=C<<A,O=P+(C<<M)+(1-C<<S),z=P+(1-C<<M)+(C<<S);o(c[P],c[O],c[z],h)<0||(C?E=1:L=1)}if(E<0||L<0)L>E&&(w|=1<<A);else{for(var C=0;C<2;++C){var P=C<<A,O=P+(C<<M)+(1-C<<S),z=P+(1-C<<M)+(C<<S),I=d([l[P],l[O],l[z],l[P+(1<<M)+(1<<S)]]);C?E=I:L=I}L>E&&(w|=1<<A)}}}for(var D=7^w,R=-1,x=0;x<8;++x)x!==w&&x!==D&&(R<0?R=x:c[R][1]>c[x][1]&&(R=x));for(var F=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D){F<0&&(F=B);var S=c[B];S[0]<c[F][0]&&(F=B)}}for(var N=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D&&B!==F){N<0&&(N=B);var S=c[B];S[0]>c[N][0]&&(N=B)}}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^N)]=R&N;var V=7^N;V===w||V===D?(V=7^F,j[n.log2(N^V)]=V&N):j[n.log2(F^V)]=V&F;for(var U=v,q=w,A=0;A<3;++A)U[A]=q&1<<A?-1:1;return m};var n=t("bit-twiddle"),a=t("gl-mat4/multiply"),i=t("split-polygon"),o=t("robust-orientation"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var a=0;a<3;++a)t[n]+=e[a]*r[4*a+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=i.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],a=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-a,h=l[0]/l[3]-n,f=l[1]/l[3]-a;o+=Math.abs(c*f-u*h)}return o}var g=[1,1,1],v=[0,0,0],m={cubeEdges:g,axis:v}},{"bit-twiddle":93,"gl-mat4/multiply":269,"robust-orientation":508,"split-polygon":525}],238:[function(t,e,r){"use strict";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var g=+r[h][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;s[h]=f,l[h]=v-f;for(var f=o.length/3|0,m=0;m<r[h].length;++m){var g=+r[h][m].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;c[h]=f,u[h]=v-f}var y=n(t,new Float32Array(o)),x=a(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=i(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t("gl-buffer"),a=t("gl-vao"),i=t("./shaders").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,a,i,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=a,this.tickOffset=i,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,a){var i=h(s);this.shader.uniforms.majorAxis=s,i[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=i;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,a){if(this.tickCount[t]){var i=h(o);i[t]=1,this.shader.uniforms.majorAxis=i,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=a;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,a,i){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=h(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=a,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,a,i){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=a,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{"./shaders":239,"gl-buffer":243,"gl-vao":328}],239:[function(t,e,r){"use strict";var n=t("glslify"),a=t("gl-shader"),i=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\n\nuniform mat4 model, view, projection;\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\nuniform float lineWidth;\nuniform vec2 screenShape;\n\nvec3 project(vec3 p) {\n  vec4 pp = projection * view * model * vec4(p, 1.0);\n  return pp.xyz / max(pp.w, 0.0001);\n}\n\nvoid main() {\n  vec3 major = position.x * majorAxis;\n  vec3 minor = position.y * minorAxis;\n\n  vec3 vPosition = major + minor + offset;\n  vec3 pPosition = project(vPosition);\n  vec3 offset = project(vPosition + screenAxis * position.z);\n\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\n\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\n}\n"]),o=n(["precision highp float;\n#define GLSLIFY 1\n\nuniform vec4 color;\nvoid main() {\n  gl_FragColor = color;\n}"]);r.line=function(t){return a(t,i,o,null,[{name:"position",type:"vec3"}])};var s=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\n\nuniform mat4 model, view, projection;\nuniform vec3 offset, axis, alignDir, alignOpt;\nuniform float scale, angle, pixelScale;\nuniform vec2 resolution;\n\nvec3 project(vec3 p) {\n  vec4 pp = projection * view * model * vec4(p, 1.0);\n  return pp.xyz / max(pp.w, 0.0001);\n}\n\nfloat computeViewAngle(vec3 a, vec3 b) {\n  vec3 A = project(a);\n  vec3 B = project(b);\n\n  return atan(\n    (B.y - A.y) * resolution.y,\n    (B.x - A.x) * resolution.x\n  );\n}\n\nconst float PI = 3.141592;\nconst float TWO_PI = 2.0 * PI;\nconst float HALF_PI = 0.5 * PI;\nconst float ONE_AND_HALF_PI = 1.5 * PI;\n\nint option = int(floor(alignOpt.x + 0.001));\nfloat hv_ratio =       alignOpt.y;\nbool enableAlign =    (alignOpt.z != 0.0);\n\nfloat mod_angle(float a) {\n  return mod(a, PI);\n}\n\nfloat positive_angle(float a) {\n  return mod_angle((a < 0.0) ?\n    a + TWO_PI :\n    a\n  );\n}\n\nfloat look_upwards(float a) {\n  float b = positive_angle(a);\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\n    b - PI :\n    b;\n}\n\nfloat look_horizontal_or_vertical(float a, float ratio) {\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\n  // if ratio is set to 0.5 then it is 50%, 50%.\n  // when using a higher ratio e.g. 0.75 the result would\n  // likely be more horizontal than vertical.\n\n  float b = positive_angle(a);\n\n  return\n    (b < (      ratio) * HALF_PI) ? 0.0 :\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\n                                    0.0;\n}\n\nfloat roundTo(float a, float b) {\n  return float(b * floor((a + 0.5 * b) / b));\n}\n\nfloat look_round_n_directions(float a, int n) {\n  float b = positive_angle(a);\n  float div = TWO_PI / float(n);\n  float c = roundTo(b, div);\n  return look_upwards(c);\n}\n\nfloat applyAlignOption(float rawAngle, float delta) {\n  return\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\n                    rawAngle;                // otherwise return back raw input angle\n}\n\nbool isAxisTitle = (axis.x == 0.0) &&\n                   (axis.y == 0.0) &&\n                   (axis.z == 0.0);\n\nvoid main() {\n  //Compute world offset\n  float axisDistance = position.z;\n  vec3 dataPosition = axisDistance * axis + offset;\n\n  float beta = angle; // i.e. user defined attributes for each tick\n\n  float axisAngle;\n  float clipAngle;\n  float flip;\n\n  if (enableAlign) {\n    axisAngle = (isAxisTitle) ? HALF_PI :\n                      computeViewAngle(dataPosition, dataPosition + axis);\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\n\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\n\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\n\n    beta += applyAlignOption(clipAngle, flip * PI);\n  }\n\n  //Compute plane offset\n  vec2 planeCoord = position.xy * pixelScale;\n\n  mat2 planeXform = scale * mat2(\n     cos(beta), sin(beta),\n    -sin(beta), cos(beta)\n  );\n\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\n\n  //Compute clip position\n  vec3 clipPosition = project(dataPosition);\n\n  //Apply text offset in clip coordinates\n  clipPosition += vec3(viewOffset, 0.0);\n\n  //Done\n  gl_Position = vec4(clipPosition, 1.0);\n}"]),l=n(["precision highp float;\n#define GLSLIFY 1\n\nuniform vec4 color;\nvoid main() {\n  gl_FragColor = color;\n}"]);r.text=function(t){return a(t,s,l,null,[{name:"position",type:"vec3"}])};var c=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\nattribute vec3 normal;\n\nuniform mat4 model, view, projection;\nuniform vec3 enable;\nuniform vec3 bounds[2];\n\nvarying vec3 colorChannel;\n\nvoid main() {\n\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\n\n  vec3 realNormal = signAxis * normal;\n\n  if(dot(realNormal, enable) > 0.0) {\n    vec3 minRange = min(bounds[0], bounds[1]);\n    vec3 maxRange = max(bounds[0], bounds[1]);\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\n  } else {\n    gl_Position = vec4(0,0,0,0);\n  }\n\n  colorChannel = abs(realNormal);\n}"]),u=n(["precision highp float;\n#define GLSLIFY 1\n\nuniform vec4 colors[3];\n\nvarying vec3 colorChannel;\n\nvoid main() {\n  gl_FragColor = colorChannel.x * colors[0] +\n                 colorChannel.y * colors[1] +\n                 colorChannel.z * colors[2];\n}"]);r.bg=function(t){return a(t,c,u,null,[{name:"position",type:"vec3"},{name:"normal",type:"vec3"}])}},{"gl-shader":303,glslify:410}],240:[function(t,e,r){(function(r){"use strict";e.exports=function(t,e,r,i,s,l){var u=n(t),h=a(t,[{buffer:u,size:3}]),f=o(t);f.attributes.position.location=0;var p=new c(t,f,u,h);return p.update(e,r,i,s,l),p};var n=t("gl-buffer"),a=t("gl-vao"),i=t("vectorize-text"),o=t("./shaders").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,h=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var a=this.shader.uniforms;a.model=t,a.view=e,a.projection=r,a.pixelScale=n,h[0]=this.gl.drawingBufferWidth,h[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=h},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,a){var o=[];function s(t,e,r,n,a,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return i(t,e)}catch(e){return console.warn('error vectorizing text:"'+t+'" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:"center",textBaseline:"middle",lineSpacing:a,styletags:s}));for(var h=(n||12)/12,f=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var v=p[d],m=2;m>=0;--m){var y=f[v[m]];o.push(h*y[0],-h*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(o.length/3|0)-h[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||a,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=h,this.labelCount=f},u.drawTicks=function(t,e,r,n,a,i,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=i,this.shader.uniforms.color=a,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,a,i,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=i,this.shader.uniforms.color=a,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t("_process"))},{"./shaders":239,_process:483,"gl-buffer":243,"gl-vao":328,"vectorize-text":548}],241:[function(t,e,r){"use strict";function n(t,e){var r=t+"",n=r.indexOf("."),a=0;n>=0&&(a=r.length-n-1);var i=Math.pow(10,a),o=Math.round(t*e*i),s=o+"";if(s.indexOf("e")>=0)return s;var l=o/i,c=o%i;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=""+l;if(o<0&&(u="-"+u),a){for(var h=""+c;h.length<a;)h="0"+h;return u+"."+h}return u}r.create=function(t,e){for(var r=[],a=0;a<3;++a){for(var i=[],o=(t[0][a],t[1][a],0);o*e[a]<=t[1][a];++o)i.push({x:o*e[a],text:n(e[a],o)});for(var o=-1;o*e[a]>=t[0][a];--o)i.push({x:o*e[a],text:n(e[a],o)});r.push(i)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var a=t[r][n],i=e[r][n];if(a.x!==i.x||a.text!==i.text||a.font!==i.font||a.fontColor!==i.fontColor||a.fontSize!==i.fontSize||a.dx!==i.dx||a.dy!==i.dy)return!1}}return!0}},{}],242:[function(t,e,r){"use strict";e.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,m=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(h=h||i(f,p,m,x,y)).axis;o(u,p,f),o(u,m,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var k=n(s(u,u));s(u,u);for(var T=0;T<3;++T){var A=(T+1)%3,M=(T+2)%3,S=v;t:for(var w=0;w<2;++w){var E=[];if(b[T]<0!=!!w){S[T]=x[w][T];for(var L=0;L<2;++L){S[A]=x[L^w][A];for(var C=0;C<2;++C)S[M]=x[C^L^w][M],E.push(S.slice())}for(var P=y?5:4,L=P;L===P;++L){if(0===E.length)continue t;E=a.positive(E,k[L])}for(var L=0;L<E.length;++L)for(var M=E[L],O=d(v,u,M,r,l),C=0;C<3;++C)_[C].lo=Math.min(_[C].lo,M[C]),_[C].hi=Math.max(_[C].hi,M[C]),C!==T&&(_[C].pixelsPerDataUnit=Math.min(_[C].pixelsPerDataUnit,Math.abs(O[C])))}}}return _};var n=t("extract-frustum-planes"),a=t("split-polygon"),i=t("./lib/cube.js"),o=t("gl-mat4/multiply"),s=t("gl-mat4/transpose"),l=t("gl-vec4/transformMat4"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,a){for(var i=0;i<3;++i){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[i]+=1,l(s,s,e),s[3]<0&&(t[i]=1/0),o[i]-=1,l(o,o,e),o[3]<0&&(t[i]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*a;t[i]=.25*Math.sqrt(u*u+h*h)}return t}var g=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],v=[0,0,0]},{"./lib/cube.js":237,"extract-frustum-planes":226,"gl-mat4/multiply":269,"gl-mat4/transpose":278,"gl-vec4/transformMat4":399,"split-polygon":525}],243:[function(t,e,r){"use strict";var n=t("typedarray-pool"),a=t("ndarray-ops"),i=t("ndarray"),o=["uint8","uint8_clamped","uint16","uint32","int8","int16","int32","float32"];function s(t,e,r,n,a){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=a}var l=s.prototype;function c(t,e,r,n,a,i){var o=a.length*a.BYTES_PER_ELEMENT;if(i<0)return t.bufferData(e,a,n),o;if(o+i>r)throw new Error("gl-buffer: If resizing buffer, must not specify offset");return t.bufferSubData(e,i,a),r}function u(t,e){for(var r=n.malloc(t.length,e),a=t.length,i=0;i<a;++i)r[i]=t[i];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if("number"!=typeof e&&(e=-1),this.bind(),"object"==typeof t&&"undefined"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r="float32"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension("OES_element_index_uint")&&"uint16"!==r?"uint32":"uint16";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=i(s,t.shape);a.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,"uint16"):u(t,"float32"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if("object"==typeof t&&"number"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if("number"!=typeof t&&void 0!==t)throw new Error("gl-buffer: Invalid data type");if(e>=0)throw new Error("gl-buffer: Cannot specify offset when resizing buffer");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error("gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error("gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW");var a=t.createBuffer(),i=new s(t,r,a,0,n);return i.update(e),i}},{ndarray:451,"ndarray-ops":445,"typedarray-pool":543}],244:[function(t,e,r){"use strict";var n=t("gl-vec3");e.exports=function(t,e){var r=t.positions,a=t.vectors,i={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),i;for(var o=0,s=1/0,l=-1/0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=null,d=null,g=[],v=1/0,m=!1,y=0;y<r.length;y++){var x=r[y];s=Math.min(x[0],s),l=Math.max(x[0],l),c=Math.min(x[1],c),u=Math.max(x[1],u),h=Math.min(x[2],h),f=Math.max(x[2],f);var b=a[y];if(n.length(b)>o&&(o=n.length(b)),y){var _=2*n.distance(p,x)/(n.length(d)+n.length(b));_?(v=Math.min(v,_),m=!1):m=!0}m||(p=x,d=b),g.push(b)}var w=[s,c,h],k=[l,u,f];e&&(e[0]=w,e[1]=k),0===o&&(o=1);var T=1/o;isFinite(v)||(v=1),i.vectorScale=v;var A=t.coneSize||.5;t.absoluteConeSize&&(A=t.absoluteConeSize*T),i.coneScale=A;y=0;for(var M=0;y<r.length;y++)for(var S=(x=r[y])[0],E=x[1],L=x[2],C=g[y],P=n.length(C)*T,O=0;O<8;O++){i.positions.push([S,E,L,M++]),i.positions.push([S,E,L,M++]),i.positions.push([S,E,L,M++]),i.positions.push([S,E,L,M++]),i.positions.push([S,E,L,M++]),i.positions.push([S,E,L,M++]),i.vectors.push(C),i.vectors.push(C),i.vectors.push(C),i.vectors.push(C),i.vectors.push(C),i.vectors.push(C),i.vertexIntensity.push(P,P,P),i.vertexIntensity.push(P,P,P);var z=i.positions.length;i.cells.push([z-6,z-5,z-4],[z-3,z-2,z-1])}return i};var a=t("./lib/shaders");e.exports.createMesh=t("./create_mesh"),e.exports.createConeMesh=function(t,r){return e.exports.createMesh(t,r,{shaders:a,traceType:"cone"})}},{"./create_mesh":245,"./lib/shaders":246,"gl-vec3":347}],245:[function(t,e,r){"use strict";var n=t("gl-shader"),a=t("gl-buffer"),i=t("gl-vao"),o=t("gl-texture2d"),s=t("gl-mat4/multiply"),l=t("gl-mat4/invert"),c=t("ndarray"),u=t("colormap"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e,r,n,a,i,o,s,l,c,u){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=a,this.triangleVectors=i,this.triangleColors=s,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=c,this.triangleCount=0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.traceType=u,this.tubeScale=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=h,this._view=h,this._projection=h,this._resolution=[1,1]}var p=f.prototype;p.isOpaque=function(){return this.opacity>=1},p.isTransparent=function(){return this.opacity<1},p.pickSlots=1,p.setPickBase=function(t){this.pickId=t},p.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,"lightPosition"in t&&(this.lightPosition=t.lightPosition),"opacity"in t&&(this.opacity=t.opacity),"ambient"in t&&(this.ambientLight=t.ambient),"diffuse"in t&&(this.diffuseLight=t.diffuse),"specular"in t&&(this.specularLight=t.specular),"roughness"in t&&(this.roughness=t.roughness),"fresnel"in t&&(this.fresnel=t.fresnel),void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=u({colormap:t,nshades:256,format:"rgba"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var a=e[n],i=0;i<3;++i)r[4*n+i]=a[i];r[4*n+3]=255*a[3]}return c(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,a=t.vectors;if(n&&r&&a){var i=[],o=[],s=[],l=[],h=[];this.cells=r,this.positions=n,this.vectors=a;var f=t.meshColor||[1,1,1,1],p=t.vertexIntensity,d=1/0,g=-1/0;if(p)if(t.vertexIntensityBounds)d=+t.vertexIntensityBounds[0],g=+t.vertexIntensityBounds[1];else for(var v=0;v<p.length;++v){var m=p[v];d=Math.min(d,m),g=Math.max(g,m)}else for(v=0;v<n.length;++v){m=n[v][2];d=Math.min(d,m),g=Math.max(g,m)}this.intensity=p||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n),this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(v=0;v<n.length;++v)for(var y=n[v],x=0;x<3;++x)!isNaN(y[x])&&isFinite(y[x])&&(this.bounds[0][x]=Math.min(this.bounds[0][x],y[x]),this.bounds[1][x]=Math.max(this.bounds[1][x],y[x]));var b=0;t:for(v=0;v<r.length;++v){var _=r[v];switch(_.length){case 3:for(x=0;x<3;++x){y=n[k=_[x]];for(var w=0;w<3;++w)if(isNaN(y[w])||!isFinite(y[w]))continue t}for(x=0;x<3;++x){var k;y=n[k=_[2-x]];i.push(y[0],y[1],y[2],y[3]);var T=a[k];o.push(T[0],T[1],T[2],T[3]||0);var A,M=f;3===M.length?s.push(M[0],M[1],M[2],1):s.push(M[0],M[1],M[2],M[3]),A=p?[(p[k]-d)/(g-d),0]:[(y[2]-d)/(g-d),0],l.push(A[0],A[1]),h.push(v)}b+=1}}this.triangleCount=b,this.trianglePositions.update(i),this.triangleVectors.update(o),this.triangleColors.update(s),this.triangleUVs.update(l),this.triangleIds.update(new Uint32Array(h))}},p.drawTransparent=p.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||h,n=t.view||h,a=t.projection||h,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);var c={model:r,view:n,projection:a,inverseModel:h.slice(),clipBounds:i,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,texture:0};c.inverseModel=l(c.inverseModel,c.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);s(u,c.view,c.model),s(u,c.projection,u),l(u,u);for(o=0;o<3;++o)c.eyePosition[o]=u[12+o]/u[15];var f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];c.lightPosition[o]=p/f}if(this.triangleCount>0){var g=this.triShader;g.bind(),g.uniforms=c,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},p.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||h,n=t.view||h,a=t.projection||h,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(a),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:a,clipBounds:i,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind())},p.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3),a={position:n,dataCoordinate:n,index:Math.floor(r[1]/48)};return"cone"===this.traceType?a.index=Math.floor(r[1]/48):"streamtube"===this.traceType&&(a.intensity=this.intensity[r[1]],a.velocity=this.vectors[r[1]].slice(0,3),a.divergence=this.vectors[r[1]][3],a.index=e),a},p.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleIds.dispose()},e.exports=function(t,e,r){var s=r.shaders;1===arguments.length&&(t=(e=t).gl);var l=function(t,e){var r=n(t,e.meshShader.vertex,e.meshShader.fragment,null,e.meshShader.attributes);return r.attributes.position.location=0,r.attributes.color.location=2,r.attributes.uv.location=3,r.attributes.vector.location=4,r}(t,s),u=function(t,e){var r=n(t,e.pickShader.vertex,e.pickShader.fragment,null,e.pickShader.attributes);return r.attributes.position.location=0,r.attributes.id.location=1,r.attributes.vector.location=4,r}(t,s),h=o(t,c(new Uint8Array([255,255,255,255]),[1,1,4]));h.generateMipmap(),h.minFilter=t.LINEAR_MIPMAP_LINEAR,h.magFilter=t.LINEAR;var p=a(t),d=a(t),g=a(t),v=a(t),m=a(t),y=new f(t,h,l,u,p,d,m,g,v,i(t,[{buffer:p,type:t.FLOAT,size:4},{buffer:m,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:v,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:4}]),r.traceType||"cone");return y.update(e),y}},{colormap:127,"gl-buffer":243,"gl-mat4/invert":267,"gl-mat4/multiply":269,"gl-shader":303,"gl-texture2d":323,"gl-vao":328,ndarray:451}],246:[function(t,e,r){var n=t("glslify"),a=n(["precision highp float;\n\nprecision highp float;\n#define GLSLIFY 1\n\nvec3 getOrthogonalVector(vec3 v) {\n  // Return up-vector for only-z vector.\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\n  // Assign z = 0, x = -b, y = a:\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\n    return normalize(vec3(-v.y, v.x, 0.0));\n  } else {\n    return normalize(vec3(0.0, v.z, -v.y));\n  }\n}\n\n// Calculate the cone vertex and normal at the given index.\n//\n// The returned vertex is for a cone with its top at origin and height of 1.0,\n// pointing in the direction of the vector attribute.\n//\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\n// These vertices are used to make up the triangles of the cone by the following:\n//   segment + 0 top vertex\n//   segment + 1 perimeter vertex a+1\n//   segment + 2 perimeter vertex a\n//   segment + 3 center base vertex\n//   segment + 4 perimeter vertex a\n//   segment + 5 perimeter vertex a+1\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\n// To go from index to segment, floor(index / 6)\n// To go from segment to angle, 2*pi * (segment/segmentCount)\n// To go from index to segment index, index - (segment*6)\n//\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\n\n  const float segmentCount = 8.0;\n\n  float index = rawIndex - floor(rawIndex /\n    (segmentCount * 6.0)) *\n    (segmentCount * 6.0);\n\n  float segment = floor(0.001 + index/6.0);\n  float segmentIndex = index - (segment*6.0);\n\n  normal = -normalize(d);\n\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\n    return mix(vec3(0.0), -d, coneOffset);\n  }\n\n  float nextAngle = (\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\n  ) ? 1.0 : 0.0;\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\n\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\n  vec3 v2 = v1 - d;\n\n  vec3 u = getOrthogonalVector(d);\n  vec3 v = normalize(cross(u, d));\n\n  vec3 x = u * cos(angle) * length(d)*0.25;\n  vec3 y = v * sin(angle) * length(d)*0.25;\n  vec3 v3 = v2 + x + y;\n  if (segmentIndex < 3.0) {\n    vec3 tx = u * sin(angle);\n    vec3 ty = v * -cos(angle);\n    vec3 tangent = tx + ty;\n    normal = normalize(cross(v3 - v1, tangent));\n  }\n\n  if (segmentIndex == 0.0) {\n    return mix(d, vec3(0.0), coneOffset);\n  }\n  return v3;\n}\n\nattribute vec3 vector;\nattribute vec4 color, position;\nattribute vec2 uv;\n\nuniform float vectorScale, coneScale, coneOffset;\nuniform mat4 model, view, projection, inverseModel;\nuniform vec3 eyePosition, lightPosition;\n\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  // Scale the vector magnitude to stay constant with\n  // model & view changes.\n  vec3 normal;\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\n\n  //Lighting geometry parameters\n  vec4 cameraCoordinate = view * conePosition;\n  cameraCoordinate.xyz /= cameraCoordinate.w;\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\n\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\n  vec4 t_position  = view * conePosition;\n  gl_Position      = projection * t_position;\n\n  f_color          = color;\n  f_data           = conePosition.xyz;\n  f_position       = position.xyz;\n  f_uv             = uv;\n}\n"]),i=n(["#extension GL_OES_standard_derivatives : enable\n\nprecision highp float;\n#define GLSLIFY 1\n\nfloat beckmannDistribution(float x, float roughness) {\n  float NdotH = max(x, 0.0001);\n  float cos2Alpha = NdotH * NdotH;\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\n  float roughness2 = roughness * roughness;\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\n  return exp(tan2Alpha / roughness2) / denom;\n}\n\nfloat cookTorranceSpecular(\n  vec3 lightDirection,\n  vec3 viewDirection,\n  vec3 surfaceNormal,\n  float roughness,\n  float fresnel) {\n\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\n\n  //Half angle vector\n  vec3 H = normalize(lightDirection + viewDirection);\n\n  //Geometric term\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\n  float VdotH = max(dot(viewDirection, H), 0.000001);\n  float LdotH = max(dot(lightDirection, H), 0.000001);\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\n  float G = min(1.0, min(G1, G2));\n  \n  //Distribution term\n  float D = beckmannDistribution(NdotH, roughness);\n\n  //Fresnel term\n  float F = pow(1.0 - VdotN, fresnel);\n\n  //Multiply terms and done\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\n}\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 clipBounds[2];\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\nuniform sampler2D texture;\n\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\n  vec3 N = normalize(f_normal);\n  vec3 L = normalize(f_lightDirection);\n  vec3 V = normalize(f_eyeDirection);\n\n  if(gl_FrontFacing) {\n    N = -N;\n  }\n\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\n\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\n\n  gl_FragColor = litColor * opacity;\n}\n"]),o=n(["precision highp float;\n\nprecision highp float;\n#define GLSLIFY 1\n\nvec3 getOrthogonalVector(vec3 v) {\n  // Return up-vector for only-z vector.\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\n  // Assign z = 0, x = -b, y = a:\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\n    return normalize(vec3(-v.y, v.x, 0.0));\n  } else {\n    return normalize(vec3(0.0, v.z, -v.y));\n  }\n}\n\n// Calculate the cone vertex and normal at the given index.\n//\n// The returned vertex is for a cone with its top at origin and height of 1.0,\n// pointing in the direction of the vector attribute.\n//\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\n// These vertices are used to make up the triangles of the cone by the following:\n//   segment + 0 top vertex\n//   segment + 1 perimeter vertex a+1\n//   segment + 2 perimeter vertex a\n//   segment + 3 center base vertex\n//   segment + 4 perimeter vertex a\n//   segment + 5 perimeter vertex a+1\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\n// To go from index to segment, floor(index / 6)\n// To go from segment to angle, 2*pi * (segment/segmentCount)\n// To go from index to segment index, index - (segment*6)\n//\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\n\n  const float segmentCount = 8.0;\n\n  float index = rawIndex - floor(rawIndex /\n    (segmentCount * 6.0)) *\n    (segmentCount * 6.0);\n\n  float segment = floor(0.001 + index/6.0);\n  float segmentIndex = index - (segment*6.0);\n\n  normal = -normalize(d);\n\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\n    return mix(vec3(0.0), -d, coneOffset);\n  }\n\n  float nextAngle = (\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\n  ) ? 1.0 : 0.0;\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\n\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\n  vec3 v2 = v1 - d;\n\n  vec3 u = getOrthogonalVector(d);\n  vec3 v = normalize(cross(u, d));\n\n  vec3 x = u * cos(angle) * length(d)*0.25;\n  vec3 y = v * sin(angle) * length(d)*0.25;\n  vec3 v3 = v2 + x + y;\n  if (segmentIndex < 3.0) {\n    vec3 tx = u * sin(angle);\n    vec3 ty = v * -cos(angle);\n    vec3 tangent = tx + ty;\n    normal = normalize(cross(v3 - v1, tangent));\n  }\n\n  if (segmentIndex == 0.0) {\n    return mix(d, vec3(0.0), coneOffset);\n  }\n  return v3;\n}\n\nattribute vec4 vector;\nattribute vec4 position;\nattribute vec4 id;\n\nuniform mat4 model, view, projection;\nuniform float vectorScale, coneScale, coneOffset;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  vec3 normal;\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector.xyz), position.w, coneOffset, normal);\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\n  gl_Position = projection * view * conePosition;\n  f_id        = id;\n  f_position  = position.xyz;\n}\n"]),s=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3  clipBounds[2];\nuniform float pickId;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\n\n  gl_FragColor = vec4(pickId, f_id.xyz);\n}"]);r.meshShader={vertex:a,fragment:i,attributes:[{name:"position",type:"vec4"},{name:"color",type:"vec4"},{name:"uv",type:"vec2"},{name:"vector",type:"vec3"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:"position",type:"vec4"},{name:"id",type:"vec4"},{name:"vector",type:"vec3"}]}},{glslify:410}],247:[function(t,e,r){e.exports={0:"NONE",1:"ONE",2:"LINE_LOOP",3:"LINE_STRIP",4:"TRIANGLES",5:"TRIANGLE_STRIP",6:"TRIANGLE_FAN",256:"DEPTH_BUFFER_BIT",512:"NEVER",513:"LESS",514:"EQUAL",515:"LEQUAL",516:"GREATER",517:"NOTEQUAL",518:"GEQUAL",519:"ALWAYS",768:"SRC_COLOR",769:"ONE_MINUS_SRC_COLOR",770:"SRC_ALPHA",771:"ONE_MINUS_SRC_ALPHA",772:"DST_ALPHA",773:"ONE_MINUS_DST_ALPHA",774:"DST_COLOR",775:"ONE_MINUS_DST_COLOR",776:"SRC_ALPHA_SATURATE",1024:"STENCIL_BUFFER_BIT",1028:"FRONT",1029:"BACK",1032:"FRONT_AND_BACK",1280:"INVALID_ENUM",1281:"INVALID_VALUE",1282:"INVALID_OPERATION",1285:"OUT_OF_MEMORY",1286:"INVALID_FRAMEBUFFER_OPERATION",2304:"CW",2305:"CCW",2849:"LINE_WIDTH",2884:"CULL_FACE",2885:"CULL_FACE_MODE",2886:"FRONT_FACE",2928:"DEPTH_RANGE",2929:"DEPTH_TEST",2930:"DEPTH_WRITEMASK",2931:"DEPTH_CLEAR_VALUE",2932:"DEPTH_FUNC",2960:"STENCIL_TEST",2961:"STENCIL_CLEAR_VALUE",2962:"STENCIL_FUNC",2963:"STENCIL_VALUE_MASK",2964:"STENCIL_FAIL",2965:"STENCIL_PASS_DEPTH_FAIL",2966:"STENCIL_PASS_DEPTH_PASS",2967:"STENCIL_REF",2968:"STENCIL_WRITEMASK",2978:"VIEWPORT",3024:"DITHER",3042:"BLEND",3088:"SCISSOR_BOX",3089:"SCISSOR_TEST",3106:"COLOR_CLEAR_VALUE",3107:"COLOR_WRITEMASK",3317:"UNPACK_ALIGNMENT",3333:"PACK_ALIGNMENT",3379:"MAX_TEXTURE_SIZE",3386:"MAX_VIEWPORT_DIMS",3408:"SUBPIXEL_BITS",3410:"RED_BITS",3411:"GREEN_BITS",3412:"BLUE_BITS",3413:"ALPHA_BITS",3414:"DEPTH_BITS",3415:"STENCIL_BITS",3553:"TEXTURE_2D",4352:"DONT_CARE",4353:"FASTEST",4354:"NICEST",5120:"BYTE",5121:"UNSIGNED_BYTE",5122:"SHORT",5123:"UNSIGNED_SHORT",5124:"INT",5125:"UNSIGNED_INT",5126:"FLOAT",5386:"INVERT",5890:"TEXTURE",6401:"STENCIL_INDEX",6402:"DEPTH_COMPONENT",6406:"ALPHA",6407:"RGB",6408:"RGBA",6409:"LUMINANCE",6410:"LUMINANCE_ALPHA",7680:"KEEP",7681:"REPLACE",7682:"INCR",7683:"DECR",7936:"VENDOR",7937:"RENDERER",7938:"VERSION",9728:"NEAREST",9729:"LINEAR",9984:"NEAREST_MIPMAP_NEAREST",9985:"LINEAR_MIPMAP_NEAREST",9986:"NEAREST_MIPMAP_LINEAR",9987:"LINEAR_MIPMAP_LINEAR",10240:"TEXTURE_MAG_FILTER",10241:"TEXTURE_MIN_FILTER",10242:"TEXTURE_WRAP_S",10243:"TEXTURE_WRAP_T",10497:"REPEAT",10752:"POLYGON_OFFSET_UNITS",16384:"COLOR_BUFFER_BIT",32769:"CONSTANT_COLOR",32770:"ONE_MINUS_CONSTANT_COLOR",32771:"CONSTANT_ALPHA",32772:"ONE_MINUS_CONSTANT_ALPHA",32773:"BLEND_COLOR",32774:"FUNC_ADD",32777:"BLEND_EQUATION_RGB",32778:"FUNC_SUBTRACT",32779:"FUNC_REVERSE_SUBTRACT",32819:"UNSIGNED_SHORT_4_4_4_4",32820:"UNSIGNED_SHORT_5_5_5_1",32823:"POLYGON_OFFSET_FILL",32824:"POLYGON_OFFSET_FACTOR",32854:"RGBA4",32855:"RGB5_A1",32873:"TEXTURE_BINDING_2D",32926:"SAMPLE_ALPHA_TO_COVERAGE",32928:"SAMPLE_COVERAGE",32936:"SAMPLE_BUFFERS",32937:"SAMPLES",32938:"SAMPLE_COVERAGE_VALUE",32939:"SAMPLE_COVERAGE_INVERT",32968:"BLEND_DST_RGB",32969:"BLEND_SRC_RGB",32970:"BLEND_DST_ALPHA",32971:"BLEND_SRC_ALPHA",33071:"CLAMP_TO_EDGE",33170:"GENERATE_MIPMAP_HINT",33189:"DEPTH_COMPONENT16",33306:"DEPTH_STENCIL_ATTACHMENT",33635:"UNSIGNED_SHORT_5_6_5",33648:"MIRRORED_REPEAT",33901:"ALIASED_POINT_SIZE_RANGE",33902:"ALIASED_LINE_WIDTH_RANGE",33984:"TEXTURE0",33985:"TEXTURE1",33986:"TEXTURE2",33987:"TEXTURE3",33988:"TEXTURE4",33989:"TEXTURE5",33990:"TEXTURE6",33991:"TEXTURE7",33992:"TEXTURE8",33993:"TEXTURE9",33994:"TEXTURE10",33995:"TEXTURE11",33996:"TEXTURE12",33997:"TEXTURE13",33998:"TEXTURE14",33999:"TEXTURE15",34000:"TEXTURE16",34001:"TEXTURE17",34002:"TEXTURE18",34003:"TEXTURE19",34004:"TEXTURE20",34005:"TEXTURE21",34006:"TEXTURE22",34007:"TEXTURE23",34008:"TEXTURE24",34009:"TEXTURE25",34010:"TEXTURE26",34011:"TEXTURE27",34012:"TEXTURE28",34013:"TEXTURE29",34014:"TEXTURE30",34015:"TEXTURE31",34016:"ACTIVE_TEXTURE",34024:"MAX_RENDERBUFFER_SIZE",34041:"DEPTH_STENCIL",34055:"INCR_WRAP",34056:"DECR_WRAP",34067:"TEXTURE_CUBE_MAP",34068:"TEXTURE_BINDING_CUBE_MAP",34069:"TEXTURE_CUBE_MAP_POSITIVE_X",34070:"TEXTURE_CUBE_MAP_NEGATIVE_X",34071:"TEXTURE_CUBE_MAP_POSITIVE_Y",34072:"TEXTURE_CUBE_MAP_NEGATIVE_Y",34073:"TEXTURE_CUBE_MAP_POSITIVE_Z",34074:"TEXTURE_CUBE_MAP_NEGATIVE_Z",34076:"MAX_CUBE_MAP_TEXTURE_SIZE",34338:"VERTEX_ATTRIB_ARRAY_ENABLED",34339:"VERTEX_ATTRIB_ARRAY_SIZE",34340:"VERTEX_ATTRIB_ARRAY_STRIDE",34341:"VERTEX_ATTRIB_ARRAY_TYPE",34342:"CURRENT_VERTEX_ATTRIB",34373:"VERTEX_ATTRIB_ARRAY_POINTER",34466:"NUM_COMPRESSED_TEXTURE_FORMATS",34467:"COMPRESSED_TEXTURE_FORMATS",34660:"BUFFER_SIZE",34661:"BUFFER_USAGE",34816:"STENCIL_BACK_FUNC",34817:"STENCIL_BACK_FAIL",34818:"STENCIL_BACK_PASS_DEPTH_FAIL",34819:"STENCIL_BACK_PASS_DEPTH_PASS",34877:"BLEND_EQUATION_ALPHA",34921:"MAX_VERTEX_ATTRIBS",34922:"VERTEX_ATTRIB_ARRAY_NORMALIZED",34930:"MAX_TEXTURE_IMAGE_UNITS",34962:"ARRAY_BUFFER",34963:"ELEMENT_ARRAY_BUFFER",34964:"ARRAY_BUFFER_BINDING",34965:"ELEMENT_ARRAY_BUFFER_BINDING",34975:"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING",35040:"STREAM_DRAW",35044:"STATIC_DRAW",35048:"DYNAMIC_DRAW",35632:"FRAGMENT_SHADER",35633:"VERTEX_SHADER",35660:"MAX_VERTEX_TEXTURE_IMAGE_UNITS",35661:"MAX_COMBINED_TEXTURE_IMAGE_UNITS",35663:"SHADER_TYPE",35664:"FLOAT_VEC2",35665:"FLOAT_VEC3",35666:"FLOAT_VEC4",35667:"INT_VEC2",35668:"INT_VEC3",35669:"INT_VEC4",35670:"BOOL",35671:"BOOL_VEC2",35672:"BOOL_VEC3",35673:"BOOL_VEC4",35674:"FLOAT_MAT2",35675:"FLOAT_MAT3",35676:"FLOAT_MAT4",35678:"SAMPLER_2D",35680:"SAMPLER_CUBE",35712:"DELETE_STATUS",35713:"COMPILE_STATUS",35714:"LINK_STATUS",35715:"VALIDATE_STATUS",35716:"INFO_LOG_LENGTH",35717:"ATTACHED_SHADERS",35718:"ACTIVE_UNIFORMS",35719:"ACTIVE_UNIFORM_MAX_LENGTH",35720:"SHADER_SOURCE_LENGTH",35721:"ACTIVE_ATTRIBUTES",35722:"ACTIVE_ATTRIBUTE_MAX_LENGTH",35724:"SHADING_LANGUAGE_VERSION",35725:"CURRENT_PROGRAM",36003:"STENCIL_BACK_REF",36004:"STENCIL_BACK_VALUE_MASK",36005:"STENCIL_BACK_WRITEMASK",36006:"FRAMEBUFFER_BINDING",36007:"RENDERBUFFER_BINDING",36048:"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE",36049:"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME",36050:"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL",36051:"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE",36053:"FRAMEBUFFER_COMPLETE",36054:"FRAMEBUFFER_INCOMPLETE_ATTACHMENT",36055:"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT",36057:"FRAMEBUFFER_INCOMPLETE_DIMENSIONS",36061:"FRAMEBUFFER_UNSUPPORTED",36064:"COLOR_ATTACHMENT0",36096:"DEPTH_ATTACHMENT",36128:"STENCIL_ATTACHMENT",36160:"FRAMEBUFFER",36161:"RENDERBUFFER",36162:"RENDERBUFFER_WIDTH",36163:"RENDERBUFFER_HEIGHT",36164:"RENDERBUFFER_INTERNAL_FORMAT",36168:"STENCIL_INDEX8",36176:"RENDERBUFFER_RED_SIZE",36177:"RENDERBUFFER_GREEN_SIZE",36178:"RENDERBUFFER_BLUE_SIZE",36179:"RENDERBUFFER_ALPHA_SIZE",36180:"RENDERBUFFER_DEPTH_SIZE",36181:"RENDERBUFFER_STENCIL_SIZE",36194:"RGB565",36336:"LOW_FLOAT",36337:"MEDIUM_FLOAT",36338:"HIGH_FLOAT",36339:"LOW_INT",36340:"MEDIUM_INT",36341:"HIGH_INT",36346:"SHADER_COMPILER",36347:"MAX_VERTEX_UNIFORM_VECTORS",36348:"MAX_VARYING_VECTORS",36349:"MAX_FRAGMENT_UNIFORM_VECTORS",37440:"UNPACK_FLIP_Y_WEBGL",37441:"UNPACK_PREMULTIPLY_ALPHA_WEBGL",37442:"CONTEXT_LOST_WEBGL",37443:"UNPACK_COLORSPACE_CONVERSION_WEBGL",37444:"BROWSER_DEFAULT_WEBGL"}},{}],248:[function(t,e,r){var n=t("./1.0/numbers");e.exports=function(t){return n[t]}},{"./1.0/numbers":247}],249:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e),o=a(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=i(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t("gl-buffer"),a=t("gl-vao"),i=t("./shaders/index"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,a=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var i=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(a[3]*i+a[7]*s+a[11]*l+a[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var a=-1;a<=1;a+=2){var i=[0,0,0];i[(n+e)%3]=a,r.push(i)}t[e]=r}return t}();function h(t,e,r,n){for(var a=u[n],i=0;i<a.length;++i){var o=a[i];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return a.length}l.update=function(t){"lineWidth"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),"capSize"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,"opacity"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var a=[],i=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<i;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],a.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(a,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],a.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(a,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(a)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{"./shaders/index":250,"gl-buffer":243,"gl-vao":328}],250:[function(t,e,r){"use strict";var n=t("glslify"),a=t("gl-shader"),i=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position, offset;\nattribute vec4 color;\nuniform mat4 model, view, projection;\nuniform float capSize;\nvarying vec4 fragColor;\nvarying vec3 fragPosition;\n\nvoid main() {\n  vec4 worldPosition  = model * vec4(position, 1.0);\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\n  gl_Position         = projection * view * worldPosition;\n  fragColor           = color;\n  fragPosition        = position;\n}"]),o=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 clipBounds[2];\nuniform float opacity;\nvarying vec3 fragPosition;\nvarying vec4 fragColor;\n\nvoid main() {\n  if (\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\n    fragColor.a * opacity == 0.\n  ) discard;\n\n  gl_FragColor = opacity * fragColor;\n}"]);e.exports=function(t){return a(t,i,o,null,[{name:"position",type:"vec3"},{name:"color",type:"vec4"},{name:"offset",type:"vec3"}])}},{"gl-shader":303,glslify:410}],251:[function(t,e,r){"use strict";var n=t("gl-texture2d");e.exports=function(t,e,r,n){a||(a=t.FRAMEBUFFER_UNSUPPORTED,i=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension("WEBGL_draw_buffers");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var a=new Array(r),i=0;i<n;++i)a[i]=t.COLOR_ATTACHMENT0+i;for(var i=n;i<r;++i)a[i]=t.NONE;l[n]=a}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if("number"!=typeof e)throw new Error("gl-fbo: Missing shape parameter");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error("gl-fbo: Parameters are too large for FBO");var h=1;if("color"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error("gl-fbo: Must specify a nonnegative number of colors");if(h>1){if(!c)throw new Error("gl-fbo: Multiple draw buffer extension not supported");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error("gl-fbo: Context does not support "+h+" draw buffers")}}var f=t.UNSIGNED_BYTE,p=t.getExtension("OES_texture_float");if(n.float&&h>0){if(!p)throw new Error("gl-fbo: Context does not support floating point textures");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var g=!0;"depth"in n&&(g=!!n.depth);var v=!1;"stencil"in n&&(v=!!n.stencil);return new d(t,e,r,f,h,g,v,c)};var a,i,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case a:throw new Error("gl-fbo: Framebuffer unsupported");case i:throw new Error("gl-fbo: Framebuffer incomplete attachment");case o:throw new Error("gl-fbo: Framebuffer incomplete dimensions");case s:throw new Error("gl-fbo: Framebuffer incomplete missing attachment");default:throw new Error("gl-fbo: Framebuffer failed for unspecified reason")}}function f(t,e,r,a,i,o){if(!a)return null;var s=n(t,e,r,i,a);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,a){var i=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,i),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,a,t.RENDERBUFFER,i),i}function d(t,e,r,n,a,i,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(a);for(var d=0;d<a;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=i,this._useStencil=o;var g=this,v=[0|e,0|r];Object.defineProperties(v,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=v,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),a=t._shape[0],i=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,v=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var m=0;m<o;++m)t.color[m]=f(r,a,i,v,r.RGBA,r.COLOR_ATTACHMENT0+m);0===o?(t._color_rb=p(r,a,i,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension("WEBGL_depth_texture");y?d?t.depth=f(r,a,i,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=f(r,a,i,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,a,i,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,a,i,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,a,i,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),m=0;m<t.color.length;++m)t.color[m].dispose(),t.color[m]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var g=d.prototype;function v(t,e,r){if(t._destroyed)throw new Error("gl-fbo: Can't resize destroyed FBO");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,a=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>a||r<0||r>a)throw new Error("gl-fbo: Can't resize FBO, invalid dimensions");t._shape[0]=e,t._shape[1]=r;for(var i=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,i),h(s)),u(n,i)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error("gl-fbo: Shape vector must be length 2");var e=0|t[0],r=0|t[1];return v(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return v(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,v(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{"gl-texture2d":323}],252:[function(t,e,r){var n=t("sprintf-js").sprintf,a=t("gl-constants/lookup"),i=t("glsl-shader-name"),o=t("add-line-numbers");e.exports=function(t,e,r){"use strict";var s=i(e)||"of unknown name (see npm glsl-shader-name)",l="unknown type";void 0!==r&&(l=r===a.FRAGMENT_SHADER?"fragment":"vertex");for(var c=n("Error compiling %s shader %s:\n",l,s),u=n("%s%s",c,t),h=t.split("\n"),f={},p=0;p<h.length;p++){var d=h[p];if(""!==d&&"\0"!==d){var g=parseInt(d.split(":")[2]);if(isNaN(g))throw new Error(n("Could not parse error: %s",d));f[g]=d}}for(var v=o(e).split("\n"),p=0;p<v.length;p++)if(f[p+3]||f[p+2]||f[p+1]){var m=v[p];if(c+=m+"\n",f[p+1]){var y=f[p+1];y=y.substr(y.split(":",3).join(":").length+1).trim(),c+=n("^^^ %s\n\n",y)}}return{long:c.trim(),short:u.trim()}}},{"add-line-numbers":63,"gl-constants/lookup":248,"glsl-shader-name":402,"sprintf-js":526}],253:[function(t,e,r){"use strict";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),a=o(r,l.pickVertex,l.pickFragment),i=s(r),u=s(r),h=s(r),f=s(r),p=new c(t,n,a,i,u,h,f);return p.update(e),t.addObject(p),p};var n=t("binary-search-bounds"),a=t("iota-array"),i=t("typedarray-pool"),o=t("gl-shader"),s=t("gl-buffer"),l=t("./lib/shaders");function c(t,e,r,n,a,i,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=a,this.colorBuffer=i,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var a=t.gl,i=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=i[2]-i[0],c=i[3]-i[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-i[0])/l-1,u[7]=2*(r[1]-i[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(a.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(a.UNSIGNED_BYTE,!0),a.drawArrays(a.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,a=this.pickShader,i=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=i[2]-i[0],u=i[3]-i[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(i[0]-l[0])/h-1,t[7]=2*(i[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,a.bind();var d=a.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=a.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,a=this.shape[0]*this.shape[1];if(r<n||r>=n+a)return null;var i=r-n,o=this.xData,s=this.yData;return{object:this,pointId:i,dataCoord:[o[i%this.shape[0]],s[i/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||a(e[0]),o=t.y||a(e[1]),s=t.z||new Float32Array(e[0]*e[1]);this.xData=r,this.yData=o;var l=t.colorLevels||[0],c=t.colorValues||[0,0,0,1],u=l.length,h=this.bounds,p=h[0]=r[0],d=h[1]=o[0],g=1/((h[2]=r[r.length-1])-p),v=1/((h[3]=o[o.length-1])-d),m=e[0],y=e[1];this.shape=[m,y];var x=(m-1)*(y-1)*(f.length>>>1);this.numVertices=x;for(var b=i.mallocUint8(4*x),_=i.mallocFloat32(2*x),w=i.mallocUint8(2*x),k=i.mallocUint32(x),T=0,A=0;A<y-1;++A)for(var M=v*(o[A]-d),S=v*(o[A+1]-d),E=0;E<m-1;++E)for(var L=g*(r[E]-p),C=g*(r[E+1]-p),P=0;P<f.length;P+=2){var O,z,I,D,R=f[P],F=f[P+1],B=s[(A+F)*m+(E+R)],N=n.le(l,B);if(N<0)O=c[0],z=c[1],I=c[2],D=c[3];else if(N===u-1)O=c[4*u-4],z=c[4*u-3],I=c[4*u-2],D=c[4*u-1];else{var j=(B-l[N])/(l[N+1]-l[N]),V=1-j,U=4*N,q=4*(N+1);O=V*c[U]+j*c[q],z=V*c[U+1]+j*c[q+1],I=V*c[U+2]+j*c[q+2],D=V*c[U+3]+j*c[q+3]}b[4*T]=255*O,b[4*T+1]=255*z,b[4*T+2]=255*I,b[4*T+3]=255*D,_[2*T]=.5*L+.5*C,_[2*T+1]=.5*M+.5*S,w[2*T]=R,w[2*T+1]=F,k[T]=A*m+E,T+=1}this.positionBuffer.update(_),this.weightBuffer.update(w),this.colorBuffer.update(b),this.idBuffer.update(k),i.free(_),i.free(b),i.free(w),i.free(k)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{"./lib/shaders":254,"binary-search-bounds":255,"gl-buffer":243,"gl-shader":303,"iota-array":417,"typedarray-pool":543}],254:[function(t,e,r){"use strict";var n=t("glslify");e.exports={fragment:n(["precision lowp float;\n#define GLSLIFY 1\nvarying vec4 fragColor;\nvoid main() {\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\n}\n"]),vertex:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 position;\nattribute vec4 color;\nattribute vec2 weight;\n\nuniform vec2 shape;\nuniform mat3 viewTransform;\n\nvarying vec4 fragColor;\n\nvoid main() {\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\n  fragColor = color;\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\n}\n"]),pickFragment:n(["precision mediump float;\n#define GLSLIFY 1\n\nvarying vec4 fragId;\nvarying vec2 vWeight;\n\nuniform vec2 shape;\nuniform vec4 pickOffset;\n\nvoid main() {\n  vec2 d = step(.5, vWeight);\n  vec4 id = fragId + pickOffset;\n  id.x += d.x + d.y*shape.x;\n\n  id.y += floor(id.x / 256.0);\n  id.x -= floor(id.x / 256.0) * 256.0;\n\n  id.z += floor(id.y / 256.0);\n  id.y -= floor(id.y / 256.0) * 256.0;\n\n  id.w += floor(id.z / 256.0);\n  id.z -= floor(id.z / 256.0) * 256.0;\n\n  gl_FragColor = id/255.;\n}\n"]),pickVertex:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 position;\nattribute vec4 pickId;\nattribute vec2 weight;\n\nuniform vec2 shape;\nuniform mat3 viewTransform;\n\nvarying vec4 fragId;\nvarying vec2 vWeight;\n\nvoid main() {\n  vWeight = weight;\n\n  fragId = pickId;\n\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\n}\n"])}},{glslify:410}],255:[function(t,e,r){arguments[4][112][0].apply(r,arguments)},{dup:112}],256:[function(t,e,r){var n=t("glslify"),a=t("gl-shader"),i=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position, nextPosition;\nattribute float arcLength, lineWidth;\nattribute vec4 color;\n\nuniform vec2 screenShape;\nuniform float pixelRatio;\nuniform mat4 model, view, projection;\n\nvarying vec4 fragColor;\nvarying vec3 worldPosition;\nvarying float pixelArcLength;\n\nvec4 project(vec3 p) {\n  return projection * view * model * vec4(p, 1.0);\n}\n\nvoid main() {\n  vec4 startPoint = project(position);\n  vec4 endPoint   = project(nextPosition);\n\n  vec2 A = startPoint.xy / startPoint.w;\n  vec2 B =   endPoint.xy /   endPoint.w;\n\n  float clipAngle = atan(\n    (B.y - A.y) * screenShape.y,\n    (B.x - A.x) * screenShape.x\n  );\n\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\n    sin(clipAngle),\n    -cos(clipAngle)\n  ) / screenShape;\n\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\n\n  worldPosition = position;\n  pixelArcLength = arcLength;\n  fragColor = color;\n}\n"]),o=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3      clipBounds[2];\nuniform sampler2D dashTexture;\nuniform float     dashScale;\nuniform float     opacity;\n\nvarying vec3    worldPosition;\nvarying float   pixelArcLength;\nvarying vec4    fragColor;\n\nvoid main() {\n  if (\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\n    fragColor.a * opacity == 0.\n  ) discard;\n\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\n  if(dashWeight < 0.5) {\n    discard;\n  }\n  gl_FragColor = fragColor * opacity;\n}\n"]),s=n(["precision highp float;\n#define GLSLIFY 1\n\n#define FLOAT_MAX  1.70141184e38\n#define FLOAT_MIN  1.17549435e-38\n\nlowp vec4 encode_float_1540259130(highp float v) {\n  highp float av = abs(v);\n\n  //Handle special cases\n  if(av < FLOAT_MIN) {\n    return vec4(0.0, 0.0, 0.0, 0.0);\n  } else if(v > FLOAT_MAX) {\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\n  } else if(v < -FLOAT_MAX) {\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\n  }\n\n  highp vec4 c = vec4(0,0,0,0);\n\n  //Compute exponent and mantissa\n  highp float e = floor(log2(av));\n  highp float m = av * pow(2.0, -e) - 1.0;\n  \n  //Unpack mantissa\n  c[1] = floor(128.0 * m);\n  m -= c[1] / 128.0;\n  c[2] = floor(32768.0 * m);\n  m -= c[2] / 32768.0;\n  c[3] = floor(8388608.0 * m);\n  \n  //Unpack exponent\n  highp float ebias = e + 127.0;\n  c[0] = floor(ebias / 2.0);\n  ebias -= c[0] * 2.0;\n  c[1] += floor(ebias) * 128.0; \n\n  //Unpack sign bit\n  c[0] += 128.0 * step(0.0, -v);\n\n  //Scale back to range\n  return c / 255.0;\n}\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform float pickId;\nuniform vec3 clipBounds[2];\n\nvarying vec3 worldPosition;\nvarying float pixelArcLength;\nvarying vec4 fragColor;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\n\n  gl_FragColor = vec4(pickId/255.0, encode_float_1540259130(pixelArcLength).xyz);\n}"]),l=[{name:"position",type:"vec3"},{name:"nextPosition",type:"vec3"},{name:"arcLength",type:"float"},{name:"lineWidth",type:"float"},{name:"color",type:"vec4"}];r.createShader=function(t){return a(t,i,o,null,l)},r.createPickShader=function(t){return a(t,i,s,null,l)}},{"gl-shader":303,glslify:410}],257:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=u(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),c=a(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),f=l(new Array(1024),[256,1,4]),p=0;p<1024;++p)f.data[p]=255;var d=i(e,f);d.wrap=e.REPEAT;var g=new v(e,r,o,s,c,d);return g.update(t),g};var n=t("gl-buffer"),a=t("gl-vao"),i=t("gl-texture2d"),o=t("glsl-read-float"),s=t("binary-search-bounds"),l=t("ndarray"),c=t("./lib/shaders"),u=c.createShader,h=c.createPickShader,f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function p(t,e){for(var r=0,n=0;n<3;++n){var a=t[n]-e[n];r+=a*a}return Math.sqrt(r)}function d(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,a,i){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=a,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=i,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var m=v.prototype;m.isTransparent=function(){return this.hasAlpha},m.isOpaque=function(){return!this.hasAlpha},m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.drawTransparent=m.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,clipBounds:d(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,pickId:this.pickId,clipBounds:d(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;"dashScale"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,"opacity"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var a=[],i=[],o=[],c=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var d=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,v=!1;t:for(e=1;e<f.length;++e){var m,y,x,b=f[e-1],_=f[e];for(i.push(c),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&a.length>0){for(var w=0;w<24;++w)a.push(a[a.length-12]);u+=2,v=!0}continue t}h[0][r]=Math.min(h[0][r],b[r],_[r]),h[1][r]=Math.max(h[1][r],b[r],_[r])}Array.isArray(d[0])?(m=d.length>e-1?d[e-1]:d.length>0?d[d.length-1]:[0,0,0,1],y=d.length>e?d[e]:d.length>0?d[d.length-1]:[0,0,0,1]):m=y=d,3===m.length&&(m=[m[0],m[1],m[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&m[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var k=c;if(c+=p(b,_),v){for(r=0;r<2;++r)a.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3]);u+=2,v=!1}a.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3],b[0],b[1],b[2],_[0],_[1],_[2],k,-x,m[0],m[1],m[2],m[3],_[0],_[1],_[2],b[0],b[1],b[2],c,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],c,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(a),i.push(c),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=i,"dashes"in t){var T=t.dashes.slice();for(T.unshift(0),e=1;e<T.length;++e)T[e]=T[e-1]+T[e];var A=l(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)A.set(e,0,r,0);1&s.le(T,T[T.length-1]*e/255)?A.set(e,0,0,0):A.set(e,0,0,255)}this.texture.setPixels(A)}},m.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=o(t.value[0],t.value[1],t.value[2],0),r=s.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],a=this.points[Math.min(r+1,this.points.length-1)],i=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),l=1-i,c=[0,0,0],u=0;u<3;++u)c[u]=l*n[u]+i*a[u];var h=Math.min(i<.5?r:r+1,this.points.length-1);return new g(e,c,h,this.points[h])}},{"./lib/shaders":256,"binary-search-bounds":258,"gl-buffer":243,"gl-texture2d":323,"gl-vao":328,"glsl-read-float":401,ndarray:451}],258:[function(t,e,r){arguments[4][112][0].apply(r,arguments)},{dup:112}],259:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=r*i-a*n;return o?(o=1/o,t[0]=i*o,t[1]=-n*o,t[2]=-a*o,t[3]=r*o,t):null}},{}],260:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=u*o-s*c,f=-u*i+s*l,p=c*i-o*l,d=r*h+n*f+a*p;return d?(d=1/d,t[0]=h*d,t[1]=(-u*n+a*c)*d,t[2]=(s*n-a*o)*d,t[3]=f*d,t[4]=(u*r-a*l)*d,t[5]=(-s*r+a*i)*d,t[6]=p*d,t[7]=(-c*r+n*l)*d,t[8]=(o*r-n*i)*d,t):null}},{}],261:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],262:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],263:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],a=t[3],i=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],g=t[14],v=t[15];return(e*o-r*i)*(h*v-f*g)-(e*s-n*i)*(u*v-f*d)+(e*l-a*i)*(u*g-h*d)+(r*s-n*o)*(c*v-f*p)-(r*l-a*o)*(c*g-h*p)+(n*l-a*s)*(c*d-u*p)}},{}],264:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=r+r,s=n+n,l=a+a,c=r*o,u=n*o,h=n*s,f=a*o,p=a*s,d=a*l,g=i*o,v=i*s,m=i*l;return t[0]=1-h-d,t[1]=u+m,t[2]=f-v,t[3]=0,t[4]=u-m,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=f+v,t[9]=p-g,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],265:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=n+n,l=a+a,c=i+i,u=n*s,h=n*l,f=n*c,p=a*l,d=a*c,g=i*c,v=o*s,m=o*l,y=o*c;return t[0]=1-(p+g),t[1]=h+y,t[2]=f-m,t[3]=0,t[4]=h-y,t[5]=1-(u+g),t[6]=d+v,t[7]=0,t[8]=f+m,t[9]=d-v,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],266:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],267:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-a*o,b=r*c-i*o,_=n*l-a*s,w=n*c-i*s,k=a*c-i*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,L=f*m-p*v,C=y*L-x*E+b*S+_*M-w*A+k*T;if(!C)return null;return C=1/C,t[0]=(s*L-l*E+c*S)*C,t[1]=(a*E-n*L-i*S)*C,t[2]=(g*k-v*w+m*_)*C,t[3]=(f*w-h*k-p*_)*C,t[4]=(l*M-o*L-c*A)*C,t[5]=(r*L-a*M+i*A)*C,t[6]=(v*b-d*k-m*x)*C,t[7]=(u*k-f*b+p*x)*C,t[8]=(o*E-s*M+c*T)*C,t[9]=(n*M-r*E-i*T)*C,t[10]=(d*w-g*b+m*y)*C,t[11]=(h*b-u*w-p*y)*C,t[12]=(s*A-o*S-l*T)*C,t[13]=(r*S-n*A+a*T)*C,t[14]=(g*x-d*_-v*y)*C,t[15]=(u*_-h*x+f*y)*C,t}},{}],268:[function(t,e,r){var n=t("./identity");e.exports=function(t,e,r,a){var i,o,s,l,c,u,h,f,p,d,g=e[0],v=e[1],m=e[2],y=a[0],x=a[1],b=a[2],_=r[0],w=r[1],k=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(v-w)<1e-6&&Math.abs(m-k)<1e-6)return n(t);h=g-_,f=v-w,p=m-k,d=1/Math.sqrt(h*h+f*f+p*p),i=x*(p*=d)-b*(f*=d),o=b*(h*=d)-y*p,s=y*f-x*h,(d=Math.sqrt(i*i+o*o+s*s))?(i*=d=1/d,o*=d,s*=d):(i=0,o=0,s=0);l=f*s-p*o,c=p*i-h*s,u=h*o-f*i,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=i,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(i*g+o*v+s*m),t[13]=-(l*g+c*v+u*m),t[14]=-(h*g+f*v+p*m),t[15]=1,t}},{"./identity":266}],269:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*a+b*l+_*f+w*v,t[2]=x*i+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*a+b*l+_*f+w*v,t[6]=x*i+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*a+b*l+_*f+w*v,t[10]=x*i+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*a+b*l+_*f+w*v,t[14]=x*i+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t}},{}],270:[function(t,e,r){e.exports=function(t,e,r,n,a,i,o){var s=1/(e-r),l=1/(n-a),c=1/(i-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(a+n)*l,t[14]=(o+i)*c,t[15]=1,t}},{}],271:[function(t,e,r){e.exports=function(t,e,r,n,a){var i=1/Math.tan(e/2),o=1/(n-a);return t[0]=i/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=i,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(a+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*a*n*o,t[15]=0,t}},{}],272:[function(t,e,r){e.exports=function(t,e,r,n){var a,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S,E=n[0],L=n[1],C=n[2],P=Math.sqrt(E*E+L*L+C*C);if(Math.abs(P)<1e-6)return null;E*=P=1/P,L*=P,C*=P,a=Math.sin(r),i=Math.cos(r),o=1-i,s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],g=e[8],v=e[9],m=e[10],y=e[11],x=E*E*o+i,b=L*E*o+C*a,_=C*E*o-L*a,w=E*L*o-C*a,k=L*L*o+i,T=C*L*o+E*a,A=E*C*o+L*a,M=L*C*o-E*a,S=C*C*o+i,t[0]=s*x+h*b+g*_,t[1]=l*x+f*b+v*_,t[2]=c*x+p*b+m*_,t[3]=u*x+d*b+y*_,t[4]=s*w+h*k+g*T,t[5]=l*w+f*k+v*T,t[6]=c*w+p*k+m*T,t[7]=u*w+d*k+y*T,t[8]=s*A+h*M+g*S,t[9]=l*A+f*M+v*S,t[10]=c*A+p*M+m*S,t[11]=u*A+d*M+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],273:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=i*a+c*n,t[5]=o*a+u*n,t[6]=s*a+h*n,t[7]=l*a+f*n,t[8]=c*a-i*n,t[9]=u*a-o*n,t[10]=h*a-s*n,t[11]=f*a-l*n,t}},{}],274:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=i*a-c*n,t[1]=o*a-u*n,t[2]=s*a-h*n,t[3]=l*a-f*n,t[8]=i*n+c*a,t[9]=o*n+u*a,t[10]=s*n+h*a,t[11]=l*n+f*a,t}},{}],275:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=i*a+c*n,t[1]=o*a+u*n,t[2]=s*a+h*n,t[3]=l*a+f*n,t[4]=c*a-i*n,t[5]=u*a-o*n,t[6]=h*a-s*n,t[7]=f*a-l*n,t}},{}],276:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],a=r[1],i=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*a,t[5]=e[5]*a,t[6]=e[6]*a,t[7]=e[7]*a,t[8]=e[8]*i,t[9]=e[9]*i,t[10]=e[10]*i,t[11]=e[11]*i,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],277:[function(t,e,r){e.exports=function(t,e,r){var n,a,i,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=a,t[2]=i,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=a*g+l*v+f*m+e[13],t[14]=i*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]);return t}},{}],278:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],a=e[3],i=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=i,t[11]=e[14],t[12]=a,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],279:[function(t,e,r){"use strict";e.exports=function(t,e){switch(e.length){case 0:break;case 1:t[0]=1/e[0];break;case 4:n(t,e);break;case 9:a(t,e);break;case 16:i(t,e);break;default:throw new Error("currently supports matrices up to 4x4")}return t};var n=t("gl-mat2/invert"),a=t("gl-mat3/invert"),i=t("gl-mat4/invert")},{"gl-mat2/invert":259,"gl-mat3/invert":260,"gl-mat4/invert":267}],280:[function(t,e,r){"use strict";var n=t("barycentric"),a=t("polytope-closest-point/lib/closest_point_2d.js");function i(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var a=0;a<4;++a)r[a]+=t[4*n+a]*e[n];return r}function o(t,e,r,n,a){for(var o=i(n,i(r,i(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*a[0]*(1+o[0]),.5*a[1]*(1-o[1])]}e.exports=function(t,e,r,i,s,l){if(1===t.length)return[0,t[0].slice()];for(var c=new Array(t.length),u=0;u<t.length;++u)c[u]=o(t[u],r,i,s,l);for(var h=0,f=1/0,u=0;u<c.length;++u){for(var p=0,d=0;d<2;++d)p+=Math.pow(c[u][d]-e[d],2);p<f&&(f=p,h=u)}for(var g=function(t,e){if(2===t.length){for(var r=0,i=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),i+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),i=Math.sqrt(i),r+i<1e-6?[1,0]:[i/(r+i),r/(i+r)]}if(3===t.length){var s=[0,0];return a(t[0],t[1],t[2],e,s),n(t,s)}return[]}(c,e),v=0,u=0;u<3;++u){if(g[u]<-.001||g[u]>1.0001)return null;v+=g[u]}if(Math.abs(v-1)>.001)return null;return[h,function(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var a=t[n],i=e[n],o=0;o<3;++o)r[o]+=i*a[o];return r}(t,g),g]}},{barycentric:74,"polytope-closest-point/lib/closest_point_2d.js":482}],281:[function(t,e,r){var n=t("glslify"),a=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position, normal;\nattribute vec4 color;\nattribute vec2 uv;\n\nuniform mat4 model\n           , view\n           , projection\n           , inverseModel;\nuniform vec3 eyePosition\n           , lightPosition;\n\nvarying vec3 f_normal\n           , f_lightDirection\n           , f_eyeDirection\n           , f_data;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvec4 project(vec3 p) {\n  return projection * view * model * vec4(p, 1.0);\n}\n\nvoid main() {\n  gl_Position      = project(position);\n\n  //Lighting geometry parameters\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\n  cameraCoordinate.xyz /= cameraCoordinate.w;\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\n\n  f_color          = color;\n  f_data           = position;\n  f_uv             = uv;\n}\n"]),i=n(["#extension GL_OES_standard_derivatives : enable\n\nprecision highp float;\n#define GLSLIFY 1\n\nfloat beckmannDistribution(float x, float roughness) {\n  float NdotH = max(x, 0.0001);\n  float cos2Alpha = NdotH * NdotH;\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\n  float roughness2 = roughness * roughness;\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\n  return exp(tan2Alpha / roughness2) / denom;\n}\n\nfloat cookTorranceSpecular(\n  vec3 lightDirection,\n  vec3 viewDirection,\n  vec3 surfaceNormal,\n  float roughness,\n  float fresnel) {\n\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\n\n  //Half angle vector\n  vec3 H = normalize(lightDirection + viewDirection);\n\n  //Geometric term\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\n  float VdotH = max(dot(viewDirection, H), 0.000001);\n  float LdotH = max(dot(lightDirection, H), 0.000001);\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\n  float G = min(1.0, min(G1, G2));\n  \n  //Distribution term\n  float D = beckmannDistribution(NdotH, roughness);\n\n  //Fresnel term\n  float F = pow(1.0 - VdotN, fresnel);\n\n  //Multiply terms and done\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\n}\n\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 clipBounds[2];\nuniform float roughness\n            , fresnel\n            , kambient\n            , kdiffuse\n            , kspecular;\nuniform sampler2D texture;\n\nvarying vec3 f_normal\n           , f_lightDirection\n           , f_eyeDirection\n           , f_data;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  if (f_color.a == 0.0 ||\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\n  ) discard;\n\n  vec3 N = normalize(f_normal);\n  vec3 L = normalize(f_lightDirection);\n  vec3 V = normalize(f_eyeDirection);\n\n  if(gl_FrontFacing) {\n    N = -N;\n  }\n\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\n\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\n\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\n\n  gl_FragColor = litColor * f_color.a;\n}\n"]),o=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\nattribute vec4 color;\nattribute vec2 uv;\n\nuniform mat4 model, view, projection;\n\nvarying vec4 f_color;\nvarying vec3 f_data;\nvarying vec2 f_uv;\n\nvoid main() {\n  gl_Position = projection * view * model * vec4(position, 1.0);\n  f_color = color;\n  f_data  = position;\n  f_uv    = uv;\n}"]),s=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 clipBounds[2];\nuniform sampler2D texture;\nuniform float opacity;\n\nvarying vec4 f_color;\nvarying vec3 f_data;\nvarying vec2 f_uv;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\n\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\n}"]),l=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nattribute vec3 position;\nattribute vec4 color;\nattribute vec2 uv;\nattribute float pointSize;\n\nuniform mat4 model, view, projection;\nuniform vec3 clipBounds[2];\n\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\n\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\n  } else {\n    gl_Position = projection * view * model * vec4(position, 1.0);\n  }\n  gl_PointSize = pointSize;\n  f_color = color;\n  f_uv = uv;\n}"]),c=n(["precision highp float;\n#define GLSLIFY 1\n\nuniform sampler2D texture;\nuniform float opacity;\n\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\n  if(dot(pointR, pointR) > 0.25) {\n    discard;\n  }\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\n}"]),u=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\nattribute vec4 id;\n\nuniform mat4 model, view, projection;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  gl_Position = projection * view * model * vec4(position, 1.0);\n  f_id        = id;\n  f_position  = position;\n}"]),h=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3  clipBounds[2];\nuniform float pickId;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\n\n  gl_FragColor = vec4(pickId, f_id.xyz);\n}"]),f=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nattribute vec3  position;\nattribute float pointSize;\nattribute vec4  id;\n\nuniform mat4 model, view, projection;\nuniform vec3 clipBounds[2];\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\n\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\n  } else {\n    gl_Position  = projection * view * model * vec4(position, 1.0);\n    gl_PointSize = pointSize;\n  }\n  f_id         = id;\n  f_position   = position;\n}"]),p=n(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec3 position;\n\nuniform mat4 model, view, projection;\n\nvoid main() {\n  gl_Position = projection * view * model * vec4(position, 1.0);\n}"]),d=n(["precision highp float;\n#define GLSLIFY 1\n\nuniform vec3 contourColor;\n\nvoid main() {\n  gl_FragColor = vec4(contourColor, 1.0);\n}\n"]);r.meshShader={vertex:a,fragment:i,attributes:[{name:"position",type:"vec3"},{name:"normal",type:"vec3"},{name:"color",type:"vec4"},{name:"uv",type:"vec2"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:"position",type:"vec3"},{name:"color",type:"vec4"},{name:"uv",type:"vec2"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:"position",type:"vec3"},{name:"color",type:"vec4"},{name:"uv",type:"vec2"},{name:"pointSize",type:"float"}]},r.pickShader={vertex:u,fragment:h,attributes:[{name:"position",type:"vec3"},{name:"id",type:"vec4"}]},r.pointPickShader={vertex:f,fragment:h,attributes:[{name:"position",type:"vec3"},{name:"pointSize",type:"float"},{name:"id",type:"vec4"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:"position",type:"vec3"}]}},{glslify:410}],282:[function(t,e,r){"use strict";var n=t("gl-shader"),a=t("gl-buffer"),i=t("gl-vao"),o=t("gl-texture2d"),s=t("normals"),l=t("gl-mat4/multiply"),c=t("gl-mat4/invert"),u=t("ndarray"),h=t("colormap"),f=t("simplicial-complex-contour"),p=t("typedarray-pool"),d=t("./lib/shaders"),g=t("./lib/closest-point"),v=d.meshShader,m=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function k(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,k,T,A,M,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=a,this.pickShader=i,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=v,this.edgeUVs=m,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=k,this.pointSizes=T,this.pointIds=b,this.pointVAO=A,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=M,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var T=k.prototype;function A(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function M(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function S(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function E(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function L(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}T.isOpaque=function(){return!this.hasAlpha},T.isTransparent=function(){return this.hasAlpha},T.pickSlots=1,T.setPickBase=function(t){this.pickId=t},T.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,a=e.vertexWeights,i=r.length,o=p.mallocFloat32(6*i),s=0,l=0;l<i;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=a[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},T.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,"contourEnable"in t&&(this.contourEnable=t.contourEnable),"contourColor"in t&&(this.contourColor=t.contourColor),"lineWidth"in t&&(this.lineWidth=t.lineWidth),"lightPosition"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,"opacity"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),"opacityscale"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),"ambient"in t&&(this.ambientLight=t.ambient),"diffuse"in t&&(this.diffuseLight=t.diffuse),"specular"in t&&(this.specularLight=t.specular),"roughness"in t&&(this.roughness=t.roughness),"fresnel"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:"rgba"}),n=new Uint8Array(1024),a=0;a<256;++a){for(var i=r[a],o=0;o<3;++o)n[4*a+o]=i[o];n[4*a+3]=e?255*A(a/255,e):255*i[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var a=[],i=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,k=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,M=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!k&&(k=s.faceNormals(r,n,M)),k||w||(w=s.vertexNormals(r,n,T));var S=t.vertexColors,E=t.cellColors,L=t.meshColor||[1,1,1,1],C=t.vertexUVs,P=t.vertexIntensity,O=t.cellUVs,z=t.cellIntensity,I=1/0,D=-1/0;if(!C&&!O)if(P)if(t.vertexIntensityBounds)I=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];I=Math.min(I,F),D=Math.max(D,F)}else if(z)for(R=0;R<z.length;++R){F=z[R];I=Math.min(I,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];I=Math.min(I,F),D=Math.max(D,F)}this.intensity=P||(z?function(t,e,r){for(var n=new Array(e),a=0;a<e;++a)n[a]=0;var i=t.length;for(a=0;a<i;++a)for(var o=t[a],s=0;s<o.length;++s)n[o[s]]=r[a];return n}(r,n.length,z):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],V=0;V<3;++V)!isNaN(j[V])&&isFinite(j[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],j[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],j[V]));var U=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],V=0;V<3;++V)if(isNaN(j[V])||!isFinite(j[V]))continue t;m.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:L,this.opacityscale&&P?i.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=C?C[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(V=0;V<2;++V){j=n[W=G[V]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(V=0;V<2;++V){j=n[W=G[V]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:L,this.opacityscale&&P?i.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=C?C[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],g.push(Z[0],Z[1]),v.push(R)}q+=1;break;case 3:for(V=0;V<3;++V)for(j=n[W=G[V]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(V=0;V<3;++V){var W,X,Z,J;j=n[W=G[2-V]];a.push(j[0],j[1],j[2]),(X=S?S[W]:E?E[R]:L)?this.opacityscale&&P?i.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?i.push(X[0],X[1],X[2],this.opacity):(i.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)):i.push(.5,.5,.5,1),Z=C?C[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],c.push(Z[0],Z[1]),J=w?w[W]:k[R],l.push(J[0],J[1],J[2]),f.push(R)}U+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=U,this.pointPositions.update(m),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(v)),this.trianglePositions.update(a),this.triangleColors.update(i),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},T.drawTransparent=T.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,a=t.projection||w,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:a,inverseModel:w.slice(),clipBounds:i,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},T.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,a=t.projection||w,i=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)i[0][o]=Math.max(i[0][o],this.clipBounds[0][o]),i[1][o]=Math.min(i[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(a),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:a,clipBounds:i,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},T.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,a=new Array(r.length),i=0;i<r.length;++i)a[i]=n[r[i]];var o=g(a,[t.coord[0],this._resolution[1]-t.coord[1]],this._model,this._view,this._projection,this._resolution);if(!o)return null;var s=o[2],l=0;for(i=0;i<r.length;++i)l+=s[i]*this.intensity[r[i]];return{position:o[1],index:r[o[0]],cell:r,cellId:e,intensity:l,dataCoordinate:this.positions[r[o[0]]]}},T.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension("OES_standard_derivatives")||t.getExtension("MOZ_OES_standard_derivatives")||t.getExtension("WEBKIT_OES_standard_derivatives")))throw new Error("derivatives not supported");var r=function(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=M(t),c=S(t),h=E(t),f=L(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=a(t),g=a(t),y=a(t),x=a(t),b=a(t),_=i(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:b,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:y,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=a(t),T=a(t),A=a(t),C=a(t),P=i(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:A,type:t.FLOAT,size:2}]),O=a(t),z=a(t),I=a(t),D=a(t),R=a(t),F=i(t,[{buffer:O,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:I,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=a(t),N=new k(t,p,r,s,l,c,h,f,d,b,g,y,x,_,w,C,T,A,P,O,R,z,I,D,F,B,i(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},{"./lib/closest-point":280,"./lib/shaders":281,colormap:127,"gl-buffer":243,"gl-mat4/invert":267,"gl-mat4/multiply":269,"gl-shader":303,"gl-texture2d":323,"gl-vao":328,ndarray:451,normals:454,"simplicial-complex-contour":516,"typedarray-pool":543}],283:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=a(e,i.boxVert,i.lineFrag);return new o(t,r,s)};var n=t("gl-buffer"),a=t("gl-shader"),i=t("./shaders");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,a){var i=this.plot,o=this.shader,c=i.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=a,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{"./shaders":286,"gl-buffer":243,"gl-shader":303}],284:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e),i=a(e,o.gridVert,o.gridFrag),l=a(e,o.tickVert,o.gridFrag);return new s(t,r,i,l)};var n=t("gl-buffer"),a=t("gl-shader"),i=t("binary-search-bounds"),o=t("./shaders");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,a=t.gl,i=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var v=i[g],m=i[g+2]-v,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*m/x,c[g]=2*(v-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){h[0]=h[1]=0,h[g]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=f[g];var _=6*n[g].length;p[g]&&_&&a.drawArrays(a.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],a=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,v=s.pixelRatio,m=s.screenBox,y=m[2]-m[0],x=m[3]-m[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var k=p[w],T=p[w+2]-k,A=.5*(d[w+2]+d[w]),M=d[w+2]-d[w];e[w]=2*T/M,t[w]=2*(k-A)/M}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,L=s.tickMarkWidth,C=s.tickMarkColor,P=6*h[0].length,O=Math.min(i.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(i.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),I=0+6*O,D=6*Math.max(0,z-O),R=Math.min(i.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(i.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=P+6*R,N=6*Math.max(0,F-R);a[0]=2*(g[0]-E[1])/y-1,a[1]=(g[3]+g[1])/x-1,o[0]=E[1]*v/y,o[1]=L[1]*v/x,N&&(S.color=C[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=a,f.drawArrays(f.TRIANGLES,B,N)),a[0]=(g[2]+g[0])/y-1,a[1]=2*(g[1]-E[0])/x-1,o[0]=L[0]*v/y,o[1]=E[0]*v/x,D&&(S.color=C[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=a,f.drawArrays(f.TRIANGLES,I,D)),a[0]=2*(g[2]+E[3])/y-1,a[1]=(g[3]+g[1])/x-1,o[0]=E[3]*v/y,o[1]=L[3]*v/x,N&&(S.color=C[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=a,f.drawArrays(f.TRIANGLES,B,N)),a[0]=(g[2]+g[0])/y-1,a[1]=2*(g[3]+E[2])/x-1,o[0]=L[2]*v/y,o[1]=E[2]*v/x,D&&(S.color=C[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=a,f.drawArrays(f.TRIANGLES,I,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),a=(this.plot.zeroLineEnable,0),i=[[],[]],o=0;o<2;++o)for(var s=i[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[a++]=d,n[a++]=f[g],n[a++]=p[g]}this.ticks=i,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{"./shaders":286,"binary-search-bounds":288,"gl-buffer":243,"gl-shader":303}],285:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=a(e,i.lineVert,i.lineFrag);return new o(t,r,s)};var n=t("gl-buffer"),a=t("gl-shader"),i=t("./shaders");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,a,i){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=a*o.pixelRatio,c.uniforms.color=i,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{"./shaders":286,"gl-buffer":243,"gl-shader":303}],286:[function(t,e,r){"use strict";var n=t("glslify"),a=n(["precision lowp float;\n#define GLSLIFY 1\nuniform vec4 color;\nvoid main() {\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\n}\n"]);e.exports={lineVert:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 coord;\n\nuniform vec4 screenBox;\nuniform vec2 start, end;\nuniform float width;\n\nvec2 perp(vec2 v) {\n  return vec2(v.y, -v.x);\n}\n\nvec2 screen(vec2 v) {\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\n}\n\nvoid main() {\n  vec2 delta = normalize(perp(start - end));\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\n}\n"]),lineFrag:a,textVert:n(["#define GLSLIFY 1\nattribute vec3 textCoordinate;\n\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\nuniform float angle;\n\nvoid main() {\n  float dataOffset  = textCoordinate.z;\n  vec2 glyphOffset  = textCoordinate.xy;\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\n    glyphMatrix * glyphOffset * textScale + screenOffset;\n  gl_Position = vec4(screenCoordinate, 0, 1);\n}\n"]),textFrag:a,gridVert:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec3 dataCoord;\n\nuniform vec2 dataAxis, dataShift, dataScale;\nuniform float lineWidth;\n\nvoid main() {\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\n  gl_Position = vec4(pos, 0, 1);\n}\n"]),gridFrag:a,boxVert:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 coord;\n\nuniform vec4 screenBox;\nuniform vec2 lo, hi;\n\nvec2 screen(vec2 v) {\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\n}\n\nvoid main() {\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\n}\n"]),tickVert:n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec3 dataCoord;\n\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\n\nvoid main() {\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\n}\n"])}},{glslify:410}],287:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e),i=a(e,s.textVert,s.textFrag);return new l(t,r,i)};var n=t("gl-buffer"),a=t("gl-shader"),i=t("text-cache"),o=t("binary-search-bounds"),s=t("./shaders");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],a=this.tickOffset[t],i=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,v=e.tickColor,m=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],k=this.labelCount[t],T=o.lt(n,l[t]),A=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var M=2/f[2+(1^t)]-f[1^t];u[1^t]=M*s[1^t]-1,d[t]&&(u[1^t]-=M*p*g[t],T<A&&a[A]>a[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t],r.uniforms.angle=m[t],i.drawArrays(i.TRIANGLES,a[T],a[A]-a[T]))),y[t]&&k&&(u[1^t]-=M*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],i.drawArrays(i.TRIANGLES,w,k)),u[1^t]=M*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=M*p*g[t+2],T<A&&a[A]>a[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t+2],r.uniforms.angle=m[t+2],i.drawArrays(i.TRIANGLES,a[T],a[A]-a[T]))),y[t+2]&&k&&(u[1^t]+=M*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],i.drawArrays(i.TRIANGLES,w,k))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,a=r.gl,i=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-i[u])/(i[2+u]-i[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,a.drawArrays(a.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,a=t.screenBox,i=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=i[o],g=i[o+2]-h,v=a[o],m=a[o+2]-v;p[o]=2*l/u*g/m,f[o]=2*(s-c)/u*g/m}d[1]=2*t.pixelRatio/(a[3]-a[1]),d[0]=d[1]*(a[3]-a[1])/(a[2]-a[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,a,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,g=p.text,v=p.font||"sans-serif";a=p.fontSize||12;for(var m=1/(c[o+2]-c[o]),y=c[o],x=g.split("\n"),b=0;b<x.length;b++)for(n=i(v,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*a,-n[r+1]*a-b*a*1.2,(d-y)*m);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=i(t.labelFont[o],t.labels[o],{textAlign:"center"}).data,a=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*a,-n[e+1]*a,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=i(t.titleFont,t.title).data,a=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*a,-n[e+1]*a,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{"./shaders":286,"binary-search-bounds":288,"gl-buffer":243,"gl-shader":303,"text-cache":534}],288:[function(t,e,r){arguments[4][112][0].apply(r,arguments)},{dup:112}],289:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=a(c),c.text=i(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t("gl-select-static"),a=t("./lib/grid"),i=t("./lib/text"),o=t("./lib/line"),s=t("./lib/box");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,a=this.pixelRatio,i=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),i.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],f[d]):o.drawLine(e[0],g,e[2],g,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var v=this.borderLineEnable,m=this.borderLineWidth,y=this.borderLineColor;for(v[1]&&o.drawLine(r[0],r[1]-.5*m[1]*a,r[0],r[3]+.5*m[3]*a,m[1],y[1]),v[0]&&o.drawLine(r[0]-.5*m[0]*a,r[1],r[2]+.5*m[2]*a,r[1],m[0],y[0]),v[3]&&o.drawLine(r[2],r[1]-.5*m[1]*a,r[2],r[3]+.5*m[3]*a,m[3],y[3]),v[2]&&o.drawLine(r[0]-.5*m[0]*a,r[3],r[2]+.5*m[2]*a,r[3],m[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl;this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,a=this.viewBox,i=0|Math.round((t-a[0]/r)*n),o=0|Math.round((e-a[1]/r)*n),s=this.pickBuffer.query(i,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(i,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,a=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/a,10,10/a]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!("titleEnable"in t&&!t.titleEnable),this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var i=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=i[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:i}),this.text.update({bounds:o,ticks:i,labels:t.labels||["x","y"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||["sans-serif","sans-serif"],title:t.title||"",titleSize:t.titleSize||18,titleFont:t.titleFont||"sans-serif"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{"./lib/box":283,"./lib/grid":284,"./lib/line":285,"./lib/text":287,"gl-select-static":302}],290:[function(t,e,r){"use strict";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];"distanceLimits"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);"zoomMin"in e&&(r[0]=e.zoomMin);"zoomMax"in e&&(r[1]=e.zoomMax);var c=a({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||"orbit",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:"rotate",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&"orthographic"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,a=e-2*r;c.idle(e-r),c.recalcMatrix(a),c.flush(e-(100+2*r));for(var i=!0,o=c.computedMatrix,s=0;s<16;++s)i=i&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,i?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),a=c.computedCenter.slice();if(c.setMode(t),"turntable"===t){var i=n();c._active.lookAt(i,r,a,e),c._active.lookAt(i+500,r,a,[0,0,1]),c._active.flush(i)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener("contextmenu",function(t){return t.preventDefault(),!1}),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,a,i){var o=d.keyBindingMode;if(!1!==o){var s="rotate"===o,l="pan"===o,u="zoom"===o,f=!!i.control,p=!!i.alt,g=!!i.shift,v=!!(1&e),m=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(a-d._lastY),w=d.flipX?1:-1,k=d.flipY?1:-1,T=Math.PI*d.rotateSpeed,A=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&v&&!f&&!p&&!g||v&&!f&&!p&&g)&&c.rotate(A,w*T*b,-k*T*_,0),(l&&v&&!f&&!p&&!g||m||v&&f&&!p&&!g)&&c.pan(A,-d.translateSpeed*b*h,d.translateSpeed*_*h,0),u&&v&&!f&&!p&&!g||y||v&&!f&&p&&!g)){var M=-d.zoomSpeed*_/window.innerHeight*(A-c.lastT())*100;c.pan(A,0,0,h*(Math.exp(M)-1))}return d._lastX=r,d._lastY=a,d._lastMods=i,!0}}d.mouseListener=i(t,e),t.addEventListener("touchstart",function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener("touchmove",function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener("touchend",function(t){e(0,d._lastX,d._lastY,d._lastMods),t.preventDefault()},!!l&&{passive:!1}),d.wheelListener=o(t,function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,a=d.flipY?1:-1,i=n();if(Math.abs(t)>Math.abs(e))c.rotate(i,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*a*e/window.innerHeight*(i-c.lastT())/20;c.pan(i,0,0,h*(Math.exp(o)-1))}}},!0)},d.enableMouseListeners(),d};var n=t("right-now"),a=t("3d-view"),i=t("mouse-change"),o=t("mouse-wheel"),s=t("mouse-event-offset"),l=t("has-passive-events")},{"3d-view":54,"has-passive-events":412,"mouse-change":436,"mouse-event-offset":437,"mouse-wheel":439,"right-now":502}],291:[function(t,e,r){var n=t("glslify"),a=t("gl-shader"),i=n(["precision mediump float;\n#define GLSLIFY 1\nattribute vec2 position;\nvarying vec2 uv;\nvoid main() {\n  uv = position;\n  gl_Position = vec4(position, 0, 1);\n}"]),o=n(["precision mediump float;\n#define GLSLIFY 1\n\nuniform sampler2D accumBuffer;\nvarying vec2 uv;\n\nvoid main() {\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\n  gl_FragColor = min(vec4(1,1,1,1), accum);\n}"]);e.exports=function(t){return a(t,i,o,null,[{name:"position",type:"vec2"}])}},{"gl-shader":303,glslify:410}],292:[function(t,e,r){"use strict";var n=t("./camera.js"),a=t("gl-axes3d"),i=t("gl-axes3d/properties"),o=t("gl-spikes3d"),s=t("gl-select-static"),l=t("gl-fbo"),c=t("a-big-triangle"),u=t("mouse-change"),h=t("gl-mat4/perspective"),f=t("gl-mat4/ortho"),p=t("./lib/shader"),d=t("is-mobile")({tablet:!0});function g(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function v(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function m(t){return"boolean"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e)if(e=document.createElement("canvas"),t.container){var r=t.container;r.appendChild(e)}else document.body.appendChild(e);var y=t.gl;y||(y=function(t,e){var r=null;try{(r=t.getContext("webgl",e))||(r=t.getContext("experimental-webgl",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:d}));if(!y)throw new Error("webgl not supported");var x=t.bounds||[[-10,-10,-10],[10,10,10]],b=new g,_=l(y,[y.drawingBufferWidth,y.drawingBufferHeight],{preferFloat:!d}),w=p(y),k=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&"orthographic"===t.camera.projection.type||!1,T={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||"turntable",_ortho:k},A=t.axes||{},M=a(y,A);M.enable=!A.disable;var S=t.spikes||{},E=o(y,S),L=[],C=[],P=[],O=[],z=!0,I=!0,D=new Array(16),R=new Array(16),F={view:null,projection:D,model:R,_ortho:!1},I=!0,B=[y.drawingBufferWidth,y.drawingBufferHeight],N=t.cameraObject||n(e,T),j={gl:y,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:b,camera:N,axes:M,axesPixels:null,spikes:E,bounds:x,objects:L,shape:B,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:m(t.autoResize),autoBounds:m(t.autoBounds),autoScale:!!t.autoScale,autoCenter:m(t.autoCenter),clipToBounds:m(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:F,oncontextloss:null,mouseListener:null,_stopped:!1,getAspectratio:function(){return{x:this.aspect[0],y:this.aspect[1],z:this.aspect[2]}},setAspectratio:function(t){this.aspect[0]=t.x,this.aspect[1]=t.y,this.aspect[2]=t.z}},V=[y.drawingBufferWidth/j.pixelRatio|0,y.drawingBufferHeight/j.pixelRatio|0];function U(){if(!j._stopped&&j.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var a=0|Math.ceil(r*j.pixelRatio),i=0|Math.ceil(n*j.pixelRatio);if(a!==e.width||i!==e.height){e.width=a,e.height=i;var o=e.style;o.position=o.position||"absolute",o.left="0px",o.top="0px",o.width=r+"px",o.height=n+"px",z=!0}}}j.autoResize&&U();function q(){for(var t=L.length,e=O.length,r=0;r<e;++r)P[r]=0;t:for(var r=0;r<t;++r){var n=L[r],a=n.pickSlots;if(a){for(var i=0;i<e;++i)if(P[i]+a<255){C[r]=i,n.setPickBase(P[i]+1),P[i]+=a;continue t}var o=s(y,B);C[r]=e,O.push(o),P.push(a),n.setPickBase(1),e+=1}else C[r]=-1}for(;e>0&&0===P[e-1];)P.pop(),O.pop().dispose()}function H(){if(j.contextLost)return!0;y.isContextLost()&&(j.contextLost=!0,j.mouseListener.enabled=!1,j.selection.object=null,j.oncontextloss&&j.oncontextloss())}window.addEventListener("resize",U),j.update=function(t){j._stopped||(t=t||{},z=!0,I=!0)},j.add=function(t){j._stopped||(t.axes=M,L.push(t),C.push(-1),z=!0,I=!0,q())},j.remove=function(t){if(!j._stopped){var e=L.indexOf(t);e<0||(L.splice(e,1),C.pop(),z=!0,I=!0,q())}},j.dispose=function(){if(!j._stopped&&(j._stopped=!0,window.removeEventListener("resize",U),e.removeEventListener("webglcontextlost",H),j.mouseListener.enabled=!1,!j.contextLost)){M.dispose(),E.dispose();for(var t=0;t<L.length;++t)L[t].dispose();_.dispose();for(var t=0;t<O.length;++t)O[t].dispose();w.dispose(),y=null,M=null,E=null,L=[]}},j._mouseRotating=!1,j._prevButtons=0,j.enableMouseListeners=function(){j.mouseListener=u(e,function(t,e,r){if(!j._stopped){var n=O.length,a=L.length,i=b.object;b.distance=1/0,b.mouse[0]=e,b.mouse[1]=r,b.object=null,b.screen=null,b.dataCoordinate=b.dataPosition=null;var o=!1;if(t&&j._prevButtons)j._mouseRotating=!0;else{j._mouseRotating&&(I=!0),j._mouseRotating=!1;for(var s=0;s<n;++s){var l=O[s].query(e,V[1]-r-1,j.pickRadius);if(l){if(l.distance>b.distance)continue;for(var c=0;c<a;++c){var u=L[c];if(C[c]===s){var h=u.pick(l);h&&(b.buttons=t,b.screen=l.coord,b.distance=l.distance,b.object=u,b.index=h.distance,b.dataPosition=h.position,b.dataCoordinate=h.dataCoordinate,b.data=h,o=!0)}}}}}i&&i!==b.object&&(i.highlight&&i.highlight(null),z=!0),b.object&&(b.object.highlight&&b.object.highlight(b.data),z=!0),(o=o||b.object!==i)&&j.onselect&&j.onselect(b),1&t&&!(1&j._prevButtons)&&j.onclick&&j.onclick(b),j._prevButtons=t}})},e.addEventListener("webglcontextlost",H);var G=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],Y=[G[0].slice(),G[1].slice()];function W(){if(!H()){U();var t=j.camera.tick();F.view=j.camera.matrix,z=z||t,I=I||t,M.pixelRatio=j.pixelRatio,E.pixelRatio=j.pixelRatio;var e=L.length,r=G[0],n=G[1];r[0]=r[1]=r[2]=1/0,n[0]=n[1]=n[2]=-1/0;for(var a=0;a<e;++a){var o=L[a];o.pixelRatio=j.pixelRatio,o.axes=j.axes,z=z||!!o.dirty,I=I||!!o.dirty;var s=o.bounds;if(s)for(var l=s[0],u=s[1],p=0;p<3;++p)r[p]=Math.min(r[p],l[p]),n[p]=Math.max(n[p],u[p])}var d=j.bounds;if(j.autoBounds)for(var p=0;p<3;++p){if(n[p]<r[p])r[p]=-1,n[p]=1;else{r[p]===n[p]&&(r[p]-=1,n[p]+=1);var g=.05*(n[p]-r[p]);r[p]=r[p]-g,n[p]=n[p]+g}d[0][p]=r[p],d[1][p]=n[p]}for(var m=!1,p=0;p<3;++p)m=m||Y[0][p]!==d[0][p]||Y[1][p]!==d[1][p],Y[0][p]=d[0][p],Y[1][p]=d[1][p];if(I=I||m,z=z||m){if(m){for(var x=[0,0,0],a=0;a<3;++a)x[a]=v((d[1][a]-d[0][a])/10);M.autoTicks?M.update({bounds:d,tickSpacing:x}):M.update({bounds:d})}var T=y.drawingBufferWidth,A=y.drawingBufferHeight;B[0]=T,B[1]=A,V[0]=0|Math.max(T/j.pixelRatio,1),V[1]=0|Math.max(A/j.pixelRatio,1),k?(f(D,-T/A,T/A,-1,1,j.zNear,j.zFar),F._ortho=!0):(h(D,j.fovy,T/A,j.zNear,j.zFar),F._ortho=!1);for(var a=0;a<16;++a)R[a]=0;R[15]=1;for(var S=0,a=0;a<3;++a)S=Math.max(S,d[1][a]-d[0][a]);for(var a=0;a<3;++a)j.autoScale?R[5*a]=j.aspect[a]/(d[1][a]-d[0][a]):R[5*a]=1/S,j.autoCenter&&(R[12+a]=.5*-R[5*a]*(d[0][a]+d[1][a]));for(var a=0;a<e;++a){var o=L[a];o.axesBounds=d,j.clipToBounds&&(o.clipBounds=d)}b.object&&(j.snapToData?E.position=b.dataCoordinate:E.position=b.dataPosition,E.bounds=d),I&&(I=!1,function(){if(H())return;y.colorMask(!0,!0,!0,!0),y.depthMask(!0),y.disable(y.BLEND),y.enable(y.DEPTH_TEST),y.depthFunc(y.LEQUAL);for(var t=L.length,e=O.length,r=0;r<e;++r){var n=O[r];n.shape=V,n.begin();for(var a=0;a<t;++a)if(C[a]===r){var i=L[a];i.drawPick&&(i.pixelRatio=1,i.drawPick(F))}n.end()}}()),j.axesPixels=i(j.axes,F,T,A),j.onrender&&j.onrender(),y.bindFramebuffer(y.FRAMEBUFFER,null),y.viewport(0,0,T,A);var P=j.clearColor;y.clearColor(P[0],P[1],P[2],P[3]),y.clear(y.COLOR_BUFFER_BIT|y.DEPTH_BUFFER_BIT),y.depthMask(!0),y.colorMask(!0,!0,!0,!0),y.enable(y.DEPTH_TEST),y.depthFunc(y.LEQUAL),y.disable(y.BLEND),y.disable(y.CULL_FACE);var N=!1;M.enable&&(N=N||M.isTransparent(),M.draw(F)),E.axes=M,b.object&&E.draw(F),y.disable(y.CULL_FACE);for(var a=0;a<e;++a){var o=L[a];o.axes=M,o.pixelRatio=j.pixelRatio,o.isOpaque&&o.isOpaque()&&o.draw(F),o.isTransparent&&o.isTransparent()&&(N=!0)}if(N){_.shape=B,_.bind(),y.clear(y.DEPTH_BUFFER_BIT),y.colorMask(!1,!1,!1,!1),y.depthMask(!0),y.depthFunc(y.LESS),M.enable&&M.isTransparent()&&M.drawTransparent(F);for(var a=0;a<e;++a){var o=L[a];o.isOpaque&&o.isOpaque()&&o.draw(F)}y.enable(y.BLEND),y.blendEquation(y.FUNC_ADD),y.blendFunc(y.ONE,y.ONE_MINUS_SRC_ALPHA),y.colorMask(!0,!0,!0,!0),y.depthMask(!1),y.clearColor(0,0,0,0),y.clear(y.COLOR_BUFFER_BIT),M.isTransparent()&&M.drawTransparent(F);for(var a=0;a<e;++a){var o=L[a];o.isTransparent&&o.isTransparent()&&o.drawTransparent(F)}y.bindFramebuffer(y.FRAMEBUFFER,null),y.blendFunc(y.ONE,y.ONE_MINUS_SRC_ALPHA),y.disable(y.DEPTH_TEST),w.bind(),_.color[0].bind(0),w.uniforms.accumBuffer=0,c(y),y.disable(y.BLEND)}z=!1;for(var a=0;a<e;++a)L[a].dirty=!1}}}return j.enableMouseListeners(),function t(){j._stopped||j.contextLost||(W(),requestAnimationFrame(t))}(),j.redraw=function(){j._stopped||(z=!0,W())},j},createCamera:n}},{"./camera.js":290,"./lib/shader":291,"a-big-triangle":61,"gl-axes3d":235,"gl-axes3d/properties":242,"gl-fbo":251,"gl-mat4/ortho":270,"gl-mat4/perspective":271,"gl-select-static":302,"gl-spikes3d":312,"is-mobile":421,"mouse-change":436}],293:[function(t,e,r){var n=t("glslify");r.pointVertex=n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 position;\n\nuniform mat3 matrix;\nuniform float pointSize;\nuniform float pointCloud;\n\nhighp float rand(vec2 co) {\n  highp float a = 12.9898;\n  highp float b = 78.233;\n  highp float c = 43758.5453;\n  highp float d = dot(co.xy, vec2(a, b));\n  highp float e = mod(d, 3.14);\n  return fract(sin(e) * c);\n}\n\nvoid main() {\n  vec3 hgPosition = matrix * vec3(position, 1);\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\n    // if we don't jitter the point size a bit, overall point cloud\n    // saturation 'jumps' on zooming, which is disturbing and confusing\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\n  if(pointCloud != 0.0) { // pointCloud is truthy\n    // get the same square surface as circle would be\n    gl_PointSize *= 0.886;\n  }\n}"]),r.pointFragment=n(["precision mediump float;\n#define GLSLIFY 1\n\nuniform vec4 color, borderColor;\nuniform float centerFraction;\nuniform float pointCloud;\n\nvoid main() {\n  float radius;\n  vec4 baseColor;\n  if(pointCloud != 0.0) { // pointCloud is truthy\n    if(centerFraction == 1.0) {\n      gl_FragColor = color;\n    } else {\n      gl_FragColor = mix(borderColor, color, centerFraction);\n    }\n  } else {\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\n    if(radius > 1.0) {\n      discard;\n    }\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\n  }\n}\n"]),r.pickVertex=n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 position;\nattribute vec4 pickId;\n\nuniform mat3 matrix;\nuniform float pointSize;\nuniform vec4 pickOffset;\n\nvarying vec4 fragId;\n\nvoid main() {\n  vec3 hgPosition = matrix * vec3(position, 1);\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\n  gl_PointSize = pointSize;\n\n  vec4 id = pickId + pickOffset;\n  id.y += floor(id.x / 256.0);\n  id.x -= floor(id.x / 256.0) * 256.0;\n\n  id.z += floor(id.y / 256.0);\n  id.y -= floor(id.y / 256.0) * 256.0;\n\n  id.w += floor(id.z / 256.0);\n  id.z -= floor(id.z / 256.0) * 256.0;\n\n  fragId = id;\n}\n"]),r.pickFragment=n(["precision mediump float;\n#define GLSLIFY 1\n\nvarying vec4 fragId;\n\nvoid main() {\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\n  if(radius > 1.0) {\n    discard;\n  }\n  gl_FragColor = fragId / 255.0;\n}\n"])},{glslify:410}],294:[function(t,e,r){"use strict";var n=t("gl-shader"),a=t("gl-buffer"),i=t("typedarray-pool"),o=t("./lib/shader");function s(t,e,r,n,a){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=a,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,i=a(r),l=a(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),h=new s(t,i,l,c,u);return h.update(e),t.addObject(h),h};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r("sizeMin",.5),this.sizeMax=r("sizeMax",20),this.color=r("color",[1,0,0,1]).slice(),this.areaRatio=r("areaRatio",1),this.borderColor=r("borderColor",[0,0,0,1]).slice(),this.blend=r("blend",!1);var n=t.positions.length>>>1,a=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=a?s:i.mallocFloat32(s.length),c=o?t.idToIndex:i.mallocInt32(n);if(a||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),a||i.free(l),o||i.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,a=this.plot.dataBox;if(0===this.pointCount)return t;var i=a[2]-a[0],o=a[3]-a[1],s=function(t,e){var r,n=0,a=t.length>>>1;for(r=0;r<a;r++){var i=t[2*r],o=t[2*r+1];i>=e[0]&&i<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,a),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/i,l[4]=2/o,l[6]=-2*a[0]/i-1,l[7]=-2*a[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,a=this.pointCount;if(r<n||r>=n+a)return null;var i=r-n,o=this.points;return{object:this,pointId:i,dataCoord:[o[2*i],o[2*i+1]]}}},{"./lib/shader":293,"gl-buffer":243,"gl-shader":303,"typedarray-pool":543}],295:[function(t,e,r){e.exports=function(t,e,r,n){var a,i,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],g=r[2],v=r[3];(i=c*p+u*d+h*g+f*v)<0&&(i=-i,p=-p,d=-d,g=-g,v=-v);1-i>1e-6?(a=Math.acos(i),o=Math.sin(a),s=Math.sin((1-n)*a)/o,l=Math.sin(n*a)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*g,t[3]=s*f+l*v,t}},{}],296:[function(t,e,r){"use strict";e.exports=function(t){return t||0===t?t.toString():""}},{}],297:[function(t,e,r){"use strict";var n=t("vectorize-text");e.exports=function(t,e,r){var i=a[e];i||(i=a[e]={});if(t in i)return i[t];var o={textAlign:"center",textBaseline:"middle",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var h=[[1/0,1/0],[-1/0,-1/0]],f=u.positions.length;for(l=0;l<f;++l){var p=u.positions[l];for(c=0;c<2;++c)h[0][c]=Math.min(h[0][c],p[c]),h[1][c]=Math.max(h[1][c],p[c])}return i[t]=[s,u,h]};var a={}},{"vectorize-text":548}],298:[function(t,e,r){var n=t("gl-shader"),a=t("glslify"),i=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nattribute vec3 position;\nattribute vec4 color;\nattribute vec2 glyph;\nattribute vec4 id;\n\nuniform vec4 highlightId;\nuniform float highlightScale;\nuniform mat4 model, view, projection;\nuniform vec3 clipBounds[2];\n\nvarying vec4 interpColor;\nvarying vec4 pickId;\nvarying vec3 dataCoordinate;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\n\n    gl_Position = vec4(0,0,0,0);\n  } else {\n    float scale = 1.0;\n    if(distance(highlightId, id) < 0.0001) {\n      scale = highlightScale;\n    }\n\n    vec4 worldPosition = model * vec4(position, 1);\n    vec4 viewPosition = view * worldPosition;\n    viewPosition = viewPosition / viewPosition.w;\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\n\n    gl_Position = clipPosition;\n    interpColor = color;\n    pickId = id;\n    dataCoordinate = position;\n  }\n}"]),o=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nattribute vec3 position;\nattribute vec4 color;\nattribute vec2 glyph;\nattribute vec4 id;\n\nuniform mat4 model, view, projection;\nuniform vec2 screenSize;\nuniform vec3 clipBounds[2];\nuniform float highlightScale, pixelRatio;\nuniform vec4 highlightId;\n\nvarying vec4 interpColor;\nvarying vec4 pickId;\nvarying vec3 dataCoordinate;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\n\n    gl_Position = vec4(0,0,0,0);\n  } else {\n    float scale = pixelRatio;\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\n      scale *= highlightScale;\n    }\n\n    vec4 worldPosition = model * vec4(position, 1.0);\n    vec4 viewPosition = view * worldPosition;\n    vec4 clipPosition = projection * viewPosition;\n    clipPosition /= clipPosition.w;\n\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\n    interpColor = color;\n    pickId = id;\n    dataCoordinate = position;\n  }\n}"]),s=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nattribute vec3 position;\nattribute vec4 color;\nattribute vec2 glyph;\nattribute vec4 id;\n\nuniform float highlightScale;\nuniform vec4 highlightId;\nuniform vec3 axes[2];\nuniform mat4 model, view, projection;\nuniform vec2 screenSize;\nuniform vec3 clipBounds[2];\nuniform float scale, pixelRatio;\n\nvarying vec4 interpColor;\nvarying vec4 pickId;\nvarying vec3 dataCoordinate;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\n\n    gl_Position = vec4(0,0,0,0);\n  } else {\n    float lscale = pixelRatio * scale;\n    if(distance(highlightId, id) < 0.0001) {\n      lscale *= highlightScale;\n    }\n\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\n\n    gl_Position = clipPosition;\n    interpColor = color;\n    pickId = id;\n    dataCoordinate = dataPosition;\n  }\n}\n"]),l=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 fragClipBounds[2];\nuniform float opacity;\n\nvarying vec4 interpColor;\nvarying vec3 dataCoordinate;\n\nvoid main() {\n  if (\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\n    interpColor.a * opacity == 0.\n  ) discard;\n  gl_FragColor = interpColor * opacity;\n}\n"]),c=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 fragClipBounds[2];\nuniform float pickGroup;\n\nvarying vec4 pickId;\nvarying vec3 dataCoordinate;\n\nvoid main() {\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\n\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\n}"]),u=[{name:"position",type:"vec3"},{name:"color",type:"vec4"},{name:"glyph",type:"vec2"},{name:"id",type:"vec4"}],h={vertex:i,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:i,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},v={vertex:s,fragment:c,attributes:u};function m(t,e){var r=n(t,e),a=r.attributes;return a.position.location=0,a.color.location=1,a.glyph.location=2,a.id.location=3,r}r.createPerspective=function(t){return m(t,h)},r.createOrtho=function(t){return m(t,f)},r.createProject=function(t){return m(t,p)},r.createPickPerspective=function(t){return m(t,d)},r.createPickOrtho=function(t){return m(t,g)},r.createPickProject=function(t){return m(t,v)}},{"gl-shader":303,glslify:410}],299:[function(t,e,r){"use strict";var n=t("is-string-blank"),a=t("gl-buffer"),i=t("gl-vao"),o=t("typedarray-pool"),s=t("gl-mat4/multiply"),l=t("./lib/shaders"),c=t("./lib/glyphs"),u=t("./lib/get-simple-string"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e){var r=t[0],n=t[1],a=t[2],i=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*a+e[12]*i,t[1]=e[1]*r+e[5]*n+e[9]*a+e[13]*i,t[2]=e[2]*r+e[6]*n+e[10]*a+e[14]*i,t[3]=e[3]*r+e[7]*n+e[11]*a+e[15]*i,t}function p(t,e,r,n){return f(n,n),f(n,n),f(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t?1:t>1?1:t}function v(t,e,r,n,a,i,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=a,this.colorBuffer=i,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=a(e),f=a(e),p=a(e),d=a(e),g=i(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),m=new v(e,r,n,o,h,f,p,d,g,s,c,u);return m.update(t),m};var m=v.prototype;m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},m.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],k=h.slice(),T=[0,0,0],A=[[0,0,0],[0,0,0]];function M(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function L(t,e,r,n){var a,i=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,d=e.axesBounds,g=function(t){for(var e=A,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);a=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var v=0;v<3;++v)if(i[v]){l.scale=e.projectScale[v],l.opacity=e.projectOpacity[v];for(var m=k,L=0;L<16;++L)m[L]=0;for(L=0;L<4;++L)m[5*L]=1;m[5*v]=0,a[v]<0?m[12+v]=d[0][v]:m[12+v]=d[1][v],s(m,c,m),l.model=m;var C=(v+1)%3,P=(v+2)%3,O=M(x),z=M(b);O[C]=1,z[P]=1;var I=p(0,0,0,S(_,O)),D=p(0,0,0,S(w,z));if(Math.abs(I[1])>Math.abs(D[1])){var R=I;I=D,D=R,R=O,O=z,z=R;var F=C;C=P,P=F}I[0]<0&&(O[C]=-1),D[1]>0&&(z[P]=-1);var B=0,N=0;for(L=0;L<4;++L)B+=Math.pow(c[4*C+L],2),N+=Math.pow(c[4*P+L],2);O[C]/=Math.sqrt(B),z[P]/=Math.sqrt(N),l.axes[0]=O,l.axes[1]=z,l.fragClipBounds[0]=E(T,g[0],v,-1e8),l.fragClipBounds[1]=E(T,g[1],v,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var C=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,a,i,o){var s=r.gl;if((i===r.projectHasAlpha||o)&&L(e,r,n,a),i===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||h,l.view=n.view||h,l.projection=n.projection||h,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=C,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=a,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*a),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function O(t,e,r,a){var i;i=Array.isArray(t)?e<t.length?t[e]:void 0:t,i=u(i);var o=!0;n(i)&&(i="\u25bc",o=!1);var s=c(i,r,a);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}m.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},m.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},m.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var a=0;a<3;++a)n.position[a]=n.dataCoordinate[a]=r[a];return n},m.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,a=e>>16&255;this.highlightId=[r/255,n/255,a/255,0]}else this.highlightId=[1,1,1,1]},m.update=function(t){if("perspective"in(t=t||{})&&(this.useOrtho=!t.perspective),"orthographic"in t&&(this.useOrtho=!!t.orthographic),"lineWidth"in t&&(this.lineWidth=t.lineWidth),"project"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if("projectScale"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,"projectOpacity"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,"opacity"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var a,i,s=t.position,l=t.font||"normal",c=t.alignment||[0,0];if(2===c.length)a=c[0],i=c[1];else{a=[],i=[];for(n=0;n<c.length;++n)a[n]=c[n][0],i[n]=c[n][1]}var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,d=t.size,v=t.angle,m=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],k=0;k<3;++k)if(isNaN(w[k])||!isFinite(w[k]))continue t;var T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;x+=3*T.cells.length,b+=2*A.edges.length}}var S=x+b,E=o.mallocFloat(3*S),L=o.mallocFloat(4*S),C=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var z=0,I=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(m)&&Array.isArray(m[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],k=0;k<3;++k){if(isNaN(w[k])||!isFinite(w[k]))continue t;h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k])}T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(V=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)D[k]=V[k];D[3]=1}else if(4===V.length){for(k=0;k<4;++k)D[k]=V[k];!this.hasAlpha&&V[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(m)){var V;if(3===(V=B?n<m.length?m[n]:[0,0,0,0]:m).length){for(k=0;k<3;++k)R[k]=V[k];R[k]=1}else if(4===V.length){for(k=0;k<4;++k)R[k]=V[k];!this.hasAlpha&&V[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var U=.5;j?Array.isArray(d)?U=n<d.length?+d[n]:12:d?U=+d:this.useOrtho&&(U=12):U=0;var q=0;Array.isArray(v)?q=n<v.length?+v[n]:0:v&&(q=+v);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],k=0;k<3;++k)h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k]);var Y=a,W=i;Y=0;Array.isArray(a)?Y=n<a.length?a[n]:0:a&&(Y=a);W=0;Array.isArray(i)?W=n<i.length?i[n]:0:i&&(W=i);var X=[Y*=Y>0?1-M[0][0]:Y<0?1+M[1][0]:1,W*=W>0?1-M[0][1]:W<0?1+M[1][1]:1],Z=T.cells||[],J=T.positions||[];for(k=0;k<Z.length;++k)for(var K=Z[k],Q=0;Q<3;++Q){for(var $=0;$<3;++$)E[3*z+$]=w[$];for($=0;$<4;++$)L[4*z+$]=D[$];P[z]=y;var tt=J[K[Q]];C[2*z]=U*(H*tt[0]-G*tt[1]+X[0]),C[2*z+1]=U*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=A.edges,J=A.positions,k=0;k<Z.length;++k)for(K=Z[k],Q=0;Q<2;++Q){for($=0;$<3;++$)E[3*I+$]=w[$];for($=0;$<4;++$)L[4*I+$]=R[$];P[I]=y;tt=J[K[Q]];C[2*I]=U*(H*tt[0]-G*tt[1]+X[0]),C[2*I+1]=U*(G*tt[0]+H*tt[1]+X[1]),I+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(L),this.glyphBuffer.update(C),this.idBuffer.update(P),o.free(E),o.free(L),o.free(C),o.free(P)},m.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{"./lib/get-simple-string":296,"./lib/glyphs":297,"./lib/shaders":298,"gl-buffer":243,"gl-mat4/multiply":269,"gl-vao":328,"is-string-blank":424,"typedarray-pool":543}],300:[function(t,e,r){"use strict";var n=t("glslify");r.boxVertex=n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec2 vertex;\n\nuniform vec2 cornerA, cornerB;\n\nvoid main() {\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\n}\n"]),r.boxFragment=n(["precision mediump float;\n#define GLSLIFY 1\n\nuniform vec4 color;\n\nvoid main() {\n  gl_FragColor = color;\n}\n"])},{glslify:410}],301:[function(t,e,r){"use strict";var n=t("gl-shader"),a=t("gl-buffer"),i=t("./lib/shaders");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=a(r,[0,0,0,1,1,0,1,1]),l=n(r,i.boxVertex,i.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),a=(this.outerFill,this.outerColor),i=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var g=s[2]-s[0],v=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,f,a),o.drawBox(0,f,h,d,a),o.drawBox(0,d,g,v,a),o.drawBox(p,f,g,d,a)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var m=r*u;o.drawBox(h-m,f-m,p+m,f+m,i),o.drawBox(h-m,d-m,p+m,d+m,i),o.drawBox(h-m,f-m,h+m,d+m,i),o.drawBox(p-m,f-m,p+m,d+m,i)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{"./lib/shaders":300,"gl-buffer":243,"gl-shader":303}],302:[function(t,e,r){"use strict";e.exports=function(t,e){var r=n(t,e),i=a.mallocUint8(e[0]*e[1]*4);return new c(t,r,i)};var n=t("gl-fbo"),a=t("typedarray-pool"),i=t("ndarray"),o=t("bit-twiddle").nextPow2,s=t("cwise/lib/wrapper")({args:["array",{offset:[0,0,1],array:0},{offset:[0,0,2],array:0},{offset:[0,0,3],array:0},"scalar","scalar","index"],pre:{body:"{this_closestD2=1e8,this_closestX=-1,this_closestY=-1}",args:[],thisVars:["this_closestD2","this_closestX","this_closestY"],localVars:[]},body:{body:"{if(_inline_16_arg0_<255||_inline_16_arg1_<255||_inline_16_arg2_<255||_inline_16_arg3_<255){var _inline_16_l=_inline_16_arg4_-_inline_16_arg6_[0],_inline_16_a=_inline_16_arg5_-_inline_16_arg6_[1],_inline_16_f=_inline_16_l*_inline_16_l+_inline_16_a*_inline_16_a;_inline_16_f<this_closestD2&&(this_closestD2=_inline_16_f,this_closestX=_inline_16_arg6_[0],this_closestY=_inline_16_arg6_[1])}}",args:[{name:"_inline_16_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg1_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg3_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg4_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg5_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_16_arg6_",lvalue:!1,rvalue:!0,count:4}],thisVars:["this_closestD2","this_closestX","this_closestY"],localVars:["_inline_16_a","_inline_16_f","_inline_16_l"]},post:{body:"{return[this_closestX,this_closestY,this_closestD2]}",args:[],thisVars:["this_closestD2","this_closestX","this_closestY"],localVars:[]},debug:!1,funcName:"cwise",blockSize:64});function l(t,e,r,n,a){this.coord=[t,e],this.id=r,this.value=n,this.distance=a}function c(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var u=c.prototype;Object.defineProperty(u,"shape",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){a.free(this.buffer);for(var n=this.buffer=a.mallocUint8(o(r*e*4)),i=0;i<r*e*4;++i)n[i]=255}return t}}}),u.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},u.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},u.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,"number"!=typeof r&&(r=1);var a=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),c=0|Math.min(Math.max(e-r,0),n[1]),u=0|Math.min(Math.max(e+r,0),n[1]);if(o<=a||u<=c)return null;var h=[o-a,u-c],f=i(this.buffer,[h[0],h[1],4],[4,4*n[0],1],4*(a+n[0]*c)),p=s(f.hi(h[0],h[1],1),r,r),d=p[0],g=p[1];return d<0||Math.pow(this.radius,2)<p[2]?null:new l(d+a|0,g+c|0,f.get(d,g,0),[f.get(d,g,1),f.get(d,g,2),f.get(d,g,3)],Math.sqrt(p[2]))},u.dispose=function(){this.gl&&(this.fbo.dispose(),a.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{"bit-twiddle":93,"cwise/lib/wrapper":150,"gl-fbo":251,ndarray:451,"typedarray-pool":543}],303:[function(t,e,r){"use strict";var n=t("./lib/create-uniforms"),a=t("./lib/create-attributes"),i=t("./lib/reflect"),o=t("./lib/shader-cache"),s=t("./lib/runtime-reflect"),l=t("./lib/GLError");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var g=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),f.fragShader=f._fref.shader,!r||!c){var v=p.createProgram();if(p.attachShader(v,f.fragShader),p.attachShader(v,f.vertShader),p.linkProgram(v),!p.getProgramParameter(v,p.LINK_STATUS)){var m=p.getProgramInfoLog(v);throw new l(m,"Error linking program:"+m)}r=r||s.uniforms(p,v),c=c||s.attributes(p,v),p.deleteProgram(v)}(c=c.slice()).sort(h);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf("mat")>=0){for(var k=0|w.type.charAt(w.type.length-1),T=new Array(k),A=0;A<k;++A)T[A]=_.length,b.push(w.name+"["+A+"]"),"number"==typeof w.location?_.push(w.location+A):Array.isArray(w.location)&&w.location.length===k&&"number"==typeof w.location[A]?_.push(0|w.location[A]):_.push(-1);x.push({name:w.name,type:w.type,locations:T})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),"number"==typeof w.location?_.push(0|w.location):_.push(-1)}var M=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(M)>=0;)M+=1;_[y]=M}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:i(r),attributes:i(c)},f.attributes=a(p,f,x,_),Object.defineProperty(f,"uniforms",n(p,f,r,S))},e.exports=function(t,e,r,n,a){var i=new c(t);return i.update(e,r,n,a),i}},{"./lib/GLError":304,"./lib/create-attributes":305,"./lib/create-uniforms":306,"./lib/reflect":307,"./lib/runtime-reflect":308,"./lib/shader-cache":309}],304:[function(t,e,r){function n(t,e,r){this.shortMessage=e||"",this.longMessage=r||"",this.rawError=t||"",this.message="gl-shader: "+(e||t||"")+(r?"\n"+r:""),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name="GLError",n.prototype.constructor=n,e.exports=n},{}],305:[function(t,e,r){"use strict";e.exports=function(t,e,r,a){for(var i={},l=0,c=r.length;l<c;++l){var u=r[l],h=u.name,f=u.type,p=u.locations;switch(f){case"bool":case"int":case"float":o(t,e,p[0],a,1,i,h);break;default:if(f.indexOf("vec")>=0){var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n("","Invalid data type for attribute "+h+": "+f);o(t,e,p[0],a,d,i,h)}else{if(!(f.indexOf("mat")>=0))throw new n("","Unknown data type for attribute "+h+": "+f);var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n("","Invalid data type for attribute "+h+": "+f);s(t,e,p,a,d,i,h)}}}return i};var n=t("./GLError");function a(t,e,r,n,a,i){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=a,this._constFunc=i}var i=a.prototype;function o(t,e,r,n,i,o,s){for(var l=["gl","v"],c=[],u=0;u<i;++u)l.push("x"+u),c.push("x"+u);l.push("if(x0.length===void 0){return gl.vertexAttrib"+i+"f(v,"+c.join()+")}else{return gl.vertexAttrib"+i+"fv(v,x0)}");var h=Function.apply(null,l),f=new a(t,e,r,n,i,h);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),h(t,n[r],e),e},get:function(){return f},enumerable:!0})}function s(t,e,r,n,a,i,s){for(var l=new Array(a),c=new Array(a),u=0;u<a;++u)o(t,e,r[u],n,a,l,u),c[u]=l[u];Object.defineProperty(l,"location",{set:function(t){if(Array.isArray(t))for(var e=0;e<a;++e)c[e].location=t[e];else for(e=0;e<a;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(a),e=0;e<a;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,i,o,s){e=e||t.FLOAT,i=!!i,o=o||a*a,s=s||0;for(var l=0;l<a;++l){var c=n[r[l]];t.vertexAttribPointer(c,a,e,i,o,s+l*a),t.enableVertexAttribArray(c)}};var h=new Array(a),f=t["vertexAttrib"+a+"fv"];Object.defineProperty(i,s,{set:function(e){for(var i=0;i<a;++i){var o=n[r[i]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[i]);else{for(var s=0;s<a;++s)h[s]=e[a*i+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}i.pointer=function(t,e,r,n){var a=this._gl,i=this._locations[this._index];a.vertexAttribPointer(i,this._dimension,t||a.FLOAT,!!e,r||0,n||0),a.enableVertexAttribArray(i)},i.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(i,"location",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{"./GLError":304}],306:[function(t,e,r){"use strict";var n=t("./reflect"),a=t("./GLError");function i(t){return new Function("y","return function(){return y}")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case"bool":case"int":case"sampler2D":case"samplerCube":return"gl.uniform1i(locations["+e+"],obj"+t+")";case"float":return"gl.uniform1f(locations["+e+"],obj"+t+")";default:var n=r.indexOf("vec");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf("mat")&&4===r.length){var i=r.charCodeAt(r.length-1)-48;if(i<2||i>4)throw new a("","Invalid uniform dimension type for matrix "+name+": "+r);return"gl.uniformMatrix"+i+"fv(locations["+e+"],false,obj"+t+")"}throw new a("","Unknown uniform data type for "+name+": "+r)}var i=r.charCodeAt(r.length-1)-48;if(i<2||i>4)throw new a("","Invalid data type");switch(r.charAt(0)){case"b":case"i":return"gl.uniform"+i+"iv(locations["+e+"],obj"+t+")";case"v":return"gl.uniform"+i+"fv(locations["+e+"],obj"+t+")";default:throw new a("","Unrecognized data type for vector "+name+": "+r)}}}function c(e){for(var n=["return function updateProperty(obj){"],a=function t(e,r){if("object"!=typeof r)return[[e,r]];var n=[];for(var a in r){var i=r[a],o=e;parseInt(a)+""===a?o+="["+a+"]":o+="."+a,"object"==typeof i?n.push.apply(n,t(o,i)):n.push([o,i])}return n}("",e),i=0;i<a.length;++i){var o=a[i],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}n.push("return obj}");var h=new Function("gl","locations",n.join("\n"));return h(t,s)}function u(n,l,u){if("object"==typeof u){var f=h(u);Object.defineProperty(n,l,{get:i(f),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function("gl","wrapper","locations","return function(){return gl.getUniform(wrapper.program,locations["+p+"])}")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case"bool":return!1;case"int":case"sampler2D":case"samplerCube":case"float":return 0;default:var e=t.indexOf("vec");if(0<=e&&e<=1&&t.length===4+e){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new a("","Invalid data type");return"b"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf("mat")&&4===t.length){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new a("","Invalid uniform dimension type for matrix "+name+": "+t);return o(r*r,0)}throw new a("","Unknown uniform data type for "+name+": "+t)}}(r[u].type);var p}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:i(h(f)),set:c(f),enumerable:!0,configurable:!0}}},{"./GLError":304,"./reflect":307}],307:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var a=t[n].name,i=a.split("."),o=r,s=0;s<i.length;++s){var l=i[s].split("[");if(l.length>1){l[0]in o||(o[l[0]]=[]),o=o[l[0]];for(var c=1;c<l.length;++c){var u=parseInt(l[c]);c<l.length-1||s<i.length-1?(u in o||(c<l.length-1?o[u]=[]:o[u]={}),o=o[u]):o[u]=e?n:t[n].type}}else s<i.length-1?(l[0]in o||(o[l[0]]={}),o=o[l[0]]):o[l[0]]=e?n:t[n].type}return r}},{}],308:[function(t,e,r){"use strict";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],a=0;a<r;++a){var o=t.getActiveUniform(e,a);if(o){var s=i(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace("[0]","["+l+"]"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],a=0;a<r;++a){var o=t.getActiveAttrib(e,a);o&&n.push({name:o.name,type:i(t,o.type)})}return n};var n={FLOAT:"float",FLOAT_VEC2:"vec2",FLOAT_VEC3:"vec3",FLOAT_VEC4:"vec4",INT:"int",INT_VEC2:"ivec2",INT_VEC3:"ivec3",INT_VEC4:"ivec4",BOOL:"bool",BOOL_VEC2:"bvec2",BOOL_VEC3:"bvec3",BOOL_VEC4:"bvec4",FLOAT_MAT2:"mat2",FLOAT_MAT3:"mat3",FLOAT_MAT4:"mat4",SAMPLER_2D:"sampler2D",SAMPLER_CUBE:"samplerCube"},a=null;function i(t,e){if(!a){var r=Object.keys(n);a={};for(var i=0;i<r.length;++i){var o=r[i];a[t[o]]=n[o]}}return a[e]}},{}],309:[function(t,e,r){"use strict";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,a){return u(t).getProgram(e,r,n,a)};var n=t("./GLError"),a=t("gl-format-compiler-error"),i=new("undefined"==typeof WeakMap?t("weakmap-shim"):WeakMap),o=0;function s(t,e,r,n,a,i,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=i,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,a=r.length;n<a;++n){var i=t.programs[r[n]];i&&(delete t.programs[n],e.deleteProgram(i))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=i.get(t);return e||(e=new l(t),i.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,i=this.shaders[t===r.FRAGMENT_SHADER|0],l=i[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var i=t.createShader(e);if(t.shaderSource(i,r),t.compileShader(i),!t.getShaderParameter(i,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(i);try{var s=a(o,r,e)}catch(t){throw console.warn("Failed to format compiler error: "+t),new n(o,"Error compiling shader:\n"+o)}throw new n(o,s.short,s.long)}return i}(r,t,e);l=i[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,a){var i=[t.id,e.id,r.join(":"),a.join(":")].join("@"),o=this.programs[i];return o&&this.gl.isProgram(o)||(this.programs[i]=o=function(t,e,r,a,i){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<a.length;++s)t.bindAttribLocation(o,i[s],a[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,"Error linking program: "+l)}return o}(this.gl,t.shader,e.shader,r,a),t.programs.push(i),e.programs.push(i)),o}},{"./GLError":304,"gl-format-compiler-error":252,"weakmap-shim":553}],310:[function(t,e,r){"use strict";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var a=n.prototype;a.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map(function(t){return t.slice()}),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},a.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,a=this.plot,i=a.line,o=a.dataBox,s=a.viewBox;if(i.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&i.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&i.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&i.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&i.drawLine(l,c,l,s[3],e[3],r[3])}},a.dispose=function(){this.plot.removeOverlay(this)}},{}],311:[function(t,e,r){"use strict";var n=t("glslify"),a=t("gl-shader"),i=n(["precision mediump float;\n#define GLSLIFY 1\n\nattribute vec3 position, color;\nattribute float weight;\n\nuniform mat4 model, view, projection;\nuniform vec3 coordinates[3];\nuniform vec4 colors[3];\nuniform vec2 screenShape;\nuniform float lineWidth;\n\nvarying vec4 fragColor;\n\nvoid main() {\n  vec3 vertexPosition = mix(coordinates[0],\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\n\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\n  vec2 delta = weight * clipOffset * screenShape;\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\n\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\n}\n"]),o=n(["precision mediump float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor;\n\nvoid main() {\n  gl_FragColor = fragColor;\n}"]);e.exports=function(t){return a(t,i,o,null,[{name:"position",type:"vec3"},{name:"color",type:"vec3"},{name:"weight",type:"float"}])}},{"gl-shader":303,glslify:410}],312:[function(t,e,r){"use strict";var n=t("gl-buffer"),a=t("gl-vao"),i=t("./shaders/index");e.exports=function(t,e){var r=[];function o(t,e,n,a,i,o){var s=[t,e,n,0,0,0,1];s[a+3]=1,s[a]=i,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[a]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[a]=i,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=a(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=i(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var a,i=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(a=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)a&&a[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=i,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&("bounds"in t&&(this.bounds=t.bounds),"position"in t&&(this.position=t.position),"lineWidth"in t&&(this.lineWidth=t.lineWidth),"colors"in t&&(this.colors=t.colors),"enabled"in t&&(this.enabled=t.enabled),"drawSides"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{"./shaders/index":311,"gl-buffer":243,"gl-vao":328}],313:[function(t,e,r){var n=t("glslify"),a=n(["precision highp float;\n\nprecision highp float;\n#define GLSLIFY 1\n\nvec3 getOrthogonalVector(vec3 v) {\n  // Return up-vector for only-z vector.\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\n  // Assign z = 0, x = -b, y = a:\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\n    return normalize(vec3(-v.y, v.x, 0.0));\n  } else {\n    return normalize(vec3(0.0, v.z, -v.y));\n  }\n}\n\n// Calculate the tube vertex and normal at the given index.\n//\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\n//\n// Each tube segment is made up of a ring of vertices.\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\n// The indexes of tube segments run from 0 to 8.\n//\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\n  float segmentCount = 8.0;\n\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\n\n  vec3 u = getOrthogonalVector(d);\n  vec3 v = normalize(cross(u, d));\n\n  vec3 x = u * cos(angle) * length(d);\n  vec3 y = v * sin(angle) * length(d);\n  vec3 v3 = x + y;\n\n  normal = normalize(v3);\n\n  return v3;\n}\n\nattribute vec4 vector;\nattribute vec4 color, position;\nattribute vec2 uv;\n\nuniform float vectorScale, tubeScale;\nuniform mat4 model, view, projection, inverseModel;\nuniform vec3 eyePosition, lightPosition;\n\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  // Scale the vector magnitude to stay constant with\n  // model & view changes.\n  vec3 normal;\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\n\n  //Lighting geometry parameters\n  vec4 cameraCoordinate = view * tubePosition;\n  cameraCoordinate.xyz /= cameraCoordinate.w;\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\n\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\n  vec4 t_position  = view * tubePosition;\n  gl_Position      = projection * t_position;\n\n  f_color          = color;\n  f_data           = tubePosition.xyz;\n  f_position       = position.xyz;\n  f_uv             = uv;\n}\n"]),i=n(["#extension GL_OES_standard_derivatives : enable\n\nprecision highp float;\n#define GLSLIFY 1\n\nfloat beckmannDistribution(float x, float roughness) {\n  float NdotH = max(x, 0.0001);\n  float cos2Alpha = NdotH * NdotH;\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\n  float roughness2 = roughness * roughness;\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\n  return exp(tan2Alpha / roughness2) / denom;\n}\n\nfloat cookTorranceSpecular(\n  vec3 lightDirection,\n  vec3 viewDirection,\n  vec3 surfaceNormal,\n  float roughness,\n  float fresnel) {\n\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\n\n  //Half angle vector\n  vec3 H = normalize(lightDirection + viewDirection);\n\n  //Geometric term\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\n  float VdotH = max(dot(viewDirection, H), 0.000001);\n  float LdotH = max(dot(lightDirection, H), 0.000001);\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\n  float G = min(1.0, min(G1, G2));\n  \n  //Distribution term\n  float D = beckmannDistribution(NdotH, roughness);\n\n  //Fresnel term\n  float F = pow(1.0 - VdotN, fresnel);\n\n  //Multiply terms and done\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\n}\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 clipBounds[2];\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\nuniform sampler2D texture;\n\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\nvarying vec4 f_color;\nvarying vec2 f_uv;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\n  vec3 N = normalize(f_normal);\n  vec3 L = normalize(f_lightDirection);\n  vec3 V = normalize(f_eyeDirection);\n\n  if(gl_FrontFacing) {\n    N = -N;\n  }\n\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\n\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\n\n  gl_FragColor = litColor * opacity;\n}\n"]),o=n(["precision highp float;\n\nprecision highp float;\n#define GLSLIFY 1\n\nvec3 getOrthogonalVector(vec3 v) {\n  // Return up-vector for only-z vector.\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\n  // Assign z = 0, x = -b, y = a:\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\n    return normalize(vec3(-v.y, v.x, 0.0));\n  } else {\n    return normalize(vec3(0.0, v.z, -v.y));\n  }\n}\n\n// Calculate the tube vertex and normal at the given index.\n//\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\n//\n// Each tube segment is made up of a ring of vertices.\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\n// The indexes of tube segments run from 0 to 8.\n//\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\n  float segmentCount = 8.0;\n\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\n\n  vec3 u = getOrthogonalVector(d);\n  vec3 v = normalize(cross(u, d));\n\n  vec3 x = u * cos(angle) * length(d);\n  vec3 y = v * sin(angle) * length(d);\n  vec3 v3 = x + y;\n\n  normal = normalize(v3);\n\n  return v3;\n}\n\nattribute vec4 vector;\nattribute vec4 position;\nattribute vec4 id;\n\nuniform mat4 model, view, projection;\nuniform float tubeScale;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  vec3 normal;\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\n\n  gl_Position = projection * view * tubePosition;\n  f_id        = id;\n  f_position  = position.xyz;\n}\n"]),s=n(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3  clipBounds[2];\nuniform float pickId;\n\nvarying vec3 f_position;\nvarying vec4 f_id;\n\nvoid main() {\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\n\n  gl_FragColor = vec4(pickId, f_id.xyz);\n}"]);r.meshShader={vertex:a,fragment:i,attributes:[{name:"position",type:"vec4"},{name:"color",type:"vec4"},{name:"uv",type:"vec2"},{name:"vector",type:"vec4"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:"position",type:"vec4"},{name:"id",type:"vec4"},{name:"vector",type:"vec4"}]}},{glslify:410}],314:[function(t,e,r){"use strict";var n=t("gl-vec3"),a=t("gl-vec4"),i=["xyz","xzy","yxz","yzx","zxy","zyx"],o=function(t,e,r,i){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++)o=Math.max(o,n.length(l[c]));var u=t.map(function(t){return function(t,e,r,i){for(var o=t.points,s=t.velocities,l=t.divergences,c=[],u=[],h=[],f=[],p=[],d=[],g=0,v=0,m=a.create(),y=a.create(),x=0;x<o.length;x++){var b=o[x],_=s[x],w=l[x];0===e&&(w=.05*r),v=n.length(_)/i,m=a.create(),n.copy(m,_),m[3]=w;for(var k=0;k<8;k++)p[k]=[b[0],b[1],b[2],k];if(f.length>0)for(k=0;k<8;k++){var T=(k+1)%8;c.push(f[k],p[k],p[T],p[T],f[T],f[k]),h.push(y,m,m,m,y,y),d.push(g,v,v,v,g,g);var A=c.length;u.push([A-6,A-5,A-4],[A-3,A-2,A-1])}var M=f;f=p,p=M;var S=y;y=m,m=S;var E=g;g=v,v=E}return{positions:c,cells:u,vectors:h,vertexIntensity:d}}(t,r,i,o)}),h=[],f=[],p=[],d=[];for(s=0;s<u.length;s++){var g=u[s],v=h.length;h=h.concat(g.positions),p=p.concat(g.vectors),d=d.concat(g.vertexIntensity);for(c=0;c<g.cells.length;c++){var m=g.cells[c],y=[];f.push(y);for(var x=0;x<m.length;x++)y.push(m[x]+v)}}return{positions:h,cells:f,vectors:p,vertexIntensity:d,colormap:e}},s=function(t,e){var r,n=t.length;for(r=0;r<n;r++){var a=t[r];if(a===e)return r;if(a>e)return r-1}return r},l=function(t,e,r){return t<e?e:t>r?r:t},c=function(t){var e=1/0;t.sort(function(t,e){return t-e});for(var r=t.length,n=1;n<r;n++){var a=Math.abs(t[n]-t[n-1]);a<e&&(e=a)}return e};e.exports=function(t,e){var r=t.startingPositions,a=t.maxLength||1e3,u=t.tubeSize||1,h=t.absoluteTubeSize,f=t.gridFill||"+x+y+z",p={};-1!==f.indexOf("-x")&&(p.reversedX=!0),-1!==f.indexOf("-y")&&(p.reversedY=!0),-1!==f.indexOf("-z")&&(p.reversedZ=!0),p.filled=i.indexOf(f.replace(/-/g,"").replace(/\+/g,""));var d=t.getVelocity||function(e){return function(t,e,r){var a=e.vectors,i=e.meshgrid,o=t[0],c=t[1],u=t[2],h=i[0].length,f=i[1].length,p=i[2].length,d=s(i[0],o),g=s(i[1],c),v=s(i[2],u),m=d+1,y=g+1,x=v+1;if(d=l(d,0,h-1),m=l(m,0,h-1),g=l(g,0,f-1),y=l(y,0,f-1),v=l(v,0,p-1),x=l(x,0,p-1),d<0||g<0||v<0||m>h-1||y>f-1||x>p-1)return n.create();var b,_,w,k,T,A,M=i[0][d],S=i[0][m],E=i[1][g],L=i[1][y],C=i[2][v],P=(o-M)/(S-M),O=(c-E)/(L-E),z=(u-C)/(i[2][x]-C);switch(isFinite(P)||(P=.5),isFinite(O)||(O=.5),isFinite(z)||(z=.5),r.reversedX&&(d=h-1-d,m=h-1-m),r.reversedY&&(g=f-1-g,y=f-1-y),r.reversedZ&&(v=p-1-v,x=p-1-x),r.filled){case 5:T=v,A=x,w=g*p,k=y*p,b=d*p*f,_=m*p*f;break;case 4:T=v,A=x,b=d*p,_=m*p,w=g*p*h,k=y*p*h;break;case 3:w=g,k=y,T=v*f,A=x*f,b=d*f*p,_=m*f*p;break;case 2:w=g,k=y,b=d*f,_=m*f,T=v*f*h,A=x*f*h;break;case 1:b=d,_=m,T=v*h,A=x*h,w=g*h*p,k=y*h*p;break;default:b=d,_=m,w=g*h,k=y*h,T=v*h*f,A=x*h*f}var I=a[b+w+T],D=a[b+w+A],R=a[b+k+T],F=a[b+k+A],B=a[_+w+T],N=a[_+w+A],j=a[_+k+T],V=a[_+k+A],U=n.create(),q=n.create(),H=n.create(),G=n.create();n.lerp(U,I,B,P),n.lerp(q,D,N,P),n.lerp(H,R,j,P),n.lerp(G,F,V,P);var Y=n.create(),W=n.create();n.lerp(Y,U,H,O),n.lerp(W,q,G,O);var X=n.create();return n.lerp(X,Y,W,z),X}(e,t,p)},g=t.getDivergence||function(t,e){var r=n.create(),a=1e-4;n.add(r,t,[a,0,0]);var i=d(r);n.subtract(i,i,e),n.scale(i,i,1e4),n.add(r,t,[0,a,0]);var o=d(r);n.subtract(o,o,e),n.scale(o,o,1e4),n.add(r,t,[0,0,a]);var s=d(r);return n.subtract(s,s,e),n.scale(s,s,1e4),n.add(r,i,o),n.add(r,r,s),r},v=[],m=e[0][0],y=e[0][1],x=e[0][2],b=e[1][0],_=e[1][1],w=e[1][2],k=function(t){var e=t[0],r=t[1],n=t[2];return!(e<m||e>b||r<y||r>_||n<x||n>w)},T=10*n.distance(e[0],e[1])/a,A=T*T,M=1,S=0,E=r.length;E>1&&(M=function(t){for(var e=[],r=[],n=[],a={},i={},o={},s=t.length,l=0;l<s;l++){var u=t[l],h=u[0],f=u[1],p=u[2];a[h]||(e.push(h),a[h]=!0),i[f]||(r.push(f),i[f]=!0),o[p]||(n.push(p),o[p]=!0)}var d=c(e),g=c(r),v=c(n),m=Math.min(d,g,v);return isFinite(m)?m:1}(r));for(var L=0;L<E;L++){var C=n.create();n.copy(C,r[L]);var P=[C],O=[],z=d(C),I=C;O.push(z);var D=[],R=g(C,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F),v.push({points:P,velocities:O,divergences:D});for(var B=0;B<100*a&&P.length<a&&k(C);){B++;var N=n.clone(z),j=n.squaredLength(N);if(0===j)break;if(j>A&&n.scale(N,N,T/Math.sqrt(j)),n.add(N,N,C),z=d(N),n.squaredDistance(I,N)-A>-1e-4*A){P.push(N),I=N,O.push(z);R=g(N,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F)}C=N}}var V=o(v,t.colormap,S,M);return h?V.tubeScale=h:(0===S&&(S=1),V.tubeScale=.5*u*M/S),V};var u=t("./lib/shaders"),h=t("gl-cone3d").createMesh;e.exports.createTubeMesh=function(t,e){return h(t,e,{shaders:u,traceType:"streamtube"})}},{"./lib/shaders":313,"gl-cone3d":244,"gl-vec3":347,"gl-vec4":383}],315:[function(t,e,r){var n=t("gl-shader"),a=t("glslify"),i=a(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec4 uv;\nattribute vec3 f;\nattribute vec3 normal;\n\nuniform vec3 objectOffset;\nuniform mat4 model, view, projection, inverseModel;\nuniform vec3 lightPosition, eyePosition;\nuniform sampler2D colormap;\n\nvarying float value, kill;\nvarying vec3 worldCoordinate;\nvarying vec2 planeCoordinate;\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\nvarying vec4 vColor;\n\nvoid main() {\n  vec3 localCoordinate = vec3(uv.zw, f.x);\n  worldCoordinate = objectOffset + localCoordinate;\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\n  vec4 clipPosition = projection * view * worldPosition;\n  gl_Position = clipPosition;\n  kill = f.y;\n  value = f.z;\n  planeCoordinate = uv.xy;\n\n  vColor = texture2D(colormap, vec2(value, value));\n\n  //Lighting geometry parameters\n  vec4 cameraCoordinate = view * worldPosition;\n  cameraCoordinate.xyz /= cameraCoordinate.w;\n  lightDirection = lightPosition - cameraCoordinate.xyz;\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\n}\n"]),o=a(["precision highp float;\n#define GLSLIFY 1\n\nfloat beckmannDistribution(float x, float roughness) {\n  float NdotH = max(x, 0.0001);\n  float cos2Alpha = NdotH * NdotH;\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\n  float roughness2 = roughness * roughness;\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\n  return exp(tan2Alpha / roughness2) / denom;\n}\n\nfloat beckmannSpecular(\n  vec3 lightDirection,\n  vec3 viewDirection,\n  vec3 surfaceNormal,\n  float roughness) {\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\n}\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec3 lowerBound, upperBound;\nuniform float contourTint;\nuniform vec4 contourColor;\nuniform sampler2D colormap;\nuniform vec3 clipBounds[2];\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\nuniform float vertexColor;\n\nvarying float value, kill;\nvarying vec3 worldCoordinate;\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\nvarying vec4 vColor;\n\nvoid main() {\n  if ((kill > 0.0) ||\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\n\n  vec3 N = normalize(surfaceNormal);\n  vec3 V = normalize(eyeDirection);\n  vec3 L = normalize(lightDirection);\n\n  if(gl_FrontFacing) {\n    N = -N;\n  }\n\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\n\n  //decide how to interpolate color \u2014 in vertex or in fragment\n  vec4 surfaceColor =\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\n    step(.5, vertexColor) * vColor;\n\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\n\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\n}\n"]),s=a(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec4 uv;\nattribute float f;\n\nuniform vec3 objectOffset;\nuniform mat3 permutation;\nuniform mat4 model, view, projection;\nuniform float height, zOffset;\nuniform sampler2D colormap;\n\nvarying float value, kill;\nvarying vec3 worldCoordinate;\nvarying vec2 planeCoordinate;\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\nvarying vec4 vColor;\n\nvoid main() {\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\n  worldCoordinate = objectOffset + dataCoordinate;\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\n\n  vec4 clipPosition = projection * view * worldPosition;\n  clipPosition.z += zOffset;\n\n  gl_Position = clipPosition;\n  value = f + objectOffset.z;\n  kill = -1.0;\n  planeCoordinate = uv.zw;\n\n  vColor = texture2D(colormap, vec2(value, value));\n\n  //Don't do lighting for contours\n  surfaceNormal   = vec3(1,0,0);\n  eyeDirection    = vec3(0,1,0);\n  lightDirection  = vec3(0,0,1);\n}\n"]),l=a(["precision highp float;\n#define GLSLIFY 1\n\nbool outOfRange(float a, float b, float p) {\n  return ((p > max(a, b)) || \n          (p < min(a, b)));\n}\n\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y));\n}\n\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\n  return (outOfRange(a.x, b.x, p.x) ||\n          outOfRange(a.y, b.y, p.y) ||\n          outOfRange(a.z, b.z, p.z));\n}\n\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\n  return outOfRange(a.xyz, b.xyz, p.xyz);\n}\n\nuniform vec2 shape;\nuniform vec3 clipBounds[2];\nuniform float pickId;\n\nvarying float value, kill;\nvarying vec3 worldCoordinate;\nvarying vec2 planeCoordinate;\nvarying vec3 surfaceNormal;\n\nvec2 splitFloat(float v) {\n  float vh = 255.0 * v;\n  float upper = floor(vh);\n  float lower = fract(vh);\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\n}\n\nvoid main() {\n  if ((kill > 0.0) ||\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\n\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\n}\n"]);r.createShader=function(t){var e=n(t,i,o,null,[{name:"uv",type:"vec4"},{name:"f",type:"vec3"},{name:"normal",type:"vec3"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,i,l,null,[{name:"uv",type:"vec4"},{name:"f",type:"vec3"},{name:"normal",type:"vec3"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:"uv",type:"vec4"},{name:"f",type:"float"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:"uv",type:"vec4"},{name:"f",type:"float"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{"gl-shader":303,glslify:410}],316:[function(t,e,r){arguments[4][112][0].apply(r,arguments)},{dup:112}],317:[function(t,e,r){"use strict";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=a(e),u=i(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),h=a(e),f=i(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=a(e),d=i(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var v=new E(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,h,f,p,d,[0,0,0]),m={levels:[[],[],[]]};for(var k in t)m[k]=t[k];return m.colormap=m.colormap||"jet",v.update(m),v};var n=t("bit-twiddle"),a=t("gl-buffer"),i=t("gl-vao"),o=t("gl-texture2d"),s=t("typedarray-pool"),l=t("colormap"),c=t("ndarray-ops"),u=t("ndarray-pack"),h=t("ndarray"),f=t("surface-nets"),p=t("gl-mat4/multiply"),d=t("gl-mat4/invert"),g=t("binary-search-bounds"),v=t("ndarray-gradient"),m=t("./lib/shaders"),y=m.createShader,x=m.createContourShader,b=m.createPickShader,_=m.createPickContourShader,w=40,k=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],A=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,a){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=a}!function(){for(var t=0;t<3;++t){var e=A[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function E(t,e,r,n,a,i,o,l,c,u,f,p,d,g,v){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=v,this.intensityBounds=[],this._shader=n,this._pickShader=a,this._coordinateBuffer=i,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var L=E.prototype;L.isTransparent=function(){return this.opacity<1},L.isOpaque=function(){if(this.opacity>=1)return!0;for(var t=0;t<3;++t)if(this._contourCounts[t].length>0||this._dynamicCounts[t]>0)return!0;return!1},L.pickSlots=1,L.setPickBase=function(t){this.pickId=t};var C=[0,0,0],P={showSurface:!1,showContour:!1,projections:[k.slice(),k.slice(),k.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function O(t,e){var r,n,a,i=e.axes&&e.axes.lastCubeProps.axis||C,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=P.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(i[r]>0)][r],p(l,t.model,l);var c=P.clipBounds[r];for(a=0;a<2;++a)for(n=0;n<3;++n)c[a][n]=t.clipBounds[a][n];c[0][r]=-1e8,c[1][r]=1e8}return P.showSurface=o,P.showContour=s,P}var z={model:k,view:k,projection:k,inverseModel:k.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=k.slice(),D=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=z;n.model=t.model||k,n.view=t.view||k,n.projection=t.projection||k,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var a=0;a<2;++a)for(var i=n.clipBounds[a],o=0;o<3;++o)i[o]=Math.min(Math.max(this.clipBounds[a][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=D,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),a=0;a<3;++a)n.eyePosition[a]=s[12+a]/s[15];var l=s[15];for(a=0;a<3;++a)l+=this.lightPosition[a]*s[4*a+3];for(a=0;a<3;++a){var c=s[12+a];for(o=0;o<3;++o)c+=s[4*o+a]*this.lightPosition[o];n.lightPosition[a]=c/l}var u=O(n,this);if(u.showSurface&&e===this.opacity<1){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),a=0;a<3;++a)this.surfaceProject[a]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[a],this._shader.uniforms.clipBounds=u.clipBounds[a],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour&&!e){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),a=0;a<3;++a)for(h.uniforms.permutation=A[a],r.lineWidth(this.contourWidth[a]*this.pixelRatio),o=0;o<this.contourLevels[a].length;++o)o===this.highlightLevel[a]?(h.uniforms.contourColor=this.highlightColor[a],h.uniforms.contourTint=this.highlightTint[a]):0!==o&&o-1!==this.highlightLevel[a]||(h.uniforms.contourColor=this.contourColor[a],h.uniforms.contourTint=this.contourTint[a]),this._contourCounts[a][o]&&(h.uniforms.height=this.contourLevels[a][o],f.draw(r.LINES,this._contourCounts[a][o],this._contourOffsets[a][o]));for(a=0;a<3;++a)for(h.uniforms.model=u.projections[a],h.uniforms.clipBounds=u.clipBounds[a],o=0;o<3;++o)if(this.contourProject[a][o]){h.uniforms.permutation=A[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(h.uniforms.height=this.contourLevels[o][g],f.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(f.unbind(),(f=this._dynamicVAO).bind(),a=0;a<3;++a)if(0!==this._dynamicCounts[a])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=A[a],r.lineWidth(this.dynamicWidth[a]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[a],h.uniforms.contourTint=this.dynamicTint[a],h.uniforms.height=this.dynamicLevel[a],f.draw(r.LINES,this._dynamicCounts[a],this._dynamicOffsets[a]),o=0;o<3;++o)this.contourProject[o][a]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[a],this._dynamicOffsets[a]));f.unbind()}}L.draw=function(t){return R.call(this,t,!1)},L.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:k,view:k,projection:k,inverseModel:k,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}L.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||k,r.view=t.view||k,r.projection=t.projection||k,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=D;for(var n=0;n<2;++n)for(var a=r.clipBounds[n],i=0;i<3;++i)a[i]=Math.min(Math.max(this.clipBounds[n][i],-1e8),1e8);var o=O(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),i=0;i<3;++i)for(e.lineWidth(this.contourWidth[i]*this.pixelRatio),s.uniforms.permutation=A[i],n=0;n<this.contourLevels[i].length;++n)this._contourCounts[i][n]&&(s.uniforms.height=this.contourLevels[i][n],l.draw(e.LINES,this._contourCounts[i][n],this._contourOffsets[i][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],i=0;i<3;++i)if(this.contourProject[n][i]){s.uniforms.permutation=A[i],e.lineWidth(this.contourWidth[i]*this.pixelRatio);for(var c=0;c<this.contourLevels[i].length;++c)this._contourCounts[i][c]&&(s.uniforms.height=this.contourLevels[i][c],l.draw(e.LINES,this._contourCounts[i][c],this._contourOffsets[i][c]))}l.unbind()}},L.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,a=Math.floor(n),i=n-a,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;a+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?i:1-i,f=0;f<2;++f)for(var p=a+u,d=s+f,v=h*(f?l:1-l),m=0;m<3;++m)c[m]+=this._field[m].get(p,d)*v;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=i<.5?a:a+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],m=0;m<3;++m)r.dataCoordinate[m]=this._field[m].get(r.index[0],r.index[1]);return r},L.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},L.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,"contourWidth"in t&&(this.contourWidth=B(t.contourWidth,Number)),"showContour"in t&&(this.showContour=B(t.showContour,Boolean)),"showSurface"in t&&(this.showSurface=!!t.showSurface),"contourTint"in t&&(this.contourTint=B(t.contourTint,Boolean)),"contourColor"in t&&(this.contourColor=j(t.contourColor)),"contourProject"in t&&(this.contourProject=B(t.contourProject,function(t){return B(t,Boolean)})),"surfaceProject"in t&&(this.surfaceProject=t.surfaceProject),"dynamicColor"in t&&(this.dynamicColor=j(t.dynamicColor)),"dynamicTint"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),"dynamicWidth"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),"opacity"in t&&(this.opacity=t.opacity),"colorBounds"in t&&(this.colorBounds=t.colorBounds),"vertexColor"in t&&(this.vertexColor=t.vertexColor?1:0);var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),"field"in t||"coords"in t){var a=(e.shape[0]+2)*(e.shape[1]+2);a>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(a))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var i=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[i[0]+2,i[1]+2]);if(t.coords){var p=t.coords;if(!Array.isArray(p)||3!==p.length)throw new Error("gl-surface: invalid coordinates for x/y");for(o=0;o<2;++o){var d=p[o];for(b=0;b<2;++b)if(d.shape[b]!==i[b])throw new Error("gl-surface: coords have incorrect shape");this.padField(this._field[o],d)}}else if(t.ticks){var g=t.ticks;if(!Array.isArray(g)||2!==g.length)throw new Error("gl-surface: invalid ticks");for(o=0;o<2;++o){var m=g[o];if((Array.isArray(m)||m.length)&&(m=h(m)),m.shape[0]!==i[o])throw new Error("gl-surface: invalid tick length");var y=h(m.data,i);y.stride[o]=m.stride[0],y.stride[1^o]=0,this.padField(this._field[o],y)}}else{for(o=0;o<2;++o){var x=[0,0];x[o]=1,this._field[o]=h(this._field[o].data,[i[0]+2,i[1]+2],x,0)}this._field[0].set(0,0,0);for(var b=0;b<i[0];++b)this._field[0].set(b+1,0,b);for(this._field[0].set(i[0]+1,0,i[0]-1),this._field[1].set(0,0,0),b=0;b<i[1];++b)this._field[1].set(0,b+1,b);this._field[1].set(0,i[1]+1,i[1]-1)}var _=this._field,w=h(s.mallocFloat(3*_[2].size*2),[3,i[0]+2,i[1]+2,2]);for(o=0;o<3;++o)v(w.pick(o),_[o],"mirror");var k=h(s.mallocFloat(3*_[2].size),[i[0]+2,i[1]+2,3]);for(o=0;o<i[0]+2;++o)for(b=0;b<i[1]+2;++b){var A=w.get(0,o,b,0),M=w.get(0,o,b,1),E=w.get(1,o,b,0),L=w.get(1,o,b,1),C=w.get(2,o,b,0),P=w.get(2,o,b,1),O=E*P-L*C,z=C*M-P*A,I=A*L-M*E,D=Math.sqrt(O*O+z*z+I*I);D<1e-8?(D=Math.max(Math.abs(O),Math.abs(z),Math.abs(I)))<1e-8?(I=1,z=O=0,D=1):D=1/D:D=1/Math.sqrt(D),k.set(o,b,0,O*D),k.set(o,b,1,z*D),k.set(o,b,2,I*D)}s.free(w.data);var R=[1/0,1/0,1/0],F=[-1/0,-1/0,-1/0],N=1/0,V=-1/0,U=(i[0]-1)*(i[1]-1)*6,q=s.mallocFloat(n.nextPow2(10*U)),H=0,G=0;for(o=0;o<i[0]-1;++o)t:for(b=0;b<i[1]-1;++b){for(var Y=0;Y<2;++Y)for(var W=0;W<2;++W)for(var X=0;X<3;++X){var Z=this._field[X].get(1+o+Y,1+b+W);if(isNaN(Z)||!isFinite(Z))continue t}for(X=0;X<6;++X){var J=o+T[X][0],K=b+T[X][1],Q=this._field[0].get(J+1,K+1),$=this._field[1].get(J+1,K+1);Z=this._field[2].get(J+1,K+1),O=k.get(J+1,K+1,0),z=k.get(J+1,K+1,1),I=k.get(J+1,K+1,2),t.intensity&&(tt=t.intensity.get(J,K));var tt=t.intensity?t.intensity.get(J,K):Z+this.objectOffset[2];q[H++]=J,q[H++]=K,q[H++]=Q,q[H++]=$,q[H++]=Z,q[H++]=0,q[H++]=tt,q[H++]=O,q[H++]=z,q[H++]=I,R[0]=Math.min(R[0],Q+this.objectOffset[0]),R[1]=Math.min(R[1],$+this.objectOffset[1]),R[2]=Math.min(R[2],Z+this.objectOffset[2]),N=Math.min(N,tt),F[0]=Math.max(F[0],Q+this.objectOffset[0]),F[1]=Math.max(F[1],$+this.objectOffset[1]),F[2]=Math.max(F[2],Z+this.objectOffset[2]),V=Math.max(V,tt),G+=1}}for(t.intensityBounds&&(N=+t.intensityBounds[0],V=+t.intensityBounds[1]),o=6;o<H;o+=10)q[o]=(q[o]-N)/(V-N);this._vertexCount=G,this._coordinateBuffer.update(q.subarray(0,H)),s.freeFloat(q),s.free(k.data),this.bounds=[R,F],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===N&&this.intensityBounds[1]===V||(r=!0),this.intensityBounds=[N,V]}if("levels"in t){var et=t.levels;for(et=Array.isArray(et[0])?et.slice():[[],[],et],o=0;o<3;++o)et[o]=et[o].slice(),et[o].sort(function(t,e){return t-e});for(o=0;o<3;++o)for(b=0;b<et[o].length;++b)et[o][b]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(et[o].length!==this.contourLevels[o].length){r=!0;break}for(b=0;b<et[o].length;++b)if(et[o][b]!==this.contourLevels[o][b]){r=!0;break t}}this.contourLevels=et}if(r){_=this._field,i=this.shape;for(var rt=[],nt=0;nt<3;++nt){var at=this.contourLevels[nt],it=[],ot=[],st=[0,0,0];for(o=0;o<at.length;++o){var lt=f(this._field[nt],at[o]);it.push(rt.length/5|0),G=0;t:for(b=0;b<lt.cells.length;++b){var ct=lt.cells[b];for(X=0;X<2;++X){var ut=lt.positions[ct[X]],ht=ut[0],ft=0|Math.floor(ht),pt=ht-ft,dt=ut[1],gt=0|Math.floor(dt),vt=dt-gt,mt=!1;e:for(var yt=0;yt<3;++yt){st[yt]=0;var xt=(nt+yt+1)%3;for(Y=0;Y<2;++Y){var bt=Y?pt:1-pt;for(J=0|Math.min(Math.max(ft+Y,0),i[0]),W=0;W<2;++W){var _t=W?vt:1-vt;if(K=0|Math.min(Math.max(gt+W,0),i[1]),Z=yt<2?this._field[xt].get(J,K):(this.intensity.get(J,K)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(Z)||isNaN(Z)){mt=!0;break e}var wt=bt*_t;st[yt]+=wt*Z}}}if(mt){if(X>0){for(var kt=0;kt<5;++kt)rt.pop();G-=1}continue t}rt.push(st[0],st[1],ut[0],ut[1],st[2]),G+=1}}ot.push(G)}this._contourOffsets[nt]=it,this._contourCounts[nt]=ot}var Tt=s.mallocFloat(rt.length);for(o=0;o<rt.length;++o)Tt[o]=rt[o];this._contourBuffer.update(Tt),s.freeFloat(Tt)}t.colormap&&this._colorMap.setPixels(function(t){var e=u([l({colormap:t,nshades:S,format:"rgba"}).map(function(t){return[t[0],t[1],t[2],255*t[3]]})]);return c.divseq(e,255),e}(t.colormap))},L.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},L.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,a=this.shape,i=s.mallocFloat(12*a[0]*a[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),g=d.cells,v=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var m=g[e],y=0;y<2;++y){var x=v[m[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,a[0]),k=b-_,T=1-k,A=+x[1],M=0|A,S=0|Math.min(M+1,a[1]),E=A-M,L=1-E,C=T*L,P=T*E,O=k*L,z=k*E,I=C*h.get(_,M)+P*h.get(_,S)+O*h.get(w,M)+z*h.get(w,S),D=C*p.get(_,M)+P*p.get(_,S)+O*p.get(w,M)+z*p.get(w,S);if(isNaN(I)||isNaN(D)){y&&(n-=1);break}i[2*n+0]=I,i[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(i.subarray(0,2*n)),s.freeFloat(i)}}},{"./lib/shaders":315,"binary-search-bounds":316,"bit-twiddle":93,colormap:127,"gl-buffer":243,"gl-mat4/invert":267,"gl-mat4/multiply":269,"gl-texture2d":323,"gl-vao":328,ndarray:451,"ndarray-gradient":442,"ndarray-ops":445,"ndarray-pack":446,"surface-nets":529,"typedarray-pool":543}],318:[function(t,e,r){"use strict";var n=t("css-font"),a=t("pick-by-alias"),i=t("regl"),o=t("gl-util/context"),s=t("es6-weak-map"),l=t("color-normalize"),c=t("font-atlas"),u=t("typedarray-pool"),h=t("parse-rect"),f=t("is-plain-obj"),p=t("parse-unit"),d=t("to-px"),g=t("detect-kerning"),v=t("object-assign"),m=t("font-measure"),y=t("flatten-vertex-data"),x=t("bit-twiddle").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement("div"));w.style.font="italic small-caps bold condensed 16px/2 cursive",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var k=function(t){!function(t){return"function"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||i({gl:this.gl}),this.charBuffer=this.regl.buffer({type:"uint8",usage:"stream"}),this.sizeBuffer=this.regl.buffer({type:"float",usage:"stream"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};k.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:"src alpha",dstRGB:"one minus src alpha",srcAlpha:"one minus dst alpha",dstAlpha:"one"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop("count"),offset:t.prop("offset"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this("sizeBuffer")},width:{offset:0,stride:8,buffer:t.this("sizeBuffer")},char:t.this("charBuffer"),position:t.this("position")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop("color"),opacity:t.prop("opacity"),viewport:t.this("viewportArray"),scale:t.this("scale"),align:t.prop("align"),baseline:t.prop("baseline"),translate:t.this("translate"),positionOffset:t.prop("positionOffset")},primitive:"points",viewport:t.this("viewport"),vert:"\n\t\t\tprecision highp float;\n\t\t\tattribute float width, charOffset, char;\n\t\t\tattribute vec2 position;\n\t\t\tuniform float fontSize, charStep, em, align, baseline;\n\t\t\tuniform vec4 viewport;\n\t\t\tuniform vec4 color;\n\t\t\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\n\t\t\tvarying vec2 charCoord, charId;\n\t\t\tvarying float charWidth;\n\t\t\tvarying vec4 fontColor;\n\t\t\tvoid main () {\n\t\t\t\t"+(k.normalViewport?"":"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);")+"\n\n\t\t\t\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\n\t\t\t\t\t+ positionOffset))\n\t\t\t\t\t/ (viewport.zw * scale.xy);\n\n\t\t\t\tvec2 position = (position + translate) * scale;\n\t\t\t\tposition += offset * scale;\n\n\t\t\t\t"+(k.normalViewport?"position.y = 1. - position.y;":"")+"\n\n\t\t\t\tcharCoord = position * viewport.zw + viewport.xy;\n\n\t\t\t\tgl_Position = vec4(position * 2. - 1., 0, 1);\n\n\t\t\t\tgl_PointSize = charStep;\n\n\t\t\t\tcharId.x = mod(char, atlasDim.x);\n\t\t\t\tcharId.y = floor(char / atlasDim.x);\n\n\t\t\t\tcharWidth = width * em;\n\n\t\t\t\tfontColor = color / 255.;\n\t\t\t}",frag:"\n\t\t\tprecision highp float;\n\t\t\tuniform sampler2D atlas;\n\t\t\tuniform float fontSize, charStep, opacity;\n\t\t\tuniform vec2 atlasSize;\n\t\t\tuniform vec4 viewport;\n\t\t\tvarying vec4 fontColor;\n\t\t\tvarying vec2 charCoord, charId;\n\t\t\tvarying float charWidth;\n\n\t\t\tfloat lightness(vec4 color) {\n\t\t\t\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\n\t\t\t}\n\n\t\t\tvoid main () {\n\t\t\t\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\n\t\t\t\tfloat halfCharStep = floor(charStep * .5 + .5);\n\n\t\t\t\t// invert y and shift by 1px (FF expecially needs that)\n\t\t\t\tuv.y = charStep - uv.y;\n\n\t\t\t\t// ignore points outside of character bounding box\n\t\t\t\tfloat halfCharWidth = ceil(charWidth * .5);\n\t\t\t\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\n\t\t\t\t\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\n\n\t\t\t\tuv += charId * charStep;\n\t\t\t\tuv = uv / atlasSize;\n\n\t\t\t\tvec4 color = fontColor;\n\t\t\t\tvec4 mask = texture2D(atlas, uv);\n\n\t\t\t\tfloat maskY = lightness(mask);\n\t\t\t\t// float colorY = lightness(color);\n\t\t\t\tcolor.a *= maskY;\n\t\t\t\tcolor.a *= opacity;\n\n\t\t\t\t// color.a += .1;\n\n\t\t\t\t// antialiasing, see yiq color space y-channel formula\n\t\t\t\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\n\n\t\t\t\tgl_FragColor = color;\n\t\t\t}"});return{regl:t,draw:e,atlas:{}}},k.prototype.update=function(t){var e=this;if("string"==typeof t)t={text:t};else if(!t)return;null!=(t=a(t,{position:"position positions coord coords coordinates",font:"font fontFace fontface typeface cssFont css-font family fontFamily",fontSize:"fontSize fontsize size font-size",text:"text texts chars characters value values symbols",align:"align alignment textAlign textbaseline",baseline:"baseline textBaseline textbaseline",direction:"dir direction textDirection",color:"color colour fill fill-color fillColor textColor textcolor",kerning:"kerning kern",range:"range dataBox",viewport:"vp viewport viewBox viewbox viewPort",opacity:"opacity alpha transparency visible visibility opaque",offset:"offset positionOffset padding shift indent indentation"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map(function(t){return parseFloat(t)}):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),k.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&("number"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=k.baseFontSize+"px sans-serif");var r,i=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach(function(t,r){if("string"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(k.baseFontSize+"px "+t)}else t=n.parse(n.stringify(t));var a=n.stringify({size:k.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&a==e.font[r].baseString||(i=!0,e.font[r]=k.fonts[a],e.font[r]))){var c=t.family.join(", "),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:a,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:m(c,{origin:"top",fontSize:k.baseFontSize,fontStyle:u.join(" ")})},k.fonts[a]=e.font[r]}}),(i||o)&&this.font.forEach(function(r,a){var i=n.stringify({size:e.fontSize[a],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[a]=e.shader.atlas[i],!e.fontAtlas[a]){var o=r.metrics;e.shader.atlas[i]=e.fontAtlas[a]={fontString:i,step:2*Math.ceil(e.fontSize[a]*o.bottom*.5),em:e.fontSize[a],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)}),"string"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||i){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join("")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach(function(t,n){k.atlasContext.font=t.baseString;for(var a=e.fontAtlas[n],i=0;i<e.text.length;i++){var o=e.text.charAt(i);if(null==a.ids[o]&&(a.ids[o]=a.chars.length,a.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=k.atlasContext.measureText(o).width/k.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);v(t.kerning,g(t.family,{pairs:s}))}}})}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,T=u.mallocFloat(2*this.count),A=0,M=0;A<this.counts.length;A++){var S=this.counts[A];if(w)for(var E=0;E<S;E++)T[M++]=t.position[2*A],T[M++]=t.position[2*A+1];else for(var L=0;L<S;L++)T[M++]=t.position[A][0],T[M++]=t.position[A][1]}this.position.call?this.position({type:"float",data:T}):this.position=this.regl.buffer({type:"float",data:T}),u.freeFloat(T)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||i){var C=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var O=0,z=0;O<this.counts.length;O++){for(var I=this.counts[O],D=this.font[O]||this.font[0],R=this.fontAtlas[O]||this.fontAtlas[0],F=0;F<I;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(C[z]=R.ids[B],P[2*z]=D.width[B],F){var j=P[2*z-2],V=P[2*z],U=P[2*z-1]+.5*j+.5*V;if(this.kerning){var q=D.kerning[N+B];q&&(U+=.001*q)}P[2*z+1]=U}else P[2*z+1]=.5*P[2*z];z++}this.textWidth.push(P.length?.5*P[2*z-2]+P[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:C,type:"uint8",usage:"stream"}),this.sizeBuffer({data:P,type:"float",usage:"stream"}),u.freeUint8(C),u.freeFloat(P),r.length&&this.font.forEach(function(t,r){var n=e.fontAtlas[r],a=n.step,i=Math.floor(k.maxAtlasSize/a),o=Math.min(i,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*a),u=x(s*a);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:k.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[a,a]})})})}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map(function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if("number"==typeof n)return n;switch(n){case"right":case"end":return-t;case"center":case"centre":case"middle":return.5*-t}return 0})),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map(function(t,r){var n=(e.font[r]||e.font[0]).metrics,a=0;return a+=.5*n.bottom,a+="number"==typeof t?t-n.baseline:-n[t],k.normalViewport||(a*=-1),a})),null!=t.color)if(t.color||(t.color="transparent"),"string"!=typeof t.color&&isNaN(t.color)){var H;if("number"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),"uint8"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,"uint8"),4*Z)}this.color=H}else this.color=l(t.color,"uint8");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},k.prototype.destroy=function(){},k.prototype.kerning=!0,k.prototype.position={constant:new Float32Array(2)},k.prototype.translate=null,k.prototype.scale=null,k.prototype.font=null,k.prototype.text="",k.prototype.positionOffset=[0,0],k.prototype.opacity=1,k.prototype.color=new Uint8Array([0,0,0,255]),k.prototype.alignOffset=[0,0],k.normalViewport=!1,k.maxAtlasSize=1024,k.atlasCanvas=document.createElement("canvas"),k.atlasContext=k.atlasCanvas.getContext("2d",{alpha:!1}),k.baseFontSize=64,k.fonts={},e.exports=k},{"bit-twiddle":93,"color-normalize":121,"css-font":140,"detect-kerning":167,"es6-weak-map":319,"flatten-vertex-data":229,"font-atlas":230,"font-measure":231,"gl-util/context":324,"is-plain-obj":423,"object-assign":455,"parse-rect":460,"parse-unit":462,"pick-by-alias":466,regl:500,"to-px":537,"typedarray-pool":543}],319:[function(t,e,r){"use strict";e.exports=t("./is-implemented")()?WeakMap:t("./polyfill")},{"./is-implemented":320,"./polyfill":322}],320:[function(t,e,r){"use strict";e.exports=function(){var t,e;if("function"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},"one"],[{},"two"],[{},"three"]])}catch(t){return!1}return"[object WeakMap]"===String(t)&&("function"==typeof t.set&&(t.set({},1)===t&&("function"==typeof t.delete&&("function"==typeof t.has&&"one"===t.get(e)))))}},{}],321:[function(t,e,r){"use strict";e.exports="function"==typeof WeakMap&&"[object WeakMap]"===Object.prototype.toString.call(new WeakMap)},{}],322:[function(t,e,r){"use strict";var n,a=t("es5-ext/object/is-value"),i=t("es5-ext/object/set-prototype-of"),o=t("es5-ext/object/valid-object"),s=t("es5-ext/object/valid-value"),l=t("es5-ext/string/random-uniq"),c=t("d"),u=t("es6-iterator/get"),h=t("es6-iterator/for-of"),f=t("es6-symbol").toStringTag,p=t("./is-native-implemented"),d=Array.isArray,g=Object.defineProperty,v=Object.prototype.hasOwnProperty,m=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError("Constructor requires 'new'");return t=p&&i&&WeakMap!==n?i(new WeakMap,m(this)):this,a(e)&&(d(e)||(e=u(e))),g(t,"__weakMapData__",c("c","$weakMap$"+l())),e?(h(e,function(e){s(e),t.set(e[0],e[1])}),t):t},p&&(i&&i(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c(function(t){return!!v.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)}),get:c(function(t){if(v.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]}),has:c(function(t){return v.call(o(t),this.__weakMapData__)}),set:c(function(t,e){return g(o(t),this.__weakMapData__,c("c",e)),this}),toString:c(function(){return"[object WeakMap]"})}),g(n.prototype,f,c("c","WeakMap"))},{"./is-native-implemented":321,d:152,"es5-ext/object/is-value":196,"es5-ext/object/set-prototype-of":202,"es5-ext/object/valid-object":206,"es5-ext/object/valid-value":207,"es5-ext/string/random-uniq":212,"es6-iterator/for-of":214,"es6-iterator/get":215,"es6-symbol":221}],323:[function(t,e,r){"use strict";var n=t("ndarray"),a=t("ndarray-ops"),i=t("typedarray-pool");e.exports=function(t){if(arguments.length<=1)throw new Error("gl-texture2d: Missing arguments for texture2d constructor");o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t);if("number"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if("object"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,a,i){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,a,a,i,e),new f(t,o,r,n,a,i)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error("gl-texture2d: Invalid texture size");var l=d(o,e.stride.slice()),c=0;"float32"===r?c=t.FLOAT:"float64"===r?(c=t.FLOAT,l=!1,r="float32"):"uint8"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r="uint8");var h,p,v=0;if(2===o.length)v=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error("gl-texture2d: Invalid shape for texture");if(1===o[2])v=t.ALPHA;else if(2===o[2])v=t.LUMINANCE_ALPHA;else if(3===o[2])v=t.RGB;else{if(4!==o[2])throw new Error("gl-texture2d: Invalid shape for pixel coords");v=t.RGBA}}c!==t.FLOAT||t.getExtension("OES_texture_float")||(c=t.UNSIGNED_BYTE,l=!1);var m=e.size;if(l)h=0===e.offset&&e.data.length===m?e.data:e.data.subarray(e.offset,e.offset+m);else{var y=[o[2],o[2]*o[0],1];p=i.malloc(m,r);var x=n(p,o,y,0);"float32"!==r&&"float64"!==r||c!==t.UNSIGNED_BYTE?a.assign(x,e):u(x,e),h=p.subarray(0,m)}var b=g(t);t.texImage2D(t.TEXTURE_2D,0,v,o[0],o[1],0,v,c,h),l||i.free(p);return new f(t,b,o[0],o[1],v,c)}(t,e)}throw new Error("gl-texture2d: Invalid arguments for texture2d constructor")};var o=null,s=null,l=null;function c(t){return"undefined"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||"undefined"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||"undefined"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||"undefined"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){a.muls(t,e,255)};function h(t,e,r){var n=t.gl,a=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error("gl-texture2d: Invalid texture size");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function f(t,e,r,n,a,i){this.gl=t,this.handle=e,this.format=a,this.type=i,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=f.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,a){var i=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error("gl-texture2d: Invalid texture shape");if(a===t.FLOAT&&!t.getExtension("OES_texture_float"))throw new Error("gl-texture2d: Floating point textures not supported on this platform");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,a,null),new f(t,o,e,r,n,a)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension("OES_texture_float_linear")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error("gl-texture2d: Unknown filter mode "+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension("OES_texture_float_linear")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error("gl-texture2d: Unknown filter mode "+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension("EXT_texture_filter_anisotropic");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error("gl-texture2d: Unknown wrap mode "+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error("gl-texture2d: Unknown wrap mode "+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error("gl-texture2d: Must specify wrap mode for rows and columns");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error("gl-texture2d: Unknown wrap mode "+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error("gl-texture2d: Invalid texture shape")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error("gl-texture2d: Unsupported data type");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error("gl-texture2d: Texture dimensions are out of bounds");!function(t,e,r,o,s,l,c,h){var f=h.dtype,p=h.shape.slice();if(p.length<2||p.length>3)throw new Error("gl-texture2d: Invalid ndarray, must be 2d or 3d");var g=0,v=0,m=d(p,h.stride.slice());"float32"===f?g=t.FLOAT:"float64"===f?(g=t.FLOAT,m=!1,f="float32"):"uint8"===f?g=t.UNSIGNED_BYTE:(g=t.UNSIGNED_BYTE,m=!1,f="uint8");if(2===p.length)v=t.LUMINANCE,p=[p[0],p[1],1],h=n(h.data,p,[h.stride[0],h.stride[1],1],h.offset);else{if(3!==p.length)throw new Error("gl-texture2d: Invalid shape for texture");if(1===p[2])v=t.ALPHA;else if(2===p[2])v=t.LUMINANCE_ALPHA;else if(3===p[2])v=t.RGB;else{if(4!==p[2])throw new Error("gl-texture2d: Invalid shape for pixel coords");v=t.RGBA}p[2]}v!==t.LUMINANCE&&v!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(v=s);if(v!==s)throw new Error("gl-texture2d: Incompatible texture format for setPixels");var y=h.size,x=c.indexOf(o)<0;x&&c.push(o);if(g===l&&m)0===h.offset&&h.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data.subarray(h.offset,h.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data.subarray(h.offset,h.offset+y));else{var b;b=l===t.FLOAT?i.mallocFloat32(y):i.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);g===t.FLOAT&&l===t.UNSIGNED_BYTE?u(_,h):a.assign(_,h),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?i.freeFloat32(b):i.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:451,"ndarray-ops":445,"typedarray-pool":543}],324:[function(t,e,r){(function(r){"use strict";var n=t("pick-by-alias");function a(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function i(t){return"function"==typeof t.getContext&&"width"in t&&"height"in t}function o(){var t=document.createElement("canvas");return t.style.position="absolute",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?"string"==typeof t&&(t={container:t}):t={},i(t)?t={container:t}:t="string"==typeof(e=t).nodeName&&"function"==typeof e.appendChild&&"function"==typeof e.getBoundingClientRect?{container:t}:function(t){return"function"==typeof t.drawArrays||"function"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:"container target element el canvas holder parent parentNode wrapper use ref root node",gl:"gl context webgl glContext",attrs:"attributes attrs contextAttributes",pixelRatio:"pixelRatio pxRatio px ratio pxratio pixelratio",width:"w width",height:"h height"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if("string"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error("Element "+t.container+" is not found");t.container=s}i(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),a(t))}else if(!t.canvas){if("undefined"==typeof document)throw Error("Not DOM environment. Use headless-gl.");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),a(t)}if(!t.gl)try{t.gl=t.canvas.getContext("webgl",t.attrs)}catch(e){try{t.gl=t.canvas.getContext("experimental-webgl",t.attrs)}catch(e){t.gl=t.canvas.getContext("webgl-experimental",t.attrs)}}return t.gl}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"pick-by-alias":466}],325:[function(t,e,r){"use strict";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error("gl-vao: Too many vertex attributes");for(var a=0;a<r.length;++a){var i=r[a];if(i.buffer){var o=i.buffer,s=i.size||4,l=i.type||t.FLOAT,c=!!i.normalized,u=i.stride||0,h=i.offset||0;o.bind(),t.enableVertexAttribArray(a),t.vertexAttribPointer(a,s,l,c,u,h)}else{if("number"==typeof i)t.vertexAttrib1f(a,i);else if(1===i.length)t.vertexAttrib1f(a,i[0]);else if(2===i.length)t.vertexAttrib2f(a,i[0],i[1]);else if(3===i.length)t.vertexAttrib3f(a,i[0],i[1],i[2]);else{if(4!==i.length)throw new Error("gl-vao: Invalid vertex attribute");t.vertexAttrib4f(a,i[0],i[1],i[2],i[3])}t.disableVertexAttribArray(a)}}for(;a<n;++a)t.disableVertexAttribArray(a)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),a=0;a<n;++a)t.disableVertexAttribArray(a)}},{}],326:[function(t,e,r){"use strict";var n=t("./do-bind.js");function a(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}a.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},a.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.dispose=function(){},a.prototype.unbind=function(){},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new a(t)}},{"./do-bind.js":325}],327:[function(t,e,r){"use strict";var n=t("./do-bind.js");function a(t,e,r,n,a,i){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=a,this.d=i}function i(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}a.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},i.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},i.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},i.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},i.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var i=0;i<t.length;++i){var o=t[i];"number"==typeof o?this._attribs.push(new a(i,1,o)):Array.isArray(o)&&this._attribs.push(new a(i,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new i(t,e,e.createVertexArrayOES())}},{"./do-bind.js":325}],328:[function(t,e,r){"use strict";var n=t("./lib/vao-native.js"),a=t("./lib/vao-emulated.js");function i(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new i(t):t.getExtension("OES_vertex_array_object");return(s=l?n(t,l):a(t)).update(e,r,o),s}},{"./lib/vao-emulated.js":326,"./lib/vao-native.js":327}],329:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],330:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);a(r,r),a(o,o);var s=i(r,o);return s>1?0:Math.acos(s)};var n=t("./fromValues"),a=t("./normalize"),i=t("./dot")},{"./dot":340,"./fromValues":346,"./normalize":357}],331:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],332:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],333:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],334:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],335:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[0],s=r[1],l=r[2];return t[0]=a*l-i*s,t[1]=i*o-n*l,t[2]=n*s-a*o,t}},{}],336:[function(t,e,r){e.exports=t("./distance")},{"./distance":337}],337:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2];return Math.sqrt(r*r+n*n+a*a)}},{}],338:[function(t,e,r){e.exports=t("./divide")},{"./divide":339}],339:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],340:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],341:[function(t,e,r){e.exports=1e-6},{}],342:[function(t,e,r){e.exports=function(t,e){var r=t[0],a=t[1],i=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(a-s)<=n*Math.max(1,Math.abs(a),Math.abs(s))&&Math.abs(i-l)<=n*Math.max(1,Math.abs(i),Math.abs(l))};var n=t("./epsilon")},{"./epsilon":341}],343:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],344:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],345:[function(t,e,r){e.exports=function(t,e,r,a,i,o){var s,l;e||(e=3);r||(r=0);l=a?Math.min(a*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],i(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t("./create")()},{"./create":334}],346:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],347:[function(t,e,r){e.exports={EPSILON:t("./epsilon"),create:t("./create"),clone:t("./clone"),angle:t("./angle"),fromValues:t("./fromValues"),copy:t("./copy"),set:t("./set"),equals:t("./equals"),exactEquals:t("./exactEquals"),add:t("./add"),subtract:t("./subtract"),sub:t("./sub"),multiply:t("./multiply"),mul:t("./mul"),divide:t("./divide"),div:t("./div"),min:t("./min"),max:t("./max"),floor:t("./floor"),ceil:t("./ceil"),round:t("./round"),scale:t("./scale"),scaleAndAdd:t("./scaleAndAdd"),distance:t("./distance"),dist:t("./dist"),squaredDistance:t("./squaredDistance"),sqrDist:t("./sqrDist"),length:t("./length"),len:t("./len"),squaredLength:t("./squaredLength"),sqrLen:t("./sqrLen"),negate:t("./negate"),inverse:t("./inverse"),normalize:t("./normalize"),dot:t("./dot"),cross:t("./cross"),lerp:t("./lerp"),random:t("./random"),transformMat4:t("./transformMat4"),transformMat3:t("./transformMat3"),transformQuat:t("./transformQuat"),rotateX:t("./rotateX"),rotateY:t("./rotateY"),rotateZ:t("./rotateZ"),forEach:t("./forEach")}},{"./add":329,"./angle":330,"./ceil":331,"./clone":332,"./copy":333,"./create":334,"./cross":335,"./dist":336,"./distance":337,"./div":338,"./divide":339,"./dot":340,"./epsilon":341,"./equals":342,"./exactEquals":343,"./floor":344,"./forEach":345,"./fromValues":346,"./inverse":348,"./len":349,"./length":350,"./lerp":351,"./max":352,"./min":353,"./mul":354,"./multiply":355,"./negate":356,"./normalize":357,"./random":358,"./rotateX":359,"./rotateY":360,"./rotateZ":361,"./round":362,"./scale":363,"./scaleAndAdd":364,"./set":365,"./sqrDist":366,"./sqrLen":367,"./squaredDistance":368,"./squaredLength":369,"./sub":370,"./subtract":371,"./transformMat3":372,"./transformMat4":373,"./transformQuat":374}],348:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],349:[function(t,e,r){e.exports=t("./length")},{"./length":350}],350:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],351:[function(t,e,r){e.exports=function(t,e,r,n){var a=e[0],i=e[1],o=e[2];return t[0]=a+n*(r[0]-a),t[1]=i+n*(r[1]-i),t[2]=o+n*(r[2]-o),t}},{}],352:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],353:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],354:[function(t,e,r){e.exports=t("./multiply")},{"./multiply":355}],355:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],356:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],357:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=r*r+n*n+a*a;i>0&&(i=1/Math.sqrt(i),t[0]=e[0]*i,t[1]=e[1]*i,t[2]=e[2]*i);return t}},{}],358:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,a=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*a,t[1]=Math.sin(r)*a,t[2]=n*e,t}},{}],359:[function(t,e,r){e.exports=function(t,e,r,n){var a=r[1],i=r[2],o=e[1]-a,s=e[2]-i,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=a+o*c-s*l,t[2]=i+o*l+s*c,t}},{}],360:[function(t,e,r){e.exports=function(t,e,r,n){var a=r[0],i=r[2],o=e[0]-a,s=e[2]-i,l=Math.sin(n),c=Math.cos(n);return t[0]=a+s*l+o*c,t[1]=e[1],t[2]=i+s*c-o*l,t}},{}],361:[function(t,e,r){e.exports=function(t,e,r,n){var a=r[0],i=r[1],o=e[0]-a,s=e[1]-i,l=Math.sin(n),c=Math.cos(n);return t[0]=a+o*c-s*l,t[1]=i+o*l+s*c,t[2]=e[2],t}},{}],362:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],363:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],364:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],365:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],366:[function(t,e,r){e.exports=t("./squaredDistance")},{"./squaredDistance":368}],367:[function(t,e,r){e.exports=t("./squaredLength")},{"./squaredLength":369}],368:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2];return r*r+n*n+a*a}},{}],369:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],370:[function(t,e,r){e.exports=t("./subtract")},{"./subtract":371}],371:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],372:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2];return t[0]=n*r[0]+a*r[3]+i*r[6],t[1]=n*r[1]+a*r[4]+i*r[7],t[2]=n*r[2]+a*r[5]+i*r[8],t}},{}],373:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[3]*n+r[7]*a+r[11]*i+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*a+r[8]*i+r[12])/o,t[1]=(r[1]*n+r[5]*a+r[9]*i+r[13])/o,t[2]=(r[2]*n+r[6]*a+r[10]*i+r[14])/o,t}},{}],374:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*i-l*a,h=c*a+l*n-o*i,f=c*i+o*a-s*n,p=-o*n-s*a-l*i;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},{}],375:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],376:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],377:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],378:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],379:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2],i=e[3]-t[3];return Math.sqrt(r*r+n*n+a*a+i*i)}},{}],380:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],381:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],382:[function(t,e,r){e.exports=function(t,e,r,n){var a=new Float32Array(4);return a[0]=t,a[1]=e,a[2]=r,a[3]=n,a}},{}],383:[function(t,e,r){e.exports={create:t("./create"),clone:t("./clone"),fromValues:t("./fromValues"),copy:t("./copy"),set:t("./set"),add:t("./add"),subtract:t("./subtract"),multiply:t("./multiply"),divide:t("./divide"),min:t("./min"),max:t("./max"),scale:t("./scale"),scaleAndAdd:t("./scaleAndAdd"),distance:t("./distance"),squaredDistance:t("./squaredDistance"),length:t("./length"),squaredLength:t("./squaredLength"),negate:t("./negate"),inverse:t("./inverse"),normalize:t("./normalize"),dot:t("./dot"),lerp:t("./lerp"),random:t("./random"),transformMat4:t("./transformMat4"),transformQuat:t("./transformQuat")}},{"./add":375,"./clone":376,"./copy":377,"./create":378,"./distance":379,"./divide":380,"./dot":381,"./fromValues":382,"./inverse":384,"./length":385,"./lerp":386,"./max":387,"./min":388,"./multiply":389,"./negate":390,"./normalize":391,"./random":392,"./scale":393,"./scaleAndAdd":394,"./set":395,"./squaredDistance":396,"./squaredLength":397,"./subtract":398,"./transformMat4":399,"./transformQuat":400}],384:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],385:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],a=t[3];return Math.sqrt(e*e+r*r+n*n+a*a)}},{}],386:[function(t,e,r){e.exports=function(t,e,r,n){var a=e[0],i=e[1],o=e[2],s=e[3];return t[0]=a+n*(r[0]-a),t[1]=i+n*(r[1]-i),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],387:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],388:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],389:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],390:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],391:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=r*r+n*n+a*a+i*i;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=a*o,t[3]=i*o);return t}},{}],392:[function(t,e,r){var n=t("./normalize"),a=t("./scale");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),a(t,t,e),t}},{"./normalize":391,"./scale":393}],393:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],395:[function(t,e,r){e.exports=function(t,e,r,n,a){return t[0]=e,t[1]=r,t[2]=n,t[3]=a,t}},{}],396:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],a=e[2]-t[2],i=e[3]-t[3];return r*r+n*n+a*a+i*i}},{}],397:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],a=t[3];return e*e+r*r+n*n+a*a}},{}],398:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],399:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3];return t[0]=r[0]*n+r[4]*a+r[8]*i+r[12]*o,t[1]=r[1]*n+r[5]*a+r[9]*i+r[13]*o,t[2]=r[2]*n+r[6]*a+r[10]*i+r[14]*o,t[3]=r[3]*n+r[7]*a+r[11]*i+r[15]*o,t}},{}],400:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*i-l*a,h=c*a+l*n-o*i,f=c*i+o*a-s*n,p=-o*n-s*a-l*i;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},{}],401:[function(t,e,r){e.exports=function(t,e,r,i){return n[0]=i,n[1]=r,n[2]=e,n[3]=t,a[0]};var n=new Uint8Array(4),a=new Float32Array(n.buffer)},{}],402:[function(t,e,r){var n=t("glsl-tokenizer"),a=t("atob-lite");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var i=e[r];if("preprocessor"===i.type){var o=i.data.match(/\#define\s+SHADER_NAME(_B64)?\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?a(l):l).trim()}}}}},{"atob-lite":73,"glsl-tokenizer":409}],403:[function(t,e,r){e.exports=function(t){var e,r,k,T=0,A=0,M=l,S=[],E=[],L=1,C=0,P=0,O=!1,z=!1,I="",D=i,R=n;"300 es"===(t=t||{}).version&&(D=s,R=o);return function(t){return E=[],null!==t?function(t){var r;T=0,k=(I+=t).length;for(;e=I[T],T<k;){switch(r=T,M){case u:T=V();break;case h:case f:T=j();break;case p:T=U();break;case d:T=G();break;case _:T=H();break;case g:T=Y();break;case c:T=W();break;case x:T=N();break;case l:T=B()}if(r!==T)switch(I[r]){case"\n":C=0,++L;break;default:++C}}return A+=T,I=I.slice(T),E}(t.replace?t.replace(/\r\n/g,"\n"):t):function(t){S.length&&F(S.join(""));return M=b,F("(eof)"),E}()};function F(t){t.length&&E.push({type:w[M],data:t,position:P,line:L,column:C})}function B(){return S=S.length?[]:S,"/"===r&&"*"===e?(P=A+T-1,M=u,r=e,T+1):"/"===r&&"/"===e?(P=A+T-1,M=h,r=e,T+1):"#"===e?(M=f,P=A+T,T):/\s/.test(e)?(M=x,P=A+T,T):(O=/\d/.test(e),z=/[^\w_]/.test(e),P=A+T,M=O?d:z?p:c,T)}function N(){return/[^\s]/g.test(e)?(F(S.join("")),M=l,T):(S.push(e),r=e,T+1)}function j(){return"\r"!==e&&"\n"!==e||"\\"===r?(S.push(e),r=e,T+1):(F(S.join("")),M=l,T)}function V(){return"/"===e&&"*"===r?(S.push(e),F(S.join("")),M=l,T+1):(S.push(e),r=e,T+1)}function U(){if("."===r&&/\d/.test(e))return M=g,T;if("/"===r&&"*"===e)return M=u,T;if("/"===r&&"/"===e)return M=h,T;if("."===e&&S.length){for(;q(S););return M=g,T}if(";"===e||")"===e||"("===e){if(S.length)for(;q(S););return F(e),M=l,T+1}var t=2===S.length&&"="!==e;if(/[\w_\d\s]/.test(e)||t){for(;q(S););return M=l,T}return S.push(e),r=e,T+1}function q(t){for(var e,r,n=0;;){if(e=a.indexOf(t.slice(0,t.length+n).join("")),r=a[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join("")}return F(r),P+=r.length,(S=S.slice(r.length)).length}}function H(){return/[^a-fA-F0-9]/.test(e)?(F(S.join("")),M=l,T):(S.push(e),r=e,T+1)}function G(){return"."===e?(S.push(e),M=g,r=e,T+1):/[eE]/.test(e)?(S.push(e),M=g,r=e,T+1):"x"===e&&1===S.length&&"0"===S[0]?(M=_,S.push(e),r=e,T+1):/[^\d]/.test(e)?(F(S.join("")),M=l,T):(S.push(e),r=e,T+1)}function Y(){return"f"===e&&(S.push(e),r=e,T+=1),/[eE]/.test(e)?(S.push(e),r=e,T+1):"-"===e&&/[eE]/.test(r)?(S.push(e),r=e,T+1):/[^\d]/.test(e)?(F(S.join("")),M=l,T):(S.push(e),r=e,T+1)}function W(){if(/[^\d\w_]/.test(e)){var t=S.join("");return M=R.indexOf(t)>-1?y:D.indexOf(t)>-1?m:v,F(S.join("")),M=l,T}return S.push(e),r=e,T+1}};var n=t("./lib/literals"),a=t("./lib/operators"),i=t("./lib/builtins"),o=t("./lib/literals-300es"),s=t("./lib/builtins-300es"),l=999,c=9999,u=0,h=1,f=2,p=3,d=4,g=5,v=6,m=7,y=8,x=9,b=10,_=11,w=["block-comment","line-comment","preprocessor","operator","integer","float","ident","builtin","keyword","whitespace","eof","integer"]},{"./lib/builtins":405,"./lib/builtins-300es":404,"./lib/literals":407,"./lib/literals-300es":406,"./lib/operators":408}],404:[function(t,e,r){var n=t("./builtins");n=n.slice().filter(function(t){return!/^(gl\_|texture)/.test(t)}),e.exports=n.concat(["gl_VertexID","gl_InstanceID","gl_Position","gl_PointSize","gl_FragCoord","gl_FrontFacing","gl_FragDepth","gl_PointCoord","gl_MaxVertexAttribs","gl_MaxVertexUniformVectors","gl_MaxVertexOutputVectors","gl_MaxFragmentInputVectors","gl_MaxVertexTextureImageUnits","gl_MaxCombinedTextureImageUnits","gl_MaxTextureImageUnits","gl_MaxFragmentUniformVectors","gl_MaxDrawBuffers","gl_MinProgramTexelOffset","gl_MaxProgramTexelOffset","gl_DepthRangeParameters","gl_DepthRange","trunc","round","roundEven","isnan","isinf","floatBitsToInt","floatBitsToUint","intBitsToFloat","uintBitsToFloat","packSnorm2x16","unpackSnorm2x16","packUnorm2x16","unpackUnorm2x16","packHalf2x16","unpackHalf2x16","outerProduct","transpose","determinant","inverse","texture","textureSize","textureProj","textureLod","textureOffset","texelFetch","texelFetchOffset","textureProjOffset","textureLodOffset","textureProjLod","textureProjLodOffset","textureGrad","textureGradOffset","textureProjGrad","textureProjGradOffset"])},{"./builtins":405}],405:[function(t,e,r){e.exports=["abs","acos","all","any","asin","atan","ceil","clamp","cos","cross","dFdx","dFdy","degrees","distance","dot","equal","exp","exp2","faceforward","floor","fract","gl_BackColor","gl_BackLightModelProduct","gl_BackLightProduct","gl_BackMaterial","gl_BackSecondaryColor","gl_ClipPlane","gl_ClipVertex","gl_Color","gl_DepthRange","gl_DepthRangeParameters","gl_EyePlaneQ","gl_EyePlaneR","gl_EyePlaneS","gl_EyePlaneT","gl_Fog","gl_FogCoord","gl_FogFragCoord","gl_FogParameters","gl_FragColor","gl_FragCoord","gl_FragData","gl_FragDepth","gl_FragDepthEXT","gl_FrontColor","gl_FrontFacing","gl_FrontLightModelProduct","gl_FrontLightProduct","gl_FrontMaterial","gl_FrontSecondaryColor","gl_LightModel","gl_LightModelParameters","gl_LightModelProducts","gl_LightProducts","gl_LightSource","gl_LightSourceParameters","gl_MaterialParameters","gl_MaxClipPlanes","gl_MaxCombinedTextureImageUnits","gl_MaxDrawBuffers","gl_MaxFragmentUniformComponents","gl_MaxLights","gl_MaxTextureCoords","gl_MaxTextureImageUnits","gl_MaxTextureUnits","gl_MaxVaryingFloats","gl_MaxVertexAttribs","gl_MaxVertexTextureImageUnits","gl_MaxVertexUniformComponents","gl_ModelViewMatrix","gl_ModelViewMatrixInverse","gl_ModelViewMatrixInverseTranspose","gl_ModelViewMatrixTranspose","gl_ModelViewProjectionMatrix","gl_ModelViewProjectionMatrixInverse","gl_ModelViewProjectionMatrixInverseTranspose","gl_ModelViewProjectionMatrixTranspose","gl_MultiTexCoord0","gl_MultiTexCoord1","gl_MultiTexCoord2","gl_MultiTexCoord3","gl_MultiTexCoord4","gl_MultiTexCoord5","gl_MultiTexCoord6","gl_MultiTexCoord7","gl_Normal","gl_NormalMatrix","gl_NormalScale","gl_ObjectPlaneQ","gl_ObjectPlaneR","gl_ObjectPlaneS","gl_ObjectPlaneT","gl_Point","gl_PointCoord","gl_PointParameters","gl_PointSize","gl_Position","gl_ProjectionMatrix","gl_ProjectionMatrixInverse","gl_ProjectionMatrixInverseTranspose","gl_ProjectionMatrixTranspose","gl_SecondaryColor","gl_TexCoord","gl_TextureEnvColor","gl_TextureMatrix","gl_TextureMatrixInverse","gl_TextureMatrixInverseTranspose","gl_TextureMatrixTranspose","gl_Vertex","greaterThan","greaterThanEqual","inversesqrt","length","lessThan","lessThanEqual","log","log2","matrixCompMult","max","min","mix","mod","normalize","not","notEqual","pow","radians","reflect","refract","sign","sin","smoothstep","sqrt","step","tan","texture2D","texture2DLod","texture2DProj","texture2DProjLod","textureCube","textureCubeLod","texture2DLodEXT","texture2DProjLodEXT","textureCubeLodEXT","texture2DGradEXT","texture2DProjGradEXT","textureCubeGradEXT"]},{}],406:[function(t,e,r){var n=t("./literals");e.exports=n.slice().concat(["layout","centroid","smooth","case","mat2x2","mat2x3","mat2x4","mat3x2","mat3x3","mat3x4","mat4x2","mat4x3","mat4x4","uint","uvec2","uvec3","uvec4","samplerCubeShadow","sampler2DArray","sampler2DArrayShadow","isampler2D","isampler3D","isamplerCube","isampler2DArray","usampler2D","usampler3D","usamplerCube","usampler2DArray","coherent","restrict","readonly","writeonly","resource","atomic_uint","noperspective","patch","sample","subroutine","common","partition","active","filter","image1D","image2D","image3D","imageCube","iimage1D","iimage2D","iimage3D","iimageCube","uimage1D","uimage2D","uimage3D","uimageCube","image1DArray","image2DArray","iimage1DArray","iimage2DArray","uimage1DArray","uimage2DArray","image1DShadow","image2DShadow","image1DArrayShadow","image2DArrayShadow","imageBuffer","iimageBuffer","uimageBuffer","sampler1DArray","sampler1DArrayShadow","isampler1D","isampler1DArray","usampler1D","usampler1DArray","isampler2DRect","usampler2DRect","samplerBuffer","isamplerBuffer","usamplerBuffer","sampler2DMS","isampler2DMS","usampler2DMS","sampler2DMSArray","isampler2DMSArray","usampler2DMSArray"])},{"./literals":407}],407:[function(t,e,r){e.exports=["precision","highp","mediump","lowp","attribute","const","uniform","varying","break","continue","do","for","while","if","else","in","out","inout","float","int","void","bool","true","false","discard","return","mat2","mat3","mat4","vec2","vec3","vec4","ivec2","ivec3","ivec4","bvec2","bvec3","bvec4","sampler1D","sampler2D","sampler3D","samplerCube","sampler1DShadow","sampler2DShadow","struct","asm","class","union","enum","typedef","template","this","packed","goto","switch","default","inline","noinline","volatile","public","static","extern","external","interface","long","short","double","half","fixed","unsigned","input","output","hvec2","hvec3","hvec4","dvec2","dvec3","dvec4","fvec2","fvec3","fvec4","sampler2DRect","sampler3DRect","sampler2DRectShadow","sizeof","cast","namespace","using"]},{}],408:[function(t,e,r){e.exports=["<<=",">>=","++","--","<<",">>","<=",">=","==","!=","&&","||","+=","-=","*=","/=","%=","&=","^^","^=","|=","(",")","[","]",".","!","~","*","/","%","+","-","<",">","&","^","|","?",":","=",",",";","{","}"]},{}],409:[function(t,e,r){var n=t("./index");e.exports=function(t,e){var r=n(e),a=[];return a=(a=a.concat(r(t))).concat(r(null))}},{"./index":403}],410:[function(t,e,r){e.exports=function(t){"string"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||"");return r.push(t[n]),r.join("")}},{}],411:[function(t,e,r){(function(r){"use strict";var n,a=t("is-browser");n="function"==typeof r.matchMedia?!r.matchMedia("(hover: none)").matches:a,e.exports=n}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"is-browser":418}],412:[function(t,e,r){"use strict";var n=t("is-browser");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},"passive",{get:function(){t=!0}});window.addEventListener("test",null,e),window.removeEventListener("test",null,e)}catch(e){t=!1}return t}()},{"is-browser":418}],413:[function(t,e,r){r.read=function(t,e,r,n,a){var i,o,s=8*a-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?a-1:0,f=r?-1:1,p=t[e+h];for(h+=f,i=p&(1<<-u)-1,p>>=-u,u+=s;u>0;i=256*i+t[e+h],h+=f,u-=8);for(o=i&(1<<-u)-1,i>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===i)i=1-c;else{if(i===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),i-=c}return(p?-1:1)*o*Math.pow(2,i-n)},r.write=function(t,e,r,n,a,i){var o,s,l,c=8*i-a-1,u=(1<<c)-1,h=u>>1,f=23===a?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:i-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,a),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,a),o=0));a>=8;t[r+p]=255&s,p+=d,s/=256,a-=8);for(o=o<<a|s,c+=a;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],414:[function(t,e,r){"use strict";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error("Must have at least d+1 points");var a=t[0].length;if(r<=a)throw new Error("Must input at least d+1 points");var o=t.slice(0,a+1),s=n.apply(void 0,o);if(0===s)throw new Error("Input not in general position");for(var l=new Array(a+1),u=0;u<=a;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);for(var h=new i(l,new Array(a+1),!1),f=h.adjacent,p=new Array(a+2),u=0;u<=a;++u){for(var d=l.slice(),g=0;g<=a;++g)g===u&&(d[g]=-1);var v=d[0];d[0]=d[1],d[1]=v;var m=new i(d,new Array(a+1),!0);f[u]=m,p[u]=m}p[a+1]=h;for(var u=0;u<=a;++u)for(var d=f[u].vertices,y=f[u].adjacent,g=0;g<=a;++g){var x=d[g];if(x<0)y[g]=h;else for(var b=0;b<=a;++b)f[b].vertices.indexOf(x)<0&&(y[g]=f[b])}for(var _=new c(a,o,p),w=!!e,u=a+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t("robust-orientation"),a=t("simplicial-complex").compareCells;function i(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return a(t.vertices,e.vertices)}i.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter(function(t){return!t.boundary}),this.tuple=new Array(t+1);for(var a=0;a<=t;++a)this.tuple[a]=this.vertices[a];var i=l[t];i||(i=l[t]=function(t){for(var e=["function orient(){var tuple=this.tuple;return test("],r=0;r<=t;++r)r>0&&e.push(","),e.push("tuple[",r,"]");e.push(")}return orient");var a=new Function("test",e.join("")),i=n[t+1];return i||(i=n),a(i)}(t)),this.orient=i}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,a=this.tuple,i=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];a[h]=f<0?e:i[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,a=this.vertices,i=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)i[u]=a[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=i[u];i[u]=t;var p=this.orient();if(i[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,a=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var v=0;v<=n;++v)if(v!==g){var m=d[v];if(m.boundary&&!(m.lastVisited>=r)){var y=m.vertices;if(m.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=a[y[b]];if(this.orient()>0){y[x]=r,m.boundary=!1,c.push(m),h.push(m),m.lastVisited=r;continue}m.lastVisited=-r}var _=m.adjacent,w=p.slice(),k=d.slice(),T=new i(w,k,!0);u.push(T);var A=_.indexOf(e);if(!(A<0)){_[A]=T,k[g]=m,w[v]=-1,k[v]=e,d[v]=T,T.flip();for(b=0;b<=n;++b){var M=w[b];if(!(M<0||M===r)){for(var S=new Array(n-1),E=0,L=0;L<=n;++L){var C=w[L];C<0||L===b||(S[E++]=C)}f.push(new o(S,T,b))}}}}}}f.sort(s);for(v=0;v+1<f.length;v+=2){var P=f[v],O=f[v+1],z=P.index,I=O.index;z<0||I<0||(P.cell.adjacent[P.index]=O.cell,O.cell.adjacent[O.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var a=this.dimension,i=this.tuple,o=0;o<=a;++o){var s=n.vertices[o];i[o]=s<0?t:r[s]}var l=this.orient(i);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,a=0;a<n;++a){var i=r[a];if(i.boundary){for(var o=new Array(t),s=i.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},{"robust-orientation":508,"simplicial-complex":518}],415:[function(t,e,r){"use strict";var n=t("binary-search-bounds"),a=0,i=1;function o(t,e,r,n,a){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=a,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new x(null);return new x(y(t))};var s=o.prototype;function l(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function c(t,e){var r=y(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function u(t,e){var r=t.intervals([]);r.push(e),c(t,r)}function h(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?a:(r.splice(n,1),c(t,r),i)}function f(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var a=r(t[n]);if(a)return a}}function p(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var a=r(t[n]);if(a)return a}}function d(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function g(t,e){return t-e}function v(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function y(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(g);var n=e[e.length>>1],a=[],i=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?a.push(l):n<l[0]?i.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(v),u.sort(m),new o(n,y(a),y(i),c,u)}function x(t){this.root=t}s.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},s.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?u(this,t):this.left.insert(t):this.left=y([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?u(this,t):this.right.insert(t):this.right=y([t]);else{var r=n.ge(this.leftPoints,t,v),a=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(a,0,t)}},s.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?h(this,t):2===(c=this.left.remove(t))?(this.left=null,this.count-=1,i):(c===i&&(this.count-=1),c):a;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?h(this,t):2===(c=this.right.remove(t))?(this.right=null,this.count-=1,i):(c===i&&(this.count-=1),c):a;if(1===this.count)return this.leftPoints[0]===t?2:a;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,o=this.left;o.right;)r=o,o=o.right;if(r===this)o.right=this.right;else{var s=this.left,c=this.right;r.count-=o.count,r.right=o.left,o.left=s,o.right=c}l(this,o),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?l(this,this.left):l(this,this.right);return i}for(s=n.ge(this.leftPoints,t,v);s<this.leftPoints.length&&this.leftPoints[s][0]===t[0];++s)if(this.leftPoints[s]===t){this.count-=1,this.leftPoints.splice(s,1);for(c=n.ge(this.rightPoints,t,m);c<this.rightPoints.length&&this.rightPoints[c][1]===t[1];++c)if(this.rightPoints[c]===t)return this.rightPoints.splice(c,1),i}return a},s.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return f(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return p(this.rightPoints,t,e)}return d(this.leftPoints,e)},s.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?f(this.leftPoints,e,r):t>this.mid?p(this.rightPoints,t,r):d(this.leftPoints,r)};var b=x.prototype;b.insert=function(t){this.root?this.root.insert(t):this.root=new o(t[0],null,null,[t],[t])},b.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),e!==a}return!1},b.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},b.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(b,"count",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(b,"intervals",{get:function(){return this.root?this.root.intervals([]):[]}})},{"binary-search-bounds":92}],416:[function(t,e,r){"use strict";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],417:[function(t,e,r){"use strict";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],418:[function(t,e,r){e.exports=!0},{}],419:[function(t,e,r){function n(t){return!!t.constructor&&"function"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}e.exports=function(t){return null!=t&&(n(t)||function(t){return"function"==typeof t.readFloatLE&&"function"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],420:[function(t,e,r){"use strict";e.exports="undefined"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\//.test(navigator.appVersion))},{}],421:[function(t,e,r){"use strict";e.exports=i,e.exports.isMobile=i,e.exports.default=i;var n=/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series[46]0|symbian|treo|up\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,a=/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series[46]0|symbian|treo|up\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function i(t){t||(t={});var e=t.ua;return e||"undefined"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&"string"==typeof e.headers["user-agent"]&&(e=e.headers["user-agent"]),"string"==typeof e&&(t.tablet?a.test(e):n.test(e))}},{}],422:[function(t,e,r){"use strict";e.exports=function(t){var e=typeof t;return null!==t&&("object"===e||"function"===e)}},{}],423:[function(t,e,r){"use strict";var n=Object.prototype.toString;e.exports=function(t){var e;return"[object Object]"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],424:[function(t,e,r){"use strict";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],425:[function(t,e,r){"use strict";e.exports=function(t){return"string"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\dz]$/i.test(t)&&t.length>4))}},{}],426:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],427:[function(t,e,r){var n,a;n=this,a=function(){"use strict";var t,e,r;function n(n,a){if(t)if(e){var i="var sharedChunk = {}; ("+t+")(sharedChunk); ("+e+")(sharedChunk);",o={};t(o),(r=a(o)).workerUrl=window.URL.createObjectURL(new Blob([i],{type:"text/javascript"}))}else e=a;else t=a}return n(0,function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,a,i,o;for(void 0===e&&(e=1e-6),a=t,o=0;o<8;o++){if(i=this.sampleCurveX(a)-t,Math.abs(i)<e)return a;var s=this.sampleCurveDerivativeX(a);if(Math.abs(s)<1e-6)break;a-=i/s}if((a=t)<(r=0))return r;if(a>(n=1))return n;for(;r<n;){if(i=this.sampleCurveX(a),Math.abs(i-t)<e)return a;t>i?r=a:n=a,a=.5*(n-r)+r}return a},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var a=i;function i(t,e){this.x=t,this.y=e}function o(t,e){if(Array.isArray(t)){if(!Array.isArray(e)||t.length!==e.length)return!1;for(var r=0;r<t.length;r++)if(!o(t[r],e[r]))return!1;return!0}if("object"==typeof t&&null!==t&&null!==e){if("object"!=typeof e)return!1;if(Object.keys(t).length!==Object.keys(e).length)return!1;for(var n in t)if(!o(t[n],e[n]))return!1;return!0}return t===e}function s(t,e,n,a){var i=new r(t,e,n,a);return function(t){return i.solve(t)}}i.prototype={clone:function(){return new i(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,a=r*this.x+e*this.y;return this.x=n,this.y=a,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),a=e.x+r*(this.x-e.x)-n*(this.y-e.y),i=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=a,this.y=i,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},i.convert=function(t){return t instanceof i?t:Array.isArray(t)?new i(t[0],t[1]):t};var l=s(.25,.1,.25,1);function c(t,e,r){return Math.min(r,Math.max(e,t))}function u(t,e,r){var n=r-e,a=((t-e)%n+n)%n+e;return a===e?r:a}function h(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,a=e;n<a.length;n+=1){var i=a[n];for(var o in i)t[o]=i[o]}return t}var f=1;function p(){return f++}function d(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function g(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function v(t,e){t.forEach(function(t){e[t]&&(e[t]=e[t].bind(e))})}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function y(t,e,r){var n={};for(var a in t)n[a]=e.call(r||this,t[a],a,t);return n}function x(t,e,r){var n={};for(var a in t)e.call(r||this,t[a],a,t)&&(n[a]=t[a]);return n}function b(t){return Array.isArray(t)?t.map(b):"object"==typeof t&&t?y(t,b):t}var _={};function w(t){_[t]||("undefined"!=typeof console&&console.warn(t),_[t]=!0)}function k(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,a=n-1,i=void 0,o=void 0;r<n;a=r++)i=t[r],e+=((o=t[a]).x-i.x)*(i.y+o.y);return e}function A(t){var e={};if(t.replace(/(?:^|(?:\s*\,\s*))([^\x00-\x20\(\)<>@\,;\:\\"\/\[\]\?\=\{\}\x7F]+)(?:\=(?:([^\x00-\x20\(\)<>@\,;\:\\"\/\[\]\?\=\{\}\x7F]+)|(?:\"((?:[^"\\]|\\.)*)\")))?/g,function(t,r,n,a){var i=n||a;return e[r]=!i||i.toLowerCase(),""}),e["max-age"]){var r=parseInt(e["max-age"],10);isNaN(r)?delete e["max-age"]:e["max-age"]=r}return e}function M(t){try{var e=self[t];return e.setItem("_mapbox_test_",1),e.removeItem("_mapbox_test_"),!0}catch(t){return!1}}var S,E,L,C,P=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),O=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,z=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,I={now:P,frame:function(t){var e=O(t);return{cancel:function(){return z(e)}}},getImageData:function(t){var e=self.document.createElement("canvas"),r=e.getContext("2d");if(!r)throw new Error("failed to create canvas 2d context");return e.width=t.width,e.height=t.height,r.drawImage(t,0,0,t.width,t.height),r.getImageData(0,0,t.width,t.height)},resolveURL:function(t){return S||(S=self.document.createElement("a")),S.href=t,S.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio},get prefersReducedMotion(){return!!self.matchMedia&&(null==E&&(E=self.matchMedia("(prefers-reduced-motion: reduce)")),E.matches)}},D={API_URL:"https://api.mapbox.com",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf("https://api.mapbox.cn")?"https://events.mapbox.cn/events/v2":0===this.API_URL.indexOf("https://api.mapbox.com")?"https://events.mapbox.com/events/v2":null:null},FEEDBACK_URL:"https://apps.mapbox.com/feedback",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},R={supported:!1,testSupport:function(t){!F&&C&&(B?N(t):L=t)}},F=!1,B=!1;function N(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,C),t.isContextLost())return;R.supported=!0}catch(t){}t.deleteTexture(e),F=!0}self.document&&((C=self.document.createElement("img")).onload=function(){L&&N(L),L=null,B=!0},C.onerror=function(){F=!0,L=null},C.src="data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=");var j="01",V=function(t,e){this._transformRequestFn=t,this._customAccessToken=e,this._createSkuToken()};function U(t){return 0===t.indexOf("mapbox:")}V.prototype._createSkuToken=function(){var t=function(){for(var t="",e=0;e<10;e++)t+="0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"[Math.floor(62*Math.random())];return{token:["1",j,t].join(""),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},V.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},V.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},V.prototype.normalizeStyleURL=function(t,e){if(!U(t))return t;var r=Y(t);return r.path="/styles/v1"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},V.prototype.normalizeGlyphsURL=function(t,e){if(!U(t))return t;var r=Y(t);return r.path="/fonts/v1"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},V.prototype.normalizeSourceURL=function(t,e){if(!U(t))return t;var r=Y(t);return r.path="/v4/"+r.authority+".json",r.params.push("secure"),this._makeAPIURL(r,this._customAccessToken||e)},V.prototype.normalizeSpriteURL=function(t,e,r,n){var a=Y(t);return U(t)?(a.path="/styles/v1"+a.path+"/sprite"+e+r,this._makeAPIURL(a,this._customAccessToken||n)):(a.path+=""+e+r,W(a))},V.prototype.normalizeTileURL=function(t,e,r){if(this._isSkuTokenExpired()&&this._createSkuToken(),!e||!U(e))return t;var n=Y(t),a=I.devicePixelRatio>=2||512===r?"@2x":"",i=R.supported?".webp":"$1";return n.path=n.path.replace(/(\.(png|jpg)\d*)(?=$)/,""+a+i),n.path=n.path.replace(/^.+\/v4\//,"/"),n.path="/v4"+n.path,D.REQUIRE_ACCESS_TOKEN&&(D.ACCESS_TOKEN||this._customAccessToken)&&this._skuToken&&n.params.push("sku="+this._skuToken),this._makeAPIURL(n,this._customAccessToken)},V.prototype.canonicalizeTileURL=function(t){var e=Y(t);if(!e.path.match(/(^\/v4\/)/)||!e.path.match(/\.[\w]+$/))return t;var r="mapbox://tiles/";r+=e.path.replace("/v4/","");var n=e.params.filter(function(t){return!t.match(/^access_token=/)});return n.length&&(r+="?"+n.join("&")),r},V.prototype.canonicalizeTileset=function(t,e){if(!U(e))return t.tiles||[];for(var r=[],n=0,a=t.tiles;n<a.length;n+=1){var i=a[n],o=this.canonicalizeTileURL(i);r.push(o)}return r},V.prototype._makeAPIURL=function(t,e){var r="See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes",n=Y(D.API_URL);if(t.protocol=n.protocol,t.authority=n.authority,"/"!==n.path&&(t.path=""+n.path+t.path),!D.REQUIRE_ACCESS_TOKEN)return W(t);if(!(e=e||D.ACCESS_TOKEN))throw new Error("An API access token is required to use Mapbox GL. "+r);if("s"===e[0])throw new Error("Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). "+r);return t.params=t.params.filter(function(t){return-1===t.indexOf("access_token")}),t.params.push("access_token="+e),W(t)};var q=/^((https?:)?\/\/)?([^\/]+\.)?mapbox\.c(n|om)(\/|\?|$)/i;function H(t){return q.test(t)}var G=/^(\w+):\/\/([^\/?]*)(\/[^?]+)?\??(.+)?/;function Y(t){var e=t.match(G);if(!e)throw new Error("Unable to parse URL object");return{protocol:e[1],authority:e[2],path:e[3]||"/",params:e[4]?e[4].split("&"):[]}}function W(t){var e=t.params.length?"?"+t.params.join("&"):"";return t.protocol+"://"+t.authority+t.path+e}function X(t){if(!t)return null;var e,r=t.split(".");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(self.atob(e).split("").map(function(t){return"%"+("00"+t.charCodeAt(0).toString(16)).slice(-2)}).join(""))))}catch(t){return null}}var Z=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};Z.prototype.getStorageKey=function(t){var e,r=X(D.ACCESS_TOKEN),n="";return r&&r.u?(e=r.u,n=self.btoa(encodeURIComponent(e).replace(/%([0-9A-F]{2})/g,function(t,e){return String.fromCharCode(Number("0x"+e))}))):n=D.ACCESS_TOKEN||"",t?"mapbox.eventData."+t+":"+n:"mapbox.eventData:"+n},Z.prototype.fetchEventData=function(){var t=M("localStorage"),e=this.getStorageKey(),r=this.getStorageKey("uuid");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var a=self.localStorage.getItem(r);a&&(this.anonId=a)}catch(t){w("Unable to read from LocalStorage")}},Z.prototype.saveEventData=function(){var t=M("localStorage"),e=this.getStorageKey(),r=this.getStorageKey("uuid");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){w("Unable to write to LocalStorage")}},Z.prototype.processRequests=function(t){},Z.prototype.postEvent=function(t,e,r,n){var a=this;if(D.EVENTS_URL){var i=Y(D.EVENTS_URL);i.params.push("access_token="+(n||D.ACCESS_TOKEN||""));var o={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:"mapbox-gl-js",sdkVersion:"1.3.2",skuId:j,userId:this.anonId},s=e?h(o,e):o,l={url:W(i),headers:{"Content-Type":"text/plain"},body:JSON.stringify([s])};this.pendingRequest=mt(l,function(t){a.pendingRequest=null,r(t),a.saveEventData(),a.processRequests(n)})}},Z.prototype.queueRequest=function(t,e){this.queue.push(t),this.processRequests(e)};var J,K=function(t){function e(){t.call(this,"map.load"),this.success={},this.skuToken=""}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r,n){this.skuToken=r,(D.EVENTS_URL&&n||D.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return U(t)||H(t)}))&&this.queueRequest({id:e,timestamp:Date.now()},n)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){var r=this.queue.shift(),n=r.id,a=r.timestamp;n&&this.success[n]||(this.anonId||this.fetchEventData(),g(this.anonId)||(this.anonId=d()),this.postEvent(a,{skuToken:this.skuToken},function(t){t||n&&(e.success[n]=!0)},t))}},e}(Z),Q=new(function(t){function e(e){t.call(this,"appUserTurnstile"),this._customAccessToken=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t,e){D.EVENTS_URL&&D.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return U(t)||H(t)})&&this.queueRequest(Date.now(),e)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var r=X(D.ACCESS_TOKEN),n=r?r.u:D.ACCESS_TOKEN,a=n!==this.eventData.tokenU;g(this.anonId)||(this.anonId=d(),a=!0);var i=this.queue.shift();if(this.eventData.lastSuccess){var o=new Date(this.eventData.lastSuccess),s=new Date(i),l=(i-this.eventData.lastSuccess)/864e5;a=a||l>=1||l<-1||o.getDate()!==s.getDate()}else a=!0;if(!a)return this.processRequests();this.postEvent(i,{"enabled.telemetry":!1},function(t){t||(e.eventData.lastSuccess=i,e.eventData.tokenU=n)},t)}},e}(Z)),$=Q.postTurnstileEvent.bind(Q),tt=new K,et=tt.postMapLoadEvent.bind(tt),rt="mapbox-tiles",nt=500,at=50,it=42e4;function ot(t){var e=t.indexOf("?");return e<0?t:t.slice(0,e)}var st=1/0,lt={Unknown:"Unknown",Style:"Style",Source:"Source",Tile:"Tile",Glyphs:"Glyphs",SpriteImage:"SpriteImage",SpriteJSON:"SpriteJSON",Image:"Image"};"function"==typeof Object.freeze&&Object.freeze(lt);var ct=function(t){function e(e,r,n){401===r&&H(n)&&(e+=": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+": "+this.message+" ("+this.status+"): "+this.url},e}(Error);function ut(){return"undefined"!=typeof WorkerGlobalScope&&"undefined"!=typeof self&&self instanceof WorkerGlobalScope}var ht=ut()?function(){return self.worker&&self.worker.referrer}:function(){return("blob:"===self.location.protocol?self.parent:self).location.href};function ft(t,e){var r,n=new self.AbortController,a=new self.Request(t.url,{method:t.method||"GET",body:t.body,credentials:t.credentials,headers:t.headers,referrer:ht(),signal:n.signal}),i=!1,o=!1,s=(r=a.url).indexOf("sku=")>0&&H(r);"json"===t.type&&a.headers.set("Accept","application/json");var l=function(r,n,i){if(!o){if(r&&"SecurityError"!==r.message&&w(r),n&&i)return c(n);var l=Date.now();self.fetch(a).then(function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new ct(r.statusText,r.status,t.url))}).catch(function(t){20!==t.code&&e(new Error(t.message))})}},c=function(r,n,s){("arrayBuffer"===t.type?r.arrayBuffer():"json"===t.type?r.json():r.text()).then(function(t){o||(n&&s&&function(t,e,r){if(self.caches){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach(function(t,e){return n.headers.set(e,t)});var a=A(e.headers.get("Cache-Control")||"");a["no-store"]||(a["max-age"]&&n.headers.set("Expires",new Date(r+1e3*a["max-age"]).toUTCString()),new Date(n.headers.get("Expires")).getTime()-r<it||function(t,e){if(void 0===J)try{new Response(new ReadableStream),J=!0}catch(t){J=!1}J?e(t.body):t.blob().then(e)}(e,function(e){var r=new self.Response(e,n);self.caches.open(rt).then(function(e){return e.put(ot(t.url),r)}).catch(function(t){return w(t.message)})}))}}(a,n,s),i=!0,e(null,t,r.headers.get("Cache-Control"),r.headers.get("Expires")))}).catch(function(t){return e(new Error(t.message))})};return s?function(t,e){if(!self.caches)return e(null);var r=ot(t.url);self.caches.open(rt).then(function(t){t.match(r).then(function(n){var a=function(t){if(!t)return!1;var e=new Date(t.headers.get("Expires")),r=A(t.headers.get("Cache-Control")||"");return e>Date.now()&&!r["no-cache"]}(n);t.delete(r),a&&t.put(r,n.clone()),e(null,n,a)}).catch(e)}).catch(e)}(a,l):l(null,null),{cancel:function(){o=!0,i||n.abort()}}}var pt,dt,gt=function(t,e){if(r=t.url,!(/^file:/.test(r)||/^file:/.test(ht())&&!/^\w+:/.test(r))){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty("signal"))return ft(t,e);if(ut()&&self.worker&&self.worker.actor)return self.worker.actor.send("getResource",t,e)}var r;return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||"GET",t.url,!0),"arrayBuffer"===t.type&&(r.responseType="arraybuffer"),t.headers)r.setRequestHeader(n,t.headers[n]);return"json"===t.type&&(r.responseType="text",r.setRequestHeader("Accept","application/json")),r.withCredentials="include"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if("json"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader("Cache-Control"),r.getResponseHeader("Expires"))}else e(new ct(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},vt=function(t,e){return gt(h(t,{type:"arrayBuffer"}),e)},mt=function(t,e){return gt(h(t,{method:"POST"}),e)};pt=[],dt=0;var yt=function(t,e){if(dt>=D.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return pt.push(r),r}dt++;var n=!1,a=function(){if(!n)for(n=!0,dt--;pt.length&&dt<D.MAX_PARALLEL_IMAGE_REQUESTS;){var t=pt.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=yt(e,r).cancel)}},i=vt(t,function(t,r,n,i){if(a(),t)e(t);else if(r){var o=new self.Image,s=self.URL||self.webkitURL;o.onload=function(){e(null,o),s.revokeObjectURL(o.src)},o.onerror=function(){return e(new Error("Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported."))};var l=new self.Blob([new Uint8Array(r)],{type:"image/png"});o.cacheControl=n,o.expires=i,o.src=r.byteLength?s.createObjectURL(l):"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII="}});return{cancel:function(){i.cancel(),a()}}};function xt(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function bt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var _t=function(t,e){void 0===e&&(e={}),h(this,e),this.type=t},wt=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,"error",h({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(_t),kt=function(){};kt.prototype.on=function(t,e){return this._listeners=this._listeners||{},xt(t,e,this._listeners),this},kt.prototype.off=function(t,e){return bt(t,e,this._listeners),bt(t,e,this._oneTimeListeners),this},kt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},xt(t,e,this._oneTimeListeners),this},kt.prototype.fire=function(t,e){"string"==typeof t&&(t=new _t(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,a=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<a.length;n+=1)a[n].call(this,t);for(var i=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];i<o.length;i+=1){var s=o[i];bt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(h(t,"function"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof wt&&console.error(t.error);return this},kt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},kt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var Tt={$version:8,$root:{version:{required:!0,type:"enum",values:[8]},name:{type:"string"},metadata:{type:"*"},center:{type:"array",value:"number"},zoom:{type:"number"},bearing:{type:"number",default:0,period:360,units:"degrees"},pitch:{type:"number",default:0,units:"degrees"},light:{type:"light"},sources:{required:!0,type:"sources"},sprite:{type:"string"},glyphs:{type:"string"},transition:{type:"transition"},layers:{required:!0,type:"array",value:"layer"}},sources:{"*":{type:"source"}},source:["source_vector","source_raster","source_raster_dem","source_geojson","source_video","source_image"],source_vector:{type:{required:!0,type:"enum",values:{vector:{}}},url:{type:"string"},tiles:{type:"array",value:"string"},bounds:{type:"array",value:"number",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:"enum",values:{xyz:{},tms:{}},default:"xyz"},minzoom:{type:"number",default:0},maxzoom:{type:"number",default:22},attribution:{type:"string"},"*":{type:"*"}},source_raster:{type:{required:!0,type:"enum",values:{raster:{}}},url:{type:"string"},tiles:{type:"array",value:"string"},bounds:{type:"array",value:"number",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:"number",default:0},maxzoom:{type:"number",default:22},tileSize:{type:"number",default:512,units:"pixels"},scheme:{type:"enum",values:{xyz:{},tms:{}},default:"xyz"},attribution:{type:"string"},"*":{type:"*"}},source_raster_dem:{type:{required:!0,type:"enum",values:{"raster-dem":{}}},url:{type:"string"},tiles:{type:"array",value:"string"},bounds:{type:"array",value:"number",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:"number",default:0},maxzoom:{type:"number",default:22},tileSize:{type:"number",default:512,units:"pixels"},attribution:{type:"string"},encoding:{type:"enum",values:{terrarium:{},mapbox:{}},default:"mapbox"},"*":{type:"*"}},source_geojson:{type:{required:!0,type:"enum",values:{geojson:{}}},data:{type:"*"},maxzoom:{type:"number",default:18},attribution:{type:"string"},buffer:{type:"number",default:128,maximum:512,minimum:0},tolerance:{type:"number",default:.375},cluster:{type:"boolean",default:!1},clusterRadius:{type:"number",default:50,minimum:0},clusterMaxZoom:{type:"number"},clusterProperties:{type:"*"},lineMetrics:{type:"boolean",default:!1},generateId:{type:"boolean",default:!1}},source_video:{type:{required:!0,type:"enum",values:{video:{}}},urls:{required:!0,type:"array",value:"string"},coordinates:{required:!0,type:"array",length:4,value:{type:"array",length:2,value:"number"}}},source_image:{type:{required:!0,type:"enum",values:{image:{}}},url:{required:!0,type:"string"},coordinates:{required:!0,type:"array",length:4,value:{type:"array",length:2,value:"number"}}},layer:{id:{type:"string",required:!0},type:{type:"enum",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},"fill-extrusion":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:"*"},source:{type:"string"},"source-layer":{type:"string"},minzoom:{type:"number",minimum:0,maximum:24},maxzoom:{type:"number",minimum:0,maximum:24},filter:{type:"filter"},layout:{type:"layout"},paint:{type:"paint"}},layout:["layout_fill","layout_line","layout_circle","layout_heatmap","layout_fill-extrusion","layout_symbol","layout_raster","layout_hillshade","layout_background"],layout_background:{visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_fill:{"fill-sort-key":{type:"number",expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_circle:{"circle-sort-key":{type:"number",expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_heatmap:{visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},"layout_fill-extrusion":{visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_line:{"line-cap":{type:"enum",values:{butt:{},round:{},square:{}},default:"butt",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"line-join":{type:"enum",values:{bevel:{},round:{},miter:{}},default:"miter",expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"line-miter-limit":{type:"number",default:2,requires:[{"line-join":"miter"}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"line-round-limit":{type:"number",default:1.05,requires:[{"line-join":"round"}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"line-sort-key":{type:"number",expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_symbol:{"symbol-placement":{type:"enum",values:{point:{},line:{},"line-center":{}},default:"point",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"symbol-spacing":{type:"number",default:250,minimum:1,units:"pixels",requires:[{"symbol-placement":"line"}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"symbol-avoid-edges":{type:"boolean",default:!1,expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"symbol-sort-key":{type:"number",expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"symbol-z-order":{type:"enum",values:{auto:{},"viewport-y":{},source:{}},default:"auto",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-allow-overlap":{type:"boolean",default:!1,requires:["icon-image"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-ignore-placement":{type:"boolean",default:!1,requires:["icon-image"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-optional":{type:"boolean",default:!1,requires:["icon-image","text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-rotation-alignment":{type:"enum",values:{map:{},viewport:{},auto:{}},default:"auto",requires:["icon-image"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-size":{type:"number",default:1,minimum:0,units:"factor of the original icon size",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"icon-text-fit":{type:"enum",values:{none:{},width:{},height:{},both:{}},default:"none",requires:["icon-image","text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-text-fit-padding":{type:"array",value:"number",length:4,default:[0,0,0,0],units:"pixels",requires:["icon-image","text-field",{"icon-text-fit":["both","width","height"]}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"icon-image":{type:"string",tokens:!0,expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"icon-rotate":{type:"number",default:0,period:360,units:"degrees",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"icon-padding":{type:"number",default:2,minimum:0,units:"pixels",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"icon-keep-upright":{type:"boolean",default:!1,requires:["icon-image",{"icon-rotation-alignment":"map"},{"symbol-placement":["line","line-center"]}],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"icon-offset":{type:"array",value:"number",length:2,default:[0,0],requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"icon-anchor":{type:"enum",values:{center:{},left:{},right:{},top:{},bottom:{},"top-left":{},"top-right":{},"bottom-left":{},"bottom-right":{}},default:"center",requires:["icon-image"],expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"icon-pitch-alignment":{type:"enum",values:{map:{},viewport:{},auto:{}},default:"auto",requires:["icon-image"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-pitch-alignment":{type:"enum",values:{map:{},viewport:{},auto:{}},default:"auto",requires:["text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-rotation-alignment":{type:"enum",values:{map:{},viewport:{},auto:{}},default:"auto",requires:["text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-field":{type:"formatted",default:"",tokens:!0,expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-font":{type:"array",value:"string",default:["Open Sans Regular","Arial Unicode MS Regular"],requires:["text-field"],expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-size":{type:"number",default:16,minimum:0,units:"pixels",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-max-width":{type:"number",default:10,minimum:0,units:"ems",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-line-height":{type:"number",default:1.2,units:"ems",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"text-letter-spacing":{type:"number",default:0,units:"ems",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-justify":{type:"enum",values:{auto:{},left:{},center:{},right:{}},default:"center",requires:["text-field"],expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-radial-offset":{type:"number",units:"ems",default:0,requires:["text-field"],"property-type":"data-driven",expression:{interpolated:!0,parameters:["zoom","feature"]}},"text-variable-anchor":{type:"array",value:"enum",values:{center:{},left:{},right:{},top:{},bottom:{},"top-left":{},"top-right":{},"bottom-left":{},"bottom-right":{}},requires:["text-field",{"symbol-placement":["point"]}],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-anchor":{type:"enum",values:{center:{},left:{},right:{},top:{},bottom:{},"top-left":{},"top-right":{},"bottom-left":{},"bottom-right":{}},default:"center",requires:["text-field",{"!":"text-variable-anchor"}],expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-max-angle":{type:"number",default:45,units:"degrees",requires:["text-field",{"symbol-placement":["line","line-center"]}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"text-writing-mode":{type:"array",value:"enum",values:{horizontal:{},vertical:{}},requires:["text-field",{"symbol-placement":["point"]}],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-rotate":{type:"number",default:0,period:360,units:"degrees",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-padding":{type:"number",default:2,minimum:0,units:"pixels",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"text-keep-upright":{type:"boolean",default:!0,requires:["text-field",{"text-rotation-alignment":"map"},{"symbol-placement":["line","line-center"]}],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-transform":{type:"enum",values:{none:{},uppercase:{},lowercase:{}},default:"none",requires:["text-field"],expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-offset":{type:"array",value:"number",units:"ems",length:2,default:[0,0],requires:["text-field",{"!":"text-radial-offset"},{"!":"text-variable-anchor"}],expression:{interpolated:!0,parameters:["zoom","feature"]},"property-type":"data-driven"},"text-allow-overlap":{type:"boolean",default:!1,requires:["text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-ignore-placement":{type:"boolean",default:!1,requires:["text-field"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-optional":{type:"boolean",default:!1,requires:["text-field","icon-image"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_raster:{visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},layout_hillshade:{visibility:{type:"enum",values:{visible:{},none:{}},default:"visible","property-type":"constant"}},filter:{type:"array",value:"*"},filter_operator:{type:"enum",values:{"==":{},"!=":{},">":{},">=":{},"<":{},"<=":{},in:{},"!in":{},all:{},any:{},none:{},has:{},"!has":{}}},geometry_type:{type:"enum",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:"expression"},stops:{type:"array",value:"function_stop"},base:{type:"number",default:1,minimum:0},property:{type:"string",default:"$zoom"},type:{type:"enum",values:{identity:{},exponential:{},interval:{},categorical:{}},default:"exponential"},colorSpace:{type:"enum",values:{rgb:{},lab:{},hcl:{}},default:"rgb"},default:{type:"*",required:!1}},function_stop:{type:"array",minimum:0,maximum:22,value:["number","color"],length:2},expression:{type:"array",value:"*",minimum:1},expression_name:{type:"enum",values:{let:{group:"Variable binding"},var:{group:"Variable binding"},literal:{group:"Types"},array:{group:"Types"},at:{group:"Lookup"},case:{group:"Decision"},match:{group:"Decision"},coalesce:{group:"Decision"},step:{group:"Ramps, scales, curves"},interpolate:{group:"Ramps, scales, curves"},"interpolate-hcl":{group:"Ramps, scales, curves"},"interpolate-lab":{group:"Ramps, scales, curves"},ln2:{group:"Math"},pi:{group:"Math"},e:{group:"Math"},typeof:{group:"Types"},string:{group:"Types"},number:{group:"Types"},boolean:{group:"Types"},object:{group:"Types"},collator:{group:"Types"},format:{group:"Types"},"number-format":{group:"Types"},"to-string":{group:"Types"},"to-number":{group:"Types"},"to-boolean":{group:"Types"},"to-rgba":{group:"Color"},"to-color":{group:"Types"},rgb:{group:"Color"},rgba:{group:"Color"},get:{group:"Lookup"},has:{group:"Lookup"},length:{group:"Lookup"},properties:{group:"Feature data"},"feature-state":{group:"Feature data"},"geometry-type":{group:"Feature data"},id:{group:"Feature data"},zoom:{group:"Zoom"},"heatmap-density":{group:"Heatmap"},"line-progress":{group:"Feature data"},accumulated:{group:"Feature data"},"+":{group:"Math"},"*":{group:"Math"},"-":{group:"Math"},"/":{group:"Math"},"%":{group:"Math"},"^":{group:"Math"},sqrt:{group:"Math"},log10:{group:"Math"},ln:{group:"Math"},log2:{group:"Math"},sin:{group:"Math"},cos:{group:"Math"},tan:{group:"Math"},asin:{group:"Math"},acos:{group:"Math"},atan:{group:"Math"},min:{group:"Math"},max:{group:"Math"},round:{group:"Math"},abs:{group:"Math"},ceil:{group:"Math"},floor:{group:"Math"},"==":{group:"Decision"},"!=":{group:"Decision"},">":{group:"Decision"},"<":{group:"Decision"},">=":{group:"Decision"},"<=":{group:"Decision"},all:{group:"Decision"},any:{group:"Decision"},"!":{group:"Decision"},"is-supported-script":{group:"String"},upcase:{group:"String"},downcase:{group:"String"},concat:{group:"String"},"resolved-locale":{group:"String"}}},light:{anchor:{type:"enum",default:"viewport",values:{map:{},viewport:{}},"property-type":"data-constant",transition:!1,expression:{interpolated:!1,parameters:["zoom"]}},position:{type:"array",default:[1.15,210,30],length:3,value:"number","property-type":"data-constant",transition:!0,expression:{interpolated:!0,parameters:["zoom"]}},color:{type:"color","property-type":"data-constant",default:"#ffffff",expression:{interpolated:!0,parameters:["zoom"]},transition:!0},intensity:{type:"number","property-type":"data-constant",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:["zoom"]},transition:!0}},paint:["paint_fill","paint_line","paint_circle","paint_heatmap","paint_fill-extrusion","paint_symbol","paint_raster","paint_hillshade","paint_background"],paint_fill:{"fill-antialias":{type:"boolean",default:!0,expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"fill-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-color":{type:"color",default:"#000000",transition:!0,requires:[{"!":"fill-pattern"}],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-outline-color":{type:"color",transition:!0,requires:[{"!":"fill-pattern"},{"fill-antialias":!0}],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"fill-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["fill-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"fill-pattern":{type:"string",transition:!0,expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"cross-faded-data-driven"}},"paint_fill-extrusion":{"fill-extrusion-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"fill-extrusion-color":{type:"color",default:"#000000",transition:!0,requires:[{"!":"fill-extrusion-pattern"}],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-extrusion-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"fill-extrusion-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["fill-extrusion-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"fill-extrusion-pattern":{type:"string",transition:!0,expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"cross-faded-data-driven"},"fill-extrusion-height":{type:"number",default:0,minimum:0,units:"meters",transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-extrusion-base":{type:"number",default:0,minimum:0,units:"meters",transition:!0,requires:["fill-extrusion-height"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"fill-extrusion-vertical-gradient":{type:"boolean",default:!0,transition:!1,expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"}},paint_line:{"line-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-color":{type:"color",default:"#000000",transition:!0,requires:[{"!":"line-pattern"}],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"line-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["line-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"line-width":{type:"number",default:1,minimum:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-gap-width":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-offset":{type:"number",default:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-blur":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"line-dasharray":{type:"array",value:"number",minimum:0,transition:!0,units:"line widths",requires:[{"!":"line-pattern"}],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"cross-faded"},"line-pattern":{type:"string",transition:!0,expression:{interpolated:!1,parameters:["zoom","feature"]},"property-type":"cross-faded-data-driven"},"line-gradient":{type:"color",transition:!1,requires:[{"!":"line-dasharray"},{"!":"line-pattern"},{source:"geojson",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:["line-progress"]},"property-type":"color-ramp"}},paint_circle:{"circle-radius":{type:"number",default:5,minimum:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-color":{type:"color",default:"#000000",transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-blur":{type:"number",default:0,transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"circle-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["circle-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"circle-pitch-scale":{type:"enum",values:{map:{},viewport:{}},default:"map",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"circle-pitch-alignment":{type:"enum",values:{map:{},viewport:{}},default:"viewport",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"circle-stroke-width":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-stroke-color":{type:"color",default:"#000000",transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"circle-stroke-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"}},paint_heatmap:{"heatmap-radius":{type:"number",default:30,minimum:1,transition:!0,units:"pixels",expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"heatmap-weight":{type:"number",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"heatmap-intensity":{type:"number",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"heatmap-color":{type:"color",default:["interpolate",["linear"],["heatmap-density"],0,"rgba(0, 0, 255, 0)",.1,"royalblue",.3,"cyan",.5,"lime",.7,"yellow",1,"red"],transition:!1,expression:{interpolated:!0,parameters:["heatmap-density"]},"property-type":"color-ramp"},"heatmap-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"}},paint_symbol:{"icon-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"icon-color":{type:"color",default:"#000000",transition:!0,requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"icon-halo-color":{type:"color",default:"rgba(0, 0, 0, 0)",transition:!0,requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"icon-halo-width":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"icon-halo-blur":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"icon-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",requires:["icon-image"],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"icon-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["icon-image","icon-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"text-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"text-color":{type:"color",default:"#000000",transition:!0,overridable:!0,requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"text-halo-color":{type:"color",default:"rgba(0, 0, 0, 0)",transition:!0,requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"text-halo-width":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"text-halo-blur":{type:"number",default:0,minimum:0,transition:!0,units:"pixels",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom","feature","feature-state"]},"property-type":"data-driven"},"text-translate":{type:"array",value:"number",length:2,default:[0,0],transition:!0,units:"pixels",requires:["text-field"],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"text-translate-anchor":{type:"enum",values:{map:{},viewport:{}},default:"map",requires:["text-field","text-translate"],expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"}},paint_raster:{"raster-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-hue-rotate":{type:"number",default:0,period:360,transition:!0,units:"degrees",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-brightness-min":{type:"number",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-brightness-max":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-saturation":{type:"number",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-contrast":{type:"number",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"raster-resampling":{type:"enum",values:{linear:{},nearest:{}},default:"linear",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"raster-fade-duration":{type:"number",default:300,minimum:0,transition:!1,units:"milliseconds",expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"}},paint_hillshade:{"hillshade-illumination-direction":{type:"number",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"hillshade-illumination-anchor":{type:"enum",values:{map:{},viewport:{}},default:"viewport",expression:{interpolated:!1,parameters:["zoom"]},"property-type":"data-constant"},"hillshade-exaggeration":{type:"number",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"hillshade-shadow-color":{type:"color",default:"#000000",transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"hillshade-highlight-color":{type:"color",default:"#FFFFFF",transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"hillshade-accent-color":{type:"color",default:"#000000",transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"}},paint_background:{"background-color":{type:"color",default:"#000000",transition:!0,requires:[{"!":"background-pattern"}],expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"},"background-pattern":{type:"string",transition:!0,expression:{interpolated:!1,parameters:["zoom"]},"property-type":"cross-faded"},"background-opacity":{type:"number",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:["zoom"]},"property-type":"data-constant"}},transition:{duration:{type:"number",default:300,minimum:0,units:"milliseconds"},delay:{type:"number",default:0,minimum:0,units:"milliseconds"}},"property-type":{"data-driven":{type:"property-type"},"cross-faded":{type:"property-type"},"cross-faded-data-driven":{type:"property-type"},"color-ramp":{type:"property-type"},"data-constant":{type:"property-type"},constant:{type:"property-type"}}},At=function(t,e,r,n){this.message=(t?t+": ":"")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Mt(t){var e=t.key,r=t.value;return r?[new At(e,r,"constants have been deprecated as of v8")]:[]}function St(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,a=e;n<a.length;n+=1){var i=a[n];for(var o in i)t[o]=i[o]}return t}function Et(t){return t instanceof Number||t instanceof String||t instanceof Boolean}function Lt(t){return Et(t)?t.valueOf():t}function Ct(t){if(Array.isArray(t))return t.map(Ct);if(t instanceof Object&&!Et(t)){var e={};for(var r in t)e[r]=Ct(t[r]);return e}return Lt(t)}var Pt=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Ot=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var a=n[r],i=a[0],o=a[1];this.bindings[i]=o}};Ot.prototype.concat=function(t){return new Ot(this,t)},Ot.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+" not found in scope.")},Ot.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var zt={kind:"null"},It={kind:"number"},Dt={kind:"string"},Rt={kind:"boolean"},Ft={kind:"color"},Bt={kind:"object"},Nt={kind:"value"},jt={kind:"collator"},Vt={kind:"formatted"};function Ut(t,e){return{kind:"array",itemType:t,N:e}}function qt(t){if("array"===t.kind){var e=qt(t.itemType);return"number"==typeof t.N?"array<"+e+", "+t.N+">":"value"===t.itemType.kind?"array":"array<"+e+">"}return t.kind}var Ht=[zt,It,Dt,Rt,Ft,Vt,Bt,Ut(Nt)];function Gt(t,e){if("error"===e.kind)return null;if("array"===t.kind){if("array"===e.kind&&(0===e.N&&"value"===e.itemType.kind||!Gt(t.itemType,e.itemType))&&("number"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if("value"===t.kind)for(var r=0,n=Ht;r<n.length;r+=1)if(!Gt(n[r],e))return null}return"Expected "+qt(t)+" but found "+qt(e)+" instead."}var Yt=e(function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function a(t){return t<0?0:t>1?1:t}function i(t){return"%"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return"%"===t[t.length-1]?a(parseFloat(t)/100):a(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,a=t.replace(/ /g,"").toLowerCase();if(a in r)return r[a].slice();if("#"===a[0])return 4===a.length?(e=parseInt(a.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===a.length&&(e=parseInt(a.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=a.indexOf("("),c=a.indexOf(")");if(-1!==l&&c+1===a.length){var u=a.substr(0,l),h=a.substr(l+1,c-(l+1)).split(","),f=1;switch(u){case"rgba":if(4!==h.length)return null;f=o(h.pop());case"rgb":return 3!==h.length?null:[i(h[0]),i(h[1]),i(h[2]),f];case"hsla":if(4!==h.length)return null;f=o(h.pop());case"hsl":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=o(h[1]),g=o(h[2]),v=g<=.5?g*(d+1):g+d-g*d,m=2*g-v;return[n(255*s(m,v,p+1/3)),n(255*s(m,v,p)),n(255*s(m,v,p-1/3)),f];default:return null}}return null}}catch(t){}}).parseCSSColor,Wt=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};Wt.parse=function(t){if(t){if(t instanceof Wt)return t;if("string"==typeof t){var e=Yt(t);if(e)return new Wt(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},Wt.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],a=t[3];return"rgba("+Math.round(e)+","+Math.round(r)+","+Math.round(n)+","+a+")"},Wt.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},Wt.black=new Wt(0,0,0,1),Wt.white=new Wt(1,1,1,1),Wt.transparent=new Wt(0,0,0,0),Wt.red=new Wt(1,0,0,1);var Xt=function(t,e,r){this.sensitivity=t?e?"variant":"case":e?"accent":"base",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:"search"})};Xt.prototype.compare=function(t,e){return this.collator.compare(t,e)},Xt.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var Zt=function(t,e,r,n){this.text=t,this.scale=e,this.fontStack=r,this.textColor=n},Jt=function(t){this.sections=t};function Kt(t,e,r,n){return"number"==typeof t&&t>=0&&t<=255&&"number"==typeof e&&e>=0&&e<=255&&"number"==typeof r&&r>=0&&r<=255?void 0===n||"number"==typeof n&&n>=0&&n<=1?null:"Invalid rgba value ["+[t,e,r,n].join(", ")+"]: 'a' must be between 0 and 1.":"Invalid rgba value ["+("number"==typeof n?[t,e,r,n]:[t,e,r]).join(", ")+"]: 'r', 'g', and 'b' must be between 0 and 255."}function Qt(t){if(null===t)return zt;if("string"==typeof t)return Dt;if("boolean"==typeof t)return Rt;if("number"==typeof t)return It;if(t instanceof Wt)return Ft;if(t instanceof Xt)return jt;if(t instanceof Jt)return Vt;if(Array.isArray(t)){for(var e,r=t.length,n=0,a=t;n<a.length;n+=1){var i=Qt(a[n]);if(e){if(e===i)continue;e=Nt;break}e=i}return Ut(e||Nt,r)}return Bt}function $t(t){var e=typeof t;return null===t?"":"string"===e||"number"===e||"boolean"===e?String(t):t instanceof Wt||t instanceof Jt?t.toString():JSON.stringify(t)}Jt.fromString=function(t){return new Jt([new Zt(t,null,null,null)])},Jt.prototype.toString=function(){return this.sections.map(function(t){return t.text}).join("")},Jt.prototype.serialize=function(){for(var t=["format"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text);var a={};n.fontStack&&(a["text-font"]=["literal",n.fontStack.split(",")]),n.scale&&(a["font-scale"]=n.scale),n.textColor&&(a["text-color"]=["rgba"].concat(n.textColor.toArray())),t.push(a)}return t};var te=function(t,e){this.type=t,this.value=e};te.parse=function(t,e){if(2!==t.length)return e.error("'literal' expression requires exactly one argument, but found "+(t.length-1)+" instead.");if(!function t(e){if(null===e)return!0;if("string"==typeof e)return!0;if("boolean"==typeof e)return!0;if("number"==typeof e)return!0;if(e instanceof Wt)return!0;if(e instanceof Xt)return!0;if(e instanceof Jt)return!0;if(Array.isArray(e)){for(var r=0,n=e;r<n.length;r+=1)if(!t(n[r]))return!1;return!0}if("object"==typeof e){for(var a in e)if(!t(e[a]))return!1;return!0}return!1}(t[1]))return e.error("invalid value");var r=t[1],n=Qt(r),a=e.expectedType;return"array"!==n.kind||0!==n.N||!a||"array"!==a.kind||"number"==typeof a.N&&0!==a.N||(n=a),new te(n,r)},te.prototype.evaluate=function(){return this.value},te.prototype.eachChild=function(){},te.prototype.possibleOutputs=function(){return[this.value]},te.prototype.serialize=function(){return"array"===this.type.kind||"object"===this.type.kind?["literal",this.value]:this.value instanceof Wt?["rgba"].concat(this.value.toArray()):this.value instanceof Jt?this.value.serialize():this.value};var ee=function(t){this.name="ExpressionEvaluationError",this.message=t};ee.prototype.toJSON=function(){return this.message};var re={string:Dt,number:It,boolean:Rt,object:Bt},ne=function(t,e){this.type=t,this.args=e};ne.parse=function(t,e){if(t.length<2)return e.error("Expected at least one argument.");var r,n=1,a=t[0];if("array"===a){var i,o;if(t.length>2){var s=t[1];if("string"!=typeof s||!(s in re)||"object"===s)return e.error('The item type argument of "array" must be one of string, number, boolean',1);i=re[s],n++}else i=Nt;if(t.length>3){if(null!==t[2]&&("number"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to "array" must be a positive integer literal',2);o=t[2],n++}r=Ut(i,o)}else r=re[a];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,Nt);if(!c)return null;l.push(c)}return new ne(r,l)},ne.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!Gt(this.type,Qt(r)))return r;if(e===this.args.length-1)throw new ee("Expected value to be of type "+qt(this.type)+", but found "+qt(Qt(r))+" instead.")}return null},ne.prototype.eachChild=function(t){this.args.forEach(t)},ne.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},ne.prototype.serialize=function(){var t=this.type,e=[t.kind];if("array"===t.kind){var r=t.itemType;if("string"===r.kind||"number"===r.kind||"boolean"===r.kind){e.push(r.kind);var n=t.N;("number"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map(function(t){return t.serialize()}))};var ae=function(t){this.type=Vt,this.sections=t};ae.parse=function(t,e){if(t.length<3)return e.error("Expected at least two arguments.");if((t.length-1)%2!=0)return e.error("Expected an even number of arguments.");for(var r=[],n=1;n<t.length-1;n+=2){var a=e.parse(t[n],1,Nt);if(!a)return null;var i=a.type.kind;if("string"!==i&&"value"!==i&&"null"!==i)return e.error("Formatted text type must be 'string', 'value', or 'null'.");var o=t[n+1];if("object"!=typeof o||Array.isArray(o))return e.error("Format options argument must be an object.");var s=null;if(o["font-scale"]&&!(s=e.parse(o["font-scale"],1,It)))return null;var l=null;if(o["text-font"]&&!(l=e.parse(o["text-font"],1,Ut(Dt))))return null;var c=null;if(o["text-color"]&&!(c=e.parse(o["text-color"],1,Ft)))return null;r.push({text:a,scale:s,font:l,textColor:c})}return new ae(r)},ae.prototype.evaluate=function(t){return new Jt(this.sections.map(function(e){return new Zt($t(e.text.evaluate(t)),e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(","):null,e.textColor?e.textColor.evaluate(t):null)}))},ae.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.text),n.scale&&t(n.scale),n.font&&t(n.font),n.textColor&&t(n.textColor)}},ae.prototype.possibleOutputs=function(){return[void 0]},ae.prototype.serialize=function(){for(var t=["format"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text.serialize());var a={};n.scale&&(a["font-scale"]=n.scale.serialize()),n.font&&(a["text-font"]=n.font.serialize()),n.textColor&&(a["text-color"]=n.textColor.serialize()),t.push(a)}return t};var ie={"to-boolean":Rt,"to-color":Ft,"to-number":It,"to-string":Dt},oe=function(t,e){this.type=t,this.args=e};oe.parse=function(t,e){if(t.length<2)return e.error("Expected at least one argument.");var r=t[0];if(("to-boolean"===r||"to-string"===r)&&2!==t.length)return e.error("Expected one argument.");for(var n=ie[r],a=[],i=1;i<t.length;i++){var o=e.parse(t[i],i,Nt);if(!o)return null;a.push(o)}return new oe(n,a)},oe.prototype.evaluate=function(t){if("boolean"===this.type.kind)return Boolean(this.args[0].evaluate(t));if("color"===this.type.kind){for(var e,r,n=0,a=this.args;n<a.length;n+=1){if(r=null,(e=a[n].evaluate(t))instanceof Wt)return e;if("string"==typeof e){var i=t.parseColor(e);if(i)return i}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?"Invalid rbga value "+JSON.stringify(e)+": expected an array containing either three or four numeric values.":Kt(e[0],e[1],e[2],e[3])))return new Wt(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new ee(r||"Could not parse color from value '"+("string"==typeof e?e:String(JSON.stringify(e)))+"'")}if("number"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new ee("Could not convert "+JSON.stringify(o)+" to number.")}return"formatted"===this.type.kind?Jt.fromString($t(this.args[0].evaluate(t))):$t(this.args[0].evaluate(t))},oe.prototype.eachChild=function(t){this.args.forEach(t)},oe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},oe.prototype.serialize=function(){if("formatted"===this.type.kind)return new ae([{text:this.args[0],scale:null,font:null,textColor:null}]).serialize();var t=["to-"+this.type.kind];return this.eachChild(function(e){t.push(e.serialize())}),t};var se=["Unknown","Point","LineString","Polygon"],le=function(){this.globals=null,this.feature=null,this.featureState=null,this.formattedSection=null,this._parseColorCache={}};le.prototype.id=function(){return this.feature&&"id"in this.feature?this.feature.id:null},le.prototype.geometryType=function(){return this.feature?"number"==typeof this.feature.type?se[this.feature.type]:this.feature.type:null},le.prototype.properties=function(){return this.feature&&this.feature.properties||{}},le.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=Wt.parse(t)),e};var ce=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};ce.prototype.evaluate=function(t){return this._evaluate(t,this.args)},ce.prototype.eachChild=function(t){this.args.forEach(t)},ce.prototype.possibleOutputs=function(){return[void 0]},ce.prototype.serialize=function(){return[this.name].concat(this.args.map(function(t){return t.serialize()}))},ce.parse=function(t,e){var r,n=t[0],a=ce.definitions[n];if(!a)return e.error('Unknown expression "'+n+'". If you wanted a literal array, use ["literal", [...]].',0);for(var i=Array.isArray(a)?a[0]:a.type,o=Array.isArray(a)?[[a[1],a[2]]]:a.overloads,s=o.filter(function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1}),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new ge(e.registry,e.path,null,e.scope);for(var d=[],g=!1,v=1;v<t.length;v++){var m=t[v],y=Array.isArray(f)?f[v-1]:f.type,x=l.parse(m,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(f)&&f.length!==d.length)l.error("Expected "+f.length+" arguments, but found "+d.length+" instead.");else{for(var b=0;b<d.length;b++){var _=Array.isArray(f)?f[b]:f.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new ce(n,i,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var k=(s.length?s:o).map(function(t){var e;return e=t[0],Array.isArray(e)?"("+e.map(qt).join(", ")+")":"("+qt(e.type)+"...)"}).join(" | "),T=[],A=1;A<t.length;A++){var M=e.parse(t[A],1+T.length);if(!M)return null;T.push(qt(M.type))}e.error("Expected arguments of type "+k+", but found ("+T.join(", ")+") instead.")}return null},ce.register=function(t,e){for(var r in ce.definitions=e,e)t[r]=ce};var ue=function(t,e,r){this.type=jt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function he(t){if(t instanceof ce){if("get"===t.name&&1===t.args.length)return!1;if("feature-state"===t.name)return!1;if("has"===t.name&&1===t.args.length)return!1;if("properties"===t.name||"geometry-type"===t.name||"id"===t.name)return!1;if(/^filter-/.test(t.name))return!1}var e=!0;return t.eachChild(function(t){e&&!he(t)&&(e=!1)}),e}function fe(t){if(t instanceof ce&&"feature-state"===t.name)return!1;var e=!0;return t.eachChild(function(t){e&&!fe(t)&&(e=!1)}),e}function pe(t,e){if(t instanceof ce&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild(function(t){r&&!pe(t,e)&&(r=!1)}),r}ue.parse=function(t,e){if(2!==t.length)return e.error("Expected one argument.");var r=t[1];if("object"!=typeof r||Array.isArray(r))return e.error("Collator options argument must be an object.");var n=e.parse(void 0!==r["case-sensitive"]&&r["case-sensitive"],1,Rt);if(!n)return null;var a=e.parse(void 0!==r["diacritic-sensitive"]&&r["diacritic-sensitive"],1,Rt);if(!a)return null;var i=null;return r.locale&&!(i=e.parse(r.locale,1,Dt))?null:new ue(n,a,i)},ue.prototype.evaluate=function(t){return new Xt(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},ue.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},ue.prototype.possibleOutputs=function(){return[void 0]},ue.prototype.serialize=function(){var t={};return t["case-sensitive"]=this.caseSensitive.serialize(),t["diacritic-sensitive"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),["collator",t]};var de=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};de.parse=function(t,e){if(2!==t.length||"string"!=typeof t[1])return e.error("'var' expression requires exactly one string literal argument.");var r=t[1];return e.scope.has(r)?new de(r,e.scope.get(r)):e.error('Unknown variable "'+r+'". Make sure "'+r+'" has been bound in an enclosing "let" expression before using it.',1)},de.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},de.prototype.eachChild=function(){},de.prototype.possibleOutputs=function(){return[void 0]},de.prototype.serialize=function(){return["var",this.name]};var ge=function(t,e,r,n,a){void 0===e&&(e=[]),void 0===n&&(n=new Ot),void 0===a&&(a=[]),this.registry=t,this.path=e,this.key=e.map(function(t){return"["+t+"]"}).join(""),this.scope=n,this.errors=a,this.expectedType=r};function ve(t,e){for(var r,n,a=t.length-1,i=0,o=a,s=0;i<=o;)if(r=t[s=Math.floor((i+o)/2)],n=t[s+1],r<=e){if(s===a||e<n)return s;i=s+1}else{if(!(r>e))throw new ee("Input is not a number.");o=s-1}return 0}ge.prototype.parse=function(t,e,r,n,a){return void 0===a&&(a={}),e?this.concat(e,r,n)._parse(t,a):this._parse(t,a)},ge.prototype._parse=function(t,e){function r(t,e,r){return"assert"===r?new ne(e,[t]):"coerce"===r?new oe(e,[t]):t}if(null!==t&&"string"!=typeof t&&"boolean"!=typeof t&&"number"!=typeof t||(t=["literal",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use ["literal", []].');var n=t[0];if("string"!=typeof n)return this.error("Expression name must be a string, but found "+typeof n+' instead. If you wanted a literal array, use ["literal", [...]].',0),null;var a=this.registry[n];if(a){var i=a.parse(t,this);if(!i)return null;if(this.expectedType){var o=this.expectedType,s=i.type;if("string"!==o.kind&&"number"!==o.kind&&"boolean"!==o.kind&&"object"!==o.kind&&"array"!==o.kind||"value"!==s.kind)if("color"!==o.kind&&"formatted"!==o.kind||"value"!==s.kind&&"string"!==s.kind){if(this.checkSubtype(o,s))return null}else i=r(i,o,e.typeAnnotation||"coerce");else i=r(i,o,e.typeAnnotation||"assert")}if(!(i instanceof te)&&function t(e){if(e instanceof de)return t(e.boundExpression);if(e instanceof ce&&"error"===e.name)return!1;if(e instanceof ue)return!1;var r=e instanceof oe||e instanceof ne,n=!0;return e.eachChild(function(e){n=r?n&&t(e):n&&e instanceof te}),!!n&&(he(e)&&pe(e,["zoom","heatmap-density","line-progress","accumulated","is-supported-script"]))}(i)){var l=new le;try{i=new te(i.type,i.evaluate(l))}catch(t){return this.error(t.message),null}}return i}return this.error('Unknown expression "'+n+'". If you wanted a literal array, use ["literal", [...]].',0)}return void 0===t?this.error("'undefined' value invalid. Use null instead."):"object"==typeof t?this.error('Bare objects invalid. Use ["literal", {...}] instead.'):this.error("Expected an array, but found "+typeof t+" instead.")},ge.prototype.concat=function(t,e,r){var n="number"==typeof t?this.path.concat(t):this.path,a=r?this.scope.concat(r):this.scope;return new ge(this.registry,n,e||null,a,this.errors)},ge.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=""+this.key+e.map(function(t){return"["+t+"]"}).join("");this.errors.push(new Pt(n,t))},ge.prototype.checkSubtype=function(t,e){var r=Gt(t,e);return r&&this.error(r),r};var me=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,a=r;n<a.length;n+=1){var i=a[n],o=i[0],s=i[1];this.labels.push(o),this.outputs.push(s)}};function ye(t,e,r){return t*(1-r)+e*r}me.parse=function(t,e){if(t.length-1<4)return e.error("Expected at least 4 arguments, but found only "+(t.length-1)+".");if((t.length-1)%2!=0)return e.error("Expected an even number of arguments.");var r=e.parse(t[1],1,It);if(!r)return null;var n=[],a=null;e.expectedType&&"value"!==e.expectedType.kind&&(a=e.expectedType);for(var i=1;i<t.length;i+=2){var o=1===i?-1/0:t[i],s=t[i+1],l=i,c=i+1;if("number"!=typeof o)return e.error('Input/output pairs for "step" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for "step" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,a);if(!u)return null;a=a||u.type,n.push([o,u])}return new me(a,r,n)},me.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var a=e.length;return n>=e[a-1]?r[a-1].evaluate(t):r[ve(e,n)].evaluate(t)},me.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},me.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},me.prototype.serialize=function(){for(var t=["step",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var xe=Object.freeze({number:ye,color:function(t,e,r){return new Wt(ye(t.r,e.r,r),ye(t.g,e.g,r),ye(t.b,e.b,r),ye(t.a,e.a,r))},array:function(t,e,r){return t.map(function(t,n){return ye(t,e[n],r)})}}),be=.95047,_e=1,we=1.08883,ke=4/29,Te=6/29,Ae=3*Te*Te,Me=Te*Te*Te,Se=Math.PI/180,Ee=180/Math.PI;function Le(t){return t>Me?Math.pow(t,1/3):t/Ae+ke}function Ce(t){return t>Te?t*t*t:Ae*(t-ke)}function Pe(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Oe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function ze(t){var e=Oe(t.r),r=Oe(t.g),n=Oe(t.b),a=Le((.4124564*e+.3575761*r+.1804375*n)/be),i=Le((.2126729*e+.7151522*r+.072175*n)/_e);return{l:116*i-16,a:500*(a-i),b:200*(i-Le((.0193339*e+.119192*r+.9503041*n)/we)),alpha:t.a}}function Ie(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=_e*Ce(e),r=be*Ce(r),n=we*Ce(n),new Wt(Pe(3.2404542*r-1.5371385*e-.4985314*n),Pe(-.969266*r+1.8760108*e+.041556*n),Pe(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}var De={forward:ze,reverse:Ie,interpolate:function(t,e,r){return{l:ye(t.l,e.l,r),a:ye(t.a,e.a,r),b:ye(t.b,e.b,r),alpha:ye(t.alpha,e.alpha,r)}}},Re={forward:function(t){var e=ze(t),r=e.l,n=e.a,a=e.b,i=Math.atan2(a,n)*Ee;return{h:i<0?i+360:i,c:Math.sqrt(n*n+a*a),l:r,alpha:t.a}},reverse:function(t){var e=t.h*Se,r=t.c;return Ie({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:function(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}(t.h,e.h,r),c:ye(t.c,e.c,r),l:ye(t.l,e.l,r),alpha:ye(t.alpha,e.alpha,r)}}},Fe=Object.freeze({lab:De,hcl:Re}),Be=function(t,e,r,n,a){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var i=0,o=a;i<o.length;i+=1){var s=o[i],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function Ne(t,e,r,n){var a=n-r,i=t-r;return 0===a?0:1===e?i/a:(Math.pow(e,i)-1)/(Math.pow(e,a)-1)}Be.interpolationFactor=function(t,e,n,a){var i=0;if("exponential"===t.name)i=Ne(e,t.base,n,a);else if("linear"===t.name)i=Ne(e,1,n,a);else if("cubic-bezier"===t.name){var o=t.controlPoints;i=new r(o[0],o[1],o[2],o[3]).solve(Ne(e,1,n,a))}return i},Be.parse=function(t,e){var r=t[0],n=t[1],a=t[2],i=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error("Expected an interpolation type expression.",1);if("linear"===n[0])n={name:"linear"};else if("exponential"===n[0]){var o=n[1];if("number"!=typeof o)return e.error("Exponential interpolation requires a numeric base.",1,1);n={name:"exponential",base:o}}else{if("cubic-bezier"!==n[0])return e.error("Unknown interpolation type "+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some(function(t){return"number"!=typeof t||t<0||t>1}))return e.error("Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.",1);n={name:"cubic-bezier",controlPoints:s}}if(t.length-1<4)return e.error("Expected at least 4 arguments, but found only "+(t.length-1)+".");if((t.length-1)%2!=0)return e.error("Expected an even number of arguments.");if(!(a=e.parse(a,2,It)))return null;var l=[],c=null;"interpolate-hcl"===r||"interpolate-lab"===r?c=Ft:e.expectedType&&"value"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<i.length;u+=2){var h=i[u],f=i[u+1],p=u+3,d=u+4;if("number"!=typeof h)return e.error('Input/output pairs for "interpolate" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for "interpolate" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(f,d,c);if(!g)return null;c=c||g.type,l.push([h,g])}return"number"===c.kind||"color"===c.kind||"array"===c.kind&&"number"===c.itemType.kind&&"number"==typeof c.N?new Be(c,r,n,a,l):e.error("Type "+qt(c)+" is not interpolatable.")},Be.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var a=e.length;if(n>=e[a-1])return r[a-1].evaluate(t);var i=ve(e,n),o=e[i],s=e[i+1],l=Be.interpolationFactor(this.interpolation,n,o,s),c=r[i].evaluate(t),u=r[i+1].evaluate(t);return"interpolate"===this.operator?xe[this.type.kind.toLowerCase()](c,u,l):"interpolate-hcl"===this.operator?Re.reverse(Re.interpolate(Re.forward(c),Re.forward(u),l)):De.reverse(De.interpolate(De.forward(c),De.forward(u),l))},Be.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Be.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Be.prototype.serialize=function(){var t;t="linear"===this.interpolation.name?["linear"]:"exponential"===this.interpolation.name?1===this.interpolation.base?["linear"]:["exponential",this.interpolation.base]:["cubic-bezier"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var je=function(t,e){this.type=t,this.args=e};je.parse=function(t,e){if(t.length<2)return e.error("Expectected at least one argument.");var r=null,n=e.expectedType;n&&"value"!==n.kind&&(r=n);for(var a=[],i=0,o=t.slice(1);i<o.length;i+=1){var s=o[i],l=e.parse(s,1+a.length,r,void 0,{typeAnnotation:"omit"});if(!l)return null;r=r||l.type,a.push(l)}var c=n&&a.some(function(t){return Gt(n,t.type)});return new je(c?Nt:r,a)},je.prototype.evaluate=function(t){for(var e=null,r=0,n=this.args;r<n.length&&null===(e=n[r].evaluate(t));r+=1);return e},je.prototype.eachChild=function(t){this.args.forEach(t)},je.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},je.prototype.serialize=function(){var t=["coalesce"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Ve=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};Ve.prototype.evaluate=function(t){return this.result.evaluate(t)},Ve.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},Ve.parse=function(t,e){if(t.length<4)return e.error("Expected at least 3 arguments, but found "+(t.length-1)+" instead.");for(var r=[],n=1;n<t.length-1;n+=2){var a=t[n];if("string"!=typeof a)return e.error("Expected string, but found "+typeof a+" instead.",n);if(/[^a-zA-Z0-9_]/.test(a))return e.error("Variable names must contain only alphanumeric characters or '_'.",n);var i=e.parse(t[n+1],n+1);if(!i)return null;r.push([a,i])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new Ve(r,o):null},Ve.prototype.possibleOutputs=function(){return this.result.possibleOutputs()},Ve.prototype.serialize=function(){for(var t=["let"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],a=n[0],i=n[1];t.push(a,i.serialize())}return t.push(this.result.serialize()),t};var Ue=function(t,e,r){this.type=t,this.index=e,this.input=r};Ue.parse=function(t,e){if(3!==t.length)return e.error("Expected 2 arguments, but found "+(t.length-1)+" instead.");var r=e.parse(t[1],1,It),n=e.parse(t[2],2,Ut(e.expectedType||Nt));if(!r||!n)return null;var a=n.type;return new Ue(a.itemType,r,n)},Ue.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new ee("Array index out of bounds: "+e+" < 0.");if(e>=r.length)throw new ee("Array index out of bounds: "+e+" > "+(r.length-1)+".");if(e!==Math.floor(e))throw new ee("Array index must be an integer, but found "+e+" instead.");return r[e]},Ue.prototype.eachChild=function(t){t(this.index),t(this.input)},Ue.prototype.possibleOutputs=function(){return[void 0]},Ue.prototype.serialize=function(){return["at",this.index.serialize(),this.input.serialize()]};var qe=function(t,e,r,n,a,i){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=a,this.otherwise=i};qe.parse=function(t,e){if(t.length<5)return e.error("Expected at least 4 arguments, but found only "+(t.length-1)+".");if(t.length%2!=1)return e.error("Expected an even number of arguments.");var r,n;e.expectedType&&"value"!==e.expectedType.kind&&(n=e.expectedType);for(var a={},i=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error("Expected at least one branch label.");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if("number"!=typeof f&&"string"!=typeof f)return c.error("Branch labels must be numbers or strings.");if("number"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error("Branch labels must be integers no larger than "+Number.MAX_SAFE_INTEGER+".");if("number"==typeof f&&Math.floor(f)!==f)return c.error("Numeric branch labels must be integer values.");if(r){if(c.checkSubtype(r,Qt(f)))return null}else r=Qt(f);if(void 0!==a[String(f)])return c.error("Branch labels must be unique.");a[String(f)]=i.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,i.push(p)}var d=e.parse(t[1],1,Nt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?"value"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new qe(r,n,d,a,i,g):null},qe.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(Qt(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},qe.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},qe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()})).concat(this.otherwise.possibleOutputs())},qe.prototype.serialize=function(){for(var t=this,e=["match",this.input.serialize()],r=[],n={},a=0,i=Object.keys(this.cases).sort();a<i.length;a+=1){var o=i[a];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return"number"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];1===f.length?e.push(s(f[0])):e.push(f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var He=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};function Ge(t,e){return"=="===t||"!="===t?"boolean"===e.kind||"string"===e.kind||"number"===e.kind||"null"===e.kind||"value"===e.kind:"string"===e.kind||"number"===e.kind||"value"===e.kind}function Ye(t,e,r,n){return 0===n.compare(e,r)}function We(t,e,r){var n="=="!==t&&"!="!==t;return function(){function a(t,e,r){this.type=Rt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument="value"===t.type.kind||"value"===e.type.kind}return a.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error("Expected two or three arguments.");var r=t[0],i=e.parse(t[1],1,Nt);if(!i)return null;if(!Ge(r,i.type))return e.concat(1).error('"'+r+"\" comparisons are not supported for type '"+qt(i.type)+"'.");var o=e.parse(t[2],2,Nt);if(!o)return null;if(!Ge(r,o.type))return e.concat(2).error('"'+r+"\" comparisons are not supported for type '"+qt(o.type)+"'.");if(i.type.kind!==o.type.kind&&"value"!==i.type.kind&&"value"!==o.type.kind)return e.error("Cannot compare types '"+qt(i.type)+"' and '"+qt(o.type)+"'.");n&&("value"===i.type.kind&&"value"!==o.type.kind?i=new ne(o.type,[i]):"value"!==i.type.kind&&"value"===o.type.kind&&(o=new ne(i.type,[o])));var s=null;if(4===t.length){if("string"!==i.type.kind&&"string"!==o.type.kind&&"value"!==i.type.kind&&"value"!==o.type.kind)return e.error("Cannot use collator to compare non-string types.");if(!(s=e.parse(t[3],3,jt)))return null}return new a(i,o,s)},a.prototype.evaluate=function(a){var i=this.lhs.evaluate(a),o=this.rhs.evaluate(a);if(n&&this.hasUntypedArgument){var s=Qt(i),l=Qt(o);if(s.kind!==l.kind||"string"!==s.kind&&"number"!==s.kind)throw new ee('Expected arguments for "'+t+'" to be (string, string) or (number, number), but found ('+s.kind+", "+l.kind+") instead.")}if(this.collator&&!n&&this.hasUntypedArgument){var c=Qt(i),u=Qt(o);if("string"!==c.kind||"string"!==u.kind)return e(a,i,o)}return this.collator?r(a,i,o,this.collator.evaluate(a)):e(a,i,o)},a.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},a.prototype.possibleOutputs=function(){return[!0,!1]},a.prototype.serialize=function(){var e=[t];return this.eachChild(function(t){e.push(t.serialize())}),e},a}()}He.parse=function(t,e){if(t.length<4)return e.error("Expected at least 3 arguments, but found only "+(t.length-1)+".");if(t.length%2!=0)return e.error("Expected an odd number of arguments.");var r;e.expectedType&&"value"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],a=1;a<t.length-1;a+=2){var i=e.parse(t[a],a,Rt);if(!i)return null;var o=e.parse(t[a+1],a+1,r);if(!o)return null;n.push([i,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new He(r,n,s):null},He.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],a=n[0],i=n[1];if(a.evaluate(t))return i.evaluate(t)}return this.otherwise.evaluate(t)},He.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],a=n[0],i=n[1];t(a),t(i)}t(this.otherwise)},He.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.branches.map(function(t){return t[0],t[1].possibleOutputs()})).concat(this.otherwise.possibleOutputs())},He.prototype.serialize=function(){var t=["case"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Xe=We("==",function(t,e,r){return e===r},Ye),Ze=We("!=",function(t,e,r){return e!==r},function(t,e,r,n){return!Ye(0,e,r,n)}),Je=We("<",function(t,e,r){return e<r},function(t,e,r,n){return n.compare(e,r)<0}),Ke=We(">",function(t,e,r){return e>r},function(t,e,r,n){return n.compare(e,r)>0}),Qe=We("<=",function(t,e,r){return e<=r},function(t,e,r,n){return n.compare(e,r)<=0}),$e=We(">=",function(t,e,r){return e>=r},function(t,e,r,n){return n.compare(e,r)>=0}),tr=function(t,e,r,n,a){this.type=Dt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=a};tr.parse=function(t,e){if(3!==t.length)return e.error("Expected two arguments.");var r=e.parse(t[1],1,It);if(!r)return null;var n=t[2];if("object"!=typeof n||Array.isArray(n))return e.error("NumberFormat options argument must be an object.");var a=null;if(n.locale&&!(a=e.parse(n.locale,1,Dt)))return null;var i=null;if(n.currency&&!(i=e.parse(n.currency,1,Dt)))return null;var o=null;if(n["min-fraction-digits"]&&!(o=e.parse(n["min-fraction-digits"],1,It)))return null;var s=null;return n["max-fraction-digits"]&&!(s=e.parse(n["max-fraction-digits"],1,It))?null:new tr(r,a,i,o,s)},tr.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?"currency":"decimal",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},tr.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},tr.prototype.possibleOutputs=function(){return[void 0]},tr.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t["min-fraction-digits"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t["max-fraction-digits"]=this.maxFractionDigits.serialize()),["number-format",this.number.serialize(),t]};var er=function(t){this.type=It,this.input=t};er.parse=function(t,e){if(2!==t.length)return e.error("Expected 1 argument, but found "+(t.length-1)+" instead.");var r=e.parse(t[1],1);return r?"array"!==r.type.kind&&"string"!==r.type.kind&&"value"!==r.type.kind?e.error("Expected argument of type string or array, but found "+qt(r.type)+" instead."):new er(r):null},er.prototype.evaluate=function(t){var e=this.input.evaluate(t);if("string"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new ee("Expected value to be of type string or array, but found "+qt(Qt(e))+" instead.")},er.prototype.eachChild=function(t){t(this.input)},er.prototype.possibleOutputs=function(){return[void 0]},er.prototype.serialize=function(){var t=["length"];return this.eachChild(function(e){t.push(e.serialize())}),t};var rr={"==":Xe,"!=":Ze,">":Ke,"<":Je,">=":$e,"<=":Qe,array:ne,at:Ue,boolean:ne,case:He,coalesce:je,collator:ue,format:ae,interpolate:Be,"interpolate-hcl":Be,"interpolate-lab":Be,length:er,let:Ve,literal:te,match:qe,number:ne,"number-format":tr,object:ne,step:me,string:ne,"to-boolean":oe,"to-color":oe,"to-number":oe,"to-string":oe,var:de};function nr(t,e){var r=e[0],n=e[1],a=e[2],i=e[3];r=r.evaluate(t),n=n.evaluate(t),a=a.evaluate(t);var o=i?i.evaluate(t):1,s=Kt(r,n,a,o);if(s)throw new ee(s);return new Wt(r/255*o,n/255*o,a/255*o,o)}function ar(t,e){return t in e}function ir(t,e){var r=e[t];return void 0===r?null:r}function or(t){return{type:t}}function sr(t){return{result:"success",value:t}}function lr(t){return{result:"error",value:t}}function cr(t){return"data-driven"===t["property-type"]||"cross-faded-data-driven"===t["property-type"]}function ur(t){return!!t.expression&&t.expression.parameters.indexOf("zoom")>-1}function hr(t){return!!t.expression&&t.expression.interpolated}function fr(t){return t instanceof Number?"number":t instanceof String?"string":t instanceof Boolean?"boolean":Array.isArray(t)?"array":null===t?"null":typeof t}function pr(t){return"object"==typeof t&&null!==t&&!Array.isArray(t)}function dr(t){return t}function gr(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function vr(t,e,r,n,a){return gr(typeof r===a?n[r]:void 0,t.default,e.default)}function mr(t,e,r){if("number"!==fr(r))return gr(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var a=ve(t.stops.map(function(t){return t[0]}),r);return t.stops[a][1]}function yr(t,e,r){var n=void 0!==t.base?t.base:1;if("number"!==fr(r))return gr(t.default,e.default);var a=t.stops.length;if(1===a)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[a-1][0])return t.stops[a-1][1];var i=ve(t.stops.map(function(t){return t[0]}),r),o=function(t,e,r,n){var a=n-r,i=t-r;return 0===a?0:1===e?i/a:(Math.pow(e,i)-1)/(Math.pow(e,a)-1)}(r,n,t.stops[i][0],t.stops[i+1][0]),s=t.stops[i][1],l=t.stops[i+1][1],c=xe[e.type]||dr;if(t.colorSpace&&"rgb"!==t.colorSpace){var u=Fe[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return"function"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function xr(t,e,r){return"color"===e.type?r=Wt.parse(r):"formatted"===e.type?r=Jt.fromString(r.toString()):fr(r)===e.type||"enum"===e.type&&e.values[r]||(r=void 0),gr(r,t.default,e.default)}ce.register(rr,{error:[{kind:"error"},[Dt],function(t,e){var r=e[0];throw new ee(r.evaluate(t))}],typeof:[Dt,[Nt],function(t,e){return qt(Qt(e[0].evaluate(t)))}],"to-rgba":[Ut(It,4),[Ft],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Ft,[It,It,It],nr],rgba:[Ft,[It,It,It,It],nr],has:{type:Rt,overloads:[[[Dt],function(t,e){return ar(e[0].evaluate(t),t.properties())}],[[Dt,Bt],function(t,e){var r=e[0],n=e[1];return ar(r.evaluate(t),n.evaluate(t))}]]},get:{type:Nt,overloads:[[[Dt],function(t,e){return ir(e[0].evaluate(t),t.properties())}],[[Dt,Bt],function(t,e){var r=e[0],n=e[1];return ir(r.evaluate(t),n.evaluate(t))}]]},"feature-state":[Nt,[Dt],function(t,e){return ir(e[0].evaluate(t),t.featureState||{})}],properties:[Bt,[],function(t){return t.properties()}],"geometry-type":[Dt,[],function(t){return t.geometryType()}],id:[Nt,[],function(t){return t.id()}],zoom:[It,[],function(t){return t.globals.zoom}],"heatmap-density":[It,[],function(t){return t.globals.heatmapDensity||0}],"line-progress":[It,[],function(t){return t.globals.lineProgress||0}],accumulated:[Nt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],"+":[It,or(It),function(t,e){for(var r=0,n=0,a=e;n<a.length;n+=1)r+=a[n].evaluate(t);return r}],"*":[It,or(It),function(t,e){for(var r=1,n=0,a=e;n<a.length;n+=1)r*=a[n].evaluate(t);return r}],"-":{type:It,overloads:[[[It,It],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[It],function(t,e){return-e[0].evaluate(t)}]]},"/":[It,[It,It],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],"%":[It,[It,It],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[It,[],function(){return Math.LN2}],pi:[It,[],function(){return Math.PI}],e:[It,[],function(){return Math.E}],"^":[It,[It,It],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[It,[It],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[It,[It],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[It,[It],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[It,[It],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[It,[It],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[It,[It],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[It,[It],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[It,[It],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[It,[It],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[It,[It],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[It,or(It),function(t,e){return Math.min.apply(Math,e.map(function(e){return e.evaluate(t)}))}],max:[It,or(It),function(t,e){return Math.max.apply(Math,e.map(function(e){return e.evaluate(t)}))}],abs:[It,[It],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[It,[It],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[It,[It],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[It,[It],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],"filter-==":[Rt,[Dt,Nt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],"filter-id-==":[Rt,[Nt],function(t,e){var r=e[0];return t.id()===r.value}],"filter-type-==":[Rt,[Dt],function(t,e){var r=e[0];return t.geometryType()===r.value}],"filter-<":[Rt,[Dt,Nt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a<i}],"filter-id-<":[Rt,[Nt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n<a}],"filter->":[Rt,[Dt,Nt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a>i}],"filter-id->":[Rt,[Nt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n>a}],"filter-<=":[Rt,[Dt,Nt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a<=i}],"filter-id-<=":[Rt,[Nt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n<=a}],"filter->=":[Rt,[Dt,Nt],function(t,e){var r=e[0],n=e[1],a=t.properties()[r.value],i=n.value;return typeof a==typeof i&&a>=i}],"filter-id->=":[Rt,[Nt],function(t,e){var r=e[0],n=t.id(),a=r.value;return typeof n==typeof a&&n>=a}],"filter-has":[Rt,[Nt],function(t,e){return e[0].value in t.properties()}],"filter-has-id":[Rt,[],function(t){return null!==t.id()}],"filter-type-in":[Rt,[Ut(Dt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],"filter-id-in":[Rt,[Ut(Nt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],"filter-in-small":[Rt,[Dt,Ut(Nt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],"filter-in-large":[Rt,[Dt,Ut(Nt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var a=r+n>>1;if(e[a]===t)return!0;e[a]>t?n=a-1:r=a+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Rt,overloads:[[[Rt,Rt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[or(Rt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Rt,overloads:[[[Rt,Rt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[or(Rt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},"!":[Rt,[Rt],function(t,e){return!e[0].evaluate(t)}],"is-supported-script":[Rt,[Dt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Dt,[Dt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Dt,[Dt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Dt,or(Nt),function(t,e){return e.map(function(e){return $t(e.evaluate(t))}).join("")}],"resolved-locale":[Dt,[jt],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var br=function(t,e){this.expression=t,this._warningHistory={},this._evaluator=new le,this._defaultValue=e?function(t){return"color"===t.type&&pr(t.default)?new Wt(0,0,0,0):"color"===t.type?Wt.parse(t.default)||null:void 0===t.default?null:t.default}(e):null,this._enumValues=e&&"enum"===e.type?e.values:null};function _r(t){return Array.isArray(t)&&t.length>0&&"string"==typeof t[0]&&t[0]in rr}function wr(t,e){var r=new ge(rr,[],e?function(t){var e={color:Ft,string:Dt,number:It,enum:Dt,boolean:Rt,formatted:Vt};return"array"===t.type?Ut(e[t.value]||Nt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&"string"===e.type?{typeAnnotation:"coerce"}:void 0);return n?sr(new br(n,e)):lr(r.errors)}br.prototype.evaluateWithoutErrorHandling=function(t,e,r,n){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this._evaluator.formattedSection=n,this.expression.evaluate(this._evaluator)},br.prototype.evaluate=function(t,e,r,n){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null,this._evaluator.formattedSection=n||null;try{var a=this.expression.evaluate(this._evaluator);if(null==a)return this._defaultValue;if(this._enumValues&&!(a in this._enumValues))throw new ee("Expected value to be one of "+Object.keys(this._enumValues).map(function(t){return JSON.stringify(t)}).join(", ")+", but found "+JSON.stringify(a)+" instead.");return a}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,"undefined"!=typeof console&&console.warn(t.message)),this._defaultValue}};var kr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent="constant"!==t&&!fe(e.expression)};kr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n)},kr.prototype.evaluate=function(t,e,r,n){return this._styleExpression.evaluate(t,e,r,n)};var Tr=function(t,e,r,n){this.kind=t,this.zoomStops=r,this._styleExpression=e,this.isStateDependent="camera"!==t&&!fe(e.expression),this.interpolationType=n};function Ar(t,e){if("error"===(t=wr(t,e)).result)return t;var r=t.value.expression,n=he(r);if(!n&&!cr(e))return lr([new Pt("","data expressions not supported")]);var a=pe(r,["zoom"]);if(!a&&!ur(e))return lr([new Pt("","zoom expressions not supported")]);var i=function t(e){var r=null;if(e instanceof Ve)r=t(e.result);else if(e instanceof je)for(var n=0,a=e.args;n<a.length;n+=1){var i=a[n];if(r=t(i))break}else(e instanceof me||e instanceof Be)&&e.input instanceof ce&&"zoom"===e.input.name&&(r=e);return r instanceof Pt?r:(e.eachChild(function(e){var n=t(e);n instanceof Pt?r=n:!r&&n?r=new Pt("",'"zoom" expression may only be used as input to a top-level "step" or "interpolate" expression.'):r&&n&&r!==n&&(r=new Pt("",'Only one zoom-based "step" or "interpolate" subexpression may be used in an expression.'))}),r)}(r);if(!i&&!a)return lr([new Pt("",'"zoom" expression may only be used as input to a top-level "step" or "interpolate" expression.')]);if(i instanceof Pt)return lr([i]);if(i instanceof Be&&!hr(e))return lr([new Pt("",'"interpolate" expressions cannot be used with this property')]);if(!i)return sr(new kr(n?"constant":"source",t.value));var o=i instanceof Be?i.interpolation:void 0;return sr(new Tr(n?"camera":"composite",t.value,i.labels,o))}Tr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n)},Tr.prototype.evaluate=function(t,e,r,n){return this._styleExpression.evaluate(t,e,r,n)},Tr.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?Be.interpolationFactor(this.interpolationType,t,e,r):0};var Mr=function(t,e){this._parameters=t,this._specification=e,St(this,function t(e,r){var n,a,i,o="color"===r.type,s=e.stops&&"object"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(hr(r)?"exponential":"interval");if(o&&((e=St({},e)).stops&&(e.stops=e.stops.map(function(t){return[t[0],Wt.parse(t[1])]})),e.default?e.default=Wt.parse(e.default):e.default=Wt.parse(r.default)),e.colorSpace&&"rgb"!==e.colorSpace&&!Fe[e.colorSpace])throw new Error("Unknown color space: "+e.colorSpace);if("exponential"===u)n=yr;else if("interval"===u)n=mr;else if("categorical"===u){n=vr,a=Object.create(null);for(var h=0,f=e.stops;h<f.length;h+=1){var p=f[h];a[p[0]]=p[1]}i=typeof e.stops[0][0]}else{if("identity"!==u)throw new Error('Unknown function type "'+u+'"');n=xr}if(s){for(var d={},g=[],v=0;v<e.stops.length;v++){var m=e.stops[v],y=m[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},g.push(y)),d[y].stops.push([m[0].value,m[1]])}for(var x=[],b=0,_=g;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}var k={name:"linear"};return{kind:"composite",interpolationType:k,interpolationFactor:Be.interpolationFactor.bind(void 0,k),zoomStops:x.map(function(t){return t[0]}),evaluate:function(t,n){var a=t.zoom;return yr({stops:x,base:e.base},r,a).evaluate(a,n)}}}if(c){var T="exponential"===u?{name:"exponential",base:void 0!==e.base?e.base:1}:null;return{kind:"camera",interpolationType:T,interpolationFactor:Be.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map(function(t){return t[0]}),evaluate:function(t){var o=t.zoom;return n(e,r,o,a,i)}}}return{kind:"source",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?gr(e.default,r.default):n(e,r,s,a,i)}}}(this._parameters,this._specification))};function Sr(t){var e=t.key,r=t.value,n=t.valueSpec||{},a=t.objectElementValidators||{},i=t.style,o=t.styleSpec,s=[],l=fr(r);if("object"!==l)return[new At(e,r,"object expected, "+l+" found")];for(var c in r){var u=c.split(".")[0],h=n[u]||n["*"],f=void 0;if(a[u])f=a[u];else if(n[u])f=Kr;else if(a["*"])f=a["*"];else{if(!n["*"]){s.push(new At(e,r[c],'unknown property "'+c+'"'));continue}f=Kr}s=s.concat(f({key:(e?e+".":e)+c,value:r[c],valueSpec:h,style:i,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)a[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new At(e,r,'missing required property "'+p+'"'));return s}function Er(t){var e=t.value,r=t.valueSpec,n=t.style,a=t.styleSpec,i=t.key,o=t.arrayElementValidator||Kr;if("array"!==fr(e))return[new At(i,e,"array expected, "+fr(e)+" found")];if(r.length&&e.length!==r.length)return[new At(i,e,"array length "+r.length+" expected, length "+e.length+" found")];if(r["min-length"]&&e.length<r["min-length"])return[new At(i,e,"array length at least "+r["min-length"]+" expected, length "+e.length+" found")];var s={type:r.value,values:r.values};a.$version<7&&(s.function=r.function),"object"===fr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:a,key:i+"["+c+"]"}));return l}function Lr(t){var e=t.key,r=t.value,n=t.valueSpec,a=fr(r);return"number"!==a?[new At(e,r,"number expected, "+a+" found")]:"minimum"in n&&r<n.minimum?[new At(e,r,r+" is less than the minimum value "+n.minimum)]:"maximum"in n&&r>n.maximum?[new At(e,r,r+" is greater than the maximum value "+n.maximum)]:[]}function Cr(t){var e,r,n,a=t.valueSpec,i=Lt(t.value.type),o={},s="categorical"!==i&&void 0===t.value.property,l=!s,c="array"===fr(t.value.stops)&&"array"===fr(t.value.stops[0])&&"object"===fr(t.value.stops[0][0]),u=Sr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if("identity"===i)return[new At(t.key,t.value,'identity function may not have a "stops" property')];var e=[],r=t.value;return e=e.concat(Er({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),"array"===fr(r)&&0===r.length&&e.push(new At(t.key,r,"array must have at least one stop")),e},default:function(t){return Kr({key:t.key,value:t.value,valueSpec:a,style:t.style,styleSpec:t.styleSpec})}}});return"identity"===i&&s&&u.push(new At(t.key,t.value,'missing required property "property"')),"identity"===i||t.value.stops||u.push(new At(t.key,t.value,'missing required property "stops"')),"exponential"===i&&t.valueSpec.expression&&!hr(t.valueSpec)&&u.push(new At(t.key,t.value,"exponential functions not supported")),t.styleSpec.$version>=8&&(l&&!cr(t.valueSpec)?u.push(new At(t.key,t.value,"property functions not supported")):s&&!ur(t.valueSpec)&&u.push(new At(t.key,t.value,"zoom functions not supported"))),"categorical"!==i&&!c||void 0!==t.value.property||u.push(new At(t.key,t.value,'"property" property is required')),u;function h(t){var e=[],i=t.value,s=t.key;if("array"!==fr(i))return[new At(s,i,"array expected, "+fr(i)+" found")];if(2!==i.length)return[new At(s,i,"array length 2 expected, length "+i.length+" found")];if(c){if("object"!==fr(i[0]))return[new At(s,i,"object expected, "+fr(i[0])+" found")];if(void 0===i[0].zoom)return[new At(s,i,"object stop key must have zoom")];if(void 0===i[0].value)return[new At(s,i,"object stop key must have value")];if(n&&n>Lt(i[0].zoom))return[new At(s,i[0].zoom,"stop zoom values must appear in ascending order")];Lt(i[0].zoom)!==n&&(n=Lt(i[0].zoom),r=void 0,o={}),e=e.concat(Sr({key:s+"[0]",value:i[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Lr,value:f}}))}else e=e.concat(f({key:s+"[0]",value:i[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},i));return _r(Ct(i[1]))?e.concat([new At(s+"[1]",i[1],"expressions are not allowed in function stops.")]):e.concat(Kr({key:s+"[1]",value:i[1],valueSpec:a,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=fr(t.value),l=Lt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new At(t.key,c,s+" stop domain type must match previous stop domain type "+e)]}else e=s;if("number"!==s&&"string"!==s&&"boolean"!==s)return[new At(t.key,c,"stop domain value must be a number, string, or boolean")];if("number"!==s&&"categorical"!==i){var u="number expected, "+s+" found";return cr(a)&&void 0===i&&(u+='\nIf you intended to use a categorical function, specify `"type": "categorical"`.'),[new At(t.key,c,u)]}return"categorical"!==i||"number"!==s||isFinite(l)&&Math.floor(l)===l?"categorical"!==i&&"number"===s&&void 0!==r&&l<r?[new At(t.key,c,"stop domain values must appear in ascending order")]:(r=l,"categorical"===i&&l in o?[new At(t.key,c,"stop domain values must be unique")]:(o[l]=!0,[])):[new At(t.key,c,"integer expected, found "+l)]}}function Pr(t){var e=("property"===t.expressionContext?Ar:wr)(Ct(t.value),t.valueSpec);if("error"===e.result)return e.value.map(function(e){return new At(""+t.key+e.key,t.value,e.message)});var r=e.value.expression||e.value._styleExpression.expression;if("property"===t.expressionContext&&"text-font"===t.propertyKey&&-1!==r.possibleOutputs().indexOf(void 0))return[new At(t.key,t.value,'Invalid data expression for "'+t.propertyKey+'". Output values must be contained as literals within the expression.')];if("property"===t.expressionContext&&"layout"===t.propertyType&&!fe(r))return[new At(t.key,t.value,'"feature-state" data expressions are not supported with layout properties.')];if("filter"===t.expressionContext&&!fe(r))return[new At(t.key,t.value,'"feature-state" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf("cluster")){if(!pe(r,["zoom","feature-state"]))return[new At(t.key,t.value,'"zoom" and "feature-state" expressions are not supported with cluster properties.')];if("cluster-initial"===t.expressionContext&&!he(r))return[new At(t.key,t.value,"Feature data expressions are not supported with initial expression part of cluster properties.")]}return[]}function Or(t){var e=t.key,r=t.value,n=t.valueSpec,a=[];return Array.isArray(n.values)?-1===n.values.indexOf(Lt(r))&&a.push(new At(e,r,"expected one of ["+n.values.join(", ")+"], "+JSON.stringify(r)+" found")):-1===Object.keys(n.values).indexOf(Lt(r))&&a.push(new At(e,r,"expected one of ["+Object.keys(n.values).join(", ")+"], "+JSON.stringify(r)+" found")),a}function zr(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case"has":return t.length>=2&&"$id"!==t[1]&&"$type"!==t[1];case"in":case"!in":case"!has":case"none":return!1;case"==":case"!=":case">":case">=":case"<":case"<=":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case"any":case"all":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!zr(n)&&"boolean"!=typeof n)return!1}return!0;default:return!0}}Mr.deserialize=function(t){return new Mr(t._parameters,t._specification)},Mr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var Ir={type:"boolean",default:!1,transition:!1,"property-type":"data-driven",expression:{interpolated:!1,parameters:["zoom","feature"]}};function Dr(t){if(null==t)return function(){return!0};zr(t)||(t=Fr(t));var e=wr(t,Ir);if("error"===e.result)throw new Error(e.value.map(function(t){return t.key+": "+t.message}).join(", "));return function(t,r){return e.value.evaluate(t,r)}}function Rr(t,e){return t<e?-1:t>e?1:0}function Fr(t){if(!t)return!0;var e,r=t[0];return t.length<=1?"any"!==r:"=="===r?Br(t[1],t[2],"=="):"!="===r?Vr(Br(t[1],t[2],"==")):"<"===r||">"===r||"<="===r||">="===r?Br(t[1],t[2],r):"any"===r?(e=t.slice(1),["any"].concat(e.map(Fr))):"all"===r?["all"].concat(t.slice(1).map(Fr)):"none"===r?["all"].concat(t.slice(1).map(Fr).map(Vr)):"in"===r?Nr(t[1],t.slice(2)):"!in"===r?Vr(Nr(t[1],t.slice(2))):"has"===r?jr(t[1]):"!has"!==r||Vr(jr(t[1]))}function Br(t,e,r){switch(t){case"$type":return["filter-type-"+r,e];case"$id":return["filter-id-"+r,e];default:return["filter-"+r,t,e]}}function Nr(t,e){if(0===e.length)return!1;switch(t){case"$type":return["filter-type-in",["literal",e]];case"$id":return["filter-id-in",["literal",e]];default:return e.length>200&&!e.some(function(t){return typeof t!=typeof e[0]})?["filter-in-large",t,["literal",e.sort(Rr)]]:["filter-in-small",t,["literal",e]]}}function jr(t){switch(t){case"$type":return!0;case"$id":return["filter-has-id"];default:return["filter-has",t]}}function Vr(t){return["!",t]}function Ur(t){return zr(Ct(t.value))?Pr(St({},t,{expressionContext:"filter",valueSpec:{value:"boolean"}})):function t(e){var r=e.value,n=e.key;if("array"!==fr(r))return[new At(n,r,"array expected, "+fr(r)+" found")];var a,i=e.styleSpec,o=[];if(r.length<1)return[new At(n,r,"filter array must have at least 1 element")];switch(o=o.concat(Or({key:n+"[0]",value:r[0],valueSpec:i.filter_operator,style:e.style,styleSpec:e.styleSpec})),Lt(r[0])){case"<":case"<=":case">":case">=":r.length>=2&&"$type"===Lt(r[1])&&o.push(new At(n,r,'"$type" cannot be use with operator "'+r[0]+'"'));case"==":case"!=":3!==r.length&&o.push(new At(n,r,'filter array for operator "'+r[0]+'" must have 3 elements'));case"in":case"!in":r.length>=2&&"string"!==(a=fr(r[1]))&&o.push(new At(n+"[1]",r[1],"string expected, "+a+" found"));for(var s=2;s<r.length;s++)a=fr(r[s]),"$type"===Lt(r[1])?o=o.concat(Or({key:n+"["+s+"]",value:r[s],valueSpec:i.geometry_type,style:e.style,styleSpec:e.styleSpec})):"string"!==a&&"number"!==a&&"boolean"!==a&&o.push(new At(n+"["+s+"]",r[s],"string, number, or boolean expected, "+a+" found"));break;case"any":case"all":case"none":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+"["+l+"]",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case"has":case"!has":a=fr(r[1]),2!==r.length?o.push(new At(n,r,'filter array for "'+r[0]+'" operator must have 2 elements')):"string"!==a&&o.push(new At(n+"[1]",r[1],"string expected, "+a+" found"))}return o}(t)}function qr(t,e){var r=t.key,n=t.style,a=t.styleSpec,i=t.value,o=t.objectKey,s=a[e+"_"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if("paint"===e&&l&&s[l[1]]&&s[l[1]].transition)return Kr({key:r,value:i,valueSpec:a.transition,style:n,styleSpec:a});var c,u=t.valueSpec||s[o];if(!u)return[new At(r,i,'unknown property "'+o+'"')];if("string"===fr(i)&&cr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(i)))return[new At(r,i,'"'+o+'" does not support interpolation syntax\nUse an identity property function instead: `{ "type": "identity", "property": '+JSON.stringify(c[1])+" }`.")];var h=[];return"symbol"===t.layerType&&("text-field"===o&&n&&!n.glyphs&&h.push(new At(r,i,'use of "text-field" requires a style "glyphs" property')),"text-font"===o&&pr(Ct(i))&&"identity"===Lt(i.type)&&h.push(new At(r,i,'"text-font" does not support identity functions'))),h.concat(Kr({key:t.key,value:i,valueSpec:u,style:n,styleSpec:a,expressionContext:"property",propertyType:e,propertyKey:o}))}function Hr(t){return qr(t,"paint")}function Gr(t){return qr(t,"layout")}function Yr(t){var e=[],r=t.value,n=t.key,a=t.style,i=t.styleSpec;r.type||r.ref||e.push(new At(n,r,'either "type" or "ref" is required'));var o,s=Lt(r.type),l=Lt(r.ref);if(r.id)for(var c=Lt(r.id),u=0;u<t.arrayIndex;u++){var h=a.layers[u];Lt(h.id)===c&&e.push(new At(n,r.id,'duplicate layer id "'+r.id+'", previously used at line '+h.id.__line__))}if("ref"in r)["type","source","source-layer","filter","layout"].forEach(function(t){t in r&&e.push(new At(n,r[t],'"'+t+'" is prohibited for ref layers'))}),a.layers.forEach(function(t){Lt(t.id)===l&&(o=t)}),o?o.ref?e.push(new At(n,r.ref,"ref cannot reference another ref layer")):s=Lt(o.type):e.push(new At(n,r.ref,'ref layer "'+l+'" not found'));else if("background"!==s)if(r.source){var f=a.sources&&a.sources[r.source],p=f&&Lt(f.type);f?"vector"===p&&"raster"===s?e.push(new At(n,r.source,'layer "'+r.id+'" requires a raster source')):"raster"===p&&"raster"!==s?e.push(new At(n,r.source,'layer "'+r.id+'" requires a vector source')):"vector"!==p||r["source-layer"]?"raster-dem"===p&&"hillshade"!==s?e.push(new At(n,r.source,"raster-dem source can only be used with layer type 'hillshade'.")):"line"!==s||!r.paint||!r.paint["line-gradient"]||"geojson"===p&&f.lineMetrics||e.push(new At(n,r,'layer "'+r.id+'" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new At(n,r,'layer "'+r.id+'" must specify a "source-layer"')):e.push(new At(n,r.source,'source "'+r.source+'" not found'))}else e.push(new At(n,r,'missing required property "source"'));return e=e.concat(Sr({key:n,value:r,valueSpec:i.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{"*":function(){return[]},type:function(){return Kr({key:n+".type",value:r.type,valueSpec:i.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:"type"})},filter:Ur,layout:function(t){return Sr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{"*":function(t){return Gr(St({layerType:s},t))}}})},paint:function(t){return Sr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{"*":function(t){return Hr(St({layerType:s},t))}}})}}}))}function Wr(t){var e=t.value,r=t.key,n=t.styleSpec,a=t.style;if(!e.type)return[new At(r,e,'"type" is required')];var i,o=Lt(e.type);switch(o){case"vector":case"raster":case"raster-dem":return Sr({key:r,value:e,valueSpec:n["source_"+o.replace("-","_")],style:t.style,styleSpec:n});case"geojson":if(i=Sr({key:r,value:e,valueSpec:n.source_geojson,style:a,styleSpec:n}),e.cluster)for(var s in e.clusterProperties){var l=e.clusterProperties[s],c=l[0],u=l[1],h="string"==typeof c?[c,["accumulated"],["get",s]]:c;i.push.apply(i,Pr({key:r+"."+s+".map",value:u,expressionContext:"cluster-map"})),i.push.apply(i,Pr({key:r+"."+s+".reduce",value:h,expressionContext:"cluster-reduce"}))}return i;case"video":return Sr({key:r,value:e,valueSpec:n.source_video,style:a,styleSpec:n});case"image":return Sr({key:r,value:e,valueSpec:n.source_image,style:a,styleSpec:n});case"canvas":return[new At(r,null,"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.","source.canvas")];default:return Or({key:r+".type",value:e.type,valueSpec:{values:["vector","raster","raster-dem","geojson","video","image"]},style:a,styleSpec:n})}}function Xr(t){var e=t.value,r=t.styleSpec,n=r.light,a=t.style,i=[],o=fr(e);if(void 0===e)return i;if("object"!==o)return i.concat([new At("light",e,"object expected, "+o+" found")]);for(var s in e){var l=s.match(/^(.*)-transition$/);i=l&&n[l[1]]&&n[l[1]].transition?i.concat(Kr({key:s,value:e[s],valueSpec:r.transition,style:a,styleSpec:r})):n[s]?i.concat(Kr({key:s,value:e[s],valueSpec:n[s],style:a,styleSpec:r})):i.concat([new At(s,e[s],'unknown property "'+s+'"')])}return i}function Zr(t){var e=t.value,r=t.key,n=fr(e);return"string"!==n?[new At(r,e,"string expected, "+n+" found")]:[]}var Jr={"*":function(){return[]},array:Er,boolean:function(t){var e=t.value,r=t.key,n=fr(e);return"boolean"!==n?[new At(r,e,"boolean expected, "+n+" found")]:[]},number:Lr,color:function(t){var e=t.key,r=t.value,n=fr(r);return"string"!==n?[new At(e,r,"color expected, "+n+" found")]:null===Yt(r)?[new At(e,r,'color expected, "'+r+'" found')]:[]},constants:Mt,enum:Or,filter:Ur,function:Cr,layer:Yr,object:Sr,source:Wr,light:Xr,string:Zr,formatted:function(t){return 0===Zr(t).length?[]:Pr(t)}};function Kr(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&pr(Lt(e))?Cr(t):r.expression&&_r(Ct(e))?Pr(t):r.type&&Jr[r.type]?Jr[r.type](t):Sr(St({},t,{valueSpec:r.type?n[r.type]:r}))}function Qr(t){var e=t.value,r=t.key,n=Zr(t);return n.length?n:(-1===e.indexOf("{fontstack}")&&n.push(new At(r,e,'"glyphs" url must include a "{fontstack}" token')),-1===e.indexOf("{range}")&&n.push(new At(r,e,'"glyphs" url must include a "{range}" token')),n)}function $r(t,e){e=e||Tt;var r=[];return r=r.concat(Kr({key:"",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:Qr,"*":function(){return[]}}})),t.constants&&(r=r.concat(Mt({key:"constants",value:t.constants,style:t,styleSpec:e}))),tn(r)}function tn(t){return[].concat(t).sort(function(t,e){return t.line-e.line})}function en(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return tn(t.apply(this,e))}}$r.source=en(Wr),$r.light=en(Xr),$r.layer=en(Yr),$r.filter=en(Ur),$r.paintProperty=en(Hr),$r.layoutProperty=en(Gr);var rn=$r,nn=rn.light,an=rn.paintProperty,on=rn.layoutProperty;function sn(t,e){var r=!1;if(e&&e.length)for(var n=0,a=e;n<a.length;n+=1){var i=a[n];t.fire(new wt(new Error(i.message))),r=!0}return r}var ln=un,cn=3;function un(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var a=new Int32Array(this.arrayBuffer);t=a[0],e=a[1],r=a[2],this.d=e+2*r;for(var i=0;i<this.d*this.d;i++){var o=a[cn+i],s=a[cn+i+1];n.push(o===s?null:a.subarray(o,s))}var l=a[cn+n.length],c=a[cn+n.length+1];this.keys=a.subarray(l,c),this.bboxes=a.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var h=r/e*t;this.min=-h,this.max=t+h}un.prototype.insert=function(t,e,r,n,a){this._forEachCell(e,r,n,a,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(a)},un.prototype._insertReadonly=function(){throw"Cannot insert into a GridIndex created from an ArrayBuffer."},un.prototype._insertCell=function(t,e,r,n,a,i){this.cells[a].push(i)},un.prototype.query=function(t,e,r,n,a){var i=this.min,o=this.max;if(t<=i&&e<=i&&o<=r&&o<=n&&!a)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},a),s},un.prototype._queryCell=function(t,e,r,n,a,i,o,s){var l=this.cells[a];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,i.push(c[f])):o[f]=!1}}},un.prototype._forEachCell=function(t,e,r,n,a,i,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&a.call(this,t,e,r,n,d,i,o,s))return}},un.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},un.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},un.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=cn+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var a=new Int32Array(e+r+this.keys.length+this.bboxes.length);a[0]=this.extent,a[1]=this.n,a[2]=this.padding;for(var i=e,o=0;o<t.length;o++){var s=t[o];a[cn+o]=i,a.set(s,i),i+=s.length}return a[cn+t.length]=i,a.set(this.keys,i),i+=this.keys.length,a[cn+t.length+1]=i,a.set(this.bboxes,i),i+=this.bboxes.length,a.buffer};var hn=self.ImageData,fn={};function pn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,"_classRegistryKey",{value:t,writeable:!1}),fn[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var dn in pn("Object",Object),ln.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},ln.deserialize=function(t){return new ln(t.buffer)},pn("Grid",ln),pn("Color",Wt),pn("Error",Error),pn("StylePropertyFunction",Mr),pn("StyleExpression",br,{omit:["_evaluator"]}),pn("ZoomDependentExpression",Tr),pn("ZoomConstantExpression",kr),pn("CompoundExpression",ce,{omit:["_evaluate"]}),rr)rr[dn]._classRegistryKey||pn("Expression_"+dn,rr[dn]);function gn(t,e){if(null==t||"boolean"==typeof t||"number"==typeof t||"string"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(t instanceof ArrayBuffer)return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof hn)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],a=0,i=t;a<i.length;a+=1){var o=i[a];n.push(gn(o,e))}return n}if("object"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error("can't serialize object of unregistered class");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(fn[l].omit.indexOf(u)>=0)){var h=t[u];c[u]=fn[l].shallow.indexOf(u)>=0?h:gn(h,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error("$name property is reserved for worker serialization logic.");return"Object"!==l&&(c.$name=l),c}throw new Error("can't serialize object of type "+typeof t)}function vn(t){if(null==t||"boolean"==typeof t||"number"==typeof t||"string"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof ArrayBuffer||ArrayBuffer.isView(t)||t instanceof hn)return t;if(Array.isArray(t))return t.map(vn);if("object"==typeof t){var e=t.$name||"Object",r=fn[e].klass;if(!r)throw new Error("can't deserialize unregistered class "+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),a=0,i=Object.keys(t);a<i.length;a+=1){var o=i[a];if("$name"!==o){var s=t[o];n[o]=fn[e].shallow.indexOf(o)>=0?s:vn(s)}}return n}throw new Error("can't deserialize object of type "+typeof t)}var mn=function(){this.first=!0};mn.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var yn={"Latin-1 Supplement":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},"Arabic Supplement":function(t){return t>=1872&&t<=1919},"Arabic Extended-A":function(t){return t>=2208&&t<=2303},"Hangul Jamo":function(t){return t>=4352&&t<=4607},"Unified Canadian Aboriginal Syllabics":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},"Unified Canadian Aboriginal Syllabics Extended":function(t){return t>=6320&&t<=6399},"General Punctuation":function(t){return t>=8192&&t<=8303},"Letterlike Symbols":function(t){return t>=8448&&t<=8527},"Number Forms":function(t){return t>=8528&&t<=8591},"Miscellaneous Technical":function(t){return t>=8960&&t<=9215},"Control Pictures":function(t){return t>=9216&&t<=9279},"Optical Character Recognition":function(t){return t>=9280&&t<=9311},"Enclosed Alphanumerics":function(t){return t>=9312&&t<=9471},"Geometric Shapes":function(t){return t>=9632&&t<=9727},"Miscellaneous Symbols":function(t){return t>=9728&&t<=9983},"Miscellaneous Symbols and Arrows":function(t){return t>=11008&&t<=11263},"CJK Radicals Supplement":function(t){return t>=11904&&t<=12031},"Kangxi Radicals":function(t){return t>=12032&&t<=12255},"Ideographic Description Characters":function(t){return t>=12272&&t<=12287},"CJK Symbols and Punctuation":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},"Hangul Compatibility Jamo":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},"Bopomofo Extended":function(t){return t>=12704&&t<=12735},"CJK Strokes":function(t){return t>=12736&&t<=12783},"Katakana Phonetic Extensions":function(t){return t>=12784&&t<=12799},"Enclosed CJK Letters and Months":function(t){return t>=12800&&t<=13055},"CJK Compatibility":function(t){return t>=13056&&t<=13311},"CJK Unified Ideographs Extension A":function(t){return t>=13312&&t<=19903},"Yijing Hexagram Symbols":function(t){return t>=19904&&t<=19967},"CJK Unified Ideographs":function(t){return t>=19968&&t<=40959},"Yi Syllables":function(t){return t>=40960&&t<=42127},"Yi Radicals":function(t){return t>=42128&&t<=42191},"Hangul Jamo Extended-A":function(t){return t>=43360&&t<=43391},"Hangul Syllables":function(t){return t>=44032&&t<=55215},"Hangul Jamo Extended-B":function(t){return t>=55216&&t<=55295},"Private Use Area":function(t){return t>=57344&&t<=63743},"CJK Compatibility Ideographs":function(t){return t>=63744&&t<=64255},"Arabic Presentation Forms-A":function(t){return t>=64336&&t<=65023},"Vertical Forms":function(t){return t>=65040&&t<=65055},"CJK Compatibility Forms":function(t){return t>=65072&&t<=65103},"Small Form Variants":function(t){return t>=65104&&t<=65135},"Arabic Presentation Forms-B":function(t){return t>=65136&&t<=65279},"Halfwidth and Fullwidth Forms":function(t){return t>=65280&&t<=65519}};function xn(t){for(var e=0,r=t;e<r.length;e+=1)if(_n(r[e].charCodeAt(0)))return!0;return!1}function bn(t){return!(yn.Arabic(t)||yn["Arabic Supplement"](t)||yn["Arabic Extended-A"](t)||yn["Arabic Presentation Forms-A"](t)||yn["Arabic Presentation Forms-B"](t))}function _n(t){return!!(746===t||747===t||!(t<4352)&&(yn["Bopomofo Extended"](t)||yn.Bopomofo(t)||yn["CJK Compatibility Forms"](t)&&!(t>=65097&&t<=65103)||yn["CJK Compatibility Ideographs"](t)||yn["CJK Compatibility"](t)||yn["CJK Radicals Supplement"](t)||yn["CJK Strokes"](t)||!(!yn["CJK Symbols and Punctuation"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||yn["CJK Unified Ideographs Extension A"](t)||yn["CJK Unified Ideographs"](t)||yn["Enclosed CJK Letters and Months"](t)||yn["Hangul Compatibility Jamo"](t)||yn["Hangul Jamo Extended-A"](t)||yn["Hangul Jamo Extended-B"](t)||yn["Hangul Jamo"](t)||yn["Hangul Syllables"](t)||yn.Hiragana(t)||yn["Ideographic Description Characters"](t)||yn.Kanbun(t)||yn["Kangxi Radicals"](t)||yn["Katakana Phonetic Extensions"](t)||yn.Katakana(t)&&12540!==t||!(!yn["Halfwidth and Fullwidth Forms"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!yn["Small Form Variants"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||yn["Unified Canadian Aboriginal Syllabics"](t)||yn["Unified Canadian Aboriginal Syllabics Extended"](t)||yn["Vertical Forms"](t)||yn["Yijing Hexagram Symbols"](t)||yn["Yi Syllables"](t)||yn["Yi Radicals"](t)))}function wn(t){return!(_n(t)||function(t){return!!(yn["Latin-1 Supplement"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||yn["General Punctuation"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||yn["Letterlike Symbols"](t)||yn["Number Forms"](t)||yn["Miscellaneous Technical"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||yn["Control Pictures"](t)&&9251!==t||yn["Optical Character Recognition"](t)||yn["Enclosed Alphanumerics"](t)||yn["Geometric Shapes"](t)||yn["Miscellaneous Symbols"](t)&&!(t>=9754&&t<=9759)||yn["Miscellaneous Symbols and Arrows"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||yn["CJK Symbols and Punctuation"](t)||yn.Katakana(t)||yn["Private Use Area"](t)||yn["CJK Compatibility Forms"](t)||yn["Small Form Variants"](t)||yn["Halfwidth and Fullwidth Forms"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function kn(t,e){return!(!e&&(t>=1424&&t<=2303||yn["Arabic Presentation Forms-A"](t)||yn["Arabic Presentation Forms-B"](t))||t>=2304&&t<=3583||t>=3840&&t<=4255||yn.Khmer(t))}var Tn,An=!1,Mn=null,Sn=!1,En=new kt,Ln={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return Sn||null!=Ln.applyArabicShaping}},Cn=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new mn,this.transition={})};Cn.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!kn(n[r].charCodeAt(0),e))return!1;return!0}(t,Ln.isLoaded())},Cn.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},Cn.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var Pn=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(pr(t))return new Mr(t,e);if(_r(t)){var r=Ar(t,e);if("error"===r.result)throw new Error(r.value.map(function(t){return t.key+": "+t.message}).join(", "));return r.value}var n=t;return"string"==typeof t&&"color"===e.type&&(n=Wt.parse(t)),{kind:"constant",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};Pn.prototype.isDataDriven=function(){return"source"===this.expression.kind||"composite"===this.expression.kind},Pn.prototype.possiblyEvaluate=function(t){return this.property.possiblyEvaluate(this,t)};var On=function(t){this.property=t,this.value=new Pn(t,void 0)};On.prototype.transitioned=function(t,e){return new In(this.property,this.value,e,h({},t.transition,this.transition),t.now)},On.prototype.untransitioned=function(){return new In(this.property,this.value,null,{},0)};var zn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};zn.prototype.getValue=function(t){return b(this._values[t].value.value)},zn.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new On(this._values[t].property)),this._values[t].value=new Pn(this._values[t].property,null===e?void 0:b(e))},zn.prototype.getTransition=function(t){return b(this._values[t].transition)},zn.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new On(this._values[t].property)),this._values[t].transition=b(e)||void 0},zn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],a=this.getValue(n);void 0!==a&&(t[n]=a);var i=this.getTransition(n);void 0!==i&&(t[n+"-transition"]=i)}return t},zn.prototype.transitioned=function(t,e){for(var r=new Dn(this._properties),n=0,a=Object.keys(this._values);n<a.length;n+=1){var i=a[n];r._values[i]=this._values[i].transitioned(t,e._values[i])}return r},zn.prototype.untransitioned=function(){for(var t=new Dn(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var In=function(t,e,r,n,a){this.property=t,this.value=e,this.begin=a+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};In.prototype.possiblyEvaluate=function(t){var e=t.now||0,r=this.value.possiblyEvaluate(t),n=this.prior;if(n){if(e>this.end)return this.prior=null,r;if(this.value.isDataDriven())return this.prior=null,r;if(e<this.begin)return n.possiblyEvaluate(t);var a=(e-this.begin)/(this.end-this.begin);return this.property.interpolate(n.possiblyEvaluate(t),r,function(t){if(a<=0)return 0;if(a>=1)return 1;var e=a*a,r=e*a;return 4*(a<.5?r:3*(a-e)+r-.75)}())}return r};var Dn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Dn.prototype.possiblyEvaluate=function(t){for(var e=new Bn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var a=n[r];e._values[a]=this._values[a].possiblyEvaluate(t)}return e},Dn.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var Rn=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};Rn.prototype.getValue=function(t){return b(this._values[t].value)},Rn.prototype.setValue=function(t,e){this._values[t]=new Pn(this._values[t].property,null===e?void 0:b(e))},Rn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],a=this.getValue(n);void 0!==a&&(t[n]=a)}return t},Rn.prototype.possiblyEvaluate=function(t){for(var e=new Bn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var a=n[r];e._values[a]=this._values[a].possiblyEvaluate(t)}return e};var Fn=function(t,e,r){this.property=t,this.value=e,this.parameters=r};Fn.prototype.isConstant=function(){return"constant"===this.value.kind},Fn.prototype.constantOr=function(t){return"constant"===this.value.kind?this.value.value:t},Fn.prototype.evaluate=function(t,e){return this.property.evaluate(this.value,this.parameters,t,e)};var Bn=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Bn.prototype.get=function(t){return this._values[t]};var Nn=function(t){this.specification=t};Nn.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},Nn.prototype.interpolate=function(t,e,r){var n=xe[this.specification.type];return n?n(t,e,r):t};var jn=function(t,e){this.specification=t,this.overrides=e};jn.prototype.possiblyEvaluate=function(t,e){return"constant"===t.expression.kind||"camera"===t.expression.kind?new Fn(this,{kind:"constant",value:t.expression.evaluate(e)},e):new Fn(this,t.expression,e)},jn.prototype.interpolate=function(t,e,r){if("constant"!==t.value.kind||"constant"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Fn(this,{kind:"constant",value:void 0},t.parameters);var n=xe[this.specification.type];return n?new Fn(this,{kind:"constant",value:n(t.value.value,e.value.value,r)},t.parameters):t},jn.prototype.evaluate=function(t,e,r,n){return"constant"===t.kind?t.value:t.evaluate(e,r,n)};var Vn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e){if(void 0===t.value)return new Fn(this,{kind:"constant",value:void 0},e);if("constant"===t.expression.kind){var r=t.expression.evaluate(e),n=this._calculate(r,r,r,e);return new Fn(this,{kind:"constant",value:n},e)}if("camera"===t.expression.kind){var a=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Fn(this,{kind:"constant",value:a},e)}return new Fn(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n){if("source"===t.kind){var a=t.evaluate(e,r,n);return this._calculate(a,a,a,e)}return"composite"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(jn),Un=function(t){this.specification=t};Un.prototype.possiblyEvaluate=function(t,e){if(void 0!==t.value){if("constant"===t.expression.kind){var r=t.expression.evaluate(e);return this._calculate(r,r,r,e)}return this._calculate(t.expression.evaluate(new Cn(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Cn(Math.floor(e.zoom),e)),t.expression.evaluate(new Cn(Math.floor(e.zoom+1),e)),e)}},Un.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},Un.prototype.interpolate=function(t){return t};var qn=function(t){this.specification=t};qn.prototype.possiblyEvaluate=function(t,e){return!!t.expression.evaluate(e)},qn.prototype.interpolate=function(){return!1};var Hn=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},this.overridableProperties=[],t){var r=t[e];r.specification.overridable&&this.overridableProperties.push(e);var n=this.defaultPropertyValues[e]=new Pn(r,void 0),a=this.defaultTransitionablePropertyValues[e]=new On(r);this.defaultTransitioningPropertyValues[e]=a.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};pn("DataDrivenProperty",jn),pn("DataConstantProperty",Nn),pn("CrossFadedDataDrivenProperty",Vn),pn("CrossFadedProperty",Un),pn("ColorRampProperty",qn);var Gn=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter=function(){return!0},"custom"!==e.type&&(e=e,this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,"background"!==e.type&&(this.source=e.source,this.sourceLayer=e["source-layer"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new Rn(r.layout)),r.paint)){for(var n in this._transitionablePaint=new zn(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var a in e.layout)this.setLayoutProperty(a,e.layout[a],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned()}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return"visibility"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n="layers."+this.id+".layout."+t;if(this._validate(on,n,t,e,r))return}"visibility"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return m(t,"-transition")?this._transitionablePaint.getTransition(t.slice(0,-"-transition".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n="layers."+this.id+".paint."+t;if(this._validate(an,n,t,e,r))return!1}if(m(t,"-transition"))return this._transitionablePaint.setTransition(t.slice(0,-"-transition".length),e||void 0),!1;var a=this._transitionablePaint._values[t],i="cross-faded-data-driven"===a.property.specification["property-type"],o=a.value.isDataDriven(),s=a.value;this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t);var l=this._transitionablePaint._values[t].value;return l.isDataDriven()||o||i||this._handleOverridablePaintPropertyUpdate(t,s,l)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype._handleOverridablePaintPropertyUpdate=function(t,e,r){return!1},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||"none"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t)),this.paint=this._transitioningPaint.possiblyEvaluate(t)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,"source-layer":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),x(t,function(t,e){return!(void 0===t||"layout"===e&&!Object.keys(t).length||"paint"===e&&!Object.keys(t).length)})},e.prototype._validate=function(t,e,r,n,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&sn(this,t.call(rn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:Tt,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof Fn&&cr(e.property.specification)&&("source"===e.value.kind||"composite"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(kt),Yn={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},Wn=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},Xn=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function Zn(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map(function(t){var a,i=(a=t.type,Yn[a].BYTES_PER_ELEMENT),o=r=Jn(r,Math.max(e,i)),s=t.components||1;return n=Math.max(n,i),r+=i*s,{name:t.name,type:t.type,components:s,offset:o}}),size:Jn(r,Math.max(n,e)),alignment:e}}function Jn(t,e){return Math.ceil(t/e)*e}Xn.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},Xn.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},Xn.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},Xn.prototype.clear=function(){this.length=0},Xn.prototype.resize=function(t){this.reserve(t),this.length=t},Xn.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},Xn.prototype._refreshViews=function(){throw new Error("_refreshViews() must be implemented by each concrete StructArray layout")};var Kn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(Xn);Kn.prototype.bytesPerElement=4,pn("StructArrayLayout2i4",Kn);var Qn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,a){var i=4*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,this.int16[i+3]=a,t},e}(Xn);Qn.prototype.bytesPerElement=8,pn("StructArrayLayout4i8",Qn);var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,a,i)},e.prototype.emplace=function(t,e,r,n,a,i,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=a,this.int16[s+4]=i,this.int16[s+5]=o,t},e}(Xn);$n.prototype.bytesPerElement=12,pn("StructArrayLayout2i4i12",$n);var ta=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,a,i)},e.prototype.emplace=function(t,e,r,n,a,i,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=a,this.uint8[l+6]=i,this.uint8[l+7]=o,t},e}(Xn);ta.prototype.bytesPerElement=8,pn("StructArrayLayout2i4ub8",ta);var ea=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,a,i,o,s)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l){var c=8*t;return this.uint16[c+0]=e,this.uint16[c+1]=r,this.uint16[c+2]=n,this.uint16[c+3]=a,this.uint16[c+4]=i,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(Xn);ea.prototype.bytesPerElement=16,pn("StructArrayLayout8ui16",ea);var ra=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,a,i,o,s)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l){var c=8*t;return this.int16[c+0]=e,this.int16[c+1]=r,this.int16[c+2]=n,this.int16[c+3]=a,this.uint16[c+4]=i,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(Xn);ra.prototype.bytesPerElement=16,pn("StructArrayLayout4i4ui16",ra);var na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=3*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,t},e}(Xn);na.prototype.bytesPerElement=12,pn("StructArrayLayout3f12",na);var aa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(Xn);aa.prototype.bytesPerElement=4,pn("StructArrayLayout1ul4",aa);var ia=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s,l,c,u){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,a,i,o,s,l,c,u)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l,c,u,h){var f=12*t,p=6*t;return this.int16[f+0]=e,this.int16[f+1]=r,this.int16[f+2]=n,this.int16[f+3]=a,this.int16[f+4]=i,this.int16[f+5]=o,this.uint32[p+3]=s,this.uint16[f+8]=l,this.uint16[f+9]=c,this.int16[f+10]=u,this.int16[f+11]=h,t},e}(Xn);ia.prototype.bytesPerElement=24,pn("StructArrayLayout6i1ul2ui2i24",ia);var oa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,a,i)},e.prototype.emplace=function(t,e,r,n,a,i,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=a,this.int16[s+4]=i,this.int16[s+5]=o,t},e}(Xn);oa.prototype.bytesPerElement=12,pn("StructArrayLayout2i2i2i12",oa);var sa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,a){var i=12*t,o=3*t;return this.uint8[i+0]=e,this.uint8[i+1]=r,this.float32[o+1]=n,this.float32[o+2]=a,t},e}(Xn);sa.prototype.bytesPerElement=12,pn("StructArrayLayout2ub2f12",sa);var la=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g){var v=this.length;return this.resize(v+1),this.emplace(v,t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,v){var m=22*t,y=11*t,x=44*t;return this.int16[m+0]=e,this.int16[m+1]=r,this.uint16[m+2]=n,this.uint16[m+3]=a,this.uint32[y+2]=i,this.uint32[y+3]=o,this.uint32[y+4]=s,this.uint16[m+10]=l,this.uint16[m+11]=c,this.uint16[m+12]=u,this.float32[y+7]=h,this.float32[y+8]=f,this.uint8[x+36]=p,this.uint8[x+37]=d,this.uint8[x+38]=g,this.uint32[y+10]=v,t},e}(Xn);la.prototype.bytesPerElement=44,pn("StructArrayLayout2i2ui3ul3ui2f3ub1ul44",la);var ca=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x){var b=this.length;return this.resize(b+1),this.emplace(b,t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x)},e.prototype.emplace=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b){var _=24*t,w=12*t;return this.int16[_+0]=e,this.int16[_+1]=r,this.int16[_+2]=n,this.int16[_+3]=a,this.int16[_+4]=i,this.int16[_+5]=o,this.uint16[_+6]=s,this.uint16[_+7]=l,this.uint16[_+8]=c,this.uint16[_+9]=u,this.uint16[_+10]=h,this.uint16[_+11]=f,this.uint16[_+12]=p,this.uint16[_+13]=d,this.uint16[_+14]=g,this.uint16[_+15]=v,this.uint16[_+16]=m,this.uint32[w+9]=y,this.float32[w+10]=x,this.float32[w+11]=b,t},e}(Xn);ca.prototype.bytesPerElement=48,pn("StructArrayLayout6i11ui1ul2f48",ca);var ua=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(Xn);ua.prototype.bytesPerElement=4,pn("StructArrayLayout1f4",ua);var ha=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=3*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,t},e}(Xn);ha.prototype.bytesPerElement=6,pn("StructArrayLayout3i6",ha);var fa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=2*t,i=4*t;return this.uint32[a+0]=e,this.uint16[i+2]=r,this.uint16[i+3]=n,t},e}(Xn);fa.prototype.bytesPerElement=8,pn("StructArrayLayout1ul2ui8",fa);var pa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var a=3*t;return this.uint16[a+0]=e,this.uint16[a+1]=r,this.uint16[a+2]=n,t},e}(Xn);pa.prototype.bytesPerElement=6,pn("StructArrayLayout3ui6",pa);var da=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(Xn);da.prototype.bytesPerElement=4,pn("StructArrayLayout2ui4",da);var ga=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(Xn);ga.prototype.bytesPerElement=2,pn("StructArrayLayout1ui2",ga);var va=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(Xn);va.prototype.bytesPerElement=8,pn("StructArrayLayout2f8",va);var ma=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,a){var i=4*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,this.float32[i+3]=a,t},e}(Xn);ma.prototype.bytesPerElement=16,pn("StructArrayLayout4f16",ma);var ya=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},radius:{configurable:!0},signedDistanceFromAnchor:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorPointY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.x1.set=function(t){this._structArray.int16[this._pos2+2]=t},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.y1.set=function(t){this._structArray.int16[this._pos2+3]=t},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.x2.set=function(t){this._structArray.int16[this._pos2+4]=t},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.y2.set=function(t){this._structArray.int16[this._pos2+5]=t},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.radius.get=function(){return this._structArray.int16[this._pos2+10]},r.radius.set=function(t){this._structArray.int16[this._pos2+10]=t},r.signedDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+11]},r.signedDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+11]=t},r.anchorPoint.get=function(){return new a(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(Wn);ya.prototype.size=24;var xa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new ya(this,t)},e}(ia);pn("CollisionBoxArray",xa);var ba=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},placedOrientation:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.glyphStartIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.numGlyphs.set=function(t){this._structArray.uint16[this._pos2+3]=t},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.vertexStartIndex.set=function(t){this._structArray.uint32[this._pos4+2]=t},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineStartIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.lineLength.set=function(t){this._structArray.uint32[this._pos4+4]=t},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.segment.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.lowerSize.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.upperSize.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetX.set=function(t){this._structArray.float32[this._pos4+7]=t},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.lineOffsetY.set=function(t){this._structArray.float32[this._pos4+8]=t},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.writingMode.set=function(t){this._structArray.uint8[this._pos1+36]=t},r.placedOrientation.get=function(){return this._structArray.uint8[this._pos1+37]},r.placedOrientation.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+38]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+38]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(Wn);ba.prototype.size=44;var _a=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new ba(this,t)},e}(la);pn("PlacedSymbolArray",_a);var wa=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},verticalTextBoxStartIndex:{configurable:!0},verticalTextBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},radialTextOffset:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.rightJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+2]=t},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.centerJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+3]=t},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.leftJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+4]=t},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.verticalPlacedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+5]=t},r.key.get=function(){return this._structArray.uint16[this._pos2+6]},r.key.set=function(t){this._structArray.uint16[this._pos2+6]=t},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+7]},r.textBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+7]=t},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.verticalTextBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.verticalTextBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.verticalTextBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.verticalTextBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.iconBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+12]},r.iconBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+13]},r.featureIndex.set=function(t){this._structArray.uint16[this._pos2+13]=t},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+14]},r.numHorizontalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+14]=t},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+15]},r.numVerticalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+15]=t},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+16]},r.numIconVertices.set=function(t){this._structArray.uint16[this._pos2+16]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+9]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+9]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+10]},r.textBoxScale.set=function(t){this._structArray.float32[this._pos4+10]=t},r.radialTextOffset.get=function(){return this._structArray.float32[this._pos4+11]},r.radialTextOffset.set=function(t){this._structArray.float32[this._pos4+11]=t},Object.defineProperties(e.prototype,r),e}(Wn);wa.prototype.size=48;var ka=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new wa(this,t)},e}(ca);pn("SymbolInstanceArray",ka);var Ta=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={offsetX:{configurable:!0}};return r.offsetX.get=function(){return this._structArray.float32[this._pos4+0]},r.offsetX.set=function(t){this._structArray.float32[this._pos4+0]=t},Object.defineProperties(e.prototype,r),e}(Wn);Ta.prototype.size=4;var Aa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e.prototype.get=function(t){return new Ta(this,t)},e}(ua);pn("GlyphOffsetArray",Aa);var Ma=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={x:{configurable:!0},y:{configurable:!0},tileUnitDistanceFromAnchor:{configurable:!0}};return r.x.get=function(){return this._structArray.int16[this._pos2+0]},r.x.set=function(t){this._structArray.int16[this._pos2+0]=t},r.y.get=function(){return this._structArray.int16[this._pos2+1]},r.y.set=function(t){this._structArray.int16[this._pos2+1]=t},r.tileUnitDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+2]},r.tileUnitDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+2]=t},Object.defineProperties(e.prototype,r),e}(Wn);Ma.prototype.size=6;var Sa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e.prototype.get=function(t){return new Ma(this,t)},e}(ha);pn("SymbolLineVertexArray",Sa);var Ea=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+0]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+3]=t},Object.defineProperties(e.prototype,r),e}(Wn);Ea.prototype.size=8;var La=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ea(this,t)},e}(fa);pn("FeatureIndexArray",La);var Ca=Zn([{name:"a_pos",components:2,type:"Int16"}],4).members,Pa=function(t){void 0===t&&(t=[]),this.segments=t};function Oa(t,e){return 256*(t=c(Math.floor(t),0,255))+c(Math.floor(e),0,255)}Pa.prototype.prepareSegment=function(t,e,r,n){var a=this.segments[this.segments.length-1];return t>Pa.MAX_VERTEX_ARRAY_LENGTH&&w("Max vertices per segment is "+Pa.MAX_VERTEX_ARRAY_LENGTH+": bucket requested "+t),(!a||a.vertexLength+t>Pa.MAX_VERTEX_ARRAY_LENGTH||a.sortKey!==n)&&(a={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(a.sortKey=n),this.segments.push(a)),a},Pa.prototype.get=function(){return this.segments},Pa.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Pa.simpleSegment=function(t,e,r,n){return new Pa([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},Pa.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,pn("SegmentVector",Pa);var za=function(){this.ids=[],this.positions=[],this.indexed=!1};function Ia(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}za.prototype.add=function(t,e,r,n){this.ids.push(t),this.positions.push(e,r,n)},za.prototype.getPositions=function(t){for(var e=0,r=this.ids.length-1;e<r;){var n=e+r>>1;this.ids[n]>=t?r=n:e=n+1}for(var a=[];this.ids[e]===t;){var i=this.positions[3*e],o=this.positions[3*e+1],s=this.positions[3*e+2];a.push({index:i,start:o,end:s}),e++}return a},za.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,a){if(!(n>=a)){for(var i=e[n+a>>1],o=n-1,s=a+1;;){do{o++}while(e[o]<i);do{s--}while(e[s]>i);if(o>=s)break;Ia(e,o,s),Ia(r,3*o,3*s),Ia(r,3*o+1,3*s+1),Ia(r,3*o+2,3*s+2)}t(e,r,n,s),t(e,r,s+1,a)}}(r,n,0,r.length-1),e.push(r.buffer,n.buffer),{ids:r,positions:n}},za.deserialize=function(t){var e=new za;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e},pn("FeaturePositionMap",za);var Da=function(t,e){this.gl=t.gl,this.location=e},Ra=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Da),Fa=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Da),Ba=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Da),Na=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Da),ja=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Da),Va=function(t){function e(e,r){t.call(this,e,r),this.current=Wt.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Da),Ua=new Float32Array(16),qa=function(t){function e(e,r){t.call(this,e,r),this.current=Ua}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Da);function Ha(t){return[Oa(255*t.r,255*t.g),Oa(255*t.b,255*t.a)]}var Ga=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return"u_"+t}),this.type=r,this.maxValue=-1/0};Ga.prototype.defines=function(){return this.names.map(function(t){return"#define HAS_UNIFORM_u_"+t})},Ga.prototype.setConstantPatternPositions=function(){},Ga.prototype.populatePaintArray=function(){},Ga.prototype.updatePaintArray=function(){},Ga.prototype.upload=function(){},Ga.prototype.destroy=function(){},Ga.prototype.setUniforms=function(t,e,r,n){e.set(n.constantOr(this.value))},Ga.prototype.getBinding=function(t,e){return"color"===this.type?new Va(t,e):new Fa(t,e)},Ga.serialize=function(t){var e=t.value,r=t.names,n=t.type;return{value:gn(e),names:r,type:n}},Ga.deserialize=function(t){var e=t.value,r=t.names,n=t.type;return new Ga(vn(e),r,n)};var Ya=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return"u_"+t}),this.type=r,this.maxValue=-1/0,this.patternPositions={patternTo:null,patternFrom:null}};Ya.prototype.defines=function(){return this.names.map(function(t){return"#define HAS_UNIFORM_u_"+t})},Ya.prototype.populatePaintArray=function(){},Ya.prototype.updatePaintArray=function(){},Ya.prototype.upload=function(){},Ya.prototype.destroy=function(){},Ya.prototype.setConstantPatternPositions=function(t,e){this.patternPositions.patternTo=t.tlbr,this.patternPositions.patternFrom=e.tlbr},Ya.prototype.setUniforms=function(t,e,r,n,a){var i=this.patternPositions;"u_pattern_to"===a&&i.patternTo&&e.set(i.patternTo),"u_pattern_from"===a&&i.patternFrom&&e.set(i.patternFrom)},Ya.prototype.getBinding=function(t,e){return new ja(t,e)};var Wa=function(t,e,r,n){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return"a_"+t}),this.maxValue=-1/0,this.paintVertexAttributes=e.map(function(t){return{name:"a_"+t,type:"Float32",components:"color"===r?2:1,offset:0}}),this.paintVertexArray=new n};Wa.prototype.defines=function(){return[]},Wa.prototype.setConstantPatternPositions=function(){},Wa.prototype.populatePaintArray=function(t,e,r,n){var a=this.paintVertexArray,i=a.length;a.reserve(t);var o=this.expression.evaluate(new Cn(0),e,{},n);if("color"===this.type)for(var s=Ha(o),l=i;l<t;l++)a.emplaceBack(s[0],s[1]);else{for(var c=i;c<t;c++)a.emplaceBack(o);this.maxValue=Math.max(this.maxValue,o)}},Wa.prototype.updatePaintArray=function(t,e,r,n){var a=this.paintVertexArray,i=this.expression.evaluate({zoom:0},r,n);if("color"===this.type)for(var o=Ha(i),s=t;s<e;s++)a.emplace(s,o[0],o[1]);else{for(var l=t;l<e;l++)a.emplace(l,i);this.maxValue=Math.max(this.maxValue,i)}},Wa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Wa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},Wa.prototype.setUniforms=function(t,e){e.set(0)},Wa.prototype.getBinding=function(t,e){return new Fa(t,e)};var Xa=function(t,e,r,n,a,i){this.expression=t,this.names=e,this.uniformNames=this.names.map(function(t){return"u_"+t+"_t"}),this.type=r,this.useIntegerZoom=n,this.zoom=a,this.maxValue=-1/0;var o=i;this.paintVertexAttributes=e.map(function(t){return{name:"a_"+t,type:"Float32",components:"color"===r?4:2,offset:0}}),this.paintVertexArray=new o};Xa.prototype.defines=function(){return[]},Xa.prototype.setConstantPatternPositions=function(){},Xa.prototype.populatePaintArray=function(t,e,r,n){var a=this.paintVertexArray,i=a.length;a.reserve(t);var o=this.expression.evaluate(new Cn(this.zoom),e,{},n),s=this.expression.evaluate(new Cn(this.zoom+1),e,{},n);if("color"===this.type)for(var l=Ha(o),c=Ha(s),u=i;u<t;u++)a.emplaceBack(l[0],l[1],c[0],c[1]);else{for(var h=i;h<t;h++)a.emplaceBack(o,s);this.maxValue=Math.max(this.maxValue,o,s)}},Xa.prototype.updatePaintArray=function(t,e,r,n){var a=this.paintVertexArray,i=this.expression.evaluate({zoom:this.zoom},r,n),o=this.expression.evaluate({zoom:this.zoom+1},r,n);if("color"===this.type)for(var s=Ha(i),l=Ha(o),c=t;c<e;c++)a.emplace(c,s[0],s[1],l[0],l[1]);else{for(var u=t;u<e;u++)a.emplace(u,i,o);this.maxValue=Math.max(this.maxValue,i,o)}},Xa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Xa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},Xa.prototype.interpolationFactor=function(t){return this.useIntegerZoom?this.expression.interpolationFactor(Math.floor(t),this.zoom,this.zoom+1):this.expression.interpolationFactor(t,this.zoom,this.zoom+1)},Xa.prototype.setUniforms=function(t,e,r){e.set(this.interpolationFactor(r.zoom))},Xa.prototype.getBinding=function(t,e){return new Fa(t,e)};var Za=function(t,e,r,n,a,i,o){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return"u_"+t+"_t"}),this.useIntegerZoom=n,this.zoom=a,this.maxValue=-1/0,this.layerId=o,this.paintVertexAttributes=e.map(function(t){return{name:"a_"+t,type:"Uint16",components:4,offset:0}}),this.zoomInPaintVertexArray=new i,this.zoomOutPaintVertexArray=new i};Za.prototype.defines=function(){return[]},Za.prototype.setConstantPatternPositions=function(){},Za.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray,a=this.zoomOutPaintVertexArray,i=this.layerId,o=n.length;if(n.reserve(t),a.reserve(t),r&&e.patterns&&e.patterns[i]){var s=e.patterns[i],l=s.min,c=s.mid,u=s.max,h=r[l],f=r[c],p=r[u];if(!h||!f||!p)return;for(var d=o;d<t;d++)n.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],h.tl[0],h.tl[1],h.br[0],h.br[1]),a.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],p.tl[0],p.tl[1],p.br[0],p.br[1])}},Za.prototype.updatePaintArray=function(t,e,r,n,a){var i=this.zoomInPaintVertexArray,o=this.zoomOutPaintVertexArray,s=this.layerId;if(a&&r.patterns&&r.patterns[s]){var l=r.patterns[s],c=l.min,u=l.mid,h=l.max,f=a[c],p=a[u],d=a[h];if(!f||!p||!d)return;for(var g=t;g<e;g++)i.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],f.tl[0],f.tl[1],f.br[0],f.br[1]),o.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],d.tl[0],d.tl[1],d.br[0],d.br[1])}},Za.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Za.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()},Za.prototype.setUniforms=function(t,e){e.set(0)},Za.prototype.getBinding=function(t,e){return new Fa(t,e)};var Ja=function(){this.binders={},this.cacheKey="",this._buffers=[],this._featureMap=new za,this._bufferOffset=0};Ja.createDynamic=function(t,e,r){var n=new Ja,a=[];for(var i in t.paint._values)if(r(i)){var o=t.paint.get(i);if(o instanceof Fn&&cr(o.property.specification)){var s=Qa(i,t.type),l=o.property.specification.type,c=o.property.useIntegerZoom;if("cross-faded"===o.property.specification["property-type"]||"cross-faded-data-driven"===o.property.specification["property-type"])if("constant"===o.value.kind)n.binders[i]=new Ya(o.value.value,s,l),a.push("/u_"+i);else{var u=$a(i,l,"source");n.binders[i]=new Za(o.value,s,l,c,e,u,t.id),a.push("/a_"+i)}else if("constant"===o.value.kind)n.binders[i]=new Ga(o.value.value,s,l),a.push("/u_"+i);else if("source"===o.value.kind){var h=$a(i,l,"source");n.binders[i]=new Wa(o.value,s,l,h),a.push("/a_"+i)}else{var f=$a(i,l,"composite");n.binders[i]=new Xa(o.value,s,l,c,e,f),a.push("/z_"+i)}}}return n.cacheKey=a.sort().join(""),n},Ja.prototype.populatePaintArrays=function(t,e,r,n,a){for(var i in this.binders)this.binders[i].populatePaintArray(t,e,n,a);void 0!==e.id&&this._featureMap.add(+e.id,r,this._bufferOffset,t),this._bufferOffset=t},Ja.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders)this.binders[r].setConstantPatternPositions(t,e)},Ja.prototype.updatePaintArrays=function(t,e,r,n){var a=!1;for(var i in t)for(var o=0,s=this._featureMap.getPositions(+i);o<s.length;o+=1){var l=s[o],c=e.feature(l.index);for(var u in this.binders){var h=this.binders[u];if(!(h instanceof Ga||h instanceof Ya)&&!0===h.expression.isStateDependent){var f=r.paint.get(u);h.expression=f.value,h.updatePaintArray(l.start,l.end,c,t[i],n),a=!0}}}return a},Ja.prototype.defines=function(){var t=[];for(var e in this.binders)t.push.apply(t,this.binders[e].defines());return t},Ja.prototype.getPaintVertexBuffers=function(){return this._buffers},Ja.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders)for(var a=this.binders[n],i=0,o=a.uniformNames;i<o.length;i+=1){var s=o[i];if(e[s]){var l=a.getBinding(t,e[s]);r.push({name:s,property:n,binding:l})}}return r},Ja.prototype.setUniforms=function(t,e,r,n){for(var a=0,i=e;a<i.length;a+=1){var o=i[a],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniforms(t,c,n,r.get(l),s)}},Ja.prototype.updatePatternPaintBuffers=function(t){var e=[];for(var r in this.binders){var n=this.binders[r];if(n instanceof Za){var a=2===t.fromScale?n.zoomInPaintVertexBuffer:n.zoomOutPaintVertexBuffer;a&&e.push(a)}else(n instanceof Wa||n instanceof Xa)&&n.paintVertexBuffer&&e.push(n.paintVertexBuffer)}this._buffers=e},Ja.prototype.upload=function(t){for(var e in this.binders)this.binders[e].upload(t);var r=[];for(var n in this.binders){var a=this.binders[n];(a instanceof Wa||a instanceof Xa)&&a.paintVertexBuffer&&r.push(a.paintVertexBuffer)}this._buffers=r},Ja.prototype.destroy=function(){for(var t in this.binders)this.binders[t].destroy()};var Ka=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var a=0,i=e;a<i.length;a+=1){var o=i[a];this.programConfigurations[o.id]=Ja.createDynamic(o,r,n),this.programConfigurations[o.id].layoutAttributes=t}this.needsUpload=!1};function Qa(t,e){return{"text-opacity":["opacity"],"icon-opacity":["opacity"],"text-color":["fill_color"],"icon-color":["fill_color"],"text-halo-color":["halo_color"],"icon-halo-color":["halo_color"],"text-halo-blur":["halo_blur"],"icon-halo-blur":["halo_blur"],"text-halo-width":["halo_width"],"icon-halo-width":["halo_width"],"line-gap-width":["gapwidth"],"line-pattern":["pattern_to","pattern_from"],"fill-pattern":["pattern_to","pattern_from"],"fill-extrusion-pattern":["pattern_to","pattern_from"]}[t]||[t.replace(e+"-","").replace(/-/g,"_")]}function $a(t,e,r){var n={color:{source:va,composite:ma},number:{source:ua,composite:va}},a=function(t){return{"line-pattern":{source:ea,composite:ea},"fill-pattern":{source:ea,composite:ea},"fill-extrusion-pattern":{source:ea,composite:ea}}[t]}(t);return a&&a[r]||n[e][r]}Ka.prototype.populatePaintArrays=function(t,e,r,n,a){for(var i in this.programConfigurations)this.programConfigurations[i].populatePaintArrays(t,e,r,n,a);this.needsUpload=!0},Ka.prototype.updatePaintArrays=function(t,e,r,n){for(var a=0,i=r;a<i.length;a+=1){var o=i[a];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,e,o,n)||this.needsUpload}},Ka.prototype.get=function(t){return this.programConfigurations[t]},Ka.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},Ka.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},pn("ConstantBinder",Ga),pn("CrossFadedConstantBinder",Ya),pn("SourceExpressionBinder",Wa),pn("CrossFadedCompositeBinder",Za),pn("CompositeExpressionBinder",Xa),pn("ProgramConfiguration",Ja,{omit:["_buffers"]}),pn("ProgramConfigurationSet",Ka);var ti=8192,ei=(15,{min:-1*Math.pow(2,14),max:Math.pow(2,14)-1});function ri(t){for(var e=ti/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var a=r[n],i=0;i<a.length;i++){var o=a[i];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<ei.min||o.x>ei.max||o.y<ei.min||o.y>ei.max)&&(w("Geometry exceeds allowed extent, reduce your vector tile buffer size"),o.x=c(o.x,ei.min,ei.max),o.y=c(o.y,ei.min,ei.max))}return r}function ni(t,e,r,n,a){t.emplaceBack(2*e+(n+1)/2,2*r+(a+1)/2)}var ai=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Kn,this.indexArray=new pa,this.segments=new Pa,this.programConfigurations=new Ka(Ca,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function ii(t,e){for(var r=0;r<t.length;r++)if(di(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(di(t,e[n]))return!0;return!!ci(t,e)}function oi(t,e,r){return!!di(t,e)||!!hi(e,t,r)}function si(t,e){if(1===t.length)return pi(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],a=0;a<n.length;a++)if(di(t,n[a]))return!0;for(var i=0;i<t.length;i++)if(pi(e,t[i]))return!0;for(var o=0;o<e.length;o++)if(ci(t,e[o]))return!0;return!1}function li(t,e,r){if(t.length>1){if(ci(t,e))return!0;for(var n=0;n<e.length;n++)if(hi(e[n],t,r))return!0}for(var a=0;a<t.length;a++)if(hi(t[a],e,r))return!0;return!1}function ci(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],a=t[r+1],i=0;i<e.length-1;i++)if(ui(n,a,e[i],e[i+1]))return!0;return!1}function ui(t,e,r,n){return k(t,r,n)!==k(e,r,n)&&k(t,e,r)!==k(t,e,n)}function hi(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var a=1;a<e.length;a++)if(fi(t,e[a-1],e[a])<n)return!0;return!1}function fi(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var a=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return a<0?t.distSqr(e):a>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(a)._add(e))}function pi(t,e){for(var r,n,a,i=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],a=r[l],n.y>e.y!=a.y>e.y&&e.x<(a.x-n.x)*(e.y-n.y)/(a.y-n.y)+n.x&&(i=!i);return i}function di(t,e){for(var r=!1,n=0,a=t.length-1;n<t.length;a=n++){var i=t[n],o=t[a];i.y>e.y!=o.y>e.y&&e.x<(o.x-i.x)*(e.y-i.y)/(o.y-i.y)+i.x&&(r=!r)}return r}function gi(t,e,r){var n=r[0],a=r[2];if(t.x<n.x&&e.x<n.x||t.x>a.x&&e.x>a.x||t.y<n.y&&e.y<n.y||t.y>a.y&&e.y>a.y)return!1;var i=k(t,e,r[0]);return i!==k(t,e,r[1])||i!==k(t,e,r[2])||i!==k(t,e,r[3])}function vi(t,e,r){var n=e.paint.get(t).value;return"constant"===n.kind?n.value:r.programConfigurations.get(e.id).binders[t].maxValue}function mi(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function yi(t,e,r,n,i){if(!e[0]&&!e[1])return t;var o=a.convert(e)._mult(i);"viewport"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}ai.prototype.populate=function(t,e){var r=this.layers[0],n=[],a=null;"circle"===r.type&&(a=r.layout.get("circle-sort-key"));for(var i=0,o=t;i<o.length;i+=1){var s=o[i],l=s.feature,c=s.index,u=s.sourceLayerIndex;if(this.layers[0]._featureFilter(new Cn(this.zoom),l)){var h=ri(l),f=a?a.evaluate(l,{}):void 0,p={id:l.id,properties:l.properties,type:l.type,sourceLayerIndex:u,index:c,geometry:h,patterns:{},sortKey:f};n.push(p)}}a&&n.sort(function(t,e){return t.sortKey-e.sortKey});for(var d=0,g=n;d<g.length;d+=1){var v=g[d],m=v,y=m.geometry,x=m.index,b=m.sourceLayerIndex,_=t[x].feature;this.addFeature(v,y,x),e.featureIndex.insert(_,y,x,b,this.index)}},ai.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},ai.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ai.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},ai.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ca),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},ai.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ai.prototype.addFeature=function(t,e,r){for(var n=0,a=e;n<a.length;n+=1)for(var i=0,o=a[n];i<o.length;i+=1){var s=o[i],l=s.x,c=s.y;if(!(l<0||l>=ti||c<0||c>=ti)){var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray,t.sortKey),h=u.vertexLength;ni(this.layoutVertexArray,l,c,-1,-1),ni(this.layoutVertexArray,l,c,1,-1),ni(this.layoutVertexArray,l,c,1,1),ni(this.layoutVertexArray,l,c,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),u.vertexLength+=4,u.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{})},pn("CircleBucket",ai,{omit:["layers"]});var xi,bi=new Hn({"circle-sort-key":new jn(Tt.layout_circle["circle-sort-key"])}),_i={paint:new Hn({"circle-radius":new jn(Tt.paint_circle["circle-radius"]),"circle-color":new jn(Tt.paint_circle["circle-color"]),"circle-blur":new jn(Tt.paint_circle["circle-blur"]),"circle-opacity":new jn(Tt.paint_circle["circle-opacity"]),"circle-translate":new Nn(Tt.paint_circle["circle-translate"]),"circle-translate-anchor":new Nn(Tt.paint_circle["circle-translate-anchor"]),"circle-pitch-scale":new Nn(Tt.paint_circle["circle-pitch-scale"]),"circle-pitch-alignment":new Nn(Tt.paint_circle["circle-pitch-alignment"]),"circle-stroke-width":new jn(Tt.paint_circle["circle-stroke-width"]),"circle-stroke-color":new jn(Tt.paint_circle["circle-stroke-color"]),"circle-stroke-opacity":new jn(Tt.paint_circle["circle-stroke-opacity"])}),layout:bi},wi="undefined"!=typeof Float32Array?Float32Array:Array;function ki(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3];return t[0]=r[0]*n+r[4]*a+r[8]*i+r[12]*o,t[1]=r[1]*n+r[5]*a+r[9]*i+r[13]*o,t[2]=r[2]*n+r[6]*a+r[10]*i+r[14]*o,t[3]=r[3]*n+r[7]*a+r[11]*i+r[15]*o,t}Math.hypot||(Math.hypot=function(){for(var t=arguments,e=0,r=arguments.length;r--;)e+=t[r]*t[r];return Math.sqrt(e)}),xi=new wi(3),wi!=Float32Array&&(xi[0]=0,xi[1]=0,xi[2]=0),function(){var t=new wi(4);wi!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();var Ti=function(t){function e(e){t.call(this,e,_i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ai(t)},e.prototype.queryRadius=function(t){var e=t;return vi("circle-radius",this,e)+vi("circle-stroke-width",this,e)+mi(this.paint.get("circle-translate"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,i,o,s){for(var l=yi(t,this.paint.get("circle-translate"),this.paint.get("circle-translate-anchor"),i.angle,o),c=this.paint.get("circle-radius").evaluate(e,r)+this.paint.get("circle-stroke-width").evaluate(e,r),u="map"===this.paint.get("circle-pitch-alignment"),h=u?l:function(t,e){return l.map(function(t){return Ai(t,e)})}(0,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,v=d[p];g<v.length;g+=1){var m=v[g],y=u?m:Ai(m,s),x=f,b=ki([],[m.x,m.y,0,1],s);if("viewport"===this.paint.get("circle-pitch-scale")&&"map"===this.paint.get("circle-pitch-alignment")?x*=b[3]/i.cameraToCenterDistance:"map"===this.paint.get("circle-pitch-scale")&&"viewport"===this.paint.get("circle-pitch-alignment")&&(x*=i.cameraToCenterDistance/b[3]),oi(h,y,x))return!0}return!1},e}(Gn);function Ai(t,e){var r=ki([],[t.x,t.y,0,1],e);return new a(r[0]/r[3],r[1]/r[3])}var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ai);function Si(t,e,r,n){var a=e.width,i=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==a*i*r)throw new RangeError("mismatched image size")}else n=new Uint8Array(a*i*r);return t.width=a,t.height=i,t.data=n,t}function Ei(t,e,r){var n=e.width,a=e.height;if(n!==t.width||a!==t.height){var i=Si({},{width:n,height:a},r);Li(t,i,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,a)},r),t.width=n,t.height=a,t.data=i.data}}function Li(t,e,r,n,a,i){if(0===a.width||0===a.height)return e;if(a.width>t.width||a.height>t.height||r.x>t.width-a.width||r.y>t.height-a.height)throw new RangeError("out of range source coordinates for image copy");if(a.width>e.width||a.height>e.height||n.x>e.width-a.width||n.y>e.height-a.height)throw new RangeError("out of range destination coordinates for image copy");for(var o=t.data,s=e.data,l=0;l<a.height;l++)for(var c=((r.y+l)*t.width+r.x)*i,u=((n.y+l)*e.width+n.x)*i,h=0;h<a.width*i;h++)s[u+h]=o[c+h];return e}pn("HeatmapBucket",Mi,{omit:["layers"]});var Ci=function(t,e){Si(this,t,1,e)};Ci.prototype.resize=function(t){Ei(this,t,1)},Ci.prototype.clone=function(){return new Ci({width:this.width,height:this.height},new Uint8Array(this.data))},Ci.copy=function(t,e,r,n,a){Li(t,e,r,n,a,1)};var Pi=function(t,e){Si(this,t,4,e)};Pi.prototype.resize=function(t){Ei(this,t,4)},Pi.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Pi.prototype.clone=function(){return new Pi({width:this.width,height:this.height},new Uint8Array(this.data))},Pi.copy=function(t,e,r,n,a){Li(t,e,r,n,a,4)},pn("AlphaImage",Ci),pn("RGBAImage",Pi);var Oi={paint:new Hn({"heatmap-radius":new jn(Tt.paint_heatmap["heatmap-radius"]),"heatmap-weight":new jn(Tt.paint_heatmap["heatmap-weight"]),"heatmap-intensity":new Nn(Tt.paint_heatmap["heatmap-intensity"]),"heatmap-color":new qn(Tt.paint_heatmap["heatmap-color"]),"heatmap-opacity":new Nn(Tt.paint_heatmap["heatmap-opacity"])})};function zi(t,e){for(var r=new Uint8Array(1024),n={},a=0,i=0;a<256;a++,i+=4){n[e]=a/255;var o=t.evaluate(n);r[i+0]=Math.floor(255*o.r/o.a),r[i+1]=Math.floor(255*o.g/o.a),r[i+2]=Math.floor(255*o.b/o.a),r[i+3]=Math.floor(255*o.a)}return new Pi({width:256,height:1},r)}var Ii=function(t){function e(e){t.call(this,e,Oi),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Mi(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){"heatmap-color"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values["heatmap-color"].value.expression;this.colorRamp=zi(t,"heatmapDensity"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get("heatmap-opacity")&&"none"!==this.visibility},e}(Gn),Di={paint:new Hn({"hillshade-illumination-direction":new Nn(Tt.paint_hillshade["hillshade-illumination-direction"]),"hillshade-illumination-anchor":new Nn(Tt.paint_hillshade["hillshade-illumination-anchor"]),"hillshade-exaggeration":new Nn(Tt.paint_hillshade["hillshade-exaggeration"]),"hillshade-shadow-color":new Nn(Tt.paint_hillshade["hillshade-shadow-color"]),"hillshade-highlight-color":new Nn(Tt.paint_hillshade["hillshade-highlight-color"]),"hillshade-accent-color":new Nn(Tt.paint_hillshade["hillshade-accent-color"])})},Ri=function(t){function e(e){t.call(this,e,Di)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get("hillshade-exaggeration")&&"none"!==this.visibility},e}(Gn),Fi=Zn([{name:"a_pos",components:2,type:"Int16"}],4).members,Bi=ji,Ni=ji;function ji(t,e,r){r=r||2;var n,a,i,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=Vi(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var a,i,o,s=[];for(a=0,i=e.length;a<i;a++)(o=Vi(t,e[a]*n,a<i-1?e[a+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(Qi(o));for(s.sort(Xi),a=0;a<s.length;a++)Zi(s[a],r),r=Ui(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=i=t[0],a=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<a&&(a=l),s>i&&(i=s),l>o&&(o=l);c=0!==(c=Math.max(i-n,o-a))?1/c:0}return qi(f,p,r,n,a,c),p}function Vi(t,e,r,n,a){var i,o;if(a===ho(t,e,r,n)>0)for(i=e;i<r;i+=n)o=lo(i,t[i],t[i+1],o);else for(i=r-n;i>=e;i-=n)o=lo(i,t[i],t[i+1],o);return o&&ro(o,o.next)&&(co(o),o=o.next),o}function Ui(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!ro(n,n.next)&&0!==eo(n.prev,n,n.next))n=n.next;else{if(co(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function qi(t,e,r,n,a,i,o){if(t){!o&&i&&function(t,e,r,n){var a=t;do{null===a.z&&(a.z=Ki(a.x,a.y,e,r,n)),a.prevZ=a.prev,a.nextZ=a.next,a=a.next}while(a!==t);a.prevZ.nextZ=null,a.prevZ=null,function(t){var e,r,n,a,i,o,s,l,c=1;do{for(r=t,t=null,i=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(a=r,r=r.nextZ,s--):(a=n,n=n.nextZ,l--),i?i.nextZ=a:t=a,a.prevZ=i,i=a;r=n}i.nextZ=null,c*=2}while(o>1)}(a)}(t,n,a,i);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,i?Gi(t,n,a,i):Hi(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),co(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?qi(t=Yi(Ui(t),e,r),e,r,n,a,i,2):2===o&&Wi(t,e,r,n,a,i):qi(Ui(t),e,r,n,a,i,1);break}}}function Hi(t){var e=t.prev,r=t,n=t.next;if(eo(e,r,n)>=0)return!1;for(var a=t.next.next;a!==t.prev;){if($i(e.x,e.y,r.x,r.y,n.x,n.y,a.x,a.y)&&eo(a.prev,a,a.next)>=0)return!1;a=a.next}return!0}function Gi(t,e,r,n){var a=t.prev,i=t,o=t.next;if(eo(a,i,o)>=0)return!1;for(var s=a.x<i.x?a.x<o.x?a.x:o.x:i.x<o.x?i.x:o.x,l=a.y<i.y?a.y<o.y?a.y:o.y:i.y<o.y?i.y:o.y,c=a.x>i.x?a.x>o.x?a.x:o.x:i.x>o.x?i.x:o.x,u=a.y>i.y?a.y>o.y?a.y:o.y:i.y>o.y?i.y:o.y,h=Ki(s,l,e,r,n),f=Ki(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=h&&d&&d.z<=f;){if(p!==t.prev&&p!==t.next&&$i(a.x,a.y,i.x,i.y,o.x,o.y,p.x,p.y)&&eo(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&$i(a.x,a.y,i.x,i.y,o.x,o.y,d.x,d.y)&&eo(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&$i(a.x,a.y,i.x,i.y,o.x,o.y,p.x,p.y)&&eo(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=f;){if(d!==t.prev&&d!==t.next&&$i(a.x,a.y,i.x,i.y,o.x,o.y,d.x,d.y)&&eo(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function Yi(t,e,r){var n=t;do{var a=n.prev,i=n.next.next;!ro(a,i)&&no(a,n,n.next,i)&&oo(a,i)&&oo(i,a)&&(e.push(a.i/r),e.push(n.i/r),e.push(i.i/r),co(n),co(n.next),n=t=i),n=n.next}while(n!==t);return Ui(n)}function Wi(t,e,r,n,a,i){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&to(o,s)){var l=so(o,s);return o=Ui(o,o.next),l=Ui(l,l.next),qi(o,e,r,n,a,i),void qi(l,e,r,n,a,i)}s=s.next}o=o.next}while(o!==t)}function Xi(t,e){return t.x-e.x}function Zi(t,e){if(e=function(t,e){var r,n=e,a=t.x,i=t.y,o=-1/0;do{if(i<=n.y&&i>=n.next.y&&n.next.y!==n.y){var s=n.x+(i-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=a&&s>o){if(o=s,s===a){if(i===n.y)return n;if(i===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(a===o)return r;var l,c=r,u=r.x,h=r.y,f=1/0;n=r;do{a>=n.x&&n.x>=u&&a!==n.x&&$i(i<h?a:o,i,u,h,i<h?o:a,i,n.x,n.y)&&(l=Math.abs(i-n.y)/(a-n.x),oo(n,t)&&(l<f||l===f&&(n.x>r.x||n.x===r.x&&Ji(r,n)))&&(r=n,f=l)),n=n.next}while(n!==c);return r}(t,e)){var r=so(e,t);Ui(r,r.next)}}function Ji(t,e){return eo(t.prev,t,e.prev)<0&&eo(e.next,t,t.next)<0}function Ki(t,e,r,n,a){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*a)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*a)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function Qi(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function $i(t,e,r,n,a,i,o,s){return(a-o)*(e-s)-(t-o)*(i-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(i-s)-(a-o)*(n-s)>=0}function to(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&no(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(oo(t,e)&&oo(e,t)&&function(t,e){var r=t,n=!1,a=(t.x+e.x)/2,i=(t.y+e.y)/2;do{r.y>i!=r.next.y>i&&r.next.y!==r.y&&a<(r.next.x-r.x)*(i-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(eo(t.prev,t,e.prev)||eo(t,e.prev,e))||ro(t,e)&&eo(t.prev,t,t.next)>0&&eo(e.prev,e,e.next)>0)}function eo(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function ro(t,e){return t.x===e.x&&t.y===e.y}function no(t,e,r,n){var a=io(eo(t,e,r)),i=io(eo(t,e,n)),o=io(eo(r,n,t)),s=io(eo(r,n,e));return a!==i&&o!==s||!(0!==a||!ao(t,r,e))||!(0!==i||!ao(t,n,e))||!(0!==o||!ao(r,t,n))||!(0!==s||!ao(r,e,n))}function ao(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function io(t){return t>0?1:t<0?-1:0}function oo(t,e){return eo(t.prev,t,t.next)<0?eo(t,e,t.next)>=0&&eo(t,t.prev,e)>=0:eo(t,e,t.prev)<0||eo(t,t.next,e)<0}function so(t,e){var r=new uo(t.i,t.x,t.y),n=new uo(e.i,e.x,e.y),a=t.next,i=e.prev;return t.next=e,e.prev=t,r.next=a,a.prev=r,n.next=r,r.prev=n,i.next=n,n.prev=i,n}function lo(t,e,r,n){var a=new uo(t,e,r);return n?(a.next=n.next,a.prev=n,n.next.prev=a,n.next=a):(a.prev=a,a.next=a),a}function co(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function uo(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function ho(t,e,r,n){for(var a=0,i=e,o=r-n;i<r;i+=n)a+=(t[o]-t[i])*(t[i+1]+t[o+1]),o=i;return a}function fo(t,e,r,n,a){!function t(e,r,n,a,i){for(;a>n;){if(a-n>600){var o=a-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(a,Math.floor(r+(o-s)*c/o+u)),i)}var h=e[r],f=n,p=a;for(po(e,n,r),i(e[a],h)>0&&po(e,n,a);f<p;){for(po(e,f,p),f++,p--;i(e[f],h)<0;)f++;for(;i(e[p],h)>0;)p--}0===i(e[n],h)?po(e,n,p):po(e,++p,a),p<=r&&(n=p+1),r<=p&&(a=p-1)}}(t,e,r||0,n||t.length-1,a||go)}function po(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function go(t,e){return t<e?-1:t>e?1:0}function vo(t,e){var r=t.length;if(r<=1)return[t];for(var n,a,i=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===a&&(a=s<0),a===s<0?(n&&i.push(n),n=[t[o]]):n.push(t[o]))}if(n&&i.push(n),e>1)for(var l=0;l<i.length;l++)i[l].length<=e||(fo(i[l],e,1,i[l].length-1,mo),i[l]=i[l].slice(0,e));return i}function mo(t,e){return e.area-t.area}function yo(t,e,r){for(var n=r.patternDependencies,a=!1,i=0,o=e;i<o.length;i+=1){var s=o[i].paint.get(t+"-pattern");s.isConstant()||(a=!0);var l=s.constantOr(null);l&&(a=!0,n[l.to]=!0,n[l.from]=!0)}return a}function xo(t,e,r,n,a){for(var i=a.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+"-pattern").value;if("constant"!==c.kind){var u=c.evaluate({zoom:n-1},r,{}),h=c.evaluate({zoom:n},r,{}),f=c.evaluate({zoom:n+1},r,{});i[u]=!0,i[h]=!0,i[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}ji.deviation=function(t,e,r,n){var a=e&&e.length,i=a?e[0]*r:t.length,o=Math.abs(ho(t,0,i,r));if(a)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(ho(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},ji.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,a=0;a<t.length;a++){for(var i=0;i<t[a].length;i++)for(var o=0;o<e;o++)r.vertices.push(t[a][i][o]);a>0&&(n+=t[a-1].length,r.holes.push(n))}return r},Bi.default=Ni;var bo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Kn,this.indexArray=new pa,this.indexArray2=new da,this.programConfigurations=new Ka(Fi,t.layers,t.zoom),this.segments=new Pa,this.segments2=new Pa,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};bo.prototype.populate=function(t,e){this.hasPattern=yo("fill",this.layers,e);for(var r=this.layers[0].layout.get("fill-sort-key"),n=[],a=0,i=t;a<i.length;a+=1){var o=i[a],s=o.feature,l=o.index,c=o.sourceLayerIndex;if(this.layers[0]._featureFilter(new Cn(this.zoom),s)){var u=ri(s),h=r?r.evaluate(s,{}):void 0,f={id:s.id,properties:s.properties,type:s.type,sourceLayerIndex:c,index:l,geometry:u,patterns:{},sortKey:h};n.push(f)}}r&&n.sort(function(t,e){return t.sortKey-e.sortKey});for(var p=0,d=n;p<d.length;p+=1){var g=d[p],v=g,m=v.geometry,y=v.index,x=v.sourceLayerIndex;if(this.hasPattern){var b=xo("fill",this.layers,g,this.zoom,e);this.patternFeatures.push(b)}else this.addFeature(g,m,y,{});var _=t[y].feature;e.featureIndex.insert(_,m,y,x,this.index)}},bo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},bo.prototype.addFeatures=function(t,e){for(var r=0,n=this.patternFeatures;r<n.length;r+=1){var a=n[r];this.addFeature(a,a.geometry,a.index,e)}},bo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},bo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},bo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Fi),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},bo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},bo.prototype.addFeature=function(t,e,r,n){for(var a=0,i=vo(e,500);a<i.length;a+=1){for(var o=i[a],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray),h=u.vertexLength,f=[],p=[],d=0,g=o;d<g.length;d+=1){var v=g[d];if(0!==v.length){v!==o[0]&&p.push(f.length/2);var m=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),y=m.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(y+v.length-1,y),f.push(v[0].x),f.push(v[0].y);for(var x=1;x<v.length;x++)this.layoutVertexArray.emplaceBack(v[x].x,v[x].y),this.indexArray2.emplaceBack(y+x-1,y+x),f.push(v[x].x),f.push(v[x].y);m.vertexLength+=v.length,m.primitiveLength+=v.length}}for(var b=Bi(f,p),_=0;_<b.length;_+=3)this.indexArray.emplaceBack(h+b[_],h+b[_+1],h+b[_+2]);u.vertexLength+=s,u.primitiveLength+=b.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},pn("FillBucket",bo,{omit:["layers","patternFeatures"]});var _o=new Hn({"fill-sort-key":new jn(Tt.layout_fill["fill-sort-key"])}),wo={paint:new Hn({"fill-antialias":new Nn(Tt.paint_fill["fill-antialias"]),"fill-opacity":new jn(Tt.paint_fill["fill-opacity"]),"fill-color":new jn(Tt.paint_fill["fill-color"]),"fill-outline-color":new jn(Tt.paint_fill["fill-outline-color"]),"fill-translate":new Nn(Tt.paint_fill["fill-translate"]),"fill-translate-anchor":new Nn(Tt.paint_fill["fill-translate-anchor"]),"fill-pattern":new Vn(Tt.paint_fill["fill-pattern"])}),layout:_o},ko=function(t){function e(e){t.call(this,e,wo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e);var r=this.paint._values["fill-outline-color"];"constant"===r.value.kind&&void 0===r.value.value&&(this.paint._values["fill-outline-color"]=this.paint._values["fill-color"])},e.prototype.createBucket=function(t){return new bo(t)},e.prototype.queryRadius=function(){return mi(this.paint.get("fill-translate"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,i,o){return si(yi(t,this.paint.get("fill-translate"),this.paint.get("fill-translate-anchor"),i.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(Gn),To=Zn([{name:"a_pos",components:2,type:"Int16"},{name:"a_normal_ed",components:4,type:"Int16"}],4).members,Ao=Mo;function Mo(t,e,r,n,a){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=a,t.readFields(So,this,e)}function So(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],a=e._values[t.readVarint()];e.properties[n]=a}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function Eo(t){for(var e,r,n=0,a=0,i=t.length,o=i-1;a<i;o=a++)e=t[a],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}Mo.types=["Unknown","Point","LineString","Polygon"],Mo.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,i=0,o=0,s=0,l=[];t.pos<r;){if(i<=0){var c=t.readVarint();n=7&c,i=c>>3}if(i--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new a(o,s));else{if(7!==n)throw new Error("unknown command "+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},Mo.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,a=0,i=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(a+=t.readSVarint())<o&&(o=a),a>s&&(s=a),(i+=t.readSVarint())<l&&(l=i),i>c&&(c=i);else if(7!==r)throw new Error("unknown command "+r)}return[o,l,s,c]},Mo.prototype.toGeoJSON=function(t,e,r){var n,a,i=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=Mo.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/i;t[e]=[360*(r.x+o)/i-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,a=[],i=0;i<e;i++){var o=Eo(t[i]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&a.push(r),r=[t[i]]):r.push(t[i]))}return r&&a.push(r),a}(l),n=0;n<l.length;n++)for(a=0;a<l[n].length;a++)u(l[n][a])}1===l.length?l=l[0]:c="Multi"+c;var f={type:"Feature",geometry:{type:c,coordinates:l},properties:this.properties};return"id"in this&&(f.id=this.id),f};var Lo=Co;function Co(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(Po,this,e),this.length=this._features.length}function Po(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function Oo(t,e,r){if(3===t){var n=new Lo(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}Co.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error("feature index out of bounds");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Ao(this._pbf,e,this.extent,this._keys,this._values)};var zo={VectorTile:function(t,e){this.layers=t.readFields(Oo,{},e)},VectorTileFeature:Ao,VectorTileLayer:Lo},Io=zo.VectorTileFeature.types,Do=Math.pow(2,13);function Ro(t,e,r,n,a,i,o,s){t.emplaceBack(e,r,2*Math.floor(n*Do)+o,a*Do*2,i*Do*2,Math.round(s))}var Fo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new $n,this.indexArray=new pa,this.programConfigurations=new Ka(To,t.layers,t.zoom),this.segments=new Pa,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function Bo(t,e){return t.x===e.x&&(t.x<0||t.x>ti)||t.y===e.y&&(t.y<0||t.y>ti)}function No(t){return t.every(function(t){return t.x<0})||t.every(function(t){return t.x>ti})||t.every(function(t){return t.y<0})||t.every(function(t){return t.y>ti})}Fo.prototype.populate=function(t,e){this.features=[],this.hasPattern=yo("fill-extrusion",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var a=n[r],i=a.feature,o=a.index,s=a.sourceLayerIndex;if(this.layers[0]._featureFilter(new Cn(this.zoom),i)){var l=ri(i),c={sourceLayerIndex:s,index:o,geometry:l,properties:i.properties,type:i.type,patterns:{}};void 0!==i.id&&(c.id=i.id),this.hasPattern?this.features.push(xo("fill-extrusion",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(i,l,o,s,this.index,!0)}}},Fo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var a=n[r],i=a.geometry;this.addFeature(a,i,a.index,e)}},Fo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Fo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Fo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Fo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,To),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Fo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Fo.prototype.addFeature=function(t,e,r,n){for(var a=0,i=vo(e,500);a<i.length;a+=1){for(var o=i[a],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,f=o;h<f.length;h+=1){var p=f[h];if(0!==p.length&&!No(p))for(var d=0,g=0;g<p.length;g++){var v=p[g];if(g>=1){var m=p[g-1];if(!Bo(v,m)){u.vertexLength+4>Pa.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var y=v.sub(m)._perp()._unit(),x=m.dist(v);d+x>32768&&(d=0),Ro(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,0,d),Ro(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,1,d),d+=x,Ro(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,0,d),Ro(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,1,d);var b=u.vertexLength;this.indexArray.emplaceBack(b,b+2,b+1),this.indexArray.emplaceBack(b+1,b+2,b+3),u.vertexLength+=4,u.primitiveLength+=2}}}}if(u.vertexLength+s>Pa.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray)),"Polygon"===Io[t.type]){for(var _=[],w=[],k=u.vertexLength,T=0,A=o;T<A.length;T+=1){var M=A[T];if(0!==M.length){M!==o[0]&&w.push(_.length/2);for(var S=0;S<M.length;S++){var E=M[S];Ro(this.layoutVertexArray,E.x,E.y,0,0,1,1,0),_.push(E.x),_.push(E.y)}}}for(var L=Bi(_,w),C=0;C<L.length;C+=3)this.indexArray.emplaceBack(k+L[C],k+L[C+2],k+L[C+1]);u.primitiveLength+=L.length/3,u.vertexLength+=s}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},pn("FillExtrusionBucket",Fo,{omit:["layers","features"]});var jo={paint:new Hn({"fill-extrusion-opacity":new Nn(Tt["paint_fill-extrusion"]["fill-extrusion-opacity"]),"fill-extrusion-color":new jn(Tt["paint_fill-extrusion"]["fill-extrusion-color"]),"fill-extrusion-translate":new Nn(Tt["paint_fill-extrusion"]["fill-extrusion-translate"]),"fill-extrusion-translate-anchor":new Nn(Tt["paint_fill-extrusion"]["fill-extrusion-translate-anchor"]),"fill-extrusion-pattern":new Vn(Tt["paint_fill-extrusion"]["fill-extrusion-pattern"]),"fill-extrusion-height":new jn(Tt["paint_fill-extrusion"]["fill-extrusion-height"]),"fill-extrusion-base":new jn(Tt["paint_fill-extrusion"]["fill-extrusion-base"]),"fill-extrusion-vertical-gradient":new Nn(Tt["paint_fill-extrusion"]["fill-extrusion-vertical-gradient"])})},Vo=function(t){function e(e){t.call(this,e,jo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Fo(t)},e.prototype.queryRadius=function(){return mi(this.paint.get("fill-extrusion-translate"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,o,s,l){var c=yi(t,this.paint.get("fill-extrusion-translate"),this.paint.get("fill-extrusion-translate-anchor"),o.angle,s),u=this.paint.get("fill-extrusion-height").evaluate(e,r),h=this.paint.get("fill-extrusion-base").evaluate(e,r),f=function(t,e,r,n){for(var i=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];ki(c,c,e),i.push(new a(c[0]/c[3],c[1]/c[3]))}return i}(c,l),p=function(t,e,r,n){for(var i=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,v=t;g<v.length;g+=1){for(var m=[],y=[],x=0,b=v[g];x<b.length;x+=1){var _=b[x],w=_.x,k=_.y,T=n[0]*w+n[4]*k+n[12],A=n[1]*w+n[5]*k+n[13],M=n[2]*w+n[6]*k+n[14],S=n[3]*w+n[7]*k+n[15],E=M+c,L=S+u,C=T+h,P=A+f,O=M+p,z=S+d,I=new a((T+s)/L,(A+l)/L);I.z=E/L,m.push(I);var D=new a(C/z,P/z);D.z=O/z,y.push(D)}i.push(m),o.push(y)}return[i,o]}(n,h,u,l);return function(t,e,r){var n=1/0;si(r,e)&&(n=qo(r,e[0]));for(var a=0;a<e.length;a++)for(var i=e[a],o=t[a],s=0;s<i.length-1;s++){var l=i[s],c=i[s+1],u=o[s],h=[l,c,o[s+1],u,l];ii(r,h)&&(n=Math.min(n,qo(r,h)))}return n!==1/0&&n}(p[0],p[1],f)},e}(Gn);function Uo(t,e){return t.x*e.x+t.y*e.y}function qo(t,e){if(1===t.length){var r=e[0],n=e[1],a=e[3],i=t[0],o=n.sub(r),s=a.sub(r),l=i.sub(r),c=Uo(o,o),u=Uo(o,s),h=Uo(s,s),f=Uo(l,o),p=Uo(l,s),d=c*h-u*u,g=(h*f-u*p)/d,v=(c*p-u*f)/d,m=1-g-v;return r.z*m+n.z*g+a.z*v}for(var y=1/0,x=0,b=e;x<b.length;x+=1){var _=b[x];y=Math.min(y,_.z)}return y}var Ho=Zn([{name:"a_pos_normal",components:2,type:"Int16"},{name:"a_data",components:4,type:"Uint8"}],4).members,Go=zo.VectorTileFeature.types,Yo=Math.cos(Math.PI/180*37.5),Wo=Math.pow(2,14)/.5,Xo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new ta,this.indexArray=new pa,this.programConfigurations=new Ka(Ho,t.layers,t.zoom),this.segments=new Pa,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};Xo.prototype.populate=function(t,e){this.hasPattern=yo("line",this.layers,e);for(var r=this.layers[0].layout.get("line-sort-key"),n=[],a=0,i=t;a<i.length;a+=1){var o=i[a],s=o.feature,l=o.index,c=o.sourceLayerIndex;if(this.layers[0]._featureFilter(new Cn(this.zoom),s)){var u=ri(s),h=r?r.evaluate(s,{}):void 0,f={id:s.id,properties:s.properties,type:s.type,sourceLayerIndex:c,index:l,geometry:u,patterns:{},sortKey:h};n.push(f)}}r&&n.sort(function(t,e){return t.sortKey-e.sortKey});for(var p=0,d=n;p<d.length;p+=1){var g=d[p],v=g,m=v.geometry,y=v.index,x=v.sourceLayerIndex;if(this.hasPattern){var b=xo("line",this.layers,g,this.zoom,e);this.patternFeatures.push(b)}else this.addFeature(g,m,y,{});var _=t[y].feature;e.featureIndex.insert(_,m,y,x,this.index)}},Xo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Xo.prototype.addFeatures=function(t,e){for(var r=0,n=this.patternFeatures;r<n.length;r+=1){var a=n[r];this.addFeature(a,a.geometry,a.index,e)}},Xo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Xo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Xo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ho),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Xo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Xo.prototype.addFeature=function(t,e,r,n){for(var a=this.layers[0].layout,i=a.get("line-join").evaluate(t,{}),o=a.get("line-cap"),s=a.get("line-miter-limit"),l=a.get("line-round-limit"),c=0,u=e;c<u.length;c+=1){var h=u[c];this.addLine(h,t,i,o,s,l,r,n)}},Xo.prototype.addLine=function(t,e,r,n,a,i,o,s){if(this.distance=0,this.scaledDistance=0,this.totalDistance=0,e.properties&&e.properties.hasOwnProperty("mapbox_clip_start")&&e.properties.hasOwnProperty("mapbox_clip_end")){this.clipStart=+e.properties.mapbox_clip_start,this.clipEnd=+e.properties.mapbox_clip_end;for(var l=0;l<t.length-1;l++)this.totalDistance+=t[l].dist(t[l+1])}for(var c="Polygon"===Go[e.type],u=t.length;u>=2&&t[u-1].equals(t[u-2]);)u--;for(var h=0;h<u-1&&t[h].equals(t[h+1]);)h++;if(!(u<(c?3:2))){"bevel"===r&&(a=1.05);var f,p=ti/(512*this.overscaling)*15,d=this.segments.prepareSegment(10*u,this.layoutVertexArray,this.indexArray),g=void 0,v=void 0,m=void 0,y=void 0;this.e1=this.e2=-1,c&&(f=t[u-2],y=t[h].sub(f)._unit()._perp());for(var x=h;x<u;x++)if(!(v=c&&x===u-1?t[h+1]:t[x+1])||!t[x].equals(v)){y&&(m=y),f&&(g=f),f=t[x],y=v?v.sub(f)._unit()._perp():m;var b=(m=m||y).add(y);0===b.x&&0===b.y||b._unit();var _=m.x*y.x+m.y*y.y,w=b.x*y.x+b.y*y.y,k=0!==w?1/w:1/0,T=2*Math.sqrt(2-2*w),A=w<Yo&&g&&v,M=m.x*y.y-m.y*y.x>0;if(A&&x>h){var S=f.dist(g);if(S>2*p){var E=f.sub(f.sub(g)._mult(p/S)._round());this.updateDistance(g,E),this.addCurrentVertex(E,m,0,0,d),g=E}}var L=g&&v,C=L?r:c?"butt":n;if(L&&"round"===C&&(k<i?C="miter":k<=2&&(C="fakeround")),"miter"===C&&k>a&&(C="bevel"),"bevel"===C&&(k>2&&(C="flipbevel"),k<a&&(C="miter")),g&&this.updateDistance(g,f),"miter"===C)b._mult(k),this.addCurrentVertex(f,b,0,0,d);else if("flipbevel"===C){if(k>100)b=y.mult(-1);else{var P=k*m.add(y).mag()/m.sub(y).mag();b._perp()._mult(P*(M?-1:1))}this.addCurrentVertex(f,b,0,0,d),this.addCurrentVertex(f,b.mult(-1),0,0,d)}else if("bevel"===C||"fakeround"===C){var O=-Math.sqrt(k*k-1),z=M?O:0,I=M?0:O;if(g&&this.addCurrentVertex(f,m,z,I,d),"fakeround"===C)for(var D=Math.round(180*T/Math.PI/20),R=1;R<D;R++){var F=R/D;if(.5!==F){var B=F-.5;F+=F*B*(F-1)*((1.0904+_*(_*(3.55645-1.43519*_)-3.2452))*B*B+(.848013+_*(.215638*_-1.06021)))}var N=y.sub(m)._mult(F)._add(m)._unit()._mult(M?-1:1);this.addHalfVertex(f,N.x,N.y,!1,M,0,d)}v&&this.addCurrentVertex(f,y,-z,-I,d)}else if("butt"===C)this.addCurrentVertex(f,b,0,0,d);else if("square"===C){var j=g?1:-1;this.addCurrentVertex(f,b,j,j,d)}else"round"===C&&(g&&(this.addCurrentVertex(f,m,0,0,d),this.addCurrentVertex(f,m,1,1,d,!0)),v&&(this.addCurrentVertex(f,y,-1,-1,d,!0),this.addCurrentVertex(f,y,0,0,d)));if(A&&x<u-1){var V=f.dist(v);if(V>2*p){var U=f.add(v.sub(f)._mult(p/V)._round());this.updateDistance(f,U),this.addCurrentVertex(U,y,0,0,d),f=U}}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,e,o,s)}},Xo.prototype.addCurrentVertex=function(t,e,r,n,a,i){void 0===i&&(i=!1);var o=e.x+e.y*r,s=e.y-e.x*r,l=-e.x+e.y*n,c=-e.y-e.x*n;this.addHalfVertex(t,o,s,i,!1,r,a),this.addHalfVertex(t,l,c,i,!0,-n,a),this.distance>Wo/2&&0===this.totalDistance&&(this.distance=0,this.addCurrentVertex(t,e,r,n,a,i))},Xo.prototype.addHalfVertex=function(t,e,r,n,a,i,o){var s=t.x,l=t.y,c=.5*this.scaledDistance;this.layoutVertexArray.emplaceBack((s<<1)+(n?1:0),(l<<1)+(a?1:0),Math.round(63*e)+128,Math.round(63*r)+128,1+(0===i?0:i<0?-1:1)|(63&c)<<2,c>>6);var u=o.vertexLength++;this.e1>=0&&this.e2>=0&&(this.indexArray.emplaceBack(this.e1,this.e2,u),o.primitiveLength++),a?this.e2=u:this.e1=u},Xo.prototype.updateDistance=function(t,e){this.distance+=t.dist(e),this.scaledDistance=this.totalDistance>0?(this.clipStart+(this.clipEnd-this.clipStart)*this.distance/this.totalDistance)*(Wo-1):this.distance},pn("LineBucket",Xo,{omit:["layers","patternFeatures"]});var Zo=new Hn({"line-cap":new Nn(Tt.layout_line["line-cap"]),"line-join":new jn(Tt.layout_line["line-join"]),"line-miter-limit":new Nn(Tt.layout_line["line-miter-limit"]),"line-round-limit":new Nn(Tt.layout_line["line-round-limit"]),"line-sort-key":new jn(Tt.layout_line["line-sort-key"])}),Jo={paint:new Hn({"line-opacity":new jn(Tt.paint_line["line-opacity"]),"line-color":new jn(Tt.paint_line["line-color"]),"line-translate":new Nn(Tt.paint_line["line-translate"]),"line-translate-anchor":new Nn(Tt.paint_line["line-translate-anchor"]),"line-width":new jn(Tt.paint_line["line-width"]),"line-gap-width":new jn(Tt.paint_line["line-gap-width"]),"line-offset":new jn(Tt.paint_line["line-offset"]),"line-blur":new jn(Tt.paint_line["line-blur"]),"line-dasharray":new Un(Tt.paint_line["line-dasharray"]),"line-pattern":new Vn(Tt.paint_line["line-pattern"]),"line-gradient":new qn(Tt.paint_line["line-gradient"])}),layout:Zo},Ko=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Cn(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,a){return r=h({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,a)},e}(jn))(Jo.paint.properties["line-width"].specification);Ko.useIntegerZoom=!0;var Qo=function(t){function e(e){t.call(this,e,Jo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){"line-gradient"===t&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values["line-gradient"].value.expression;this.gradient=zi(t,"lineProgress"),this.gradientTexture=null},e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),this.paint._values["line-floorwidth"]=Ko.possiblyEvaluate(this._transitioningPaint._values["line-width"].value,e)},e.prototype.createBucket=function(t){return new Xo(t)},e.prototype.queryRadius=function(t){var e=t,r=$o(vi("line-width",this,e),vi("line-gap-width",this,e)),n=vi("line-offset",this,e);return r/2+Math.abs(n)+mi(this.paint.get("line-translate"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,o,s){var l=yi(t,this.paint.get("line-translate"),this.paint.get("line-translate-anchor"),o.angle,s),c=s/2*$o(this.paint.get("line-width").evaluate(e,r),this.paint.get("line-gap-width").evaluate(e,r)),u=this.paint.get("line-offset").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new a(0,0),i=0;i<t.length;i++){for(var o=t[i],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],h=o[l+1],f=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:h.sub(u)._unit()._perp(),d=f._add(p)._unit(),g=d.x*p.x+d.y*p.y;d._mult(1/g),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var a=e[n];if(t.length>=3)for(var i=0;i<a.length;i++)if(di(t,a[i]))return!0;if(li(t,a,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(Gn);function $o(t,e){return e>0?e+2*t:t}var ts=Zn([{name:"a_pos_offset",components:4,type:"Int16"},{name:"a_data",components:4,type:"Uint16"}]),es=Zn([{name:"a_projected_pos",components:3,type:"Float32"}],4),rs=(Zn([{name:"a_fade_opacity",components:1,type:"Uint32"}],4),Zn([{name:"a_placed",components:2,type:"Uint8"},{name:"a_shift",components:2,type:"Float32"}])),ns=(Zn([{type:"Int16",name:"anchorPointX"},{type:"Int16",name:"anchorPointY"},{type:"Int16",name:"x1"},{type:"Int16",name:"y1"},{type:"Int16",name:"x2"},{type:"Int16",name:"y2"},{type:"Uint32",name:"featureIndex"},{type:"Uint16",name:"sourceLayerIndex"},{type:"Uint16",name:"bucketIndex"},{type:"Int16",name:"radius"},{type:"Int16",name:"signedDistanceFromAnchor"}]),Zn([{name:"a_pos",components:2,type:"Int16"},{name:"a_anchor_pos",components:2,type:"Int16"},{name:"a_extrude",components:2,type:"Int16"}],4)),as=Zn([{name:"a_pos",components:2,type:"Int16"},{name:"a_anchor_pos",components:2,type:"Int16"},{name:"a_extrude",components:2,type:"Int16"}],4);function is(t,e,r){return t.sections.forEach(function(t){t.text=function(t,e,r){var n=e.layout.get("text-transform").evaluate(r,{});return"uppercase"===n?t=t.toLocaleUpperCase():"lowercase"===n&&(t=t.toLocaleLowerCase()),Ln.applyArabicShaping&&(t=Ln.applyArabicShaping(t)),t}(t.text,e,r)}),t}Zn([{type:"Int16",name:"anchorX"},{type:"Int16",name:"anchorY"},{type:"Uint16",name:"glyphStartIndex"},{type:"Uint16",name:"numGlyphs"},{type:"Uint32",name:"vertexStartIndex"},{type:"Uint32",name:"lineStartIndex"},{type:"Uint32",name:"lineLength"},{type:"Uint16",name:"segment"},{type:"Uint16",name:"lowerSize"},{type:"Uint16",name:"upperSize"},{type:"Float32",name:"lineOffsetX"},{type:"Float32",name:"lineOffsetY"},{type:"Uint8",name:"writingMode"},{type:"Uint8",name:"placedOrientation"},{type:"Uint8",name:"hidden"},{type:"Uint32",name:"crossTileID"}]),Zn([{type:"Int16",name:"anchorX"},{type:"Int16",name:"anchorY"},{type:"Int16",name:"rightJustifiedTextSymbolIndex"},{type:"Int16",name:"centerJustifiedTextSymbolIndex"},{type:"Int16",name:"leftJustifiedTextSymbolIndex"},{type:"Int16",name:"verticalPlacedTextSymbolIndex"},{type:"Uint16",name:"key"},{type:"Uint16",name:"textBoxStartIndex"},{type:"Uint16",name:"textBoxEndIndex"},{type:"Uint16",name:"verticalTextBoxStartIndex"},{type:"Uint16",name:"verticalTextBoxEndIndex"},{type:"Uint16",name:"iconBoxStartIndex"},{type:"Uint16",name:"iconBoxEndIndex"},{type:"Uint16",name:"featureIndex"},{type:"Uint16",name:"numHorizontalGlyphVertices"},{type:"Uint16",name:"numVerticalGlyphVertices"},{type:"Uint16",name:"numIconVertices"},{type:"Uint32",name:"crossTileID"},{type:"Float32",name:"textBoxScale"},{type:"Float32",name:"radialTextOffset"}]),Zn([{type:"Float32",name:"offsetX"}]),Zn([{type:"Int16",name:"x"},{type:"Int16",name:"y"},{type:"Int16",name:"tileUnitDistanceFromAnchor"}]);var os={"!":"\ufe15","#":"\uff03",$:"\uff04","%":"\uff05","&":"\uff06","(":"\ufe35",")":"\ufe36","*":"\uff0a","+":"\uff0b",",":"\ufe10","-":"\ufe32",".":"\u30fb","/":"\uff0f",":":"\ufe13",";":"\ufe14","<":"\ufe3f","=":"\uff1d",">":"\ufe40","?":"\ufe16","@":"\uff20","[":"\ufe47","\\":"\uff3c","]":"\ufe48","^":"\uff3e",_:"\ufe33","`":"\uff40","{":"\ufe37","|":"\u2015","}":"\ufe38","~":"\uff5e","\xa2":"\uffe0","\xa3":"\uffe1","\xa5":"\uffe5","\xa6":"\uffe4","\xac":"\uffe2","\xaf":"\uffe3","\u2013":"\ufe32","\u2014":"\ufe31","\u2018":"\ufe43","\u2019":"\ufe44","\u201c":"\ufe41","\u201d":"\ufe42","\u2026":"\ufe19","\u2027":"\u30fb","\u20a9":"\uffe6","\u3001":"\ufe11","\u3002":"\ufe12","\u3008":"\ufe3f","\u3009":"\ufe40","\u300a":"\ufe3d","\u300b":"\ufe3e","\u300c":"\ufe41","\u300d":"\ufe42","\u300e":"\ufe43","\u300f":"\ufe44","\u3010":"\ufe3b","\u3011":"\ufe3c","\u3014":"\ufe39","\u3015":"\ufe3a","\u3016":"\ufe17","\u3017":"\ufe18","\uff01":"\ufe15","\uff08":"\ufe35","\uff09":"\ufe36","\uff0c":"\ufe10","\uff0d":"\ufe32","\uff0e":"\u30fb","\uff1a":"\ufe13","\uff1b":"\ufe14","\uff1c":"\ufe3f","\uff1e":"\ufe40","\uff1f":"\ufe16","\uff3b":"\ufe47","\uff3d":"\ufe48","\uff3f":"\ufe33","\uff5b":"\ufe37","\uff5c":"\u2015","\uff5d":"\ufe38","\uff5f":"\ufe35","\uff60":"\ufe36","\uff61":"\ufe12","\uff62":"\ufe41","\uff63":"\ufe42"},ss=24,ls={horizontal:1,vertical:2,horizontalOnly:3},cs=function(){this.text="",this.sectionIndex=[],this.sections=[]};function us(t,e,r,n,a,i,o,s,l,c,u){var h,f=cs.fromFeature(t,r);c===ls.vertical&&f.verticalizePunctuation();var p=Ln.processBidirectionalText,d=Ln.processStyledBidirectionalText;if(p&&1===f.sections.length){h=[];for(var g=0,v=p(f.toString(),vs(f,s,n,e));g<v.length;g+=1){var m=v[g],y=new cs;y.text=m,y.sections=f.sections;for(var x=0;x<m.length;x++)y.sectionIndex.push(0);h.push(y)}}else if(d){h=[];for(var b=0,_=d(f.text,f.sectionIndex,vs(f,s,n,e));b<_.length;b+=1){var w=_[b],k=new cs;k.text=w[0],k.sectionIndex=w[1],k.sections=f.sections,h.push(k)}}else h=function(t,e){for(var r=[],n=t.text,a=0,i=0,o=e;i<o.length;i+=1){var s=o[i];r.push(t.substring(a,s)),a=s}return a<n.length&&r.push(t.substring(a,n.length)),r}(f,vs(f,s,n,e));var T=[],A={positionedGlyphs:T,text:f.toString(),top:l[1],bottom:l[1],left:l[0],right:l[0],writingMode:c,lineCount:h.length,yOffset:-17};return function(t,e,r,n,a,i,o,s,l){for(var c=0,u=t.yOffset,h=0,f=t.positionedGlyphs,p="right"===i?1:"left"===i?0:.5,d=0,g=r;d<g.length;d+=1){var v=g[d];v.trim();var m=v.getMaxScale();if(v.length()){for(var y=f.length,x=0;x<v.length();x++){var b=v.getSection(x),_=v.getSectionIndex(x),w=v.getCharCode(x),k=24*(m-b.scale),T=e[b.fontStack],A=T&&T[w];A&&(o===ls.horizontal||!l&&!_n(w)||l&&(hs[w]||(S=w,yn.Arabic(S)||yn["Arabic Supplement"](S)||yn["Arabic Extended-A"](S)||yn["Arabic Presentation Forms-A"](S)||yn["Arabic Presentation Forms-B"](S)))?(f.push({glyph:w,x:c,y:u+k,vertical:!1,scale:b.scale,fontStack:b.fontStack,sectionIndex:_}),c+=A.metrics.advance*b.scale+s):(f.push({glyph:w,x:c,y:u+k,vertical:!0,scale:b.scale,fontStack:b.fontStack,sectionIndex:_}),c+=ss*b.scale+s))}if(f.length!==y){var M=c-s;h=Math.max(M,h),ys(f,e,y,f.length-1,p)}c=0,u+=n*m}else u+=n}var S,E=ms(a),L=E.horizontalAlign,C=E.verticalAlign;!function(t,e,r,n,a,i,o){for(var s=(e-r)*a,l=(-n*o+.5)*i,c=0;c<t.length;c++)t[c].x+=s,t[c].y+=l}(f,p,L,C,h,n,r.length);var P=u-t.yOffset;t.top+=-C*P,t.bottom=t.top+P,t.left+=-L*h,t.right=t.left+h}(A,e,h,a,i,o,c,s,u),!!T.length&&A}cs.fromFeature=function(t,e){for(var r=new cs,n=0;n<t.sections.length;n++){var a=t.sections[n];r.sections.push({scale:a.scale||1,fontStack:a.fontStack||e}),r.text+=a.text;for(var i=0;i<a.text.length;i++)r.sectionIndex.push(n)}return r},cs.prototype.length=function(){return this.text.length},cs.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},cs.prototype.getSectionIndex=function(t){return this.sectionIndex[t]},cs.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},cs.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e="",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,a=t.charCodeAt(r-1)||null;n&&wn(n)&&!os[t[r+1]]||a&&wn(a)&&!os[t[r-1]]||!os[t[r]]?e+=t[r]:e+=os[t[r]]}return e}(this.text)},cs.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&hs[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&hs[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},cs.prototype.substring=function(t,e){var r=new cs;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},cs.prototype.toString=function(){return this.text},cs.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce(function(e,r){return Math.max(e,t.sections[r].scale)},0)};var hs={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},fs={};function ps(t,e,r,n){var a=Math.pow(t-e,2);return n?t<e?a/2:2*a:a+Math.abs(r)*r}function ds(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function gs(t,e,r,n,a,i){for(var o=null,s=ps(e,r,a,i),l=0,c=n;l<c.length;l+=1){var u=c[l],h=ps(e-u.x,r,a,i)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function vs(t,e,r,n){if(!r)return[];if(!t)return[];for(var a,i=[],o=function(t,e,r,n){for(var a=0,i=0;i<t.length();i++){var o=t.getSection(i),s=n[o.fontStack],l=s&&s[t.getCharCode(i)];l&&(a+=l.metrics.advance*o.scale+e)}return a/Math.max(1,Math.ceil(a/r))}(t,e,r,n),s=t.text.indexOf("\u200b")>=0,l=0,c=0;c<t.length();c++){var u=t.getSection(c),h=t.getCharCode(c),f=n[u.fontStack],p=f&&f[h];if(p&&!hs[h]&&(l+=p.metrics.advance*u.scale+e),c<t.length()-1){var d=!((a=h)<11904||!(yn["Bopomofo Extended"](a)||yn.Bopomofo(a)||yn["CJK Compatibility Forms"](a)||yn["CJK Compatibility Ideographs"](a)||yn["CJK Compatibility"](a)||yn["CJK Radicals Supplement"](a)||yn["CJK Strokes"](a)||yn["CJK Symbols and Punctuation"](a)||yn["CJK Unified Ideographs Extension A"](a)||yn["CJK Unified Ideographs"](a)||yn["Enclosed CJK Letters and Months"](a)||yn["Halfwidth and Fullwidth Forms"](a)||yn.Hiragana(a)||yn["Ideographic Description Characters"](a)||yn["Kangxi Radicals"](a)||yn["Katakana Phonetic Extensions"](a)||yn.Katakana(a)||yn["Vertical Forms"](a)||yn["Yi Radicals"](a)||yn["Yi Syllables"](a)));(fs[h]||d)&&i.push(gs(c+1,l,o,i,ds(h,t.getCharCode(c+1),d&&s),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(gs(t.length(),l,o,i,0,!0))}function ms(t){var e=.5,r=.5;switch(t){case"right":case"top-right":case"bottom-right":e=1;break;case"left":case"top-left":case"bottom-left":e=0}switch(t){case"bottom":case"bottom-right":case"bottom-left":r=1;break;case"top":case"top-right":case"top-left":r=0}return{horizontalAlign:e,verticalAlign:r}}function ys(t,e,r,n,a){if(a){var i=t[n],o=e[i.fontStack],s=o&&o[i.glyph];if(s)for(var l=s.metrics.advance*i.scale,c=(t[n].x+l)*a,u=r;u<=n;u++)t[u].x-=c}}fs[10]=!0,fs[32]=!0,fs[38]=!0,fs[40]=!0,fs[41]=!0,fs[43]=!0,fs[45]=!0,fs[47]=!0,fs[173]=!0,fs[183]=!0,fs[8203]=!0,fs[8208]=!0,fs[8211]=!0,fs[8231]=!0;var xs=function(t){function e(e,r,n,a){t.call(this,e,r),this.angle=n,void 0!==a&&(this.segment=a)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(a);pn("Anchor",xs);var bs=256;function _s(t,e){var r=e.expression;if("constant"===r.kind)return{kind:"constant",layoutSize:r.evaluate(new Cn(t+1))};if("source"===r.kind)return{kind:"source"};for(var n=r.zoomStops,a=r.interpolationType,i=0;i<n.length&&n[i]<=t;)i++;for(var o=i=Math.max(0,i-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[i],l=n[o];return"composite"===r.kind?{kind:"composite",minZoom:s,maxZoom:l,interpolationType:a}:{kind:"camera",minZoom:s,maxZoom:l,minSize:r.evaluate(new Cn(s)),maxSize:r.evaluate(new Cn(l)),interpolationType:a}}function ws(t,e,r){var n=e.uSize,a=e.uSizeT,i=r.lowerSize,o=r.upperSize;return"source"===t.kind?i/bs:"composite"===t.kind?ye(i/bs,o/bs,a):n}function ks(t,e){var r=0,n=0;if("constant"===t.kind)n=t.layoutSize;else if("source"!==t.kind){var a=t.interpolationType,i=t.minZoom,o=t.maxZoom,s=a?c(Be.interpolationFactor(a,e,i,o),0,1):0;"camera"===t.kind?n=ye(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var Ts=Object.freeze({getSizeData:_s,evaluateSizeForFeature:ws,evaluateSizeForZoom:ks,SIZE_PACK_FACTOR:bs}),As=zo.VectorTileFeature.types,Ms=[{name:"a_fade_opacity",components:1,type:"Uint8",offset:0}];function Ss(t,e,r,n,a,i,o,s){t.emplaceBack(e,r,Math.round(32*n),Math.round(32*a),i,o,s?s[0]:0,s?s[1]:0)}function Es(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}var Ls=function(t){this.layoutVertexArray=new ra,this.indexArray=new pa,this.programConfigurations=t,this.segments=new Pa,this.dynamicLayoutVertexArray=new na,this.opacityVertexArray=new aa,this.placedSymbolArray=new _a};Ls.prototype.upload=function(t,e,r,n){r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ts.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,es.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,Ms,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t)},Ls.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},pn("SymbolBuffers",Ls);var Cs=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Pa,this.collisionVertexArray=new sa};Cs.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,rs.members,!0)},Cs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},pn("CollisionBuffers",Cs);var Ps=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1,this.hasPaintOverrides=!1;var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=_s(this.zoom,e["text-size"]),this.iconSizeData=_s(this.zoom,e["icon-size"]);var r=this.layers[0].layout,n=r.get("symbol-sort-key"),a=r.get("symbol-z-order");this.sortFeaturesByKey="viewport-y"!==a&&void 0!==n.constantOr(1);var i="viewport-y"===a||"auto"===a&&!this.sortFeaturesByKey;this.sortFeaturesByY=i&&(r.get("text-allow-overlap")||r.get("icon-allow-overlap")||r.get("text-ignore-placement")||r.get("icon-ignore-placement")),"point"===r.get("symbol-placement")&&(this.writingModes=r.get("text-writing-mode").map(function(t){return ls[t]})),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id}),this.sourceID=t.sourceID};Ps.prototype.createArrays=function(){var t=this.layers[0].layout;this.hasPaintOverrides=Ds.hasPaintOverrides(t),this.text=new Ls(new Ka(ts.members,this.layers,this.zoom,function(t){return/^text/.test(t)})),this.icon=new Ls(new Ka(ts.members,this.layers,this.zoom,function(t){return/^icon/.test(t)})),this.collisionBox=new Cs(oa,ns.members,da),this.collisionCircle=new Cs(oa,as.members,pa),this.glyphOffsetArray=new Aa,this.lineVertexArray=new Sa,this.symbolInstances=new ka},Ps.prototype.calculateGlyphDependencies=function(t,e,r,n,a){for(var i=0;i<t.length;i++)if(e[t.charCodeAt(i)]=!0,(r||n)&&a){var o=os[t.charAt(i)];o&&(e[o.charCodeAt(0)]=!0)}},Ps.prototype.populate=function(t,e){var r=this.layers[0],n=r.layout,a=n.get("text-font"),i=n.get("text-field"),o=n.get("icon-image"),s=("constant"!==i.value.kind||i.value.value.toString().length>0)&&("constant"!==a.value.kind||a.value.value.length>0),l="constant"!==o.value.kind||o.value.value&&o.value.value.length>0,c=n.get("symbol-sort-key");if(this.features=[],s||l){for(var u=e.iconDependencies,h=e.glyphDependencies,f=new Cn(this.zoom),p=0,d=t;p<d.length;p+=1){var g=d[p],v=g.feature,m=g.index,y=g.sourceLayerIndex;if(r._featureFilter(f,v)){var x=void 0;if(s){var b=r.getValueAndResolveTokens("text-field",v);x=is(b instanceof Jt?b:Jt.fromString(b),r,v)}var _=void 0;if(l&&(_=r.getValueAndResolveTokens("icon-image",v)),x||_){var w=this.sortFeaturesByKey?c.evaluate(v,{}):void 0,k={text:x,icon:_,index:m,sourceLayerIndex:y,geometry:ri(v),properties:v.properties,type:As[v.type],sortKey:w};if(void 0!==v.id&&(k.id=v.id),this.features.push(k),_&&(u[_]=!0),x){var T=a.evaluate(v,{}).join(","),A="map"===n.get("text-rotation-alignment")&&"point"!==n.get("symbol-placement");this.allowVerticalPlacement=this.writingModes&&this.writingModes.indexOf(ls.vertical)>=0;for(var M=0,S=x.sections;M<S.length;M+=1){var E=S[M],L=xn(x.toString()),C=E.fontStack||T,P=h[C]=h[C]||{};this.calculateGlyphDependencies(E.text,P,A,this.allowVerticalPlacement,L)}}}}}"line"===n.get("symbol-placement")&&(this.features=function(t){var e={},r={},n=[],a=0;function i(e){n.push(t[e]),a++}function o(t,e,a){var i=r[t];return delete r[t],r[e]=i,n[i].geometry[0].pop(),n[i].geometry[0]=n[i].geometry[0].concat(a[0]),i}function s(t,r,a){var i=e[r];return delete e[r],e[t]=i,n[i].geometry[0].shift(),n[i].geometry[0]=a[0].concat(n[i].geometry[0]),i}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+":"+n.x+":"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,h),v=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(f,n[v].geometry,!0)]=v,n[g].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(i(c),e[p]=a-1,r[d]=a-1)}else i(c)}return n.filter(function(t){return t.geometry})}(this.features)),this.sortFeaturesByKey&&this.features.sort(function(t,e){return t.sortKey-e.sortKey})}},Ps.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},Ps.prototype.isEmpty=function(){return 0===this.symbolInstances.length},Ps.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},Ps.prototype.upload=function(t){this.uploaded||(this.collisionBox.upload(t),this.collisionCircle.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},Ps.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.collisionBox.destroy(),this.collisionCircle.destroy()},Ps.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),a=t.dist(e[t.segment]),i={},o=t.segment+1;o<e.length;o++)i[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)i[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:a},s>0&&(a+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=i[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Ps.prototype.addSymbols=function(t,e,r,n,a,i,o,s,l,c){var u=this,h=t.indexArray,f=t.layoutVertexArray,p=t.dynamicLayoutVertexArray,d=t.segments.prepareSegment(4*e.length,t.layoutVertexArray,t.indexArray,i.sortKey),g=this.glyphOffsetArray.length,v=d.vertexLength,m=this.allowVerticalPlacement&&o===ls.vertical?Math.PI/2:0,y=function(t){var e=t.tl,n=t.tr,a=t.bl,i=t.br,o=t.tex,l=d.vertexLength,c=t.glyphOffset[1];Ss(f,s.x,s.y,e.x,c+e.y,o.x,o.y,r),Ss(f,s.x,s.y,n.x,c+n.y,o.x+o.w,o.y,r),Ss(f,s.x,s.y,a.x,c+a.y,o.x,o.y+o.h,r),Ss(f,s.x,s.y,i.x,c+i.y,o.x+o.w,o.y+o.h,r),Es(p,s,m),h.emplaceBack(l,l+1,l+2),h.emplaceBack(l+1,l+2,l+3),d.vertexLength+=4,d.primitiveLength+=2,u.glyphOffsetArray.emplaceBack(t.glyphOffset[0])};if(i.text&&i.text.sections){var x=i.text.sections;if(this.hasPaintOverrides){for(var b,_=function(e,r){void 0===b||b===e&&!r||t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,i,i.index,{},x[b]),b=e},w=0,k=e;w<k.length;w+=1){var T=k[w];_(T.sectionIndex,!1),y(T)}_(b,!0)}else{for(var A=0,M=e;A<M.length;A+=1)y(M[A]);t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,i,i.index,{},x[0])}}else{for(var S=0,E=e;S<E.length;S+=1)y(E[S]);t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,i,i.index,{})}t.placedSymbolArray.emplaceBack(s.x,s.y,g,this.glyphOffsetArray.length-g,v,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,0,!1,0)},Ps.prototype._addCollisionDebugVertex=function(t,e,r,n,a,i){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,a,Math.round(i.x),Math.round(i.y))},Ps.prototype.addCollisionDebugVertices=function(t,e,r,n,i,o,s,l){var c=i.segments.prepareSegment(4,i.layoutVertexArray,i.indexArray),u=c.vertexLength,h=i.layoutVertexArray,f=i.collisionVertexArray,p=s.anchorX,d=s.anchorY;if(this._addCollisionDebugVertex(h,f,o,p,d,new a(t,e)),this._addCollisionDebugVertex(h,f,o,p,d,new a(r,e)),this._addCollisionDebugVertex(h,f,o,p,d,new a(r,n)),this._addCollisionDebugVertex(h,f,o,p,d,new a(t,n)),c.vertexLength+=4,l){var g=i.indexArray;g.emplaceBack(u,u+1,u+2),g.emplaceBack(u,u+2,u+3),c.primitiveLength+=2}else{var v=i.indexArray;v.emplaceBack(u,u+1),v.emplaceBack(u+1,u+2),v.emplaceBack(u+2,u+3),v.emplaceBack(u+3,u),c.primitiveLength+=4}},Ps.prototype.addDebugCollisionBoxes=function(t,e,r){for(var n=t;n<e;n++){var a=this.collisionBoxArray.get(n),i=a.x1,o=a.y1,s=a.x2,l=a.y2,c=a.radius>0;this.addCollisionDebugVertices(i,o,s,l,c?this.collisionCircle:this.collisionBox,a.anchorPoint,r,c)}},Ps.prototype.generateCollisionDebugBuffers=function(){for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e),this.addDebugCollisionBoxes(e.verticalTextBoxStartIndex,e.verticalTextBoxEndIndex,e),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e)}},Ps.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,a,i,o){for(var s={},l=e;l<r;l++){var c=t.get(l);if(0===c.radius){s.textBox={x1:c.x1,y1:c.y1,x2:c.x2,y2:c.y2,anchorPointX:c.anchorPointX,anchorPointY:c.anchorPointY},s.textFeatureIndex=c.featureIndex;break}s.textCircles||(s.textCircles=[],s.textFeatureIndex=c.featureIndex),s.textCircles.push(c.anchorPointX,c.anchorPointY,c.radius,c.signedDistanceFromAnchor,1)}for(var u=n;u<a;u++){var h=t.get(u);if(0===h.radius){s.verticalTextBox={x1:h.x1,y1:h.y1,x2:h.x2,y2:h.y2,anchorPointX:h.anchorPointX,anchorPointY:h.anchorPointY},s.verticalTextFeatureIndex=h.featureIndex;break}}for(var f=i;f<o;f++){var p=t.get(f);if(0===p.radius){s.iconBox={x1:p.x1,y1:p.y1,x2:p.x2,y2:p.y2,anchorPointX:p.anchorPointX,anchorPointY:p.anchorPointY},s.iconFeatureIndex=p.featureIndex;break}}return s},Ps.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.verticalTextBoxStartIndex,r.verticalTextBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex))}},Ps.prototype.hasTextData=function(){return this.text.segments.get().length>0},Ps.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Ps.prototype.hasCollisionBoxData=function(){return this.collisionBox.segments.get().length>0},Ps.prototype.hasCollisionCircleData=function(){return this.collisionCircle.segments.get().length>0},Ps.prototype.addIndicesForPlacedTextSymbol=function(t){for(var e=this.text.placedSymbolArray.get(t),r=e.vertexStartIndex+4*e.numGlyphs,n=e.vertexStartIndex;n<r;n+=4)this.text.indexArray.emplaceBack(n,n+1,n+2),this.text.indexArray.emplaceBack(n+1,n+2,n+3)},Ps.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],a=[],i=[],o=0;o<this.symbolInstances.length;++o){i.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),a.push(s.featureIndex)}return i.sort(function(t,e){return n[t]-n[e]||a[e]-a[t]}),i},Ps.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var a=n[r],i=this.symbolInstances.get(a);this.featureSortOrder.push(i.featureIndex),[i.rightJustifiedTextSymbolIndex,i.centerJustifiedTextSymbolIndex,i.leftJustifiedTextSymbolIndex].forEach(function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedTextSymbol(t)}),i.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedTextSymbol(i.verticalPlacedTextSymbolIndex);var o=this.icon.placedSymbolArray.get(a);if(o.numGlyphs){var s=o.vertexStartIndex;this.icon.indexArray.emplaceBack(s,s+1,s+2),this.icon.indexArray.emplaceBack(s+1,s+2,s+3)}}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},pn("SymbolBucket",Ps,{omit:["layers","collisionBoxArray","features","compareText"]}),Ps.MAX_GLYPHS=65535,Ps.addDynamicAttributes=Es;var Os=new Hn({"symbol-placement":new Nn(Tt.layout_symbol["symbol-placement"]),"symbol-spacing":new Nn(Tt.layout_symbol["symbol-spacing"]),"symbol-avoid-edges":new Nn(Tt.layout_symbol["symbol-avoid-edges"]),"symbol-sort-key":new jn(Tt.layout_symbol["symbol-sort-key"]),"symbol-z-order":new Nn(Tt.layout_symbol["symbol-z-order"]),"icon-allow-overlap":new Nn(Tt.layout_symbol["icon-allow-overlap"]),"icon-ignore-placement":new Nn(Tt.layout_symbol["icon-ignore-placement"]),"icon-optional":new Nn(Tt.layout_symbol["icon-optional"]),"icon-rotation-alignment":new Nn(Tt.layout_symbol["icon-rotation-alignment"]),"icon-size":new jn(Tt.layout_symbol["icon-size"]),"icon-text-fit":new Nn(Tt.layout_symbol["icon-text-fit"]),"icon-text-fit-padding":new Nn(Tt.layout_symbol["icon-text-fit-padding"]),"icon-image":new jn(Tt.layout_symbol["icon-image"]),"icon-rotate":new jn(Tt.layout_symbol["icon-rotate"]),"icon-padding":new Nn(Tt.layout_symbol["icon-padding"]),"icon-keep-upright":new Nn(Tt.layout_symbol["icon-keep-upright"]),"icon-offset":new jn(Tt.layout_symbol["icon-offset"]),"icon-anchor":new jn(Tt.layout_symbol["icon-anchor"]),"icon-pitch-alignment":new Nn(Tt.layout_symbol["icon-pitch-alignment"]),"text-pitch-alignment":new Nn(Tt.layout_symbol["text-pitch-alignment"]),"text-rotation-alignment":new Nn(Tt.layout_symbol["text-rotation-alignment"]),"text-field":new jn(Tt.layout_symbol["text-field"]),"text-font":new jn(Tt.layout_symbol["text-font"]),"text-size":new jn(Tt.layout_symbol["text-size"]),"text-max-width":new jn(Tt.layout_symbol["text-max-width"]),"text-line-height":new Nn(Tt.layout_symbol["text-line-height"]),"text-letter-spacing":new jn(Tt.layout_symbol["text-letter-spacing"]),"text-justify":new jn(Tt.layout_symbol["text-justify"]),"text-radial-offset":new jn(Tt.layout_symbol["text-radial-offset"]),"text-variable-anchor":new Nn(Tt.layout_symbol["text-variable-anchor"]),"text-anchor":new jn(Tt.layout_symbol["text-anchor"]),"text-max-angle":new Nn(Tt.layout_symbol["text-max-angle"]),"text-writing-mode":new Nn(Tt.layout_symbol["text-writing-mode"]),"text-rotate":new jn(Tt.layout_symbol["text-rotate"]),"text-padding":new Nn(Tt.layout_symbol["text-padding"]),"text-keep-upright":new Nn(Tt.layout_symbol["text-keep-upright"]),"text-transform":new jn(Tt.layout_symbol["text-transform"]),"text-offset":new jn(Tt.layout_symbol["text-offset"]),"text-allow-overlap":new Nn(Tt.layout_symbol["text-allow-overlap"]),"text-ignore-placement":new Nn(Tt.layout_symbol["text-ignore-placement"]),"text-optional":new Nn(Tt.layout_symbol["text-optional"])}),zs={paint:new Hn({"icon-opacity":new jn(Tt.paint_symbol["icon-opacity"]),"icon-color":new jn(Tt.paint_symbol["icon-color"]),"icon-halo-color":new jn(Tt.paint_symbol["icon-halo-color"]),"icon-halo-width":new jn(Tt.paint_symbol["icon-halo-width"]),"icon-halo-blur":new jn(Tt.paint_symbol["icon-halo-blur"]),"icon-translate":new Nn(Tt.paint_symbol["icon-translate"]),"icon-translate-anchor":new Nn(Tt.paint_symbol["icon-translate-anchor"]),"text-opacity":new jn(Tt.paint_symbol["text-opacity"]),"text-color":new jn(Tt.paint_symbol["text-color"],{runtimeType:Ft,getOverride:function(t){return t.textColor},hasOverride:function(t){return!!t.textColor}}),"text-halo-color":new jn(Tt.paint_symbol["text-halo-color"]),"text-halo-width":new jn(Tt.paint_symbol["text-halo-width"]),"text-halo-blur":new jn(Tt.paint_symbol["text-halo-blur"]),"text-translate":new Nn(Tt.paint_symbol["text-translate"]),"text-translate-anchor":new Nn(Tt.paint_symbol["text-translate-anchor"])}),layout:Os},Is=function(t){this.type=t.property.overrides?t.property.overrides.runtimeType:zt,this.defaultValue=t};Is.prototype.evaluate=function(t){if(t.formattedSection){var e=this.defaultValue.property.overrides;if(e&&e.hasOverride(t.formattedSection))return e.getOverride(t.formattedSection)}return t.feature&&t.featureState?this.defaultValue.evaluate(t.feature,t.featureState):this.defaultValue.property.specification.default},Is.prototype.eachChild=function(t){this.defaultValue.isConstant()||t(this.defaultValue.value._styleExpression.expression)},Is.prototype.possibleOutputs=function(){return[void 0]},Is.prototype.serialize=function(){return null},pn("FormatSectionOverride",Is,{omit:["defaultValue"]});var Ds=function(t){function e(e){t.call(this,e,zs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){if(t.prototype.recalculate.call(this,e),"auto"===this.layout.get("icon-rotation-alignment")&&("point"!==this.layout.get("symbol-placement")?this.layout._values["icon-rotation-alignment"]="map":this.layout._values["icon-rotation-alignment"]="viewport"),"auto"===this.layout.get("text-rotation-alignment")&&("point"!==this.layout.get("symbol-placement")?this.layout._values["text-rotation-alignment"]="map":this.layout._values["text-rotation-alignment"]="viewport"),"auto"===this.layout.get("text-pitch-alignment")&&(this.layout._values["text-pitch-alignment"]=this.layout.get("text-rotation-alignment")),"auto"===this.layout.get("icon-pitch-alignment")&&(this.layout._values["icon-pitch-alignment"]=this.layout.get("icon-rotation-alignment")),"point"===this.layout.get("symbol-placement")){var r=this.layout.get("text-writing-mode");if(r){for(var n=[],a=0,i=r;a<i.length;a+=1){var o=i[a];n.indexOf(o)<0&&n.push(o)}this.layout._values["text-writing-mode"]=n}else this.layout._values["text-writing-mode"]=["horizontal"]}this._setPaintOverrides()},e.prototype.getValueAndResolveTokens=function(t,e){var r=this.layout.get(t).evaluate(e,{}),n=this._unevaluatedLayout._values[t];return n.isDataDriven()||_r(n.value)?r:function(t,e){return r.replace(/{([^{}]+)}/g,function(e,r){return r in t?String(t[r]):""})}(e.properties)},e.prototype.createBucket=function(t){return new Ps(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype._setPaintOverrides=function(){for(var t=0,r=zs.paint.overridableProperties;t<r.length;t+=1){var n=r[t];if(e.hasPaintOverride(this.layout,n)){var a,i=this.paint.get(n),o=new Is(i),s=new br(o,i.property.specification);a="constant"===i.value.kind||"source"===i.value.kind?new kr("source",s):new Tr("composite",s,i.value.zoomStops,i.value._interpolationType),this.paint._values[n]=new Fn(i.property,a,i.parameters)}}},e.prototype._handleOverridablePaintPropertyUpdate=function(t,r,n){return!(!this.layout||r.isDataDriven()||n.isDataDriven())&&e.hasPaintOverride(this.layout,t)},e.hasPaintOverride=function(t,e){var r=t.get("text-field"),n=zs.paint.properties[e],a=!1,i=function(t){for(var e=0,r=t;e<r.length;e+=1){var i=r[e];if(n.overrides&&n.overrides.hasOverride(i))return void(a=!0)}};if("constant"===r.value.kind&&r.value.value instanceof Jt)i(r.value.value.sections);else if("source"===r.value.kind){var o=function(t){if(!a)if(t instanceof te&&Qt(t.value)===Vt){var e=t.value;i(e.sections)}else t instanceof ae?i(t.sections):t.eachChild(o)},s=r.value;s._styleExpression&&o(s._styleExpression.expression)}return a},e.hasPaintOverrides=function(t){for(var r=0,n=zs.paint.overridableProperties;r<n.length;r+=1){var a=n[r];if(e.hasPaintOverride(t,a))return!0}return!1},e}(Gn),Rs={paint:new Hn({"background-color":new Nn(Tt.paint_background["background-color"]),"background-pattern":new Un(Tt.paint_background["background-pattern"]),"background-opacity":new Nn(Tt.paint_background["background-opacity"])})},Fs=function(t){function e(e){t.call(this,e,Rs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Gn),Bs={paint:new Hn({"raster-opacity":new Nn(Tt.paint_raster["raster-opacity"]),"raster-hue-rotate":new Nn(Tt.paint_raster["raster-hue-rotate"]),"raster-brightness-min":new Nn(Tt.paint_raster["raster-brightness-min"]),"raster-brightness-max":new Nn(Tt.paint_raster["raster-brightness-max"]),"raster-saturation":new Nn(Tt.paint_raster["raster-saturation"]),"raster-contrast":new Nn(Tt.paint_raster["raster-contrast"]),"raster-resampling":new Nn(Tt.paint_raster["raster-resampling"]),"raster-fade-duration":new Nn(Tt.paint_raster["raster-fade-duration"])})},Ns=function(t){function e(e){t.call(this,e,Bs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Gn),js=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return"3d"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(Gn),Vs={circle:Ti,heatmap:Ii,hillshade:Ri,fill:ko,"fill-extrusion":Vo,line:Qo,symbol:Ds,background:Fs,raster:Ns};function Us(t){for(var e=0,r=0,n=0,a=t;n<a.length;n+=1){var i=a[n];e+=i.w*i.h,r=Math.max(r,i.w)}t.sort(function(t,e){return e.h-t.h});for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var qs=function(t,e){var r=e.pixelRatio,n=e.version;this.paddedRect=t,this.pixelRatio=r,this.version=n},Hs={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};Hs.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},Hs.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},Hs.tlbr.get=function(){return this.tl.concat(this.br)},Hs.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(qs.prototype,Hs);var Gs=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var a=[];this.addImages(t,r,a),this.addImages(e,n,a);var i=Us(a),o=i.w,s=i.h,l=new Pi({width:o||1,height:s||1});for(var c in t){var u=t[c],h=r[c].paddedRect;Pi.copy(u.data,l,{x:0,y:0},{x:h.x+1,y:h.y+1},u.data)}for(var f in e){var p=e[f],d=n[f].paddedRect,g=d.x+1,v=d.y+1,m=p.data.width,y=p.data.height;Pi.copy(p.data,l,{x:0,y:0},{x:g,y:v},p.data),Pi.copy(p.data,l,{x:0,y:y-1},{x:g,y:v-1},{width:m,height:1}),Pi.copy(p.data,l,{x:0,y:0},{x:g,y:v+y},{width:m,height:1}),Pi.copy(p.data,l,{x:m-1,y:0},{x:g-1,y:v},{width:1,height:y}),Pi.copy(p.data,l,{x:0,y:0},{x:g+m,y:v},{width:1,height:y})}this.image=l,this.iconPositions=r,this.patternPositions=n};Gs.prototype.addImages=function(t,e,r){for(var n in t){var a=t[n],i={x:0,y:0,w:a.data.width+2,h:a.data.height+2};r.push(i),e[n]=new qs(i,a),a.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},Gs.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},Gs.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,a=n[0],i=n[1];r.update(e.data,void 0,{x:a,y:i})}},pn("ImagePosition",qs),pn("ImageAtlas",Gs);var Ys=self.HTMLImageElement,Ws=self.HTMLCanvasElement,Xs=self.HTMLVideoElement,Zs=self.ImageData,Js=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Js.prototype.update=function(t,e,r){var n=t.width,a=t.height,i=!(this.size&&this.size[0]===n&&this.size[1]===a||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),i)this.size=[n,a],t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,a,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,a,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Js.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Js.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Js.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ks=function(t,e,r,n,a){var i,o,s=8*a-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?a-1:0,f=r?-1:1,p=t[e+h];for(h+=f,i=p&(1<<-u)-1,p>>=-u,u+=s;u>0;i=256*i+t[e+h],h+=f,u-=8);for(o=i&(1<<-u)-1,i>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===i)i=1-c;else{if(i===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),i-=c}return(p?-1:1)*o*Math.pow(2,i-n)},Qs=function(t,e,r,n,a,i){var o,s,l,c=8*i-a-1,u=(1<<c)-1,h=u>>1,f=23===a?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:i-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,a),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,a),o=0));a>=8;t[r+p]=255&s,p+=d,s/=256,a-=8);for(o=o<<a|s,c+=a;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},$s=tl;function tl(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}function el(t){return t.type===tl.Bytes?t.readVarint()+t.pos:t.pos+1}function rl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function nl(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var a=r.pos-1;a>=t;a--)r.buf[a+n]=r.buf[a]}function al(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function il(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function ol(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function sl(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function ll(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function cl(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function ul(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function hl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function fl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function pl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function dl(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function gl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}tl.Varint=0,tl.Fixed64=1,tl.Bytes=2,tl.Fixed32=5,tl.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),a=n>>3,i=this.pos;this.type=7&n,t(a,e,this),this.pos===i&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=pl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=gl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*pl(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*gl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Ks(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Ks(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,a,i=r.buf;if(n=(112&(a=i[r.pos++]))>>4,a<128)return rl(t,n,e);if(n|=(127&(a=i[r.pos++]))<<3,a<128)return rl(t,n,e);if(n|=(127&(a=i[r.pos++]))<<10,a<128)return rl(t,n,e);if(n|=(127&(a=i[r.pos++]))<<17,a<128)return rl(t,n,e);if(n|=(127&(a=i[r.pos++]))<<24,a<128)return rl(t,n,e);if(n|=(1&(a=i[r.pos++]))<<31,a<128)return rl(t,n,e);throw new Error("Expected varint not more than 10 bytes")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=function(t,e,r){for(var n="",a=e;a<r;){var i,o,s,l=t[a],c=null,u=l>239?4:l>223?3:l>191?2:1;if(a+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(i=t[a+1]))&&(c=(31&l)<<6|63&i)<=127&&(c=null):3===u?(i=t[a+1],o=t[a+2],128==(192&i)&&128==(192&o)&&((c=(15&l)<<12|(63&i)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(i=t[a+1],o=t[a+2],s=t[a+3],128==(192&i)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&i)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),a+=u}return n}(this.buf,this.pos,t);return this.pos=t,e},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==tl.Bytes)return t.push(this.readVarint(e));var r=el(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==tl.Bytes)return t.push(this.readSVarint());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==tl.Bytes)return t.push(this.readBoolean());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==tl.Bytes)return t.push(this.readFloat());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==tl.Bytes)return t.push(this.readDouble());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===tl.Varint)for(;this.buf[this.pos++]>127;);else if(e===tl.Bytes)this.pos=this.readVarint()+this.pos;else if(e===tl.Fixed32)this.pos+=4;else{if(e!==tl.Fixed64)throw new Error("Unimplemented type: "+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error("Given varint doesn't fit into 10 bytes");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,a,i=0;i<e.length;i++){if((n=e.charCodeAt(i))>55295&&n<57344){if(!a){n>56319||i+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):a=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,a=n;continue}n=a-55296<<10|n-56320|65536,a=null}else a&&(t[r++]=239,t[r++]=191,t[r++]=189,a=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&nl(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),Qs(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),Qs(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&nl(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,tl.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,al,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,il,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,ll,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,ol,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,sl,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,cl,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,ul,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,hl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,fl,e)},writeBytesField:function(t,e){this.writeTag(t,tl.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,tl.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,tl.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var vl=3;function ml(t,e,r){1===t&&r.readMessage(yl,e)}function yl(t,e,r){if(3===t){var n=r.readMessage(xl,{}),a=n.id,i=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:a,bitmap:new Ci({width:o+2*vl,height:s+2*vl},i),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function xl(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var bl=vl,_l=function(t){var e=this;this._callback=t,this._triggered=!1,"undefined"!=typeof MessageChannel&&(this._channel=new MessageChannel,this._channel.port2.onmessage=function(){e._triggered=!1,e._callback()})};_l.prototype.trigger=function(){var t=this;this._triggered||(this._triggered=!0,this._channel?this._channel.port1.postMessage(!0):setTimeout(function(){t._triggered=!1,t._callback()},0))};var wl=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.tasks={},this.taskQueue=[],this.cancelCallbacks={},v(["receive","process"],this),this.invoker=new _l(this.process),this.target.addEventListener("message",this.receive,!1)};function kl(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}wl.prototype.send=function(t,e,r,n){var a=this,i=Math.round(1e18*Math.random()).toString(36).substring(0,10);r&&(this.callbacks[i]=r);var o=[];return this.target.postMessage({id:i,type:t,hasCallback:!!r,targetMapId:n,sourceMapId:this.mapId,data:gn(e,o)},o),{cancel:function(){r&&delete a.callbacks[i],a.target.postMessage({id:i,type:"<cancel>",targetMapId:n,sourceMapId:a.mapId})}}},wl.prototype.receive=function(t){var e=t.data,r=e.id;if(r&&(!e.targetMapId||this.mapId===e.targetMapId))if("<cancel>"===e.type){delete this.tasks[r];var n=this.cancelCallbacks[r];delete this.cancelCallbacks[r],n&&n()}else this.tasks[r]=e,this.taskQueue.push(r),this.invoker.trigger()},wl.prototype.process=function(){var t=this;if(this.taskQueue.length){var e=this.taskQueue.shift(),r=this.tasks[e];if(delete this.tasks[e],this.taskQueue.length&&this.invoker.trigger(),r)if("<response>"===r.type){var n=this.callbacks[e];delete this.callbacks[e],n&&(r.error?n(vn(r.error)):n(null,vn(r.data)))}else{var a=!1,i=r.hasCallback?function(r,n){a=!0,delete t.cancelCallbacks[e];var i=[];t.target.postMessage({id:e,type:"<response>",sourceMapId:t.mapId,error:r?gn(r):null,data:gn(n,i)},i)}:function(t){a=!0},o=null,s=vn(r.data);if(this.parent[r.type])o=this.parent[r.type](r.sourceMapId,s,i);else if(this.parent.getWorkerSource){var l=r.type.split(".");o=this.parent.getWorkerSource(r.sourceMapId,l[0],s.source)[l[1]](s,i)}else i(new Error("Could not find function "+r.type));!a&&o&&o.cancel&&(this.cancelCallbacks[e]=o.cancel)}}},wl.prototype.remove=function(){this.target.removeEventListener("message",this.receive,!1)};var Tl=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};Tl.prototype.setNorthEast=function(t){return this._ne=t instanceof Al?new Al(t.lng,t.lat):Al.convert(t),this},Tl.prototype.setSouthWest=function(t){return this._sw=t instanceof Al?new Al(t.lng,t.lat):Al.convert(t),this},Tl.prototype.extend=function(t){var e,r,n=this._sw,a=this._ne;if(t instanceof Al)e=t,r=t;else{if(!(t instanceof Tl))return Array.isArray(t)?t.every(Array.isArray)?this.extend(Tl.convert(t)):this.extend(Al.convert(t)):this;if(e=t._sw,r=t._ne,!e||!r)return this}return n||a?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),a.lng=Math.max(r.lng,a.lng),a.lat=Math.max(r.lat,a.lat)):(this._sw=new Al(e.lng,e.lat),this._ne=new Al(r.lng,r.lat)),this},Tl.prototype.getCenter=function(){return new Al((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},Tl.prototype.getSouthWest=function(){return this._sw},Tl.prototype.getNorthEast=function(){return this._ne},Tl.prototype.getNorthWest=function(){return new Al(this.getWest(),this.getNorth())},Tl.prototype.getSouthEast=function(){return new Al(this.getEast(),this.getSouth())},Tl.prototype.getWest=function(){return this._sw.lng},Tl.prototype.getSouth=function(){return this._sw.lat},Tl.prototype.getEast=function(){return this._ne.lng},Tl.prototype.getNorth=function(){return this._ne.lat},Tl.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},Tl.prototype.toString=function(){return"LngLatBounds("+this._sw.toString()+", "+this._ne.toString()+")"},Tl.prototype.isEmpty=function(){return!(this._sw&&this._ne)},Tl.convert=function(t){return!t||t instanceof Tl?t:new Tl(t)};var Al=function(t,e){if(isNaN(t)||isNaN(e))throw new Error("Invalid LngLat object: ("+t+", "+e+")");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error("Invalid LngLat latitude value: must be between -90 and 90")};Al.prototype.wrap=function(){return new Al(u(this.lng,-180,180),this.lat)},Al.prototype.toArray=function(){return[this.lng,this.lat]},Al.prototype.toString=function(){return"LngLat("+this.lng+", "+this.lat+")"},Al.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new Tl(new Al(this.lng-r,this.lat-e),new Al(this.lng+r,this.lat+e))},Al.convert=function(t){if(t instanceof Al)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Al(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&"object"==typeof t&&null!==t)return new Al(Number("lng"in t?t.lng:t.lon),Number(t.lat));throw new Error("`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]")};var Ml=2*Math.PI*6378137;function Sl(t){return Ml*Math.cos(t*Math.PI/180)}function El(t){return(180+t)/360}function Ll(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function Cl(t,e){return t/Sl(e)}function Pl(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}var Ol=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Ol.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Al.convert(t);return new Ol(El(r.lng),Ll(r.lat),Cl(e,r.lat))},Ol.prototype.toLngLat=function(){return new Al(360*this.x-180,Pl(this.y))},Ol.prototype.toAltitude=function(){return this.z*Sl(Pl(this.y))},Ol.prototype.meterInMercatorCoordinateUnits=function(){return 1/Ml*(t=Pl(this.y),1/Math.cos(t*Math.PI/180));var t};var zl=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Rl(0,t,e,r)};zl.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},zl.prototype.url=function(t,e){var r,n,a,i,o,s=(r=this.x,n=this.y,a=this.z,i=kl(256*r,256*(n=Math.pow(2,a)-n-1),a),o=kl(256*(r+1),256*(n+1),a),i[0]+","+i[1]+","+o[0]+","+o[1]),l=function(t,e,r){for(var n,a="",i=t;i>0;i--)a+=(e&(n=1<<i-1)?1:0)+(r&n?2:0);return a}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace("{prefix}",(this.x%16).toString(16)+(this.y%16).toString(16)).replace("{z}",String(this.z)).replace("{x}",String(this.x)).replace("{y}",String("tms"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace("{quadkey}",l).replace("{bbox-epsg-3857}",s)},zl.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new a((t.x*e-this.x)*ti,(t.y*e-this.y)*ti)};var Il=function(t,e){this.wrap=t,this.canonical=e,this.key=Rl(t,e.z,e.x,e.y)},Dl=function(t,e,r,n,a){this.overscaledZ=t,this.wrap=e,this.canonical=new zl(r,+n,+a),this.key=Rl(e,t,n,a)};function Rl(t,e,r,n){(t*=2)<0&&(t=-1*t-1);var a=1<<e;return 32*(a*a*t+a*n+r)+e}Dl.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},Dl.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new Dl(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new Dl(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},Dl.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},Dl.prototype.children=function(t){if(this.overscaledZ>=t)return[new Dl(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new Dl(e,this.wrap,e,r,n),new Dl(e,this.wrap,e,r+1,n),new Dl(e,this.wrap,e,r,n+1),new Dl(e,this.wrap,e,r+1,n+1)]},Dl.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},Dl.prototype.wrapped=function(){return new Dl(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},Dl.prototype.unwrapTo=function(t){return new Dl(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},Dl.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},Dl.prototype.toUnwrapped=function(){return new Il(this.wrap,this.canonical)},Dl.prototype.toString=function(){return this.overscaledZ+"/"+this.canonical.x+"/"+this.canonical.y},Dl.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Ol(t.x-this.wrap,t.y))},pn("CanonicalTileID",zl),pn("OverscaledTileID",Dl,{omit:["posMatrix"]});var Fl=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError("DEM tiles must be square");if(r&&"mapbox"!==r&&"terrarium"!==r)return w('"'+r+'" is not a valid encoding type. Valid types include "mapbox" and "terrarium".');var n=this.dim=e.height;this.stride=this.dim+2,this.data=new Int32Array(this.stride*this.stride);for(var a=e.data,i="terrarium"===r?this._unpackTerrarium:this._unpackMapbox,o=0;o<n;o++)for(var s=0;s<n;s++){var l=4*(o*n+s);this.set(s,o,i(a[l],a[l+1],a[l+2]))}for(var c=0;c<n;c++)this.set(-1,c,this.get(0,c)),this.set(n,c,this.get(n-1,c)),this.set(c,-1,this.get(c,0)),this.set(c,n,this.get(c,n-1));this.set(-1,-1,this.get(0,0)),this.set(n,-1,this.get(n-1,0)),this.set(-1,n,this.get(0,n-1)),this.set(n,n,this.get(n-1,n-1))};Fl.prototype.set=function(t,e,r){this.data[this._idx(t,e)]=r+65536},Fl.prototype.get=function(t,e){return this.data[this._idx(t,e)]-65536},Fl.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError("out of range source coordinates for DEM data");return(e+1)*this.stride+(t+1)},Fl.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Fl.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Fl.prototype.getPixels=function(){return new Pi({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Fl.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error("dem dimension mismatch");var n=e*this.dim,a=e*this.dim+this.dim,i=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=a-1;break;case 1:a=n+1}switch(r){case-1:i=o-1;break;case 1:o=i+1}for(var s=-e*this.dim,l=-r*this.dim,c=i;c<o;c++)for(var u=n;u<a;u++)this.set(u,c,t.get(u+s,c+l))},pn("DEMData",Fl);var Bl=Zn([{name:"a_pos",type:"Int16",components:2},{name:"a_texture_pos",type:"Int16",components:2}]),Nl=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Nl.prototype.encode=function(t){return this._stringToNumber[t]},Nl.prototype.decode=function(t){return this._numberToString[t]};var jl=function(t,e,r,n){this.type="Feature",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,null!=t.id&&(this.id=t.id)},Vl={geometry:{configurable:!0}};Vl.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Vl.geometry.set=function(t){this._geometry=t},jl.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)"_geometry"!==e&&"_vectorTileFeature"!==e&&(t[e]=this[e]);return t},Object.defineProperties(jl.prototype,Vl);var Ul=function(){this.state={},this.stateChanges={},this.deletedStates={}};Ul.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},h(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var a in this.deletedStates[t]={},this.state[t])a!==n&&(this.deletedStates[t][a]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var i in this.deletedStates[t][n]={},this.state[t][n])r[i]||(this.deletedStates[t][n][i]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},Ul.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e&&e>=0)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e&&e>=0)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},Ul.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},a=this.stateChanges[t]||{},i=h({},n[r],a[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete i[s]}return i},Ul.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},Ul.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var a={};for(var i in this.stateChanges[n])this.state[n][i]||(this.state[n][i]={}),h(this.state[n][i],this.stateChanges[n][i]),a[i]=this.state[n][i];r[n]=a}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var u=0,f=Object.keys(this.deletedStates[o][c]);u<f.length;u+=1){var p=f[u];delete this.state[o][c][p]}s[c]=this.state[o][c]}r[o]=r[o]||{},h(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t)t[d].setFeatureState(r,e)};var ql=function(t,e,r){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=e||new ln(ti,16,0),this.grid3D=new ln(ti,16,0),this.featureIndexArray=r||new La};function Hl(t){for(var e=1/0,r=1/0,n=-1/0,a=-1/0,i=0,o=t;i<o.length;i+=1){var s=o[i];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),a=Math.max(a,s.y)}return{minX:e,minY:r,maxX:n,maxY:a}}function Gl(t,e){return e-t}ql.prototype.insert=function(t,e,r,n,a,i){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,a);for(var s=i?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<ti&&u[1]<ti&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},ql.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new zo.VectorTile(new $s(this.rawTileData)).layers,this.sourceLayerCoder=new Nl(this.vtLayers?Object.keys(this.vtLayers).sort():["_geojsonTileLayer"])),this.vtLayers},ql.prototype.query=function(t,e,r){var n=this;this.loadVTLayers();for(var i=t.params||{},o=ti/t.tileSize/t.scale,s=Dr(i.filter),l=t.queryGeometry,c=t.queryPadding*o,u=Hl(l),h=this.grid.query(u.minX-c,u.minY-c,u.maxX+c,u.maxY+c),f=Hl(t.cameraQueryGeometry),p=0,d=this.grid3D.query(f.minX-c,f.minY-c,f.maxX+c,f.maxY+c,function(e,r,n,i){return function(t,e,r,n,i){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&i>=l.y)return!0}var c=[new a(e,r),new a(e,i),new a(n,i),new a(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(di(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(gi(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-c,r-c,n+c,i+c)});p<d.length;p+=1){var g=d[p];h.push(g)}h.sort(Gl);for(var v,m={},y=function(a){var c=h[a];if(c!==v){v=c;var u=n.featureIndexArray.get(c),f=null;n.loadMatchingFeature(m,u.bucketIndex,u.sourceLayerIndex,u.featureIndex,s,i.layers,e,function(e,a){f||(f=ri(e));var i={};return e.id&&(i=r.getState(a.sourceLayer||"_geojsonTileLayer",e.id)),a.queryIntersectsFeature(l,e,i,f,n.z,t.transform,o,t.pixelPosMatrix)})}},x=0;x<h.length;x++)y(x);return m},ql.prototype.loadMatchingFeature=function(t,e,r,n,a,i,o,s){var l=this.bucketLayerIDs[e];if(!i||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(i,l)){var c=this.sourceLayerCoder.decode(r),u=this.vtLayers[c].feature(n);if(a(new Cn(this.tileID.overscaledZ),u))for(var h=0;h<l.length;h++){var f=l[h];if(!(i&&i.indexOf(f)<0)){var p=o[f];if(p){var d=!s||s(u,p);if(d){var g=new jl(u,this.z,this.x,this.y);g.layer=p.serialize();var v=t[f];void 0===v&&(v=t[f]=[]),v.push({featureIndex:n,feature:g,intersectionZ:d})}}}}}},ql.prototype.lookupSymbolFeatures=function(t,e,r,n,a,i){var o={};this.loadVTLayers();for(var s=Dr(n),l=0,c=t;l<c.length;l+=1){var u=c[l];this.loadMatchingFeature(o,e,r,u,s,a,i)}return o},ql.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,a=r[e];n<a.length;n+=1)if(t===a[n])return!0;return!1},pn("FeatureIndex",ql,{omit:["rawTileData","sourceLayerCoder"]});var Yl=function(t,e){this.tileID=t,this.uid=p(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.expiredRequestCount=0,this.state="loading"};function Wl(t,e,r,n,a){if(void 0===e.segment)return!0;for(var i=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(i),i=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],h=t[o],f=t[o+1];if(!f)return!1;var p=u.angleTo(h)-h.angleTo(f);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>a)return!1;o++,s+=h.dist(f)}return!0}function Xl(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function Zl(t,e,r){return t?.6*e*r:0}function Jl(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function Kl(t,e,r,n,a,i){for(var o=Zl(r,a,i),s=Jl(r,n)*i,l=0,c=Xl(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,g=ye(h.x,f.x,d),v=ye(h.y,f.y,d),m=new xs(g,v,f.angleTo(h),u);return m._round(),!o||Wl(t,m,s,o,e)?m:void 0}l+=p}}function Ql(t,e,r,n,a,i,o,s,l){var c=Zl(n,i,o),u=Jl(n,a),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),function t(e,r,n,a,i,o,s,l,c){for(var u=o/2,h=Xl(e),f=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var v=e[g],m=e[g+1],y=v.dist(m),x=m.angleTo(v);p+n<f+y;){var b=((p+=n)-f)/y,_=ye(v.x,m.x,b),w=ye(v.y,m.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=h){var k=new xs(_,w,x,g);k._round(),a&&!Wl(e,k,o,a,i)||d.push(k)}}f+=y}return l||d.length||s||(d=t(e,f/2,n,a,i,o,s,!0,c)),d}(t,f?e/2*s%e:(u/2+2*i)*o*s%e,e,c,r,h,f,!1,l)}Yl.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<I.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},Yl.prototype.wasRequested=function(){return"errored"===this.state||"loaded"===this.state||"reloading"===this.state},Yl.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state="loaded",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=i[a],n=t.layerIds.map(function(t){return e.getLayer(t)}).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map(function(t){return n.filter(function(e){return e.id===t})[0]}));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},a=0,i=t;a<i.length;a+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var a=this.buckets[n];if(a instanceof Ps){if(this.hasSymbolBuckets=!0,!r)break;a.justReloaded=!0}}for(var i in this.queryPadding=0,this.buckets){var o=this.buckets[i];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(i).queryRadius(o))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new xa},Yl.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state="unloaded"},Yl.prototype.unloadDEMData=function(){this.dem=null,this.neighboringTiles=null,this.state="unloaded"},Yl.prototype.getBucket=function(t){return this.buckets[t.id]},Yl.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Js(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Js(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},Yl.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},Yl.prototype.queryRenderedFeatures=function(t,e,r,n,a,i,o,s,l){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:r,cameraQueryGeometry:n,scale:a,tileSize:this.tileSize,pixelPosMatrix:l,transform:o,params:i,queryPadding:this.queryPadding*s},t,e):{}},Yl.prototype.querySourceFeatures=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData){var r=this.latestFeatureIndex.loadVTLayers(),n=e?e.sourceLayer:"",a=r._geojsonTileLayer||r[n];if(a)for(var i=Dr(e&&e.filter),o=this.tileID.canonical,s=o.z,l=o.x,c=o.y,u={z:s,x:l,y:c},h=0;h<a.length;h++){var f=a.feature(h);if(i(new Cn(this.tileID.overscaledZ),f)){var p=new jl(f,s,l,c);p.tile=u,t.push(p)}}}},Yl.prototype.clearMask=function(){this.segments&&(this.segments.destroy(),delete this.segments),this.maskedBoundsBuffer&&(this.maskedBoundsBuffer.destroy(),delete this.maskedBoundsBuffer),this.maskedIndexBuffer&&(this.maskedIndexBuffer.destroy(),delete this.maskedIndexBuffer)},Yl.prototype.setMask=function(t,e){if(!o(this.mask,t)&&(this.mask=t,this.clearMask(),!o(t,{0:!0}))){var r=new Qn,n=new pa;this.segments=new Pa,this.segments.prepareSegment(0,r,n);for(var i=Object.keys(t),s=0;s<i.length;s++){var l=t[+i[s]],c=ti>>l.z,u=new a(l.x*c,l.y*c),h=new a(u.x+c,u.y+c),f=this.segments.prepareSegment(4,r,n);r.emplaceBack(u.x,u.y,u.x,u.y),r.emplaceBack(h.x,u.y,h.x,u.y),r.emplaceBack(u.x,h.y,u.x,h.y),r.emplaceBack(h.x,h.y,h.x,h.y);var p=f.vertexLength;n.emplaceBack(p,p+1,p+2),n.emplaceBack(p+1,p+2,p+3),f.vertexLength+=4,f.primitiveLength+=2}this.maskedBoundsBuffer=e.createVertexBuffer(r,Bl.members),this.maskedIndexBuffer=e.createIndexBuffer(n)}},Yl.prototype.hasData=function(){return"loaded"===this.state||"reloading"===this.state||"expired"===this.state},Yl.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},Yl.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=A(t.cacheControl);r["max-age"]&&(this.expirationTime=Date.now()+1e3*r["max-age"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),a=!1;if(this.expirationTime>n)a=!1;else if(e)if(this.expirationTime<e)a=!0;else{var i=this.expirationTime-e;i?this.expirationTime=n+Math.max(i,3e4):a=!0}else a=!0;a?(this.expiredRequestCount++,this.state="expired"):this.expiredRequestCount=0}},Yl.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},Yl.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets){var a=this.buckets[n],i=a.layers[0].sourceLayer||"_geojsonTileLayer",o=r[i],s=t[i];o&&s&&0!==Object.keys(s).length&&(a.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{}),e&&e.style&&(this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(n).queryRadius(a))))}}},Yl.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},Yl.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<I.now()},Yl.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},Yl.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=I.now()+t};var $l=function(t,e,r,n,i,o,s,l,c,u,h,f){var p=s.top*l-c,d=s.bottom*l+c,g=s.left*l-c,v=s.right*l+c;if(this.boxStartIndex=t.length,u){var m=d-p,y=v-g;m>0&&(m=Math.max(10*l,m),this._addLineCollisionCircles(t,e,r,r.segment,y,m,n,i,o,h))}else{if(f){var x=new a(g,p),b=new a(v,p),_=new a(g,d),w=new a(v,d),k=f*Math.PI/180;x._rotate(k),b._rotate(k),_._rotate(k),w._rotate(k),g=Math.min(x.x,b.x,_.x,w.x),v=Math.max(x.x,b.x,_.x,w.x),p=Math.min(x.y,b.y,_.y,w.y),d=Math.max(x.y,b.y,_.y,w.y)}t.emplaceBack(r.x,r.y,g,p,v,d,n,i,o,0,0)}this.boxEndIndex=t.length};$l.prototype._addLineCollisionCircles=function(t,e,r,n,a,i,o,s,l,c){var u=i/2,h=Math.floor(a/u)||1,f=1+.4*Math.log(c)/Math.LN2,p=Math.floor(h*f/2),d=-i/2,g=r,v=n+1,m=d,y=-a/2,x=y-a/4;do{if(--v<0){if(m>y)return;v=0;break}m-=e[v].dist(g),g=e[v]}while(m>x);for(var b=e[v].dist(e[v+1]),_=-p;_<h+p;_++){var w=_*u,k=y+w;if(w<0&&(k+=w),w>a&&(k+=w-a),!(k<m)){for(;m+b<k;){if(m+=b,++v+1>=e.length)return;b=e[v].dist(e[v+1])}var T=k-m,A=e[v],M=e[v+1].sub(A)._unit()._mult(T)._add(A)._round(),S=Math.abs(k-d)<u?0:.8*(k-d);t.emplaceBack(M.x,M.y,-i/2,-i/2,i/2,i/2,o,s,l,i/2,S)}}};var tc=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=ec),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function ec(t,e){return t<e?-1:t>e?1:0}function rc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,i=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<i)&&(i=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=o-n,f=s-i,p=Math.min(h,f),d=p/2,g=new tc([],nc);if(0===p)return new a(n,i);for(var v=n;v<o;v+=p)for(var m=i;m<s;m+=p)g.push(new ac(v+d,m+d,d,t));for(var y=function(t){for(var e=0,r=0,n=0,a=t[0],i=0,o=a.length,s=o-1;i<o;s=i++){var l=a[i],c=a[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new ac(r/e,n/e,0,t)}(t),x=g.length;g.length;){var b=g.pop();(b.d>y.d||!y.d)&&(y=b,r&&console.log("found best %d after %d probes",Math.round(1e4*b.d)/1e4,x)),b.max-y.d<=e||(d=b.h/2,g.push(new ac(b.p.x-d,b.p.y-d,d,t)),g.push(new ac(b.p.x+d,b.p.y-d,d,t)),g.push(new ac(b.p.x-d,b.p.y+d,d,t)),g.push(new ac(b.p.x+d,b.p.y+d,d,t)),x+=4)}return r&&(console.log("num probes: "+x),console.log("best distance: "+y.d)),y.p}function nc(t,e){return e.max-t.max}function ac(t,e,r,n){this.p=new a(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,a=0;a<e.length;a++)for(var i=e[a],o=0,s=i.length,l=s-1;o<s;l=o++){var c=i[o],u=i[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,fi(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}tc.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},tc.prototype.pop=function(){if(0!==this.length){var t=this.data[0],e=this.data.pop();return this.length--,this.length>0&&(this.data[0]=e,this._down(0)),t}},tc.prototype.peek=function(){return this.data[0]},tc.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var a=t-1>>1,i=e[a];if(r(n,i)>=0)break;e[t]=i,t=a}e[t]=n},tc.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,a=e[t];t<n;){var i=1+(t<<1),o=e[i],s=i+1;if(s<this.length&&r(e[s],o)<0&&(i=s,o=e[s]),r(o,a)>=0)break;e[t]=o,t=i}e[t]=a};var ic=e(function(t){t.exports=function(t,e){var r,n,a,i,o,s,l,c;for(r=3&t.length,n=t.length-r,a=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,a=27492+(65535&(i=5*(65535&(a=(a^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|a>>>19))+((5*(a>>>16)&65535)<<16)&4294967295))+((58964+(i>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:a^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return a^=t.length,a=2246822507*(65535&(a^=a>>>16))+((2246822507*(a>>>16)&65535)<<16)&4294967295,a=3266489909*(65535&(a^=a>>>13))+((3266489909*(a>>>16)&65535)<<16)&4294967295,(a^=a>>>16)>>>0}}),oc=e(function(t){t.exports=function(t,e){for(var r,n=t.length,a=e^n,i=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(i)|(255&t.charCodeAt(++i))<<8|(255&t.charCodeAt(++i))<<16|(255&t.charCodeAt(++i))<<24))+((1540483477*(r>>>16)&65535)<<16),a=1540483477*(65535&a)+((1540483477*(a>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++i;switch(n){case 3:a^=(255&t.charCodeAt(i+2))<<16;case 2:a^=(255&t.charCodeAt(i+1))<<8;case 1:a=1540483477*(65535&(a^=255&t.charCodeAt(i)))+((1540483477*(a>>>16)&65535)<<16)}return a=1540483477*(65535&(a^=a>>>13))+((1540483477*(a>>>16)&65535)<<16),(a^=a>>>15)>>>0}}),sc=ic,lc=ic,cc=oc;sc.murmur3=lc,sc.murmur2=cc;var uc=7;function hc(t,e){var r=0,n=0,a=e/Math.sqrt(2);switch(t){case"top-right":case"top-left":n=a-uc;break;case"bottom-right":case"bottom-left":n=-a+uc;break;case"bottom":n=-e+uc;break;case"top":n=e-uc}switch(t){case"top-right":case"bottom-right":r=-a;break;case"top-left":case"bottom-left":r=a;break;case"left":r=e;break;case"right":r=-e}return[r,n]}function fc(t){switch(t){case"right":case"top-right":case"bottom-right":return"right";case"left":case"top-left":case"bottom-left":return"left"}return"center"}var pc=65535;function dc(t,e,r,n,i,o,s,l,c,u,h,f,p){var d=function(t,e,r,n,i,o,s,l){for(var c=n.layout.get("text-rotate").evaluate(o,{})*Math.PI/180,u=e.positionedGlyphs,h=[],f=0;f<u.length;f++){var p=u[f],d=s[p.fontStack],g=d&&d[p.glyph];if(g){var v=g.rect;if(v){var m=bl+1,y=g.metrics.advance*p.scale/2,x=i?[p.x+y,p.y]:[0,0],b=i?[0,0]:[p.x+y+r[0],p.y+r[1]],_=(i||l)&&p.vertical,w=[0,0];_&&(w=b,b=[0,0]);var k=(g.metrics.left-m)*p.scale-y+b[0],T=(-g.metrics.top-m)*p.scale+b[1],A=k+v.w*p.scale,M=T+v.h*p.scale,S=new a(k,T),E=new a(A,T),L=new a(k,M),C=new a(A,M);if(_){var P=new a(-y,y-e.yOffset),O=-Math.PI/2,z=ss/2-y,I=new a(5-e.yOffset-z,0),D=new(Function.prototype.bind.apply(a,[null].concat(w)));S._rotateAround(O,P)._add(I)._add(D),E._rotateAround(O,P)._add(I)._add(D),L._rotateAround(O,P)._add(I)._add(D),C._rotateAround(O,P)._add(I)._add(D)}if(c){var R=Math.sin(c),F=Math.cos(c),B=[F,-R,R,F];S._matMult(B),E._matMult(B),L._matMult(B),C._matMult(B)}h.push({tl:S,tr:E,bl:L,br:C,tex:v,writingMode:e.writingMode,glyphOffset:x,sectionIndex:p.sectionIndex})}}}return h}(0,r,s,n,i,o,f,t.allowVerticalPlacement),g=t.textSizeData,v=null;"source"===g.kind?(v=[bs*n.layout.get("text-size").evaluate(o,{})])[0]>pc&&w(t.layerIds[0]+': Value for "text-size" is >= 256. Reduce your "text-size".'):"composite"===g.kind&&((v=[bs*p.compositeTextSizes[0].evaluate(o,{}),bs*p.compositeTextSizes[1].evaluate(o,{})])[0]>pc||v[1]>pc)&&w(t.layerIds[0]+': Value for "text-size" is >= 256. Reduce your "text-size".'),t.addSymbols(t.text,d,v,s,i,o,c,e,l.lineStartIndex,l.lineLength);for(var m=0,y=u;m<y.length;m+=1)h[y[m]]=t.text.placedSymbolArray.length-1;return 4*d.length}function gc(t){for(var e in t)return t[e];return null}function vc(t,e,r,n){var a=t.compareText;if(e in a){for(var i=a[e],o=i.length-1;o>=0;o--)if(n.dist(i[o])<r)return!0}else a[e]=[];return a[e].push(n),!1}t.Actor=wl,t.AlphaImage=Ci,t.CanonicalTileID=zl,t.CollisionBoxArray=xa,t.Color=Wt,t.DEMData=Fl,t.DataConstantProperty=Nn,t.DictionaryCoder=Nl,t.EXTENT=ti,t.ErrorEvent=wt,t.EvaluationParameters=Cn,t.Event=_t,t.Evented=kt,t.FeatureIndex=ql,t.FillBucket=bo,t.FillExtrusionBucket=Fo,t.ImageAtlas=Gs,t.ImagePosition=qs,t.LineBucket=Xo,t.LngLat=Al,t.LngLatBounds=Tl,t.MercatorCoordinate=Ol,t.ONE_EM=ss,t.OverscaledTileID=Dl,t.Point=a,t.Point$1=a,t.ProgramConfiguration=Ja,t.Properties=Hn,t.Protobuf=$s,t.RGBAImage=Pi,t.RequestManager=V,t.ResourceType=lt,t.SegmentVector=Pa,t.SourceFeatureState=Ul,t.StructArrayLayout1ui2=ga,t.StructArrayLayout2i4=Kn,t.StructArrayLayout2ui4=da,t.StructArrayLayout3ui6=pa,t.StructArrayLayout4i8=Qn,t.SymbolBucket=Ps,t.Texture=Js,t.Tile=Yl,t.Transitionable=zn,t.Uniform1f=Fa,t.Uniform1i=Ra,t.Uniform2f=Ba,t.Uniform3f=Na,t.Uniform4f=ja,t.UniformColor=Va,t.UniformMatrix4f=qa,t.UnwrappedTileID=Il,t.ValidationError=At,t.WritingMode=ls,t.ZoomHistory=mn,t.addDynamicAttributes=Es,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,a=new Array(t.length),i=null;t.forEach(function(t,o){e(t,function(t,e){t&&(i=t),a[o]=e,0==--n&&r(i,a)})})},t.bezier=s,t.bindAll=v,t.browser=I,t.cacheEntryPossiblyAdded=function(t){++st>at&&(t.getActor().send("enforceCacheSizeLimit",nt),st=0)},t.clamp=c,t.clearTileCache=function(t){var e=self.caches.delete(rt);t&&e.catch(t).then(function(){return t()})},t.clone=function(t){var e=new wi(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=b,t.config=D,t.create=function(){var t=new wi(16);return wi!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=function(){var t=new wi(9);return wi!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t},t.create$2=function(){var t=new wi(4);return wi!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=wr,t.createLayout=Zn,t.createStyleLayer=function(t){return"custom"===t.type?new js(t):new Vs[t.type](t)},t.deepEqual=o,t.ease=l,t.emitValidationErrors=sn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){self.caches&&self.caches.open(rt).then(function(e){e.keys().then(function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])})})},t.evaluateRadialOffset=hc,t.evaluateSizeForFeature=ws,t.evaluateSizeForZoom=ks,t.evented=En,t.extend=h,t.featureFilter=Dr,t.filterObject=x,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=ms,t.getAnchorJustification=fc,t.getArrayBuffer=vt,t.getImage=yt,t.getJSON=function(t,e){return gt(h(t,{type:"json"}),e)},t.getReferrer=ht,t.getVideo=function(t,e){var r,n,a=self.document.createElement("video");a.muted=!0,a.onloadstart=function(){e(null,a)};for(var i=0;i<t.length;i++){var o=self.document.createElement("source");r=t[i],n=void 0,(n=self.document.createElement("a")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(a.crossOrigin="Anonymous"),o.src=t[i],a.appendChild(o)}return{cancel:function(){}}},t.identity=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},t.invert=function(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-a*o,b=r*c-i*o,_=n*l-a*s,w=n*c-i*s,k=a*c-i*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,L=f*m-p*v,C=y*L-x*E+b*S+_*M-w*A+k*T;return C?(C=1/C,t[0]=(s*L-l*E+c*S)*C,t[1]=(a*E-n*L-i*S)*C,t[2]=(g*k-v*w+m*_)*C,t[3]=(f*w-h*k-p*_)*C,t[4]=(l*M-o*L-c*A)*C,t[5]=(r*L-a*M+i*A)*C,t[6]=(v*b-d*k-m*x)*C,t[7]=(u*k-f*b+p*x)*C,t[8]=(o*E-s*M+c*T)*C,t[9]=(n*M-r*E-i*T)*C,t[10]=(d*w-g*b+m*y)*C,t[11]=(h*b-u*w-p*y)*C,t[12]=(s*A-o*S-l*T)*C,t[13]=(r*S-n*A+a*T)*C,t[14]=(g*x-d*_-v*y)*C,t[15]=(u*_-h*x+f*y)*C,t):null},t.isChar=yn,t.isMapboxURL=U,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=gt,t.mapObject=y,t.mercatorXfromLng=El,t.mercatorYfromLat=Ll,t.mercatorZfromAltitude=Cl,t.multiply=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*a+b*l+_*f+w*v,t[2]=x*i+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*a+b*l+_*f+w*v,t[6]=x*i+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*a+b*l+_*f+w*v,t[10]=x*i+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*a+b*l+_*f+w*v,t[14]=x*i+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t},t.mvt=zo,t.number=ye,t.ortho=function(t,e,r,n,a,i,o){var s=1/(e-r),l=1/(n-a),c=1/(i-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(a+n)*l,t[14]=(o+i)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new $s(t).readFields(ml,[])},t.pbf=$s,t.performSymbolLayout=function(t,e,r,n,i,o){t.createArrays();var s=512*t.overscaling;t.tilePixelRatio=ti/s,t.compareText={},t.iconsNeedLinear=!1;var l=t.layers[0].layout,c=t.layers[0]._unevaluatedLayout._values,u={};if("composite"===t.textSizeData.kind){var h=t.textSizeData,f=h.minZoom,p=h.maxZoom;u.compositeTextSizes=[c["text-size"].possiblyEvaluate(new Cn(f)),c["text-size"].possiblyEvaluate(new Cn(p))]}if("composite"===t.iconSizeData.kind){var d=t.iconSizeData,g=d.minZoom,v=d.maxZoom;u.compositeIconSizes=[c["icon-size"].possiblyEvaluate(new Cn(g)),c["icon-size"].possiblyEvaluate(new Cn(v))]}u.layoutTextSize=c["text-size"].possiblyEvaluate(new Cn(t.zoom+1)),u.layoutIconSize=c["icon-size"].possiblyEvaluate(new Cn(t.zoom+1)),u.textMaxSize=c["text-size"].possiblyEvaluate(new Cn(18));for(var m=l.get("text-line-height")*ss,y="map"===l.get("text-rotation-alignment")&&"point"!==l.get("symbol-placement"),x=l.get("text-keep-upright"),b=function(){var o=k[_],s=l.get("text-font").evaluate(o,{}).join(","),c=r,h={horizontal:{},vertical:void 0},f=o.text,p=[0,0];if(f){var d=f.toString(),g=l.get("text-letter-spacing").evaluate(o,{})*ss,v=function(t){for(var e=0,r=d;e<r.length;e+=1)if(!bn(r[e].charCodeAt(0)))return!1;return!0}()?g:0,b=l.get("text-anchor").evaluate(o,{}),T=l.get("text-variable-anchor"),A=l.get("text-radial-offset").evaluate(o,{});T||(p=A?hc(b,A*ss):l.get("text-offset").evaluate(o,{}).map(function(t){return t*ss}));var M=y?"center":l.get("text-justify").evaluate(o,{}),S="point"===l.get("symbol-placement")?l.get("text-max-width").evaluate(o,{})*ss:0,E=function(){t.allowVerticalPlacement&&xn(d)&&(h.vertical=us(f,e,s,S,m,b,"left",v,p,ls.vertical,!0))};if(!y&&T){for(var L="auto"===M?T.map(function(t){return fc(t)}):[M],C=!1,P=0;P<L.length;P++){var O=L[P];if(!h.horizontal[O])if(C)h.horizontal[O]=h.horizontal[0];else{var z=us(f,e,s,S,m,"center",O,v,p,ls.horizontal,!1);z&&(h.horizontal[O]=z,C=1===z.lineCount)}}E()}else{"auto"===M&&(M=fc(b));var I=us(f,e,s,S,m,b,M,v,p,ls.horizontal,!1);I&&(h.horizontal[M]=I),E(),xn(d)&&y&&x&&(h.vertical=us(f,e,s,S,m,b,M,v,p,ls.vertical,!1))}}var D=void 0;if(o.icon){var R=n[o.icon];R&&(D=function(t,e,r){var n=ms(r),a=n.horizontalAlign,i=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*a,c=l+t.displaySize[0],u=s-t.displaySize[1]*i;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}(i[o.icon],l.get("icon-offset").evaluate(o,{}),l.get("icon-anchor").evaluate(o,{})),void 0===t.sdfIcons?t.sdfIcons=R.sdf:t.sdfIcons!==R.sdf&&w("Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer"),R.pixelRatio!==t.pixelRatio?t.iconsNeedLinear=!0:0!==l.get("icon-rotate").constantOr(1)&&(t.iconsNeedLinear=!0))}(Object.keys(h.horizontal).length||D)&&function(t,e,r,n,i,o,s){var l=o.layoutTextSize.evaluate(e,{}),c=o.layoutIconSize.evaluate(e,{}),u=o.textMaxSize.evaluate(e,{});void 0===u&&(u=l);var h=t.layers[0].layout,f=h.get("icon-offset").evaluate(e,{}),p=gc(r.horizontal),d=l/24,g=t.tilePixelRatio*d,v=t.tilePixelRatio*u/24,m=t.tilePixelRatio*c,y=t.tilePixelRatio*h.get("symbol-spacing"),x=h.get("text-padding")*t.tilePixelRatio,b=h.get("icon-padding")*t.tilePixelRatio,_=h.get("text-max-angle")/180*Math.PI,k="map"===h.get("text-rotation-alignment")&&"point"!==h.get("symbol-placement"),T="map"===h.get("icon-rotation-alignment")&&"point"!==h.get("symbol-placement"),A=h.get("symbol-placement"),M=y/2,S=function(l,c){c.x<0||c.x>=ti||c.y<0||c.y>=ti||function(t,e,r,n,i,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_){var k,T,A,M=t.addToLineVertexArray(e,r),S=0,E=0,L=0,C={},P=sc(""),O=(o.layout.get("text-radial-offset").evaluate(x,{})||0)*ss;if(t.allowVerticalPlacement&&n.vertical){var z=o.layout.get("text-rotate").evaluate(x,{})+90,I=n.vertical;A=new $l(s,r,e,l,c,u,I,h,f,p,t.overscaling,z)}for(var D in n.horizontal){var R=n.horizontal[D];if(!k){P=sc(R.text);var F=o.layout.get("text-rotate").evaluate(x,{});k=new $l(s,r,e,l,c,u,R,h,f,p,t.overscaling,F)}var B=1===R.lineCount;if(E+=dc(t,e,R,o,p,x,d,M,n.vertical?ls.horizontal:ls.horizontalOnly,B?Object.keys(n.horizontal):[D],C,b,_),B)break}n.vertical&&(L+=dc(t,e,n.vertical,o,p,x,d,M,ls.vertical,["vertical"],C,b,_));var N=k?k.boxStartIndex:t.collisionBoxArray.length,j=k?k.boxEndIndex:t.collisionBoxArray.length,V=A?A.boxStartIndex:t.collisionBoxArray.length,U=A?A.boxEndIndex:t.collisionBoxArray.length;if(i){var q=function(t,e,r,n,i,o){var s,l,c,u,h=e.image,f=r.layout,p=e.top-1/h.pixelRatio,d=e.left-1/h.pixelRatio,g=e.bottom+1/h.pixelRatio,v=e.right+1/h.pixelRatio;if("none"!==f.get("icon-text-fit")&&i){var m=v-d,y=g-p,x=f.get("text-size").evaluate(o,{})/24,b=i.left*x,_=i.right*x,w=i.top*x,k=_-b,T=i.bottom*x-w,A=f.get("icon-text-fit-padding")[0],M=f.get("icon-text-fit-padding")[1],S=f.get("icon-text-fit-padding")[2],E=f.get("icon-text-fit-padding")[3],L="width"===f.get("icon-text-fit")?.5*(T-y):0,C="height"===f.get("icon-text-fit")?.5*(k-m):0,P="width"===f.get("icon-text-fit")||"both"===f.get("icon-text-fit")?k:m,O="height"===f.get("icon-text-fit")||"both"===f.get("icon-text-fit")?T:y;s=new a(b+C-E,w+L-A),l=new a(b+C+M+P,w+L-A),c=new a(b+C+M+P,w+L+S+O),u=new a(b+C-E,w+L+S+O)}else s=new a(d,p),l=new a(v,p),c=new a(v,g),u=new a(d,g);var z=r.layout.get("icon-rotate").evaluate(o,{})*Math.PI/180;if(z){var I=Math.sin(z),D=Math.cos(z),R=[D,-I,I,D];s._matMult(R),l._matMult(R),u._matMult(R),c._matMult(R)}return[{tl:s,tr:l,bl:u,br:c,tex:h.paddedRect,writingMode:void 0,glyphOffset:[0,0],sectionIndex:0}]}(0,i,o,0,gc(n.horizontal),x),H=o.layout.get("icon-rotate").evaluate(x,{});T=new $l(s,r,e,l,c,u,i,g,v,!1,t.overscaling,H),S=4*q.length;var G=t.iconSizeData,Y=null;"source"===G.kind?(Y=[bs*o.layout.get("icon-size").evaluate(x,{})])[0]>pc&&w(t.layerIds[0]+': Value for "icon-size" is >= 256. Reduce your "icon-size".'):"composite"===G.kind&&((Y=[bs*_.compositeIconSizes[0].evaluate(x,{}),bs*_.compositeIconSizes[1].evaluate(x,{})])[0]>pc||Y[1]>pc)&&w(t.layerIds[0]+': Value for "icon-size" is >= 256. Reduce your "icon-size".'),t.addSymbols(t.icon,q,Y,y,m,x,!1,e,M.lineStartIndex,M.lineLength)}var W=T?T.boxStartIndex:t.collisionBoxArray.length,X=T?T.boxEndIndex:t.collisionBoxArray.length;t.glyphOffsetArray.length>=Ps.MAX_GLYPHS&&w("Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907"),t.symbolInstances.emplaceBack(e.x,e.y,C.right>=0?C.right:-1,C.center>=0?C.center:-1,C.left>=0?C.left:-1,C.vertical||-1,P,N,j,V,U,W,X,l,E,L,S,0,h,O)}(t,c,l,r,n,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,g,x,k,s,m,b,T,f,e,i,o)};if("line"===A)for(var E=0,L=function(t,e,r,n,i){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<0&&f.x<0||(h.x<0?h=new a(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round():f.x<0&&(f=new a(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round()),h.y<0&&f.y<0||(h.y<0?h=new a(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round():f.y<0&&(f=new a(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new a(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round():f.x>=n&&(f=new a(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round()),h.y>=i&&f.y>=i||(h.y>=i?h=new a(h.x+(f.x-h.x)*((i-h.y)/(f.y-h.y)),i)._round():f.y>=i&&(f=new a(h.x+(f.x-h.x)*((i-h.y)/(f.y-h.y)),i)._round()),c&&h.equals(c[c.length-1])||(c=[h],o.push(c)),c.push(f)))))}return o}(e.geometry,0,0,ti,ti);E<L.length;E+=1)for(var C=L[E],P=0,O=Ql(C,y,_,r.vertical||p,n,24,v,t.overscaling,ti);P<O.length;P+=1){var z=O[P];p&&vc(t,p.text,M,z)||S(C,z)}else if("line-center"===A)for(var I=0,D=e.geometry;I<D.length;I+=1){var R=D[I];if(R.length>1){var F=Kl(R,_,r.vertical||p,n,24,v);F&&S(R,F)}}else if("Polygon"===e.type)for(var B=0,N=vo(e.geometry,0);B<N.length;B+=1){var j=N[B],V=rc(j,16);S(j[0],new xs(V.x,V.y,0))}else if("LineString"===e.type)for(var U=0,q=e.geometry;U<q.length;U+=1){var H=q[U];S(H,new xs(H[0].x,H[0].y,0))}else if("Point"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1)for(var W=0,X=Y[G];W<X.length;W+=1){var Z=X[W];S([Z],new xs(Z.x,Z.y,0))}}(t,o,h,D,c,u,p)},_=0,k=t.features;_<k.length;_+=1)b();o&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,a){var i,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=a&&a!==1/0?(i=1/(n-a),t[10]=(a+n)*i,t[14]=2*a*n*i):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var a=e[n];a in t&&(r[a]=t[a])}return r},t.plugin=Ln,t.polygonIntersectsPolygon=ii,t.postMapLoadEvent=et,t.postTurnstileEvent=$,t.potpack=Us,t.rasterBoundsAttributes=Bl,t.refProperties=["type","source","source-layer","minzoom","maxzoom","filter","layout"],t.register=pn,t.registerForPluginAvailability=function(t){return Mn?t({pluginURL:Mn,completionCallback:Tn}):En.once("pluginAvailable",t),t},t.rotate=function(t,e,r){var n=e[0],a=e[1],i=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+i*s,t[1]=a*l+o*s,t[2]=n*-s+i*l,t[3]=a*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=i*a+c*n,t[5]=o*a+u*n,t[6]=s*a+h*n,t[7]=l*a+f*n,t[8]=c*a-i*n,t[9]=u*a-o*n,t[10]=h*a-s*n,t[11]=f*a-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),a=Math.cos(r),i=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=i*a+c*n,t[1]=o*a+u*n,t[2]=s*a+h*n,t[3]=l*a+f*n,t[4]=c*a-i*n,t[5]=u*a-o*n,t[6]=h*a-s*n,t[7]=f*a-l*n,t},t.scale=function(t,e,r){var n=r[0],a=r[1],i=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*a,t[5]=e[5]*a,t[6]=e[6]*a,t[7]=e[7]*a,t[8]=e[8]*i,t[9]=e[9]*i,t[10]=e[10]*i,t[11]=e[11]*i,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.setCacheLimits=function(t,e){nt=t,at=e},t.setRTLTextPlugin=function(t,e){if(An)throw new Error("setRTLTextPlugin cannot be called multiple times.");An=!0,Mn=I.resolveURL(t),Tn=function(t){t?(An=!1,Mn=null,e&&e(t)):Sn=!0},En.fire(new _t("pluginAvailable",{pluginURL:Mn,completionCallback:Tn}))},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.styleSpec=Tt,t.symbolSize=Ts,t.transformMat3=function(t,e,r){var n=e[0],a=e[1],i=e[2];return t[0]=n*r[0]+a*r[3]+i*r[6],t[1]=n*r[1]+a*r[4]+i*r[7],t[2]=n*r[2]+a*r[5]+i*r[8],t},t.transformMat4=ki,t.translate=function(t,e,r){var n,a,i,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];return e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],a=e[1],i=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=a,t[2]=i,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=a*g+l*v+f*m+e[13],t[14]=i*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]),t},t.uniqueId=p,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:"layers."+r+': missing required property "id"'}),void 0===t.render&&e.push({message:"layers."+r+': missing required method "render"'}),t.renderingMode&&"2d"!==t.renderingMode&&"3d"!==t.renderingMode&&e.push({message:"layers."+r+': property "renderingMode" must be either "2d" or "3d"'}),e},t.validateLight=nn,t.validateStyle=rn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=zo,t.version="1.3.2",t.warnOnce=w,t.webpSupported=R,t.window=self,t.wrap=u}),n(0,function(t){function e(t){var r=typeof t;if("number"===r||"boolean"===r||"string"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n="[",a=0,i=t;a<i.length;a+=1)n+=e(i[a])+",";return n+"]"}for(var o=Object.keys(t).sort(),s="{",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+":"+e(t[o[l]])+",";return s+"}"}function r(r){for(var n="",a=0,i=t.refProperties;a<i.length;a+=1)n+="/"+e(r[i[a]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var a=this,i=0,o=e;i<o.length;i+=1){var s=o[i];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},a=0;a<t.length;a++){var i=e&&e[t[a].id]||r(t[a]);e&&(e[t[a].id]=i);var o=n[i];o||(o=n[i]=[]),o.push(t[a])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map(function(t){return a._layers[t.id]}),g=d[0];if("none"!==g.visibility){var v=g.source||"",m=this.familiesBySource[v];m||(m=this.familiesBySource[v]={});var y=g.sourceLayer||"_geojsonTileLayer",x=m[y];x||(x=m[y]=[]),x.push(d)}}};var a=function(e){var r={},n=[];for(var a in e){var i=e[a],o=r[a]={};for(var s in i){var l=i[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=u.w,f=u.h,p=new t.AlphaImage({width:h||1,height:f||1});for(var d in e){var g=e[d];for(var v in g){var m=g[+v];if(m&&0!==m.bitmap.width&&0!==m.bitmap.height){var y=r[d][v].rect;t.AlphaImage.copy(m.bitmap,p,{x:0,y:0},{x:y.x+1,y:y.y+1},m.bitmap)}}}this.image=p,this.positions=r};t.register("GlyphAtlas",a);var i=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies};function o(e,r){for(var n=new t.EvaluationParameters(r),a=0,i=e;a<i.length;a+=1)i[a].recalculate(n)}i.prototype.parse=function(e,r,n,i){var s=this;this.status="parsing",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var l=new t.DictionaryCoder(Object.keys(e.layers).sort()),c=new t.FeatureIndex(this.tileID);c.bucketLayerIDs=[];var u,h,f,p,d={},g={featureIndex:c,iconDependencies:{},patternDependencies:{},glyphDependencies:{}},v=r.familiesBySource[this.source];for(var m in v){var y=e.layers[m];if(y){1===y.version&&t.warnOnce('Vector tile source "'+this.source+'" layer "'+m+'" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var x=l.encode(m),b=[],_=0;_<y.length;_++){var w=y.feature(_);b.push({feature:w,index:_,sourceLayerIndex:x})}for(var k=0,T=v[m];k<T.length;k+=1){var A=T[k],M=A[0];M.minzoom&&this.zoom<Math.floor(M.minzoom)||M.maxzoom&&this.zoom>=M.maxzoom||"none"!==M.visibility&&(o(A,this.zoom),(d[M.id]=M.createBucket({index:c.bucketLayerIDs.length,layers:A,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:x,sourceID:this.source})).populate(b,g),c.bucketLayerIDs.push(A.map(function(t){return t.id})))}}}var S=t.mapObject(g.glyphDependencies,function(t){return Object.keys(t).map(Number)});Object.keys(S).length?n.send("getGlyphs",{uid:this.uid,stacks:S},function(t,e){u||(u=t,h=e,C.call(s))}):h={};var E=Object.keys(g.iconDependencies);E.length?n.send("getImages",{icons:E},function(t,e){u||(u=t,f=e,C.call(s))}):f={};var L=Object.keys(g.patternDependencies);function C(){if(u)return i(u);if(h&&f&&p){var e=new a(h),r=new t.ImageAtlas(f,p);for(var n in d){var s=d[n];s instanceof t.SymbolBucket?(o(s.layers,this.zoom),t.performSymbolLayout(s,h,e.positions,f,r.iconPositions,this.showCollisionBoxes)):s.hasPattern&&(s instanceof t.LineBucket||s instanceof t.FillBucket||s instanceof t.FillExtrusionBucket)&&(o(s.layers,this.zoom),s.addFeatures(g,r.patternPositions))}this.status="done",i(null,{buckets:t.values(d).filter(function(t){return!t.isEmpty()}),featureIndex:c,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?f:null,glyphPositions:this.returnDependencies?e.positions:null})}}L.length?n.send("getImages",{icons:L},function(t,e){u||(u=t,p=e,C.call(s))}):p={},C.call(this)};var s="undefined"!=typeof performance,l={getEntriesByName:function(t){return!!(s&&performance&&performance.getEntriesByName)&&performance.getEntriesByName(t)},mark:function(t){return!!(s&&performance&&performance.mark)&&performance.mark(t)},measure:function(t,e,r){return!!(s&&performance&&performance.measure)&&performance.measure(t,e,r)},clearMarks:function(t){return!!(s&&performance&&performance.clearMarks)&&performance.clearMarks(t)},clearMeasures:function(t){return!!(s&&performance&&performance.clearMeasures)&&performance.clearMeasures(t)}},c=function(t){this._marks={start:[t.url,"start"].join("#"),end:[t.url,"end"].join("#"),measure:t.url.toString()},l.mark(this._marks.start)};function u(e,r){var n=t.getArrayBuffer(e.request,function(e,n,a,i){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:a,expires:i})});return function(){n.cancel(),r()}}c.prototype.finish=function(){l.mark(this._marks.end);var t=l.getEntriesByName(this._marks.measure);return 0===t.length&&(l.measure(this._marks.measure,this._marks.start,this._marks.end),t=l.getEntriesByName(this._marks.measure),l.clearMarks(this._marks.start),l.clearMarks(this._marks.end),l.clearMeasures(this._marks.measure)),t},l.Performance=c;var h=function(t,e,r){this.actor=t,this.layerIndex=e,this.loadVectorData=r||u,this.loading={},this.loaded={}};h.prototype.loadTile=function(e,r){var n=this,a=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new l.Performance(e.request),s=this.loading[a]=new i(e);s.abort=this.loadVectorData(e,function(e,i){if(delete n.loading[a],e||!i)return s.status="done",n.loaded[a]=s,r(e);var l=i.rawData,c={};i.expires&&(c.expires=i.expires),i.cacheControl&&(c.cacheControl=i.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=i.vectorTile,s.parse(i.vectorTile,n.layerIndex,n.actor,function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))}),n.loaded=n.loaded||{},n.loaded[a]=s})},h.prototype.reloadTile=function(t,e){var r=this.loaded,n=t.uid,a=this;if(r&&r[n]){var i=r[n];i.showCollisionBoxes=t.showCollisionBoxes;var o=function(t,r){var n=i.reloadCallback;n&&(delete i.reloadCallback,i.parse(i.vectorTile,a.layerIndex,a.actor,n)),e(t,r)};"parsing"===i.status?i.reloadCallback=o:"done"===i.status&&(i.vectorTile?i.parse(i.vectorTile,this.layerIndex,this.actor,o):o())}},h.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},h.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var f=function(){this.loaded={}};f.prototype.loadTile=function(e,r){var n=e.uid,a=e.encoding,i=e.rawImageData,o=new t.DEMData(n,i,a);this.loaded=this.loaded||{},this.loaded[n]=o,r(null,o)},f.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p={RADIUS:6378137,FLATTENING:1/298.257223563,POLAR_RADIUS:6356752.3142};function d(t){var e=0;if(t&&t.length>0){e+=Math.abs(g(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(g(t[r]))}return e}function g(t){var e,r,n,a,i,o,s=0,l=t.length;if(l>2){for(o=0;o<l;o++)o===l-2?(n=l-2,a=l-1,i=0):o===l-1?(n=l-1,a=0,i=1):(n=o,a=o+1,i=o+2),e=t[n],r=t[a],s+=(v(t[i][0])-v(e[0]))*Math.sin(v(r[1]));s=s*p.RADIUS*p.RADIUS/2}return s}function v(t){return t*Math.PI/180}var m={geometry:function t(e){var r,n=0;switch(e.type){case"Polygon":return d(e.coordinates);case"MultiPolygon":for(r=0;r<e.coordinates.length;r++)n+=d(e.coordinates[r]);return n;case"Point":case"MultiPoint":case"LineString":case"MultiLineString":return 0;case"GeometryCollection":for(r=0;r<e.geometries.length;r++)n+=t(e.geometries[r]);return n}},ring:g};function y(t,e){return function(r){return t(r,e)}}function x(t,e){e=!!e,t[0]=b(t[0],e);for(var r=1;r<t.length;r++)t[r]=b(t[r],!e);return t}function b(t,e){return function(t){return m.ring(t)>=0}(t)===e?t:t.reverse()}var _=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,w=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,"id"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};w.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var a=n[r];e.push([new t.Point$1(a[0],a[1])])}return e}for(var i=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}i.push(l)}return i},w.prototype.toGeoJSON=function(t,e,r){return _.call(this,t,e,r)};var k=function(e){this.layers={_geojsonTileLayer:this},this.name="_geojsonTileLayer",this.extent=t.EXTENT,this.length=e.length,this._features=e};k.prototype.feature=function(t){return new w(this._features[t])};var T=t.vectorTile.VectorTileFeature,A=M;function M(t,e){this.options=e||{},this.features=t,this.length=t.length}function S(t,e){this.id="number"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}M.prototype.feature=function(t){return new S(this.features[t],this.options.extent)},S.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],a=[],i=0;i<n.length;i++)a.push(new t.Point$1(n[i][0],n[i][1]));this.geometry.push(a)}return this.geometry},S.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,a=-1/0,i=0;i<t.length;i++)for(var o=t[i],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),a=Math.max(a,l.y)}return[e,n,r,a]},S.prototype.toGeoJSON=T.prototype.toGeoJSON;var E=P,L=P,C=A;function P(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,O,t.layers[r])}(e,r),r.finish()}function O(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||""),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,z,n);var a=n.keys;for(r=0;r<a.length;r++)e.writeStringField(3,a[r]);var i=n.values;for(r=0;r<i.length;r++)e.writeMessage(4,B,i[r])}function z(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,I,t),e.writeVarintField(3,r.type),e.writeMessage(4,F,r)}function I(t,e){var r=t.feature,n=t.keys,a=t.values,i=t.keycache,o=t.valuecache;for(var s in r.properties){var l=i[s];void 0===l&&(n.push(s),l=n.length-1,i[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;"string"!==u&&"boolean"!==u&&"number"!==u&&(c=JSON.stringify(c));var h=u+":"+c,f=o[h];void 0===f&&(a.push(c),f=a.length-1,o[h]=f),e.writeVarint(f)}}function D(t,e){return(e<<3)+(7&t)}function R(t){return t<<1^t>>31}function F(t,e){for(var r=t.loadGeometry(),n=t.type,a=0,i=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(D(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(D(2,u-1));var f=l[h].x-a,p=l[h].y-i;e.writeVarint(R(f)),e.writeVarint(R(p)),a+=f,i+=p}3===n&&e.writeVarint(D(7,1))}}function B(t,e){var r=typeof t;"string"===r?e.writeStringField(1,t):"boolean"===r?e.writeBooleanField(7,t):"number"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function N(t,e,r,n){j(t,r,n),j(e,2*r,2*n),j(e,2*r+1,2*n+1)}function j(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function V(t,e,r,n){var a=t-r,i=e-n;return a*a+i*i}E.fromVectorTileJs=L,E.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new A(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return P({layers:r})},E.GeoJSONWrapper=C;var U=function(t){return t[0]},q=function(t){return t[1]},H=function(t,e,r,n,a){void 0===e&&(e=U),void 0===r&&(r=q),void 0===n&&(n=64),void 0===a&&(a=Float64Array),this.nodeSize=n,this.points=t;for(var i=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new i(t.length),s=this.coords=new a(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,a,i,o){if(!(i-a<=n)){var s=a+i>>1;!function t(e,r,n,a,i,o){for(;i>a;){if(i-a>600){var s=i-a+1,l=n-a+1,c=Math.log(s),u=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(a,Math.floor(n-l*u/s+h)),Math.min(i,Math.floor(n+(s-l)*u/s+h)),o)}var f=r[2*n+o],p=a,d=i;for(N(e,r,a,n),r[2*i+o]>f&&N(e,r,a,i);p<d;){for(N(e,r,p,d),p++,d--;r[2*p+o]<f;)p++;for(;r[2*d+o]>f;)d--}r[2*a+o]===f?N(e,r,a,d):N(e,r,++d,i),d<=n&&(a=d+1),n<=d&&(i=d-1)}}(e,r,s,a,i,o%2),t(e,r,n,a,s-1,o+1),t(e,r,n,s+1,i,o+1)}}(o,s,n,0,o.length-1,0)};H.prototype.range=function(t,e,r,n){return function(t,e,r,n,a,i,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=a&&l>=n&&l<=i&&u.push(t[d]);else{var g=Math.floor((p+f)/2);s=e[2*g],l=e[2*g+1],s>=r&&s<=a&&l>=n&&l<=i&&u.push(t[g]);var v=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(v)),(0===h?a>=s:i>=l)&&(c.push(g+1),c.push(f),c.push(v))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},H.prototype.within=function(t,e,r){return function(t,e,r,n,a,i){for(var o=[0,t.length-1,0],s=[],l=a*a;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=i)for(var f=h;f<=u;f++)V(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],g=e[2*p+1];V(d,g,r,n)<=l&&s.push(t[p]);var v=(c+1)%2;(0===c?r-a<=d:n-a<=g)&&(o.push(h),o.push(p-1),o.push(v)),(0===c?r+a>=d:n+a>=g)&&(o.push(p+1),o.push(u),o.push(v))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var G={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,reduce:null,map:function(t){return t}},Y=function(t){this.options=$(Object.create(G),t),this.trees=new Array(this.options.maxZoom+1)};function W(t,e,r,n,a){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:a}}function X(t,e){var r=t.geometry.coordinates,n=r[0],a=r[1];return{x:K(n),y:Q(a),zoom:1/0,index:e,parentId:-1}}function Z(t){return{type:"Feature",id:t.id,properties:J(t),geometry:{type:"Point",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function J(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+"k":e>=1e3?Math.round(e/100)/10+"k":e;return $($({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function K(t){return t/360+.5}function Q(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function $(t,e){for(var r in e)t[r]=e[r];return t}function tt(t){return t.x}function et(t){return t.y}function rt(t,e,r,n,a,i){var o=a-r,s=i-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=a,n=i):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function nt(t,e,r,n){var a={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if("Point"===r||"MultiPoint"===r||"LineString"===r)at(t,e);else if("Polygon"===r||"MultiLineString"===r)for(var n=0;n<e.length;n++)at(t,e[n]);else if("MultiPolygon"===r)for(n=0;n<e.length;n++)for(var a=0;a<e[n].length;a++)at(t,e[n][a])}(a),a}function at(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function it(t,e,r,n){if(e.geometry){var a=e.geometry.coordinates,i=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),"Point"===i)ot(a,s);else if("MultiPoint"===i)for(var c=0;c<a.length;c++)ot(a[c],s);else if("LineString"===i)st(a,s,o,!1);else if("MultiLineString"===i){if(r.lineMetrics){for(c=0;c<a.length;c++)s=[],st(a[c],s,o,!1),t.push(nt(l,"LineString",s,e.properties));return}lt(a,s,o,!1)}else if("Polygon"===i)lt(a,s,o,!0);else{if("MultiPolygon"!==i){if("GeometryCollection"===i){for(c=0;c<e.geometry.geometries.length;c++)it(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error("Input data is not a valid GeoJSON object.")}for(c=0;c<a.length;c++){var u=[];lt(a[c],u,o,!0),s.push(u)}}t.push(nt(l,i,s,e.properties))}}function ot(t,e){e.push(ct(t[0])),e.push(ut(t[1])),e.push(0)}function st(t,e,r,n){for(var a,i,o=0,s=0;s<t.length;s++){var l=ct(t[s][0]),c=ut(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(a*c-l*i)/2:Math.sqrt(Math.pow(l-a,2)+Math.pow(c-i,2))),a=l,i=c}var u=e.length-3;e[2]=1,function t(e,r,n,a){for(var i,o=a,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],h=e[n],f=e[n+1],p=r+3;p<n;p+=3){var d=rt(e[p],e[p+1],c,u,h,f);if(d>o)i=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(i=p,l=g)}}o>a&&(i-r>3&&t(e,r,i,a),e[i+2]=o,n-i>3&&t(e,i,n,a))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function lt(t,e,r,n){for(var a=0;a<t.length;a++){var i=[];st(t[a],i,r,n),e.push(i)}}function ct(t){return t/360+.5}function ut(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function ht(t,e,r,n,a,i,o,s){if(n/=e,i>=(r/=e)&&o<n)return t;if(o<r||i>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===a?u.minX:u.minY,d=0===a?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if("Point"===f||"MultiPoint"===f)ft(h,g,r,n,a);else if("LineString"===f)pt(h,g,r,n,a,!1,s.lineMetrics);else if("MultiLineString"===f)gt(h,g,r,n,a,!1);else if("Polygon"===f)gt(h,g,r,n,a,!0);else if("MultiPolygon"===f)for(var v=0;v<h.length;v++){var m=[];gt(h[v],m,r,n,a,!0),m.length&&g.push(m)}if(g.length){if(s.lineMetrics&&"LineString"===f){for(v=0;v<g.length;v++)l.push(nt(u.id,f,g[v],u.tags));continue}"LineString"!==f&&"MultiLineString"!==f||(1===g.length?(f="LineString",g=g[0]):f="MultiLineString"),"Point"!==f&&"MultiPoint"!==f||(f=3===g.length?"Point":"MultiPoint"),l.push(nt(u.id,f,g,u.tags))}}}return l.length?l:null}function ft(t,e,r,n,a){for(var i=0;i<t.length;i+=3){var o=t[i+a];o>=r&&o<=n&&(e.push(t[i]),e.push(t[i+1]),e.push(t[i+2]))}}function pt(t,e,r,n,a,i,o){for(var s,l,c=dt(t),u=0===a?mt:yt,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],g=t[f+2],v=t[f+3],m=t[f+4],y=0===a?p:d,x=0===a?v:m,b=!1;o&&(s=Math.sqrt(Math.pow(p-v,2)+Math.pow(d-m,2))),y<r?x>r&&(l=u(c,p,d,v,m,r),o&&(c.start=h+s*l)):y>n?x<n&&(l=u(c,p,d,v,m,n),o&&(c.start=h+s*l)):vt(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,v,m,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,v,m,n),b=!0),!i&&b&&(o&&(c.end=h+s*l),e.push(c),c=dt(t)),o&&(h+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===a?p:d)>=r&&y<=n&&vt(c,p,d,g),_=c.length-3,i&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&vt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function dt(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function gt(t,e,r,n,a,i){for(var o=0;o<t.length;o++)pt(t[o],e,r,n,a,i,!1)}function vt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function mt(t,e,r,n,a,i){var o=(i-e)/(n-e);return t.push(i),t.push(r+(a-r)*o),t.push(1),o}function yt(t,e,r,n,a,i){var o=(i-r)/(a-r);return t.push(e+(n-e)*o),t.push(i),t.push(1),o}function xt(t,e){for(var r=[],n=0;n<t.length;n++){var a,i=t[n],o=i.type;if("Point"===o||"MultiPoint"===o||"LineString"===o)a=bt(i.geometry,e);else if("MultiLineString"===o||"Polygon"===o){a=[];for(var s=0;s<i.geometry.length;s++)a.push(bt(i.geometry[s],e))}else if("MultiPolygon"===o)for(a=[],s=0;s<i.geometry.length;s++){for(var l=[],c=0;c<i.geometry[s].length;c++)l.push(bt(i.geometry[s][c],e));a.push(l)}r.push(nt(i.id,o,a,i.tags))}return r}function bt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function _t(t,e){if(t.transformed)return t;var r,n,a,i=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(wt(c[n],c[n+1],e,i,o,s));else for(n=0;n<c.length;n++){var h=[];for(a=0;a<c[n].length;a+=2)h.push(wt(c[n][a],c[n][a+1],e,i,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function wt(t,e,r,n,a,i){return[Math.round(r*(t*n-a)),Math.round(r*(e*n-i))]}function kt(t,e,r,n,a){for(var i=e===a.maxZoom?0:a.tolerance/((1<<e)*a.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,Tt(o,t[s],i,a);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function Tt(t,e,r,n){var a=e.geometry,i=e.type,o=[];if("Point"===i||"MultiPoint"===i)for(var s=0;s<a.length;s+=3)o.push(a[s]),o.push(a[s+1]),t.numPoints++,t.numSimplified++;else if("LineString"===i)At(o,a,t,r,!1,!1);else if("MultiLineString"===i||"Polygon"===i)for(s=0;s<a.length;s++)At(o,a[s],t,r,"Polygon"===i,0===s);else if("MultiPolygon"===i)for(var l=0;l<a.length;l++){var c=a[l];for(s=0;s<c.length;s++)At(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if("LineString"===i&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=a.start/a.size,u.mapbox_clip_end=a.end/a.size}var f={geometry:o,type:"Polygon"===i||"MultiPolygon"===i?3:"LineString"===i||"MultiLineString"===i?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function At(t,e,r,n,a,i){var o=n*n;if(n>0&&e.size<(a?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;a&&function(t,e){for(var r=0,n=0,a=t.length,i=a-2;n<a;i=n,n+=2)r+=(t[n]-t[i])*(t[n+1]+t[i+1]);if(r>0===e)for(n=0,a=t.length;n<a/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[a-2-n],t[n+1]=t[a-1-n],t[a-2-n]=o,t[a-1-n]=s}}(s,i),t.push(s)}}function Mt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time("preprocess data"),e.maxZoom<0||e.maxZoom>24)throw new Error("maxZoom should be in the 0-24 range");if(e.promoteId&&e.generateId)throw new Error("promoteId and generateId cannot be used together.");var n=function(t,e){var r=[];if("FeatureCollection"===t.type)for(var n=0;n<t.features.length;n++)it(r,t.features[n],e,n);else"Feature"===t.type?it(r,t,e):it(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd("preprocess data"),console.log("index: maxZoom: %d, maxPoints: %d",e.indexMaxZoom,e.indexMaxPoints),console.time("generate tiles"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,a=ht(t,1,-1-r,r,0,-1,2,e),i=ht(t,1,1-r,2+r,0,-1,2,e);return(a||i)&&(n=ht(t,1,-r,1+r,0,-1,2,e)||[],a&&(n=xt(a,1).concat(n)),i&&(n=n.concat(xt(i,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log("features: %d, points: %d",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd("generate tiles"),console.log("tiles generated:",this.total,JSON.stringify(this.stats)))}function St(t,e,r){return 32*((1<<t)*r+e)+t}function Et(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var a=new k(n.features),i=E(a);0===i.byteOffset&&i.byteLength===i.buffer.byteLength||(i=new Uint8Array(i)),e(null,{vectorTile:a,rawData:i.buffer})}Y.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,a=e.maxZoom,i=e.nodeSize;r&&console.time("total time");var o="prepare "+t.length+" points";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(X(t[l],l));this.trees[a+1]=new H(s,tt,et,i,Float32Array),r&&console.timeEnd(o);for(var c=a;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new H(s,tt,et,i,Float32Array),r&&console.log("z%d: %d clusters in %dms",c,s.length,+Date.now()-u)}return r&&console.timeEnd("total time"),this},Y.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),a=180===t[2]?180:((t[2]+180)%360+360)%360-180,i=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,a=180;else if(r>a){var o=this.getClusters([r,n,180,i],e),s=this.getClusters([-180,n,a,i],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(K(r),Q(i),K(a),Q(n));u<h.length;u+=1){var f=h[u],p=l.points[f];c.push(p.numPoints?Z(p):this.points[p.index])}return c},Y.prototype.getChildren=function(t){var e=t>>5,r=t%32,n="No cluster with the specified id.",a=this.trees[r];if(!a)throw new Error(n);var i=a.points[e];if(!i)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=a.within(i.x,i.y,o);l<c.length;l+=1){var u=c[l],h=a.points[u];h.parentId===t&&s.push(h.numPoints?Z(h):this.points[h.index])}if(0===s.length)throw new Error(n);return s},Y.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},Y.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],a=Math.pow(2,t),i=this.options,o=i.extent,s=i.radius/o,l=(r-s)/a,c=(r+1+s)/a,u={features:[]};return this._addTileFeatures(n.range((e-s)/a,l,(e+1+s)/a,c),n.points,e,r,a,u),0===e&&this._addTileFeatures(n.range(1-s/a,l,1,c),n.points,a,r,a,u),e===a-1&&this._addTileFeatures(n.range(0,l,s/a,c),n.points,-1,r,a,u),u.features.length?u:null},Y.prototype.getClusterExpansionZoom=function(t){for(var e=t%32-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},Y.prototype._appendLeaves=function(t,e,r,n,a){for(var i=0,o=this.getChildren(e);i<o.length;i+=1){var s=o[i],l=s.properties;if(l&&l.cluster?a+l.point_count<=n?a+=l.point_count:a=this._appendLeaves(t,l.cluster_id,r,n,a):a<n?a++:t.push(s),t.length===r)break}return a},Y.prototype._addTileFeatures=function(t,e,r,n,a,i){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c={type:1,geometry:[[Math.round(this.options.extent*(l.x*a-r)),Math.round(this.options.extent*(l.y*a-n))]],tags:l.numPoints?J(l):this.points[l.index].properties},u=l.numPoints?l.id:this.points[l.index].id;void 0!==u&&(c.id=u),i.features.push(c)}},Y.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},Y.prototype._cluster=function(t,e){for(var r=[],n=this.options,a=n.radius,i=n.extent,o=n.reduce,s=a/(i*Math.pow(2,e)),l=0;l<t.length;l++){var c=t[l];if(!(c.zoom<=e)){c.zoom=e;for(var u=this.trees[e+1],h=u.within(c.x,c.y,s),f=c.numPoints||1,p=c.x*f,d=c.y*f,g=o&&f>1?this._map(c,!0):null,v=(l<<5)+(e+1),m=0,y=h;m<y.length;m+=1){var x=y[m],b=u.points[x];if(!(b.zoom<=e)){b.zoom=e;var _=b.numPoints||1;p+=b.x*_,d+=b.y*_,f+=_,b.parentId=v,o&&(g||(g=this._map(c,!0)),o(g,this._map(b)))}}1===f?r.push(c):(c.parentId=v,r.push(W(p/f,d/f,v,f,g)))}}return r},Y.prototype._map=function(t,e){if(t.numPoints)return e?$({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?$({},n):n},Mt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},Mt.prototype.splitTile=function(t,e,r,n,a,i,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=St(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time("creation"),f=this.tiles[h]=kt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log("tile z%d-%d-%d (features: %d, points: %d, simplified: %d)",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd("creation"));var p="z"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,a){if(e===l.maxZoom||e===a)continue;var d=1<<a-e;if(r!==Math.floor(i/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time("clipping");var g,v,m,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,k=.5+_,T=1+_;g=v=m=y=null,x=ht(t,u,r-_,r+k,0,f.minX,f.maxX,l),b=ht(t,u,r+w,r+T,0,f.minX,f.maxX,l),t=null,x&&(g=ht(x,u,n-_,n+k,1,f.minY,f.maxY,l),v=ht(x,u,n+w,n+T,1,f.minY,f.maxY,l),x=null),b&&(m=ht(b,u,n-_,n+k,1,f.minY,f.maxY,l),y=ht(b,u,n+w,n+T,1,f.minY,f.maxY,l),b=null),c>1&&console.timeEnd("clipping"),s.push(g||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(m||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},Mt.prototype.getTile=function(t,e,r){var n=this.options,a=n.extent,i=n.debug;if(t<0||t>24)return null;var o=1<<t,s=St(t,e=(e%o+o)%o,r);if(this.tiles[s])return _t(this.tiles[s],a);i>1&&console.log("drilling down to z%d-%d-%d",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[St(c,u,h)];return l&&l.source?(i>1&&console.log("found parent tile z%d-%d-%d",c,u,h),i>1&&console.time("drilling down"),this.splitTile(l.source,c,u,h,t,e,r),i>1&&console.timeEnd("drilling down"),this.tiles[s]?_t(this.tiles[s],a):null):null};var Lt=function(e){function r(t,r,n){e.call(this,t,r,Et),n&&(this.loadGeoJSON=n)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&"Idle"!==this._state?this._state="NeedsLoadData":(this._state="Coalescing",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var a=!!(n&&n.request&&n.request.collectResourceTiming)&&new l.Performance(n.request);this.loadGeoJSON(n,function(i,o){if(i||!o)return r(i);if("object"!=typeof o)return r(new Error("Input data given to '"+n.source+"' is not a valid GeoJSON object."));!function t(e,r){switch(e&&e.type||null){case"FeatureCollection":return e.features=e.features.map(y(t,r)),e;case"GeometryCollection":return e.geometries=e.geometries.map(y(t,r)),e;case"Feature":return e.geometry=t(e.geometry,r),e;case"Polygon":case"MultiPolygon":return function(t,e){return"Polygon"===t.type?t.coordinates=x(t.coordinates,e):"MultiPolygon"===t.type&&(t.coordinates=t.coordinates.map(y(x,e))),t}(e,r);default:return e}}(o,!0);try{e._geoJSONIndex=n.cluster?new Y(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var a={},i={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=f[1],g=t.createExpression(d),v=t.createExpression("string"==typeof p?[p,["accumulated"],["get",h]]:p);a[h]=g.value,i[h]=v.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var i=n[r];e[i]=a[i].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var a=n[r];o.accumulated=t[a],t[a]=i[a].evaluate(o,s)}},r}(n)).load(o.features):new Mt(o,n.geojsonVtOptions)}catch(i){return r(i)}e.loaded={};var s={};if(a){var l=a.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)})}},r.prototype.coalesce=function(){"Coalescing"===this._state?this._state="Idle":"NeedsLoadData"===this._state&&(this._state="Coalescing",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,a=t.uid;return n&&n[a]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if("string"!=typeof e.data)return r(new Error("Input data given to '"+e.source+"' is not a valid GeoJSON object."));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error("Input data given to '"+e.source+"' is not a valid GeoJSON object."))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))},r.prototype.getClusterChildren=function(t,e){e(null,this._geoJSONIndex.getChildren(t.clusterId))},r.prototype.getClusterLeaves=function(t,e){e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))},r}(h),Ct=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.workerSourceTypes={vector:h,geojson:Lt},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name "'+t+'" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isLoaded())throw new Error("RTL text plugin already registered.");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return Ct.prototype.setReferrer=function(t,e){this.referrer=e},Ct.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Ct.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Ct.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Ct.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Ct.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Ct.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Ct.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Ct.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Ct.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Ct.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Ct.prototype.loadRTLTextPlugin=function(e,r,n){try{t.plugin.isLoaded()||(this.self.importScripts(r),n(t.plugin.isLoaded()?null:new Error("RTL Text Plugin failed to import scripts from "+r)))}catch(t){n(t.toString())}},Ct.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Ct.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var a={send:function(e,r,a){n.actor.send(e,r,a,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](a,this.getLayerIndex(t))}return this.workerSources[t][e][r]},Ct.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new f),this.demWorkerSources[t][e]},Ct.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},"undefined"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new Ct(t.window)),Ct}),n(0,function(t){var e=t.createCommonjsModule(function(t){function e(t){return!!("undefined"!=typeof window&&"undefined"!=typeof document&&Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray&&Function.prototype&&Function.prototype.bind&&Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions&&"JSON"in window&&"parse"in JSON&&"stringify"in JSON&&function(){if(!("Worker"in window&&"Blob"in window&&"URL"in window))return!1;var t,e,r=new Blob([""],{type:"text/javascript"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()&&"Uint8ClampedArray"in window&&ArrayBuffer.isView&&function(t){return void 0===r[t]&&(r[t]=function(t){var r=document.createElement("canvas"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext("webgl",n)||r.probablySupportsContext("experimental-webgl",n):r.supportsContext?r.supportsContext("webgl",n)||r.supportsContext("experimental-webgl",n):r.getContext("webgl",n)||r.getContext("experimental-webgl",n)}(t)),r[t]}(t&&t.failIfMajorPerformanceCaveat))}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e);var r={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}}),r={create:function(e,r,n){var a=t.window.document.createElement(e);return void 0!==r&&(a.className=r),n&&n.appendChild(a),a},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function a(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var i,o=a(["userSelect","MozUserSelect","WebkitUserSelect","msUserSelect"]);r.disableDrag=function(){n&&o&&(i=n[o],n[o]="none")},r.enableDrag=function(){n&&o&&(n[o]=i)};var s=a(["transform","WebkitTransform"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},"passive",{get:function(){l=!0}});t.window.addEventListener("test",c,c),t.window.removeEventListener("test",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),"passive"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),"passive"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener("click",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener("click",u,!0),t.window.setTimeout(function(){t.window.removeEventListener("click",u,!0)},0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect(),a=t.window.TouchEvent&&r instanceof t.window.TouchEvent?r.touches[0]:r;return new t.Point(a.clientX-n.left-e.clientLeft,a.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),a=[],i="touchend"===r.type?r.changedTouches:r.touches,o=0;o<i.length;o++)a.push(new t.Point(i[o].clientX-n.left-e.clientLeft,i[o].clientY-n.top-e.clientTop));return a},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf("MAC")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],a=n.ids,i=n.callback;this._notify(a,i)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this.images[t]=e},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,a=t;n<a.length;n+=1){var i=a[n];this.images[i]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},a=0,i=e;a<i.length;a+=1){var o=i[a];this.images[o]||this.fire(new t.Event("styleimagemissing",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image "'+o+'" could not be loaded. Please make sure you have added the image with map.addImage() or a "sprite" property in your style. You can provide missing images by listening for the "styleimagemissing" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var a={w:n.data.width+2,h:n.data.height+2,x:0,y:0},i=new t.ImagePosition(a,n);this.patterns[e]={bin:a,position:i}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),a=n.w,i=n.h,o=this.atlasImage;for(var s in o.resize({width:a||1,height:i||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var a=this.images[n];h(a)&&this.updateImage(n,a)}}},r}(t.Evented),p=v,d=v,g=1e20;function v(t,e,r,n,a,i){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=a||"sans-serif",this.fontWeight=i||"normal",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement("canvas"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext("2d"),this.ctx.font=this.fontWeight+" "+this.fontSize+"px "+this.fontFamily,this.ctx.textBaseline="middle",this.ctx.fillStyle="black",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf("Gecko/")>=0?1.2:1))}function m(t,e,r,n,a,i,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(y(n,a,i,o,r),l=0;l<r;l++)t[l*e+s]=a[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(y(n,a,i,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(a[s])}}function y(t,e,r,n,a){r[0]=0,n[0]=-g,n[1]=+g;for(var i=1,o=0;i<a;i++){for(var s=(t[i]+i*i-(t[r[o]]+r[o]*r[o]))/(2*i-2*r[o]);s<=n[o];)o--,s=(t[i]+i*i-(t[r[o]]+r[o]*r[o]))/(2*i-2*r[o]);r[++o]=i,n[o]=s,n[o+1]=+g}for(i=0,o=0;i<a;i++){for(;n[o+1]<i;)o++;e[i]=(i-r[o])*(i-r[o])+t[r[o]]}}v.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var a=e.data[4*n+3]/255;this.gridOuter[n]=1===a?0:0===a?g:Math.pow(Math.max(0,.5-a),2),this.gridInner[n]=1===a?g:0===a?0:Math.pow(Math.max(0,a-.5),2)}for(m(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),m(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var i=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(i/this.radius+this.cutoff))))}return r},p.default=d;var x=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};x.prototype.setURL=function(t){this.url=t},x.prototype.getGlyphs=function(e,r){var n=this,a=[];for(var i in e)for(var o=0,s=e[i];o<s.length;o+=1){var l=s[o];a.push({stack:i,id:l})}t.asyncAll(a,function(t,e){var r=t.stack,a=t.id,i=n.entries[r];i||(i=n.entries[r]={glyphs:{},requests:{}});var o=i.glyphs[a];if(void 0===o){if(o=n._tinySDF(i,r,a))return i.glyphs[a]=o,void e(null,{stack:r,id:a,glyph:o});var s=Math.floor(a/256);if(256*s>65535)e(new Error("glyphs > 65535 not supported"));else{var l=i.requests[s];l||(l=i.requests[s]=[],x.loadGlyphRange(r,s,n.url,n.requestManager,function(t,e){if(e)for(var r in e)n._doesCharSupportLocalGlyph(+r)||(i.glyphs[+r]=e[+r]);for(var a=0,o=l;a<o.length;a+=1)(0,o[a])(t,e);delete i.requests[s]})),l.push(function(t,n){t?e(t):n&&e(null,{stack:r,id:a,glyph:n[a]||null})})}}else e(null,{stack:r,id:a,glyph:o})},function(t,e){if(t)r(t);else if(e){for(var n={},a=0,i=e;a<i.length;a+=1){var o=i[a],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}})},x.prototype._doesCharSupportLocalGlyph=function(e){return!!this.localIdeographFontFamily&&(t.isChar["CJK Unified Ideographs"](e)||t.isChar["Hangul Syllables"](e)||t.isChar.Hiragana(e)||t.isChar.Katakana(e))},x.prototype._tinySDF=function(e,r,n){var a=this.localIdeographFontFamily;if(a&&this._doesCharSupportLocalGlyph(n)){var i=e.tinySDF;if(!i){var o="400";/bold/i.test(r)?o="900":/medium/i.test(r)?o="500":/light/i.test(r)&&(o="200"),i=e.tinySDF=new x.TinySDF(24,3,8,.25,a,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},i.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},x.loadGlyphRange=function(e,r,n,a,i){var o=256*r,s=o+255,l=a.transformRequest(a.normalizeGlyphsURL(n).replace("{fontstack}",e).replace("{range}",o+"-"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,function(e,r){if(e)i(e);else if(r){for(var n={},a=0,o=t.parseGlyphPBF(r);a<o.length;a+=1){var s=o[a];n[s.id]=s}i(null,n)}})},x.TinySDF=p;var b=function(){this.specification=t.styleSpec.light.position};b.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},b.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var _=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new b,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),w=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(_),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var a=e[n];t.endsWith(n,"-transition")?this._transitionable.setTransition(n.slice(0,-"-transition".length),a):this._transitionable.setValue(n,a)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),k=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.bytes=4,this.data=new Uint8Array(this.width*this.height*this.bytes),this.positions={}};k.prototype.getDash=function(t,e){var r=t.join(",")+String(e);return this.positions[r]||(this.positions[r]=this.addDash(t,e)),this.positions[r]},k.prototype.addDash=function(e,r){var n=r?7:0,a=2*n+1;if(this.nextRow+a>this.height)return t.warnOnce("LineAtlas out of space"),null;for(var i=0,o=0;o<e.length;o++)i+=e[o];for(var s=this.width/i,l=s/2,c=e.length%2==1,u=-n;u<=n;u++)for(var h=this.nextRow+n+u,f=this.width*h,p=c?-e[e.length-1]:0,d=e[0],g=1,v=0;v<this.width;v++){for(;d<v/s;)p=d,d+=e[g],c&&g===e.length-1&&(d+=e[0]),g++;var m=Math.abs(v-p*s),y=Math.abs(v-d*s),x=Math.min(m,y),b=g%2==1,_=void 0;if(r){var w=n?u/n*(l+1):0;if(b){var k=l-Math.abs(w);_=Math.sqrt(x*x+k*k)}else _=l-Math.sqrt(x*x+w*w)}else _=(b?1:-1)*x;this.data[3+4*(f+v)]=Math.max(0,Math.min(255,_+128))}var T={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:i};return this.nextRow+=a,this.dirty=!0,T},k.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.RGBA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.RGBA,this.width,this.height,0,e.RGBA,e.UNSIGNED_BYTE,this.data))};var T=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var a=this.workerPool.acquire(this.id),i=0;i<a.length;i++){var o=a[i],s=new e.Actor(o,n,this.id);s.name="Worker "+i,this.actors.push(s)}};function A(e,r,n){var a=function(a,i){if(a)return n(a);if(i){var o=t.pick(t.extend(i,e),["tiles","minzoom","maxzoom","attribution","mapbox_logo","bounds","scheme","tileSize","encoding"]);i.vector_layers&&(o.vectorLayers=i.vector_layers,o.vectorLayerIds=o.vectorLayers.map(function(t){return t.id})),e.url&&(o.tiles=r.canonicalizeTileset(o,e.url)),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),a):t.browser.frame(function(){return a(null,e)})}T.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,function(t,n){t.send(e,r,n)},n)},T.prototype.getActor=function(){return this.currentActor=(this.currentActor+1)%this.actors.length,this.actors[this.currentActor]},T.prototype.remove=function(){this.actors.forEach(function(t){t.remove()}),this.actors=[],this.workerPool.release(this.id)},T.Actor=t.Actor;var M=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};M.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},M.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),a=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),i=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<i&&e.y>=a&&e.y<o};var S=function(e){function r(r,n,a,i){if(e.call(this),this.id=r,this.dispatcher=a,this.type="vector",this.minzoom=0,this.maxzoom=22,this.scheme="xyz",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,this._loaded=!1,t.extend(this,t.pick(n,["url","scheme","tileSize"])),this._options=t.extend({type:"vector"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error("vector tile sources must have a tileSize of 512");this.setEventedParent(i)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event("dataloading",{dataType:"source"})),this._tileJSONRequest=A(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new M(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles,e.map._requestManager._customAccessToken),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken,e.map._requestManager._customAccessToken),e.fire(new t.Event("data",{dataType:"source",sourceDataType:"metadata"})),e.fire(new t.Event("data",{dataType:"source",sourceDataType:"content"})))})},r.prototype.loaded=function(){return this._loaded},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,null),a={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};function i(n,a){return delete e.request,e.aborted?r(null):n&&404!==n.status?r(n):(a&&a.resourceTiming&&(e.resourceTiming=a.resourceTiming),this.map._refreshExpiredTiles&&a&&e.setExpiryData(a),e.loadVectorData(a,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}a.request.collectResourceTiming=this._collectResourceTiming,e.actor&&"expired"!==e.state?"loading"===e.state?e.reloadCallback=r:e.request=e.actor.send("reloadTile",a,i.bind(this)):(e.actor=this.dispatcher.getActor(),e.request=e.actor.send("loadTile",a,i.bind(this)))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.actor&&t.actor.send("abortTile",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.unloadTile=function(t){t.unloadVectorData(),t.actor&&t.actor.send("removeTile",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,a,i){e.call(this),this.id=r,this.dispatcher=a,this.setEventedParent(i),this.type="raster",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme="xyz",this.tileSize=512,this._loaded=!1,this._options=t.extend({type:"raster"},n),t.extend(this,t.pick(n,["url","scheme","tileSize"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event("dataloading",{dataType:"source"})),this._tileJSONRequest=A(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new M(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event("data",{dataType:"source",sourceDataType:"metadata"})),e.fire(new t.Event("data",{dataType:"source",sourceDataType:"content"})))})},r.prototype.loaded=function(){return this._loaded},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,a=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(a,t.ResourceType.Tile),function(a,i){if(delete e.request,e.aborted)e.state="unloaded",r(null);else if(a)e.state="errored",r(a);else if(i){n.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(i.width),e.texture?e.texture.update(i,{useMipmap:!0}):(e.texture=new t.Texture(o,i,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state="loaded",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}})},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(r,n,a,i){e.call(this,r,n,a,i),this.type="raster-dem",this.maxzoom=22,this._options=t.extend({type:"raster-dem"},n),this.encoding=n.encoding||"mapbox"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:"raster-dem",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,a){if(delete e.request,e.aborted)e.state="unloaded",r(null);else if(n)e.state="errored",r(n);else if(a){this.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var i=t.browser.getImageData(a),o={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:i,encoding:this.encoding};e.actor&&"expired"!==e.state||(e.actor=this.dispatcher.getActor(),e.actor.send("loadDEMTile",o,function(t,n){t&&(e.state="errored",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state="loaded",r(null))}.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),a=(r.x-1+n)%n,i=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,i,r.z,a,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,i,r.z,a,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,i,r.z,a,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state="unloaded",t.actor&&t.actor.send("removeDEMTile",{uid:t.uid,source:this.id})},r}(E),C=function(e){function r(r,n,a,i){e.call(this),this.id=r,this.type="geojson",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this._loaded=!1,this.actor=a.getActor(),this.setEventedParent(i),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution);var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event("dataloading",{dataType:"source"})),this._updateWorkerData(function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:"source",sourceDataType:"metadata"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event("data",n))}})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event("dataloading",{dataType:"source"})),this._updateWorkerData(function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:"source",sourceDataType:"content"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event("data",n))}}),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.actor.send("geojson.getClusterExpansionZoom",{clusterId:t,source:this.id},e),this},r.prototype.getClusterChildren=function(t,e){return this.actor.send("geojson.getClusterChildren",{clusterId:t,source:this.id},e),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.actor.send("geojson.getClusterLeaves",{source:this.id,clusterId:t,limit:e,offset:r},n),this},r.prototype._updateWorkerData=function(e){var r=this;this._loaded=!1;var n=t.extend({},this.workerOptions),a=this._data;"string"==typeof a?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(a),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(a),this.actor.send(this.type+".loadData",n,function(t,a){r._removed||a&&a.abandoned||(r._loaded=!0,a&&a.resourceTiming&&a.resourceTiming[r.id]&&(r._resourceTiming=a.resourceTiming[r.id].slice(0)),r.actor.send(r.type+".coalesce",{source:n.source},null),e(t))})},r.prototype.loaded=function(){return this._loaded},r.prototype.loadTile=function(e,r){var n=this,a=e.actor?"reloadTile":"loadTile";e.actor=this.actor;var i={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};e.request=this.actor.send(a,i,function(t,i){return delete e.request,e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(i,n.map.painter,"reloadTile"===a),r(null))})},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.actor.send("removeTile",{uid:t.uid,type:this.type,source:this.id})},r.prototype.onRemove=function(){this._removed=!0,this.actor.send("removeSource",{type:this.type,source:this.id})},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=function(e){function r(t,r,n,a){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type="image",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this._loaded=!1,this.setEventedParent(a),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this._loaded=!1,this.fire(new t.Event("dataloading",{dataType:"source"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),function(a,i){n._loaded=!0,a?n.fire(new t.ErrorEvent(a)):i&&(n.image=i,e&&(n.coordinates=e),r&&r(),n._finishLoading())})},r.prototype.loaded=function(){return this._loaded},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,function(){e.texture=null}),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event("data",{dataType:"source",sourceDataType:"metadata"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,a=-1/0,i=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),a=Math.max(a,l.x),i=Math.max(i,l.y)}var c=a-r,u=i-n,h=Math.max(c,u),f=Math.max(0,Math.floor(-Math.log(h)/Math.LN2)),p=Math.pow(2,f);return new t.CanonicalTileID(f,Math.floor((r+a)/2*p),Math.floor((n+i)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var a=n.map(function(t){return r.tileID.getTilePoint(t)._round()});return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(a[0].x,a[0].y,0,0),this._boundsArray.emplaceBack(a[1].x,a[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(a[3].x,a[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(a[2].x,a[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event("data",{dataType:"source",sourceDataType:"content"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var a=this.tiles[n];"loaded"!==a.state&&(a.state="loaded",a.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state="errored",e(null))},r.prototype.serialize=function(){return{type:"image",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),O=function(e){function r(t,r,n,a){e.call(this,t,r,n,a),this.roundZoom=!0,this.type="video",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1;var r=this.options;this.urls=[];for(var n=0,a=r.urls;n<a.length;n+=1){var i=a[n];this.urls.push(this.map._requestManager.transformRequest(i,t.ResourceType.Source).url)}t.getVideo(this.urls,function(r,n){e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener("playing",function(){e.map.triggerRepaint()}),e.map&&e.video.play(),e._finishLoading())})},r.prototype.pause=function(){this.video&&this.video.pause()},r.prototype.play=function(){this.video&&this.video.play()},r.prototype.seek=function(e){if(this.video){var r=this.video.seekable;e<r.start(0)||e>r.end(0)?this.fire(new t.ErrorEvent(new t.ValidationError("Playback for this video can be set only between the "+r.start(0)+" and "+r.end(0)+"-second mark."))):this.video.currentTime=e}},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var a=this.tiles[n];"loaded"!==a.state&&(a.state="loaded",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:"video",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(P),z=function(e){function r(r,n,a,i){e.call(this,r,n,a,i),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some(function(t){return!Array.isArray(t)||2!==t.length||t.some(function(t){return"number"!=typeof t})})||this.fire(new t.ErrorEvent(new t.ValidationError("sources."+r,null,'"coordinates" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError("sources."+r,null,'missing required property "coordinates"'))),n.animate&&"boolean"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError("sources."+r,null,'optional "animate" property must be a boolean value'))),n.canvas?"string"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError("sources."+r,null,'"canvas" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError("sources."+r,null,'missing required property "canvas"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this._loaded=!0,this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error("Canvas dimensions cannot be less than or equal to zero."))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var a in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var i=this.tiles[a];"loaded"!==i.state&&(i.state="loaded",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:"canvas",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(P),I={vector:S,raster:E,"raster-dem":L,geojson:C,video:O,image:P,canvas:z},D=function(e,r,n,a){var i=new I[r.type](e,r,n,a);if(i.id!==e)throw new Error("Expected Source id to be "+e+" instead of "+i.id);return t.bindAll(["load","abort","unload","serialize","prepare"],i),i};function R(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function F(t,e,r,n,a){var i=function(t,e,r){if(t)for(var n=0,a=t;n<a.length;n+=1){var i=e[a[n]];if(i&&i.source===r&&"fill-extrusion"===i.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&"fill-extrusion"===s.type)return!0}return!1}(n&&n.layers,e,t.id),o=a.maxPitchScaleFactor(),s=t.tilesIn(r,o,i);s.sort(B);for(var l=[],c=0,u=s;c<u.length;c+=1){var h=u[c];l.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,n,a,o,R(t.transform,h.tileID))})}var f=function(t){for(var e={},r={},n=0,a=t;n<a.length;n+=1){var i=a[n],o=i.queryResults,s=i.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];h[g.featureIndex]||(h[g.featureIndex]=!0,f.push(g))}}return e}(l);for(var p in f)f[p].forEach(function(e){var r=e.feature,n=t.getFeatureState(r.layer["source-layer"],r.id);r.source=r.layer.source,r.layer["source-layer"]&&(r.sourceLayer=r.layer["source-layer"]),r.state=n});return f}function B(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var N=function(t,e){this.max=t,this.onRemove=e,this.reset()};N.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},N.prototype.add=function(t,e,r){var n=this,a=t.wrapped().key;void 0===this.data[a]&&(this.data[a]=[]);var i={value:e,timeout:void 0};if(void 0!==r&&(i.timeout=setTimeout(function(){n.remove(t,i)},r)),this.data[a].push(i),this.order.push(a),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},N.prototype.has=function(t){return t.wrapped().key in this.data},N.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},N.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},N.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},N.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),a=this.data[r][n];return this.data[r].splice(n,1),a.timeout&&clearTimeout(a.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(a.value),this.order.splice(this.order.indexOf(r),1),this},N.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this};var j=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};j.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},j.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},j.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var V={Int8:"BYTE",Uint8:"UNSIGNED_BYTE",Int16:"SHORT",Uint16:"UNSIGNED_SHORT",Int32:"INT",Uint32:"UNSIGNED_INT",Float32:"FLOAT"},U=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var a=t.gl;this.buffer=a.createBuffer(),t.bindVertexBuffer.set(this.buffer),a.bufferData(a.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?a.DYNAMIC_DRAW:a.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};U.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},U.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},U.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],a=e.attributes[n.name];void 0!==a&&t.enableVertexAttribArray(a)}},U.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var a=this.attributes[n],i=e.attributes[a.name];void 0!==i&&t.vertexAttribPointer(i,a.components,t[V[a.type]],!1,this.itemSize,a.offset+this.itemSize*(r||0))}},U.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var q=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};q.prototype.get=function(){return this.current},q.prototype.set=function(t){},q.prototype.getDefault=function(){return this.default},q.prototype.setDefault=function(){this.set(this.default)};var H=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(q),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(q),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(q),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(q),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(q),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(q),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(q),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(q),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(q),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(q),nt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),at=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(q),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(q),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(q),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(q),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(q),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(q),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(q),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(q),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(q),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(q),vt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(q),mt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(q),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(q),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),bt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),_t=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(q),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(_t),kt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(_t),Tt=function(t,e,r){this.context=t,this.width=e,this.height=r;var n=t.gl,a=this.framebuffer=n.createFramebuffer();this.colorAttachment=new wt(t,a),this.depthAttachment=new kt(t,a)};Tt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();e&&t.deleteTexture(e);var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r),t.deleteFramebuffer(this.framebuffer)};var At=function(t,e,r){this.func=t,this.mask=e,this.range=r};At.ReadOnly=!1,At.ReadWrite=!0,At.disabled=new At(519,At.ReadOnly,[0,1]);var Mt=function(t,e,r,n,a,i){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=a,this.pass=i};Mt.disabled=new Mt({func:519,mask:0},0,0,7680,7680,7680);var St=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};St.disabled=new St(St.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),St.unblended=new St(St.Replace,t.Color.transparent,[!0,!0,!0,!0]),St.alphaBlended=new St([1,771],t.Color.transparent,[!0,!0,!0,!0]);var Et=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};Et.disabled=new Et(!1,1029,2305),Et.backCCW=new Et(!0,1029,2305);var Lt=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension("OES_vertex_array_object"),this.clearColor=new H(this),this.clearDepth=new G(this),this.clearStencil=new Y(this),this.colorMask=new W(this),this.depthMask=new X(this),this.stencilMask=new Z(this),this.stencilFunc=new J(this),this.stencilOp=new K(this),this.stencilTest=new Q(this),this.depthRange=new $(this),this.depthTest=new tt(this),this.depthFunc=new et(this),this.blend=new rt(this),this.blendFunc=new nt(this),this.blendColor=new at(this),this.blendEquation=new it(this),this.cullFace=new ot(this),this.cullFaceSide=new st(this),this.frontFace=new lt(this),this.program=new ct(this),this.activeTexture=new ut(this),this.viewport=new ht(this),this.bindFramebuffer=new ft(this),this.bindRenderbuffer=new pt(this),this.bindTexture=new dt(this),this.bindVertexBuffer=new gt(this),this.bindElementBuffer=new vt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new mt(this),this.pixelStoreUnpack=new yt(this),this.pixelStoreUnpackPremultiplyAlpha=new xt(this),this.pixelStoreUnpackFlipY=new bt(this),this.extTextureFilterAnisotropic=t.getExtension("EXT_texture_filter_anisotropic")||t.getExtension("MOZ_EXT_texture_filter_anisotropic")||t.getExtension("WEBKIT_EXT_texture_filter_anisotropic"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension("OES_texture_half_float"),this.extTextureHalfFloat&&t.getExtension("OES_texture_half_float_linear")};Lt.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Lt.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Lt.prototype.createIndexBuffer=function(t,e){return new j(this,t,e)},Lt.prototype.createVertexBuffer=function(t,e,r){return new U(this,t,e,r)},Lt.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,a=n.createRenderbuffer();return this.bindRenderbuffer.set(a),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),a},Lt.prototype.createFramebuffer=function(t,e){return new Tt(this,t,e)},Lt.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,a=0;e&&(a|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(a|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(a)},Lt.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Lt.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Lt.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Lt.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,St.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Lt.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Ct=function(e){function r(r,n,a){var i=this;e.call(this),this.id=r,this.dispatcher=a,this.on("data",function(t){"source"===t.dataType&&"metadata"===t.sourceDataType&&(i._sourceLoaded=!0),i._sourceLoaded&&!i._paused&&"source"===t.dataType&&"content"===t.sourceDataType&&(i.reload(),i.transform&&i.update(i.transform))}),this.on("error",function(){i._sourceErrored=!0}),this._source=D(r,n,a,this),this._tiles={},this._cache=new N(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;if(!this._source.loaded())return!1;for(var t in this._tiles){var e=this._tiles[t];if("loaded"!==e.state&&"errored"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,function(){})},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,function(){})},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return Object.keys(this._tiles).map(Number).sort(Pt)},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var a in this._tiles)this._isIdRenderable(+a,e)&&n.push(+a);return e?n.sort(function(e,n){var a=r._tiles[e].tileID,i=r._tiles[n].tileID,o=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle),s=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle);return a.overscaledZ-i.overscaledZ||s.y-o.y||s.x-o.x}):n.sort(Pt)},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)"errored"!==this._tiles[t].state&&this._reloadTile(t,"reloading")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&("loading"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,a){if(a)return e.state="errored",void(404!==a.status?this._source.fire(new t.ErrorEvent(a,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),"expired"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),"raster-dem"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event("data",{dataType:"source",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var a=this.getTileByID(n);i(t,a),i(a,t)}}function i(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,a=Math.pow(2,t.tileID.canonical.z),i=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+a)?r+=a:1===Math.abs(r-a)&&(r-=a)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[i]&&(t.neighboringTiles[i].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype.getZoom=function(t){return t.zoom+t.scaleZoom(t.tileSize/this._source.tileSize)},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var a in this._tiles){var i=this._tiles[a];if(!(n[a]||!i.hasData()||i.tileID.overscaledZ<=e||i.tileID.overscaledZ>r)){for(var o=i.tileID;i&&i.tileID.overscaledZ>e+1;){var s=i.tileID.scaledTo(i.tileID.overscaledZ-1);(i=this._tiles[s.key])&&i.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){for(var r=t.overscaledZ-1;r>=e;r--){var n=t.scaledTo(r);if(!n)return;var a=String(n.key),i=this._tiles[a];if(i&&i.hasData())return i;if(this._cache.has(n))return this._cache.get(n)}},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n="number"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var a in this._tiles){var i=this._tiles[a];i.tileID=i.tileID.unwrapTo(i.tileID.wrap+r),n[i.tileID.key]=i}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var a;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?a=e.getVisibleUnwrappedCoordinates(this._source.tileID).map(function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)}):(a=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(a=a.filter(function(t){return n._source.hasTile(t)}))):a=[];var i=(this._source.roundZoom?Math.round:Math.floor)(this.getZoom(e)),o=Math.max(i-r.maxOverzooming,this._source.minzoom),s=Math.max(i+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(a,i);if(Ot(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var v=this.findLoadedParent(d,o);v&&(this._addTile(v.tileID),c[v.tileID.key]=v.tileID),u[p]=d}}for(var m in this._retainLoadedChildren(u,i,s,l),c)l[m]||(this._coveredTiles[m]=!0,l[m]=c[m])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},a={},i=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var v=d.children(this._source.maxzoom)[0],m=this.getTile(v);if(m&&m.hasData()){n[v.key]=v;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=i;--b){var _=d.scaledTo(b);if(a[_.key])break;if(a[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event("dataloading",{tile:r,coord:r.tileID,dataType:"source"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout(function(){r._reloadTile(t,"expired"),delete r._timers[t]},n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()&&"reloading"!==e.state?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var a=this,i=[],o=this.transform;if(!o)return i;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map(function(t){return o.pointCoordinate(t)}),c=s.map(function(t){return o.pointCoordinate(t)}),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,g=0,v=c;g<v.length;g+=1){var m=v[g];h=Math.min(h,m.x),f=Math.min(f,m.y),p=Math.max(p,m.x),d=Math.max(d,m.y)}for(var y=function(e){var n=a._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),v=r*n.queryPadding*t.EXTENT/n.tileSize/g,m=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(m[0].x-v<t.EXTENT&&m[0].y-v<t.EXTENT&&m[1].x+v>=0&&m[1].y+v>=0){var y=l.map(function(t){return s.getTilePoint(t)}),x=c.map(function(t){return s.getTilePoint(t)});i.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return i},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map(function(t){return e._tiles[t].tileID}),n=0,a=r;n<a.length;n+=1){var i=a[n];i.posMatrix=this.transform.calculatePosMatrix(i.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Ot(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||"_geojsonTileLayer",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||"_geojsonTileLayer",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||"_geojsonTileLayer",this._state.getState(t,e)},r}(t.Evented);function Pt(t,e){return t%32-e%32||e-t}function Ot(t){return"raster"===t||"image"===t||"video"===t}function zt(){return new t.window.Worker(Qn.workerUrl)}Ct.maxOverzooming=10,Ct.maxUnderzooming=3;var It=function(){this.active={}};It.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<It.workerCount;)this.workers.push(new zt);return this.active[t]=!0,this.workers.slice()},It.prototype.release=function(t){delete this.active[t],0===Object.keys(this.active).length&&(this.workers.forEach(function(t){t.terminate()}),this.workers=null)};var Dt,Rt=Math.floor(t.browser.hardwareConcurrency/2);function Ft(e,r){var n={};for(var a in e)"ref"!==a&&(n[a]=e[a]);return t.refProperties.forEach(function(t){t in r&&(n[t]=r[t])}),n}function Bt(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)"ref"in t[n]&&(t[n]=Ft(t[n],e[t[n].ref]));return t}It.workerCount=Math.max(Math.min(Rt,6),1);var Nt={setStyle:"setStyle",addLayer:"addLayer",removeLayer:"removeLayer",setPaintProperty:"setPaintProperty",setLayoutProperty:"setLayoutProperty",setFilter:"setFilter",addSource:"addSource",removeSource:"removeSource",setGeoJSONSourceData:"setGeoJSONSourceData",setLayerZoomRange:"setLayerZoomRange",setLayerProperty:"setLayerProperty",setCenter:"setCenter",setZoom:"setZoom",setBearing:"setBearing",setPitch:"setPitch",setSprite:"setSprite",setGlyphs:"setGlyphs",setTransition:"setTransition",setLight:"setLight"};function jt(t,e,r){r.push({command:Nt.addSource,args:[t,e[t]]})}function Vt(t,e,r){e.push({command:Nt.removeSource,args:[t]}),r[t]=!0}function Ut(t,e,r,n){Vt(t,r,n),jt(t,e,r)}function qt(e,r,n){var a;for(a in e[n])if(e[n].hasOwnProperty(a)&&"data"!==a&&!t.deepEqual(e[n][a],r[n][a]))return!1;for(a in r[n])if(r[n].hasOwnProperty(a)&&"data"!==a&&!t.deepEqual(e[n][a],r[n][a]))return!1;return!0}function Ht(e,r,n,a,i,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[a,s,r[s],i]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[a,s,r[s],i]}))}function Gt(t){return t.id}function Yt(t,e){return t[e.id]=e,t}var Wt=function(t,e,r){var n=this.boxCells=[],a=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var i=0;i<this.xCellCount*this.yCellCount;i++)n.push([]),a.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Xt(e,r,n,a,i){var o=t.create();return r?(t.scale(o,o,[1/i,1/i,1]),n||t.rotateZ(o,o,a.angle)):t.multiply(o,a.labelPlaneMatrix,e),o}function Zt(e,r,n,a,i){if(r){var o=t.clone(e);return t.scale(o,o,[i,i,1]),n||t.rotateZ(o,o,-a.angle),o}return a.glCoordMatrix}function Jt(e,r){var n=[e.x,e.y,0,1];oe(n,n,r);var a=n[3];return{point:new t.Point(n[0]/a,n[1]/a),signedDistanceFromCamera:a}}function Kt(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function Qt(e,r,n,a,i,o,s,l){var c=a?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=a?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=a?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,v=!1,m=0;m<d.length;m++){var y=d.get(m);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!v)ie(y.numGlyphs,f);else{v=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),Kt(x,h)){var b=.5+x[3]/n.transform.cameraToCenterDistance*.5,_=t.evaluateSizeForFeature(c,u,y),w=s?_*b:_/b,k=new t.Point(y.anchorX,y.anchorY),T=Jt(k,i).point,A={},M=ee(y,w,!1,l,r,i,o,e.glyphOffsetArray,p,f,T,k,A,g);v=M.useVertical,(M.notEnoughRoom||v||M.needsFlipping&&ee(y,w,!0,l,r,i,o,e.glyphOffsetArray,p,f,T,k,A,g).notEnoughRoom)&&ie(y.numGlyphs,f)}else ie(y.numGlyphs,f)}}a?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function $t(t,e,r,n,a,i,o,s,l,c,u,h){var f=s.glyphStartIndex+s.numGlyphs,p=s.lineStartIndex,d=s.lineStartIndex+s.lineLength,g=e.getoffsetX(s.glyphStartIndex),v=e.getoffsetX(f-1),m=ne(t*g,r,n,a,i,o,s.segment,p,d,l,c,u,h);if(!m)return null;var y=ne(t*v,r,n,a,i,o,s.segment,p,d,l,c,u,h);return y?{first:m,last:y}:null}function te(e,r,n,a){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*a?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function ee(e,r,n,a,i,o,s,l,c,u,h,f,p,d){var g,v=r/24,m=e.lineOffsetX*v,y=e.lineOffsetY*v;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=$t(v,l,m,y,n,h,f,e,c,o,p,!1);if(!w)return{notEnoughRoom:!0};var k=Jt(w.first.point,s).point,T=Jt(w.last.point,s).point;if(a&&!n){var A=te(e.writingMode,k,T,d);if(A)return A}g=[w.first];for(var M=e.glyphStartIndex+1;M<x-1;M++)g.push(ne(v*l.getoffsetX(M),m,y,n,h,f,e.segment,b,_,c,o,p,!1));g.push(w.last)}else{if(a&&!n){var S=Jt(f,i).point,E=e.lineStartIndex+e.segment+1,L=new t.Point(c.getx(E),c.gety(E)),C=Jt(L,i),P=C.signedDistanceFromCamera>0?C.point:re(f,L,S,1,i),O=te(e.writingMode,S,P,d);if(O)return O}var z=ne(v*l.getoffsetX(e.glyphStartIndex),m,y,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p,!1);if(!z)return{notEnoughRoom:!0};g=[z]}for(var I=0,D=g;I<D.length;I+=1){var R=D[I];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function re(t,e,r,n,a){var i=Jt(t.add(t.sub(e)._unit()),a).point,o=r.sub(i);return r.add(o._mult(n/o.mag()))}function ne(e,r,n,a,i,o,s,l,c,u,h,f,p){var d=a?e-r:e+r,g=d>0?1:-1,v=0;a&&(g*=-1,v=Math.PI),g<0&&(v+=Math.PI);for(var m=g>0?l+s:l+s+1,y=m,x=i,b=i,_=0,w=0,k=Math.abs(d);_+w<=k;){if((m+=g)<l||m>=c)return null;if(b=x,void 0===(x=f[m])){var T=new t.Point(u.getx(m),u.gety(m)),A=Jt(T,h);if(A.signedDistanceFromCamera>0)x=f[m]=A.point;else{var M=m-g;x=re(0===_?o:new t.Point(u.getx(M),u.gety(M)),T,b,k-_+1,h)}}_+=w,w=b.dist(x)}var S=(k-_)/w,E=x.sub(b),L=E.mult(S)._add(b);return L._add(E._unit()._perp()._mult(n*g)),{point:L,angle:v+Math.atan2(x.y-b.y,x.x-b.x),tileDistance:p?{prevTileDistance:m-g===y?0:u.gettileUnitDistanceFromAnchor(m-g),lastSegmentViewportDistance:k-_}:null}}Wt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Wt.prototype.insert=function(t,e,r,n,a){this._forEachCell(e,r,n,a,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(a)},Wt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Wt.prototype._insertBoxCell=function(t,e,r,n,a,i){this.boxCells[a].push(i)},Wt.prototype._insertCircleCell=function(t,e,r,n,a,i){this.circleCells[a].push(i)},Wt.prototype._query=function(t,e,r,n,a,i){if(r<0||t>this.width||n<0||e>this.height)return!a&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(a)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return i?o.filter(i):o}var f={hitTest:a,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,f,i),a?o.length>0:o},Wt.prototype._queryCircle=function(t,e,r,n,a){var i=t-r,o=t+r,s=e-r,l=e+r;if(o<0||i>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(i,s,o,l,this._queryCellCircle,c,u,a),n?c.length>0:c},Wt.prototype.query=function(t,e,r,n,a){return this._query(t,e,r,n,!1,a)},Wt.prototype.hitTest=function(t,e,r,n,a){return this._query(t,e,r,n,!0,a)},Wt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Wt.prototype._queryCell=function(t,e,r,n,a,i,o,s){var l=o.seenUids,c=this.boxCells[a];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return i.push(!0),!0;i.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[a];if(null!==g)for(var v=this.circles,m=0,y=g;m<y.length;m+=1){var x=y[m];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(v[b],v[b+1],v[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return i.push(!0),!0;var _=v[b],w=v[b+1],k=v[b+2];i.push({key:this.circleKeys[x],x1:_-k,y1:w-k,x2:_+k,y2:w+k})}}}},Wt.prototype._queryCellCircle=function(t,e,r,n,a,i,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[a];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[g+0],h[g+1],h[g+2],h[g+3])&&(!s||s(this.boxKeys[d])))return i.push(!0),!0}}var v=this.circleCells[a];if(null!==v)for(var m=this.circles,y=0,x=v;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(m[_],m[_+1],m[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return i.push(!0),!0}}},Wt.prototype._forEachCell=function(t,e,r,n,a,i,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.xCellCount*p+f;if(a.call(this,t,e,r,n,d,i,o,s))return}},Wt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Wt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Wt.prototype._circlesCollide=function(t,e,r,n,a,i){var o=n-t,s=a-e,l=r+i;return l*l>o*o+s*s},Wt.prototype._circleAndRectCollide=function(t,e,r,n,a,i,o){var s=(i-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-a)/2,u=Math.abs(e-(a+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var ae=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ie(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(ae,3*n)}}function oe(t,e,r){var n=e[0],a=e[1];return t[0]=r[0]*n+r[4]*a+r[12],t[1]=r[1]*n+r[5]*a+r[13],t[3]=r[3]*n+r[7]*a+r[15],t}var se=function(t,e,r){void 0===e&&(e=new Wt(t.width+200,t.height+200,25)),void 0===r&&(r=new Wt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function le(t,e,r){t[e+4]=r?1:0}function ce(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}se.prototype.placeCollisionBox=function(t,e,r,n,a){var i=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*i.perspectiveRatio,s=t.x1*o+i.point.x,l=t.y1*o+i.point.y,c=t.x2*o+i.point.x,u=t.y2*o+i.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,a)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},se.prototype.approximateTileDistance=function(t,e,r,n,a){var i=a?1:n/this.pitchfactor,o=t.lastSegmentViewportDistance*r;return t.prevTileDistance+o+(i-1)*o*Math.abs(Math.sin(e))},se.prototype.placeCollisionCircles=function(e,r,n,a,i,o,s,l,c,u,h,f,p){var d=[],g=this.projectAnchor(c,i.anchorX,i.anchorY),v=l/24,m=i.lineOffsetX*l,y=i.lineOffsetY*l,x=new t.Point(i.anchorX,i.anchorY),b=$t(v,s,m,y,!1,Jt(x,u).point,x,i,o,u,{},!0),_=!1,w=!1,k=!0,T=g.perspectiveRatio*a,A=1/(a*n),M=0,S=0;b&&(M=this.approximateTileDistance(b.first.tileDistance,b.first.angle,A,g.cameraDistance,f),S=this.approximateTileDistance(b.last.tileDistance,b.last.angle,A,g.cameraDistance,f));for(var E=0;E<e.length;E+=5){var L=e[E],C=e[E+1],P=e[E+2],O=e[E+3];if(!b||O<-M||O>S)le(e,E,!1);else{var z=this.projectPoint(c,L,C),I=P*T;if(d.length>0){var D=z.x-d[d.length-4],R=z.y-d[d.length-3];if(I*I*2>D*D+R*R&&E+8<e.length){var F=e[E+8];if(F>-M&&F<S){le(e,E,!1);continue}}}var B=E/5;d.push(z.x,z.y,I,B),le(e,E,!0);var N=z.x-I,j=z.y-I,V=z.x+I,U=z.y+I;if(k=k&&this.isOffscreen(N,j,V,U),w=w||this.isInsideGrid(N,j,V,U),!r&&this.grid.hitTestCircle(z.x,z.y,I,p)){if(!h)return{circles:[],offscreen:!1};_=!0}}}return{circles:_||!w?[]:d,offscreen:k}},se.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,a=1/0,i=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),a=Math.min(a,u.y),i=Math.max(i,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,a,i,o).concat(this.ignoredGrid.query(n,a,i,o));p<d.length;p+=1){var g=d[p],v=g.key;if(void 0===h[v.bucketInstanceId]&&(h[v.bucketInstanceId]={}),!h[v.bucketInstanceId][v.featureIndex]){var m=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,m)&&(h[v.bucketInstanceId][v.featureIndex]=!0,void 0===f[v.bucketInstanceId]&&(f[v.bucketInstanceId]=[]),f[v.bucketInstanceId].push(v.featureIndex))}}return f},se.prototype.insertCollisionBox=function(t,e,r,n,a){var i={bucketInstanceId:r,featureIndex:n,collisionGroupID:a};(e?this.ignoredGrid:this.grid).insert(i,t[0],t[1],t[2],t[3])},se.prototype.insertCollisionCircles=function(t,e,r,n,a){for(var i=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:a},s=0;s<t.length;s+=4)i.insertCircle(o,t[s],t[s+1],t[s+2])},se.prototype.projectAnchor=function(t,e,r){var n=[e,r,0,1];return oe(n,n,t),{perspectiveRatio:.5+this.transform.cameraToCenterDistance/n[3]*.5,cameraDistance:n[3]}},se.prototype.projectPoint=function(e,r,n){var a=[r,n,0,1];return oe(a,a,e),new t.Point((a[0]/a[3]+1)/2*this.transform.width+100,(-a[1]/a[3]+1)/2*this.transform.height+100)},se.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var a=[r,n,0,1];return oe(a,a,e),{point:new t.Point((a[0]/a[3]+1)/2*this.transform.width+100,(-a[1]/a[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/a[3]*.5}},se.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},se.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary};var ue=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};ue.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var he=function(t,e,r,n,a){this.text=new ue(t?t.text:null,e,r,a),this.icon=new ue(t?t.icon:null,e,n,a)};he.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var fe=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},pe=function(t,e,r,n,a){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=a},de=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function ge(e,r,n,a,i){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateRadialOffset(e,a);return new t.Point(s+c[0]*i,l+c[1]*i)}de.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var ve=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new se(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new de(r),this.prevPlacement=n,n&&(n.prevPlacement=void 0),this.placedOrientations={}};function me(t,e,r,n,a){t.emplaceBack(e?1:0,r?1:0,n||0,a||0),t.emplaceBack(e?1:0,r?1:0,n||0,a||0),t.emplaceBack(e?1:0,r?1:0,n||0,a||0),t.emplaceBack(e?1:0,r?1:0,n||0,a||0)}ve.prototype.placeLayerTile=function(e,r,n,a){var i=r.getBucket(e),o=r.latestFeatureIndex;if(i&&o&&e.id===i.layerIds[0]){var s=r.collisionBoxArray,l=i.layers[0].layout,c=Math.pow(2,this.transform.zoom-r.tileID.overscaledZ),u=r.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(r.tileID.toUnwrapped()),f=Xt(h,"map"===l.get("text-pitch-alignment"),"map"===l.get("text-rotation-alignment"),this.transform,ce(r,1,this.transform.zoom)),p=Xt(h,"map"===l.get("icon-pitch-alignment"),"map"===l.get("icon-rotation-alignment"),this.transform,ce(r,1,this.transform.zoom));this.retainedQueryData[i.bucketInstanceId]=new pe(i.bucketInstanceId,o,i.sourceLayerIndex,i.index,r.tileID),this.placeLayerBucket(i,h,f,p,c,u,n,r.holdingForFade(),a,s)}},ve.prototype.attemptAnchorPlacement=function(e,r,n,a,i,o,s,l,c,u,h,f,p,d,g){var v,m=ge(e,n,a,i,o),y=this.collisionIndex.placeCollisionBox(function(e,r,n,a,i,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return a&&p._rotate(i?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}(r,m.x,m.y,s,l,this.transform.angle),f,c,u,h.predicate);if(y.box.length>0)return this.prevPlacement&&this.prevPlacement.variableOffsets[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID].text&&(v=this.prevPlacement.variableOffsets[p.crossTileID].anchor),this.variableOffsets[p.crossTileID]={radialOffset:i,width:n,height:a,anchor:e,textBoxScale:o,prevAnchor:v},this.markUsedJustification(d,e,p,g),d.allowVerticalPlacement&&(this.markUsedOrientation(d,g,p),this.placedOrientations[p.crossTileID]=g),y},ve.prototype.placeLayerBucket=function(e,r,n,a,i,o,s,l,c,u){var h=this,f=e.layers[0].layout,p=t.evaluateSizeForZoom(e.textSizeData,this.transform.zoom),d=f.get("text-optional"),g=f.get("icon-optional"),v=f.get("text-allow-overlap"),m=f.get("icon-allow-overlap"),y=v&&(m||!e.hasIconData()||g),x=m&&(v||!e.hasTextData()||d),b=this.collisionGroups.get(e.sourceID),_="map"===f.get("text-rotation-alignment"),w="map"===f.get("text-pitch-alignment"),k="viewport-y"===f.get("symbol-z-order");!e.collisionArrays&&u&&e.deserializeCollisionBoxes(u);var T=function(a,u){if(!c[a.crossTileID])if(l)h.placements[a.crossTileID]=new fe(!1,!1,!1);else{var m,k=!1,T=!1,A=!0,M={box:null,offscreen:null},S={box:null,offscreen:null},E=null,L=null,C=0,P=0,O=0;u.textFeatureIndex&&(C=u.textFeatureIndex),u.verticalTextFeatureIndex&&(P=u.verticalTextFeatureIndex);var z=u.textBox;if(z){var I=function(r){var n=t.WritingMode.horizontal;if(e.allowVerticalPlacement&&!r&&h.prevPlacement){var i=h.prevPlacement.placedOrientations[a.crossTileID];i&&(h.placedOrientations[a.crossTileID]=i,n=i,h.markUsedOrientation(e,n,a))}return n},D=function(r,n){if(e.allowVerticalPlacement&&a.numVerticalGlyphVertices>0&&u.verticalTextBox)for(var i=0,o=e.writingModes;i<o.length&&(o[i]===t.WritingMode.vertical?(M=n(),S=M):M=r(),!(M&&M.box&&M.box.length));i+=1);else M=r()};if(f.get("text-variable-anchor")){var R=f.get("text-variable-anchor");if(h.prevPlacement&&h.prevPlacement.variableOffsets[a.crossTileID]){var F=h.prevPlacement.variableOffsets[a.crossTileID];R.indexOf(F.anchor)>0&&(R=R.filter(function(t){return t!==F.anchor})).unshift(F.anchor)}var B=function(t,n){for(var i=t.x2-t.x1,s=t.y2-t.y1,l=a.textBoxScale,c={box:[],offscreen:!1},u=v?2*R.length:R.length,f=0;f<u;++f){var p=R[f%R.length],d=f>=R.length;if((c=h.attemptAnchorPlacement(p,t,i,s,a.radialTextOffset,l,_,w,o,r,b,d,a,e,n))&&c.box&&c.box.length){k=!0;break}}return c};D(function(){return B(z,t.WritingMode.horizontal)},function(){var r=u.verticalTextBox,n=M&&M.box&&M.box.length;return e.allowVerticalPlacement&&!n&&a.numVerticalGlyphVertices>0&&r?B(r,t.WritingMode.vertical):{box:null,offscreen:null}}),M&&(k=M.box,A=M.offscreen);var N=I(M&&M.box);if(!k&&h.prevPlacement){var j=h.prevPlacement.variableOffsets[a.crossTileID];j&&(h.variableOffsets[a.crossTileID]=j,h.markUsedJustification(e,j.anchor,a,N))}}else{var V=function(t,n){var i=h.collisionIndex.placeCollisionBox(t,f.get("text-allow-overlap"),o,r,b.predicate);return i&&i.box&&i.box.length&&(h.markUsedOrientation(e,n,a),h.placedOrientations[a.crossTileID]=n),i};D(function(){return V(z,t.WritingMode.horizontal)},function(){var r=u.verticalTextBox;return e.allowVerticalPlacement&&a.numVerticalGlyphVertices>0&&r?V(r,t.WritingMode.vertical):{box:null,offscreen:null}}),I(M&&M.box&&M.box.length)}}k=(m=M)&&m.box&&m.box.length>0,A=m&&m.offscreen;var U=u.textCircles;if(U){var q=e.text.placedSymbolArray.get(a.centerJustifiedTextSymbolIndex),H=t.evaluateSizeForFeature(e.textSizeData,p,q);E=h.collisionIndex.placeCollisionCircles(U,f.get("text-allow-overlap"),i,o,q,e.lineVertexArray,e.glyphOffsetArray,H,r,n,s,w,b.predicate),k=f.get("text-allow-overlap")||E.circles.length>0,A=A&&E.offscreen}u.iconFeatureIndex&&(O=u.iconFeatureIndex),u.iconBox&&(T=(L=h.collisionIndex.placeCollisionBox(u.iconBox,f.get("icon-allow-overlap"),o,r,b.predicate)).box.length>0,A=A&&L.offscreen);var G=d||0===a.numHorizontalGlyphVertices&&0===a.numVerticalGlyphVertices,Y=g||0===a.numIconVertices;G||Y?Y?G||(T=T&&k):k=T&&k:T=k=T&&k,k&&m&&m.box&&(S&&S.box&&P?h.collisionIndex.insertCollisionBox(m.box,f.get("text-ignore-placement"),e.bucketInstanceId,P,b.ID):h.collisionIndex.insertCollisionBox(m.box,f.get("text-ignore-placement"),e.bucketInstanceId,C,b.ID)),T&&L&&h.collisionIndex.insertCollisionBox(L.box,f.get("icon-ignore-placement"),e.bucketInstanceId,O,b.ID),k&&E&&h.collisionIndex.insertCollisionCircles(E.circles,f.get("text-ignore-placement"),e.bucketInstanceId,C,b.ID),h.placements[a.crossTileID]=new fe(k||y,T||x,A||e.justReloaded),c[a.crossTileID]=!0}};if(k)for(var A=e.getSortedSymbolIndexes(this.transform.angle),M=A.length-1;M>=0;--M){var S=A[M];T(e.symbolInstances.get(S),e.collisionArrays[S])}else for(var E=0;E<e.symbolInstances.length;++E)T(e.symbolInstances.get(E),e.collisionArrays[E]);e.justReloaded=!1},ve.prototype.markUsedJustification=function(e,r,n,a){var i,o={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex};i=a===t.WritingMode.vertical?n.verticalPlacedTextSymbolIndex:o[t.getAnchorJustification(r)];for(var s=0,l=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex,n.verticalPlacedTextSymbolIndex];s<l.length;s+=1){var c=l[s];c>=0&&(e.text.placedSymbolArray.get(c).crossTileID=i>=0&&c!==i?0:n.crossTileID)}},ve.prototype.markUsedOrientation=function(e,r,n){for(var a=r===t.WritingMode.horizontal||r===t.WritingMode.horizontalOnly?r:0,i=r===t.WritingMode.vertical?r:0,o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex];o<s.length;o+=1){var l=s[o];e.text.placedSymbolArray.get(l).placedOrientation=a}n.verticalPlacedTextSymbolIndex&&(e.text.placedSymbolArray.get(n.verticalPlacedTextSymbolIndex).placedOrientation=i)},ve.prototype.commit=function(t){this.commitTime=t;var e=this.prevPlacement,r=!1,n=e&&0!==this.fadeDuration?(this.commitTime-e.commitTime)/this.fadeDuration:1,a=e?e.opacities:{},i=e?e.variableOffsets:{},o=e?e.placedOrientations:{};for(var s in this.placements){var l=this.placements[s],c=a[s];c?(this.opacities[s]=new he(c,n,l.text,l.icon),r=r||l.text!==c.text.placed||l.icon!==c.icon.placed):(this.opacities[s]=new he(null,n,l.text,l.icon,l.skipFade),r=r||l.text||l.icon)}for(var u in a){var h=a[u];if(!this.opacities[u]){var f=new he(h,n,!1,!1);f.isHidden()||(this.opacities[u]=f,r=r||h.text.placed||h.icon.placed)}}for(var p in i)this.variableOffsets[p]||!this.opacities[p]||this.opacities[p].isHidden()||(this.variableOffsets[p]=i[p]);for(var d in o)this.placedOrientations[d]||!this.opacities[d]||this.opacities[d].isHidden()||(this.placedOrientations[d]=o[d]);r?this.lastPlacementChangeTime=t:"number"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},ve.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,a=e;n<a.length;n+=1){var i=a[n],o=i.getBucket(t);o&&i.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,i.collisionBoxArray)}},ve.prototype.updateBucketOpacities=function(e,r,n){e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexArray.clear(),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexArray.clear();var a=e.layers[0].layout,i=new he(null,0,!1,!1,!0),o=a.get("text-allow-overlap"),s=a.get("icon-allow-overlap"),l=a.get("text-variable-anchor"),c="map"===a.get("text-rotation-alignment"),u="map"===a.get("text-pitch-alignment"),h=new he(null,0,o&&(s||!e.hasIconData()||a.get("icon-optional")),s&&(o||!e.hasTextData()||a.get("text-optional")),!0);!e.collisionArrays&&n&&(e.hasCollisionBoxData()||e.hasCollisionCircleData())&&e.deserializeCollisionBoxes(n);for(var f=0;f<e.symbolInstances.length;f++){var p=e.symbolInstances.get(f),d=p.numHorizontalGlyphVertices,g=p.numVerticalGlyphVertices,v=p.crossTileID,m=r[v],y=this.opacities[v];m?y=i:y||(y=h,this.opacities[v]=y),r[v]=!0;var x=d>0||g>0,b=p.numIconVertices>0;if(x){for(var _=Ae(y.text),w=(d+g)/4,k=0;k<w;k++)e.text.opacityVertexArray.emplaceBack(_);var T=y.text.isHidden()?1:0,A=this.placedOrientations[p.crossTileID],M=A===t.WritingMode.horizontal||A===t.WritingMode.horizontalOnly?1:0,S=A===t.WritingMode.vertical?1:0;[p.rightJustifiedTextSymbolIndex,p.centerJustifiedTextSymbolIndex,p.leftJustifiedTextSymbolIndex].forEach(function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=T||S)}),p.verticalPlacedTextSymbolIndex>=0&&(e.text.placedSymbolArray.get(p.verticalPlacedTextSymbolIndex).hidden=T||M);var E=this.variableOffsets[p.crossTileID];E&&this.markUsedJustification(e,E.anchor,p,A);var L=this.placedOrientations[p.crossTileID];L&&(this.markUsedJustification(e,"left",p,L),this.markUsedOrientation(e,L,p))}if(b){for(var C=Ae(y.icon),P=0;P<p.numIconVertices/4;P++)e.icon.opacityVertexArray.emplaceBack(C);e.icon.placedSymbolArray.get(f).hidden=y.icon.isHidden()}if(e.hasCollisionBoxData()||e.hasCollisionCircleData()){var O=e.collisionArrays[f];if(O){if(O.textBox){var z=new t.Point(0,0),I=!0;if(l){var D=this.variableOffsets[v];D?(z=ge(D.anchor,D.width,D.height,D.radialOffset,D.textBoxScale),c&&z._rotate(u?this.transform.angle:-this.transform.angle)):I=!1}me(e.collisionBox.collisionVertexArray,y.text.placed,!I,z.x,z.y)}O.iconBox&&me(e.collisionBox.collisionVertexArray,y.icon.placed,!1);var R=O.textCircles;if(R&&e.hasCollisionCircleData())for(var F=0;F<R.length;F+=5){var B=m||0===R[F+4];me(e.collisionCircle.collisionVertexArray,y.text.placed,B)}}}}e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexBuffer&&e.collisionBox.collisionVertexBuffer.updateData(e.collisionBox.collisionVertexArray),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexBuffer&&e.collisionCircle.collisionVertexBuffer.updateData(e.collisionCircle.collisionVertexArray)},ve.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration},ve.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},ve.prototype.stillRecent=function(t){return this.commitTime+this.fadeDuration>t},ve.prototype.setStale=function(){this.stale=!0};var ye=Math.pow(2,25),xe=Math.pow(2,24),be=Math.pow(2,17),_e=Math.pow(2,16),we=Math.pow(2,9),ke=Math.pow(2,8),Te=Math.pow(2,1);function Ae(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*ye+e*xe+r*be+e*_e+r*we+e*ke+r*Te+e}var Me=function(){this._currentTileIndex=0,this._seenCrossTileIDs={}};Me.prototype.continuePlacement=function(t,e,r,n,a){for(;this._currentTileIndex<t.length;){var i=t[this._currentTileIndex];if(e.placeLayerTile(n,i,r,this._seenCrossTileIDs),this._currentTileIndex++,a())return!0}};var Se=function(t,e,r,n,a,i,o){this.placement=new ve(t,a,i,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Se.prototype.isDone=function(){return this._done},Se.prototype.continuePlacement=function(e,r,n){for(var a=this,i=t.browser.now(),o=function(){var e=t.browser.now()-i;return!a._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if("symbol"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Me),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},Se.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Ee=512/t.EXTENT/2,Le=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var a=e.get(n),i=a.key;this.indexedSymbolInstances[i]||(this.indexedSymbolInstances[i]=[]),this.indexedSymbolInstances[i].push({crossTileID:a.crossTileID,coord:this.getScaledCoordinates(a,t)})}};Le.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,a=Ee/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*a),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*a)}},Le.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),a=0;a<t.length;a++){var i=t.get(a);if(!i.crossTileID){var o=this.indexedSymbolInstances[i.key];if(o)for(var s=this.getScaledCoordinates(i,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,i.crossTileID=u.crossTileID;break}}}}};var Ce=function(){this.maxCrossTileID=0};Ce.prototype.generate=function(){return++this.maxCrossTileID};var Pe=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Pe.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],a={};for(var i in n){var o=n[i];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),a[o.tileID.key]=o}this.indexes[r]=a}this.lng=t},Pe.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var a=this.usedCrossTileIDs[t.overscaledZ];for(var i in this.indexes){var o=this.indexes[i];if(Number(i)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,a)}else{var c=o[t.scaledTo(Number(i)).key];c&&c.findMatches(e.symbolInstances,t,a)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),a[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Le(t,e.symbolInstances,e.bucketInstanceId),!0},Pe.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,a=e.indexedSymbolInstances[r];n<a.length;n+=1){var i=a[n];delete this.usedCrossTileIDs[t][i.crossTileID]}},Pe.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var a in n)t[n[a].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[a]),delete n[a],e=!0)}return e};var Oe=function(){this.layerIndexes={},this.crossTileIDs=new Ce,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Oe.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Pe);var a=!1,i={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(a=!0),i[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(i)&&(a=!0),a},Oe.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach(function(t){e[t]=!0}),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var ze=function(e,r){return t.emitValidationErrors(e,r&&r.filter(function(t){return"source.canvas"!==t.identifier}))},Ie=t.pick(Nt,["addLayer","removeLayer","setPaintProperty","setLayoutProperty","setFilter","addSource","removeSource","setLayerZoomRange","setLight","setTransition","setGeoJSONSourceData"]),De=t.pick(Nt,["setCenter","setZoom","setBearing","setPitch"]),Re=function(e){function r(n,a){var i=this;void 0===a&&(a={}),e.call(this),this.map=n,this.dispatcher=new T((Dt||(Dt=new It),Dt),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new x(n._requestManager,a.localIdeographFontFamily),this.lineAtlas=new k(256,512),this.crossTileSymbolIndex=new Oe,this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._resetUpdates(),this.dispatcher.broadcast("setReferrer",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginAvailability(function(t){for(var e in o.dispatcher.broadcast("loadRTLTextPlugin",t.pluginURL,t.completionCallback),o.sourceCaches)o.sourceCaches[e].reload()}),this.on("data",function(t){if("source"===t.dataType&&"metadata"===t.sourceDataType){var e=i.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in i._layers){var a=i._layers[n];a.source===r.id&&i._validateLayer(a)}}}})}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event("dataloading",{dataType:"style"}));var a="boolean"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var i=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(i,function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,a)})},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event("dataloading",{dataType:"style"})),this._request=t.browser.frame(function(){n._request=null,n._load(e,!1!==r.validate)})},r.prototype._load=function(e,r){var n=this;if(!r||!ze(this,t.validateStyle(e))){for(var a in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(a,e.sources[a],{validate:!1});e.sprite?this._spriteRequest=function(e,r,n){var a,i,o,s=t.browser.devicePixelRatio>1?"@2x":"",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,".json"),t.ResourceType.SpriteJSON),function(t,e){l=null,o||(o=t,a=e,u())}),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,".png"),t.ResourceType.SpriteImage),function(t,e){c=null,o||(o=t,i=e,u())});function u(){if(o)n(o);else if(a&&i){var e=t.browser.getImageData(i),r={};for(var s in a){var l=a[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,g=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,g,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:g,pixelRatio:d,sdf:p}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e.sprite,this.map._requestManager,function(e,r){if(n._spriteRequest=null,e)n.fire(new t.ErrorEvent(e));else if(r)for(var a in r)n.imageManager.addImage(a,r[a]);n.imageManager.setLoaded(!0),n.fire(new t.Event("data",{dataType:"style"}))}):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var i=Bt(this.stylesheet.layers);this._order=i.map(function(t){return t.id}),this._layers={};for(var o=0,s=i;o<s.length;o+=1){var l=s[o];(l=t.createStyleLayer(l)).setEventedParent(this,{layer:{id:l.id}}),this._layers[l.id]=l}this.dispatcher.broadcast("setLayers",this._serializeLayers(this._order)),this.light=new w(this.stylesheet.light),this.fire(new t.Event("data",{dataType:"style"})),this.fire(new t.Event("style.load"))}},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var a=r.getSource();("geojson"===a.type||a.vectorLayerIds&&-1===a.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer "'+n+'" does not exist on source "'+a.id+'" as specified by style layer "'+e.id+'"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var a=n[r],i=this._layers[a];"custom"!==i.type&&e.push(i.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error("Style is not done loading")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),a=Object.keys(this._removedLayers);for(var i in(n.length||a.length)&&this._updateWorkerLayers(n,a),this._updatedSources){var o=this._updatedSources[i];"reload"===o?this._reloadSource(i):"clear"===o&&this._clearSource(i)}for(var s in this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var h=u[c],f=this._layers[h];f.recalculate(e),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event("data",{dataType:"style"}))}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast("updateLayers",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),ze(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=Bt(e.layers);var n=function(e,r){if(!e)return[{command:Nt.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Nt.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Nt.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Nt.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Nt.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Nt.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Nt.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Nt.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Nt.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Nt.setLight,args:[r.light]});var a={},i=[];!function(e,r,n,a){var i;for(i in r=r||{},e=e||{})e.hasOwnProperty(i)&&(r.hasOwnProperty(i)||Vt(i,n,a));for(i in r)r.hasOwnProperty(i)&&(e.hasOwnProperty(i)?t.deepEqual(e[i],r[i])||("geojson"===e[i].type&&"geojson"===r[i].type&&qt(e,r,i)?n.push({command:Nt.setGeoJSONSourceData,args:[i,r[i].data]}):Ut(i,r,n,a)):jt(i,r,n))}(e.sources,r.sources,i,a);var o=[];e.layers&&e.layers.forEach(function(t){a[t.source]?n.push({command:Nt.removeLayer,args:[t.id]}):o.push(t)}),n=n.concat(i),function(e,r,n){r=r||[];var a,i,o,s,l,c,u,h=(e=e||[]).map(Gt),f=r.map(Gt),p=e.reduce(Yt,{}),d=r.reduce(Yt,{}),g=h.slice(),v=Object.create(null);for(a=0,i=0;a<h.length;a++)o=h[a],d.hasOwnProperty(o)?i++:(n.push({command:Nt.removeLayer,args:[o]}),g.splice(g.indexOf(o,i),1));for(a=0,i=0;a<f.length;a++)o=f[f.length-1-a],g[g.length-1-a]!==o&&(p.hasOwnProperty(o)?(n.push({command:Nt.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-i),1)):i++,c=g[g.length-a],n.push({command:Nt.addLayer,args:[d[o],c]}),g.splice(g.length-a,0,o),v[o]=!0);for(a=0;a<f.length;a++)if(s=p[o=f[a]],l=d[o],!v[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s["source-layer"],l["source-layer"])&&t.deepEqual(s.type,l.type)){for(u in Ht(s.layout,l.layout,n,o,null,Nt.setLayoutProperty),Ht(s.paint,l.paint,n,o,null,Nt.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Nt.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Nt.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&"layout"!==u&&"paint"!==u&&"filter"!==u&&"metadata"!==u&&"minzoom"!==u&&"maxzoom"!==u&&(0===u.indexOf("paint.")?Ht(s[u],l[u],n,o,u.slice(6),Nt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Nt.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&"layout"!==u&&"paint"!==u&&"filter"!==u&&"metadata"!==u&&"minzoom"!==u&&"maxzoom"!==u&&(0===u.indexOf("paint.")?Ht(s[u],l[u],n,o,u.slice(6),Nt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Nt.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Nt.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Nt.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn("Unable to compute style diff:",t),n=[{command:Nt.setStyle,args:[r]}]}return n}(this.serialize(),e).filter(function(t){return!(t.command in De)});if(0===n.length)return!1;var a=n.filter(function(t){return!(t.command in Ie)});if(a.length>0)throw new Error("Unimplemented: "+a.map(function(t){return t.command}).join(", ")+".");return n.forEach(function(t){"setTransition"!==t.command&&r[t.command].apply(r,t.args)}),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error("An image with this name already exists.")));this.imageManager.addImage(e,r),this.fire(new t.Event("data",{dataType:"style"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error("No image with this name exists.")));this.imageManager.removeImage(e),this.fire(new t.Event("data",{dataType:"style"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var a=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error("There is already a source with this ID");if(!r.type)throw new Error("The type property must be defined, but the only the following properties were given: "+Object.keys(r).join(", ")+".");if(!(["vector","raster","geojson","video","image"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,"sources."+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var i=this.sourceCaches[e]=new Ct(e,r,this.dispatcher);i.style=this,i.setEventedParent(this,function(){return{isSourceLoaded:a.loaded(),source:i.serialize(),sourceId:e}}),i.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error("There is no source with this ID");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source "'+e+'" cannot be removed while layer "'+r+'" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event("data",{sourceDataType:"metadata",dataType:"source",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var a=e.id;if(this.getLayer(a))this.fire(new t.ErrorEvent(new Error('Layer with id "'+a+'" already exists on this map')));else{var i;if("custom"===e.type){if(ze(this,t.validateCustomStyleLayer(e)))return;i=t.createStyleLayer(e)}else{if("object"==typeof e.source&&(this.addSource(a,e.source),e=t.clone$1(e),e=t.extend(e,{source:a})),this._validate(t.validateStyle.layer,"layers."+a,e,{arrayIndex:-1},n))return;i=t.createStyleLayer(e),this._validateLayer(i),i.setEventedParent(this,{layer:{id:a}})}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id "'+r+'" does not exist on this map.')));else{if(this._order.splice(o,0,a),this._layerOrderChanged=!0,this._layers[a]=i,this._removedLayers[a]&&i.source&&"custom"!==i.type){var s=this._removedLayers[a];delete this._removedLayers[a],s.type!==i.type?this._updatedSources[i.source]="clear":(this._updatedSources[i.source]="reload",this.sourceCaches[i.source].pause())}this._updateLayer(i),i.onAdd&&i.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var a=r?this._order.indexOf(r):this._order.length;r&&-1===a?this.fire(new t.ErrorEvent(new Error('Layer with id "'+r+'" does not exist on this map.'))):(this._order.splice(a,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot be moved.")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot be removed.")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var a=this.getLayer(e);a?a.minzoom===r&&a.maxzoom===n||(null!=r&&(a.minzoom=r),null!=n&&(a.maxzoom=n),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot have zoom extent.")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var a=this.getLayer(e);if(a){if(!t.deepEqual(a.filter,r))return null==r?(a.filter=void 0,void this._updateLayer(a)):void(this._validate(t.validateStyle.filter,"layers."+a.id+".filter",r,null,n)||(a.filter=t.clone$1(r),this._updateLayer(a)))}else this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot be filtered.")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,a){void 0===a&&(a={}),this._checkLoaded();var i=this.getLayer(e);i?t.deepEqual(i.getLayoutProperty(r),n)||(i.setLayoutProperty(r,n,a),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot be styled.")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style.")))},r.prototype.setPaintProperty=function(e,r,n,a){void 0===a&&(a={}),this._checkLoaded();var i=this.getLayer(e);i?t.deepEqual(i.getPaintProperty(r),n)||(i.setPaintProperty(r,n,a)&&this._updateLayer(i),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error("The layer '"+e+"' does not exist in the map's style and cannot be styled.")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,a=e.sourceLayer,i=this.sourceCaches[n],o=parseInt(e.id,10);if(void 0!==i){var s=i.getSource().type;"geojson"===s&&a?this.fire(new t.ErrorEvent(new Error("GeoJSON sources cannot have a sourceLayer parameter."))):"vector"!==s||a?isNaN(o)||o<0?this.fire(new t.ErrorEvent(new Error("The feature id parameter must be provided and non-negative."))):i.setFeatureState(a,o,r):this.fire(new t.ErrorEvent(new Error("The sourceLayer parameter must be provided for vector source types.")))}else this.fire(new t.ErrorEvent(new Error("The source '"+n+"' does not exist in the map's style.")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,a=this.sourceCaches[n];if(void 0!==a){var i=a.getSource().type,o="vector"===i?e.sourceLayer:void 0,s=parseInt(e.id,10);"vector"!==i||o?void 0!==e.id&&isNaN(s)||s<0?this.fire(new t.ErrorEvent(new Error("The feature id parameter must be non-negative."))):r&&"string"!=typeof e.id&&"number"!=typeof e.id?this.fire(new t.ErrorEvent(new Error("A feature id is requred to remove its specific state property."))):a.removeFeatureState(o,s,r):this.fire(new t.ErrorEvent(new Error("The sourceLayer parameter must be provided for vector source types.")))}else this.fire(new t.ErrorEvent(new Error("The source '"+n+"' does not exist in the map's style.")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,a=this.sourceCaches[r],i=parseInt(e.id,10);if(void 0!==a)if("vector"!==a.getSource().type||n){if(!(isNaN(i)||i<0))return a.getFeatureState(n,i);this.fire(new t.ErrorEvent(new Error("The feature id parameter must be provided and non-negative.")))}else this.fire(new t.ErrorEvent(new Error("The sourceLayer parameter must be provided for vector source types.")));else this.fire(new t.ErrorEvent(new Error("The source '"+r+"' does not exist in the map's style.")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,function(t){return t.serialize()}),layers:this._serializeLayers(this._order)},function(t){return void 0!==t})},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&(this._updatedSources[t.source]="reload",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return"fill-extrusion"===e._layers[t].type},n={},a=[],i=this._order.length-1;i>=0;i--){var o=this._order[i];if(r(o)){n[o]=i;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1){var f=h[u];a.push(f)}}}}a.sort(function(t,e){return e.intersectionZ-t.intersectionZ});for(var p=[],d=this._order.length-1;d>=0;d--){var g=this._order[d];if(r(g))for(var v=a.length-1;v>=0;v--){var m=a[v].feature;if(n[m.layer.id]<d)break;p.push(m),a.pop()}else for(var y=0,x=t;y<x.length;y+=1){var b=x[y][g];if(b)for(var _=0,w=b;_<w.length;_+=1){var k=w[_];p.push(k.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,"queryRenderedFeatures.filter",r.filter,null,r);var a={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error("parameters.layers must be an Array."))),[];for(var i=0,o=r.layers;i<o.length;i+=1){var s=o[i],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error("The layer '"+s+"' does not exist in the map's style and cannot be queried for features."))),[];a[l.source]=!0}}var c=[];for(var u in this.sourceCaches)r.layers&&!a[u]||c.push(F(this.sourceCaches[u],this._layers,e,r,n));return this.placement&&c.push(function(t,e,r,n,a,i){for(var o={},s=a.queryRenderedSymbols(r),l=[],c=0,u=Object.keys(s).map(Number);c<u.length;c+=1){var h=u[c];l.push(i[h])}l.sort(B);for(var f=function(){var e=d[p],r=e.featureIndex.lookupSymbolFeatures(s[e.bucketInstanceId],e.bucketIndex,e.sourceLayerIndex,n.filter,n.layers,t);for(var a in r){var i=o[a]=o[a]||[],l=r[a];l.sort(function(t,r){var n=e.featureSortOrder;if(n){var a=n.indexOf(t.featureIndex);return n.indexOf(r.featureIndex)-a}return r.featureIndex-t.featureIndex});for(var c=0,u=l;c<u.length;c+=1){var h=u[c];i.push(h)}}},p=0,d=l;p<d.length;p+=1)f();var g=function(r){o[r].forEach(function(n){var a=n.feature,i=t[r],o=e[i.source].getFeatureState(a.layer["source-layer"],a.id);a.source=a.layer.source,a.layer["source-layer"]&&(a.sourceLayer=a.layer["source-layer"]),a.state=o})};for(var v in o)g(v);return o}(this._layers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,"querySourceFeatures.filter",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map(function(e){return t.getTileByID(e)}),n=[],a={},i=0;i<r.length;i++){var o=r[i],s=o.tileID.canonical.key;a[s]||(a[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called "'+t+'" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast("loadWorkerSource",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),a=!1;for(var i in e)if(!t.deepEqual(e[i],n[i])){a=!0;break}if(a){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,a,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&ze(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},a)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off("pluginAvailable",this._rtlTextPluginCallback),this.sourceCaches)this.sourceCaches[e].clearTiles();this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,a){for(var i=!1,o=!1,s={},l=0,c=this._order;l<c.length;l+=1){var u=c[l],h=this._layers[u];if("symbol"===h.type){if(!s[h.source]){var f=this.sourceCaches[h.source];s[h.source]=f.getRenderableIds(!0).map(function(t){return f.getTileByID(t)}).sort(function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)})}var p=this.crossTileSymbolIndex.addLayer(h,s[h.source],e.center.lng);i=i||p}}this.crossTileSymbolIndex.pruneUnusedLayers(this._order);var d=this._layerOrderChanged||0===n;if((d||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now()))&&(this.pauseablePlacement=new Se(e,this._order,d,r,n,a,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,s),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),o=!0),i&&this.pauseablePlacement.placement.setStale()),o||i)for(var g=0,v=this._order;g<v.length;g+=1){var m=v[g],y=this._layers[m];"symbol"===y.type&&this.placement.updateLayerOpacities(y,s[y.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);Re.getSourceType=function(t){return I[t]},Re.setSourceType=function(t,e){I[t]=e},Re.registerForPluginAvailability=t.registerForPluginAvailability;var Fe=t.createLayout([{name:"a_pos",type:"Int16",components:2}]),Be=cr("#ifdef GL_ES\nprecision mediump float;\n#else\n#if !defined(lowp)\n#define lowp\n#endif\n#if !defined(mediump)\n#define mediump\n#endif\n#if !defined(highp)\n#define highp\n#endif\n#endif","#ifdef GL_ES\nprecision highp float;\n#else\n#if !defined(lowp)\n#define lowp\n#endif\n#if !defined(mediump)\n#define mediump\n#endif\n#if !defined(highp)\n#define highp\n#endif\n#endif\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}"),Ne=cr("uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}"),je=cr("uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}"),Ve=cr("varying vec3 v_data;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define mediump float radius\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define highp vec4 stroke_color\n#pragma mapbox: define mediump float stroke_width\n#pragma mapbox: define lowp float stroke_opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize mediump float radius\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize highp vec4 stroke_color\n#pragma mapbox: initialize mediump float stroke_width\n#pragma mapbox: initialize lowp float stroke_opacity\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define mediump float radius\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define highp vec4 stroke_color\n#pragma mapbox: define mediump float stroke_width\n#pragma mapbox: define lowp float stroke_opacity\nvoid main(void) {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize mediump float radius\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize highp vec4 stroke_color\n#pragma mapbox: initialize mediump float stroke_width\n#pragma mapbox: initialize lowp float stroke_opacity\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}"),Ue=cr("void main() {gl_FragColor=vec4(1.0);}","attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}"),qe=cr("uniform highp float u_intensity;varying vec2 v_extrude;\n#pragma mapbox: define highp float weight\n#define GAUSS_COEF 0.3989422804014327\nvoid main() {\n#pragma mapbox: initialize highp float weight\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\n#pragma mapbox: define highp float weight\n#pragma mapbox: define mediump float radius\nconst highp float ZERO=1.0/255.0/16.0;\n#define GAUSS_COEF 0.3989422804014327\nvoid main(void) {\n#pragma mapbox: initialize highp float weight\n#pragma mapbox: initialize mediump float radius\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}"),He=cr("uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(0.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}"),Ge=cr("varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}","attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}"),Ye=cr("uniform float u_overscale_factor;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {float alpha=0.5;vec4 color=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {color=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {color*=.2;}float extrude_scale_length=length(v_extrude_scale);float extrude_length=length(v_extrude)*extrude_scale_length;float stroke_width=15.0*extrude_scale_length/u_overscale_factor;float radius=v_radius*extrude_scale_length;float distance_to_edge=abs(extrude_length-radius);float opacity_t=smoothstep(-stroke_width,0.0,-distance_to_edge);gl_FragColor=opacity_t*color;}","attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);highp float padding_factor=1.2;gl_Position.xy+=a_extrude*u_extrude_scale*padding_factor*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;v_radius=abs(a_extrude.y);v_extrude=a_extrude*padding_factor;v_extrude_scale=u_extrude_scale*u_camera_to_center_distance*collision_perspective_ratio;}"),We=cr("uniform highp vec4 u_color;void main() {gl_FragColor=u_color;}","attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}"),Xe=cr("#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float opacity\ngl_FragColor=color*opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","attribute vec2 a_pos;uniform mat4 u_matrix;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float opacity\ngl_Position=u_matrix*vec4(a_pos,0,1);}"),Ze=cr("varying vec2 v_pos;\n#pragma mapbox: define highp vec4 outline_color\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 outline_color\n#pragma mapbox: initialize lowp float opacity\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\n#pragma mapbox: define highp vec4 outline_color\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 outline_color\n#pragma mapbox: initialize lowp float opacity\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}"),Je=cr("uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}"),Ke=cr("uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}"),Qe=cr("varying vec4 v_color;void main() {gl_FragColor=v_color;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\n#pragma mapbox: define highp float base\n#pragma mapbox: define highp float height\n#pragma mapbox: define highp vec4 color\nvoid main() {\n#pragma mapbox: initialize highp float base\n#pragma mapbox: initialize highp float height\n#pragma mapbox: initialize highp vec4 color\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}"),$e=cr("uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\n#pragma mapbox: define lowp float base\n#pragma mapbox: define lowp float height\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float base\n#pragma mapbox: initialize lowp float height\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec4 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\n#pragma mapbox: define lowp float base\n#pragma mapbox: define lowp float height\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float base\n#pragma mapbox: initialize lowp float height\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\n? a_pos\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}"),tr=cr("#ifdef GL_ES\nprecision highp float;\n#endif\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;return (data.r+data.g*256.0+data.b*256.0*256.0)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}"),er=cr("uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\n#define PI 3.141592653589793\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}"),rr=cr("uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","\n#define scale 0.015873016\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define mediump float gapwidth\n#pragma mapbox: define lowp float offset\n#pragma mapbox: define mediump float width\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump float gapwidth\n#pragma mapbox: initialize lowp float offset\n#pragma mapbox: initialize mediump float width\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}"),nr=cr("uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","\n#define MAX_LINE_DISTANCE 32767.0\n#define scale 0.015873016\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define mediump float gapwidth\n#pragma mapbox: define lowp float offset\n#pragma mapbox: define mediump float width\nvoid main() {\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump float gapwidth\n#pragma mapbox: initialize lowp float offset\n#pragma mapbox: initialize mediump float width\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}"),ar=cr("uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec4 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x,1.0);float x_b=mod(v_linesofar/pattern_size_b.x,1.0);float y_a=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_a.y+2.0)/2.0)/pattern_size_a.y);float y_b=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_b.y+2.0)/2.0)/pattern_size_b.y);vec2 pos_a=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,vec2(x_a,y_a));vec2 pos_b=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,vec2(x_b,y_b));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","\n#define scale 0.015873016\n#define LINE_DISTANCE_SCALE 2.0\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp float offset\n#pragma mapbox: define mediump float gapwidth\n#pragma mapbox: define mediump float width\n#pragma mapbox: define lowp vec4 pattern_from\n#pragma mapbox: define lowp vec4 pattern_to\nvoid main() {\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize lowp float offset\n#pragma mapbox: initialize mediump float gapwidth\n#pragma mapbox: initialize mediump float width\n#pragma mapbox: initialize mediump vec4 pattern_from\n#pragma mapbox: initialize mediump vec4 pattern_to\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);}"),ir=cr("uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define mediump float width\n#pragma mapbox: define lowp float floorwidth\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump float width\n#pragma mapbox: initialize lowp float floorwidth\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","\n#define scale 0.015873016\n#define LINE_DISTANCE_SCALE 2.0\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\n#pragma mapbox: define highp vec4 color\n#pragma mapbox: define lowp float blur\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define mediump float gapwidth\n#pragma mapbox: define lowp float offset\n#pragma mapbox: define mediump float width\n#pragma mapbox: define lowp float floorwidth\nvoid main() {\n#pragma mapbox: initialize highp vec4 color\n#pragma mapbox: initialize lowp float blur\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize mediump float gapwidth\n#pragma mapbox: initialize lowp float offset\n#pragma mapbox: initialize mediump float width\n#pragma mapbox: initialize lowp float floorwidth\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}"),or=cr("uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}"),sr=cr("uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\n#pragma mapbox: define lowp float opacity\nvoid main() {\n#pragma mapbox: initialize lowp float opacity\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\ncamera_to_anchor_distance/u_camera_to_center_distance :\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}"),lr=cr("#define SDF_PX 8.0\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\n#pragma mapbox: define highp vec4 fill_color\n#pragma mapbox: define highp vec4 halo_color\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp float halo_width\n#pragma mapbox: define lowp float halo_blur\nvoid main() {\n#pragma mapbox: initialize highp vec4 fill_color\n#pragma mapbox: initialize highp vec4 halo_color\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize lowp float halo_width\n#pragma mapbox: initialize lowp float halo_blur\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\n#ifdef OVERDRAW_INSPECTOR\ngl_FragColor=vec4(1.0);\n#endif\n}","const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\n#pragma mapbox: define highp vec4 fill_color\n#pragma mapbox: define highp vec4 halo_color\n#pragma mapbox: define lowp float opacity\n#pragma mapbox: define lowp float halo_width\n#pragma mapbox: define lowp float halo_blur\nvoid main() {\n#pragma mapbox: initialize highp vec4 fill_color\n#pragma mapbox: initialize highp vec4 halo_color\n#pragma mapbox: initialize lowp float opacity\n#pragma mapbox: initialize lowp float halo_width\n#pragma mapbox: initialize lowp float halo_blur\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\ncamera_to_anchor_distance/u_camera_to_center_distance :\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=vec2(tex.x,tex.y);v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}");function cr(t,e){var r=/#pragma mapbox: ([\w]+) ([\w]+) ([\w]+) ([\w]+)/g,n={};return{fragmentSource:t=t.replace(r,function(t,e,r,a,i){return n[i]=!0,"define"===e?"\n#ifndef HAS_UNIFORM_u_"+i+"\nvarying "+r+" "+a+" "+i+";\n#else\nuniform "+r+" "+a+" u_"+i+";\n#endif\n":"\n#ifdef HAS_UNIFORM_u_"+i+"\n    "+r+" "+a+" "+i+" = u_"+i+";\n#endif\n"}),vertexSource:e=e.replace(r,function(t,e,r,a,i){var o="float"===a?"vec2":"vec4",s=i.match(/color/)?"color":o;return n[i]?"define"===e?"\n#ifndef HAS_UNIFORM_u_"+i+"\nuniform lowp float u_"+i+"_t;\nattribute "+r+" "+o+" a_"+i+";\nvarying "+r+" "+a+" "+i+";\n#else\nuniform "+r+" "+a+" u_"+i+";\n#endif\n":"vec4"===s?"\n#ifndef HAS_UNIFORM_u_"+i+"\n    "+i+" = a_"+i+";\n#else\n    "+r+" "+a+" "+i+" = u_"+i+";\n#endif\n":"\n#ifndef HAS_UNIFORM_u_"+i+"\n    "+i+" = unpack_mix_"+s+"(a_"+i+", u_"+i+"_t);\n#else\n    "+r+" "+a+" "+i+" = u_"+i+";\n#endif\n":"define"===e?"\n#ifndef HAS_UNIFORM_u_"+i+"\nuniform lowp float u_"+i+"_t;\nattribute "+r+" "+o+" a_"+i+";\n#else\nuniform "+r+" "+a+" u_"+i+";\n#endif\n":"vec4"===s?"\n#ifndef HAS_UNIFORM_u_"+i+"\n    "+r+" "+a+" "+i+" = a_"+i+";\n#else\n    "+r+" "+a+" "+i+" = u_"+i+";\n#endif\n":"\n#ifndef HAS_UNIFORM_u_"+i+"\n    "+r+" "+a+" "+i+" = unpack_mix_"+s+"(a_"+i+", u_"+i+"_t);\n#else\n    "+r+" "+a+" "+i+" = u_"+i+";\n#endif\n"})}}var ur=Object.freeze({prelude:Be,background:Ne,backgroundPattern:je,circle:Ve,clippingMask:Ue,heatmap:qe,heatmapTexture:He,collisionBox:Ge,collisionCircle:Ye,debug:We,fill:Xe,fillOutline:Ze,fillOutlinePattern:Je,fillPattern:Ke,fillExtrusion:Qe,fillExtrusionPattern:$e,hillshadePrepare:tr,hillshade:er,line:rr,lineGradient:nr,linePattern:ar,lineSDF:ir,raster:or,symbolIcon:sr,symbolSDF:lr}),hr=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};hr.prototype.bind=function(t,e,r,n,a,i,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==a||this.boundVertexOffset!==i||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,a,i,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),a&&a.dynamicDraw&&a.bind(),s&&s.bind())},hr.prototype.freshBind=function(t,e,r,n,a,i,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=a,this.boundDynamicVertexBuffer=i,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);i&&i.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,a);for(var d=0,g=r;d<g.length;d+=1){var v=g[d];v.bind(),v.setVertexAttribPointers(u,t,a)}i&&(i.bind(),i.setVertexAttribPointers(u,t,a)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,a)),c.currentNumAttributes=l},hr.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var fr=function(t,e,r,n,a){var i=t.gl;this.program=i.createProgram();var o=r.defines();a&&o.push("#define OVERDRAW_INSPECTOR;");var s=o.concat(Be.fragmentSource,e.fragmentSource).join("\n"),l=o.concat(Be.vertexSource,e.vertexSource).join("\n"),c=i.createShader(i.FRAGMENT_SHADER);i.shaderSource(c,s),i.compileShader(c),i.attachShader(this.program,c);var u=i.createShader(i.VERTEX_SHADER);i.shaderSource(u,l),i.compileShader(u),i.attachShader(this.program,u);for(var h=r.layoutAttributes||[],f=0;f<h.length;f++)i.bindAttribLocation(this.program,f,h[f].name);i.linkProgram(this.program),this.numAttributes=i.getProgramParameter(this.program,i.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=i.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=i.getAttribLocation(this.program,g.name))}for(var v=i.getProgramParameter(this.program,i.ACTIVE_UNIFORMS),m=0;m<v;m++){var y=i.getActiveUniform(this.program,m);y&&(p[y.name]=i.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r.getUniforms(t,p)};function pr(e,r,n){var a=1/ce(n,1,r.transform.tileZoom),i=Math.pow(2,n.tileID.overscaledZ),o=n.tileSize*Math.pow(2,r.transform.tileZoom)/i,s=o*(n.tileID.canonical.x+n.tileID.wrap*i),l=o*n.tileID.canonical.y;return{u_image:0,u_texsize:n.imageAtlasTexture.size,u_scale:[t.browser.devicePixelRatio,a,e.fromScale,e.toScale],u_fade:e.t,u_pixel_coord_upper:[s>>16,l>>16],u_pixel_coord_lower:[65535&s,65535&l]}}fr.prototype.draw=function(t,e,r,n,a,i,o,s,l,c,u,h,f,p,d,g){var v,m=t.gl;for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(a),t.setCullFace(i),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(v={},v[m.LINES]=2,v[m.TRIANGLES]=3,v[m.LINE_STRIP]=1,v)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],k=w.vaos||(w.vaos={});(k[s]||(k[s]=new hr)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),m.drawElements(e,w.primitiveLength*x,m.UNSIGNED_SHORT,w.primitiveOffset*x*2)}};var dr=function(e,r,n,a){var i=r.style.light,o=i.properties.get("position"),s=[o.x,o.y,o.z],l=t.create$1();"viewport"===i.properties.get("anchor")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=i.properties.get("color");return{u_matrix:e,u_lightpos:s,u_lightintensity:i.properties.get("intensity"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:a}},gr=function(e,r,n,a,i,o,s){return t.extend(dr(e,r,n,a),pr(o,r,s),{u_height_factor:-Math.pow(2,i.overscaledZ)/s.tileSize/8})},vr=function(t){return{u_matrix:t}},mr=function(e,r,n,a){return t.extend(vr(e),pr(n,r,a))},yr=function(t,e){return{u_matrix:t,u_world:e}},xr=function(e,r,n,a,i){return t.extend(mr(e,r,n,a),{u_world:i})},br=function(e,r,n,a){var i,o,s=e.transform;if("map"===a.paint.get("circle-pitch-alignment")){var l=ce(n,1,s.zoom);i=!0,o=[l,l]}else i=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+("map"===a.paint.get("circle-pitch-scale")),u_matrix:e.translatePosMatrix(r.posMatrix,n,a.paint.get("circle-translate"),a.paint.get("circle-translate-anchor")),u_pitch_with_map:+i,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},_r=function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},wr=function(t,e,r){var n=ce(r,1,e.zoom),a=Math.pow(2,e.zoom-r.tileID.overscaledZ),i=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*a),e.pixelsToGLUnits[1]/(n*a)],u_overscale_factor:i}},kr=function(t,e){return{u_matrix:t,u_color:e}},Tr=function(t){return{u_matrix:t}},Ar=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:ce(e,1,r),u_intensity:n}},Mr=function(t,e,r){var n=r.paint.get("hillshade-shadow-color"),a=r.paint.get("hillshade-highlight-color"),i=r.paint.get("hillshade-accent-color"),o=r.paint.get("hillshade-illumination-direction")*(Math.PI/180);"viewport"===r.paint.get("hillshade-illumination-anchor")&&(o-=t.transform.angle);var s=!t.options.moving;return{u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),s),u_image:0,u_latrange:Er(t,e.tileID),u_light:[r.paint.get("hillshade-exaggeration"),o],u_shadow:n,u_highlight:a,u_accent:i}},Sr=function(e,r){var n=e.dem.stride,a=t.create();return t.ortho(a,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(a,a,[0,-t.EXTENT,0]),{u_matrix:a,u_image:1,u_dimension:[n,n],u_zoom:e.tileID.overscaledZ,u_maxzoom:r}};function Er(e,r){var n=Math.pow(2,r.canonical.z),a=r.canonical.y;return[new t.MercatorCoordinate(0,a/n).toLngLat().lat,new t.MercatorCoordinate(0,(a+1)/n).toLngLat().lat]}var Lr=function(e,r,n){var a=e.transform;return{u_matrix:Ir(e,r,n),u_ratio:1/ce(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Cr=function(e,r,n){return t.extend(Lr(e,r,n),{u_image:0})},Pr=function(e,r,n,a){var i=e.transform,o=zr(r,i);return{u_matrix:Ir(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/ce(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[t.browser.devicePixelRatio,o,a.fromScale,a.toScale],u_fade:a.t,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Or=function(e,r,n,a,i){var o=e.transform,s=e.lineAtlas,l=zr(r,o),c="round"===n.layout.get("line-cap"),u=s.getDash(a.from,c),h=s.getDash(a.to,c),f=u.width*i.fromScale,p=h.width*i.toScale;return t.extend(Lr(e,r,n),{u_patternscale_a:[l/f,-u.height/2],u_patternscale_b:[l/p,-h.height/2],u_sdfgamma:s.width/(256*Math.min(f,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:h.y,u_mix:i.t})};function zr(t,e){return 1/ce(t,1,e.tileZoom)}function Ir(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get("line-translate"),r.paint.get("line-translate-anchor"))}var Dr=function(t,e,r,n,a){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*a.paint.get("raster-opacity"),u_image0:0,u_image1:1,u_brightness_low:a.paint.get("raster-brightness-min"),u_brightness_high:a.paint.get("raster-brightness-max"),u_saturation_factor:(o=a.paint.get("raster-saturation"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(i=a.paint.get("raster-contrast"),i>0?1/(1-i):1+i),u_spin_weights:function(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}(a.paint.get("raster-hue-rotate"))};var i,o};var Rr=function(t,e,r,n,a,i,o,s,l,c){var u=a.transform;return{u_is_size_zoom_constant:+("constant"===t||"source"===t),u_is_size_feature_constant:+("constant"===t||"camera"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:a.options.fadeDuration?a.symbolFadeChange:1,u_matrix:i,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Fr=function(e,r,n,a,i,o,s,l,c,u,h){var f=i.transform;return t.extend(Rr(e,r,n,a,i,o,s,l,c,u),{u_gamma_scale:a?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Br=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Nr=function(e,r,n,a,i,o){return t.extend(function(t,e,r,n){var a=r.imageManager.getPattern(t.from),i=r.imageManager.getPattern(t.to),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:a.tl,u_pattern_br_a:a.br,u_pattern_tl_b:i.tl,u_pattern_br_b:i.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:a.displaySize,u_pattern_size_b:i.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/ce(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(a,o,n,i),{u_matrix:e,u_opacity:r})},jr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:_r,collisionCircle:_r,debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1f(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function Vr(e,r){for(var n=e.sort(function(t,e){return t.tileID.isLessThan(e.tileID)?-1:e.tileID.isLessThan(t.tileID)?1:0}),a=0;a<n.length;a++){var i={},o=n[a],s=n.slice(a+1);Ur(o.tileID.wrapped(),o.tileID,s,new t.OverscaledTileID(0,o.tileID.wrap+1,0,0,0),i),o.setMask(i,r)}}function Ur(e,r,n,a,i){for(var o=0;o<n.length;o++){var s=n[o];if(a.isLessThan(s.tileID))break;if(r.key===s.tileID.key)return;if(s.tileID.isChildOf(r)){for(var l=r.children(1/0),c=0;c<l.length;c++)Ur(e,l[c],n.slice(o),a,i);return}}var u=r.overscaledZ-e.overscaledZ,h=new t.CanonicalTileID(u,r.canonical.x-(e.canonical.x<<u),r.canonical.y-(e.canonical.y<<u));i[h.key]=i[h.key]||h}function qr(t,e,r,n,a){for(var i=t.context,o=i.gl,s=a?t.useProgram("collisionCircle"):t.useProgram("collisionBox"),l=0;l<n.length;l++){var c=n[l],u=e.getTile(c),h=u.getBucket(r);if(h){var f=a?h.collisionCircle:h.collisionBox;f&&s.draw(i,a?o.TRIANGLES:o.LINES,At.disabled,Mt.disabled,t.colorModeForRenderPass(),Et.disabled,wr(c.posMatrix,t.transform,u),r.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,null,t.transform.zoom,null,null,f.collisionVertexBuffer)}}}var Hr=t.identity(new Float32Array(16));function Gr(e,r,n,a,i,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateRadialOffset(e,a);return new t.Point((l/i+u[0])*o,(c/i+u[1])*o)}function Yr(e,r,n,a,i,o,s,l,c,u){var h=e.text.placedSymbolArray,f=e.text.dynamicLayoutVertexArray;f.clear();for(var p=0;p<h.length;p++){var d=h.get(p),g=e.allowVerticalPlacement&&!d.placedOrientation,v=d.hidden||!d.crossTileID||g?null:a[d.crossTileID];if(v){var m=new t.Point(d.anchorX,d.anchorY),y=Jt(m,n?l:s),x=.5+o.cameraToCenterDistance/y.signedDistanceFromCamera*.5,b=i.evaluateSizeForFeature(e.textSizeData,u,d)*x/t.ONE_EM;n&&(b*=e.tilePixelRatio/c);for(var _=v.width,w=v.height,k=v.radialOffset,T=v.textBoxScale,A=Gr(v.anchor,_,w,k,T,b),M=n?Jt(m.add(A),s).point:y.point.add(r?A.rotate(-o.angle):A),S=e.allowVerticalPlacement&&d.placedOrientation===t.WritingMode.vertical?Math.PI/2:0,E=0;E<d.numGlyphs;E++)t.addDynamicAttributes(f,M,S)}else ie(d.numGlyphs,f)}e.text.dynamicLayoutVertexBuffer.updateData(f)}function Wr(e){var r=e.text.placedSymbolArray,n=e.text.dynamicLayoutVertexArray;n.clear();for(var a=0;a<r.length;a++){var i=r.get(a);if(i.hidden||!i.placedOrientation)ie(i.numGlyphs,n);else for(var o=new t.Point(i.anchorX,i.anchorY),s=e.allowVerticalPlacement&&i.placedOrientation===t.WritingMode.vertical?Math.PI/2:0,l=0;l<i.numGlyphs;l++)t.addDynamicAttributes(n,o,s)}e.text.dynamicLayoutVertexBuffer.updateData(n)}function Xr(e,r,n,a,i,o,s,l,c,u,h,f,p){for(var d,g,v=e.context,m=v.gl,y=e.transform,x="map"===l,b="map"===c,_=x&&"point"!==n.layout.get("symbol-placement"),w=x&&!b&&!_,k=void 0!==n.layout.get("symbol-sort-key").constantOr(1),T=e.depthModeForSublayer(0,At.ReadOnly),A=n.layout.get("text-variable-anchor"),M=[],S=0,E=a;S<E.length;S+=1){var L=E[S],C=r.getTile(L),P=C.getBucket(n);if(P){var O=i?P.text:P.icon;if(O&&O.segments.get().length){var z=O.programConfigurations.get(n.id),I=i||P.sdfIcons,D=i?P.textSizeData:P.iconSizeData;d||(d=e.useProgram(I?"symbolSDF":"symbolIcon",z),g=t.evaluateSizeForZoom(D,y.zoom)),v.activeTexture.set(m.TEXTURE0);var R=void 0,F=void 0,B=void 0;if(i)F=C.glyphAtlasTexture,B=m.LINEAR,R=C.glyphAtlasTexture.size;else{var N=1!==n.layout.get("icon-size").constantOr(0)||P.iconsNeedLinear,j=b||0!==y.pitch;F=C.imageAtlasTexture,B=I||e.options.rotating||e.options.zooming||N||j?m.LINEAR:m.NEAREST,R=C.imageAtlasTexture.size}var V=ce(C,1,e.transform.zoom),U=Xt(L.posMatrix,b,x,e.transform,V),q=Zt(L.posMatrix,b,x,e.transform,V);if(_)Qt(P,L.posMatrix,e,i,U,q,b,u);else if(i&&g&&A){var H=Math.pow(2,y.zoom-C.tileID.overscaledZ);Yr(P,x,b,p,t.symbolSize,y,U,L.posMatrix,H,g)}else i&&g&&P.allowVerticalPlacement&&Wr(P);var G=e.translatePosMatrix(L.posMatrix,C,o,s),Y=_||i&&A?Hr:U,W=e.translatePosMatrix(q,C,o,s,!0),X=I&&0!==n.paint.get(i?"text-halo-width":"icon-halo-width").constantOr(1),Z={program:d,buffers:O,uniformValues:I?Fr(D.kind,g,w,b,e,G,Y,W,i,R,!0):Rr(D.kind,g,w,b,e,G,Y,W,i,R),atlasTexture:F,atlasInterpolation:B,isSDF:I,hasHalo:X};if(k)for(var J=0,K=O.segments.get();J<K.length;J+=1){var Q=K[J];M.push({segments:new t.SegmentVector([Q]),sortKey:Q.sortKey,state:Z})}else M.push({segments:O.segments,sortKey:0,state:Z})}}}k&&M.sort(function(t,e){return t.sortKey-e.sortKey});for(var $=0,tt=M;$<tt.length;$+=1){var et=tt[$],rt=et.state;if(rt.atlasTexture.bind(rt.atlasInterpolation,m.CLAMP_TO_EDGE),rt.isSDF){var nt=rt.uniformValues;rt.hasHalo&&(nt.u_is_halo=1,Zr(rt.buffers,et.segments,n,e,rt.program,T,h,f,nt)),nt.u_is_halo=0}Zr(rt.buffers,et.segments,n,e,rt.program,T,h,f,rt.uniformValues)}}function Zr(t,e,r,n,a,i,o,s,l){var c=n.context,u=c.gl;a.draw(c,u.TRIANGLES,i,o,s,Et.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function Jr(t,e,r,n,a,i,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get("fill-pattern"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty("fill-outline-color")?"fillOutlinePattern":"fillOutline",s=f.LINES):(l=d?"fillPattern":"fill",s=f.TRIANGLES);for(var v=0,m=n;v<m.length;v+=1){var y=m[v],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),_.updatePatternPaintBuffers(g));var k=p.constantOr(null);if(k&&x.imageAtlas){var T=x.imageAtlas.patternPositions[k.to],A=x.imageAtlas.patternPositions[k.from];T&&A&&_.setConstantPatternPositions(T,A)}var M=t.translatePosMatrix(y.posMatrix,x,r.paint.get("fill-translate"),r.paint.get("fill-translate-anchor"));if(o){u=b.indexBuffer2,h=b.segments2;var S=[f.drawingBufferWidth,f.drawingBufferHeight];c="fillOutlinePattern"===l&&d?xr(M,t,g,x,S):yr(M,S)}else u=b.indexBuffer,h=b.segments,c=d?mr(M,t,g,x):vr(M);w.draw(t.context,s,a,t.stencilModeForClipping(y),i,Et.disabled,c,r.id,b.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,_)}}}}function Kr(t,e,r,n,a,i,o){for(var s=t.context,l=s.gl,c=r.paint.get("fill-extrusion-pattern"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get("fill-extrusion-opacity"),p=0,d=n;p<d.length;p+=1){var g=d[p],v=e.getTile(g),m=v.getBucket(r);if(m){var y=m.programConfigurations.get(r.id),x=t.useProgram(u?"fillExtrusionPattern":"fillExtrusion",y);u&&(t.context.activeTexture.set(l.TEXTURE0),v.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePatternPaintBuffers(h));var b=c.constantOr(null);if(b&&v.imageAtlas){var _=v.imageAtlas.patternPositions[b.to],w=v.imageAtlas.patternPositions[b.from];_&&w&&y.setConstantPatternPositions(_,w)}var k=t.translatePosMatrix(g.posMatrix,v,r.paint.get("fill-extrusion-translate"),r.paint.get("fill-extrusion-translate-anchor")),T=r.paint.get("fill-extrusion-vertical-gradient"),A=u?gr(k,t,T,f,g,h,v):dr(k,t,T,f);x.draw(s,s.gl.TRIANGLES,a,i,o,Et.backCCW,A,r.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,r.paint,t.transform.zoom,y)}}}function Qr(t,e,r,n,a,i){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram("hillshade");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=Mr(t,e,r);e.maskedBoundsBuffer&&e.maskedIndexBuffer&&e.segments?c.draw(o,s.TRIANGLES,n,a,i,Et.disabled,u,r.id,e.maskedBoundsBuffer,e.maskedIndexBuffer,e.segments):c.draw(o,s.TRIANGLES,n,a,i,Et.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function $r(e,r,n,a,i,o,s){var l=e.context,c=l.gl;if(r.dem&&r.dem.data){var u=r.dem.dim,h=r.dem.stride,f=r.dem.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var p=r.demTexture;p.update(f,{premultiply:!1}),p.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,f,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var d=r.fbo;if(!d){var g=new t.Texture(l,{width:u,height:u,data:null},c.RGBA);g.bind(c.LINEAR,c.CLAMP_TO_EDGE),(d=r.fbo=l.createFramebuffer(u,u)).colorAttachment.set(g.texture)}l.bindFramebuffer.set(d.framebuffer),l.viewport.set([0,0,u,u]),e.useProgram("hillshadePrepare").draw(l,c.TRIANGLES,i,o,s,Et.disabled,Sr(r,a),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function tn(e,r,n,a,i){var o=a.paint.get("raster-fade-duration");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=i.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}function en(e,r,n){var a=e.context,i=a.gl,o=n.posMatrix,s=e.useProgram("debug"),l=At.disabled,c=Mt.disabled,u=e.colorModeForRenderPass(),h="$debug";s.draw(a,i.LINE_STRIP,l,c,u,Et.disabled,kr(o,t.Color.red),h,e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);for(var f=r.getTileByID(n.key).latestRawTileData,p=f&&f.byteLength||0,d=Math.floor(p/1024),g=r.getTile(n).tileSize,v=512/Math.min(g,512),m=function(t,e,r,n){n=n||1;var a,i,o,s,l,c,u,h,f=[];for(a=0,i=t.length;a<i;a++)if(l=rn[t[a]]){for(h=null,o=0,s=l[1].length;o<s;o+=2)-1===l[1][o]&&-1===l[1][o+1]?h=null:(c=e+l[1][o]*n,u=r-l[1][o+1]*n,h&&f.push(h.x,h.y,c,u),h={x:c,y:u});e+=l[0]*n}return f}(n.toString()+" "+d+"kb",50,200*v,5*v),y=new t.StructArrayLayout2i4,x=new t.StructArrayLayout2ui4,b=0;b<m.length;b+=2)y.emplaceBack(m[b],m[b+1]),x.emplaceBack(b,b+1);for(var _=a.createVertexBuffer(y,Fe.members),w=a.createIndexBuffer(x),k=t.SegmentVector.simpleSegment(0,0,y.length/2,y.length/2),T=t.EXTENT/(Math.pow(2,e.transform.zoom-n.overscaledZ)*g*v),A=[],M=-1;M<=1;M++)for(var S=-1;S<=1&&(0!==M||0!==S);S++)A.push([M,S]);for(var E=0;E<A.length;E++){var L=A[E];s.draw(a,i.LINES,l,c,u,Et.disabled,kr(t.translate([],o,[T*L[0],T*L[1],0]),t.Color.white),h,_,w,k)}s.draw(a,i.LINES,l,c,u,Et.disabled,kr(o,t.Color.black),h,_,w,k)}var rn={" ":[16,[]],"!":[10,[5,21,5,7,-1,-1,5,2,4,1,5,0,6,1,5,2]],'"':[16,[4,21,4,14,-1,-1,12,21,12,14]],"#":[21,[11,25,4,-7,-1,-1,17,25,10,-7,-1,-1,4,12,18,12,-1,-1,3,6,17,6]],$:[20,[8,25,8,-4,-1,-1,12,25,12,-4,-1,-1,17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],"%":[24,[21,21,3,0,-1,-1,8,21,10,19,10,17,9,15,7,14,5,14,3,16,3,18,4,20,6,21,8,21,10,20,13,19,16,19,19,20,21,21,-1,-1,17,7,15,6,14,4,14,2,16,0,18,0,20,1,21,3,21,5,19,7,17,7]],"&":[26,[23,12,23,13,22,14,21,14,20,13,19,11,17,6,15,3,13,1,11,0,7,0,5,1,4,2,3,4,3,6,4,8,5,9,12,13,13,14,14,16,14,18,13,20,11,21,9,20,8,18,8,16,9,13,11,10,16,3,18,1,20,0,22,0,23,1,23,2]],"'":[10,[5,19,4,20,5,21,6,20,6,18,5,16,4,15]],"(":[14,[11,25,9,23,7,20,5,16,4,11,4,7,5,2,7,-2,9,-5,11,-7]],")":[14,[3,25,5,23,7,20,9,16,10,11,10,7,9,2,7,-2,5,-5,3,-7]],"*":[16,[8,21,8,9,-1,-1,3,18,13,12,-1,-1,13,18,3,12]],"+":[26,[13,18,13,0,-1,-1,4,9,22,9]],",":[10,[6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],"-":[26,[4,9,22,9]],".":[10,[5,2,4,1,5,0,6,1,5,2]],"/":[22,[20,25,2,-7]],0:[20,[9,21,6,20,4,17,3,12,3,9,4,4,6,1,9,0,11,0,14,1,16,4,17,9,17,12,16,17,14,20,11,21,9,21]],1:[20,[6,17,8,18,11,21,11,0]],2:[20,[4,16,4,17,5,19,6,20,8,21,12,21,14,20,15,19,16,17,16,15,15,13,13,10,3,0,17,0]],3:[20,[5,21,16,21,10,13,13,13,15,12,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],4:[20,[13,21,3,7,18,7,-1,-1,13,21,13,0]],5:[20,[15,21,5,21,4,12,5,13,8,14,11,14,14,13,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],6:[20,[16,18,15,20,12,21,10,21,7,20,5,17,4,12,4,7,5,3,7,1,10,0,11,0,14,1,16,3,17,6,17,7,16,10,14,12,11,13,10,13,7,12,5,10,4,7]],7:[20,[17,21,7,0,-1,-1,3,21,17,21]],8:[20,[8,21,5,20,4,18,4,16,5,14,7,13,11,12,14,11,16,9,17,7,17,4,16,2,15,1,12,0,8,0,5,1,4,2,3,4,3,7,4,9,6,11,9,12,13,13,15,14,16,16,16,18,15,20,12,21,8,21]],9:[20,[16,14,15,11,13,9,10,8,9,8,6,9,4,11,3,14,3,15,4,18,6,20,9,21,10,21,13,20,15,18,16,14,16,9,15,4,13,1,10,0,8,0,5,1,4,3]],":":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,5,2,4,1,5,0,6,1,5,2]],";":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],"<":[24,[20,18,4,9,20,0]],"=":[26,[4,12,22,12,-1,-1,4,6,22,6]],">":[24,[4,18,20,9,4,0]],"?":[18,[3,16,3,17,4,19,5,20,7,21,11,21,13,20,14,19,15,17,15,15,14,13,13,12,9,10,9,7,-1,-1,9,2,8,1,9,0,10,1,9,2]],"@":[27,[18,13,17,15,15,16,12,16,10,15,9,14,8,11,8,8,9,6,11,5,14,5,16,6,17,8,-1,-1,12,16,10,14,9,11,9,8,10,6,11,5,-1,-1,18,16,17,8,17,6,19,5,21,5,23,7,24,10,24,12,23,15,22,17,20,19,18,20,15,21,12,21,9,20,7,19,5,17,4,15,3,12,3,9,4,6,5,4,7,2,9,1,12,0,15,0,18,1,20,2,21,3,-1,-1,19,16,18,8,18,6,19,5]],A:[18,[9,21,1,0,-1,-1,9,21,17,0,-1,-1,4,7,14,7]],B:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,-1,-1,4,11,13,11,16,10,17,9,18,7,18,4,17,2,16,1,13,0,4,0]],C:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5]],D:[21,[4,21,4,0,-1,-1,4,21,11,21,14,20,16,18,17,16,18,13,18,8,17,5,16,3,14,1,11,0,4,0]],E:[19,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11,-1,-1,4,0,17,0]],F:[18,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11]],G:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,18,8,-1,-1,13,8,18,8]],H:[22,[4,21,4,0,-1,-1,18,21,18,0,-1,-1,4,11,18,11]],I:[8,[4,21,4,0]],J:[16,[12,21,12,5,11,2,10,1,8,0,6,0,4,1,3,2,2,5,2,7]],K:[21,[4,21,4,0,-1,-1,18,21,4,7,-1,-1,9,12,18,0]],L:[17,[4,21,4,0,-1,-1,4,0,16,0]],M:[24,[4,21,4,0,-1,-1,4,21,12,0,-1,-1,20,21,12,0,-1,-1,20,21,20,0]],N:[22,[4,21,4,0,-1,-1,4,21,18,0,-1,-1,18,21,18,0]],O:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21]],P:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,14,17,12,16,11,13,10,4,10]],Q:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21,-1,-1,12,4,18,-2]],R:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,4,11,-1,-1,11,11,18,0]],S:[20,[17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],T:[16,[8,21,8,0,-1,-1,1,21,15,21]],U:[22,[4,21,4,6,5,3,7,1,10,0,12,0,15,1,17,3,18,6,18,21]],V:[18,[1,21,9,0,-1,-1,17,21,9,0]],W:[24,[2,21,7,0,-1,-1,12,21,7,0,-1,-1,12,21,17,0,-1,-1,22,21,17,0]],X:[20,[3,21,17,0,-1,-1,17,21,3,0]],Y:[18,[1,21,9,11,9,0,-1,-1,17,21,9,11]],Z:[20,[17,21,3,0,-1,-1,3,21,17,21,-1,-1,3,0,17,0]],"[":[14,[4,25,4,-7,-1,-1,5,25,5,-7,-1,-1,4,25,11,25,-1,-1,4,-7,11,-7]],"\\":[14,[0,21,14,-3]],"]":[14,[9,25,9,-7,-1,-1,10,25,10,-7,-1,-1,3,25,10,25,-1,-1,3,-7,10,-7]],"^":[16,[6,15,8,18,10,15,-1,-1,3,12,8,17,13,12,-1,-1,8,17,8,0]],_:[16,[0,-2,16,-2]],"`":[10,[6,21,5,20,4,18,4,16,5,15,6,16,5,17]],a:[19,[15,14,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],b:[19,[4,21,4,0,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],c:[18,[15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],d:[19,[15,21,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],e:[18,[3,8,15,8,15,10,14,12,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],f:[12,[10,21,8,21,6,20,5,17,5,0,-1,-1,2,14,9,14]],g:[19,[15,14,15,-2,14,-5,13,-6,11,-7,8,-7,6,-6,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],h:[19,[4,21,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],i:[8,[3,21,4,20,5,21,4,22,3,21,-1,-1,4,14,4,0]],j:[10,[5,21,6,20,7,21,6,22,5,21,-1,-1,6,14,6,-3,5,-6,3,-7,1,-7]],k:[17,[4,21,4,0,-1,-1,14,14,4,4,-1,-1,8,8,15,0]],l:[8,[4,21,4,0]],m:[30,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0,-1,-1,15,10,18,13,20,14,23,14,25,13,26,10,26,0]],n:[19,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],o:[19,[8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3,16,6,16,8,15,11,13,13,11,14,8,14]],p:[19,[4,14,4,-7,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],q:[19,[15,14,15,-7,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],r:[13,[4,14,4,0,-1,-1,4,8,5,11,7,13,9,14,12,14]],s:[17,[14,11,13,13,10,14,7,14,4,13,3,11,4,9,6,8,11,7,13,6,14,4,14,3,13,1,10,0,7,0,4,1,3,3]],t:[12,[5,21,5,4,6,1,8,0,10,0,-1,-1,2,14,9,14]],u:[19,[4,14,4,4,5,1,7,0,10,0,12,1,15,4,-1,-1,15,14,15,0]],v:[16,[2,14,8,0,-1,-1,14,14,8,0]],w:[22,[3,14,7,0,-1,-1,11,14,7,0,-1,-1,11,14,15,0,-1,-1,19,14,15,0]],x:[17,[3,14,14,0,-1,-1,14,14,3,0]],y:[16,[2,14,8,0,-1,-1,14,14,8,0,6,-4,4,-6,2,-7,1,-7]],z:[17,[14,14,3,0,-1,-1,3,14,14,14,-1,-1,3,0,14,0]],"{":[14,[9,25,7,24,6,23,5,21,5,19,6,17,7,16,8,14,8,12,6,10,-1,-1,7,24,6,22,6,20,7,18,8,17,9,15,9,13,8,11,4,9,8,7,9,5,9,3,8,1,7,0,6,-2,6,-4,7,-6,-1,-1,6,8,8,6,8,4,7,2,6,1,5,-1,5,-3,6,-5,7,-6,9,-7]],"|":[8,[4,25,4,-7]],"}":[14,[5,25,7,24,8,23,9,21,9,19,8,17,7,16,6,14,6,12,8,10,-1,-1,7,24,8,22,8,20,7,18,6,17,5,15,5,13,6,11,10,9,6,7,5,5,5,3,6,1,7,0,8,-2,8,-4,7,-6,-1,-1,8,8,6,6,6,4,7,2,8,1,9,-1,9,-3,8,-5,7,-6,5,-7]],"~":[24,[3,6,3,8,4,11,6,12,8,12,10,11,14,8,16,7,18,7,20,8,21,10,-1,-1,3,8,4,10,6,11,8,11,10,10,14,7,16,6,18,6,20,7,21,10,21,12]]},nn={symbol:function(t,e,r,n,a){if("translucent"===t.renderPass){var i=Mt.disabled,o=t.colorModeForRenderPass();0!==r.paint.get("icon-opacity").constantOr(1)&&Xr(t,e,r,n,!1,r.paint.get("icon-translate"),r.paint.get("icon-translate-anchor"),r.layout.get("icon-rotation-alignment"),r.layout.get("icon-pitch-alignment"),r.layout.get("icon-keep-upright"),i,o,a),0!==r.paint.get("text-opacity").constantOr(1)&&Xr(t,e,r,n,!0,r.paint.get("text-translate"),r.paint.get("text-translate-anchor"),r.layout.get("text-rotation-alignment"),r.layout.get("text-pitch-alignment"),r.layout.get("text-keep-upright"),i,o,a),e.map.showCollisionBoxes&&function(t,e,r,n){qr(t,e,r,n,!1),qr(t,e,r,n,!0)}(t,e,r,n)}},circle:function(e,r,n,a){if("translucent"===e.renderPass){var i=n.paint.get("circle-opacity"),o=n.paint.get("circle-stroke-width"),s=n.paint.get("circle-stroke-opacity"),l=void 0!==n.layout.get("circle-sort-key").constantOr(1);if(0!==i.constantOr(1)||0!==o.constantOr(1)&&0!==s.constantOr(1)){for(var c=e.context,u=c.gl,h=e.depthModeForSublayer(0,At.ReadOnly),f=Mt.disabled,p=e.colorModeForRenderPass(),d=[],g=0;g<a.length;g++){var v=a[g],m=r.getTile(v),y=m.getBucket(n);if(y){var x=y.programConfigurations.get(n.id),b={programConfiguration:x,program:e.useProgram("circle",x),layoutVertexBuffer:y.layoutVertexBuffer,indexBuffer:y.indexBuffer,uniformValues:br(e,v,m,n)};if(l)for(var _=0,w=y.segments.get();_<w.length;_+=1){var k=w[_];d.push({segments:new t.SegmentVector([k]),sortKey:k.sortKey,state:b})}else d.push({segments:y.segments,sortKey:0,state:b})}}l&&d.sort(function(t,e){return t.sortKey-e.sortKey});for(var T=0,A=d;T<A.length;T+=1){var M=A[T],S=M.state,E=S.programConfiguration,L=S.program,C=S.layoutVertexBuffer,P=S.indexBuffer,O=S.uniformValues,z=M.segments;L.draw(c,u.TRIANGLES,h,f,p,Et.disabled,O,n.id,C,P,z,n.paint,e.transform.zoom,E)}}}},heatmap:function(e,r,n,a){if(0!==n.paint.get("heatmap-opacity"))if("offscreen"===e.renderPass){var i=e.context,o=i.gl,s=e.depthModeForSublayer(0,At.ReadOnly),l=Mt.disabled,c=new St([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var a=r.heatmapFbo;if(a)n.bindTexture(n.TEXTURE_2D,a.colorAttachment.get()),t.bindFramebuffer.set(a.framebuffer);else{var i=n.createTexture();n.bindTexture(n.TEXTURE_2D,i),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),a=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4),function t(e,r,n,a){var i=e.gl;i.texImage2D(i.TEXTURE_2D,0,i.RGBA,r.width/4,r.height/4,0,i.RGBA,e.extTextureHalfFloat?e.extTextureHalfFloat.HALF_FLOAT_OES:i.UNSIGNED_BYTE,null),a.colorAttachment.set(n),e.extTextureHalfFloat&&i.checkFramebufferStatus(i.FRAMEBUFFER)!==i.FRAMEBUFFER_COMPLETE&&(e.extTextureHalfFloat=null,a.colorAttachment.setDirty(),t(e,r,n,a))}(t,e,i,a)}}(i,e,n),i.clear({color:t.Color.transparent});for(var u=0;u<a.length;u++){var h=a[u];if(!r.hasRenderableParent(h)){var f=r.getTile(h),p=f.getBucket(n);if(p){var d=p.programConfigurations.get(n.id),g=e.useProgram("heatmap",d),v=e.transform.zoom;g.draw(i,o.TRIANGLES,s,l,c,Et.disabled,Ar(h.posMatrix,f,v,n.paint.get("heatmap-intensity")),n.id,p.layoutVertexBuffer,p.indexBuffer,p.segments,n.paint,e.transform.zoom,d)}}}i.viewport.set([0,0,e.width,e.height])}else"translucent"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,a=n.gl,i=r.heatmapFbo;if(i){n.activeTexture.set(a.TEXTURE0),a.bindTexture(a.TEXTURE_2D,i.colorAttachment.get()),n.activeTexture.set(a.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,a.RGBA)),o.bind(a.LINEAR,a.CLAMP_TO_EDGE),e.useProgram("heatmapTexture").draw(n,a.TRIANGLES,At.disabled,Mt.disabled,e.colorModeForRenderPass(),Et.disabled,function(e,r,n,a){var i=t.create();t.ortho(i,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:i,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:a,u_opacity:r.paint.get("heatmap-opacity")}}(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,a){if("translucent"===e.renderPass){var i=n.paint.get("line-opacity"),o=n.paint.get("line-width");if(0!==i.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,At.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get("line-dasharray"),u=n.paint.get("line-pattern"),h=u.constantOr(1),f=n.paint.get("line-gradient"),p=n.getCrossfadeParameters(),d=c?"lineSDF":h?"linePattern":f?"lineGradient":"line",g=e.context,v=g.gl,m=!0;if(f){g.activeTexture.set(v.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,v.RGBA)),y.bind(v.LINEAR,v.CLAMP_TO_EDGE)}for(var x=0,b=a;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!h||w.patternsLoaded()){var k=w.getBucket(n);if(k){var T=k.programConfigurations.get(n.id),A=e.context.program.get(),M=e.useProgram(d,T),S=m||M.program!==A,E=u.constantOr(null);if(E&&w.imageAtlas){var L=w.imageAtlas.patternPositions[E.to],C=w.imageAtlas.patternPositions[E.from];L&&C&&T.setConstantPatternPositions(L,C)}var P=c?Or(e,w,n,c,p):h?Pr(e,w,n,p):f?Cr(e,w,n):Lr(e,w,n);c&&(S||e.lineAtlas.dirty)?(g.activeTexture.set(v.TEXTURE0),e.lineAtlas.bind(g)):h&&(g.activeTexture.set(v.TEXTURE0),w.imageAtlasTexture.bind(v.LINEAR,v.CLAMP_TO_EDGE),T.updatePatternPaintBuffers(p)),M.draw(g,v.TRIANGLES,s,e.stencilModeForClipping(_),l,Et.disabled,P,n.id,k.layoutVertexBuffer,k.indexBuffer,k.segments,n.paint,e.transform.zoom,T),m=!1}}}}}},fill:function(e,r,n,a){var i=n.paint.get("fill-color"),o=n.paint.get("fill-opacity");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get("fill-pattern"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===i.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?"opaque":"translucent";if(e.renderPass===c){var u=e.depthModeForSublayer(1,"opaque"===e.renderPass?At.ReadWrite:At.ReadOnly);Jr(e,r,n,a,u,s,!1)}if("translucent"===e.renderPass&&n.paint.get("fill-antialias")){var h=e.depthModeForSublayer(n.getPaintProperty("fill-outline-color")?2:0,At.ReadOnly);Jr(e,r,n,a,h,s,!0)}}},"fill-extrusion":function(t,e,r,n){var a=r.paint.get("fill-extrusion-opacity");if(0!==a&&"translucent"===t.renderPass){var i=new At(t.context.gl.LEQUAL,At.ReadWrite,t.depthRangeFor3D);if(1!==a||r.paint.get("fill-extrusion-pattern").constantOr(1))Kr(t,e,r,n,i,Mt.disabled,St.disabled),Kr(t,e,r,n,i,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();Kr(t,e,r,n,i,Mt.disabled,o)}}},hillshade:function(t,e,r,n){if("offscreen"===t.renderPass||"translucent"===t.renderPass){for(var a=t.context,i=e.getSource().maxzoom,o=t.depthModeForSublayer(0,At.ReadOnly),s=Mt.disabled,l=t.colorModeForRenderPass(),c=0,u=n;c<u.length;c+=1){var h=u[c],f=e.getTile(h);f.needsHillshadePrepare&&"offscreen"===t.renderPass?$r(t,f,r,i,o,s,l):"translucent"===t.renderPass&&Qr(t,f,r,o,s,l)}a.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if("translucent"===t.renderPass&&0!==r.paint.get("raster-opacity"))for(var a=t.context,i=a.gl,o=e.getSource(),s=t.useProgram("raster"),l=Mt.disabled,c=t.colorModeForRenderPass(),u=n.length&&n[0].overscaledZ,h=!t.options.moving,f=0,p=n;f<p.length;f+=1){var d=p[f],g=t.depthModeForSublayer(d.overscaledZ-u,1===r.paint.get("raster-opacity")?At.ReadWrite:At.ReadOnly,i.LESS),v=e.getTile(d),m=t.transform.calculatePosMatrix(d.toUnwrapped(),h);v.registerFadeDuration(r.paint.get("raster-fade-duration"));var y=e.findLoadedParent(d,0),x=tn(v,y,e,r,t.transform),b=void 0,_=void 0,w="nearest"===r.paint.get("raster-resampling")?i.NEAREST:i.LINEAR;a.activeTexture.set(i.TEXTURE0),v.texture.bind(w,i.CLAMP_TO_EDGE,i.LINEAR_MIPMAP_NEAREST),a.activeTexture.set(i.TEXTURE1),y?(y.texture.bind(w,i.CLAMP_TO_EDGE,i.LINEAR_MIPMAP_NEAREST),b=Math.pow(2,y.tileID.overscaledZ-v.tileID.overscaledZ),_=[v.tileID.canonical.x*b%1,v.tileID.canonical.y*b%1]):v.texture.bind(w,i.CLAMP_TO_EDGE,i.LINEAR_MIPMAP_NEAREST);var k=Dr(m,_||[0,0],b||1,x,r);o instanceof P?s.draw(a,i.TRIANGLES,g,l,c,Et.disabled,k,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):v.maskedBoundsBuffer&&v.maskedIndexBuffer&&v.segments?s.draw(a,i.TRIANGLES,g,l,c,Et.disabled,k,r.id,v.maskedBoundsBuffer,v.maskedIndexBuffer,v.segments,r.paint,t.transform.zoom):s.draw(a,i.TRIANGLES,g,l,c,Et.disabled,k,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get("background-color"),a=r.paint.get("background-opacity");if(0!==a){var i=t.context,o=i.gl,s=t.transform,l=s.tileSize,c=r.paint.get("background-pattern");if(!t.isPatternMissing(c)){var u=!c&&1===n.a&&1===a&&t.opaquePassEnabledForLayer()?"opaque":"translucent";if(t.renderPass===u){var h=Mt.disabled,f=t.depthModeForSublayer(0,"opaque"===u?At.ReadWrite:At.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?"backgroundPattern":"background"),g=s.coveringTiles({tileSize:l});c&&(i.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var v=r.getCrossfadeParameters(),m=0,y=g;m<y.length;m+=1){var x=y[m],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Nr(b,a,t,c,{tileID:x,tileSize:l},v):Br(b,a,n);d.draw(i,o.TRIANGLES,f,h,p,Et.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)en(t,e,r[n])},custom:function(t,e,r){var n=t.context,a=r.implementation;if("offscreen"===t.renderPass){var i=a.prerender;i&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),i.call(a,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if("translucent"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(Mt.disabled);var o="3d"===a.renderingMode?new At(t.context.gl.LEQUAL,At.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,At.ReadOnly);n.setDepthMode(o),a.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},an=function(e,r){this.context=new Lt(e),this.transform=r,this._tileTextures={},this.setup(),this.numSublayers=Ct.maxUnderzooming+Ct.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.depthRboNeedsClear=!0,this.emptyProgramConfiguration=new t.ProgramConfiguration,this.crossTileSymbolIndex=new Oe};function on(t,e){if(t.y>e.y){var r=t;t=e,e=r}return{x0:t.x,y0:t.y,x1:e.x,y1:e.y,dx:e.x-t.x,dy:e.y-t.y}}function sn(t,e,r,n,a){var i=Math.max(r,Math.floor(e.y0)),o=Math.min(n,Math.ceil(e.y1));if(t.x0===e.x0&&t.y0===e.y0?t.x0+e.dy/t.dy*t.dx<e.x1:t.x1-e.dy/t.dy*t.dx<e.x0){var s=t;t=e,e=s}for(var l=t.dx/t.dy,c=e.dx/e.dy,u=t.dx>0,h=e.dx<0,f=i;f<o;f++){var p=l*Math.max(0,Math.min(t.dy,f+u-t.y0))+t.x0,d=c*Math.max(0,Math.min(e.dy,f+h-e.y0))+e.x0;a(Math.floor(d),Math.ceil(p),f)}}function ln(t,e,r,n,a,i){var o,s=on(t,e),l=on(e,r),c=on(r,t);s.dy>l.dy&&(o=s,s=l,l=o),s.dy>c.dy&&(o=s,s=c,c=o),l.dy>c.dy&&(o=l,l=c,c=o),s.dy&&sn(c,s,n,a,i),l.dy&&sn(c,l,n,a,i)}an.prototype.resize=function(e,r){var n=this.context.gl;if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var a=0,i=this.style._order;a<i.length;a+=1){var o=i[a];this.style._layers[o].resize()}this.depthRbo&&(n.deleteRenderbuffer(this.depthRbo),this.depthRbo=null)},an.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Fe.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Fe.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var a=new t.StructArrayLayout4i8;a.emplaceBack(0,0,0,0),a.emplaceBack(t.EXTENT,0,t.EXTENT,0),a.emplaceBack(0,t.EXTENT,0,t.EXTENT),a.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(a,t.rasterBoundsAttributes.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var i=new t.StructArrayLayout2i4;i.emplaceBack(0,0),i.emplaceBack(1,0),i.emplaceBack(0,1),i.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(i,Fe.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s);var l=this.context.gl;this.stencilClearMode=new Mt({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},an.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram("clippingMask").draw(e,r.TRIANGLES,At.disabled,this.stencilClearMode,St.disabled,Et.disabled,Tr(n),"$clipping",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},an.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(St.disabled),r.setDepthMode(At.disabled);var a=this.useProgram("clippingMask");this._tileClippingMaskIDs={};for(var i=0,o=e;i<o.length;i+=1){var s=o[i],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;a.draw(r,n.TRIANGLES,At.disabled,new Mt({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),St.disabled,Et.disabled,Tr(s.posMatrix),"$clipping",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},an.prototype.stencilModeFor3D=function(){this.currentStencilSource=void 0,this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new Mt({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},an.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new Mt({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},an.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new St([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):"opaque"===this.renderPass?St.unblended:St.alphaBlended},an.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return At.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new At(r||this.context.gl.LEQUAL,e,[n,n])},an.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},an.prototype.render=function(e,r){this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var n=this.style._order,a=this.style.sourceCaches;for(var i in a){var o=a[i];o.used&&o.prepare(this.context)}var s={},l={},c={};for(var u in a){var h=a[u];s[u]=h.getVisibleCoordinates(),l[u]=s[u].slice().reverse(),c[u]=h.getVisibleCoordinates(!0).reverse()}for(var f in a){var p=a[f],d=p.getSource();if("raster"===d.type||"raster-dem"===d.type){for(var g=[],v=0,m=s[f];v<m.length;v+=1){var y=m[v];g.push(p.getTile(y))}Vr(g,this.context)}}this.opaquePassCutoff=1/0;for(var x=0;x<n.length;x++){var b=n[x];if(this.style._layers[b].is3D()){this.opaquePassCutoff=x;break}}this.renderPass="offscreen",this.depthRboNeedsClear=!0;for(var _=0,w=n;_<w.length;_+=1){var k=w[_],T=this.style._layers[k];if(T.hasOffscreenPass()&&!T.isHidden(this.transform.zoom)){var A=l[T.source];("custom"===T.type||A.length)&&this.renderLayer(this,a[T.source],T,A)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass="opaque",this.currentLayer=n.length-1;this.currentLayer>=0;this.currentLayer--){var M=this.style._layers[n[this.currentLayer]],S=a[M.source],E=s[M.source];this._renderTileClippingMasks(M,E),this.renderLayer(this,S,M,E)}for(this.renderPass="translucent",this.currentLayer=0;this.currentLayer<n.length;this.currentLayer++){var L=this.style._layers[n[this.currentLayer]],C=a[L.source],P=("symbol"===L.type?c:l)[L.source];this._renderTileClippingMasks(L,s[L.source]),this.renderLayer(this,C,L,P)}if(this.options.showTileBoundaries)for(var O in a){nn.debug(this,a[O],s[O]);break}this.context.setDefault()},an.prototype.setupOffscreenDepthRenderbuffer=function(){var t=this.context;this.depthRbo||(this.depthRbo=t.createRenderbuffer(t.gl.DEPTH_COMPONENT16,this.width,this.height))},an.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||("background"===r.type||"custom"===r.type||n.length)&&(this.id=r.id,nn[r.type](t,e,r,n,this.style.placement.variableOffsets))},an.prototype.translatePosMatrix=function(e,r,n,a,i){if(!n[0]&&!n[1])return e;var o=i?"map"===a?this.transform.angle:0:"viewport"===a?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[i?n[0]:ce(r,n[0],this.transform.zoom),i?n[1]:ce(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},an.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},an.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},an.prototype.isPatternMissing=function(t){if(!t)return!1;var e=this.imageManager.getPattern(t.from),r=this.imageManager.getPattern(t.to);return!e||!r},an.prototype.useProgram=function(t,e){void 0===e&&(e=this.emptyProgramConfiguration),this.cache=this.cache||{};var r=""+t+(e.cacheKey||"")+(this._showOverdrawInspector?"/overdraw":"");return this.cache[r]||(this.cache[r]=new fr(this.context,ur[t],e,jr[t],this._showOverdrawInspector)),this.cache[r]},an.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},an.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)};var cn=function(e,r,n){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===n||n,this._minZoom=e||0,this._maxZoom=r||22,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._posMatrixCache={},this._alignedPosMatrixCache={}},un={minZoom:{configurable:!0},maxZoom:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerPoint:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};cn.prototype.clone=function(){var t=new cn(this._minZoom,this._maxZoom,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._calcMatrices(),t},un.minZoom.get=function(){return this._minZoom},un.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},un.maxZoom.get=function(){return this._maxZoom},un.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},un.renderWorldCopies.get=function(){return this._renderWorldCopies},un.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},un.worldSize.get=function(){return this.tileSize*this.scale},un.centerPoint.get=function(){return this.size._div(2)},un.size.get=function(){return new t.Point(this.width,this.height)},un.bearing.get=function(){return-this.angle/Math.PI*180},un.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},un.pitch.get=function(){return this._pitch/Math.PI*180},un.pitch.set=function(e){var r=t.clamp(e,0,60)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},un.fov.get=function(){return this._fov/Math.PI*180},un.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},un.zoom.get=function(){return this._zoom},un.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},un.center.get=function(){return this._center},un.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},cn.prototype.coveringZoomLevel=function(t){return(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize))},cn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),a=this.pointCoordinate(new t.Point(this.width,0)),i=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,a.x,i.x,o.x)),l=Math.floor(Math.max(n.x,a.x,i.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},cn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var a=t.MercatorCoordinate.fromLngLat(this.center),i=Math.pow(2,r),o=new t.Point(i*a.x-.5,i*a.y-.5);return function(e,r,n,a){void 0===a&&(a=!0);var i=1<<e,o={};function s(r,s,l){var c,u,h,f;if(l>=0&&l<=i)for(c=r;c<s;c++)u=Math.floor(c/i),h=(c%i+i)%i,0!==u&&!0!==a||(f=new t.OverscaledTileID(n,u,e,h,l),o[f.key]=f)}var l=r.map(function(e){return new t.Point(e.x,e.y)._mult(i)});return ln(l[0],l[1],l[2],0,i,s),ln(l[2],l[3],l[0],0,i,s),Object.keys(o).map(function(t){return o[t]})}(r,[this.pointCoordinate(new t.Point(0,0)),this.pointCoordinate(new t.Point(this.width,0)),this.pointCoordinate(new t.Point(this.width,this.height)),this.pointCoordinate(new t.Point(0,this.height))],e.reparseOverscaled?n:r,this._renderWorldCopies).sort(function(t,e){return o.dist(t.canonical)-o.dist(e.canonical)})},cn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},un.unmodified.get=function(){return this._unmodified},cn.prototype.zoomScale=function(t){return Math.pow(2,t)},cn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},cn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},cn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},un.point.get=function(){return this.project(this.center)},cn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),a=this.pointCoordinate(this.centerPoint),i=this.locationCoordinate(e),o=new t.MercatorCoordinate(i.x-(n.x-a.x),i.y-(n.y-a.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},cn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},cn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},cn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},cn.prototype.coordinateLocation=function(t){return t.toLngLat()},cn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var a=r[3],i=n[3],o=r[0]/a,s=n[0]/i,l=r[1]/a,c=n[1]/i,u=r[2]/a,h=n[2]/i,f=u===h?0:(0-u)/(h-u);return new t.MercatorCoordinate(t.number(o,s,f)/this.worldSize,t.number(l,c,f)/this.worldSize)},cn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},cn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},cn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},cn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},cn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,a=r?this._alignedPosMatrixCache:this._posMatrixCache;if(a[n])return a[n];var i=e.canonical,o=this.worldSize/this.zoomScale(i.z),s=i.x+Math.pow(2,i.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,i.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),a[n]=new Float32Array(l),a[n]},cn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},cn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,a,i=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;i=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-i<c.y?c.y/(o-i):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+i)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,v=c.y/2;g-v<i&&(a=i+v),g+v>o&&(a=o-v)}if(this.lngRange){var m=p.x,y=c.x/2;m-y<s&&(n=s+y),m+y>l&&(n=l-y)}void 0===n&&void 0===a||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==a?a:p.y))),this._unmodified=u,this._constraining=!1}},cn.prototype._calcMatrices=function(){if(this.height){this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var e=this._fov/2,r=Math.PI/2+this._pitch,n=Math.sin(e)*this.cameraToCenterDistance/Math.sin(Math.PI-r-e),a=this.point,i=a.x,o=a.y,s=1.01*(Math.cos(Math.PI/2-this._pitch)*n+this.cameraToCenterDistance),l=this.height/50,c=new Float64Array(16);t.perspective(c,this._fov,this.width/this.height,l,s),t.scale(c,c,[1,-1,1]),t.translate(c,c,[0,0,-this.cameraToCenterDistance]),t.rotateX(c,c,this._pitch),t.rotateZ(c,c,this.angle),t.translate(c,c,[-i,-o,0]),this.mercatorMatrix=t.scale([],c,[this.worldSize,this.worldSize,this.worldSize]),t.scale(c,c,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=c;var u=this.width%2/2,h=this.height%2/2,f=Math.cos(this.angle),p=Math.sin(this.angle),d=i-Math.round(i)+f*u+p*h,g=o-Math.round(o)+f*h+p*u,v=new Float64Array(c);if(t.translate(v,v,[d>.5?d-1:d,g>.5?g-1:g,0]),this.alignedProjMatrix=v,c=t.create(),t.scale(c,c,[this.width/2,-this.height/2,1]),t.translate(c,c,[1,-1,0]),this.labelPlaneMatrix=c,c=t.create(),t.scale(c,c,[1,-1,1]),t.translate(c,c,[-1,-1,0]),t.scale(c,c,[2/this.width,2/this.height,1]),this.glCoordMatrix=c,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(c=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error("failed to invert matrix");this.pixelMatrixInverse=c,this._posMatrixCache={},this._alignedPosMatrixCache={}}},cn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},cn.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},cn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,a=r.y,i=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),a=Math.min(a,c.y),i=Math.max(i,c.x),o=Math.max(o,c.y)}return[new t.Point(n,a),new t.Point(i,a),new t.Point(i,o),new t.Point(n,o),new t.Point(n,a)]},Object.defineProperties(cn.prototype,un);var hn=function(){var e,r,n,a;t.bindAll(["_onHashChange","_updateHash"],this),this._updateHash=(e=this._updateHashUnthrottled.bind(this),300,r=!1,n=null,a=function(){n=null,r&&(e(),n=setTimeout(a,300),r=!1)},function(){return r=!0,n||a(),n})};hn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener("hashchange",this._onHashChange,!1),this._map.on("moveend",this._updateHash),this},hn.prototype.remove=function(){return t.window.removeEventListener("hashchange",this._onHashChange,!1),this._map.off("moveend",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},hn.prototype.getHashString=function(t){var e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),a=Math.pow(10,n),i=Math.round(e.lng*a)/a,o=Math.round(e.lat*a)/a,s=this._map.getBearing(),l=this._map.getPitch(),c="";return c+=t?"#/"+i+"/"+o+"/"+r:"#"+r+"/"+o+"/"+i,(s||l)&&(c+="/"+Math.round(10*s)/10),l&&(c+="/"+Math.round(l)),c},hn.prototype._onHashChange=function(){var e=t.window.location.hash.replace("#","").split("/");return e.length>=3&&(this._map.jumpTo({center:[+e[2],+e[1]],zoom:+e[0],bearing:+(e[3]||0),pitch:+(e[4]||0)}),!0)},hn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,"",e)}catch(t){}};var fn=function(e){function n(n,a,i,o){void 0===o&&(o={});var s=r.mousePos(a.getCanvasContainer(),i),l=a.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:i},o)),this._defaultPrevented=!1,this.target=a}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var a={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},a.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,a),n}(t.Event),pn=function(e){function n(n,a,i){var o=r.touchPos(a.getCanvasContainer(),i),s=o.map(function(t){return a.unproject(t)}),l=o.reduce(function(t,e,r,n){return t.add(e.div(n.length))},new t.Point(0,0)),c=a.unproject(l);e.call(this,n,{points:o,point:l,lngLats:s,lngLat:c,originalEvent:i}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var a={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},a.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,a),n}(t.Event),dn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),gn=function(e){this._map=e,this._el=e.getCanvasContainer(),this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll(["_onWheel","_onTimeout","_onScrollFrame","_onScrollFinished"],this)};gn.prototype.setZoomRate=function(t){this._defaultZoomRate=t},gn.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},gn.prototype.isEnabled=function(){return!!this._enabled},gn.prototype.isActive=function(){return!!this._active},gn.prototype.isZooming=function(){return!!this._zooming},gn.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&"center"===t.around)},gn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},gn.prototype.onWheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),a=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type="wheel":0!==r&&Math.abs(r)<4?this._type="trackpad":a>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(a*r)<200?"trackpad":"wheel",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this.isActive()||this._start(e)),e.preventDefault()}},gn.prototype._onTimeout=function(t){this._type="wheel",this._delta-=this._lastValue,this.isActive()||this._start(t)},gn.prototype._start=function(e){if(this._delta){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0,this._map.fire(new t.Event("movestart",{originalEvent:e})),this._map.fire(new t.Event("zoomstart",{originalEvent:e}))),this._finishTimeout&&clearTimeout(this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame))}},gn.prototype._onScrollFrame=function(){var e=this;if(this._frameId=null,this.isActive()){var r=this._map.transform;if(0!==this._delta){var n="wheel"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,a=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==a&&(a=1/a);var i="number"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(i*a))),"wheel"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o="number"==typeof this._targetZoom?this._targetZoom:r.zoom,s=this._startZoom,l=this._easing,c=!1;if("wheel"===this._type&&s&&l){var u=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=l(u);r.zoom=t.number(s,o,h),u<1?this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame)):c=!0}else r.zoom=o,c=!0;r.setLocationAtPoint(this._around,this._aroundPoint),this._map.fire(new t.Event("move",{originalEvent:this._lastWheelEvent})),this._map.fire(new t.Event("zoom",{originalEvent:this._lastWheelEvent})),c&&(this._active=!1,this._finishTimeout=setTimeout(function(){e._zooming=!1,e._map.fire(new t.Event("zoomend",{originalEvent:e._lastWheelEvent})),e._map.fire(new t.Event("moveend",{originalEvent:e._lastWheelEvent})),delete e._targetZoom},200))}},gn.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,a=(t.browser.now()-n.start)/n.duration,i=n.easing(a+.01)-n.easing(a),o=.27/Math.sqrt(i*i+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r};var vn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._container=e.getContainer(),this._clickTolerance=r.clickTolerance||1,t.bindAll(["_onMouseMove","_onMouseUp","_onKeyDown"],this)};vn.prototype.isEnabled=function(){return!!this._enabled},vn.prototype.isActive=function(){return!!this._active},vn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},vn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},vn.prototype.onMouseDown=function(e){this.isEnabled()&&e.shiftKey&&0===e.button&&(t.window.document.addEventListener("mousemove",this._onMouseMove,!1),t.window.document.addEventListener("keydown",this._onKeyDown,!1),t.window.document.addEventListener("mouseup",this._onMouseUp,!1),r.disableDrag(),this._startPos=this._lastPos=r.mousePos(this._el,e),this._active=!0)},vn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);if(!(this._lastPos.equals(e)||!this._box&&e.dist(this._startPos)<this._clickTolerance)){var n=this._startPos;this._lastPos=e,this._box||(this._box=r.create("div","mapboxgl-boxzoom",this._container),this._container.classList.add("mapboxgl-crosshair"),this._fireEvent("boxzoomstart",t));var a=Math.min(n.x,e.x),i=Math.max(n.x,e.x),o=Math.min(n.y,e.y),s=Math.max(n.y,e.y);r.setTransform(this._box,"translate("+a+"px,"+o+"px)"),this._box.style.width=i-a+"px",this._box.style.height=s-o+"px"}},vn.prototype._onMouseUp=function(e){if(0===e.button){var n=this._startPos,a=r.mousePos(this._el,e);this._finish(),r.suppressClick(),n.x===a.x&&n.y===a.y?this._fireEvent("boxzoomcancel",e):this._map.fitScreenCoordinates(n,a,this._map.getBearing(),{linear:!0}).fire(new t.Event("boxzoomend",{originalEvent:e}))}},vn.prototype._onKeyDown=function(t){27===t.keyCode&&(this._finish(),this._fireEvent("boxzoomcancel",t))},vn.prototype._finish=function(){this._active=!1,t.window.document.removeEventListener("mousemove",this._onMouseMove,!1),t.window.document.removeEventListener("keydown",this._onKeyDown,!1),t.window.document.removeEventListener("mouseup",this._onMouseUp,!1),this._container.classList.remove("mapboxgl-crosshair"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},vn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var mn=t.bezier(0,0,.25,1),yn=function(e,r){this._map=e,this._el=r.element||e.getCanvasContainer(),this._state="disabled",this._button=r.button||"right",this._bearingSnap=r.bearingSnap||0,this._pitchWithRotate=!1!==r.pitchWithRotate,t.bindAll(["onMouseDown","_onMouseMove","_onMouseUp","_onBlur","_onDragFrame"],this)};yn.prototype.isEnabled=function(){return"disabled"!==this._state},yn.prototype.isActive=function(){return"active"===this._state},yn.prototype.enable=function(){this.isEnabled()||(this._state="enabled")},yn.prototype.disable=function(){if(this.isEnabled())switch(this._state){case"active":this._state="disabled",this._unbind(),this._deactivate(),this._fireEvent("rotateend"),this._pitchWithRotate&&this._fireEvent("pitchend"),this._fireEvent("moveend");break;case"pending":this._state="disabled",this._unbind();break;default:this._state="disabled"}},yn.prototype.onMouseDown=function(e){if("enabled"===this._state){var n="touchstart"===e.type;if(n)this._startTime=Date.now();else if("right"===this._button){if(this._eventButton=r.mouseButton(e),this._eventButton!==(e.ctrlKey?0:2))return}else{if(e.ctrlKey||0!==r.mouseButton(e))return;this._eventButton=0}r.disableDrag(),n?(t.window.document.addEventListener("touchmove",this._onMouseMove,{capture:!0}),t.window.document.addEventListener("touchend",this._onMouseUp)):(t.window.document.addEventListener("mousemove",this._onMouseMove,{capture:!0}),t.window.document.addEventListener("mouseup",this._onMouseUp)),t.window.addEventListener("blur",this._onBlur),this._state="pending",this._inertia=[[t.browser.now(),this._map.getBearing()]],this._startPos=this._prevPos=this._lastPos=r.mousePos(this._el,e),this._center=this._map.transform.centerPoint,e.preventDefault()}},yn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);this._lastPos.equals(e)||(this._lastMoveEvent=t,this._lastPos=e,"pending"===this._state&&(this._state="active",this._fireEvent("rotatestart",t),this._fireEvent("movestart",t),this._pitchWithRotate&&this._fireEvent("pitchstart",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},yn.prototype._onDragFrame=function(){this._frameId=null;var e=this._lastMoveEvent;if(e){var r=this._map.transform,n=this._prevPos,a=this._lastPos,i=.8*(n.x-a.x),o=-.5*(n.y-a.y),s=r.bearing-i,l=r.pitch-o,c=this._inertia,u=c[c.length-1];this._drainInertiaBuffer(),c.push([t.browser.now(),this._map._normalizeBearing(s,u[1])]),r.bearing=s,this._pitchWithRotate&&(this._fireEvent("pitch",e),r.pitch=l),this._fireEvent("rotate",e),this._fireEvent("move",e),delete this._lastMoveEvent,this._prevPos=this._lastPos}},yn.prototype._onMouseUp=function(t){if("touchend"===t.type&&this._startPos===this._lastPos&&Date.now()-this._startTime<300&&this._el.click(),r.mouseButton(t)===this._eventButton)switch(this._state){case"active":this._state="enabled",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialRotate(t);break;case"pending":this._state="enabled",this._unbind()}},yn.prototype._onBlur=function(t){switch(this._state){case"active":this._state="enabled",this._unbind(),this._deactivate(),this._fireEvent("rotateend",t),this._pitchWithRotate&&this._fireEvent("pitchend",t),this._fireEvent("moveend",t);break;case"pending":this._state="enabled",this._unbind()}},yn.prototype._unbind=function(){t.window.document.removeEventListener("mousemove",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener("mouseup",this._onMouseUp),t.window.document.removeEventListener("touchmove",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener("touchend",this._onMouseUp),t.window.removeEventListener("blur",this._onBlur),r.enableDrag()},yn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._prevPos,delete this._lastPos},yn.prototype._inertialRotate=function(t){var e=this;this._fireEvent("rotateend",t),this._drainInertiaBuffer();var r=this._map,n=r.getBearing(),a=this._inertia,i=function(){Math.abs(n)<e._bearingSnap?r.resetNorth({noMoveStart:!0},{originalEvent:t}):e._fireEvent("moveend",t),e._pitchWithRotate&&e._fireEvent("pitchend",t)};if(a.length<2)i();else{var o=a[0],s=a[a.length-1],l=a[a.length-2],c=r._normalizeBearing(n,l[1]),u=s[1]-o[1],h=u<0?-1:1,f=(s[0]-o[0])/1e3;if(0!==u&&0!==f){var p=Math.abs(u*(.25/f));p>180&&(p=180);var d=p/180;c+=h*p*(d/2),Math.abs(r._normalizeBearing(c,0))<this._bearingSnap&&(c=r._normalizeBearing(0,c)),r.rotateTo(c,{duration:1e3*d,easing:mn,noMoveStart:!0},{originalEvent:t})}else i()}},yn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},yn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var xn=t.bezier(0,0,.3,1),bn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._state="disabled",this._clickTolerance=r.clickTolerance||1,t.bindAll(["_onMove","_onMouseUp","_onTouchEnd","_onBlur","_onDragFrame"],this)};bn.prototype.isEnabled=function(){return"disabled"!==this._state},bn.prototype.isActive=function(){return"active"===this._state},bn.prototype.enable=function(){this.isEnabled()||(this._el.classList.add("mapboxgl-touch-drag-pan"),this._state="enabled")},bn.prototype.disable=function(){if(this.isEnabled())switch(this._el.classList.remove("mapboxgl-touch-drag-pan"),this._state){case"active":this._state="disabled",this._unbind(),this._deactivate(),this._fireEvent("dragend"),this._fireEvent("moveend");break;case"pending":this._state="disabled",this._unbind();break;default:this._state="disabled"}},bn.prototype.onMouseDown=function(e){"enabled"===this._state&&(e.ctrlKey||0!==r.mouseButton(e)||(r.addEventListener(t.window.document,"mousemove",this._onMove,{capture:!0}),r.addEventListener(t.window.document,"mouseup",this._onMouseUp),this._start(e)))},bn.prototype.onTouchStart=function(e){"enabled"===this._state&&(e.touches.length>1||(r.addEventListener(t.window.document,"touchmove",this._onMove,{capture:!0,passive:!1}),r.addEventListener(t.window.document,"touchend",this._onTouchEnd),this._start(e)))},bn.prototype._start=function(e){t.window.addEventListener("blur",this._onBlur),this._state="pending",this._startPos=this._mouseDownPos=this._prevPos=this._lastPos=r.mousePos(this._el,e),this._inertia=[[t.browser.now(),this._startPos]]},bn.prototype._onMove=function(e){e.preventDefault();var n=r.mousePos(this._el,e);this._lastPos.equals(n)||"pending"===this._state&&n.dist(this._mouseDownPos)<this._clickTolerance||(this._lastMoveEvent=e,this._lastPos=n,this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),this._lastPos]),"pending"===this._state&&(this._state="active",this._fireEvent("dragstart",e),this._fireEvent("movestart",e)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},bn.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform;e.setLocationAtPoint(e.pointLocation(this._prevPos),this._lastPos),this._fireEvent("drag",t),this._fireEvent("move",t),this._prevPos=this._lastPos,delete this._lastMoveEvent}},bn.prototype._onMouseUp=function(t){if(0===r.mouseButton(t))switch(this._state){case"active":this._state="enabled",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialPan(t);break;case"pending":this._state="enabled",this._unbind()}},bn.prototype._onTouchEnd=function(t){switch(this._state){case"active":this._state="enabled",this._unbind(),this._deactivate(),this._inertialPan(t);break;case"pending":this._state="enabled",this._unbind()}},bn.prototype._onBlur=function(t){switch(this._state){case"active":this._state="enabled",this._unbind(),this._deactivate(),this._fireEvent("dragend",t),this._fireEvent("moveend",t);break;case"pending":this._state="enabled",this._unbind()}},bn.prototype._unbind=function(){r.removeEventListener(t.window.document,"touchmove",this._onMove,{capture:!0,passive:!1}),r.removeEventListener(t.window.document,"touchend",this._onTouchEnd),r.removeEventListener(t.window.document,"mousemove",this._onMove,{capture:!0}),r.removeEventListener(t.window.document,"mouseup",this._onMouseUp),r.removeEventListener(t.window,"blur",this._onBlur)},bn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._prevPos,delete this._mouseDownPos,delete this._lastPos},bn.prototype._inertialPan=function(t){this._fireEvent("dragend",t),this._drainInertiaBuffer();var e=this._inertia;if(e.length<2)this._fireEvent("moveend",t);else{var r=e[e.length-1],n=e[0],a=r[1].sub(n[1]),i=(r[0]-n[0])/1e3;if(0===i||r[1].equals(n[1]))this._fireEvent("moveend",t);else{var o=a.mult(.3/i),s=o.mag();s>1400&&(s=1400,o._unit()._mult(s));var l=s/750,c=o.mult(-l/2);this._map.panBy(c,{duration:1e3*l,easing:xn,noMoveStart:!0},{originalEvent:t})}}},bn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},bn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var _n=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll(["_onKeyDown"],this)};function wn(t){return t*(2-t)}_n.prototype.isEnabled=function(){return!!this._enabled},_n.prototype.enable=function(){this.isEnabled()||(this._el.addEventListener("keydown",this._onKeyDown,!1),this._enabled=!0)},_n.prototype.disable=function(){this.isEnabled()&&(this._el.removeEventListener("keydown",this._onKeyDown),this._enabled=!1)},_n.prototype._onKeyDown=function(t){if(!(t.altKey||t.ctrlKey||t.metaKey)){var e=0,r=0,n=0,a=0,i=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),a=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),a=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),i=-1);break;case 40:t.shiftKey?n=-1:(i=1,t.preventDefault());break;default:return}var o=this._map,s=o.getZoom(),l={duration:300,delayEndEvents:500,easing:wn,zoom:e?Math.round(s)+e*(t.shiftKey?2:1):s,bearing:o.getBearing()+15*r,pitch:o.getPitch()+10*n,offset:[100*-a,100*-i],center:o.getCenter()};o.easeTo(l,{originalEvent:t})}};var kn=function(e){this._map=e,t.bindAll(["_onDblClick","_onZoomEnd"],this)};kn.prototype.isEnabled=function(){return!!this._enabled},kn.prototype.isActive=function(){return!!this._active},kn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},kn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},kn.prototype.onTouchStart=function(t){var e=this;if(this.isEnabled()&&!(t.points.length>1))if(this._tapped){var r=t.points[0],n=this._tappedPoint;if(n&&n.dist(r)<=30){t.originalEvent.preventDefault();var a=function(){e._tapped&&e._zoom(t),e._map.off("touchcancel",i),e._resetTapped()},i=function(){e._map.off("touchend",a),e._resetTapped()};this._map.once("touchend",a),this._map.once("touchcancel",i)}else this._resetTapped()}else this._tappedPoint=t.points[0],this._tapped=setTimeout(function(){e._tapped=null,e._tappedPoint=null},300)},kn.prototype._resetTapped=function(){clearTimeout(this._tapped),this._tapped=null,this._tappedPoint=null},kn.prototype.onDblClick=function(t){this.isEnabled()&&(t.originalEvent.preventDefault(),this._zoom(t))},kn.prototype._zoom=function(t){this._active=!0,this._map.on("zoomend",this._onZoomEnd),this._map.zoomTo(this._map.getZoom()+(t.originalEvent.shiftKey?-1:1),{around:t.lngLat},t)},kn.prototype._onZoomEnd=function(){this._active=!1,this._map.off("zoomend",this._onZoomEnd)};var Tn=t.bezier(0,0,.15,1),An=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll(["_onMove","_onEnd","_onTouchFrame"],this)};An.prototype.isEnabled=function(){return!!this._enabled},An.prototype.enable=function(t){this.isEnabled()||(this._el.classList.add("mapboxgl-touch-zoom-rotate"),this._enabled=!0,this._aroundCenter=!!t&&"center"===t.around)},An.prototype.disable=function(){this.isEnabled()&&(this._el.classList.remove("mapboxgl-touch-zoom-rotate"),this._enabled=!1)},An.prototype.disableRotation=function(){this._rotationDisabled=!0},An.prototype.enableRotation=function(){this._rotationDisabled=!1},An.prototype.onStart=function(e){if(this.isEnabled()&&2===e.touches.length){var n=r.mousePos(this._el,e.touches[0]),a=r.mousePos(this._el,e.touches[1]),i=n.add(a).div(2);this._startVec=n.sub(a),this._startAround=this._map.transform.pointLocation(i),this._gestureIntent=void 0,this._inertia=[],r.addEventListener(t.window.document,"touchmove",this._onMove,{passive:!1}),r.addEventListener(t.window.document,"touchend",this._onEnd)}},An.prototype._getTouchEventData=function(t){var e=r.mousePos(this._el,t.touches[0]),n=r.mousePos(this._el,t.touches[1]),a=e.sub(n);return{vec:a,center:e.add(n).div(2),scale:a.mag()/this._startVec.mag(),bearing:this._rotationDisabled?0:180*a.angleWith(this._startVec)/Math.PI}},An.prototype._onMove=function(e){if(2===e.touches.length){var r=this._getTouchEventData(e),n=r.vec,a=r.scale,i=r.bearing;if(!this._gestureIntent){var o=this._rotationDisabled&&1!==a||Math.abs(1-a)>.15;Math.abs(i)>10?this._gestureIntent="rotate":o&&(this._gestureIntent="zoom"),this._gestureIntent&&(this._map.fire(new t.Event(this._gestureIntent+"start",{originalEvent:e})),this._map.fire(new t.Event("movestart",{originalEvent:e})),this._startVec=n)}this._lastTouchEvent=e,this._frameId||(this._frameId=this._map._requestRenderFrame(this._onTouchFrame)),e.preventDefault()}},An.prototype._onTouchFrame=function(){this._frameId=null;var e=this._gestureIntent;if(e){var r=this._map.transform;this._startScale||(this._startScale=r.scale,this._startBearing=r.bearing);var n=this._getTouchEventData(this._lastTouchEvent),a=n.center,i=n.bearing,o=n.scale,s=r.pointLocation(a),l=r.locationPoint(s);"rotate"===e&&(r.bearing=this._startBearing+i),r.zoom=r.scaleZoom(this._startScale*o),r.setLocationAtPoint(this._startAround,l),this._map.fire(new t.Event(e,{originalEvent:this._lastTouchEvent})),this._map.fire(new t.Event("move",{originalEvent:this._lastTouchEvent})),this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),o,a])}},An.prototype._onEnd=function(e){r.removeEventListener(t.window.document,"touchmove",this._onMove,{passive:!1}),r.removeEventListener(t.window.document,"touchend",this._onEnd);var n=this._gestureIntent,a=this._startScale;if(this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._gestureIntent,delete this._startScale,delete this._startBearing,delete this._lastTouchEvent,n){this._map.fire(new t.Event(n+"end",{originalEvent:e})),this._drainInertiaBuffer();var i=this._inertia,o=this._map;if(i.length<2)o.snapToNorth({},{originalEvent:e});else{var s=i[i.length-1],l=i[0],c=o.transform.scaleZoom(a*s[1]),u=o.transform.scaleZoom(a*l[1]),h=c-u,f=(s[0]-l[0])/1e3,p=s[2];if(0!==f&&c!==u){var d=.15*h/f;Math.abs(d)>2.5&&(d=d>0?2.5:-2.5);var g=1e3*Math.abs(d/(12*.15)),v=c+d*g/2e3;v<0&&(v=0),o.easeTo({zoom:v,duration:g,easing:Tn,around:this._aroundCenter?o.getCenter():o.unproject(p),noMoveStart:!0},{originalEvent:e})}else o.snapToNorth({},{originalEvent:e})}}},An.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>2&&r-e[0][0]>160;)e.shift()};var Mn={scrollZoom:gn,boxZoom:vn,dragRotate:yn,dragPan:bn,keyboard:_n,doubleClickZoom:kn,touchZoomRotate:An},Sn=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll(["_renderFrameCallback"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.resetNorthPitch=function(e,r){return this.easeTo(t.extend({bearing:0,pitch:0,duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,a){if("number"==typeof(a=t.extend({padding:{top:0,bottom:0,right:0,left:0},offset:[0,0],maxZoom:this.transform.maxZoom},a)).padding){var i=a.padding;a.padding={top:i,bottom:i,right:i,left:i}}if(t.deepEqual(Object.keys(a.padding).sort(function(t,e){return t<e?-1:t>e?1:0}),["bottom","left","right","top"])){var o=this.transform,s=o.project(t.LngLat.convert(e)),l=o.project(t.LngLat.convert(r)),c=s.rotate(-n*Math.PI/180),u=l.rotate(-n*Math.PI/180),h=new t.Point(Math.max(c.x,u.x),Math.max(c.y,u.y)),f=new t.Point(Math.min(c.x,u.x),Math.min(c.y,u.y)),p=h.sub(f),d=(o.width-a.padding.left-a.padding.right)/p.x,g=(o.height-a.padding.top-a.padding.bottom)/p.y;if(!(g<0||d<0)){var v=Math.min(o.scaleZoom(o.scale*Math.min(d,g)),a.maxZoom),m=t.Point.convert(a.offset),y=(a.padding.left-a.padding.right)/2,x=(a.padding.top-a.padding.bottom)/2,b=new t.Point(m.x+y,m.y+x).mult(o.scale/o.zoomScale(v));return{center:o.unproject(s.add(l).div(2).sub(b)),zoom:v,bearing:n}}t.warnOnce("Map cannot fit within canvas with the given bounds, padding, and/or offset.")}else t.warnOnce("options.padding must be a positive number, or an Object with keys 'bottom', 'left', 'right', 'top'")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,a,i){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,a),a,i)},r.prototype._fitInternal=function(e,r,n){return e?(r=t.extend(e,r)).linear?this.easeTo(r,n):this.flyTo(r,n):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,a=!1,i=!1,o=!1;return"zoom"in e&&n.zoom!==+e.zoom&&(a=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),"bearing"in e&&n.bearing!==+e.bearing&&(i=!0,n.bearing=+e.bearing),"pitch"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),this.fire(new t.Event("movestart",r)).fire(new t.Event("move",r)),a&&this.fire(new t.Event("zoomstart",r)).fire(new t.Event("zoom",r)).fire(new t.Event("zoomend",r)),i&&this.fire(new t.Event("rotatestart",r)).fire(new t.Event("rotate",r)).fire(new t.Event("rotateend",r)),o&&this.fire(new t.Event("pitchstart",r)).fire(new t.Event("pitch",r)).fire(new t.Event("pitchend",r)),this.fire(new t.Event("moveend",r))},r.prototype.easeTo=function(e,r){var n=this;this.stop(),(!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate||t.browser.prefersReducedMotion)&&(e.duration=0);var a=this.transform,i=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l="zoom"in e?+e.zoom:i,c="bearing"in e?this._normalizeBearing(e.bearing,o):o,u="pitch"in e?+e.pitch:s,h=a.centerPoint.add(t.Point.convert(e.offset)),f=a.pointLocation(h),p=t.LngLat.convert(e.center||f);this._normalizeCenter(p);var d,g,v=a.project(f),m=a.project(p).sub(v),y=a.zoomScale(l-i);return e.around&&(d=t.LngLat.convert(e.around),g=a.locationPoint(d)),this._zooming=l!==i,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,e.noMoveStart),clearTimeout(this._easeEndTimeoutID),this._ease(function(e){if(n._zooming&&(a.zoom=t.number(i,l,e)),n._rotating&&(a.bearing=t.number(o,c,e)),n._pitching&&(a.pitch=t.number(s,u,e)),d)a.setLocationAtPoint(d,g);else{var f=a.zoomScale(a.zoom-i),p=l>i?Math.min(2,y):Math.max(.5,y),x=Math.pow(p,1-e),b=a.unproject(v.add(m.mult(e*x)).mult(f));a.setLocationAtPoint(a.renderWorldCopies?b.wrap():b,h)}n._fireMoveEvents(r)},function(){e.delayEndEvents?n._easeEndTimeoutID=setTimeout(function(){return n._afterEase(r)},e.delayEndEvents):n._afterEase(r)},e),this},r.prototype._prepareEase=function(e,r){this._moving=!0,r||this.fire(new t.Event("movestart",e)),this._zooming&&this.fire(new t.Event("zoomstart",e)),this._rotating&&this.fire(new t.Event("rotatestart",e)),this._pitching&&this.fire(new t.Event("pitchstart",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event("move",e)),this._zooming&&this.fire(new t.Event("zoom",e)),this._rotating&&this.fire(new t.Event("rotate",e)),this._pitching&&this.fire(new t.Event("pitch",e))},r.prototype._afterEase=function(e){var r=this._zooming,n=this._rotating,a=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,r&&this.fire(new t.Event("zoomend",e)),n&&this.fire(new t.Event("rotateend",e)),a&&this.fire(new t.Event("pitchend",e)),this.fire(new t.Event("moveend",e))},r.prototype.flyTo=function(e,r){var n=this;if(t.browser.prefersReducedMotion){var a=t.pick(e,["center","zoom","bearing","pitch","around"]);return this.jumpTo(a,r)}this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,o=this.getZoom(),s=this.getBearing(),l=this.getPitch(),c="zoom"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):o,u="bearing"in e?this._normalizeBearing(e.bearing,s):s,h="pitch"in e?+e.pitch:l,f=i.zoomScale(c-o),p=i.centerPoint.add(t.Point.convert(e.offset)),d=i.pointLocation(p),g=t.LngLat.convert(e.center||d);this._normalizeCenter(g);var v=i.project(d),m=i.project(g).sub(v),y=e.curve,x=Math.max(i.width,i.height),b=x/f,_=m.mag();if("minZoom"in e){var w=t.clamp(Math.min(e.minZoom,o,c),i.minZoom,i.maxZoom),k=x/i.zoomScale(w-o);y=Math.sqrt(k/_*2)}var T=y*y;function A(t){var e=(b*b-x*x+(t?-1:1)*T*T*_*_)/(2*(t?b:x)*T*_);return Math.log(Math.sqrt(e*e+1)-e)}function M(t){return(Math.exp(t)-Math.exp(-t))/2}function S(t){return(Math.exp(t)+Math.exp(-t))/2}var E=A(0),L=function(t){return S(E)/S(E+y*t)},C=function(t){return x*((S(E)*(M(e=E+y*t)/S(e))-M(E))/T)/_;var e},P=(A(1)-E)/y;if(Math.abs(_)<1e-6||!isFinite(P)){if(Math.abs(x-b)<1e-6)return this.easeTo(e,r);var O=b<x?-1:1;P=Math.abs(Math.log(b/x))/y,C=function(){return 0},L=function(t){return Math.exp(O*y*t)}}if("duration"in e)e.duration=+e.duration;else{var z="screenSpeed"in e?+e.screenSpeed/y:+e.speed;e.duration=1e3*P/z}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=s!==u,this._pitching=h!==l,this._prepareEase(r,!1),this._ease(function(e){var a=e*P,f=1/L(a);i.zoom=1===e?c:o+i.scaleZoom(f),n._rotating&&(i.bearing=t.number(s,u,e)),n._pitching&&(i.pitch=t.number(l,h,e));var d=1===e?g:i.unproject(v.add(m.mult(C(a))).mult(f));i.setLocationAtPoint(i.renderWorldCopies?d.wrap():d,p),n._fireMoveEvents(r)},function(){return n._afterEase(r)},e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var t=this._onEaseEnd;delete this._onEaseEnd,t.call(this)}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),En=function(e){void 0===e&&(e={}),this.options=e,t.bindAll(["_updateEditLink","_updateData","_updateCompact"],this)};En.prototype.getDefaultPosition=function(){return"bottom-right"},En.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create("div","mapboxgl-ctrl mapboxgl-ctrl-attrib"),this._innerContainer=r.create("div","mapboxgl-ctrl-attrib-inner",this._container),e&&this._container.classList.add("mapboxgl-compact"),this._updateAttributions(),this._updateEditLink(),this._map.on("styledata",this._updateData),this._map.on("sourcedata",this._updateData),this._map.on("moveend",this._updateEditLink),void 0===e&&(this._map.on("resize",this._updateCompact),this._updateCompact()),this._container},En.prototype.onRemove=function(){r.remove(this._container),this._map.off("styledata",this._updateData),this._map.off("sourcedata",this._updateData),this._map.off("moveend",this._updateEditLink),this._map.off("resize",this._updateCompact),this._map=void 0},En.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(".mapbox-improve-map"));var r=[{key:"owner",value:this.styleOwner},{key:"id",value:this.styleId},{key:"access_token",value:this._map._requestManager._customAccessToken||t.config.ACCESS_TOKEN}];if(e){var n=r.reduce(function(t,e,n){return e.value&&(t+=e.key+"="+e.value+(n<r.length-1?"&":"")),t},"?");e.href=t.config.FEEDBACK_URL+"/"+n+(this._map._hash?this._map._hash.getHashString(!0):""),e.rel="noopener nofollow"}},En.prototype._updateData=function(t){!t||"metadata"!==t.sourceDataType&&"style"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},En.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map(function(t){return"string"!=typeof t?"":t})):"string"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var a=r[n];if(a.used){var i=a.getSource();i.attribution&&t.indexOf(i.attribution)<0&&t.push(i.attribution)}}t.sort(function(t,e){return t.length-e.length});var o=(t=t.filter(function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0})).join(" | ");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove("mapboxgl-attrib-empty")):this._container.classList.add("mapboxgl-attrib-empty"),this._editLink=null)}},En.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add("mapboxgl-compact"):this._container.classList.remove("mapboxgl-compact")};var Ln=function(){t.bindAll(["_updateLogo"],this),t.bindAll(["_updateCompact"],this)};Ln.prototype.onAdd=function(t){this._map=t,this._container=r.create("div","mapboxgl-ctrl");var e=r.create("a","mapboxgl-ctrl-logo");return e.target="_blank",e.rel="noopener nofollow",e.href="https://www.mapbox.com/",e.setAttribute("aria-label","Mapbox logo"),e.setAttribute("rel","noopener nofollow"),this._container.appendChild(e),this._container.style.display="none",this._map.on("sourcedata",this._updateLogo),this._updateLogo(),this._map.on("resize",this._updateCompact),this._updateCompact(),this._container},Ln.prototype.onRemove=function(){r.remove(this._container),this._map.off("sourcedata",this._updateLogo),this._map.off("resize",this._updateCompact)},Ln.prototype.getDefaultPosition=function(){return"bottom-left"},Ln.prototype._updateLogo=function(t){t&&"metadata"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?"block":"none")},Ln.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},Ln.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add("mapboxgl-compact"):e.classList.remove("mapboxgl-compact")}};var Cn=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};Cn.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},Cn.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var a=n[r];if(a.id===t)return void(a.cancelled=!0)}},Cn.prototype.run=function(){var t=this._currentlyRunning=this._queue;this._queue=[];for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!n.cancelled&&(n.callback(),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},Cn.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var Pn=t.window.HTMLImageElement,On=t.window.HTMLElement,zn={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:0,maxZoom:22,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,bearingSnap:7,clickTolerance:3,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:"sans-serif",transformRequest:null,accessToken:null,fadeDuration:300,crossSourceCollisions:!0},In=function(n){function a(e){var a=this;if(null!=(e=t.extend({},zn,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error("maxZoom must be greater than minZoom");var i=new cn(e.minZoom,e.maxZoom,e.renderWorldCopies);if(n.call(this,i,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new Cn,this._controls=[],this._mapId=t.uniqueId(),this._requestManager=new t.RequestManager(e.transformRequest,e.accessToken),"string"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error("Container '"+e.container+"' not found.")}else{if(!(e.container instanceof On))throw new Error("Invalid type: 'container' must be a String or HTMLElement.");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll(["_onWindowOnline","_onWindowResize","_contextLost","_contextRestored"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error("Failed to initialize WebGL.");this.on("move",function(){return a._update(!1)}),this.on("moveend",function(){return a._update(!1)}),this.on("zoom",function(){return a._update(!0)}),void 0!==t.window&&(t.window.addEventListener("online",this._onWindowOnline,!1),t.window.addEventListener("resize",this._onWindowResize,!1)),function(t,e){var n=t.getCanvasContainer(),a=null,i=!1,o=null;for(var s in Mn)t[s]=new Mn[s](t,e),e.interactive&&e[s]&&t[s].enable(e[s]);r.addEventListener(n,"mouseout",function(e){t.fire(new fn("mouseout",t,e))}),r.addEventListener(n,"mousedown",function(a){i=!0,o=r.mousePos(n,a);var s=new fn("mousedown",t,a);t.fire(s),s.defaultPrevented||(e.interactive&&!t.doubleClickZoom.isActive()&&t.stop(),t.boxZoom.onMouseDown(a),t.boxZoom.isActive()||t.dragPan.isActive()||t.dragRotate.onMouseDown(a),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onMouseDown(a))}),r.addEventListener(n,"mouseup",function(e){var r=t.dragRotate.isActive();a&&!r&&t.fire(new fn("contextmenu",t,a)),a=null,i=!1,t.fire(new fn("mouseup",t,e))}),r.addEventListener(n,"mousemove",function(e){if(!t.dragPan.isActive()&&!t.dragRotate.isActive()){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new fn("mousemove",t,e))}}),r.addEventListener(n,"mouseover",function(e){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new fn("mouseover",t,e))}),r.addEventListener(n,"touchstart",function(r){var n=new pn("touchstart",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&t.stop(),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onTouchStart(r),t.touchZoomRotate.onStart(r),t.doubleClickZoom.onTouchStart(n))},{passive:!1}),r.addEventListener(n,"touchmove",function(e){t.fire(new pn("touchmove",t,e))},{passive:!1}),r.addEventListener(n,"touchend",function(e){t.fire(new pn("touchend",t,e))}),r.addEventListener(n,"touchcancel",function(e){t.fire(new pn("touchcancel",t,e))}),r.addEventListener(n,"click",function(a){var i=r.mousePos(n,a);(!o||i.equals(o)||i.dist(o)<e.clickTolerance)&&t.fire(new fn("click",t,a))}),r.addEventListener(n,"dblclick",function(e){var r=new fn("dblclick",t,e);t.fire(r),r.defaultPrevented||t.doubleClickZoom.onDblClick(r)}),r.addEventListener(n,"contextmenu",function(e){var r=t.dragRotate.isActive();i||r?i&&(a=e):t.fire(new fn("contextmenu",t,e)),(t.dragRotate.isEnabled()||t.listens("contextmenu"))&&e.preventDefault()}),r.addEventListener(n,"wheel",function(r){e.interactive&&t.stop();var n=new dn("wheel",t,r);t.fire(n),n.defaultPrevented||t.scrollZoom.onWheel(r)},{passive:!1})}(this,e),this._hash=e.hash&&(new hn).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new En({customAttribution:e.customAttribution})),this.addControl(new Ln,e.logoPosition),this.on("style.load",function(){a.transform.unmodified&&a.jumpTo(a.style.stylesheet)}),this.on("data",function(e){a._update("style"===e.dataType),a.fire(new t.Event(e.dataType+"data",e))}),this.on("dataloading",function(e){a.fire(new t.Event(e.dataType+"dataloading",e))})}n&&(a.__proto__=n),a.prototype=Object.create(n&&n.prototype),a.prototype.constructor=a;var i={showTileBoundaries:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0},version:{configurable:!0}};return a.prototype._getMapId=function(){return this._mapId},a.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r="top-right"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error("Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.")));var n=e.onAdd(this);this._controls.push(e);var a=this._controlPositions[r];return-1!==r.indexOf("bottom")?a.insertBefore(n,a.firstChild):a.appendChild(n),this},a.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error("Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},a.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],a=r[1];return this._resizeCanvas(n,a),this.transform.resize(n,a),this.painter.resize(n,a),this.fire(new t.Event("movestart",e)).fire(new t.Event("move",e)).fire(new t.Event("resize",e)).fire(new t.Event("moveend",e)),this},a.prototype.getBounds=function(){return this.transform.getBounds()},a.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},a.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},a.prototype.setMinZoom=function(t){if((t=null==t?0:t)>=0&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error("minZoom must be between 0 and the current maxZoom, inclusive")},a.prototype.getMinZoom=function(){return this.transform.minZoom},a.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error("maxZoom must be greater than the current minZoom")},a.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},a.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},a.prototype.getMaxZoom=function(){return this.transform.maxZoom},a.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},a.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},a.prototype.isMoving=function(){return this._moving||this.dragPan.isActive()||this.dragRotate.isActive()||this.scrollZoom.isActive()},a.prototype.isZooming=function(){return this._zooming||this.scrollZoom.isZooming()},a.prototype.isRotating=function(){return this._rotating||this.dragRotate.isActive()},a.prototype.on=function(t,e,r){var a=this;if(void 0===r)return n.prototype.on.call(this,t,e);var i=function(){var n;if("mouseenter"===t||"mouseover"===t){var i=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=a.getLayer(e)?a.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?i||(i=!0,r.call(a,new fn(t,a,n.originalEvent,{features:o}))):i=!1},mouseout:function(){i=!1}}}}if("mouseleave"===t||"mouseout"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(a.getLayer(e)?a.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(a,new fn(t,a,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(a,new fn(t,a,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=a.getLayer(e)?a.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(a,t),delete t.features)},n)}}();for(var o in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(i),i.delegates)this.on(o,i.delegates[o]);return this},a.prototype.off=function(t,e,r){if(void 0===r)return n.prototype.off.call(this,t,e);if(this._delegatedListeners&&this._delegatedListeners[t])for(var a=this._delegatedListeners[t],i=0;i<a.length;i++){var o=a[i];if(o.layer===e&&o.listener===r){for(var s in o.delegates)this.off(s,o.delegates[s]);return a.splice(i,1),this}}return this},a.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||"number"==typeof e[0])n=[t.Point.convert(e)];else{var a=t.Point.convert(e[0]),i=t.Point.convert(e[1]);n=[a,new t.Point(i.x,a.y),i,new t.Point(a.x,i.y),a]}return this.style.queryRenderedFeatures(n,r,this.transform)},a.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},a.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:this._localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},a.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new Re(this,e||{}),this.style.setEventedParent(this,{style:this.style}),"string"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},a.prototype._diffStyle=function(e,r){var n=this;if("string"==typeof e){var a=this._requestManager.normalizeStyleURL(e),i=this._requestManager.transformRequest(a,t.ResourceType.Style);t.getJSON(i,function(e,a){e?n.fire(new t.ErrorEvent(e)):a&&n._updateDiff(a,r)})}else"object"==typeof e&&this._updateDiff(e,r)},a.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce("Unable to perform style diff: "+(n.message||n.error||n)+".  Rebuilding the style from scratch."),this._updateStyle(e,r)}},a.prototype.getStyle=function(){if(this.style)return this.style.serialize()},a.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce("There is no style added to the map.")},a.prototype.addSource=function(t,e){return this.style.addSource(t,e),this._update(!0)},a.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error("There is no source with ID '"+e+"'")))},a.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var a=r[n];if("loaded"!==a.state&&"errored"!==a.state)return!1}}return!0},a.prototype.addSourceType=function(t,e,r){return this.style.addSourceType(t,e,r)},a.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},a.prototype.getSource=function(t){return this.style.getSource(t)},a.prototype.addImage=function(e,r,n){void 0===n&&(n={});var a=n.pixelRatio;void 0===a&&(a=1);var i=n.sdf;if(void 0===i&&(i=!1),r instanceof Pn){var o=t.browser.getImageData(r),s=o.width,l=o.height,c=o.data;this.style.addImage(e,{data:new t.RGBAImage({width:s,height:l},c),pixelRatio:a,sdf:i,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error("Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`")));var u=r.width,h=r.height,f=r.data,p=r;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:h},new Uint8Array(f)),pixelRatio:a,sdf:i,version:0,userImage:p}),p.onAdd&&p.onAdd(this,e)}},a.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error("The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.")));var a=r instanceof Pn?t.browser.getImageData(r):r,i=a.width,o=a.height,s=a.data;if(void 0===i||void 0===o)return this.fire(new t.ErrorEvent(new Error("Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`")));if(i!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error("The width and height of the updated image must be that same as the previous version of the image")));var l=!(r instanceof Pn);n.data.replace(s,l),this.style.updateImage(e,n)},a.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error("Missing required image id"))),!1)},a.prototype.removeImage=function(t){this.style.removeImage(t)},a.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},a.prototype.listImages=function(){return this.style.listImages()},a.prototype.addLayer=function(t,e){return this.style.addLayer(t,e),this._update(!0)},a.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},a.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},a.prototype.getLayer=function(t){return this.style.getLayer(t)},a.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},a.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},a.prototype.getFilter=function(t){return this.style.getFilter(t)},a.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},a.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},a.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},a.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},a.prototype.setLight=function(t,e){return void 0===e&&(e={}),this.style.setLight(t,e),this._update(!0)},a.prototype.getLight=function(){return this.style.getLight()},a.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},a.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},a.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},a.prototype.getContainer=function(){return this._container},a.prototype.getCanvasContainer=function(){return this._canvasContainer},a.prototype.getCanvas=function(){return this._canvas},a.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},a.prototype._detectMissingCSS=function(){"rgb(250, 128, 114)"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue("background-color")&&t.warnOnce("This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.")},a.prototype._setupContainer=function(){var t=this._container;t.classList.add("mapboxgl-map"),(this._missingCSSCanary=r.create("div","mapboxgl-canary",t)).style.visibility="hidden",this._detectMissingCSS();var e=this._canvasContainer=r.create("div","mapboxgl-canvas-container",t);this._interactive&&e.classList.add("mapboxgl-interactive"),this._canvas=r.create("canvas","mapboxgl-canvas",e),this._canvas.style.position="absolute",this._canvas.addEventListener("webglcontextlost",this._contextLost,!1),this._canvas.addEventListener("webglcontextrestored",this._contextRestored,!1),this._canvas.setAttribute("tabindex","0"),this._canvas.setAttribute("aria-label","Map");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var a=this._controlContainer=r.create("div","mapboxgl-control-container",t),i=this._controlPositions={};["top-left","top-right","bottom-left","bottom-right"].forEach(function(t){i[t]=r.create("div","mapboxgl-ctrl-"+t,a)})},a.prototype._resizeCanvas=function(e,r){var n=t.window.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+"px",this._canvas.style.height=r+"px"},a.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext("webgl",r)||this._canvas.getContext("experimental-webgl",r);n?(this.painter=new an(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error("Failed to initialize WebGL")))},a.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event("webglcontextlost",{originalEvent:e}))},a.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event("webglcontextrestored",{originalEvent:e}))},a.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},a.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},a.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},a.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},a.prototype._render=function(){this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run();var e=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var r=this.transform.zoom,n=t.browser.now();this.style.zoomHistory.update(r,n);var a=new t.EvaluationParameters(r,{now:n,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),i=a.crossFadingFactor();1===i&&i===this._crossFadingFactor||(e=!0,this._crossFadingFactor=i),this.style.update(a)}return this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration}),this.fire(new t.Event("render")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event("load"))),this.style&&(this.style.hasTransitions()||e)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this._sourcesDirty||this._repaint||this._styleDirty||this._placementDirty?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new t.Event("idle")),this},a.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener("resize",this._onWindowResize,!1),t.window.removeEventListener("online",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension("WEBGL_lose_context");n&&n.loseContext(),Dn(this._canvasContainer),Dn(this._controlContainer),Dn(this._missingCSSCanary),this._container.classList.remove("mapboxgl-map"),this.fire(new t.Event("remove"))},a.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame(function(){e._frame=null,e._render()}))},a.prototype._onWindowOnline=function(){this._update()},a.prototype._onWindowResize=function(){this._trackResize&&this.resize()._update()},i.showTileBoundaries.get=function(){return!!this._showTileBoundaries},i.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},i.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},i.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},i.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},i.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},i.repaint.get=function(){return!!this._repaint},i.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},i.vertices.get=function(){return!!this._vertices},i.vertices.set=function(t){this._vertices=t,this._update()},a.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},i.version.get=function(){return t.version},Object.defineProperties(a.prototype,i),a}(Sn);function Dn(t){t.parentNode&&t.parentNode.removeChild(t)}var Rn={showCompass:!0,showZoom:!0,visualizePitch:!1},Fn=function(e){var n=this;this.options=t.extend({},Rn,e),this._container=r.create("div","mapboxgl-ctrl mapboxgl-ctrl-group"),this._container.addEventListener("contextmenu",function(t){return t.preventDefault()}),this.options.showZoom&&(t.bindAll(["_updateZoomButtons"],this),this._zoomInButton=this._createButton("mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-in","Zoom in",function(){return n._map.zoomIn()}),this._zoomOutButton=this._createButton("mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-out","Zoom out",function(){return n._map.zoomOut()})),this.options.showCompass&&(t.bindAll(["_rotateCompassArrow"],this),this._compass=this._createButton("mapboxgl-ctrl-icon mapboxgl-ctrl-compass","Reset bearing to north",function(){n.options.visualizePitch?n._map.resetNorthPitch():n._map.resetNorth()}),this._compassArrow=r.create("span","mapboxgl-ctrl-compass-arrow",this._compass))};function Bn(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var a=new t.LngLat(e.lng-360,e.lat),i=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(a).distSqr(r)<o?e=a:n.locationPoint(i).distSqr(r)<o&&(e=i)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Fn.prototype._updateZoomButtons=function(){var t=this._map.getZoom();t===this._map.getMaxZoom()?this._zoomInButton.classList.add("mapboxgl-ctrl-icon-disabled"):this._zoomInButton.classList.remove("mapboxgl-ctrl-icon-disabled"),t===this._map.getMinZoom()?this._zoomOutButton.classList.add("mapboxgl-ctrl-icon-disabled"):this._zoomOutButton.classList.remove("mapboxgl-ctrl-icon-disabled")},Fn.prototype._rotateCompassArrow=function(){var t=this.options.visualizePitch?"scale("+1/Math.pow(Math.cos(this._map.transform.pitch*(Math.PI/180)),.5)+") rotateX("+this._map.transform.pitch+"deg) rotateZ("+this._map.transform.angle*(180/Math.PI)+"deg)":"rotate("+this._map.transform.angle*(180/Math.PI)+"deg)";this._compassArrow.style.transform=t},Fn.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._map.on("zoom",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this.options.visualizePitch&&this._map.on("pitch",this._rotateCompassArrow),this._map.on("rotate",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new yn(t,{button:"left",element:this._compass}),r.addEventListener(this._compass,"mousedown",this._handler.onMouseDown),r.addEventListener(this._compass,"touchstart",this._handler.onMouseDown,{passive:!1}),this._handler.enable()),this._container},Fn.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off("zoom",this._updateZoomButtons),this.options.showCompass&&(this.options.visualizePitch&&this._map.off("pitch",this._rotateCompassArrow),this._map.off("rotate",this._rotateCompassArrow),r.removeEventListener(this._compass,"mousedown",this._handler.onMouseDown),r.removeEventListener(this._compass,"touchstart",this._handler.onMouseDown,{passive:!1}),this._handler.disable(),delete this._handler),delete this._map},Fn.prototype._createButton=function(t,e,n){var a=r.create("button",t,this._container);return a.type="button",a.title=e,a.setAttribute("aria-label",e),a.addEventListener("click",n),a};var Nn={center:"translate(-50%,-50%)",top:"translate(-50%,0)","top-left":"translate(0,0)","top-right":"translate(-100%,0)",bottom:"translate(-50%,-100%)","bottom-left":"translate(0,-100%)","bottom-right":"translate(-100%,-100%)",left:"translate(0,-50%)",right:"translate(-100%,-50%)"};function jn(t,e,r){var n=t.classList;for(var a in Nn)n.remove("mapboxgl-"+r+"-anchor-"+a);n.add("mapboxgl-"+r+"-anchor-"+e)}var Vn,Un=function(e){function n(n,a){if(e.call(this),(n instanceof t.window.HTMLElement||a)&&(n=t.extend({element:n},a)),t.bindAll(["_update","_onMove","_onUp","_addDragHandler","_onMapClick"],this),this._anchor=n&&n.anchor||"center",this._color=n&&n.color||"#3FB1CE",this._draggable=n&&n.draggable||!1,this._state="inactive",n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create("div");var i=r.createNS("http://www.w3.org/2000/svg","svg");i.setAttributeNS(null,"display","block"),i.setAttributeNS(null,"height","41px"),i.setAttributeNS(null,"width","27px"),i.setAttributeNS(null,"viewBox","0 0 27 41");var o=r.createNS("http://www.w3.org/2000/svg","g");o.setAttributeNS(null,"stroke","none"),o.setAttributeNS(null,"stroke-width","1"),o.setAttributeNS(null,"fill","none"),o.setAttributeNS(null,"fill-rule","evenodd");var s=r.createNS("http://www.w3.org/2000/svg","g");s.setAttributeNS(null,"fill-rule","nonzero");var l=r.createNS("http://www.w3.org/2000/svg","g");l.setAttributeNS(null,"transform","translate(3.0, 29.0)"),l.setAttributeNS(null,"fill","#000000");for(var c=0,u=[{rx:"10.5",ry:"5.25002273"},{rx:"10.5",ry:"5.25002273"},{rx:"9.5",ry:"4.77275007"},{rx:"8.5",ry:"4.29549936"},{rx:"7.5",ry:"3.81822308"},{rx:"6.5",ry:"3.34094679"},{rx:"5.5",ry:"2.86367051"},{rx:"4.5",ry:"2.38636864"}];c<u.length;c+=1){var h=u[c],f=r.createNS("http://www.w3.org/2000/svg","ellipse");f.setAttributeNS(null,"opacity","0.04"),f.setAttributeNS(null,"cx","10.5"),f.setAttributeNS(null,"cy","5.80029008"),f.setAttributeNS(null,"rx",h.rx),f.setAttributeNS(null,"ry",h.ry),l.appendChild(f)}var p=r.createNS("http://www.w3.org/2000/svg","g");p.setAttributeNS(null,"fill",this._color);var d=r.createNS("http://www.w3.org/2000/svg","path");d.setAttributeNS(null,"d","M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z"),p.appendChild(d);var g=r.createNS("http://www.w3.org/2000/svg","g");g.setAttributeNS(null,"opacity","0.25"),g.setAttributeNS(null,"fill","#000000");var v=r.createNS("http://www.w3.org/2000/svg","path");v.setAttributeNS(null,"d","M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z"),g.appendChild(v);var m=r.createNS("http://www.w3.org/2000/svg","g");m.setAttributeNS(null,"transform","translate(6.0, 7.0)"),m.setAttributeNS(null,"fill","#FFFFFF");var y=r.createNS("http://www.w3.org/2000/svg","g");y.setAttributeNS(null,"transform","translate(8.0, 8.0)");var x=r.createNS("http://www.w3.org/2000/svg","circle");x.setAttributeNS(null,"fill","#000000"),x.setAttributeNS(null,"opacity","0.25"),x.setAttributeNS(null,"cx","5.5"),x.setAttributeNS(null,"cy","5.5"),x.setAttributeNS(null,"r","5.4999962");var b=r.createNS("http://www.w3.org/2000/svg","circle");b.setAttributeNS(null,"fill","#FFFFFF"),b.setAttributeNS(null,"cx","5.5"),b.setAttributeNS(null,"cy","5.5"),b.setAttributeNS(null,"r","5.4999962"),y.appendChild(x),y.appendChild(b),s.appendChild(l),s.appendChild(p),s.appendChild(g),s.appendChild(m),s.appendChild(y),i.appendChild(s),this._element.appendChild(i),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add("mapboxgl-marker"),this._element.addEventListener("dragstart",function(t){t.preventDefault()}),jn(this._element,this._anchor,"marker"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on("move",this._update),t.on("moveend",this._update),this.setDraggable(this._draggable),this._update(),this._map.on("click",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off("click",this._onMapClick),this._map.off("move",this._update),this._map.off("moveend",this._update),this._map.off("mousedown",this._addDragHandler),this._map.off("touchstart",this._addDragHandler),this._map.off("mouseup",this._onUp),this._map.off("touchend",this._onUp),this._map.off("mousemove",this._onMove),this._map.off("touchmove",this._onMove),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null),t){if(!("offset"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],"top-left":[0,0],"top-right":[0,0],bottom:[0,-38.1],"bottom-left":[e,-1*(24.6+e)],"bottom-right":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat)}return this},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){this._map&&(this._map.transform.renderWorldCopies&&(this._lngLat=Bn(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset),t&&"moveend"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Nn[this._anchor]+" translate("+this._pos.x+"px, "+this._pos.y+"px)"))},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents="none","pending"===this._state&&(this._state="active",this.fire(new t.Event("dragstart"))),this.fire(new t.Event("drag"))},n.prototype._onUp=function(){this._element.style.pointerEvents="auto",this._positionDelta=null,this._map.off("mousemove",this._onMove),this._map.off("touchmove",this._onMove),"active"===this._state&&this.fire(new t.Event("dragend")),this._state="inactive"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state="pending",this._map.on("mousemove",this._onMove),this._map.on("touchmove",this._onMove),this._map.once("mouseup",this._onUp),this._map.once("touchend",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on("mousedown",this._addDragHandler),this._map.on("touchstart",this._addDragHandler)):(this._map.off("mousedown",this._addDragHandler),this._map.off("touchstart",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n}(t.Evented),qn={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showUserLocation:!0},Hn=function(e){function n(r){e.call(this),this.options=t.extend({},qn,r),t.bindAll(["_onSuccess","_onError","_finish","_setupUI","_updateCamera","_updateMarker"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create("div","mapboxgl-ctrl mapboxgl-ctrl-group"),n=this._setupUI,void 0!==Vn?n(Vn):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:"geolocation"}).then(function(t){Vn="denied"!==t.state,n(Vn)}):(Vn=!!t.window.navigator.geolocation,n(Vn)),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),r.remove(this._container),this._map=void 0},n.prototype._onSuccess=function(e){if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case"WAITING_ACTIVE":case"ACTIVE_LOCK":case"ACTIVE_ERROR":this._watchState="ACTIVE_LOCK",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active-error"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active");break;case"BACKGROUND":case"BACKGROUND_ERROR":this._watchState="BACKGROUND",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background-error"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-background")}this.options.showUserLocation&&"OFF"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&"ACTIVE_LOCK"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove("mapboxgl-user-location-dot-stale"),this.fire(new t.Event("geolocate",e)),this._finish()},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,a=this._map.getBearing(),i=t.extend({bearing:a},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),i,{geolocateSource:!0})},n.prototype._updateMarker=function(t){t?this._userLocationDotMarker.setLngLat([t.coords.longitude,t.coords.latitude]).addTo(this._map):this._userLocationDotMarker.remove()},n.prototype._onError=function(e){if(this.options.trackUserLocation)if(1===e.code)this._watchState="OFF",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active-error"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background-error"),void 0!==this._geolocationWatchID&&this._clearWatch();else switch(this._watchState){case"WAITING_ACTIVE":this._watchState="ACTIVE_ERROR",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active-error");break;case"ACTIVE_LOCK":this._watchState="ACTIVE_ERROR",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active-error"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting");break;case"BACKGROUND":this._watchState="BACKGROUND_ERROR",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-background-error"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting")}"OFF"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add("mapboxgl-user-location-dot-stale"),this.fire(new t.Event("error",e)),this._finish()},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;!1!==e?(this._container.addEventListener("contextmenu",function(t){return t.preventDefault()}),this._geolocateButton=r.create("button","mapboxgl-ctrl-icon mapboxgl-ctrl-geolocate",this._container),this._geolocateButton.type="button",this._geolocateButton.setAttribute("aria-label","Geolocate"),this.options.trackUserLocation&&(this._geolocateButton.setAttribute("aria-pressed","false"),this._watchState="OFF"),this.options.showUserLocation&&(this._dotElement=r.create("div","mapboxgl-user-location-dot"),this._userLocationDotMarker=new Un(this._dotElement),this.options.trackUserLocation&&(this._watchState="OFF")),this._geolocateButton.addEventListener("click",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on("movestart",function(e){e.geolocateSource||"ACTIVE_LOCK"!==n._watchState||(n._watchState="BACKGROUND",n._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-background"),n._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active"),n.fire(new t.Event("trackuserlocationend")))})):t.warnOnce("Geolocation support is not available, the GeolocateControl will not be visible.")},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce("Geolocate control triggered before added to a map"),!1;if(this.options.trackUserLocation){switch(this._watchState){case"OFF":this._watchState="WAITING_ACTIVE",this.fire(new t.Event("trackuserlocationstart"));break;case"WAITING_ACTIVE":case"ACTIVE_LOCK":case"ACTIVE_ERROR":case"BACKGROUND_ERROR":this._watchState="OFF",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-active-error"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background"),this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background-error"),this.fire(new t.Event("trackuserlocationend"));break;case"BACKGROUND":this._watchState="ACTIVE_LOCK",this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-background"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event("trackuserlocationstart"))}switch(this._watchState){case"WAITING_ACTIVE":this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active");break;case"ACTIVE_LOCK":this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active");break;case"ACTIVE_ERROR":this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-active-error");break;case"BACKGROUND":this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-background");break;case"BACKGROUND_ERROR":this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-background-error")}"OFF"===this._watchState&&void 0!==this._geolocationWatchID?this._clearWatch():void 0===this._geolocationWatchID&&(this._geolocateButton.classList.add("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.setAttribute("aria-pressed","true"),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,this.options.positionOptions))}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove("mapboxgl-ctrl-geolocate-waiting"),this._geolocateButton.setAttribute("aria-pressed","false"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),Gn={maxWidth:100,unit:"metric"},Yn=function(e){this.options=t.extend({},Gn,e),t.bindAll(["_onMove","setUnit"],this)};function Wn(t,e,r){var n,a,i,o,s,l,c=r&&r.maxWidth||100,u=t._container.clientHeight/2,h=(n=t.unproject([0,u]),a=t.unproject([c,u]),i=Math.PI/180,o=n.lat*i,s=a.lat*i,l=Math.sin(o)*Math.sin(s)+Math.cos(o)*Math.cos(s)*Math.cos((a.lng-n.lng)*i),6371e3*Math.acos(Math.min(l,1)));if(r&&"imperial"===r.unit){var f=3.2808*h;f>5280?Xn(e,c,f/5280,"mi"):Xn(e,c,f,"ft")}else r&&"nautical"===r.unit?Xn(e,c,h/1852,"nm"):Xn(e,c,h,"m")}function Xn(t,e,r,n){var a,i,o,s=(a=r,(i=Math.pow(10,(""+Math.floor(a)).length-1))*(o=(o=a/i)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o))),l=s/r;"m"===n&&s>=1e3&&(s/=1e3,n="km"),t.style.width=e*l+"px",t.innerHTML=s+n}Yn.prototype.getDefaultPosition=function(){return"bottom-left"},Yn.prototype._onMove=function(){Wn(this._map,this._container,this.options)},Yn.prototype.onAdd=function(t){return this._map=t,this._container=r.create("div","mapboxgl-ctrl mapboxgl-ctrl-scale",t.getContainer()),this._map.on("move",this._onMove),this._onMove(),this._container},Yn.prototype.onRemove=function(){r.remove(this._container),this._map.off("move",this._onMove),this._map=void 0},Yn.prototype.setUnit=function(t){this.options.unit=t,Wn(this._map,this._container,this.options)};var Zn=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce("Full screen control 'container' must be a DOM element.")),t.bindAll(["_onClickFullscreen","_changeIcon"],this),"onfullscreenchange"in t.window.document?this._fullscreenchange="fullscreenchange":"onmozfullscreenchange"in t.window.document?this._fullscreenchange="mozfullscreenchange":"onwebkitfullscreenchange"in t.window.document?this._fullscreenchange="webkitfullscreenchange":"onmsfullscreenchange"in t.window.document&&(this._fullscreenchange="MSFullscreenChange"),this._className="mapboxgl-ctrl"};Zn.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create("div",this._className+" mapboxgl-ctrl-group"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display="none",t.warnOnce("This device does not support fullscreen mode.")),this._controlContainer},Zn.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},Zn.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},Zn.prototype._setupUI=function(){(this._fullscreenButton=r.create("button",this._className+"-icon "+this._className+"-fullscreen",this._controlContainer)).type="button",this._updateTitle(),this._fullscreenButton.addEventListener("click",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},Zn.prototype._updateTitle=function(){var t=this._isFullscreen()?"Exit fullscreen":"Enter fullscreen";this._fullscreenButton.setAttribute("aria-label",t),this._fullscreenButton.title=t},Zn.prototype._isFullscreen=function(){return this._fullscreen},Zn.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(this._className+"-shrink"),this._fullscreenButton.classList.toggle(this._className+"-fullscreen"),this._updateTitle())},Zn.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Jn={closeButton:!0,closeOnClick:!0,className:"",maxWidth:"240px"},Kn=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Jn),r),t.bindAll(["_update","_onClickClose","remove"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){var r=this;return this._map=e,this.options.closeOnClick&&this._map.on("click",this._onClickClose),this._map.on("remove",this.remove),this._update(),this._trackPointer?(this._map.on("mousemove",function(t){r._update(t.point)}),this._map.on("mouseup",function(t){r._update(t.point)}),this._container.classList.add("mapboxgl-popup-track-pointer"),this._map._canvasContainer.classList.add("mapboxgl-track-pointer")):this._map.on("move",this._update),this.fire(new t.Event("open")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off("move",this._update),this._map.off("click",this._onClickClose),this._map.off("remove",this.remove),this._map.off("mousemove"),delete this._map),this.fire(new t.Event("close")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._trackPointer=!1,this._update(),this._map&&(this._map.on("move",this._update),this._map.off("mousemove"),this._container.classList.remove("mapboxgl-popup-track-pointer"),this._map._canvasContainer.classList.remove("mapboxgl-track-pointer")),this},n.prototype.trackPointer=function(){var t=this;return this._trackPointer=!0,this._pos=null,this._map&&(this._map.off("move",this._update),this._map.on("mousemove",function(e){t._update(e.point)}),this._map.on("drag",function(e){t._update(e.point)}),this._container.classList.add("mapboxgl-popup-track-pointer"),this._map._canvasContainer.classList.add("mapboxgl-track-pointer")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),a=t.window.document.createElement("body");for(a.innerHTML=e;r=a.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create("div","mapboxgl-popup-content",this._container),this.options.closeButton&&(this._closeButton=r.create("button","mapboxgl-popup-close-button",this._content),this._closeButton.type="button",this._closeButton.setAttribute("aria-label","Close popup"),this._closeButton.innerHTML="&#215;",this._closeButton.addEventListener("click",this._onClickClose))},n.prototype._update=function(e){var n=this,a=this._lngLat||this._trackPointer;if(this._map&&a&&this._content&&(this._container||(this._container=r.create("div","mapboxgl-popup",this._map.getContainer()),this._tip=r.create("div","mapboxgl-popup-tip",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(" ").forEach(function(t){return n._container.classList.add(t)})),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Bn(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var i=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),o=this.options.anchor,s=function e(r){if(r){if("number"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),"top-left":new t.Point(n,n),"top-right":new t.Point(-n,n),bottom:new t.Point(0,-r),"bottom-left":new t.Point(n,-n),"bottom-right":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var a=t.Point.convert(r);return{center:a,top:a,"top-left":a,"top-right":a,bottom:a,"bottom-left":a,"bottom-right":a,left:a,right:a}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),"top-left":t.Point.convert(r["top-left"]||[0,0]),"top-right":t.Point.convert(r["top-right"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),"bottom-left":t.Point.convert(r["bottom-left"]||[0,0]),"bottom-right":t.Point.convert(r["bottom-right"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!o){var l,c=this._container.offsetWidth,u=this._container.offsetHeight;l=i.y+s.bottom.y<u?["top"]:i.y>this._map.transform.height-u?["bottom"]:[],i.x<c/2?l.push("left"):i.x>this._map.transform.width-c/2&&l.push("right"),o=0===l.length?"bottom":l.join("-")}var h=i.add(s[o]).round();r.setTransform(this._container,Nn[o]+" translate("+h.x+"px,"+h.y+"px)"),jn(this._container,o,"popup")}},n.prototype._onClickClose=function(){this.remove()},n}(t.Evented),Qn={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,Map:In,NavigationControl:Fn,GeolocateControl:Hn,AttributionControl:En,ScaleControl:Yn,FullscreenControl:Zn,Popup:Kn,Marker:Un,Style:Re,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return It.workerCount},set workerCount(t){It.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:""};return Qn}),r},"object"==typeof r&&"undefined"!=typeof e?e.exports=a():(n=n||self).mapboxgl=a()},{}],428:[function(t,e,r){"use strict";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=i(t,n);return r};var n=t("convex-hull");function a(t,e,r){for(var n=new Array(t),a=0;a<t;++a)n[a]=0,a===e&&(n[a]+=.5),a===r&&(n[a]+=.5);return n}function i(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],i=[],o=0;o<=t;++o)if(e&1<<o){r.push(a(t,o-1,o-1)),i.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(a(t,o-1,s-1)),i.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],h=[];for(s=0;s<u.length;++s){if(!i[u[s]])continue t;h.push(i[u[s]].slice())}c.push(h)}return c}},{"convex-hull":131}],429:[function(t,e,r){var n=t("./normalize"),a=t("gl-mat4/create"),i=t("gl-mat4/clone"),o=t("gl-mat4/determinant"),s=t("gl-mat4/invert"),l=t("gl-mat4/transpose"),c={length:t("gl-vec3/length"),normalize:t("gl-vec3/normalize"),dot:t("gl-vec3/dot"),cross:t("gl-vec3/cross")},u=a(),h=a(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,a){t[0]=e[0]*n+r[0]*a,t[1]=e[1]*n+r[1]*a,t[2]=e[2]*n+r[2]*a}e.exports=function(t,e,r,a,v,m){if(e||(e=[0,0,0]),r||(r=[0,0,0]),a||(a=[0,0,0]),v||(v=[0,0,0,1]),m||(m=[0,0,0,1]),!n(u,t))return!1;if(i(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var y,x,b,_,w,k,T,A=u[3],M=u[7],S=u[11],E=u[12],L=u[13],C=u[14],P=u[15];if(0!==A||0!==M||0!==S){if(f[0]=A,f[1]=M,f[2]=S,f[3]=P,!s(h,h))return!1;l(h,h),y=v,b=h,_=(x=f)[0],w=x[1],k=x[2],T=x[3],y[0]=b[0]*_+b[4]*w+b[8]*k+b[12]*T,y[1]=b[1]*_+b[5]*w+b[9]*k+b[13]*T,y[2]=b[2]*_+b[6]*w+b[10]*k+b[14]*T,y[3]=b[3]*_+b[7]*w+b[11]*k+b[15]*T}else v[0]=v[1]=v[2]=0,v[3]=1;if(e[0]=E,e[1]=L,e[2]=C,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),a[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-a[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),a[0]/=r[1],a[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-a[1]),a[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-a[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),a[1]/=r[2],a[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var O=0;O<3;O++)r[O]*=-1,p[O][0]*=-1,p[O][1]*=-1,p[O][2]*=-1;return m[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),m[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),m[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),m[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(m[0]=-m[0]),p[0][2]>p[2][0]&&(m[1]=-m[1]),p[1][0]>p[0][1]&&(m[2]=-m[2]),!0}},{"./normalize":430,"gl-mat4/clone":261,"gl-mat4/create":262,"gl-mat4/determinant":263,"gl-mat4/invert":267,"gl-mat4/transpose":278,"gl-vec3/cross":335,"gl-vec3/dot":340,"gl-vec3/length":350,"gl-vec3/normalize":357}],430:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,a=0;a<16;a++)t[a]=e[a]*n;return!0}},{}],431:[function(t,e,r){var n=t("gl-vec3/lerp"),a=t("mat4-recompose"),i=t("mat4-decompose"),o=t("gl-mat4/determinant"),s=t("quat-slerp"),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=i(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=i(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p||(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),a(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},{"gl-mat4/determinant":263,"gl-vec3/lerp":351,"mat4-decompose":429,"mat4-recompose":432,"quat-slerp":484}],432:[function(t,e,r){var n={identity:t("gl-mat4/identity"),translate:t("gl-mat4/translate"),multiply:t("gl-mat4/multiply"),create:t("gl-mat4/create"),scale:t("gl-mat4/scale"),fromRotationTranslation:t("gl-mat4/fromRotationTranslation")},a=(n.create(),n.create());e.exports=function(t,e,r,i,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(a),0!==i[2]&&(a[9]=i[2],n.multiply(t,t,a)),0!==i[1]&&(a[9]=0,a[8]=i[1],n.multiply(t,t,a)),0!==i[0]&&(a[8]=0,a[4]=i[0],n.multiply(t,t,a)),n.scale(t,t,r),t}},{"gl-mat4/create":262,"gl-mat4/fromRotationTranslation":265,"gl-mat4/identity":266,"gl-mat4/multiply":269,"gl-mat4/scale":276,"gl-mat4/translate":277}],433:[function(t,e,r){"use strict";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],434:[function(t,e,r){"use strict";var n=t("binary-search-bounds"),a=t("mat4-interpolate"),i=t("gl-mat4/invert"),o=t("gl-mat4/rotateX"),s=t("gl-mat4/rotateY"),l=t("gl-mat4/rotateZ"),c=t("gl-mat4/lookAt"),u=t("gl-mat4/translate"),h=(t("gl-mat4/scale"),t("gl-vec3/normalize")),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else a(o,f,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],h(g,g);var v=this.computedInverse;i(v,o);var m=this.computedEye,y=v[15];m[0]=v[12]/y,m[1]=v[13]/y,m[2]=v[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=m[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var a=0,i=0;i<3;++i)a+=Math.pow(r[i]-e[i],2);a=Math.log(Math.sqrt(a)),this.computedRadius[0]=a},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var a=this.computedInverse;e&&s(a,a,e),r&&o(a,a,r),n&&l(a,a,n),this.setMatrix(t,i(this.computedMatrix,a))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var a=this.computedInverse;u(a,a,g),this.setMatrix(t,i(a,a))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var a=this.computedMatrix;u(a,a,g),this.setMatrix(t,a)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{"binary-search-bounds":92,"gl-mat4/invert":267,"gl-mat4/lookAt":268,"gl-mat4/rotateX":273,"gl-mat4/rotateY":274,"gl-mat4/rotateZ":275,"gl-mat4/scale":276,"gl-mat4/translate":277,"gl-vec3/normalize":357,"mat4-interpolate":431}],435:[function(t,e,r){"use strict";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),a=0;a<e;++a)r[a]=a;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}for(var i=new Array(e),a=0;a<e;++a)i[a]=a;i.sort(function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]});for(var o=[i[0],i[1]],s=[i[0],i[1]],a=2;a<e;++a){for(var l=i[a],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}for(var r=new Array(s.length+o.length-2),h=0,a=0,f=o.length;a<f;++a)r[h++]=o[a];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=t("robust-orientation")[3]},{"robust-orientation":508}],436:[function(t,e,r){"use strict";e.exports=function(t,e){e||(e=t,t=window);var r=0,a=0,i=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return"altKey"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),"shiftKey"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),"ctrlKey"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),"metaKey"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);"buttons"in s&&(t=0|s.buttons),(t!==r||c!==a||u!==i||l(s))&&(r=0|t,a=c||0,i=u||0,e&&e(r,a,i,o))}function u(t){c(0,t)}function h(){(r||a||i||o.shift||o.alt||o.meta||o.control)&&(a=i=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,a,i,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function v(){s||(s=!0,t.addEventListener("mousemove",p),t.addEventListener("mousedown",d),t.addEventListener("mouseup",g),t.addEventListener("mouseleave",u),t.addEventListener("mouseenter",u),t.addEventListener("mouseout",u),t.addEventListener("mouseover",u),t.addEventListener("blur",h),t.addEventListener("keyup",f),t.addEventListener("keydown",f),t.addEventListener("keypress",f),t!==window&&(window.addEventListener("blur",h),window.addEventListener("keyup",f),window.addEventListener("keydown",f),window.addEventListener("keypress",f)))}v();var m={element:t};return Object.defineProperties(m,{enabled:{get:function(){return s},set:function(e){e?v():s&&(s=!1,t.removeEventListener("mousemove",p),t.removeEventListener("mousedown",d),t.removeEventListener("mouseup",g),t.removeEventListener("mouseleave",u),t.removeEventListener("mouseenter",u),t.removeEventListener("mouseout",u),t.removeEventListener("mouseover",u),t.removeEventListener("blur",h),t.removeEventListener("keyup",f),t.removeEventListener("keydown",f),t.removeEventListener("keypress",f),t!==window&&(window.removeEventListener("blur",h),window.removeEventListener("keyup",f),window.removeEventListener("keydown",f),window.removeEventListener("keypress",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return a},enumerable:!0},y:{get:function(){return i},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),m};var n=t("mouse-event")},{"mouse-event":438}],437:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var a=t.clientX||0,i=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=a-o.left,r[1]=i-o.top,r}},{}],438:[function(t,e,r){"use strict";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if("object"==typeof t){if("buttons"in t)return t.buttons;if("which"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if("button"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if("object"==typeof t){if("offsetX"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if("object"==typeof t){if("offsetY"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],439:[function(t,e,r){"use strict";var n=t("to-px");e.exports=function(t,e,r){"function"==typeof t&&(r=!!e,e=t,t=window);var a=n("ex",t),i=function(t){r&&t.preventDefault();var n=t.deltaX||0,i=t.deltaY||0,o=t.deltaZ||0,s=t.deltaMode,l=1;switch(s){case 1:l=a;break;case 2:l=window.innerHeight}if(i*=l,o*=l,(n*=l)||i||o)return e(n,i,o,t)};return t.addEventListener("wheel",i),i}},{"to-px":537}],440:[function(t,e,r){"use strict";var n=t("typedarray-pool");function a(t){return"a"+t}function i(t){return"d"+t}function o(t,e){return"c"+t+"_"+e}function s(t){return"s"+t}function l(t,e){return"t"+t+"_"+e}function c(t){return"o"+t}function u(t){return"x"+t}function h(t){return"p"+t}function f(t,e){return"d"+t+"_"+e}function p(t){return"i"+t}function d(t,e){return"u"+t+"_"+e}function g(t){return"b"+t}function v(t){return"y"+t}function m(t){return"e"+t}function y(t){return"v"+t}e.exports=function(t){function e(t){throw new Error("ndarray-extract-contour: "+t)}"object"!=typeof t&&e("Must specify arguments");var r=t.order;Array.isArray(r)||e("Must specify order");var M=t.arrayArguments||1;M<1&&e("Must have at least one array argument");var S=t.scalarArguments||0;S<0&&e("Scalar arg count must be > 0");"function"!=typeof t.vertex&&e("Must specify vertex creation function");"function"!=typeof t.cell&&e("Must specify cell creation function");"function"!=typeof t.phase&&e("Must specify phase function");for(var E=t.getters||[],L=new Array(M),C=0;C<M;++C)E.indexOf(C)>=0?L[C]=!0:L[C]=!1;return function(t,e,r,M,S,E){var L=E.length,C=S.length;if(C<2)throw new Error("ndarray-extract-contour: Dimension must be at least 2");for(var P="extractContour"+S.join("_"),O=[],z=[],I=[],D=0;D<L;++D)I.push(a(D));for(var D=0;D<M;++D)I.push(u(D));for(var D=0;D<C;++D)z.push(s(D)+"="+a(0)+".shape["+D+"]|0");for(var D=0;D<L;++D){z.push(i(D)+"="+a(D)+".data",c(D)+"="+a(D)+".offset|0");for(var R=0;R<C;++R)z.push(l(D,R)+"="+a(D)+".stride["+R+"]|0")}for(var D=0;D<L;++D){z.push(h(D)+"="+c(D)),z.push(o(D,0));for(var R=1;R<1<<C;++R){for(var F=[],B=0;B<C;++B)R&1<<B&&F.push("-"+l(D,B));z.push(f(D,R)+"=("+F.join("")+")|0"),z.push(o(D,R)+"=0")}}for(var D=0;D<L;++D)for(var R=0;R<C;++R){var N=[l(D,S[R])];R>0&&N.push(l(D,S[R-1])+"*"+s(S[R-1])),z.push(d(D,S[R])+"=("+N.join("-")+")|0")}for(var D=0;D<C;++D)z.push(p(D)+"=0");z.push(_+"=0");for(var j=["2"],D=C-2;D>=0;--D)j.push(s(S[D]));z.push(w+"=("+j.join("*")+")|0",b+"=mallocUint32("+w+")",x+"=mallocUint32("+w+")",k+"=0"),z.push(g(0)+"=0");for(var R=1;R<1<<C;++R){for(var V=[],U=[],B=0;B<C;++B)R&1<<B&&(0===U.length?V.push("1"):V.unshift(U.join("*"))),U.push(s(S[B]));var q="";V[0].indexOf(s(S[C-2]))<0&&(q="-");var H=A(C,R,S);z.push(m(H)+"=(-"+V.join("-")+")|0",v(H)+"=("+q+V.join("-")+")|0",g(H)+"=0")}function G(t,e){O.push("for(",p(S[t]),"=",e,";",p(S[t]),"<",s(S[t]),";","++",p(S[t]),"){")}function Y(t){for(var e=0;e<L;++e)O.push(h(e),"+=",d(e,S[t]),";");O.push("}")}function W(){for(var t=1;t<1<<C;++t)O.push(T,"=",m(t),";",m(t),"=",v(t),";",v(t),"=",T,";")}z.push(y(0)+"=0",T+"=0"),function t(e,r){if(e<0)return void function(t){for(var e=0;e<L;++e)E[e]?O.push(o(e,0),"=",i(e),".get(",h(e),");"):O.push(o(e,0),"=",i(e),"[",h(e),"];");for(var r=[],e=0;e<L;++e)r.push(o(e,0));for(var e=0;e<M;++e)r.push(u(e));O.push(g(0),"=",b,"[",k,"]=phase(",r.join(),");");for(var n=1;n<1<<C;++n)O.push(g(n),"=",b,"[",k,"+",m(n),"];");for(var a=[],n=1;n<1<<C;++n)a.push("("+g(0)+"!=="+g(n)+")");O.push("if(",a.join("||"),"){");for(var s=[],e=0;e<C;++e)s.push(p(e));for(var e=0;e<L;++e){s.push(o(e,0));for(var n=1;n<1<<C;++n)E[e]?O.push(o(e,n),"=",i(e),".get(",h(e),"+",f(e,n),");"):O.push(o(e,n),"=",i(e),"[",h(e),"+",f(e,n),"];"),s.push(o(e,n))}for(var e=0;e<1<<C;++e)s.push(g(e));for(var e=0;e<M;++e)s.push(u(e));O.push("vertex(",s.join(),");",y(0),"=",x,"[",k,"]=",_,"++;");for(var l=(1<<C)-1,c=g(l),n=0;n<C;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,v=g(d),w=[],T=d;T>0;T=T-1&d)w.push(x+"["+k+"+"+m(T)+"]");w.push(y(0));for(var T=0;T<L;++T)1&n?w.push(o(T,l),o(T,d)):w.push(o(T,d),o(T,l));1&n?w.push(c,v):w.push(v,c);for(var T=0;T<M;++T)w.push(u(T));O.push("if(",c,"!==",v,"){","face(",w.join(),")}")}O.push("}",k,"+=1;")}(r);!function(t){for(var e=t-1;e>=0;--e)G(e,0);for(var r=[],e=0;e<L;++e)E[e]?r.push(i(e)+".get("+h(e)+")"):r.push(i(e)+"["+h(e)+"]");for(var e=0;e<M;++e)r.push(u(e));O.push(b,"[",k,"++]=phase(",r.join(),");");for(var e=0;e<t;++e)Y(e);for(var n=0;n<L;++n)O.push(h(n),"+=",d(n,S[t]),";")}(e);O.push("if(",s(S[e]),">0){",p(S[e]),"=1;");t(e-1,r|1<<S[e]);for(var n=0;n<L;++n)O.push(h(n),"+=",d(n,S[e]),";");e===C-1&&(O.push(k,"=0;"),W());G(e,2);t(e-1,r);e===C-1&&(O.push("if(",p(S[C-1]),"&1){",k,"=0;}"),W());Y(e);O.push("}")}(C-1,0),O.push("freeUint32(",x,");freeUint32(",b,");");var X=["'use strict';","function ",P,"(",I.join(),"){","var ",z.join(),";",O.join(""),"}","return ",P].join("");return new Function("vertex","face","phase","mallocUint32","freeUint32",X)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,S,r,L)};var x="V",b="P",_="N",w="Q",k="X",T="T";function A(t,e,r){for(var n=0,a=0;a<t;++a)e&1<<a&&(n|=1<<r[a]);return n}},{"typedarray-pool":543}],441:[function(t,e,r){"use strict";var n=t("cwise/lib/wrapper")({args:["index","array","scalar"],pre:{body:"{}",args:[],thisVars:[],localVars:[]},body:{body:"{_inline_1_arg1_=_inline_1_arg2_.apply(void 0,_inline_1_arg0_)}",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_1_arg1_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_1_arg2_",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},debug:!1,funcName:"cwise",blockSize:64});e.exports=function(t,e){return n(t,e),t}},{"cwise/lib/wrapper":150}],442:[function(t,e,r){"use strict";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error("ndarray-gradient: invalid boundary conditions")}else r=n(e.dimension,"string"==typeof r?r:"clamp");if(t.dimension!==e.dimension+1)throw new Error("ndarray-gradient: output dimension must be +1 input dimension");if(t.shape[e.dimension]!==e.dimension)throw new Error("ndarray-gradient: output shape must match input shape");for(var a=0;a<e.dimension;++a)if(t.shape[a]!==e.shape[a])throw new Error("ndarray-gradient: shape mismatch");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(m=o[e])return m;var r=t.length,n=["function gradient(dst,src){var s=src.shape.slice();"];function a(e){for(var a=r-e.length,i=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push("0"):e.indexOf(-(l+1))>=0?s.push("s["+l+"]-1"):(s.push("-1"),i.push("1"),o.push("s["+l+"]-2"));var c=".lo("+i.join()+").hi("+o.join()+")";if(0===i.length&&(c=""),a>0){n.push("if(1");for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push("&&s[",l,"]>2");n.push("){grad",a,"(src.pick(",s.join(),")",c);for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(",dst.pick(",s.join(),",",l,")",c);n.push(");")}for(var l=0;l<e.length;++l){var u=Math.abs(e[l])-1,h="dst.pick("+s.join()+","+u+")"+c;switch(t[u]){case"clamp":var f=s.slice(),p=s.slice();e[l]<0?f[u]="s["+u+"]-2":p[u]="1",0===a?n.push("if(s[",u,"]>1){dst.set(",s.join(),",",u,",0.5*(src.get(",f.join(),")-src.get(",p.join(),")))}else{dst.set(",s.join(),",",u,",0)};"):n.push("if(s[",u,"]>1){diff(",h,",src.pick(",f.join(),")",c,",src.pick(",p.join(),")",c,");}else{zero(",h,");};");break;case"mirror":0===a?n.push("dst.set(",s.join(),",",u,",0);"):n.push("zero(",h,");");break;case"wrap":var d=s.slice(),g=s.slice();e[l]<0?(d[u]="s["+u+"]-2",g[u]="0"):(d[u]="s["+u+"]-1",g[u]="1"),0===a?n.push("if(s[",u,"]>2){dst.set(",s.join(),",",u,",0.5*(src.get(",d.join(),")-src.get(",g.join(),")))}else{dst.set(",s.join(),",",u,",0)};"):n.push("if(s[",u,"]>2){diff(",h,",src.pick(",d.join(),")",c,",src.pick(",g.join(),")",c,");}else{zero(",h,");};");break;default:throw new Error("ndarray-gradient: Invalid boundary condition")}}a>0&&n.push("};")}for(var s=0;s<1<<r;++s){for(var h=[],f=0;f<r;++f)s&1<<f&&h.push(f+1);for(var p=0;p<1<<h.length;++p){for(var d=h.slice(),f=0;f<h.length;++f)p&1<<f&&(d[f]=-d[f]);a(d)}}n.push("return dst;};return gradient");for(var g=["diff","zero"],v=[l,c],s=1;s<=r;++s)g.push("grad"+s),v.push(u(s));g.push(n.join(""));var m=Function.apply(void 0,g).apply(void 0,v);return i[e]=m,m}(r)(t,e)};var n=t("dup"),a=t("cwise-compiler"),i={},o={},s={body:"",args:[],thisVars:[],localVars:[]},l=a({args:["array","array","array"],pre:s,post:s,body:{args:[{name:"out",lvalue:!0,rvalue:!1,count:1},{name:"left",lvalue:!1,rvalue:!0,count:1},{name:"right",lvalue:!1,rvalue:!0,count:1}],body:"out=0.5*(left-right)",thisVars:[],localVars:[]},funcName:"cdiff"}),c=a({args:["array"],pre:s,post:s,body:{args:[{name:"out",lvalue:!0,rvalue:!1,count:1}],body:"out=0",thisVars:[],localVars:[]},funcName:"zero"});function u(t){if(t in i)return i[t];for(var e=[],r=0;r<t;++r)e.push("out",r,"s=0.5*(inp",r,"l-inp",r,"r);");var o=["array"],l=["junk"];for(r=0;r<t;++r){o.push("array"),l.push("out"+r+"s");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push("inp"+r+"l","inp"+r+"r")}return i[t]=a({args:o,pre:s,post:s,body:{body:e.join(""),args:l.map(function(t){return{name:t,lvalue:0===t.indexOf("out"),rvalue:0===t.indexOf("inp"),count:"junk"!==t|0}}),thisVars:[],localVars:[]},funcName:"fdTemplate"+t})}},{"cwise-compiler":147,dup:171}],443:[function(t,e,r){"use strict";var n=t("ndarray-warp"),a=t("gl-matrix-invert");e.exports=function(t,e,r){var i=e.dimension,o=a([],r);return n(t,e,function(t,e){for(var r=0;r<i;++r){t[r]=o[(i+1)*i+r];for(var n=0;n<i;++n)t[r]+=o[(i+1)*n+r]*e[n]}var a=o[(i+1)*(i+1)-1];for(n=0;n<i;++n)a+=o[(i+1)*n+i]*e[n];var s=1/a;for(r=0;r<i;++r)t[r]*=s;return t}),t}},{"gl-matrix-invert":279,"ndarray-warp":450}],444:[function(t,e,r){"use strict";function n(t,e){var r=Math.floor(e),n=e-r,a=0<=r&&r<t.shape[0],i=0<=r+1&&r+1<t.shape[0];return(1-n)*(a?+t.get(r):0)+n*(i?+t.get(r+1):0)}function a(t,e,r){var n=Math.floor(e),a=e-n,i=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=i&&c?t.get(n,s):0,f=i&&u?t.get(n,s+1):0;return(1-l)*((1-a)*h+a*(o&&c?t.get(n+1,s):0))+l*((1-a)*f+a*(o&&u?t.get(n+1,s+1):0))}function i(t,e,r,n){var a=Math.floor(e),i=e-a,o=0<=a&&a<t.shape[0],s=0<=a+1&&a+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],g=0<=f+1&&f+1<t.shape[2],v=o&&u&&d?t.get(a,l,f):0,m=o&&h&&d?t.get(a,l+1,f):0,y=s&&u&&d?t.get(a+1,l,f):0,x=s&&h&&d?t.get(a+1,l+1,f):0,b=o&&u&&g?t.get(a,l,f+1):0,_=o&&h&&g?t.get(a,l+1,f+1):0;return(1-p)*((1-c)*((1-i)*v+i*y)+c*((1-i)*m+i*x))+p*((1-c)*((1-i)*b+i*(s&&u&&g?t.get(a+1,l,f+1):0))+c*((1-i)*_+i*(s&&h&&g?t.get(a+1,l+1,f+1):0)))}e.exports=function(t,e,r,o){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return a(t,e,r);case 3:return i(t,e,r,o);default:return function(t){var e,r,n=0|t.shape.length,a=new Array(n),i=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],a[e]=Math.floor(r),i[e]=r-a[e],o[e]=0<=a[e]&&a[e]<t.shape[e],s[e]=0<=a[e]+1&&a[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=i[l],u+=t.stride[l]*(a[l]+1)}else{if(!o[l])continue t;c*=1-i[l],u+=t.stride[l]*a[l]}h+=c*t.data[u]}return h}.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=a,e.exports.d3=i},{}],445:[function(t,e,r){"use strict";var n=t("cwise-compiler"),a={body:"",args:[],thisVars:[],localVars:[]};function i(t){if(!t)return a;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push("a"+r);return new Function("P",["return function ",t.funcName,"_ndarrayops(",e.join(","),") {P(",e.join(","),");return a0}"].join(""))(function(t){return n({args:t.args,pre:i(t.pre),body:i(t.body),post:i(t.proc),funcName:t.funcName})}(t))}var s={add:"+",sub:"-",mul:"*",div:"/",mod:"%",band:"&",bor:"|",bxor:"^",lshift:"<<",rshift:">>",rrshift:">>>"};!function(){for(var t in s){var e=s[t];r[t]=o({args:["array","array","array"],body:{args:["a","b","c"],body:"a=b"+e+"c"},funcName:t}),r[t+"eq"]=o({args:["array","array"],body:{args:["a","b"],body:"a"+e+"=b"},rvalue:!0,funcName:t+"eq"}),r[t+"s"]=o({args:["array","array","scalar"],body:{args:["a","b","s"],body:"a=b"+e+"s"},funcName:t+"s"}),r[t+"seq"]=o({args:["array","scalar"],body:{args:["a","s"],body:"a"+e+"=s"},rvalue:!0,funcName:t+"seq"})}}();var l={not:"!",bnot:"~",neg:"-",recip:"1.0/"};!function(){for(var t in l){var e=l[t];r[t]=o({args:["array","array"],body:{args:["a","b"],body:"a="+e+"b"},funcName:t}),r[t+"eq"]=o({args:["array"],body:{args:["a"],body:"a="+e+"a"},rvalue:!0,count:2,funcName:t+"eq"})}}();var c={and:"&&",or:"||",eq:"===",neq:"!==",lt:"<",gt:">",leq:"<=",geq:">="};!function(){for(var t in c){var e=c[t];r[t]=o({args:["array","array","array"],body:{args:["a","b","c"],body:"a=b"+e+"c"},funcName:t}),r[t+"s"]=o({args:["array","array","scalar"],body:{args:["a","b","s"],body:"a=b"+e+"s"},funcName:t+"s"}),r[t+"eq"]=o({args:["array","array"],body:{args:["a","b"],body:"a=a"+e+"b"},rvalue:!0,count:2,funcName:t+"eq"}),r[t+"seq"]=o({args:["array","scalar"],body:{args:["a","s"],body:"a=a"+e+"s"},rvalue:!0,count:2,funcName:t+"seq"})}}();var u=["abs","acos","asin","atan","ceil","cos","exp","floor","log","round","sin","sqrt","tan"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:["array","array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b"],body:"a=this_f(b)",thisVars:["this_f"]},funcName:e}),r[e+"eq"]=o({args:["array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a"],body:"a=this_f(a)",thisVars:["this_f"]},rvalue:!0,count:2,funcName:e+"eq"})}}();var h=["max","min","atan2","pow"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e]=o({args:["array","array","array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b","c"],body:"a=this_f(b,c)",thisVars:["this_f"]},funcName:e}),r[e+"s"]=o({args:["array","array","scalar"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b","c"],body:"a=this_f(b,c)",thisVars:["this_f"]},funcName:e+"s"}),r[e+"eq"]=o({args:["array","array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b"],body:"a=this_f(a,b)",thisVars:["this_f"]},rvalue:!0,count:2,funcName:e+"eq"}),r[e+"seq"]=o({args:["array","scalar"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b"],body:"a=this_f(a,b)",thisVars:["this_f"]},rvalue:!0,count:2,funcName:e+"seq"})}}();var f=["atan2","pow"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e+"op"]=o({args:["array","array","array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b","c"],body:"a=this_f(c,b)",thisVars:["this_f"]},funcName:e+"op"}),r[e+"ops"]=o({args:["array","array","scalar"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b","c"],body:"a=this_f(c,b)",thisVars:["this_f"]},funcName:e+"ops"}),r[e+"opeq"]=o({args:["array","array"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b"],body:"a=this_f(b,a)",thisVars:["this_f"]},rvalue:!0,count:2,funcName:e+"opeq"}),r[e+"opseq"]=o({args:["array","scalar"],pre:{args:[],body:"this_f=Math."+e,thisVars:["this_f"]},body:{args:["a","b"],body:"a=this_f(b,a)",thisVars:["this_f"]},rvalue:!0,count:2,funcName:e+"opseq"})}}(),r.any=n({args:["array"],pre:a,body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:1}],body:"if(a){return true}",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:"return false"},funcName:"any"}),r.all=n({args:["array"],pre:a,body:{args:[{name:"x",lvalue:!1,rvalue:!0,count:1}],body:"if(!x){return false}",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:"return true"},funcName:"all"}),r.sum=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=0"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:1}],body:"this_s+=a",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return this_s"},funcName:"sum"}),r.prod=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=1"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:1}],body:"this_s*=a",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return this_s"},funcName:"prod"}),r.norm2squared=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=0"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:2}],body:"this_s+=a*a",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return this_s"},funcName:"norm2squared"}),r.norm2=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=0"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:2}],body:"this_s+=a*a",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return Math.sqrt(this_s)"},funcName:"norm2"}),r.norminf=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=0"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:4}],body:"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return this_s"},funcName:"norminf"}),r.norm1=n({args:["array"],pre:{args:[],localVars:[],thisVars:["this_s"],body:"this_s=0"},body:{args:[{name:"a",lvalue:!1,rvalue:!0,count:3}],body:"this_s+=a<0?-a:a",localVars:[],thisVars:["this_s"]},post:{args:[],localVars:[],thisVars:["this_s"],body:"return this_s"},funcName:"norm1"}),r.sup=n({args:["array"],pre:{body:"this_h=-Infinity",args:[],thisVars:["this_h"],localVars:[]},body:{body:"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:2}],thisVars:["this_h"],localVars:[]},post:{body:"return this_h",args:[],thisVars:["this_h"],localVars:[]}}),r.inf=n({args:["array"],pre:{body:"this_h=Infinity",args:[],thisVars:["this_h"],localVars:[]},body:{body:"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:2}],thisVars:["this_h"],localVars:[]},post:{body:"return this_h",args:[],thisVars:["this_h"],localVars:[]}}),r.argmin=n({args:["index","array","shape"],pre:{body:"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}",args:[{name:"_inline_0_arg0_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_0_arg1_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_0_arg2_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_i","this_v"],localVars:[]},body:{body:"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:2},{name:"_inline_1_arg1_",lvalue:!1,rvalue:!0,count:2}],thisVars:["this_i","this_v"],localVars:["_inline_1_k"]},post:{body:"{return this_i}",args:[],thisVars:["this_i"],localVars:[]}}),r.argmax=n({args:["index","array","shape"],pre:{body:"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}",args:[{name:"_inline_0_arg0_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_0_arg1_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_0_arg2_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_i","this_v"],localVars:[]},body:{body:"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:2},{name:"_inline_1_arg1_",lvalue:!1,rvalue:!0,count:2}],thisVars:["this_i","this_v"],localVars:["_inline_1_k"]},post:{body:"{return this_i}",args:[],thisVars:["this_i"],localVars:[]}}),r.random=o({args:["array"],pre:{args:[],body:"this_f=Math.random",thisVars:["this_f"]},body:{args:["a"],body:"a=this_f()",thisVars:["this_f"]},funcName:"random"}),r.assign=o({args:["array","array"],body:{args:["a","b"],body:"a=b"},funcName:"assign"}),r.assigns=o({args:["array","scalar"],body:{args:["a","b"],body:"a=b"},funcName:"assigns"}),r.equals=n({args:["array","array"],pre:a,body:{args:[{name:"x",lvalue:!1,rvalue:!0,count:1},{name:"y",lvalue:!1,rvalue:!0,count:1}],body:"if(x!==y){return false}",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:"return true"},funcName:"equals"})},{"cwise-compiler":147}],446:[function(t,e,r){"use strict";var n=t("ndarray"),a=t("./doConvert.js");e.exports=function(t,e){for(var r=[],i=t,o=1;Array.isArray(i);)r.push(i.length),o*=i.length,i=i[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),a(e,t),e)}},{"./doConvert.js":447,ndarray:451}],447:[function(t,e,r){e.exports=t("cwise-compiler")({args:["array","scalar","index"],pre:{body:"{}",args:[],thisVars:[],localVars:[]},body:{body:"{\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\n}\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\n}",args:[{name:"_inline_1_arg0_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_1_arg1_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_1_arg2_",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:["_inline_1_i","_inline_1_v"]},post:{body:"{}",args:[],thisVars:[],localVars:[]},funcName:"convert",blockSize:64})},{"cwise-compiler":147}],448:[function(t,e,r){"use strict";var n=t("typedarray-pool"),a=32;function i(t){switch(t){case"uint8":return[n.mallocUint8,n.freeUint8];case"uint16":return[n.mallocUint16,n.freeUint16];case"uint32":return[n.mallocUint32,n.freeUint32];case"int8":return[n.mallocInt8,n.freeInt8];case"int16":return[n.mallocInt16,n.freeInt16];case"int32":return[n.mallocInt32,n.freeInt32];case"float32":return[n.mallocFloat,n.freeFloat];case"float64":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push("s"+r);for(r=0;r<t;++r)e.push("n"+r);for(r=1;r<t;++r)e.push("d"+r);for(r=1;r<t;++r)e.push("e"+r);for(r=1;r<t;++r)e.push("f"+r);return e}e.exports=function(t,e){var r=["'use strict'"],n=["ndarraySortWrapper",t.join("d"),e].join("");r.push(["function ",n,"(",["array"].join(","),"){"].join(""));for(var s=["data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride"],l=0;l<t.length;++l)s.push(["s",l,"=stride[",l,"]|0,n",l,"=shape[",l,"]|0"].join(""));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l)0!==(p=t[l])&&(0===u.length?c[p]="1":c[p]=u.join("*"),u.push("n"+p));var h=-1,f=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(h>0?s.push(["d",d,"=s",d,"-d",h,"*n",h].join("")):s.push(["d",d,"=s",d].join("")),h=d),0!=(p=t.length-1-l)&&(f>0?s.push(["e",p,"=s",p,"-e",f,"*n",f,",f",p,"=",c[p],"-f",f,"*n",f].join("")):s.push(["e",p,"=s",p,",f",p,"=",c[p]].join("")),f=p)}r.push("var "+s.join(","));var g=["0","n0-1","data","offset"].concat(o(t.length));r.push(["if(n0<=",a,"){","insertionSort(",g.join(","),")}else{","quickSort(",g.join(","),")}"].join("")),r.push("}return "+n);var v=new Function("insertionSort","quickSort",r.join("\n")),m=function(t,e){var r=["'use strict'"],n=["ndarrayInsertionSort",t.join("d"),e].join(""),a=["left","right","data","offset"].concat(o(t.length)),s=i(e),l=["i,j,cptr,ptr=left*s0+offset"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push("i"+u),c.push("n"+u);s?l.push("scratch=malloc("+c.join("*")+")"):l.push("scratch=new Array("+c.join("*")+")"),l.push("dptr","sptr","a","b")}else l.push("scratch");function h(t){return"generic"===e?["data.get(",t,")"].join(""):["data[",t,"]"].join("")}function f(t,r){return"generic"===e?["data.set(",t,",",r,")"].join(""):["data[",t,"]=",r].join("")}if(r.push(["function ",n,"(",a.join(","),"){var ",l.join(",")].join(""),"for(i=left+1;i<=right;++i){","j=i;ptr+=s0","cptr=ptr"),t.length>1){for(r.push("dptr=0;sptr=ptr"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push(["for(i",p,"=0;i",p,"<n",p,";++i",p,"){"].join(""));for(r.push("scratch[dptr++]=",h("sptr")),u=0;u<t.length;++u)0!==(p=t[u])&&r.push("sptr+=d"+p,"}");for(r.push("__g:while(j--\x3eleft){","dptr=0","sptr=cptr-s0"),u=1;u<t.length;++u)1===u&&r.push("__l:"),r.push(["for(i",u,"=0;i",u,"<n",u,";++i",u,"){"].join(""));for(r.push(["a=",h("sptr"),"\nb=scratch[dptr]\nif(a<b){break __g}\nif(a>b){break __l}"].join("")),u=t.length-1;u>=1;--u)r.push("sptr+=e"+u,"dptr+=f"+u,"}");for(r.push("dptr=cptr;sptr=cptr-s0"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push(["for(i",p,"=0;i",p,"<n",p,";++i",p,"){"].join(""));for(r.push(f("dptr",h("sptr"))),u=0;u<t.length;++u)0!==(p=t[u])&&r.push(["dptr+=d",p,";sptr+=d",p].join(""),"}");for(r.push("cptr-=s0\n}"),r.push("dptr=cptr;sptr=0"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push(["for(i",p,"=0;i",p,"<n",p,";++i",p,"){"].join(""));for(r.push(f("dptr","scratch[sptr++]")),u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push("dptr+=d"+p,"}")}}else r.push("scratch="+h("ptr"),"while((j--\x3eleft)&&("+h("cptr-s0")+">scratch)){",f("cptr",h("cptr-s0")),"cptr-=s0","}",f("cptr","scratch"));return r.push("}"),t.length>1&&s&&r.push("free(scratch)"),r.push("} return "+n),s?new Function("malloc","free",r.join("\n"))(s[0],s[1]):new Function(r.join("\n"))()}(t,e),y=function(t,e,r){var n=["'use strict'"],s=["ndarrayQuickSort",t.join("d"),e].join(""),l=["left","right","data","offset"].concat(o(t.length)),c=i(e),u=0;n.push(["function ",s,"(",l.join(","),"){"].join(""));var h=["sixth=((right-left+1)/6)|0","index1=left+sixth","index5=right-sixth","index3=(left+right)>>1","index2=index3-sixth","index4=index3+sixth","el1=index1","el2=index2","el3=index3","el4=index4","el5=index5","less=left+1","great=right-1","pivots_are_equal=true","tmp","tmp0","x","y","z","k","ptr0","ptr1","ptr2","comp_pivot1=0","comp_pivot2=0","comp=0"];if(t.length>1){for(var f=[],p=1;p<t.length;++p)f.push("n"+p),h.push("i"+p);for(p=0;p<8;++p)h.push("b_ptr"+p);h.push("ptr3","ptr4","ptr5","ptr6","ptr7","pivot_ptr","ptr_shift","elementSize="+f.join("*")),c?h.push("pivot1=malloc(elementSize)","pivot2=malloc(elementSize)"):h.push("pivot1=new Array(elementSize),pivot2=new Array(elementSize)")}else h.push("pivot1","pivot2");function d(t){return["(offset+",t,"*s0)"].join("")}function g(t){return"generic"===e?["data.get(",t,")"].join(""):["data[",t,"]"].join("")}function v(t,r){return"generic"===e?["data.set(",t,",",r,")"].join(""):["data[",t,"]=",r].join("")}function m(e,r,a){if(1===e.length)n.push("ptr0="+d(e[0]));else for(var i=0;i<e.length;++i)n.push(["b_ptr",i,"=s0*",e[i]].join(""));for(r&&n.push("pivot_ptr=0"),n.push("ptr_shift=offset"),i=t.length-1;i>=0;--i)0!==(o=t[i])&&n.push(["for(i",o,"=0;i",o,"<n",o,";++i",o,"){"].join(""));if(e.length>1)for(i=0;i<e.length;++i)n.push(["ptr",i,"=b_ptr",i,"+ptr_shift"].join(""));for(n.push(a),r&&n.push("++pivot_ptr"),i=0;i<t.length;++i){var o;0!==(o=t[i])&&(e.length>1?n.push("ptr_shift+=d"+o):n.push("ptr0+=d"+o),n.push("}"))}}function y(e,r,a,i){if(1===r.length)n.push("ptr0="+d(r[0]));else{for(var o=0;o<r.length;++o)n.push(["b_ptr",o,"=s0*",r[o]].join(""));n.push("ptr_shift=offset")}for(a&&n.push("pivot_ptr=0"),e&&n.push(e+":"),o=1;o<t.length;++o)n.push(["for(i",o,"=0;i",o,"<n",o,";++i",o,"){"].join(""));if(r.length>1)for(o=0;o<r.length;++o)n.push(["ptr",o,"=b_ptr",o,"+ptr_shift"].join(""));for(n.push(i),o=t.length-1;o>=1;--o)a&&n.push("pivot_ptr+=f"+o),r.length>1?n.push("ptr_shift+=e"+o):n.push("ptr0+=e"+o),n.push("}")}function x(){t.length>1&&c&&n.push("free(pivot1)","free(pivot2)")}function b(e,r){var a="el"+e,i="el"+r;if(t.length>1){var o="__l"+ ++u;y(o,[a,i],!1,["comp=",g("ptr0"),"-",g("ptr1"),"\n","if(comp>0){tmp0=",a,";",a,"=",i,";",i,"=tmp0;break ",o,"}\n","if(comp<0){break ",o,"}"].join(""))}else n.push(["if(",g(d(a)),">",g(d(i)),"){tmp0=",a,";",a,"=",i,";",i,"=tmp0}"].join(""))}function _(e,r){t.length>1?m([e,r],!1,v("ptr0",g("ptr1"))):n.push(v(d(e),g(d(r))))}function w(e,r,a){if(t.length>1){var i="__l"+ ++u;y(i,[r],!0,[e,"=",g("ptr0"),"-pivot",a,"[pivot_ptr]\n","if(",e,"!==0){break ",i,"}"].join(""))}else n.push([e,"=",g(d(r)),"-pivot",a].join(""))}function k(e,r){t.length>1?m([e,r],!1,["tmp=",g("ptr0"),"\n",v("ptr0",g("ptr1")),"\n",v("ptr1","tmp")].join("")):n.push(["ptr0=",d(e),"\n","ptr1=",d(r),"\n","tmp=",g("ptr0"),"\n",v("ptr0",g("ptr1")),"\n",v("ptr1","tmp")].join(""))}function T(e,r,a){t.length>1?(m([e,r,a],!1,["tmp=",g("ptr0"),"\n",v("ptr0",g("ptr1")),"\n",v("ptr1",g("ptr2")),"\n",v("ptr2","tmp")].join("")),n.push("++"+r,"--"+a)):n.push(["ptr0=",d(e),"\n","ptr1=",d(r),"\n","ptr2=",d(a),"\n","++",r,"\n","--",a,"\n","tmp=",g("ptr0"),"\n",v("ptr0",g("ptr1")),"\n",v("ptr1",g("ptr2")),"\n",v("ptr2","tmp")].join(""))}function A(t,e){k(t,e),n.push("--"+e)}function M(e,r,a){t.length>1?m([e,r],!0,[v("ptr0",g("ptr1")),"\n",v("ptr1",["pivot",a,"[pivot_ptr]"].join(""))].join("")):n.push(v(d(e),g(d(r))),v(d(r),"pivot"+a))}function S(e,r){n.push(["if((",r,"-",e,")<=",a,"){\n","insertionSort(",e,",",r,",data,offset,",o(t.length).join(","),")\n","}else{\n",s,"(",e,",",r,",data,offset,",o(t.length).join(","),")\n","}"].join(""))}function E(e,r,a){t.length>1?(n.push(["__l",++u,":while(true){"].join("")),m([e],!0,["if(",g("ptr0"),"!==pivot",r,"[pivot_ptr]){break __l",u,"}"].join("")),n.push(a,"}")):n.push(["while(",g(d(e)),"===pivot",r,"){",a,"}"].join(""))}return n.push("var "+h.join(",")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?m(["el1","el2","el3","el4","el5","index1","index3","index5"],!0,["pivot1[pivot_ptr]=",g("ptr1"),"\n","pivot2[pivot_ptr]=",g("ptr3"),"\n","pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\n","x=",g("ptr0"),"\n","y=",g("ptr2"),"\n","z=",g("ptr4"),"\n",v("ptr5","x"),"\n",v("ptr6","y"),"\n",v("ptr7","z")].join("")):n.push(["pivot1=",g(d("el2")),"\n","pivot2=",g(d("el4")),"\n","pivots_are_equal=pivot1===pivot2\n","x=",g(d("el1")),"\n","y=",g(d("el3")),"\n","z=",g(d("el5")),"\n",v(d("index1"),"x"),"\n",v(d("index3"),"y"),"\n",v(d("index5"),"z")].join("")),_("index2","left"),_("index4","right"),n.push("if(pivots_are_equal){"),n.push("for(k=less;k<=great;++k){"),w("comp","k",1),n.push("if(comp===0){continue}"),n.push("if(comp<0){"),n.push("if(k!==less){"),k("k","less"),n.push("}"),n.push("++less"),n.push("}else{"),n.push("while(true){"),w("comp","great",1),n.push("if(comp>0){"),n.push("great--"),n.push("}else if(comp<0){"),T("k","less","great"),n.push("break"),n.push("}else{"),A("k","great"),n.push("break"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),n.push("}else{"),n.push("for(k=less;k<=great;++k){"),w("comp_pivot1","k",1),n.push("if(comp_pivot1<0){"),n.push("if(k!==less){"),k("k","less"),n.push("}"),n.push("++less"),n.push("}else{"),w("comp_pivot2","k",2),n.push("if(comp_pivot2>0){"),n.push("while(true){"),w("comp","great",2),n.push("if(comp>0){"),n.push("if(--great<k){break}"),n.push("continue"),n.push("}else{"),w("comp","great",1),n.push("if(comp<0){"),T("k","less","great"),n.push("}else{"),A("k","great"),n.push("}"),n.push("break"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),M("left","(less-1)",1),M("right","(great+1)",2),S("left","(less-2)"),S("(great+2)","right"),n.push("if(pivots_are_equal){"),x(),n.push("return"),n.push("}"),n.push("if(less<index1&&great>index5){"),E("less",1,"++less"),E("great",2,"--great"),n.push("for(k=less;k<=great;++k){"),w("comp_pivot1","k",1),n.push("if(comp_pivot1===0){"),n.push("if(k!==less){"),k("k","less"),n.push("}"),n.push("++less"),n.push("}else{"),w("comp_pivot2","k",2),n.push("if(comp_pivot2===0){"),n.push("while(true){"),w("comp","great",2),n.push("if(comp===0){"),n.push("if(--great<k){break}"),n.push("continue"),n.push("}else{"),w("comp","great",1),n.push("if(comp<0){"),T("k","less","great"),n.push("}else{"),A("k","great"),n.push("}"),n.push("break"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),n.push("}"),x(),S("less","great"),n.push("}return "+s),t.length>1&&c?new Function("insertionSort","malloc","free",n.join("\n"))(r,c[0],c[1]):new Function("insertionSort",n.join("\n"))(r)}(t,e,m);return v(m,y)}},{"typedarray-pool":543}],449:[function(t,e,r){"use strict";var n=t("./lib/compile_sort.js"),a={};e.exports=function(t){var e=t.order,r=t.dtype,i=[e,r].join(":"),o=a[i];return o||(a[i]=o=n(e,r)),o(t),t}},{"./lib/compile_sort.js":448}],450:[function(t,e,r){"use strict";var n=t("ndarray-linear-interpolate"),a=t("cwise/lib/wrapper")({args:["index","array","scalar","scalar","scalar"],pre:{body:"{this_warped=new Array(_inline_3_arg4_)}",args:[{name:"_inline_3_arg0_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_3_arg1_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_3_arg2_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_3_arg3_",lvalue:!1,rvalue:!1,count:0},{name:"_inline_3_arg4_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_warped"],localVars:[]},body:{body:"{_inline_4_arg2_(this_warped,_inline_4_arg0_),_inline_4_arg1_=_inline_4_arg3_.apply(void 0,this_warped)}",args:[{name:"_inline_4_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_4_arg1_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_4_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_4_arg3_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_4_arg4_",lvalue:!1,rvalue:!1,count:0}],thisVars:["this_warped"],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},debug:!1,funcName:"warpND",blockSize:64}),i=t("cwise/lib/wrapper")({args:["index","array","scalar","scalar","scalar"],pre:{body:"{this_warped=[0]}",args:[],thisVars:["this_warped"],localVars:[]},body:{body:"{_inline_7_arg2_(this_warped,_inline_7_arg0_),_inline_7_arg1_=_inline_7_arg3_(_inline_7_arg4_,this_warped[0])}",args:[{name:"_inline_7_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_7_arg1_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_7_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_7_arg3_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_7_arg4_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_warped"],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},debug:!1,funcName:"warp1D",blockSize:64}),o=t("cwise/lib/wrapper")({args:["index","array","scalar","scalar","scalar"],pre:{body:"{this_warped=[0,0]}",args:[],thisVars:["this_warped"],localVars:[]},body:{body:"{_inline_10_arg2_(this_warped,_inline_10_arg0_),_inline_10_arg1_=_inline_10_arg3_(_inline_10_arg4_,this_warped[0],this_warped[1])}",args:[{name:"_inline_10_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_10_arg1_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_10_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_10_arg3_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_10_arg4_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_warped"],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},debug:!1,funcName:"warp2D",blockSize:64}),s=t("cwise/lib/wrapper")({args:["index","array","scalar","scalar","scalar"],pre:{body:"{this_warped=[0,0,0]}",args:[],thisVars:["this_warped"],localVars:[]},body:{body:"{_inline_13_arg2_(this_warped,_inline_13_arg0_),_inline_13_arg1_=_inline_13_arg3_(_inline_13_arg4_,this_warped[0],this_warped[1],this_warped[2])}",args:[{name:"_inline_13_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_13_arg1_",lvalue:!0,rvalue:!1,count:1},{name:"_inline_13_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_13_arg3_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_13_arg4_",lvalue:!1,rvalue:!0,count:1}],thisVars:["this_warped"],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},debug:!1,funcName:"warp3D",blockSize:64});e.exports=function(t,e,r){switch(e.shape.length){case 1:i(t,r,n.d1,e);break;case 2:o(t,r,n.d2,e);break;case 3:s(t,r,n.d3,e);break;default:a(t,r,n.bind(void 0,e),e.shape.length)}return t}},{"cwise/lib/wrapper":150,"ndarray-linear-interpolate":444}],451:[function(t,e,r){var n=t("iota-array"),a=t("is-buffer"),i="undefined"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=["View",e,"d",t].join("");e<0&&(r="View_Nil"+t);var a="generic"===t;if(-1===e){var i="function "+r+"(a){this.data=a;};var proto="+r+".prototype;proto.dtype='"+t+"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new "+r+"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_"+r+"(a){return new "+r+"(a);}";return new Function(i)()}if(0===e){i="function "+r+"(a,d) {this.data = a;this.offset = d};var proto="+r+".prototype;proto.dtype='"+t+"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function "+r+"_copy() {return new "+r+"(this.data,this.offset)};proto.pick=function "+r+"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function "+r+"_get(){return "+(a?"this.data.get(this.offset)":"this.data[this.offset]")+"};proto.set=function "+r+"_set(v){return "+(a?"this.data.set(this.offset,v)":"this.data[this.offset]=v")+"};return function construct_"+r+"(a,b,c,d){return new "+r+"(a,d)}";return new Function("TrivialArray",i)(c[t][0])}i=["'use strict'"];var o=n(e),l=o.map(function(t){return"i"+t}),u="this.offset+"+o.map(function(t){return"this.stride["+t+"]*i"+t}).join("+"),h=o.map(function(t){return"b"+t}).join(","),f=o.map(function(t){return"c"+t}).join(",");i.push("function "+r+"(a,"+h+","+f+",d){this.data=a","this.shape=["+h+"]","this.stride=["+f+"]","this.offset=d|0}","var proto="+r+".prototype","proto.dtype='"+t+"'","proto.dimension="+e),i.push("Object.defineProperty(proto,'size',{get:function "+r+"_size(){return "+o.map(function(t){return"this.shape["+t+"]"}).join("*"),"}})"),1===e?i.push("proto.order=[0]"):(i.push("Object.defineProperty(proto,'order',{get:"),e<4?(i.push("function "+r+"_order(){"),2===e?i.push("return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})"):3===e&&i.push("var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})")):i.push("ORDER})")),i.push("proto.set=function "+r+"_set("+l.join(",")+",v){"),a?i.push("return this.data.set("+u+",v)}"):i.push("return this.data["+u+"]=v}"),i.push("proto.get=function "+r+"_get("+l.join(",")+"){"),a?i.push("return this.data.get("+u+")}"):i.push("return this.data["+u+"]}"),i.push("proto.index=function "+r+"_index(",l.join(),"){return "+u+"}"),i.push("proto.hi=function "+r+"_hi("+l.join(",")+"){return new "+r+"(this.data,"+o.map(function(t){return["(typeof i",t,"!=='number'||i",t,"<0)?this.shape[",t,"]:i",t,"|0"].join("")}).join(",")+","+o.map(function(t){return"this.stride["+t+"]"}).join(",")+",this.offset)}");var p=o.map(function(t){return"a"+t+"=this.shape["+t+"]"}),d=o.map(function(t){return"c"+t+"=this.stride["+t+"]"});i.push("proto.lo=function "+r+"_lo("+l.join(",")+"){var b=this.offset,d=0,"+p.join(",")+","+d.join(","));for(var g=0;g<e;++g)i.push("if(typeof i"+g+"==='number'&&i"+g+">=0){d=i"+g+"|0;b+=c"+g+"*d;a"+g+"-=d}");i.push("return new "+r+"(this.data,"+o.map(function(t){return"a"+t}).join(",")+","+o.map(function(t){return"c"+t}).join(",")+",b)}"),i.push("proto.step=function "+r+"_step("+l.join(",")+"){var "+o.map(function(t){return"a"+t+"=this.shape["+t+"]"}).join(",")+","+o.map(function(t){return"b"+t+"=this.stride["+t+"]"}).join(",")+",c=this.offset,d=0,ceil=Math.ceil");for(g=0;g<e;++g)i.push("if(typeof i"+g+"==='number'){d=i"+g+"|0;if(d<0){c+=b"+g+"*(a"+g+"-1);a"+g+"=ceil(-a"+g+"/d)}else{a"+g+"=ceil(a"+g+"/d)}b"+g+"*=d}");i.push("return new "+r+"(this.data,"+o.map(function(t){return"a"+t}).join(",")+","+o.map(function(t){return"b"+t}).join(",")+",c)}");var v=new Array(e),m=new Array(e);for(g=0;g<e;++g)v[g]="a[i"+g+"]",m[g]="b[i"+g+"]";i.push("proto.transpose=function "+r+"_transpose("+l+"){"+l.map(function(t,e){return t+"=("+t+"===undefined?"+e+":"+t+"|0)"}).join(";"),"var a=this.shape,b=this.stride;return new "+r+"(this.data,"+v.join(",")+","+m.join(",")+",this.offset)}"),i.push("proto.pick=function "+r+"_pick("+l+"){var a=[],b=[],c=this.offset");for(g=0;g<e;++g)i.push("if(typeof i"+g+"==='number'&&i"+g+">=0){c=(c+this.stride["+g+"]*i"+g+")|0}else{a.push(this.shape["+g+"]);b.push(this.stride["+g+"])}");return i.push("var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}"),i.push("return function construct_"+r+"(data,shape,stride,offset){return new "+r+"(data,"+o.map(function(t){return"shape["+t+"]"}).join(",")+","+o.map(function(t){return"stride["+t+"]"}).join(",")+",offset)}"),new Function("CTOR_LIST","ORDER",i.join("\n"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);"number"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n)for(n=0,s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s]);for(var h=function(t){if(a(t))return"buffer";if(i)switch(Object.prototype.toString.call(t)){case"[object Float64Array]":return"float64";case"[object Float32Array]":return"float32";case"[object Int8Array]":return"int8";case"[object Int16Array]":return"int16";case"[object Int32Array]":return"int32";case"[object Uint8Array]":return"uint8";case"[object Uint16Array]":return"uint16";case"[object Uint32Array]":return"uint32";case"[object Uint8ClampedArray]":return"uint8_clamped"}return Array.isArray(t)?"array":"generic"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,n)}},{"iota-array":417,"is-buffer":419}],452:[function(t,e,r){"use strict";var n=t("double-bits"),a=Math.pow(2,-1074),i=-1>>>0;e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-a:a;var r=n.hi(t),o=n.lo(t);e>t==t>0?o===i?(r+=1,o=0):o+=1:0===o?(o=i,r-=1):o-=1;return n.pack(o,r)}},{"double-bits":168}],453:[function(t,e,r){var n=Math.PI,a=c(120);function i(t,e,r,n){return["C",t,e,r,n,r,n]}function o(t,e,r,n,a,i){return["C",t/3+2/3*r,e/3+2/3*n,a/3+2/3*r,i/3+2/3*n,a,i]}function s(t,e,r,i,o,c,u,h,f,p){if(p)k=p[0],T=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(h=(d=l(h,f,-o)).x))/2,v=(e-(f=d.y))/2,m=g*g/(r*r)+v*v/(i*i);m>1&&(r*=m=Math.sqrt(m),i*=m);var y=r*r,x=i*i,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*v*v-x*g*g)/(y*v*v+x*g*g)));b==1/0&&(b=1);var _=b*r*v/i+(t+h)/2,w=b*-i*g/r+(e+f)/2,k=Math.asin(((e-w)/i).toFixed(9)),T=Math.asin(((f-w)/i).toFixed(9));(k=t<_?n-k:k)<0&&(k=2*n+k),(T=h<_?n-T:T)<0&&(T=2*n+T),u&&k>T&&(k-=2*n),!u&&T>k&&(T-=2*n)}if(Math.abs(T-k)>a){var A=T,M=h,S=f;T=k+a*(u&&T>k?1:-1);var E=s(h=_+r*Math.cos(T),f=w+i*Math.sin(T),r,i,o,0,u,M,S,[T,A,_,w])}var L=Math.tan((T-k)/4),C=4/3*r*L,P=4/3*i*L,O=[2*t-(t+C*Math.sin(k)),2*e-(e-P*Math.cos(k)),h+C*Math.sin(T),f-P*Math.cos(T),h,f];if(p)return O;E&&(O=O.concat(E));for(var z=0;z<O.length;){var I=l(O[z],O[z+1],o);O[z++]=I.x,O[z++]=I.y}return O}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,a=0,l=0,u=0,h=null,f=null,p=0,d=0,g=0,v=t.length;g<v;g++){var m=t[g],y=m[0];switch(y){case"M":l=m[1],u=m[2];break;case"A":(m=s(p,d,m[1],m[2],c(m[3]),m[4],m[5],m[6],m[7])).unshift("C"),m.length>7&&(r.push(m.splice(0,7)),m.unshift("C"));break;case"S":var x=p,b=d;"C"!=e&&"S"!=e||(x+=x-n,b+=b-a),m=["C",x,b,m[1],m[2],m[3],m[4]];break;case"T":"Q"==e||"T"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),m=o(p,d,h,f,m[1],m[2]);break;case"Q":h=m[1],f=m[2],m=o(p,d,m[1],m[2],m[3],m[4]);break;case"L":m=i(p,d,m[1],m[2]);break;case"H":m=i(p,d,m[1],d);break;case"V":m=i(p,d,p,m[1]);break;case"Z":m=i(p,d,l,u)}e=y,p=m[m.length-2],d=m[m.length-1],m.length>4?(n=m[m.length-4],a=m[m.length-3]):(n=p,a=d),r.push(m)}return r}},{}],454:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,a=new Array(n),i=void 0===r?1e-6:r,o=0;o<n;++o)a[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],g=new Array(3),v=0,m=new Array(3),y=0,x=0;x<3;++x)g[x]=f[x]-p[x],v+=g[x]*g[x],m[x]=d[x]-p[x],y+=m[x]*m[x];if(v*y>i){var b=a[c],_=1/Math.sqrt(v*y);for(x=0;x<3;++x){var w=(x+1)%3,k=(x+2)%3;b[x]+=_*(m[w]*g[k]-m[k]*g[w])}}}for(o=0;o<n;++o){b=a[o];var T=0;for(x=0;x<3;++x)T+=b[x]*b[x];if(T>i)for(_=1/Math.sqrt(T),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return a},r.faceNormals=function(t,e,r){for(var n=t.length,a=new Array(n),i=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;f[c]=u[d]*h[g]-u[g]*h[d],p+=f[c]*f[c]}p=p>i?1/Math.sqrt(p):0;for(c=0;c<3;++c)f[c]*=p;a[o]=f}return a}},{}],455:[function(t,e,r){"use strict";var n=Object.getOwnPropertySymbols,a=Object.prototype.hasOwnProperty,i=Object.prototype.propertyIsEnumerable;e.exports=function(){try{if(!Object.assign)return!1;var t=new String("abc");if(t[5]="de","5"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e["_"+String.fromCharCode(r)]=r;if("0123456789"!==Object.getOwnPropertyNames(e).map(function(t){return e[t]}).join(""))return!1;var n={};return"abcdefghijklmnopqrst".split("").forEach(function(t){n[t]=t}),"abcdefghijklmnopqrst"===Object.keys(Object.assign({},n)).join("")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,o,s=function(t){if(null==t)throw new TypeError("Object.assign cannot be called with null or undefined");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in r=Object(arguments[l]))a.call(r,c)&&(s[c]=r[c]);if(n){o=n(r);for(var u=0;u<o.length;u++)i.call(r,o[u])&&(s[o[u]]=r[o[u]])}}return s}},{}],456:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a,i,o,s,l,c){var u=e+i+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-i)/h,t[3]=.5*h}else{var f=Math.max(e,i,c),h=Math.sqrt(2*f-u+1);e>=f?(t[0]=.5*h,t[1]=.5*(a+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):i>=f?(t[0]=.5*(r+a)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-a)/h)}return t}},{}],457:[function(t,e,r){"use strict";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var a=new h(r,e,Math.log(n));a.setDistanceLimits(t.zoomMin,t.zoomMax),("eye"in t||"up"in t)&&a.lookAt(0,t.eye,t.center,t.up);return a};var n=t("filtered-vector"),a=t("gl-mat4/lookAt"),i=t("gl-mat4/fromQuat"),o=t("gl-mat4/invert"),s=t("./lib/quatFromFrame");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],a=e[2],i=e[3],o=c(r,n,a,i);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=a/o,t[3]=i/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;i(r,e);var n=this.computedCenter,a=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);a[0]=n[0]+s*r[2],a[1]=n[1]+s*r[6],a[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*a[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var a=this.computedMatrix,i=a[1],o=a[5],s=a[9],c=l(i,o,s);i/=c,o/=c,s/=c;var u=a[0],h=a[4],f=a[8],p=u*i+h*o+f*s,d=l(u-=i*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var g=a[2],v=a[6],m=a[10],y=g*i+v*o+m*s,x=g*u+v*h+m*f,b=l(g-=y*i+x*u,v-=y*o+x*h,m-=y*s+x*f);g/=b,v/=b,m/=b;var _=u*e+i*r,w=h*e+o*r,k=f*e+s*r;this.center.move(t,_,w,k);var T=Math.exp(this.computedRadius[0]);T=Math.max(1e-4,T+n),this.radius.set(t,Math.log(T))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var a=this.computedMatrix,i=a[0],o=a[4],s=a[8],u=a[1],h=a[5],f=a[9],p=a[2],d=a[6],g=a[10],v=e*i+r*u,m=e*o+r*h,y=e*s+r*f,x=-(d*y-g*m),b=-(g*v-p*y),_=-(p*m-d*v),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),k=c(x,b,_,w);k>1e-6?(x/=k,b/=k,_/=k,w/=k):(x=b=_=0,w=1);var T=this.computedRotation,A=T[0],M=T[1],S=T[2],E=T[3],L=A*w+E*x+M*_-S*b,C=M*w+E*b+S*x-A*_,P=S*w+E*_+A*b-M*x,O=E*w-A*x-M*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,O=O*(w=Math.cos(e))-(L=L*w+O*x+C*_-P*b)*x-(C=C*w+O*b+P*x-L*_)*b-(P=P*w+O*_+L*b-C*x)*_}var I=c(L,C,P,O);I>1e-6?(L/=I,C/=I,P/=I,O/=I):(L=C=P=0,O=1),this.rotation.set(t,L,C,P,O)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var i=this.computedMatrix;a(i,e,r,n);var o=this.computedRotation;s(o,i[0],i[1],i[2],i[4],i[5],i[6],i[8],i[9],i[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var a=n[15];if(Math.abs(a)>1e-6){var i=n[12]/a,l=n[13]/a,c=n[14]/a;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,i-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var a=t.distance;a&&a>0&&this.radius.set(e,Math.log(a)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{"./lib/quatFromFrame":456,"filtered-vector":228,"gl-mat4/fromQuat":264,"gl-mat4/invert":267,"gl-mat4/lookAt":268}],458:[function(t,e,r){"use strict";var n=t("repeat-string");e.exports=function(t,e,r){return n(r="undefined"!=typeof r?r+"":" ",e)+t}},{"repeat-string":501}],459:[function(t,e,r){"use strict";function n(t,e){if("string"!=typeof t)return[t];var r=[t];"string"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:["{}","[]","()"],a=e.escape||"___",i=!!e.flat;n.forEach(function(t){var e=new RegExp(["\\",t[0],"[^\\",t[0],"\\",t[1],"]*\\",t[1]].join("")),n=[];function i(e,i,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),a+s+a}r.forEach(function(t,n){for(var a,o=0;t!=a;)if(a=t,t=t.replace(e,i),o++>1e4)throw Error("References have circular dependency. Please, check them.");r[n]=t}),n=n.reverse(),r=r.map(function(e){return n.forEach(function(r){e=e.replace(new RegExp("(\\"+a+r+"\\"+a+")","g"),t[0]+"$1"+t[1])}),e})});var o=new RegExp("\\"+a+"([0-9]+)\\"+a);return i?r:function t(e,r,n){for(var a,i=[],s=0;a=o.exec(e);){if(s++>1e4)throw Error("Circular references in parenthesis");i.push(e.slice(0,a.index)),i.push(t(r[a[1]],r)),e=e.slice(a.index+a[0].length)}return i.push(e),i}(r[0],r)}function a(t,e){if(e&&e.flat){var r,n=e&&e.escape||"___",a=t[0];if(!a)return"";for(var i=new RegExp("\\"+n+"([0-9]+)\\"+n),o=0;a!=r;){if(o++>1e4)throw Error("Circular references in "+t);r=a,a=a.replace(i,s)}return a}return t.reduce(function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,"")),e+r},"");function s(e,r){if(null==t[r])throw Error("Reference "+r+"is undefined");return t[r]}}function i(t,e){return Array.isArray(t)?a(t,e):n(t,e)}i.parse=n,i.stringify=a,e.exports=i},{}],460:[function(t,e,r){"use strict";var n=t("pick-by-alias");e.exports=function(t){var e;arguments.length>1&&(t=arguments);"string"==typeof t?t=t.split(/\s/).map(parseFloat):"number"==typeof t&&(t=[t]);t.length&&"number"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:"x l left Left",top:"y t top Top",width:"w width W Width",height:"h height W Width",bottom:"b bottom Bottom",right:"r right Right"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{"pick-by-alias":466}],461:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(a,function(t,r,a){var o=r.toLowerCase();for(a=function(t){var e=t.match(i);return e?e.map(Number):[]}(a),"m"==o&&a.length>2&&(e.push([r].concat(a.splice(0,2))),o="l",r="m"==r?"l":"L");;){if(a.length==n[o])return a.unshift(r),e.push(a);if(a.length<n[o])throw new Error("malformed path data");e.push([r].concat(a.splice(0,n[o])))}}),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},a=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var i=/-?[0-9]*\.?[0-9]+(?:e[-+]?\d+)?/gi},{}],462:[function(t,e,r){e.exports=function(t,e){e||(e=[0,""]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\d.\-\+]*\s*(.*)/)[1]||"",e}},{}],463:[function(t,e,r){(function(t){(function(){var r,n,a,i,o,s;"undefined"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:"undefined"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,i=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=i-s):Date.now?(e.exports=function(){return Date.now()-a},a=Date.now()):(e.exports=function(){return(new Date).getTime()-a},a=(new Date).getTime())}).call(this)}).call(this,t("_process"))},{_process:483}],464:[function(t,e,r){"use strict";e.exports=function(t){var e=t.length;if(e<n){for(var r=1,i=0;i<e;++i)for(var o=0;o<i;++o)if(t[i]<t[o])r=-r;else if(t[i]===t[o])return 0;return r}for(var s=a.mallocUint8(e),i=0;i<e;++i)s[i]=0;for(var r=1,i=0;i<e;++i)if(!s[i]){var l=1;s[i]=1;for(var o=t[i];o!==i;o=t[o]){if(s[o])return a.freeUint8(s),0;l+=1,s[o]=1}1&l||(r=-r)}return a.freeUint8(s),r};var n=32,a=t("typedarray-pool")},{"typedarray-pool":543}],465:[function(t,e,r){"use strict";var n=t("typedarray-pool"),a=t("invert-permutation");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,i,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(a(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)i=l[o],r=s[o],s[o]=s[i],s[i]=r,l[o]=l[r],l[r]=i,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,a,i,o=1;for((r=r||new Array(t))[0]=0,i=1;i<t;++i)r[i]=i,o=o*i|0;for(i=t-1;i>0;--i)e=e-(n=e/o|0)*o|0,o=o/i|0,a=0|r[i],r[i]=0|r[n],r[n]=0|a;return r}},{"invert-permutation":416,"typedarray-pool":543}],466:[function(t,e,r){"use strict";e.exports=function(t,e,r){var n,i,o={};if("string"==typeof e&&(e=a(e)),Array.isArray(e)){var s={};for(i=0;i<e.length;i++)s[e[i]]=!0;e=s}for(n in e)e[n]=a(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(i=0;i<c.length;i++){var u=c[i];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var h=i;h<c.length;h++)l[c[h]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function a(t){return n[t]?n[t]:("string"==typeof t&&(t=n[t]=t.split(/\s*,\s*|\s+/)),t)}},{}],467:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r=0|e.length,a=t.length,i=[new Array(r),new Array(r)],o=0;o<r;++o)i[0][o]=[],i[1][o]=[];for(var o=0;o<a;++o){var s=t[o];i[0][s[0]].push(s),i[1][s[1]].push(s)}for(var l=[],o=0;o<r;++o)i[0][o].length+i[1][o].length===0&&l.push([o]);function c(t,e){var r=i[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,a){for(var o,s,l,u=0;u<2;++u)if(i[u][r].length>0){o=i[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=i[h][r],p=0;p<f.length;++p){var d=f[p],g=d[1^h],v=n(e[t],e[r],e[s],e[g]);v>0&&(o=d,s=g,l=h)}return a?s:(o&&c(o,l),s)}function h(t,r){var a=i[r][t][0],o=[t];c(a,r);for(var s=a[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(i[0][t].length+i[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(var o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];i[p][o].length>0;){i[0][o].length;var g=h(o,p);f(d,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t("compare-angle")},{"compare-angle":128}],468:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r=n(t,e.length),a=new Array(e.length),i=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;i[s]=l,a[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();a[c]=!1;for(var u=r[c],s=0;s<u.length;++s){var h=u[s];0==--i[h]&&o.push(h)}}for(var f=new Array(e.length),p=[],s=0;s<e.length;++s)if(a[s]){var c=p.length;f[s]=c,p.push(e[s])}else f[s]=-1;for(var d=[],s=0;s<t.length;++s){var g=t[s];a[g[0]]&&a[g[1]]&&d.push([f[g[0]],f[g[1]]])}return[d,p]};var n=t("edges-to-adjacency-list")},{"edges-to-adjacency-list":173}],469:[function(t,e,r){"use strict";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error("planar-graph-to-polyline: graph must be manifold");var d=a(t,e);for(var g=(d=d.filter(function(t){for(var r=t.length,n=[0],a=0;a<r;++a){var i=e[t[a]],l=e[t[(a+1)%r]],c=o(-i[0],i[1]),u=o(-i[0],l[1]),h=o(l[0],i[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0})).length,v=new Array(g),m=new Array(g),p=0;p<g;++p){v[p]=p;var y=new Array(g),x=d[p].map(function(t){return e[t]}),b=i([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var k=d[w],T=k.length,A=0;A<T;++A){var M=b(e[k[A]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}m[p]=[_,p,y]}m.sort(function(t,e){return e[0]-t[0]});for(var p=0;p<g;++p)for(var y=m[p],S=y[1],E=y[2],w=0;w<g;++w)E[w]&&(v[w]=S);for(var L=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g),p=0;p<g;++p)L[p].push(v[p]),L[v[p]].push(p);for(var C={},P=u(h,!1),p=0;p<g;++p)for(var k=d[p],T=k.length,w=0;w<T;++w){var O=k[w],z=k[(w+1)%T],I=Math.min(O,z)+":"+Math.max(O,z);if(I in C){var D=C[I];L[D].push(p),L[p].push(D),P[O]=P[z]=!0}else C[I]=p}function R(t){for(var e=t.length,r=0;r<e;++r)if(!P[t[r]])return!1;return!0}for(var F=[],B=u(g,-1),p=0;p<g;++p)v[p]!==p||R(d[p])?B[p]=-1:(F.push(p),B[p]=0);var r=[];for(;F.length>0;){var N=F.pop(),j=L[N];l(j,function(t,e){return t-e});var V,U=j.length,q=B[N];if(0===q){var k=d[N];V=[k]}for(var p=0;p<U;++p){var H=j[p];if(!(B[H]>=0)&&(B[H]=1^q,F.push(H),0===q)){var k=d[H];R(k)||(k.reverse(),V.push(k))}}0===q&&r.push(V)}return r};var n=t("edges-to-adjacency-list"),a=t("planar-dual"),i=t("point-in-big-polygon"),o=t("two-product"),s=t("robust-sum"),l=t("uniq"),c=t("./lib/trim-leaves");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{"./lib/trim-leaves":468,"edges-to-adjacency-list":173,"planar-dual":467,"point-in-big-polygon":473,"robust-sum":513,"two-product":541,uniq:545}],470:[function(t,e,r){"use strict";e.exports=t("./quad")},{"./quad":472}],471:[function(t,e,r){arguments[4][112][0].apply(r,arguments)},{dup:112}],472:[function(t,e,r){"use strict";var n=t("binary-search-bounds"),a=t("clamp"),i=t("parse-rect"),o=t("array-bounds"),s=t("pick-by-alias"),l=t("defined"),c=t("flatten-vertex-data"),u=t("is-obj"),h=t("dtype"),f=t("math-log2"),p=1073741824;function d(t,e){for(var r=e[0],n=e[1],i=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=a((t[2*l]-r)*i,0,1),s[2*l+1]=a((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,"float64"),e=s(e,{bounds:"range bounds dataBox databox",maxDepth:"depth maxDepth maxdepth level maxLevel maxlevel levels",dtype:"type dtype format out dst output destination"});var r=l(e.maxDepth,255),a=l(e.bounds,o(t,2));a[0]===a[2]&&a[2]++,a[1]===a[3]&&a[3]++;var g,v=d(t,a),m=t.length>>>1;e.dtype||(e.dtype="array"),"string"==typeof e.dtype?g=new(h(e.dtype))(m):e.dtype&&(g=e.dtype,Array.isArray(g)&&(g.length=m));for(var y=0;y<m;++y)g[y]=y;var x=[],b=[],_=[],w=[];!function t(e,n,a,i,o,s){if(!i.length)return null;var l=x[o]||(x[o]=[]);var c=_[o]||(_[o]=[]);var u=b[o]||(b[o]=[]);var h=l.length;o++;if(o>r||s>p){for(var f=0;f<i.length;f++)l.push(i[f]),c.push(s),u.push(null,null,null,null);return h}l.push(i[0]);c.push(s);if(i.length<=1)return u.push(null,null,null,null),h;var d=.5*a;var g=e+d,m=n+d;var y=[],w=[],k=[],T=[];for(var A=1,M=i.length;A<M;A++){var S=i[A],E=v[2*S],L=v[2*S+1];E<g?L<m?y.push(S):w.push(S):L<m?k.push(S):T.push(S)}s<<=2;u.push(t(e,n,d,y,o,s),t(e,m,d,w,o,s+1),t(g,n,d,k,o,s+2),t(g,m,d,T,o,s+3));return h}(0,0,1,g,0,1);for(var k=0,T=0;T<x.length;T++){var A=x[T];if(g.set)g.set(A,k);else for(var M=0,S=A.length;M<S;M++)g[M+k]=A[M];var E=k+x[T].length;w[T]=[k,E],k=E}return g.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:"level maxLevel",d:"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize",lod:"lod details ranges offsets"})}else e={};r.length||(r=a);var h=i.apply(void 0,r),p=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=p[0],v=p[1],m=p[2],y=p[3],k=d([g,v,m,y],a),T=k[0],A=k[1],M=k[2],S=k[3],E=l(e.level,x.length);if(null!=e.d){var C;"number"==typeof e.d?C=[e.d,e.d]:e.d.length&&(C=e.d),E=Math.min(Math.max(Math.ceil(-f(Math.abs(C[0])/(a[2]-a[0]))),Math.ceil(-f(Math.abs(C[1])/(a[3]-a[1])))),E)}if(E=Math.min(E,x.length),e.lod)return function(t,e,r,a,i){for(var o=[],s=0;s<i;s++){var l=_[s],c=w[s][0],u=L(t,e,s),h=L(r,a,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,E);var P=[];return function e(r,n,a,i,o,s){if(null!==o&&null!==s){var l=r+a,c=n+a;if(!(T>l||A>c||M<r||S<n||i>=E||o===s)){var u=x[i];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=y&&P.push(f)}var _=b[i],w=_[4*o+0],k=_[4*o+1],L=_[4*o+2],C=_[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(_,o+1),z=.5*a,I=i+1;e(r,n,z,I,w,k||L||C||O),e(r,n+z,z,I,k,L||C||O),e(r+z,n,z,I,L,C||O),e(r+z,n+z,z,I,C,O)}}}(0,0,1,0,0,1),P},g;function L(t,e,r){for(var n=1,a=.5,i=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<a?e<i?0:1:e<i?2:3,o*=.5,a+=t<a?-o:o,i+=e<i?-o:o;return n}}},{"array-bounds":67,"binary-search-bounds":471,clamp:116,defined:165,dtype:170,"flatten-vertex-data":229,"is-obj":422,"math-log2":433,"parse-rect":460,"pick-by-alias":466}],473:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],i=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],g=u[p];d[0]===g[0]?i.push([d,g]):r.push([d,g])}if(0===r.length)return 0===i.length?c:(v=l(i),function(t){return v(t[0],t[1])?0:1});var v;var m=a(r),y=function(t,e){return function(r){var a=o.le(e,r[0]);if(a<0)return 1;var i=t[a];if(!i){if(!(a>0&&e[a]===r[0]))return 1;i=t[a-1]}for(var s=1;i;){var l=i.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)i=i.left;else{if(!(c>0))return 0;s=-1,i=i.right}else if(c>0)i=i.left;else{if(!(c<0))return 0;s=1,i=i.right}}return s}}(m.slabs,m.coordinates);return 0===i.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(i),y)};var n=t("robust-orientation")[3],a=t("slab-decomposition"),i=t("interval-tree-1d"),o=t("binary-search-bounds");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],a=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];a in e?e[a].push(c):e[a]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=i(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{"binary-search-bounds":92,"interval-tree-1d":415,"robust-orientation":508,"slab-decomposition":524}],474:[function(t,e,r){var n,a=t("./lib/build-log"),i=t("./lib/epsilon"),o=t("./lib/intersecter"),s=t("./lib/segment-chainer"),l=t("./lib/segment-selector"),c=t("./lib/geojson"),u=!1,h=i();function f(t,e,r){var a=n.segments(t),i=n.segments(e),o=r(n.combine(a,i));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=a():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},"object"==typeof window&&(window.PolyBool=n),e.exports=n},{"./lib/build-log":475,"./lib/epsilon":476,"./lib/geojson":477,"./lib/intersecter":478,"./lib/segment-chainer":480,"./lib/segment-selector":481}],475:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n("check",{seg1:t,seg2:e})},segmentChop:function(t,e){return n("div_seg",{seg:t,pt:e}),n("chop",{seg:t,pt:e})},statusRemove:function(t){return n("pop_seg",{seg:t})},segmentUpdate:function(t){return n("seg_update",{seg:t})},segmentNew:function(t,e){return n("new_seg",{seg:t,primary:e})},segmentRemove:function(t){return n("rem_seg",{seg:t})},tempStatus:function(t,e,r){return n("temp_status",{seg:t,above:e,below:r})},rewind:function(t){return n("rewind",{seg:t})},status:function(t,e,r){return n("status",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n("vert",{x:e}))},log:function(t){return"string"!=typeof t&&(t=JSON.stringify(t,!1,"  ")),n("log",{txt:t})},reset:function(){return n("reset")},selected:function(t){return n("selected",{segs:t})},chainStart:function(t){return n("chain_start",{seg:t})},chainRemoveHead:function(t,e){return n("chain_rem_head",{index:t,pt:e})},chainRemoveTail:function(t,e){return n("chain_rem_tail",{index:t,pt:e})},chainNew:function(t,e){return n("chain_new",{pt1:t,pt2:e})},chainMatch:function(t){return n("chain_match",{index:t})},chainClose:function(t){return n("chain_close",{index:t})},chainAddHead:function(t,e){return n("chain_add_head",{index:t,pt:e})},chainAddTail:function(t,e){return n("chain_add_tail",{index:t,pt:e})},chainConnect:function(t,e){return n("chain_con",{index1:t,index2:e})},chainReverse:function(t){return n("chain_rev",{index:t})},chainJoin:function(t,e){return n("chain_join",{index1:t,index2:e})},done:function(){return n("done")}}}},{}],476:[function(t,e,r){e.exports=function(t){"number"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return"number"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var a=r[0],i=r[1],o=n[0],s=n[1],l=e[0];return(o-a)*(e[1]-i)-(s-i)*(l-a)>=-t},pointBetween:function(e,r,n){var a=e[1]-r[1],i=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*i+a*s;return!(l<t||l-(i*i+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var a=e[0]-r[0],i=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(a*s-o*i)<t},linesIntersect:function(e,r,n,a){var i=r[0]-e[0],o=r[1]-e[1],s=a[0]-n[0],l=a[1]-n[1],c=i*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(i*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*i,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],a=e[1],i=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-a>t!=o-a>t&&(i-c)*(a-u)/(o-u)+c-n>t&&(s=!s),i=c,o=u}return s}};return e}},{}],477:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),a=1;a<e.length;a++)n=t.selectDifference(t.combine(n,r(e[a])));return n}if("Polygon"===e.type)return t.polygon(r(e.coordinates));if("MultiPolygon"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),a=0;a<e.coordinates.length;a++)n=t.selectUnion(t.combine(n,r(e.coordinates[a])));return t.polygon(n)}throw new Error("PolyBool: Cannot convert GeoJSON object to PolyBool polygon")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function a(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var i=a(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var i=a(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(i.children.push(s),t.children.splice(r,1),r--)}t.children.push(i)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(i,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],a=t[t.length-1][1],i=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];i.push([s,l]),r+=l*n-s*a,n=s,a=l}return r<0!==e&&i.reverse(),i.push([i[0][0],i[0][1]]),i}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<i.children.length;s++)h(i.children[s]);return u.length<=0?{type:"Polygon",coordinates:[]}:1==u.length?{type:"Polygon",coordinates:u[0]}:{type:"MultiPolygon",coordinates:u}}};e.exports=n},{}],478:[function(t,e,r){var n=t("./linked-list");e.exports=function(t,e,r){function a(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var i=n.create();function o(t,r){i.insertBefore(t,function(n){return function(t,r,n,a,i,o){var s=e.pointsCompare(r,i);return 0!==s?s:e.pointsSame(n,o)?0:t!==a?t?1:-1:e.pointAboveOrOnLine(n,a?i:o,a?o:i)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0})}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var a=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=a,o(a,t.pt)}(r,t,e),r}function l(t,e){var n=a(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(a,o){var s=n.create();function c(t){return s.findTransition(function(r){var n,a,i,o,s,l;return n=t,a=r.ev,i=n.seg.start,o=n.seg.end,s=a.seg.start,l=a.seg.end,(e.pointsCollinear(i,s,l)?e.pointsCollinear(o,s,l)?1:e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(i,s,l)?1:-1)>0})}function u(t,n){var a=t.seg,i=n.seg,o=a.start,s=a.end,c=i.start,u=i.end;r&&r.checkIntersection(a,i);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(f)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!i.isEmpty();){var f=i.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function v(){if(d){var t=u(f,d);if(t)return t}return!!g&&u(f,g)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!g&&g.seg);var m,y,x=v();if(x)t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=f.seg.myFill,r&&r.segmentUpdate(x.seg),f.other.remove(),f.remove();if(i.getHead()!==f){r&&r.rewind(f.seg);continue}t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=g?g.seg.myFill.above:a,f.seg.myFill.above=y?!f.seg.myFill.below:f.seg.myFill.below):null===f.seg.otherFill&&(m=g?f.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:f.primary?o:a,f.seg.otherFill={above:m,below:m}),r&&r.status(f.seg,!!d&&d.seg,!!g&&g.seg),f.other.status=p.insert(n.node({ev:f}))}else{var b=f.status;if(null===b)throw new Error("PolyBool: Zero-length segment detected; your epsilon is probably too small or too large");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!f.primary){var _=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=_}h.push(f.seg)}i.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,a,i,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((a=c<0?n:o,i=c<0?o:n,{id:r?r.segmentId():-1,start:a,end:i,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach(function(t){s(a(t.start,t.end,t),!0)}),r.forEach(function(t){s(a(t.start,t.end,t),!1)}),c(e,n)}}}},{"./linked-list":479}],479:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,a=t.root.next;null!==a;){if(r(a))return e.prev=a.prev,e.next=a,a.prev.next=e,void(a.prev=e);n=a,a=a.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],480:[function(t,e,r){e.exports=function(t,e,r){var n=[],a=[];return t.forEach(function(t){var i=t.start,o=t.end;if(e.pointsSame(i,o))console.warn("PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(v=n[u])[0],f=(v[1],v[v.length-1]);if(v[v.length-2],e.pointsSame(h,i)){if(T(u,!0,!0))break}else if(e.pointsSame(h,o)){if(T(u,!0,!1))break}else if(e.pointsSame(f,i)){if(T(u,!1,!0))break}else if(e.pointsSame(f,o)&&T(u,!1,!1))break}if(c===s)return n.push([i,o]),void(r&&r.chainNew(i,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:i,g=s.matches_head,v=n[p],m=g?v[0]:v[v.length-1],y=g?v[1]:v[v.length-2],x=g?v[v.length-1]:v[0],b=g?v[v.length-2]:v[1];return e.pointsCollinear(y,m,d)&&(g?(r&&r.chainRemoveHead(s.index,d),v.shift()):(r&&r.chainRemoveTail(s.index,d),v.pop()),m=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,m)&&(g?(r&&r.chainRemoveTail(s.index,m),v.pop()):(r&&r.chainRemoveHead(s.index,m),v.shift())),r&&r.chainClose(s.index),void a.push(v)):void(g?(r&&r.chainAddHead(s.index,d),v.unshift(d)):(r&&r.chainAddTail(s.index,d),v.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var k=n[_].length<n[w].length;s.matches_head?l.matches_head?k?(A(_),M(_,w)):(A(w),M(w,_)):M(w,_):l.matches_head?M(_,w):k?(A(_),M(w,_)):(A(w),M(_,w))}function T(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function A(t){r&&r.chainReverse(t),n[t].reverse()}function M(t,a){var i=n[t],o=n[a],s=i[i.length-1],l=i[i.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),i.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(a,c),o.shift()),r&&r.chainJoin(t,a),n[t]=i.concat(o),n.splice(a,1)}}),a}},{}],481:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach(function(t){var a=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[a]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[a],below:2===e[a]},otherFill:null})}),r&&r.selected(n),n}var a={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=a},{}],482:[function(t,e,r){"use strict";var n=new Float64Array(4),a=new Float64Array(4),i=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),a=new Float64Array(o.length),i=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],a[l]=e[l]-t[l],i[l]=r[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var g=a[l],v=i[l],m=n[l];c+=g*g,u+=g*v,h+=v*v,f+=m*g,p+=m*v,d+=m*m}var y,x,b,_,w,k=Math.abs(c*h-u*u),T=u*p-h*f,A=u*f-c*p;if(T+A<=k)if(T<0)A<0&&f<0?(A=0,-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d):(T=0,p>=0?(A=0,y=d):-p>=h?(A=1,y=h+2*p+d):y=p*(A=-p/h)+d);else if(A<0)A=0,f>=0?(T=0,y=d):-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d;else{var M=1/k;y=(T*=M)*(c*T+u*(A*=M)+2*f)+A*(u*T+h*A+2*p)+d}else T<0?(b=h+p)>(x=u+f)?(_=b-x)>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d:(T=0,b<=0?(A=1,y=h+2*p+d):p>=0?(A=0,y=d):y=p*(A=-p/h)+d):A<0?(b=c+f)>(x=u+p)?(_=b-x)>=(w=c-2*u+h)?(A=1,T=0,y=h+2*p+d):y=(T=1-(A=_/w))*(c*T+u*A+2*f)+A*(u*T+h*A+2*p)+d:(A=0,b<=0?(T=1,y=c+2*f+d):f>=0?(T=0,y=d):y=f*(T=-f/c)+d):(_=h+p-u-f)<=0?(T=0,A=1,y=h+2*p+d):_>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d;var S=1-T-A;for(l=0;l<o.length;++l)s[l]=S*t[l]+T*e[l]+A*r[l];return y<0?0:y}},{}],483:[function(t,e,r){var n,a,i=e.exports={};function o(){throw new Error("setTimeout has not been defined")}function s(){throw new Error("clearTimeout has not been defined")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n="function"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{a="function"==typeof clearTimeout?clearTimeout:s}catch(t){a=s}}();var c,u=[],h=!1,f=-1;function p(){h&&c&&(h=!1,c.length?u=c.concat(u):f=-1,u.length&&d())}function d(){if(!h){var t=l(p);h=!0;for(var e=u.length;e;){for(c=u,u=[];++f<e;)c&&c[f].run();f=-1,e=u.length}c=null,h=!1,function(t){if(a===clearTimeout)return clearTimeout(t);if((a===s||!a)&&clearTimeout)return a=clearTimeout,clearTimeout(t);try{a(t)}catch(e){try{return a.call(null,t)}catch(e){return a.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function v(){}i.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||h||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},i.title="browser",i.browser=!0,i.env={},i.argv=[],i.version="",i.versions={},i.on=v,i.addListener=v,i.once=v,i.off=v,i.removeListener=v,i.removeAllListeners=v,i.emit=v,i.prependListener=v,i.prependOnceListener=v,i.listeners=function(t){return[]},i.binding=function(t){throw new Error("process.binding is not supported")},i.cwd=function(){return"/"},i.chdir=function(t){throw new Error("process.chdir is not supported")},i.umask=function(){return 0}},{}],484:[function(t,e,r){e.exports=t("gl-quat/slerp")},{"gl-quat/slerp":295}],485:[function(t,e,r){(function(r){for(var n=t("performance-now"),a="undefined"==typeof window?r:window,i=["moz","webkit"],o="AnimationFrame",s=a["request"+o],l=a["cancel"+o]||a["cancelRequest"+o],c=0;!s&&c<i.length;c++)s=a[i[c]+"Request"+o],l=a[i[c]+"Cancel"+o]||a[i[c]+"CancelRequest"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout(function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout(function(){throw t},0)}},Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}e.exports=function(t){return s.call(a,t)},e.exports.cancel=function(){l.apply(a,arguments)},e.exports.polyfill=function(t){t||(t=a),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"performance-now":463}],486:[function(t,e,r){"use strict";var n=t("big-rat/add");e.exports=function(t,e){for(var r=t.length,a=new Array(r),i=0;i<r;++i)a[i]=n(t[i],e[i]);return a}},{"big-rat/add":76}],487:[function(t,e,r){"use strict";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t("big-rat")},{"big-rat":79}],488:[function(t,e,r){"use strict";var n=t("big-rat"),a=t("big-rat/mul");e.exports=function(t,e){for(var r=n(e),i=t.length,o=new Array(i),s=0;s<i;++s)o[s]=a(t[s],r);return o}},{"big-rat":79,"big-rat/mul":88}],489:[function(t,e,r){"use strict";var n=t("big-rat/sub");e.exports=function(t,e){for(var r=t.length,a=new Array(r),i=0;i<r;++i)a[i]=n(t[i],e[i]);return a}},{"big-rat/sub":90}],490:[function(t,e,r){"use strict";var n=t("compare-cell"),a=t("compare-oriented-cell"),i=t("cell-orientation");e.exports=function(t){t.sort(a);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=i(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&i(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{"cell-orientation":113,"compare-cell":129,"compare-oriented-cell":130}],491:[function(t,e,r){"use strict";var n=t("array-bounds"),a=t("color-normalize"),i=t("update-diff"),o=t("pick-by-alias"),s=t("object-assign"),l=t("flatten-vertex-data"),c=t("to-float32"),u=c.float32,h=c.fract32;e.exports=function(t,e){"function"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension("ANGLE_instanced_arrays"))throw Error("regl-error2d: `ANGLE_instanced_arrays` extension should be enabled");var r,c,p,d,g,v,m=t._gl,y={color:"black",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:"dynamic",type:"uint8",data:new Uint8Array(0)}),c=t.buffer({usage:"dynamic",type:"float",data:new Uint8Array(0)}),p=t.buffer({usage:"dynamic",type:"float",data:new Uint8Array(0)}),g=t.buffer({usage:"dynamic",type:"float",data:new Uint8Array(0)}),v=t.buffer({usage:"static",type:"float",data:f}),k(e),r=t({vert:"\n\t\tprecision highp float;\n\n\t\tattribute vec2 position, positionFract;\n\t\tattribute vec4 error;\n\t\tattribute vec4 color;\n\n\t\tattribute vec2 direction, lineOffset, capOffset;\n\n\t\tuniform vec4 viewport;\n\t\tuniform float lineWidth, capSize;\n\t\tuniform vec2 scale, scaleFract, translate, translateFract;\n\n\t\tvarying vec4 fragColor;\n\n\t\tvoid main() {\n\t\t\tfragColor = color / 255.;\n\n\t\t\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\n\n\t\t\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\n\n\t\t\tvec2 position = position + dxy;\n\n\t\t\tvec2 pos = (position + translate) * scale\n\t\t\t\t+ (positionFract + translateFract) * scale\n\t\t\t\t+ (position + translate) * scaleFract\n\t\t\t\t+ (positionFract + translateFract) * scaleFract;\n\n\t\t\tpos += pixelOffset / viewport.zw;\n\n\t\t\tgl_Position = vec4(pos * 2. - 1., 0, 1);\n\t\t}\n\t\t",frag:"\n\t\tprecision highp float;\n\n\t\tvarying vec4 fragColor;\n\n\t\tuniform float opacity;\n\n\t\tvoid main() {\n\t\t\tgl_FragColor = fragColor;\n\t\t\tgl_FragColor.a *= opacity;\n\t\t}\n\t\t",uniforms:{range:t.prop("range"),lineWidth:t.prop("lineWidth"),capSize:t.prop("capSize"),opacity:t.prop("opacity"),scale:t.prop("scale"),translate:t.prop("translate"),scaleFract:t.prop("scaleFract"),translateFract:t.prop("translateFract"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:v,stride:24,offset:0},lineOffset:{buffer:v,stride:24,offset:8},capOffset:{buffer:v,stride:24,offset:16}},primitive:"triangles",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:"add",alpha:"add"},func:{srcRGB:"src alpha",dstRGB:"one minus src alpha",srcAlpha:"one minus dst alpha",dstAlpha:"one"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop("viewport")},viewport:t.prop("viewport"),stencil:!1,instances:t.prop("count"),count:f.length}),s(b,{update:k,draw:_,destroy:T,regl:t,gl:m,canvas:m.canvas,groups:x}),b;function b(t){t?k(t):null===t&&T(),_()}function _(e){if("number"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach(function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)})}function w(t){"number"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function k(t){if(t){null!=t.length?"number"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map(function(t,c){var u=x[c];return t?("function"==typeof t?t={after:t}:"number"==typeof t[0]&&(t={positions:t}),t=o(t,{color:"color colors fill",capSize:"capSize cap capsize cap-size",lineWidth:"lineWidth line-width width line thickness",opacity:"opacity alpha",range:"range dataBox",viewport:"viewport viewBox",errors:"errors error",positions:"positions position data points"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),i(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,"float64"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t="transparent"),!Array.isArray(t)||"number"==typeof t[0]){var n=t;t=Array(r);for(var i=0;i<r;i++)t[i]=n}if(t.length<r)throw Error("Not enough colors");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=a(t[s],"uint8");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:m.drawingBufferWidth,height:m.drawingBufferHeight},e}}]),u):u}),e||r){var f=x.reduce(function(t,e,r){return t+(e?e.count:0)},0),v=new Float64Array(2*f),_=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach(function(t,e){if(t){var r=t.positions,n=t.count,a=t.offset,i=t.color,o=t.errors;n&&(_.set(i,4*a),w.set(o,4*a),v.set(r,2*a))}}),c(u(v)),p(h(v)),d(_),g(w)}}}function T(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),v.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{"array-bounds":67,"color-normalize":121,"flatten-vertex-data":229,"object-assign":455,"pick-by-alias":466,"to-float32":536,"update-diff":547}],492:[function(t,e,r){"use strict";var n=t("color-normalize"),a=t("array-bounds"),i=t("object-assign"),o=t("glslify"),s=t("pick-by-alias"),l=t("flatten-vertex-data"),c=t("earcut"),u=t("array-normalize"),h=t("to-float32"),f=h.float32,p=h.fract32,d=t("es6-weak-map"),g=t("parse-rect");function v(t,e){if(!(this instanceof v))return new v(t,e);if("function"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension("ANGLE_instanced_arrays"))throw Error("regl-error2d: `ANGLE_instanced_arrays` extension should be enabled");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:"static",type:"float",data:[0,1,0,0,1,1,1,0]}),n={primitive:"triangle strip",instances:t.prop("count"),count:4,offset:0,uniforms:{miterMode:function(t,e){return"round"===e.join?2:1},miterLimit:t.prop("miterLimit"),scale:t.prop("scale"),scaleFract:t.prop("scaleFract"),translateFract:t.prop("translateFract"),translate:t.prop("translate"),thickness:t.prop("thickness"),dashPattern:t.prop("dashTexture"),opacity:t.prop("opacity"),pixelRatio:t.context("pixelRatio"),id:t.prop("id"),dashSize:t.prop("dashLength"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop("depth")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:"add",alpha:"add"},func:{srcRGB:"src alpha",dstRGB:"one minus src alpha",srcAlpha:"one minus dst alpha",dstAlpha:"one"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop("viewport")},viewport:t.prop("viewport")},a=t(i({vert:o(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\nattribute vec4 color;\nattribute float lineEnd, lineTop;\n\nuniform vec2 scale, scaleFract, translate, translateFract;\nuniform float thickness, pixelRatio, id, depth;\nuniform vec4 viewport;\n\nvarying vec4 fragColor;\nvarying vec2 tangent;\n\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\n\t// the order is important\n\treturn position * scale + translate\n       + positionFract * scale + translateFract\n       + position * scaleFract\n       + positionFract * scaleFract;\n}\n\nvoid main() {\n\tfloat lineStart = 1. - lineEnd;\n\tfloat lineOffset = lineTop * 2. - 1.;\n\n\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\n\ttangent = normalize(diff * scale * viewport.zw);\n\tvec2 normal = vec2(-tangent.y, tangent.x);\n\n\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\n\t\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\n\n\t\t+ thickness * normal * .5 * lineOffset / viewport.zw;\n\n\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\n\n\tfragColor = color / 255.;\n}\n"]),frag:o(["precision highp float;\n#define GLSLIFY 1\n\nuniform sampler2D dashPattern;\n\nuniform float dashSize, pixelRatio, thickness, opacity, id;\n\nvarying vec4 fragColor;\nvarying vec2 tangent;\n\nvoid main() {\n\tfloat alpha = 1.;\n\n\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\n\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\n\n\tgl_FragColor = fragColor;\n\tgl_FragColor.a *= alpha * opacity * dash;\n}\n"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop("positionFractBuffer"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop("positionFractBuffer"),stride:8,offset:16,divisor:1},color:{buffer:t.prop("colorBuffer"),stride:4,offset:0,divisor:1}}},n));try{e=t(i({cull:{enable:!0,face:"back"},vert:o(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\nattribute vec4 aColor, bColor;\nattribute float lineEnd, lineTop;\n\nuniform vec2 scale, translate;\nuniform float thickness, pixelRatio, id, depth;\nuniform vec4 viewport;\nuniform float miterLimit, miterMode;\n\nvarying vec4 fragColor;\nvarying vec4 startCutoff, endCutoff;\nvarying vec2 tangent;\nvarying vec2 startCoord, endCoord;\nvarying float enableStartMiter, enableEndMiter;\n\nconst float REVERSE_THRESHOLD = -.875;\nconst float MIN_DIFF = 1e-6;\n\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\n// TODO: precalculate dot products, normalize things beforehead etc.\n// TODO: refactor to rectangular algorithm\n\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\n\tvec2 diff = b - a;\n\tvec2 perp = normalize(vec2(-diff.y, diff.x));\n\treturn dot(p - a, perp);\n}\n\nbool isNaN( float val ){\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\n}\n\nvoid main() {\n\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\n\n  vec2 adjustedScale;\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\n\n  vec2 scaleRatio = adjustedScale * viewport.zw;\n\tvec2 normalWidth = thickness / scaleRatio;\n\n\tfloat lineStart = 1. - lineEnd;\n\tfloat lineBot = 1. - lineTop;\n\n\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\n\n\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\n\n\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\n\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\n\n\tvec2 prevDiff = aCoord - prevCoord;\n\tvec2 currDiff = bCoord - aCoord;\n\tvec2 nextDiff = nextCoord - bCoord;\n\n\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\n\tvec2 currTangent = normalize(currDiff * scaleRatio);\n\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\n\n\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\n\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\n\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\n\n\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\n\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\n\n\t// collapsed/unidirectional segment cases\n\t// FIXME: there should be more elegant solution\n\tvec2 prevTanDiff = abs(prevTangent - currTangent);\n\tvec2 nextTanDiff = abs(nextTangent - currTangent);\n\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\n\t\tstartJoinDirection = currNormal;\n\t}\n\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\n\t\tendJoinDirection = currNormal;\n\t}\n\tif (aCoord == bCoord) {\n\t\tendJoinDirection = startJoinDirection;\n\t\tcurrNormal = prevNormal;\n\t\tcurrTangent = prevTangent;\n\t}\n\n\ttangent = currTangent;\n\n\t//calculate join shifts relative to normals\n\tfloat startJoinShift = dot(currNormal, startJoinDirection);\n\tfloat endJoinShift = dot(currNormal, endJoinDirection);\n\n\tfloat startMiterRatio = abs(1. / startJoinShift);\n\tfloat endMiterRatio = abs(1. / endJoinShift);\n\n\tvec2 startJoin = startJoinDirection * startMiterRatio;\n\tvec2 endJoin = endJoinDirection * endMiterRatio;\n\n\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\n\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\n\tstartBotJoin = -startTopJoin;\n\n\tendTopJoin = sign(endJoinShift) * endJoin * .5;\n\tendBotJoin = -endTopJoin;\n\n\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\n\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\n\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\n\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\n\n\t//miter anti-clipping\n\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\n\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\n\n\t//prevent close to reverse direction switch\n\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\n\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\n\n\tif (prevReverse) {\n\t\t//make join rectangular\n\t\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\n\t\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\n\t\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\n\t\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\n\t}\n\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\n\t\t//handle miter clipping\n\t\tbTopCoord -= normalWidth * endTopJoin;\n\t\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\n\t}\n\n\tif (nextReverse) {\n\t\t//make join rectangular\n\t\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\n\t\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\n\t\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\n\t\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\n\t}\n\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\n\t\t//handle miter clipping\n\t\taBotCoord -= normalWidth * startBotJoin;\n\t\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\n\t}\n\n\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\n\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\n\n\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\n\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\n\n\t//position is normalized 0..1 coord on the screen\n\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\n\n\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\n\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\n\n\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\n\n\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\n\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\n\n\t//bevel miter cutoffs\n\tif (miterMode == 1.) {\n\t\tif (enableStartMiter == 1.) {\n\t\t\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\n\t\t\tstartCutoff = vec4(aCoord, aCoord);\n\t\t\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\n\t\t\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\n\t\t\tstartCutoff += viewport.xyxy;\n\t\t\tstartCutoff += startMiterWidth.xyxy;\n\t\t}\n\n\t\tif (enableEndMiter == 1.) {\n\t\t\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\n\t\t\tendCutoff = vec4(bCoord, bCoord);\n\t\t\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\n\t\t\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\n\t\t\tendCutoff += viewport.xyxy;\n\t\t\tendCutoff += endMiterWidth.xyxy;\n\t\t}\n\t}\n\n\t//round miter cutoffs\n\telse if (miterMode == 2.) {\n\t\tif (enableStartMiter == 1.) {\n\t\t\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\n\t\t\tstartCutoff = vec4(aCoord, aCoord);\n\t\t\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\n\t\t\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\n\t\t\tstartCutoff += viewport.xyxy;\n\t\t\tstartCutoff += startMiterWidth.xyxy;\n\t\t}\n\n\t\tif (enableEndMiter == 1.) {\n\t\t\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\n\t\t\tendCutoff = vec4(bCoord, bCoord);\n\t\t\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\n\t\t\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\n\t\t\tendCutoff += viewport.xyxy;\n\t\t\tendCutoff += endMiterWidth.xyxy;\n\t\t}\n\t}\n}\n"]),frag:o(["precision highp float;\n#define GLSLIFY 1\n\nuniform sampler2D dashPattern;\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\n\nvarying vec4 fragColor;\nvarying vec2 tangent;\nvarying vec4 startCutoff, endCutoff;\nvarying vec2 startCoord, endCoord;\nvarying float enableStartMiter, enableEndMiter;\n\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\n\tvec2 diff = b - a;\n\tvec2 perp = normalize(vec2(-diff.y, diff.x));\n\treturn dot(p - a, perp);\n}\n\nvoid main() {\n\tfloat alpha = 1., distToStart, distToEnd;\n\tfloat cutoff = thickness * .5;\n\n\t//bevel miter\n\tif (miterMode == 1.) {\n\t\tif (enableStartMiter == 1.) {\n\t\t\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\n\t\t\tif (distToStart < -1.) {\n\t\t\t\tdiscard;\n\t\t\t\treturn;\n\t\t\t}\n\t\t\talpha *= min(max(distToStart + 1., 0.), 1.);\n\t\t}\n\n\t\tif (enableEndMiter == 1.) {\n\t\t\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\n\t\t\tif (distToEnd < -1.) {\n\t\t\t\tdiscard;\n\t\t\t\treturn;\n\t\t\t}\n\t\t\talpha *= min(max(distToEnd + 1., 0.), 1.);\n\t\t}\n\t}\n\n\t// round miter\n\telse if (miterMode == 2.) {\n\t\tif (enableStartMiter == 1.) {\n\t\t\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\n\t\t\tif (distToStart < 0.) {\n\t\t\t\tfloat radius = length(gl_FragCoord.xy - startCoord);\n\n\t\t\t\tif(radius > cutoff + .5) {\n\t\t\t\t\tdiscard;\n\t\t\t\t\treturn;\n\t\t\t\t}\n\n\t\t\t\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\n\t\t\t}\n\t\t}\n\n\t\tif (enableEndMiter == 1.) {\n\t\t\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\n\t\t\tif (distToEnd < 0.) {\n\t\t\t\tfloat radius = length(gl_FragCoord.xy - endCoord);\n\n\t\t\t\tif(radius > cutoff + .5) {\n\t\t\t\t\tdiscard;\n\t\t\t\t\treturn;\n\t\t\t\t}\n\n\t\t\t\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\n\t\t\t}\n\t\t}\n\t}\n\n\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\n\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\n\n\tgl_FragColor = fragColor;\n\tgl_FragColor.a *= alpha * opacity * dash;\n}\n"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop("colorBuffer"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop("colorBuffer"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop("positionBuffer"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=a}return{fill:t({primitive:"triangle",elements:function(t,e){return e.triangles},offset:0,vert:o(["precision highp float;\n#define GLSLIFY 1\n\nattribute vec2 position, positionFract;\n\nuniform vec4 color;\nuniform vec2 scale, scaleFract, translate, translateFract;\nuniform float pixelRatio, id;\nuniform vec4 viewport;\nuniform float opacity;\n\nvarying vec4 fragColor;\n\nconst float MAX_LINES = 256.;\n\nvoid main() {\n\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\n\n\tvec2 position = position * scale + translate\n       + positionFract * scale + translateFract\n       + position * scaleFract\n       + positionFract * scaleFract;\n\n\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\n\n\tfragColor = color / 255.;\n\tfragColor.a *= opacity;\n}\n"]),frag:o(["precision highp float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor;\n\nvoid main() {\n\tgl_FragColor = fragColor;\n}\n"]),uniforms:{scale:t.prop("scale"),color:t.prop("fill"),scaleFract:t.prop("scaleFract"),translateFract:t.prop("translateFract"),translate:t.prop("translate"),opacity:t.prop("opacity"),pixelRatio:t.context("pixelRatio"),id:t.prop("id"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop("positionBuffer"),stride:8,offset:8},positionFract:{buffer:t.prop("positionFractBuffer"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:a,miter:e}},v.defaults={dashes:null,join:"miter",miterLimit:1,thickness:10,cap:"square",color:"black",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach(function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);"number"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold?t.shaders.rect(e):"rect"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))}),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?"number"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach(function(t,h){var d=e.passes[h];if(void 0!==t)if(null!==t){if("number"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:"positions points data coords",thickness:"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth",join:"lineJoin linejoin join type mode",miterLimit:"miterlimit miterLimit",dashes:"dash dashes dasharray dash-array dashArray",color:"color colour stroke colors colours stroke-color strokeColor",fill:"fill fill-color fillColor",opacity:"alpha opacity",overlay:"overlay crease overlap intersect",close:"closed close closed-path closePath",range:"range dataBox",viewport:"viewport viewBox",hole:"holes hole hollow"}),d||(e.passes[h]=d={id:h,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:"linear",min:"linear"}),colorBuffer:r.buffer({usage:"dynamic",type:"uint8",data:new Uint8Array}),positionBuffer:r.buffer({usage:"dynamic",type:"float",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:"dynamic",type:"float",data:new Uint8Array})},t=i({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,h<v.maxLines&&(d.depth=2*(v.maxLines-1-h%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,"uint8"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var m,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),m=new Float64Array(2*y);for(var _=0;_<y;_++)m[2*_]=x[_],m[2*_+1]=b[_]}else m=l(t.positions,"float64"),y=d.count=Math.floor(m.length/2);var w=d.bounds=a(m,2);if(d.fill){for(var k=[],T={},A=0,M=0,S=0,E=d.count;M<E;M++){var L=m[2*M],C=m[2*M+1];isNaN(L)||isNaN(C)||null==L||null==C?(L=m[2*A],C=m[2*A+1],T[M]=A):A=M,k[S++]=L,k[S++]=C}for(var P=c(k,d.hole||[]),O=0,z=P.length;O<z;O++)null!=T[P[O]]&&(P[O]=T[P[O]]);d.triangles=P}var I=new Float64Array(m);u(I,2,w);var D=new Float64Array(2*y+6);d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[0]=I[2*y-4],D[1]=I[2*y-3]):(D[0]=I[2*y-2],D[1]=I[2*y-1]):(D[0]=I[0],D[1]=I[1]),D.set(I,2),d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[2*y+2]=I[2],D[2*y+3]=I[3],d.count-=1):(D[2*y+2]=I[0],D[2*y+3]=I[1],D[2*y+4]=I[2],D[2*y+5]=I[3]):(D[2*y+2]=I[2*y-2],D[2*y+3]=I[2*y-1],D[2*y+4]=I[2*y-2],D[2*y+5]=I[2*y-1]),d.positionBuffer(f(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var V,U=0;if(!t.dashes||t.dashes.length<2)U=1,V=new Uint8Array([255,255,255,255,255,255,255,255]);else{U=0;for(var q=0;q<t.dashes.length;++q)U+=t.dashes[q];V=new Uint8Array(U*v.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*v.dashMult*.5;X<Z;++X)V[H++]=G;G^=255}}d.dashLength=U,d.dashTexture({channels:1,data:V,width:V.length,height:1,mag:"linear",min:"linear"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K="transparent");var Q=new Uint8Array(4*J+4);if(Array.isArray(K)&&"number"!=typeof K[0]){for(var $=0;$<J;$++){var tt=n(K[$],"uint8");Q.set(tt,4*$)}Q.set(n(K[0],"uint8"),4*J)}else for(var et=n(K,"uint8"),rt=0;rt<J+1;rt++)Q.set(et,4*rt);d.colorBuffer({usage:"dynamic",type:"uint8",data:Q})}}else e.passes[h]=null}),t.length<this.passes.length){for(var h=t.length;h<this.passes.length;h++){var d=e.passes[h];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var m=[],y=0;y<this.passes.length;y++)null!==e.passes[y]&&m.push(e.passes[y]);return this.passes=m,this}},v.prototype.destroy=function(){return this.passes.forEach(function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()}),this.passes.length=0,this}},{"array-bounds":67,"array-normalize":493,"color-normalize":121,earcut:172,"es6-weak-map":494,"flatten-vertex-data":229,glslify:410,"object-assign":455,"parse-rect":460,"pick-by-alias":466,"to-float32":536}],493:[function(t,e,r){"use strict";var n=t("array-bounds");e.exports=function(t,e,r){if(!t||null==t.length)throw Error("Argument should be an array");null==e&&(e=1);null==r&&(r=n(t,e));for(var a=0;a<e;a++){var i=r[e+a],o=r[a],s=a,l=t.length;if(i===1/0&&o===-1/0)for(s=a;s<l;s+=e)t[s]=t[s]===i?1:t[s]===o?0:.5;else if(i===1/0)for(s=a;s<l;s+=e)t[s]=t[s]===i?1:0;else if(o===-1/0)for(s=a;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=i-o;for(s=a;s<l;s+=e)isNaN(t[s])||(t[s]=0===c?.5:(t[s]-o)/c)}}return t}},{"array-bounds":67}],494:[function(t,e,r){arguments[4][319][0].apply(r,arguments)},{"./is-implemented":495,"./polyfill":497,dup:319}],495:[function(t,e,r){arguments[4][320][0].apply(r,arguments)},{dup:320}],496:[function(t,e,r){arguments[4][321][0].apply(r,arguments)},{dup:321}],497:[function(t,e,r){arguments[4][322][0].apply(r,arguments)},{"./is-native-implemented":496,d:152,dup:322,"es5-ext/object/is-value":196,"es5-ext/object/set-prototype-of":202,"es5-ext/object/valid-object":206,"es5-ext/object/valid-value":207,"es5-ext/string/random-uniq":212,"es6-iterator/for-of":214,"es6-iterator/get":215,"es6-symbol":221}],498:[function(t,e,r){"use strict";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=[],n=!0,a=!1,i=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){a=!0,i=t}finally{try{n||null==s.return||s.return()}finally{if(a)throw i}}return r}(t,e)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance")}()}function a(t){return function(t){if(Array.isArray(t)){for(var e=0,r=new Array(t.length);e<t.length;e++)r[e]=t[e];return r}}(t)||function(t){if(Symbol.iterator in Object(t)||"[object Arguments]"===Object.prototype.toString.call(t))return Array.from(t)}(t)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance")}()}var i=t("color-normalize"),o=t("array-bounds"),s=t("color-id"),l=t("point-cluster"),c=t("object-assign"),u=t("glslify"),h=t("pick-by-alias"),f=t("update-diff"),p=t("flatten-vertex-data"),d=t("is-iexplorer"),g=t("to-float32"),v=t("parse-rect"),m=y;function y(t,e){var r=this;if(!(this instanceof y))return new y(t,e);"function"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,a=(t=e.regl)._gl,i=[];this.tooManyColors=d,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:"uint8",format:"rgba",wrapS:"clamp",wrapT:"clamp",mag:"nearest",min:"nearest"}),c(this,{regl:t,gl:a,groups:[],markerCache:[null],markerTextures:[null],palette:i,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:a.canvas}),this.update(e);var o={uniforms:{pixelRatio:t.context("pixelRatio"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop("scale"),scaleFract:t.prop("scaleFract"),translate:t.prop("translate"),translateFract:t.prop("translateFract"),opacity:t.prop("opacity"),marker:t.prop("markerTexture")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?i.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?i.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:"src alpha",dstRGB:"one minus src alpha",srcAlpha:"one minus dst alpha",dstAlpha:"one"}},scissor:{enable:!0,box:t.prop("viewport")},viewport:t.prop("viewport"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop("elements"),count:t.prop("count"),offset:t.prop("offset"),primitive:"points"},s=c({},o);s.frag=u(["precision highp float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor, fragBorderColor;\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\n\nuniform sampler2D marker;\nuniform float pixelRatio, opacity;\n\nfloat smoothStep(float x, float y) {\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\n}\n\nvoid main() {\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\n\n  // max-distance alpha\n  if (dist < 0.003) discard;\n\n  // null-border case\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\n  }\n  else {\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\n\n    vec4 color = fragBorderColor;\n    color.a *= borderColorAmt;\n    color = mix(color, fragColor, colorAmt);\n    color.a *= opacity;\n\n    gl_FragColor = color;\n  }\n\n}\n"]),s.vert=u(["precision highp float;\n#define GLSLIFY 1\n\nattribute float x, y, xFract, yFract;\nattribute float size, borderSize;\nattribute vec4 colorId, borderColorId;\nattribute float isActive;\n\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\nuniform float pixelRatio;\nuniform sampler2D palette;\n\nconst float maxSize = 100.;\nconst float borderLevel = .5;\n\nvarying vec4 fragColor, fragBorderColor;\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\n\nbool isDirect = (paletteSize.x < 1.);\n\nvec4 getColor(vec4 id) {\n  return isDirect ? id / 255. : texture2D(palette,\n    vec2(\n      (id.x + .5) / paletteSize.x,\n      (id.y + .5) / paletteSize.y\n    )\n  );\n}\n\nvoid main() {\n  if (isActive == 0.) return;\n\n  vec2 position = vec2(x, y);\n  vec2 positionFract = vec2(xFract, yFract);\n\n  vec4 color = getColor(colorId);\n  vec4 borderColor = getColor(borderColorId);\n\n  float size = size * maxSize / 255.;\n  float borderSize = borderSize * maxSize / 255.;\n\n  gl_PointSize = 2. * size * pixelRatio;\n  fragPointSize = size * pixelRatio;\n\n  vec2 pos = (position + translate) * scale\n      + (positionFract + translateFract) * scale\n      + (position + translate) * scaleFract\n      + (positionFract + translateFract) * scaleFract;\n\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\n\n  fragColor = color;\n  fragBorderColor = borderColor;\n  fragWidth = 1. / gl_PointSize;\n\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\n}"]),this.drawMarker=t(s);var l=c({},o);l.frag=u(["precision highp float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor, fragBorderColor;\n\nuniform float opacity;\nvarying float fragBorderRadius, fragWidth;\n\nfloat smoothStep(float edge0, float edge1, float x) {\n\tfloat t;\n\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\n\treturn t * t * (3.0 - 2.0 * t);\n}\n\nvoid main() {\n\tfloat radius, alpha = 1.0, delta = fragWidth;\n\n\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\n\n\tif (radius > 1.0 + delta) {\n\t\tdiscard;\n\t}\n\n\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\n\n\tfloat borderRadius = fragBorderRadius;\n\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\n\tvec4 color = mix(fragColor, fragBorderColor, ratio);\n\tcolor.a *= alpha * opacity;\n\tgl_FragColor = color;\n}\n"]),l.vert=u(["precision highp float;\n#define GLSLIFY 1\n\nattribute float x, y, xFract, yFract;\nattribute float size, borderSize;\nattribute vec4 colorId, borderColorId;\nattribute float isActive;\n\nuniform vec2 scale, scaleFract, translate, translateFract;\nuniform float pixelRatio;\nuniform sampler2D palette;\nuniform vec2 paletteSize;\n\nconst float maxSize = 100.;\n\nvarying vec4 fragColor, fragBorderColor;\nvarying float fragBorderRadius, fragWidth;\n\nbool isDirect = (paletteSize.x < 1.);\n\nvec4 getColor(vec4 id) {\n  return isDirect ? id / 255. : texture2D(palette,\n    vec2(\n      (id.x + .5) / paletteSize.x,\n      (id.y + .5) / paletteSize.y\n    )\n  );\n}\n\nvoid main() {\n  // ignore inactive points\n  if (isActive == 0.) return;\n\n  vec2 position = vec2(x, y);\n  vec2 positionFract = vec2(xFract, yFract);\n\n  vec4 color = getColor(colorId);\n  vec4 borderColor = getColor(borderColorId);\n\n  float size = size * maxSize / 255.;\n  float borderSize = borderSize * maxSize / 255.;\n\n  gl_PointSize = (size + borderSize) * pixelRatio;\n\n  vec2 pos = (position + translate) * scale\n      + (positionFract + translateFract) * scale\n      + (position + translate) * scaleFract\n      + (positionFract + translateFract) * scaleFract;\n\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\n\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\n  fragColor = color;\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\n  fragWidth = 1. / gl_PointSize;\n}\n"]),d&&(l.frag=l.frag.replace("smoothstep","smoothStep"),s.frag=s.frag.replace("smoothstep","smoothStep")),this.drawCircle=t(l)}y.defaults={color:"black",borderColor:"transparent",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},y.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},y.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var a=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var i=0;i<r.length;i++)this.drawItem(i,r[i]);else a.forEach(function(e,r){t.drawItem(r)});return this},y.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if("number"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var i=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&i.push.apply(i,a(this.getMarkerDrawOptions(o,n,e)));i.length&&this.drawMarker(i)}},y.prototype.getMarkerDrawOptions=function(t,e,r){var a=e.range,i=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,u=e.count;this.regl;if(!i)return r?[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var h=[],f=i.range(a,{lod:!0,px:[(a[2]-a[0])/o.width,(a[3]-a[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(u),g=0;g<r.length;g++){var v=r[g];d[v]=p?p[v]:1}l.subdata(d)}for(var m=f.length;m--;){var y=n(f[m],2),x=y[0],b=y[1];h.push(c({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return h},y.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var a=this.groups,i=this.gl,s=this.regl,u=this.maxSize,d=this.maxColors,m=this.palette;this.groups=a=r.map(function(e,r){var n=a[r];if(void 0===e)return n;null===e?e={positions:null}:"function"==typeof e?e={ondraw:e}:"number"==typeof e[0]&&(e={positions:e}),null===(e=h(e,{positions:"positions data points",snap:"snap cluster lod tree",size:"sizes size radius",borderSize:"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline",color:"colors color fill fill-color fillColor",borderColor:"borderColors borderColor stroke stroke-color strokeColor",marker:"markers marker shape",range:"range dataBox databox",viewport:"viewport viewPort viewBox viewbox",opacity:"opacity alpha transparency",bounds:"bound bounds boundaries limits",tooManyColors:"tooManyColors palette paletteMode optimizePalette enablePalette"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(a[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:s.buffer({data:new Uint8Array(0),usage:"stream",type:"uint8"}),sizeBuffer:s.buffer({data:new Uint8Array(0),usage:"dynamic",type:"uint8"}),colorBuffer:s.buffer({data:new Uint8Array(0),usage:"dynamic",type:"uint8"}),positionBuffer:s.buffer({data:new Uint8Array(0),usage:"dynamic",type:"float"}),positionFractBuffer:s.buffer({data:new Uint8Array(0),usage:"dynamic",type:"float"})},e=c({},y.defaults,e)),!e.positions||"marker"in e||(e.marker=n.marker,delete n.marker),!e.marker||"positions"in e||(e.positions=n.positions,delete n.positions);var x=0,b=0;if(f(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=y.defaults.size),x+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=y.defaults.borderSize),x+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=y.defaults.color),e=t.updateColor(e),b++,e},borderColor:function(e,r){return null==e&&(e=y.defaults.borderColor),e=t.updateColor(e),b++,e},bounds:function(t,e,r){return"range"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,a=e.positionBuffer,i=e.positionFractBuffer,c=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:s.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:s.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=p(t,"float64");var u=e.count=Math.floor(t.length/2),h=e.bounds=u?o(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=l(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:"points",usage:"static",data:e.tree,type:"uint32"};e.elements?e.elements(f):e.elements=s.elements(f)}return a({data:g.float(t),usage:"dynamic"}),i({data:g.fract(t),usage:"dynamic"}),c({data:new Uint8Array(u),type:"uint8",usage:"stream"}),t}},{marker:function(e,r,n){var a=r.activation;if(a.forEach(function(t){return t&&t.destroy&&t.destroy()}),a.length=0,e&&"number"!=typeof e[0]){for(var i=[],o=0,l=Math.min(e.length,r.count);o<l;o++){var c=t.addMarker(e[o]);i[c]||(i[c]=new Uint8Array(r.count)),i[c][o]=1}for(var u=0;u<i.length;u++)if(i[u]){var h={data:i[u],type:"uint8",usage:"static"};a[u]?a[u](h):a[u]=s.buffer(h),a[u].data=i[u]}}else{a[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return v(t||[i.drawingBufferWidth,i.drawingBufferHeight])}}]),x){var _=n,w=_.count,k=_.size,T=_.borderSize,A=_.sizeBuffer,M=new Uint8Array(2*w);if(k.length||T.length)for(var S=0;S<w;S++)M[2*S]=Math.round(255*(null==k[S]?k:k[S])/u),M[2*S+1]=Math.round(255*(null==T[S]?T:T[S])/u);A({data:M,usage:"dynamic"})}if(b){var E,L=n,C=L.count,P=L.color,O=L.borderColor,z=L.colorBuffer;if(t.tooManyColors){if(P.length||O.length){E=new Uint8Array(8*C);for(var I=0;I<C;I++){var D=P[I];E[8*I]=m[4*D],E[8*I+1]=m[4*D+1],E[8*I+2]=m[4*D+2],E[8*I+3]=m[4*D+3];var R=O[I];E[8*I+4]=m[4*R],E[8*I+5]=m[4*R+1],E[8*I+6]=m[4*R+2],E[8*I+7]=m[4*R+3]}}}else if(P.length||O.length){E=new Uint8Array(4*C+2);for(var F=0;F<C;F++)null!=P[F]&&(E[4*F]=P[F]%d,E[4*F+1]=Math.floor(P[F]/d)),null!=O[F]&&(E[4*F+2]=O[F]%d,E[4*F+3]=Math.floor(O[F]/d))}z({data:E||new Uint8Array(0),type:"uint8",usage:"dynamic"})}return n})}},y.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,a=this.markerCache,i=null==t?0:a.indexOf(t);if(i>=0)return i;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return i=r.length,a.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:"linear",min:"linear"})),i},y.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var a=[];if("number"==typeof t[0]){var o=[];if(Array.isArray(t))for(var l=0;l<t.length;l+=4)o.push(t.slice(l,l+4));else for(var c=0;c<t.length;c+=4)o.push(t.subarray(c,c+4));t=o}for(var u=0;u<t.length;u++){var h=t[u];h=i(h,"uint8");var f=s(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}a[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===a.length?a[0]:a},y.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var a=.25*(t=t.slice()).length%e;a<n*e;a++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},y.prototype.destroy=function(){return this.groups.forEach(function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach(function(t){return t&&t.destroy&&t.destroy()}),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()}),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach(function(t){return t&&t.destroy&&t.destroy()}),this};var x=t("object-assign");e.exports=function(t,e){var r=new m(t,e),n=r.render.bind(r);return x(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{"array-bounds":67,"color-id":119,"color-normalize":121,"flatten-vertex-data":229,glslify:410,"is-iexplorer":420,"object-assign":455,"parse-rect":460,"pick-by-alias":466,"point-cluster":470,"to-float32":536,"update-diff":547}],499:[function(t,e,r){"use strict";var n=t("regl-scatter2d"),a=t("pick-by-alias"),i=t("array-bounds"),o=t("raf"),s=t("array-range"),l=t("parse-rect"),c=t("flatten-vertex-data");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,a,i,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],a=s[3]):s.length?(n=s[0],a=s[1]):(s.x,n=s.y,s.x+s.width,a=s.y+s.height),l.length>2?(i=l[0],o=l[2],l[1],l[3]):l.length?(i=l[0],o=l[1]):(i=l.x,l.y,o=l.x+l.width,l.y+l.height),[i,n,o,a]}function p(t){if("number"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o(function(){e.draw(),e.dirty=!0,e.planned=null})):(this.draw(),this.dirty=!0,o(function(){e.dirty=!1})),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var a=[],i=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)a.push(this.passes[l[c]]);s.passOffset=i,i+=s.passes.length}return(t=this.scatter).update.apply(t,a),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=a(e,{data:"data items columns rows values dimensions samples x",snap:"snap cluster",size:"sizes size radius",color:"colors color fill fill-color fillColor",opacity:"opacity alpha transparency opaque",borderSize:"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline",borderColor:"borderColors borderColor bordercolor stroke stroke-color strokeColor",marker:"markers marker shape",range:"range ranges databox dataBox",viewport:"viewport viewBox viewbox",domain:"domain domains area areas",padding:"pad padding paddings pads margin margins",transpose:"transpose transposed",diagonal:"diagonal diag showDiagonal",upper:"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf",lower:"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:"dynamic",type:"float",data:new Uint8Array}),color:"black",marker:null,size:12,borderColor:"transparent",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=i(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&"number"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&"number"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,v=s.count,m=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=m/g,w=y/g;s.passes=[];for(var k=0;k<g;k++)for(var T=0;T<g;T++)if((s.diagonal||T!==k)&&(s.upper||!(k>T))&&(s.lower||!(k<T))){var A=h(s.id,k,T),M=this.passes[A]||(this.passes[A]={});if(o.data&&(o.transpose?M.positions={x:{buffer:s.buffer,offset:T,count:v,stride:g},y:{buffer:s.buffer,offset:k,count:v,stride:g}}:M.positions={x:{buffer:s.buffer,offset:T*v,count:v},y:{buffer:s.buffer,offset:k*v,count:v}},M.bounds=f(s.bounds,k,T)),o.domain||o.viewport||o.data){var S=d?f(s.padding,k,T):s.padding;if(s.domain){var E=f(s.domain,k,T),L=E[0],C=E[1],P=E[2],O=E[3];M.viewport=[x+L*m+S[0],b+C*y+S[1],x+P*m-S[2],b+O*y-S[3]]}else M.viewport=[x+T*_+_*S[0],b+k*w+w*S[1],x+(T+1)*_-_*S[2],b+(k+1)*w-w*S[3]]}o.color&&(M.color=s.color),o.size&&(M.size=s.size),o.marker&&(M.marker=s.marker),o.borderSize&&(M.borderSize=s.borderSize),o.borderColor&&(M.borderColor=s.borderColor),o.opacity&&(M.opacity=s.opacity),o.range&&(M.range=n?f(s.range,k,T):s.range||M.bounds),s.passes.push(A)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],a=0;a<e.length;a++)if("number"==typeof e[a]){var i=this.traces[e[a]],o=i.passes,l=i.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[a].length){var c=e[a],u=this.traces[a],h=u.passes,f=u.passOffset;h=h.map(function(t,e){n[f+e]=c})}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach(function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()}),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{"array-bounds":67,"array-range":68,"flatten-vertex-data":229,"parse-rect":460,"pick-by-alias":466,raf:485,"regl-scatter2d":498}],500:[function(t,e,r){var n,a;n=this,a=function(){function t(t,e){this.id=V++,this.type=t,this.data=e}function e(t){return"["+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('"'===r||"'"===r))return['"'+e.substr(1,e.length-2).replace(/\\/g,"\\\\").replace(/"/g,'\\"')+'"'];if(r=/\[(false|true|null|\d+|'[^']*'|"[^"]*")\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(".")).length)return['"'+e.replace(/\\/g,"\\\\").replace(/"/g,'\\"')+'"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join("][")+"]"}function r(t){return"string"==typeof t?t.split():t}function n(t){return"string"==typeof t?document.querySelector(t):t}function a(t){var e,a,i,o,s=t||{};t={};var l=[],c=[],u="undefined"==typeof window?1:window.devicePixelRatio,h=!1,f=function(t){},p=function(){};if("string"==typeof s?e=document.querySelector(s):"object"==typeof s&&("string"==typeof s.nodeName&&"function"==typeof s.appendChild&&"function"==typeof s.getBoundingClientRect?e=s:"function"==typeof s.drawArrays||"function"==typeof s.drawElements?i=(o=s).canvas:("gl"in s?o=s.gl:"canvas"in s?i=n(s.canvas):"container"in s&&(a=n(s.container)),"attributes"in s&&(t=s.attributes),"extensions"in s&&(l=r(s.extensions)),"optionalExtensions"in s&&(c=r(s.optionalExtensions)),"onDone"in s&&(f=s.onDone),"profile"in s&&(h=!!s.profile),"pixelRatio"in s&&(u=+s.pixelRatio))),e&&("canvas"===e.nodeName.toLowerCase()?i=e:a=e),!o){if(!i){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),a.width=r*e,a.height=r*n,j(a.style,{width:e+"px",height:n+"px"})}var a=document.createElement("canvas");return j(a.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(a),t===document.body&&(a.style.position="absolute",j(t.style,{margin:0,padding:0})),window.addEventListener("resize",n,!1),n(),{canvas:a,onDestroy:function(){window.removeEventListener("resize",n),t.removeChild(a)}}}(a||document.body,0,u)))return null;i=e.canvas,p=e.onDestroy}o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r("webgl")||r("experimental-webgl")||r("webgl-experimental")}(i,t)}return o?{gl:o,canvas:i,container:a,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,onDone:f,onDestroy:p}:(p(),f("webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org"),null)}function i(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=i(8,function(){return[]});return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&"object"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&"number"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||W(t.data))}function c(t,e,r,n,a,i){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)a[i++]=c[u]}function u(t){return 0|J[Object.prototype.toString.call(t)]}function h(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function f(t,e,r,n,a,i,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[a*l+i*c+o]}function p(t,e,r,n){function a(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function i(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,a,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){a=tt(e);for(var s=n=1;s<a.length;++s)n*=a[s];t.dimension=n,i(t,e=$(e,a,t.dtype),r),o?t.persistentData=e:G.freeType(e)}else"number"==typeof e[0]?(t.dimension=a,h(a=G.allocType(t.dtype,e.length),e),i(t,a,r),o?t.persistentData=a:G.freeType(a)):W(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,i(t,e=$(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:G.freeType(e))}else if(W(e))t.dtype=n||u(e),t.dimension=a,i(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){a=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,v=0;1===a.length?(p=a[0],d=1,g=c[0],v=0):2===a.length&&(p=a[0],d=a[1],g=c[0],v=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,f(a=G.allocType(t.dtype,p*d),e.data,p,d,g,v,s),i(t,a,r),o?t.persistentData=a:G.freeType(a)}}function s(r){e.bufferCount--;for(var a=0;a<n.state.length;++a){var i=n.state[a];i.buffer===r&&(t.disableVertexAttribArray(a),i.buffer=null)}t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};a.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},a.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach(function(e){t+=p[e].stats.size}),t}),{create:function(n,i,c,d){function g(e){var n=35044,a=null,i=0,s=0,c=1;return Array.isArray(e)||W(e)||l(e)?a=e:"number"==typeof e?i=0|e:e&&("data"in e&&(a=e.data),"usage"in e&&(n=Q[e.usage]),"type"in e&&(s=K[e.type]),"dimension"in e&&(c=0|e.dimension),"length"in e&&(i=0|e.length)),v.bind(),a?o(v,a,n,s,c,d):(i&&t.bufferData(v.type,i,n),v.dtype=s||5121,v.usage=n,v.dimension=c,v.byteLength=i),r.profile&&(v.stats.size=v.byteLength*et[v.dtype]),g}e.bufferCount++;var v=new a(i);return p[v.id]=v,c||g(n),g._reglType="buffer",g._buffer=v,g.subdata=function(e,r){var n,a=0|(r||0);if(v.bind(),W(e))t.bufferSubData(v.type,a,e);else if(Array.isArray(e)){if(0<e.length)if("number"==typeof e[0]){var i=G.allocType(v.dtype,e.length);h(i,e),t.bufferSubData(v.type,a,i),G.freeType(i)}else(Array.isArray(e[0])||W(e[0]))&&(n=tt(e),i=$(e,n,v.dtype),t.bufferSubData(v.type,a,i),G.freeType(i))}else if(l(e)){n=e.shape;var o=e.stride,s=i=0,c=0,p=0;1===n.length?(i=n[0],s=1,c=o[0],p=0):2===n.length&&(i=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?v.dtype:u(e.data),f(n=G.allocType(n,i*s),e.data,i,s,c,p,e.offset),t.bufferSubData(v.type,a,n),G.freeType(n)}return g},r.profile&&(g.stats=v.stats),g.destroy=function(){s(v)},g},createStream:function(t,e){var r=d.pop();return r||(r=new a(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof a?t._buffer:null},restore:function(){X(p).forEach(function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)})},_initBuffer:o}}function d(t,e,r,n){function a(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function i(n,a,i,o,s,c,u){if(n.buffer.bind(),a){var h=u;u||W(a)&&(!l(a)||W(a.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,a,i,h,3)}else t.bufferData(34963,c,i),n.buffer.dtype=h||5121,n.buffer.usage=i,n.buffer.dimension=3,n.buffer.byteLength=c;if(h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(a=s)&&(a=n.buffer.byteLength,5123===h?a>>=1:5125===h&&(a>>=2)),n.vertCount=a,a=o,0>o&&(a=4,1===(o=n.buffer.dimension)&&(a=0),2===o&&(a=1),3===o&&(a=4)),n.primType=a}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),a.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if("number"==typeof t)c(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,a=-1,o=0,f=0;Array.isArray(t)||W(t)||l(t)?e=t:("data"in t&&(e=t.data),"usage"in t&&(r=Q[t.usage]),"primitive"in t&&(n=rt[t.primitive]),"count"in t&&(a=0|t.count),"type"in t&&(f=u[t.type]),"length"in t?o=0|t.length:(o=a,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),i(h,e,r,n,a,o,f)}else c(),h.primType=4,h.vertCount=0,h.type=5121;return s}var c=r.create(null,34963,!0),h=new a(c._buffer);return n.elementsCount++,s(t),s._reglType="elements",s._elements=h,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new a(r.create(null,34963,!0,!1)._buffer)),i(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return"function"==typeof t&&t._elements instanceof a?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=G.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{nt[0]=t[r];var n=(i=at[0])>>>31<<15,a=(i<<1>>>24)-127,i=i>>13&1023;e[r]=-24>a?n:-14>a?n+(i+1024>>-14-a):15<a?n+31744:n+(a+15<<10)+i}return e}function v(t){return Array.isArray(t)||W(t)}function m(t){return"[object "+t+"]"}function y(t){return Array.isArray(t)&&(0===t.length||"number"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=pt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),G.freeType(e)):t.data=e}function k(t,e,r,n,a,i){if(t="undefined"!=typeof gt[t]?gt[t]:st[t]*dt[e],i&&(t*=6),a){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function T(t,e,r,n,a,i,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if("object"==typeof e&&e){"premultiplyAlpha"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),"flipY"in e&&(t.flipY=e.flipY),"alignment"in e&&(t.unpackAlignment=e.alignment),"colorSpace"in e&&(t.colorSpace=q[e.colorSpace]),"type"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,a=t.channels,i=!1;"shape"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(a=e.shape[2],i=!0)):("radius"in e&&(r=n=e.radius),"width"in e&&(r=e.width),"height"in e&&(n=e.height),"channels"in e&&(a=e.channels,i=!0)),t.width=0|r,t.height=0|n,t.channels=0|a,r=!1,"format"in e&&(r=e.format,n=t.internalformat=Y[r],t.format=pt[n],r in H&&!("type"in e)&&(t.type=H[r]),r in K&&(t.compressed=!0),r=!0),!i&&r?t.channels=st[t.format]:i&&!r&&t.channels!==ot[t.format]&&(t.format=t.internalformat=ot[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),"x"in e&&(t.xOffset=0|e.x),"y"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=a.viewportWidth,i=a.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||i-t.yOffset,t.needsCopy=!0}else if(r){if(W(r))t.channels=t.channels||4,t.data=r,"type"in e||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,i=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(i=G.allocType(t.type,i)).set(n),t.data=i;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(n)]);i=r.shape;var o,s,c,h,f=r.stride;3===i.length?(c=i[2],h=f[2]):h=c=1,o=i[0],s=i[1],i=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=ot[c],t.needsFree=!0,o=h,r=r.offset,c=t.width,h=t.height,s=t.channels;for(var p=G.allocType(36193===t.type?5126:t.type,c*h*s),d=0,m=0;m<h;++m)for(var k=0;k<c;++k)for(var T=0;T<s;++T)p[d++]=n[i*k+f*m+o*T+r];w(t,p)}else if(b(r)===lt||b(r)===ct)b(r)===lt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ut)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,i=t.height||r.length,f=t.channels,f=v(r[0][0])?f||r[0][0].length:f||1,o=Z.shape(r),c=1,h=0;h<o.length;++h)c*=o[h];c=G.allocType(36193===t.type?5126:t.type,c),Z.flatten(r,o,"",c),w(t,c),t.alignment=1,t.width=n,t.height=i,t.channels=f,t.format=t.internalformat=ot[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,a,i,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,a,i,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,a,i,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,a,i,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,a,i,p,d,u,f,l)}function m(){return dt.pop()||new f}function T(t){t.needsFree&&G.freeType(t.data),f.call(t),dt.push(t)}function A(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function M(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,a=0;a<n.length;++a)c(r=t.images[a]=m(),t),r.width>>=a,r.height>>=a,p(r,n[a]),t.mipmask|=1<<a;else c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var a=e.images,i=0;i<a.length&&a[i];++i){var o=a[i],s=r,l=i,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,g=o.width,v=o.height,m=o.channels;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,g,v,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,v,0)):((o=!u)&&(u=G.zero.allocType(d,g*v*m)),t.texImage2D(s,l,p,g,v,0,p,d,u),o&&u&&G.zero.freeType(u))}}function L(){var t=gt.pop()||new A;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function C(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&T(e[r]),e[r]=null;gt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function O(t,e){"min"in e&&(t.minFilter=U[e.min],0<=it.indexOf(t.minFilter)&&!("faces"in e)&&(t.genMipmaps=!0)),"mag"in e&&(t.magFilter=V[e.mag]);var r=t.wrapS,n=t.wrapT;if("wrap"in e){var a=e.wrap;"string"==typeof a?r=n=N[a]:Array.isArray(a)&&(r=N[a[0]],n=N[a[1]])}else"wrapS"in e&&(r=N[e.wrapS]),"wrapT"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,"anisotropic"in e&&(t.anisotropic=e.anisotropic),"mipmap"in e){switch(r=!1,typeof e.mipmap){case"string":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case"boolean":r=t.genMipmaps=e.mipmap;break;case"object":t.genMipmaps=!1,r=!0}!r||"min"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function I(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=xt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,a=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(a,null),xt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete mt[e.id],i.textureCount--}var B={"don't care":4352,"dont care":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},V={nearest:9728,linear:9729},U=j({mipmap:9987,"nearest mipmap nearest":9984,"linear mipmap nearest":9985,"nearest mipmap linear":9986,"linear mipmap linear":9987},V),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,"rgb5 a1":32820},Y={alpha:6406,luminance:6409,"luminance alpha":6410,rgb:6407,rgba:6408,rgba4:32854,"rgb5 a1":32855,rgb565:36194},K={};e.ext_srgb&&(Y.srgb=35904,Y.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H["half float"]=36193),e.webgl_depth_texture&&(j(Y,{depth:6402,"depth stencil":34041}),j(H,{uint16:5123,uint32:5125,"depth stencil":34042})),e.webgl_compressed_texture_s3tc&&j(K,{"rgb s3tc dxt1":33776,"rgba s3tc dxt1":33777,"rgba s3tc dxt3":33778,"rgba s3tc dxt5":33779}),e.webgl_compressed_texture_atc&&j(K,{"rgb atc":35986,"rgba atc explicit alpha":35987,"rgba atc interpolated alpha":34798}),e.webgl_compressed_texture_pvrtc&&j(K,{"rgb pvrtc 4bppv1":35840,"rgb pvrtc 2bppv1":35841,"rgba pvrtc 4bppv1":35842,"rgba pvrtc 2bppv1":35843}),e.webgl_compressed_texture_etc1&&(K["rgb etc1"]=36196);var Q=Array.prototype.slice.call(t.getParameter(34467));Object.keys(K).forEach(function(t){var e=K[t];0<=Q.indexOf(e)&&(Y[t]=e)});var $=Object.keys(Y);r.textureFormats=$;var tt=[];Object.keys(Y).forEach(function(t){tt[Y[t]]=t});var et=[];Object.keys(H).forEach(function(t){et[H[t]]=t});var rt=[];Object.keys(V).forEach(function(t){rt[V[t]]=t});var nt=[];Object.keys(U).forEach(function(t){nt[U[t]]=t});var at=[];Object.keys(N).forEach(function(t){at[N[t]]=t});var pt=$.reduce(function(t,e){var r=Y[e];return 6409===r||6406===r||6409===r||6410===r||6402===r||34041===r?t[r]=r:32855===r||0<=e.indexOf("rgba")?t[r]=6408:t[r]=6407,t},{}),dt=[],gt=[],vt=0,mt={},yt=r.maxTextureUnits,xt=Array(yt).map(function(){return null});return j(I.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<yt;++r){var n=xt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}xt[r]=this,e=r;break}o.profile&&i.maxTextureUnits<e+1&&(i.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(i.getTotalTextureSize=function(){var t=0;return Object.keys(mt).forEach(function(e){t+=mt[e].stats.size}),t}),{create2D:function(e,r){function n(t,e){var r=a.texInfo;P.call(r);var i=L();return"number"==typeof t?M(i,0|t,"number"==typeof e?0|e:0|t):t?(O(r,t),S(i,t)):M(i,1,1),r.genMipmaps&&(i.mipmask=(i.width<<1)-1),a.mipmask=i.mipmask,c(a,i),a.internalformat=i.internalformat,n.width=i.width,n.height=i.height,D(a),E(i,3553),z(r,3553),R(),C(i),o.profile&&(a.stats.size=k(a.internalformat,a.type,i.width,i.height,r.genMipmaps,!1)),n.format=tt[a.internalformat],n.type=et[a.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=at[r.wrapS],n.wrapT=at[r.wrapT],n}var a=new I(3553);return mt[a.id]=a,i.textureCount++,n(e,r),n.subimage=function(t,e,r,i){e|=0,r|=0,i|=0;var o=m();return c(o,a),o.width=0,o.height=0,p(o,t),o.width=o.width||(a.width>>i)-e,o.height=o.height||(a.height>>i)-r,D(a),d(o,3553,e,r,i),R(),T(o),n},n.resize=function(e,r){var i=0|e,s=0|r||i;if(i===a.width&&s===a.height)return n;n.width=a.width=i,n.height=a.height=s,D(a);for(var l,c=a.channels,u=a.type,h=0;a.mipmask>>h;++h){var f=i>>h,p=s>>h;if(!f||!p)break;l=G.zero.allocType(u,f*p*c),t.texImage2D(3553,h,a.format,f,p,0,a.format,a.type,l),l&&G.zero.freeType(l)}return R(),o.profile&&(a.stats.size=k(a.internalformat,a.type,i,s,!1,!1)),n},n._reglType="texture2d",n._texture=a,o.profile&&(n.stats=a.stats),n.destroy=function(){a.decRef()},n},createCube:function(e,r,n,a,s,l){function h(t,e,r,n,a,i){var s,l=f.texInfo;for(P.call(l),s=0;6>s;++s)g[s]=L();if("number"!=typeof t&&t){if("object"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],a),S(g[5],i);else if(O(l,t),u(f,t),"faces"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],f),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)M(g[s],t,t);for(c(f,g[0]),f.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,f.internalformat=g[0].internalformat,h.width=g[0].width,h.height=g[0].height,D(f),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,l.genMipmaps,!0)),h.format=tt[f.internalformat],h.type=et[f.type],h.mag=rt[l.magFilter],h.min=nt[l.minFilter],h.wrapS=at[l.wrapS],h.wrapT=at[l.wrapT],s=0;6>s;++s)C(g[s]);return h}var f=new I(34067);mt[f.id]=f,i.cubeCount++;var g=Array(6);return h(e,r,n,a,s,l),h.subimage=function(t,e,r,n,a){r|=0,n|=0,a|=0;var i=m();return c(i,f),i.width=0,i.height=0,p(i,e),i.width=i.width||(f.width>>a)-r,i.height=i.height||(f.height>>a)-n,D(f),d(i,34069+t,r,n,a),R(),T(i),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType="textureCube",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<yt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),xt[e]=null;X(mt).forEach(F),i.cubeCount=0,i.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<yt;++e){var r=xt[e];r&&(r.bindCount=0,r.unit=-1,xt[e]=null)}X(mt).forEach(function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)})}}}function A(t,e,r,n,a,i){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,a=t;return"object"==typeof t&&(a=t.data,"target"in t&&(e=0|t.target)),"texture2d"===(t=a._reglType)?r=a:"textureCube"===t?r=a:"renderbuffer"===t&&(n=a,e=36161),new o(e,r,n)}function h(t,e,r,i,s){return r?((t=n.create2D({width:t,height:e,format:i,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=a.create({width:t,height:e,format:i}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=k++,T[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function v(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,i.framebufferCount--,delete T[e.id]}function m(e){var n;t.bindFramebuffer(36160,e.framebuffer);var a=e.colorAttachments;for(n=0;n<a.length;++n)c(36064+n,a[n]);for(n=a.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var a,i=0,o=0,s=!0,c=!0;a=null;var p=!0,d="rgba",v="uint8",y=1,x=null,w=null,k=null,T=!1;"number"==typeof t?(i=0|t,o=0|e||i):t?("shape"in t?(i=(o=t.shape)[0],o=o[1]):("radius"in t&&(i=o=t.radius),"width"in t&&(i=t.width),"height"in t&&(o=t.height)),("color"in t||"colors"in t)&&(a=t.color||t.colors,Array.isArray(a)),a||("colorCount"in t&&(y=0|t.colorCount),"colorTexture"in t&&(p=!!t.colorTexture,d="rgba4"),"colorType"in t&&(v=t.colorType,!p)&&("half float"===v||"float16"===v?d="rgba16f":"float"!==v&&"float32"!==v||(d="rgba32f")),"colorFormat"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),("depthTexture"in t||"depthStencilTexture"in t)&&(T=!(!t.depthTexture&&!t.depthStencilTexture)),"depth"in t&&("boolean"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),"stencil"in t&&("boolean"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),"depthStencil"in t&&("boolean"==typeof t.depthStencil?s=c=t.depthStencil:(k=t.depthStencil,c=s=!1))):i=o=1;var A=null,M=null,S=null,E=null;if(Array.isArray(a))A=a.map(u);else if(a)A=[u(a)];else for(A=Array(y),a=0;a<y;++a)A[a]=h(i,o,p,d,v);for(i=i||A[0].width,o=o||A[0].height,x?M=u(x):s&&!c&&(M=h(i,o,T,"depth","uint32")),w?S=u(w):c&&!s&&(S=h(i,o,!1,"stencil","uint8")),k?E=u(k):!x&&!w&&c&&s&&(E=h(i,o,T,"depth stencil","depth stencil")),s=null,a=0;a<A.length;++a)l(A[a]),A[a]&&A[a].texture&&(c=yt[A[a].texture._texture.format]*xt[A[a].texture._texture.type],null===s&&(s=c));return l(M),l(S),l(E),g(n),n.width=i,n.height=o,n.colorAttachments=A,n.depthAttachment=M,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=A.map(f),r.depth=f(M),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,m(n),r}var n=new d;return i.framebufferCount++,r(t,e),j(r,{resize:function(t,e){var a=Math.max(0|t,1),i=Math.max(0|e||a,1);if(a===n.width&&i===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],a,i);return p(n.depthAttachment,a,i),p(n.stencilAttachment,a,i),p(n.depthStencilAttachment,a,i),n.width=r.width=a,n.height=r.height=i,m(n),r},_reglType:"framebuffer",_framebuffer:n,destroy:function(){v(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=["rgba"],_=["rgba4","rgb565","rgb5 a1"];e.ext_srgb&&_.push("srgba"),e.ext_color_buffer_half_float&&_.push("rgba16f","rgb16f"),e.webgl_color_buffer_float&&_.push("rgba32f");var w=["uint8"];e.oes_texture_half_float&&w.push("half float","float16"),e.oes_texture_float&&w.push("float","float32");var k=0,T={};return j(x,{getFramebuffer:function(t){return"function"==typeof t&&"framebuffer"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var a,i={color:null},o=0,s=null;a="rgba";var l="uint8",c=1;if("number"==typeof t?o=0|t:t?("shape"in t?o=t.shape[0]:("radius"in t&&(o=0|t.radius),"width"in t?o=0|t.width:"height"in t&&(o=0|t.height)),("color"in t||"colors"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||("colorCount"in t&&(c=0|t.colorCount),"colorType"in t&&(l=t.colorType),"colorFormat"in t&&(a=t.colorFormat)),"depth"in t&&(i.depth=t.depth),"stencil"in t&&(i.stencil=t.stencil),"depthStencil"in t&&(i.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],a=0;a<s.length;++a)t[a]=s[a];else t=[s];else for(t=Array(c),s={radius:o,format:a,type:l},a=0;a<c;++a)t[a]=n.createCube(s);for(i.color=Array(t.length),a=0;a<t.length;++a)c=t[a],o=o||c.width,i.color[a]={target:34069,data:t[a]};for(a=0;6>a;++a){for(c=0;c<t.length;++c)i.color[c].target=34069+a;0<a&&(i.depth=r[0].depth,i.stencil=r[0].stencil,i.depthStencil=r[0].depthStencil),r[a]?r[a](i):r[a]=y(i)}return j(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),j(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var a=e.color;for(t=0;t<a.length;++t)a[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:"framebufferCube",destroy:function(){r.forEach(function(t){t.destroy()})}})},clear:function(){X(T).forEach(v)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(T).forEach(function(e){e.framebuffer=t.createFramebuffer(),m(e)})}})}function M(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n){function a(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function i(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,a){if(!(o=(a=35632===r?c:u)[n])){var i=e.str(n),o=t.createShader(r);t.shaderSource(o,i),t.compileShader(o),a[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s){var l,c;l=o(35632,r.fragId),c=o(35633,r.vertId);var u=r.program=t.createProgram();t.attachShader(u,l),t.attachShader(u,c),t.linkProgram(u);var h=t.getProgramParameter(u,35718);n.profile&&(r.stats.uniformsCount=h);var f=r.uniforms;for(l=0;l<h;++l)if(c=t.getActiveUniform(u,l))if(1<c.size)for(var p=0;p<c.size;++p){var d=c.name.replace("[0]","["+p+"]");i(f,new a(d,e.id(d),t.getUniformLocation(u,d),c))}else i(f,new a(c.name,e.id(c.name),t.getUniformLocation(u,c.name),c));for(h=t.getProgramParameter(u,35721),n.profile&&(r.stats.attributesCount=h),f=r.attributes,l=0;l<h;++l)(c=t.getActiveAttrib(u,l))&&i(f,new a(c.name,e.id(c.name),t.getAttribLocation(u,c.name),c))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach(function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)}),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach(function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)}),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},f.forEach(function(e){t.deleteProgram(e.program)}),f.length=0,h={},r.shaderCount=0},program:function(t,e,n){var a=h[e];a||(a=h[e]={});var i=a[t];return i||(i=new s(e,t),r.shaderCount++,l(i),a[t]=i,f.push(i)),i},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t])},shader:o,frag:-1,vert:-1}}function E(t,e,r,n,a,i,o){function s(a){var i;i=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return W(a)?u=a:a&&(o=0|a.x,s=0|a.y,l=0|(a.width||n.framebufferWidth-o),c=0|(a.height||n.framebufferHeight-s),u=a.data||null),r(),a=l*c*4,u||(5121===i?u=new Uint8Array(a):5126===i&&(u=u||new Float32Array(a))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,i,u),u}return function(t){return t&&"framebuffer"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},function(){r=s(t)}),r}(t):s(t)}}function L(t){return Array.prototype.slice.call(t)}function C(t){return L(t).join("")}function P(){function t(){var t=[],e=[];return j(function(){t.push.apply(t,L(arguments))},{def:function(){var n="v"+r++;return e.push(n),0<arguments.length&&(t.push(n,"="),t.push.apply(t,L(arguments)),t.push(";")),n},toString:function(){return C([0<e.length?"var "+e+";":"",C(t)])}})}function e(){function e(t,e){n(t,e,"=",r.def(t,e),";")}var r=t(),n=t(),a=r.toString,i=n.toString;return j(function(){r.apply(r,L(arguments))},{def:r.def,entry:r,exit:n,save:e,set:function(t,n,a){e(t,n),r(t,n,"=",a,";")},toString:function(){return a()+i()}})}var r=0,n=[],a=[],i=t(),o={};return{global:i,link:function(t){for(var e=0;e<a.length;++e)if(a[e]===t)return n[e];return e="g"+r++,n.push(e),a.push(t),e},block:t,proc:function(t,r){function n(){var t="a"+a.length;return a.push(t),t}var a=[];r=r||0;for(var i=0;i<r;++i)n();var s=(i=e()).toString;return o[t]=j(i,{arg:n,toString:function(){return C(["function(",a.join(),"){",s(),"}"])}})},scope:e,cond:function(){var t=C(arguments),r=e(),n=e(),a=r.toString,i=n.toString;return j(r,{then:function(){return r.apply(r,L(arguments)),this},else:function(){return n.apply(n,L(arguments)),this},toString:function(){var e=i();return e&&(e="else{"+e+"}"),C(["if(",t,"){",a(),"}",e])}})},compile:function(){var t=['"use strict";',i,"return {"];Object.keys(o).forEach(function(e){t.push('"',e,'":',o[e].toString(),",")}),t.push("}");var e=C(t).replace(/;/g,";\n").replace(/}/g,"}\n").replace(/{/g,"{\n");return Function.apply(null,n.concat(e)).apply(null,a)}}}function O(t){return Array.isArray(t)||W(t)||l(t)}function z(t){return t.sort(function(t,e){return"viewport"===t?-1:"viewport"===e?1:t<e?-1:1})}function I(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function D(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function R(t){return new I(!1,!1,!1,t)}function F(t,e){var r=t.type;return 0===r?new I(!0,1<=(r=t.data.length),2<=r,e):4===r?new I((r=t.data).thisDep,r.contextDep,r.propDep,e):new I(3===r,2===r,1===r,e)}function B(t,e,r,n,a,o,s,l,c,u,h,f,p,d,g){function m(t){return t.replace(".","_")}function y(t,e,r){var n=m(t);nt.push(t),et[n]=tt[n]=!!r,at[n]=e}function x(t,e,r){var n=m(t);nt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,it[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId="0";var a=r(ot),i=t.shared={props:"a0"};Object.keys(ot).forEach(function(t){i[t]=n.def(a,".",t)});var o=t.next={},s=t.current={};Object.keys(it).forEach(function(t){Array.isArray(tt[t])&&(o[t]=n.def(i.next,".",t),s[t]=n.def(i.current,".",t))});var l=t.constants={};Object.keys(st).forEach(function(t){l[t]=n.def(JSON.stringify(st[t]))}),t.invoke=function(e,n){switch(n.type){case 0:var a=["this",i.context,i.props,t.batchId];return e.def(r(n.data),".call(",a.slice(0,Math.max(n.data.length+1,4)),")");case 1:return e.def(i.props,n.data);case 2:return e.def(i.context,n.data);case 3:return e.def("this",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if("framebuffer"in r){var a=r.framebuffer;return a?(a=l.getFramebuffer(a),R(function(t,e){var r=t.link(a),n=t.shared;return e.set(n.framebuffer,".next",r),n=n.context,e.set(n,".framebufferWidth",r+".width"),e.set(n,".framebufferHeight",r+".height"),r})):R(function(t,e){var r=t.shared;return e.set(r.framebuffer,".next","null"),r=r.context,e.set(r,".framebufferWidth",r+".drawingBufferWidth"),e.set(r,".framebufferHeight",r+".drawingBufferHeight"),"null"})}if("framebuffer"in n){var i=n.framebuffer;return F(i,function(t,e){var r=t.invoke(e,i),n=t.shared,a=n.framebuffer;r=e.def(a,".getFramebuffer(",r,")");return e.set(a,".next",r),n=n.context,e.set(n,".framebufferWidth",r+"?"+r+".width:"+n+".drawingBufferWidth"),e.set(n,".framebufferHeight",r+"?"+r+".height:"+n+".drawingBufferHeight"),r})}return null}function w(t){function r(t){if(t in n){var r=e.id(n[t]);return(t=R(function(){return r})).id=r,t}if(t in a){var i=a[t];return F(i,function(t,e){var r=t.invoke(e,i);return e.def(t.shared.strings,".id(",r,")")})}return null}var n=t.static,a=t.dynamic,i=r("frag"),o=r("vert"),s=null;return D(i)&&D(o)?(s=h.program(o.id,i.id),t=R(function(t,e){return t.link(s)})):t=new I(i&&i.thisDep||o&&o.thisDep,i&&i.contextDep||o&&o.contextDep,i&&i.propDep||o&&o.propDep,function(t,e){var r,n,a=t.shared.shader;return r=i?i.append(t,e):e.def(a,".","frag"),n=o?o.append(t,e):e.def(a,".","vert"),e.def(a+".program("+n+","+r+")")}),{frag:i,vert:o,progVar:t,program:s}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return R(function(t,n){return e&&(t.OFFSET=r),r})}if(t in a){var o=a[t];return F(o,function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n})}return e&&i?R(function(t,e){return t.OFFSET="0",0}):null}var n=t.static,a=t.dynamic,i=function(){if("elements"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=R(function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null});return e.value=t,e}if("elements"in a){var r=a.elements;return F(r,function(t,e){var n=(a=t.shared).isBufferArgs,a=a.elements,i=t.invoke(e,r),o=e.def("null");n=e.def(n,"(",i,")"),i=t.cond(n).then(o,"=",a,".createStream(",i,");").else(o,"=",a,".getElements(",i,");");return e.entry(i),e.exit(t.cond(n).then(a,".destroyStream(",o,");")),t.ELEMENTS=o})}return null}(),s=r("offset",!0);return{elements:i,primitive:function(){if("primitive"in n){var t=n.primitive;return R(function(e,r){return rt[t]})}if("primitive"in a){var e=a.primitive;return F(e,function(t,r){var n=t.constants.primTypes,a=t.invoke(r,e);return r.def(n,"[",a,"]")})}return i?D(i)?i.value?R(function(t,e){return e.def(t.ELEMENTS,".primType")}):R(function(){return 4}):new I(i.thisDep,i.contextDep,i.propDep,function(t,e){var r=t.ELEMENTS;return e.def(r,"?",r,".primType:",4)}):null}(),count:function(){if("count"in n){var t=0|n.count;return R(function(){return t})}if("count"in a){var e=a.count;return F(e,function(t,r){return t.invoke(r,e)})}return i?D(i)?i?s?new I(s.thisDep,s.contextDep,s.propDep,function(t,e){return e.def(t.ELEMENTS,".vertCount-",t.OFFSET)}):R(function(t,e){return e.def(t.ELEMENTS,".vertCount")}):R(function(){return-1}):new I(i.thisDep||s.thisDep,i.contextDep||s.contextDep,i.propDep||s.propDep,function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,"?",r,".vertCount-",t.OFFSET,":-1"):e.def(r,"?",r,".vertCount:-1")}):null}(),instances:r("instances",!1),offset:s}}function T(t,r){var n=t.static,i=t.dynamic,o={};return Object.keys(n).forEach(function(t){var r=n[t],i=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=a.getBuffer(a.create(r,34962,!1,!0)),s.type=0;else if(c=a.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if("constant"in r){var l=r.constant;s.buffer="null",s.state=2,"number"==typeof l?s.x=l:bt.forEach(function(t,e){e<l.length&&(s[t]=l[e])})}else{var c=O(r.buffer)?a.getBuffer(a.create(r.buffer,34962,!1,!0)):a.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;"type"in r&&(d=K[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=R(function(t,e){var r=t.attribCache;if(i in r)return r[i];var n={isStream:!1};return Object.keys(s).forEach(function(t){n[t]=s[t]}),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+".dtype"),r[i]=n})}),Object.keys(i).forEach(function(t){var e=i[t];o[t]=F(e,function(t,r){function n(t){r(l[t],"=",a,".",t,"|0;")}var a=t.invoke(r,e),i=t.shared,o=i.isBufferArgs,s=i.buffer,l={isStream:r.def(!1)},c=new Z;c.state=1,Object.keys(c).forEach(function(t){l[t]=r.def(""+c[t])});var u=l.buffer,h=l.type;return r("if(",o,"(",a,")){",l.isStream,"=true;",u,"=",s,".createStream(",34962,",",a,");",h,"=",u,".dtype;","}else{",u,"=",s,".getBuffer(",a,");","if(",u,"){",h,"=",u,".dtype;",'}else if("constant" in ',a,"){",l.state,"=",2,";","if(typeof "+a+'.constant === "number"){',l[bt[0]],"=",a,".constant;",bt.slice(1).map(function(t){return l[t]}).join("="),"=0;","}else{",bt.map(function(t,e){return l[t]+"="+a+".constant.length>"+e+"?"+a+".constant["+e+"]:0;"}).join(""),"}}else{","if(",o,"(",a,".buffer)){",u,"=",s,".createStream(",34962,",",a,".buffer);","}else{",u,"=",s,".getBuffer(",a,".buffer);","}",h,'="type" in ',a,"?",i.glTypes,"[",a,".type]:",u,".dtype;",l.normalized,"=!!",a,".normalized;"),n("size"),n("offset"),n("stride"),n("divisor"),r("}}"),r.exit("if(",l.isStream,"){",s,".destroyStream(",u,");","}"),l})}),o}function A(t,e,r,n,a){var o=_(t),s=function(t,e,r){function n(t){if(t in a){var r=a[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return"width"in r?n=0|r.width:t=!1,"height"in r?o=0|r.height:t=!1,new I(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,function(t,e){var a=t.shared.context,i=n;"width"in r||(i=e.def(a,".","framebufferWidth","-",s));var c=o;return"height"in r||(c=e.def(a,".","framebufferHeight","-",l)),[s,l,i,c]})}if(t in i){var c=i[t];return t=F(c,function(t,e){var r=t.invoke(e,c),n=t.shared.context,a=e.def(r,".x|0"),i=e.def(r,".y|0");return[a,i,e.def('"width" in ',r,"?",r,".width|0:","(",n,".","framebufferWidth","-",a,")"),r=e.def('"height" in ',r,"?",r,".height|0:","(",n,".","framebufferHeight","-",i,")")]}),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new I(e.thisDep,e.contextDep,e.propDep,function(t,e){var r=t.shared.context;return[0,0,e.def(r,".","framebufferWidth"),e.def(r,".","framebufferHeight")]}):null}var a=t.static,i=t.dynamic;if(t=n("viewport")){var o=t;t=new I(t.thisDep,t.contextDep,t.propDep,function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,".viewportWidth",r[2]),e.set(n,".viewportHeight",r[3]),r})}return{viewport:t,scissor_box:n("scissor.box")}}(t,o),l=k(t),c=function(t,e){var r=t.static,n=t.dynamic,a={};return nt.forEach(function(t){function e(e,i){if(t in r){var s=e(r[t]);a[o]=R(function(){return s})}else if(t in n){var l=n[t];a[o]=F(l,function(t,e){return i(t,e,t.invoke(e,l))})}}var o=m(t);switch(t){case"cull.enable":case"blend.enable":case"dither":case"stencil.enable":case"depth.enable":case"scissor.enable":case"polygonOffset.enable":case"sample.alpha":case"sample.enable":case"depth.mask":return e(function(t){return t},function(t,e,r){return r});case"depth.func":return e(function(t){return kt[t]},function(t,e,r){return e.def(t.constants.compareFuncs,"[",r,"]")});case"depth.range":return e(function(t){return t},function(t,e,r){return[e.def("+",r,"[0]"),e=e.def("+",r,"[1]")]});case"blend.func":return e(function(t){return[wt["srcRGB"in t?t.srcRGB:t.src],wt["dstRGB"in t?t.dstRGB:t.dst],wt["srcAlpha"in t?t.srcAlpha:t.src],wt["dstAlpha"in t?t.dstAlpha:t.dst]]},function(t,e,r){function n(t,n){return e.def('"',t,n,'" in ',r,"?",r,".",t,n,":",r,".",t)}t=t.constants.blendFuncs;var a=n("src","RGB"),i=n("dst","RGB"),o=(a=e.def(t,"[",a,"]"),e.def(t,"[",n("src","Alpha"),"]"));return[a,i=e.def(t,"[",i,"]"),o,t=e.def(t,"[",n("dst","Alpha"),"]")]});case"blend.equation":return e(function(t){return"string"==typeof t?[J[t],J[t]]:"object"==typeof t?[J[t.rgb],J[t.alpha]]:void 0},function(t,e,r){var n=t.constants.blendEquations,a=e.def(),i=e.def();return(t=t.cond("typeof ",r,'==="string"')).then(a,"=",i,"=",n,"[",r,"];"),t.else(a,"=",n,"[",r,".rgb];",i,"=",n,"[",r,".alpha];"),e(t),[a,i]});case"blend.color":return e(function(t){return i(4,function(e){return+t[e]})},function(t,e,r){return i(4,function(t){return e.def("+",r,"[",t,"]")})});case"stencil.mask":return e(function(t){return 0|t},function(t,e,r){return e.def(r,"|0")});case"stencil.func":return e(function(t){return[kt[t.cmp||"keep"],t.ref||0,"mask"in t?t.mask:-1]},function(t,e,r){return[t=e.def('"cmp" in ',r,"?",t.constants.compareFuncs,"[",r,".cmp]",":",7680),e.def(r,".ref|0"),e=e.def('"mask" in ',r,"?",r,".mask|0:-1")]});case"stencil.opFront":case"stencil.opBack":return e(function(e){return["stencil.opBack"===t?1029:1028,Tt[e.fail||"keep"],Tt[e.zfail||"keep"],Tt[e.zpass||"keep"]]},function(e,r,n){function a(t){return r.def('"',t,'" in ',n,"?",i,"[",n,".",t,"]:",7680)}var i=e.constants.stencilOps;return["stencil.opBack"===t?1029:1028,a("fail"),a("zfail"),a("zpass")]});case"polygonOffset.offset":return e(function(t){return[0|t.factor,0|t.units]},function(t,e,r){return[e.def(r,".factor|0"),e=e.def(r,".units|0")]});case"cull.face":return e(function(t){var e=0;return"front"===t?e=1028:"back"===t&&(e=1029),e},function(t,e,r){return e.def(r,'==="front"?',1028,":",1029)});case"lineWidth":return e(function(t){return t},function(t,e,r){return r});case"frontFace":return e(function(t){return At[t]},function(t,e,r){return e.def(r+'==="cw"?2304:2305')});case"colorMask":return e(function(t){return t.map(function(t){return!!t})},function(t,e,r){return i(4,function(t){return"!!"+r+"["+t+"]"})});case"sample.coverage":return e(function(t){return["value"in t?t.value:1,!!t.invert]},function(t,e,r){return[e.def('"value" in ',r,"?+",r,".value:1"),e=e.def("!!",r,".invert")]})}}),a}(t),u=w(t),h=s.viewport;return h&&(c.viewport=h),(s=s[h=m("scissor.box")])&&(c[h]=s),(o={framebuffer:o,draw:l,shader:u,state:c,dirty:s=0<Object.keys(c).length}).profile=function(t){var e,r=t.static;if(t=t.dynamic,"profile"in r){var n=!!r.profile;(e=R(function(t,e){return n})).enable=n}else if("profile"in t){var a=t.profile;e=F(a,function(t,e){return t.invoke(e,a)})}return e}(t),o.uniforms=function(t,e){var r=t.static,n=t.dynamic,a={};return Object.keys(r).forEach(function(t){var e,n=r[t];if("number"==typeof n||"boolean"==typeof n)e=R(function(){return n});else if("function"==typeof n){var o=n._reglType;"texture2d"===o||"textureCube"===o?e=R(function(t){return t.link(n)}):"framebuffer"!==o&&"framebufferCube"!==o||(e=R(function(t){return t.link(n.color[0])}))}else v(n)&&(e=R(function(t){return t.global.def("[",i(n.length,function(t){return n[t]}),"]")}));e.value=n,a[t]=e}),Object.keys(n).forEach(function(t){var e=n[t];a[t]=F(e,function(t,r){return t.invoke(r,e)})}),a}(r),o.attributes=T(e),o.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach(function(t){var r=e[t];n[t]=R(function(t,e){return"number"==typeof r||"boolean"==typeof r?""+r:t.link(r)})}),Object.keys(r).forEach(function(t){var e=r[t];n[t]=F(e,function(t,r){return t.invoke(r,e)})}),n}(n),o}function M(t,e,r){var n=t.shared.context,a=t.scope();Object.keys(r).forEach(function(i){e.save(n,"."+i),a(n,".",i,"=",r[i].append(t,e),";")}),e(a)}function S(t,e,r,n){var a,i=(s=t.shared).gl,o=s.framebuffer;$&&(a=e.def(s.extensions,".webgl_draw_buffers"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,".next"),n||e("if(",t,"!==",o,".cur){"),e("if(",t,"){",i,".bindFramebuffer(",36160,",",t,".framebuffer);"),$&&e(a,".drawBuffersWEBGL(",s,"[",t,".colorAttachments.length]);"),e("}else{",i,".bindFramebuffer(",36160,",null);"),$&&e(a,".drawBuffersWEBGL(",l,");"),e("}",o,".cur=",t,";"),n||e("}")}function E(t,e,r){var n=t.shared,a=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,".dirty");nt.forEach(function(e){var n,h;if(!((e=m(e))in r.state))if(e in s){n=s[e],h=o[e];var f=i(tt[e].length,function(t){return u.def(n,"[",t,"]")});u(t.cond(f.map(function(t,e){return t+"!=="+h+"["+e+"]"}).join("||")).then(a,".",it[e],"(",f,");",f.map(function(t,e){return h+"["+e+"]="+t}).join(";"),";"))}else n=u.def(c,".",e),f=t.cond(n,"!==",l,".",e),u(f),e in at?f(t.cond(n).then(a,".enable(",at[e],");").else(a,".disable(",at[e],");"),l,".",e,"=",n,";"):f(a,".",it[e],"(",n,");",l,".",e,"=",n,";")}),0===Object.keys(r.state).length&&u(l,".dirty=false;"),e(u)}function L(t,e,r,n){var a=t.shared,i=t.current,o=a.current,s=a.gl;z(Object.keys(r)).forEach(function(a){var l=r[a];if(!n||n(l)){var c=l.append(t,e);if(at[a]){var u=at[a];D(l)?e(s,c?".enable(":".disable(",u,");"):e(t.cond(c).then(s,".enable(",u,");").else(s,".disable(",u,");")),e(o,".",a,"=",c,";")}else if(v(c)){var h=i[a];e(s,".",it[a],"(",c,");",c.map(function(t,e){return h+"["+e+"]="+t}).join(";"),";")}else e(s,".",it[a],"(",c,");",o,".",a,"=",c,";")}})}function C(t,e){Q&&(t.instancing=e.def(t.shared.extensions,".angle_instanced_arrays"))}function B(t,e,r,n,a){function i(){return"undefined"==typeof performance?"Date.now()":"performance.now()"}function o(t){t(c=e.def(),"=",i(),";"),"string"==typeof a?t(f,".count+=",a,";"):t(f,".count++;"),d&&(n?t(u=e.def(),"=",g,".getNumPendingQueries();"):t(g,".beginQuery(",f,");"))}function s(t){t(f,".cpuTime+=",i(),"-",c,";"),d&&(n?t(g,".pushScopeStats(",u,",",g,".getNumPendingQueries(),",f,");"):t(g,".endQuery();"))}function l(t){var r=e.def(p,".profile");e(p,".profile=",t,";"),e.exit(p,".profile=",r,";")}var c,u,h=t.shared,f=t.stats,p=h.current,g=h.timer;if(r=r.profile){if(D(r))return void(r.enable?(o(e),s(e.exit),l("true")):l("false"));l(r=r.append(t,e))}else r=e.def(p,".profile");o(h=t.block()),e("if(",r,"){",h,"}"),s(t=t.block()),e.exit("if(",r,"){",t,"}")}function N(t,e,r,n,a){function i(r,n,a){function i(){e("if(!",u,".buffer){",l,".enableVertexAttribArray(",c,");}");var r,i=a.type;r=a.size?e.def(a.size,"||",n):n,e("if(",u,".type!==",i,"||",u,".size!==",r,"||",p.map(function(t){return u+"."+t+"!=="+a[t]}).join("||"),"){",l,".bindBuffer(",34962,",",h,".buffer);",l,".vertexAttribPointer(",[c,r,i,a.normalized,a.stride,a.offset],");",u,".type=",i,";",u,".size=",r,";",p.map(function(t){return u+"."+t+"="+a[t]+";"}).join(""),"}"),Q&&(i=a.divisor,e("if(",u,".divisor!==",i,"){",t.instancing,".vertexAttribDivisorANGLE(",[c,i],");",u,".divisor=",i,";}"))}function s(){e("if(",u,".buffer){",l,".disableVertexAttribArray(",c,");","}if(",bt.map(function(t,e){return u+"."+t+"!=="+f[e]}).join("||"),"){",l,".vertexAttrib4f(",c,",",f,");",bt.map(function(t,e){return u+"."+t+"="+f[e]+";"}).join(""),"}")}var l=o.gl,c=e.def(r,".location"),u=e.def(o.attributes,"[",c,"]");r=a.state;var h=a.buffer,f=[a.x,a.y,a.z,a.w],p=["buffer","normalized","offset","stride"];1===r?i():2===r?s():(e("if(",r,"===",1,"){"),i(),e("}else{"),s(),e("}"))}var o=t.shared;n.forEach(function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!a(l))return;o=l.append(t,e)}else{if(!a(Mt))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach(function(t){o[t]=e.def(c,".",t)})}i(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)})}function j(t,r,n,a,o){for(var s,l=t.shared,c=l.gl,u=0;u<a.length;++u){var h,f=(g=a[u]).name,p=g.info.type,d=n.uniforms[f],g=t.link(g)+".location";if(d){if(!o(d))continue;if(D(d)){if(f=d.value,35678===p||35680===p)r(c,".uniform1i(",g,",",(p=t.link(f._texture||f.color[0]._texture))+".bind());"),r.exit(p,".unbind();");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,".uniformMatrix",d,"fv(",g,",false,",f=t.global.def("new Float32Array(["+Array.prototype.slice.call(f)+"])"),");");else{switch(p){case 5126:s="1f";break;case 35664:s="2f";break;case 35665:s="3f";break;case 35666:s="4f";break;case 35670:case 5124:s="1i";break;case 35671:case 35667:s="2i";break;case 35672:case 35668:s="3i";break;case 35673:s="4i";break;case 35669:s="4i"}r(c,".uniform",s,"(",g,",",v(f)?Array.prototype.slice.call(f):f,");")}continue}h=d.append(t,r)}else{if(!o(Mt))continue;h=r.def(l.uniforms,"[",e.id(f),"]")}switch(35678===p?r("if(",h,"&&",h,'._reglType==="framebuffer"){',h,"=",h,".color[0];","}"):35680===p&&r("if(",h,"&&",h,'._reglType==="framebufferCube"){',h,"=",h,".color[0];","}"),f=1,p){case 35678:case 35680:p=r.def(h,"._texture"),r(c,".uniform1i(",g,",",p,".bind());"),r.exit(p,".unbind();");continue;case 5124:case 35670:s="1i";break;case 35667:case 35671:s="2i",f=2;break;case 35668:case 35672:s="3i",f=3;break;case 35669:case 35673:s="4i",f=4;break;case 5126:s="1f";break;case 35664:s="2f",f=2;break;case 35665:s="3f",f=3;break;case 35666:s="4f",f=4;break;case 35674:s="Matrix2fv";break;case 35675:s="Matrix3fv";break;case 35676:s="Matrix4fv"}if(r(c,".uniform",s,"(",g,","),"M"===s.charAt(0)){g=Math.pow(p-35674+2,2);var m=t.global.def("new Float32Array(",g,")");r("false,(Array.isArray(",h,")||",h," instanceof Float32Array)?",h,":(",i(g,function(t){return m+"["+t+"]="+h+"["+t+"]"}),",",m,")")}else r(1<f?i(f,function(t){return h+"["+t+"]"}):h);r(");")}}function V(t,e,r,n){function a(a){var i=f[a];return i?i.contextDep&&n.contextDynamic||i.propDep?i.append(t,r):i.append(t,e):e.def(h,".",a)}function i(){function t(){r(l,".drawElementsInstancedANGLE(",[d,v,m,g+"<<(("+m+"-5121)>>1)",s],");")}function e(){r(l,".drawArraysInstancedANGLE(",[d,g,v,s],");")}p?y?t():(r("if(",p,"){"),t(),r("}else{"),e(),r("}")):e()}function o(){function t(){r(u+".drawElements("+[d,v,m,g+"<<(("+m+"-5121)>>1)"]+");")}function e(){r(u+".drawArrays("+[d,g,v]+");")}p?y?t():(r("if(",p,"){"),t(),r("}else{"),e(),r("}")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var a=f.elements,i=e;return a?((a.contextDep&&n.contextDynamic||a.propDep)&&(i=r),a=a.append(t,i)):a=i.def(h,".","elements"),a&&i("if("+a+")"+u+".bindBuffer(34963,"+a+".buffer.buffer);"),a}(),d=a("primitive"),g=a("offset"),v=function(){var a=f.count,i=e;return a?((a.contextDep&&n.contextDynamic||a.propDep)&&(i=r),a=a.append(t,i)):a=i.def(h,".","count"),a}();if("number"==typeof v){if(0===v)return}else r("if(",v,"){"),r.exit("}");Q&&(s=a("instances"),l=t.instancing);var m=p+".type",y=f.elements&&D(f.elements);Q&&("number"!=typeof s||0<=s)?"string"==typeof s?(r("if(",s,">0){"),i(),r("}else if(",s,"<0){"),o(),r("}")):i():o()}function q(t,e,r,n,a){return a=(e=b()).proc("body",a),Q&&(e.instancing=a.def(e.shared.extensions,".angle_instanced_arrays")),t(e,a,r,n),e.compile().body}function H(t,e,r,n){C(t,e),N(t,e,r,n.attributes,function(){return!0}),j(t,e,r,n.uniforms,function(){return!0}),V(t,e,e,r)}function G(t,e,r,n){function a(){return!0}t.batchId="a1",C(t,e),N(t,e,r,n.attributes,a),j(t,e,r,n.uniforms,a),V(t,e,e,r)}function Y(t,e,r,n){function a(t){return t.contextDep&&o||t.propDep}function i(t){return!a(t)}C(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,"for(",s,"=0;",s,"<","a1",";++",s,"){",l,"=","a0","[",s,"];",u,"}",c.exit),r.needsContext&&M(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),L(t,u,r.state,a),r.profile&&a(r.profile)&&B(t,u,r,!1,!0),n?(N(t,c,r,n.attributes,i),N(t,u,r,n.attributes,a),j(t,c,r,n.uniforms,i),j(t,u,r,n.uniforms,a),V(t,c,u,r)):(e=t.global.def("{}"),n=r.shader.progVar.append(t,u),l=u.def(n,".id"),c=u.def(e,"[",l,"]"),u(t.shared.gl,".useProgram(",n,".program);","if(!",c,"){",c,"=",e,"[",l,"]=",t.link(function(e){return q(G,t,r,e,2)}),"(",n,");}",c,".call(this,a0[",s,"],",s,");"))}function W(t,r){function n(e){var n=r.shader[e];n&&a.set(i.shader,"."+e,n.append(t,a))}var a=t.proc("scope",3);t.batchId="a2";var i=t.shared,o=i.current;M(t,a,r.context),r.framebuffer&&r.framebuffer.append(t,a),z(Object.keys(r.state)).forEach(function(e){var n=r.state[e].append(t,a);v(n)?n.forEach(function(r,n){a.set(t.next[e],"["+n+"]",r)}):a.set(i.next,"."+e,n)}),B(t,a,r,!0,!0),["elements","offset","count","instances","primitive"].forEach(function(e){var n=r.draw[e];n&&a.set(i.draw,"."+e,""+n.append(t,a))}),Object.keys(r.uniforms).forEach(function(n){a.set(i.uniforms,"["+e.id(n)+"]",r.uniforms[n].append(t,a))}),Object.keys(r.attributes).forEach(function(e){var n=r.attributes[e].append(t,a),i=t.scopeAttrib(e);Object.keys(new Z).forEach(function(t){a.set(i,"."+t,n[t])})}),n("vert"),n("frag"),0<Object.keys(r.state).length&&(a(o,".dirty=true;"),a.exit(o,".dirty=true;")),a("a1(",t.shared.context,",a0,",t.batchId,");")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if("object"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(U.isDynamic(t[e[r]]))return!0;return!1}}(n)){var a=t.global,i=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def("{}");i.forEach(function(e){var r=n[e];if(U.isDynamic(r))"function"==typeof r&&(r=n[e]=U.unbox(r)),e=F(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(a(c,".",e,"="),typeof r){case"number":a(r);break;case"string":a('"',r,'"');break;case"object":Array.isArray(r)&&a("[",r.join(),"]");break;default:a(t.link(r))}a(";")}}),e.dynamic[r]=new U.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){i.forEach(function(r){var a=n[r];U.isDynamic(a)&&(a=t.invoke(e,a),e(c,".",r,"=",a,";"))})}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,"reverse subtract":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var Q=r.angle_instanced_arrays,$=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},nt=[],at={},it={};y("dither",3024),y("blend.enable",3042),x("blend.color","blendColor",[0,0,0,0]),x("blend.equation","blendEquationSeparate",[32774,32774]),x("blend.func","blendFuncSeparate",[1,0,1,0]),y("depth.enable",2929,!0),x("depth.func","depthFunc",513),x("depth.range","depthRange",[0,1]),x("depth.mask","depthMask",!0),x("colorMask","colorMask",[!0,!0,!0,!0]),y("cull.enable",2884),x("cull.face","cullFace",1029),x("frontFace","frontFace",2305),x("lineWidth","lineWidth",1),y("polygonOffset.enable",32823),x("polygonOffset.offset","polygonOffset",[0,0]),y("sample.alpha",32926),y("sample.enable",32928),x("sample.coverage","sampleCoverage",[1,!1]),y("stencil.enable",2960),x("stencil.mask","stencilMask",-1),x("stencil.func","stencilFunc",[519,0,-1]),x("stencil.opFront","stencilOpSeparate",[1028,7680,7680,7680]),x("stencil.opBack","stencilOpSeparate",[1029,7680,7680,7680]),y("scissor.enable",3089),x("scissor.box","scissor",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x("viewport","viewport",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:f,elements:o,buffer:a,shader:h,attributes:u.state,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:rt,compareFuncs:kt,blendFuncs:wt,blendEquations:J,stencilOps:Tt,glTypes:K,orientationType:At};$&&(st.backBuffer=[1029],st.drawBuffer=i(n.maxDrawbuffers,function(t){return 0===t?[0]:i(t,function(t){return 36064+t})}));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc("poll"),r=t.proc("refresh"),a=t.block();e(a),r(a);var o,s=t.shared,l=s.gl,c=s.next,u=s.current;a(u,".dirty=false;"),S(t,e),S(t,r,null,!0),Q&&(o=t.link(Q));for(var h=0;h<n.maxAttributes;++h){var f=r.def(s.attributes,"[",h,"]"),p=t.cond(f,".buffer");p.then(l,".enableVertexAttribArray(",h,");",l,".bindBuffer(",34962,",",f,".buffer.buffer);",l,".vertexAttribPointer(",h,",",f,".size,",f,".type,",f,".normalized,",f,".stride,",f,".offset);").else(l,".disableVertexAttribArray(",h,");",l,".vertexAttrib4f(",h,",",f,".x,",f,".y,",f,".z,",f,".w);",f,".buffer=null;"),r(p),Q&&r(o,".vertexAttribDivisorANGLE(",h,",",f,".divisor);")}return Object.keys(at).forEach(function(n){var i=at[n],o=a.def(c,".",n),s=t.block();s("if(",o,"){",l,".enable(",i,")}else{",l,".disable(",i,")}",u,".",n,"=",o,";"),r(s),e("if(",o,"!==",u,".",n,"){",s,"}")}),Object.keys(it).forEach(function(n){var o,s,h=it[n],f=tt[n],p=t.block();p(l,".",h,"("),v(f)?(h=f.length,o=t.global.def(c,".",n),s=t.global.def(u,".",n),p(i(h,function(t){return o+"["+t+"]"}),");",i(h,function(t){return s+"["+t+"]="+o+"["+t+"];"}).join("")),e("if(",i(h,function(t){return o+"["+t+"]!=="+s+"["+t+"]"}).join("||"),"){",p,"}")):(o=a.def(c,".",n),s=a.def(u,".",n),p(o,");",u,".",n,"=",o,";"),e("if(",o,"!==",s,"){",p,"}")),r(p)}),t.compile()}(),compile:function(t,e,r,n,a){var i=b();return i.stats=i.link(a),Object.keys(e.static).forEach(function(t){X(i,e,t)}),_t.forEach(function(e){X(i,t,e)}),r=A(t,e,r,n),function(t,e){var r=t.proc("draw",1);C(t,r),M(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),L(t,r,e.state),B(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,".useProgram(",n,".program);"),e.shader.program)H(t,r,e,e.shader.program);else{var a=t.global.def("{}"),i=r.def(n,".id"),o=r.def(a,"[",i,"]");r(t.cond(o).then(o,".call(this,a0);").else(o,"=",a,"[",i,"]=",t.link(function(r){return q(H,t,e,r,1)}),"(",n,");",o,".call(this,a0);"))}0<Object.keys(e.state).length&&r(t.shared.current,".dirty=true;")}(i,r),W(i,r),function(t,e){function r(t){return t.contextDep&&a||t.propDep}var n=t.proc("batch",2);t.batchId="0",C(t,n);var a=!1,i=!0;Object.keys(e.context).forEach(function(t){a=a||e.context[t].propDep}),a||(M(t,n,e.context),i=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?a=o=!0:s.contextDep&&a&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(a=!0),E(t,n,e),L(t,n,e.state,function(t){return!r(t)}),e.profile&&r(e.profile)||B(t,n,e,!1,"a1"),e.contextDep=a,e.needsContext=i,e.needsFramebuffer=o,(i=e.shader.progVar).contextDep&&a||i.propDep)Y(t,n,e,null);else if(i=i.append(t,n),n(t.shared.gl,".useProgram(",i,".program);"),e.shader.program)Y(t,n,e,e.shader.program);else{var s=t.global.def("{}"),l=(o=n.def(i,".id"),n.def(s,"[",o,"]"));n(t.cond(l).then(l,".call(this,a0,a1);").else(l,"=",s,"[",o,"]=",t.link(function(r){return q(Y,t,e,r,2)}),"(",i,");",l,".call(this,a0,a1);"))}0<Object.keys(e.state).length&&n(t.shared.current,".dirty=true;")}(i,r),i.compile()}}}function N(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var j=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},V=0,U={DynamicVariable:t,define:function(r,n){return new t(r,e(n+""))},isDynamic:function(e){return"function"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return"function"==typeof e?new t(0,e):e},accessor:e},q={next:"function"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:"function"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},H="undefined"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},G=s();G.zero=s();var Y=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,a=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),a=t.getParameter(36063));var i=!!e.oes_texture_float;if(i){i=t.createTexture(),t.bindTexture(3553,i),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,i,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))i=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=G.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?i=!1:(t.deleteFramebuffer(o),t.deleteTexture(i),i=1===s[0]),G.freeType(s)}}return s=!0,"undefined"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=G.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),G.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter(function(t){return!!e[t]}),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:a,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:i,npotTextureCube:s}},W=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map(function(e){return t[e]})},Z={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var a=1;if(e.length)for(var i=0;i<e.length;++i)a*=e[i];else a=0;switch(r=n||G.allocType(r,a),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],i=a=0;i<n;++i)for(var o=t[i],s=0;s<e;++s)r[a++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,a,i){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],h=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,h,r,a,i),i+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,a,i),i+=o}(t,e,0,r,0)}return r}},J={"[object Int8Array]":5120,"[object Int16Array]":5122,"[object Int32Array]":5124,"[object Uint8Array]":5121,"[object Uint8ClampedArray]":5121,"[object Uint16Array]":5123,"[object Uint32Array]":5125,"[object Float32Array]":5126,"[object Float64Array]":5121,"[object ArrayBuffer]":5121},K={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},Q={dynamic:35048,stream:35040,static:35044},$=Z.flatten,tt=Z.shape,et=[];et[5120]=1,et[5122]=2,et[5124]=4,et[5121]=1,et[5123]=2,et[5125]=4,et[5126]=4;var rt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,"line loop":2,"line strip":3,"triangle strip":5,"triangle fan":6},nt=new Float32Array(1),at=new Uint32Array(nt.buffer),it=[9984,9986,9985,9987],ot=[0,6409,6410,6407,6408],st={};st[6409]=st[6406]=st[6402]=1,st[34041]=st[6410]=2,st[6407]=st[35904]=3,st[6408]=st[35906]=4;var lt=m("HTMLCanvasElement"),ct=m("CanvasRenderingContext2D"),ut=m("ImageBitmap"),ht=m("HTMLImageElement"),ft=m("HTMLVideoElement"),pt=Object.keys(J).concat([lt,ct,ut,ht,ft]),dt=[];dt[5121]=1,dt[5126]=4,dt[36193]=2,dt[5123]=2,dt[5125]=4;var gt=[];gt[32854]=2,gt[32855]=2,gt[36194]=2,gt[34041]=4,gt[33776]=.5,gt[33777]=.5,gt[33778]=1,gt[33779]=1,gt[35986]=.5,gt[35987]=1,gt[34798]=1,gt[35840]=.5,gt[35841]=.25,gt[35842]=.5,gt[35843]=.25,gt[36196]=.5;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[33189]=2,vt[36168]=1,vt[34041]=4,vt[35907]=4,vt[34836]=16,vt[34842]=8,vt[34843]=6;var mt=function(t,e,r,n,a){function i(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,a.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,"rgb5 a1":32855,depth:33189,stencil:36168,"depth stencil":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach(function(t){l[s[t]]=t});var c=0,u={};return i.prototype.decRef=function(){0>=--this.refCount&&o(this)},a.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach(function(e){t+=u[e].stats.size}),t}),{create:function(e,r){function o(e,r){var n=0,i=0,u=32854;if("object"==typeof e&&e?("shape"in e?(n=0|(i=e.shape)[0],i=0|i[1]):("radius"in e&&(n=i=0|e.radius),"width"in e&&(n=0|e.width),"height"in e&&(i=0|e.height)),"format"in e&&(u=s[e.format])):"number"==typeof e?(n=0|e,i="number"==typeof r?0|r:n):e||(n=i=1),n!==c.width||i!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=i,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,i),a.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new i(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,i=0|r||n;return n===c.width&&i===c.height?o:(o.width=c.width=n,o.height=c.height=i,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,i),a.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o)},o._reglType="renderbuffer",o._renderbuffer=c,a.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach(function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)}),t.bindRenderbuffer(36161,null)}}},yt=[];yt[6408]=4,yt[6407]=3;var xt=[];xt[5121]=1,xt[5126]=4,xt[36193]=2;var bt=["x","y","z","w"],_t="blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset".split(" "),wt={0:0,1:1,zero:0,one:1,"src color":768,"one minus src color":769,"src alpha":770,"one minus src alpha":771,"dst color":774,"one minus dst color":775,"dst alpha":772,"one minus dst alpha":773,"constant color":32769,"one minus constant color":32770,"constant alpha":32771,"one minus constant alpha":32772,"src alpha saturate":776},kt={never:512,less:513,"<":513,equal:514,"=":514,"==":514,"===":514,lequal:515,"<=":515,greater:516,">":516,notequal:517,"!=":517,"!==":517,gequal:518,">=":518,always:519},Tt={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,"increment wrap":34055,"decrement wrap":34056,invert:5386},At={cw:2304,ccw:2305},Mt=new I(!1,!1,!1,function(){});return function(t){function e(){if(0===Z.length)w&&w.update(),$=null;else{$=q.next(e),h();for(var t=Z.length-1;0<=t;--t){var r=Z[t];r&&r(P,null,0)}v.flush(),w&&w.update()}}function r(){!$&&0<Z.length&&($=q.next(e))}function n(){$&&(q.cancel(e),$=null)}function i(t){t.preventDefault(),n(),J.forEach(function(t){t()})}function o(t){v.getError(),y.restore(),D.restore(),z.restore(),R.restore(),F.restore(),V.restore(),w&&w.restore(),G.procs.refresh(),r(),K.forEach(function(t){t()})}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach(function(n){var a=t[n];U.isDynamic(a)?r[n]=U.unbox(a,n):e[n]=a}),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),a=e(t.attributes||{}),i=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach(function(n){r[t+"."+n]=e[n]})}}var r=j({},t);return delete r.uniforms,delete r.attributes,delete r.context,"stencil"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e("blend"),e("depth"),e("cull"),e("stencil"),e("polygonOffset"),e("scissor"),e("sample"),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=G.compile(i,a,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return j(function(t,e){var r;if("function"==typeof t)return l.call(this,null,t,0);if("function"==typeof e)if("number"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if("number"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}},{stats:t})}function l(t,e){var r=0;G.procs.poll();var n=e.color;n&&(v.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),"depth"in e&&(v.clearDepth(+e.depth),r|=256),"stencil"in e&&(v.clearStencil(0|e.stencil),r|=1024),v.clear(r)}function c(t){return Z.push(t),r(),{cancel:function(){var e=N(Z,t);Z[e]=function t(){var e=N(Z,t);Z[e]=Z[Z.length-1],--Z.length,0>=Z.length&&n()}}}}function u(){var t=W.viewport,e=W.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=v.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=v.drawingBufferHeight}function h(){P.tick+=1,P.time=g(),u(),G.procs.poll()}function f(){u(),G.procs.refresh(),w&&w.update()}function g(){return(H()-k)/1e3}if(!(t=a(t)))return null;var v=t.gl,m=v.getContextAttributes();v.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},a=0;a<e.extensions.length;++a){var i=e.extensions[a];if(!r(i))return e.onDestroy(),e.onDone('"'+i+'" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach(function(t){if(n[t]&&!r(t))throw Error("(regl): error restoring extension "+t)})}}}(v,t);if(!y)return null;var x=function(){var t={"":0},e=[""];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var a=o.pop()||new r;a.startQueryIndex=t,a.endQueryIndex=e,a.sum=0,a.stats=n,s.push(a)}if(!e.ext_disjoint_timer_query)return null;var a=[],i=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=a.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),i.push(r),n(i.length-1,i.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=i.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<i.length;++r){var u=i[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),a.push(u)):i[t++]=u,l[r+1]=n,c[r+1]=t}for(i.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return i.length},clear:function(){a.push.apply(a,i);for(var t=0;t<a.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(a[t]);i.length=0,a.length=0},restore:function(){i.length=0,a.length=0}}}(0,_),k=H(),L=v.drawingBufferWidth,C=v.drawingBufferHeight,P={tick:0,time:0,viewportWidth:L,viewportHeight:C,framebufferWidth:L,framebufferHeight:C,drawingBufferWidth:L,drawingBufferHeight:C,pixelRatio:t.pixelRatio},O=Y(v,_),z=(L=function(t,e,r,n){for(t=r.maxAttributes,e=Array(t),r=0;r<t;++r)e[r]=new M;return{Record:M,scope:{},state:e}}(v,_,O),p(v,b,t,L)),I=d(v,_,z,b),D=S(v,x,b,t),R=T(v,_,O,function(){G.procs.poll()},P,b,t),F=mt(v,_,0,b,t),V=A(v,_,O,R,F,b),G=B(v,x,_,O,z,I,0,V,{},L,D,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),W=(x=E(v,V,G.procs.poll,P),G.next),X=v.canvas,Z=[],J=[],K=[],Q=[t.onDestroy],$=null;X&&(X.addEventListener("webglcontextlost",i,!1),X.addEventListener("webglcontextrestored",o,!1));var tt=V.setFBO=s({framebuffer:U.define.call(null,1,"framebuffer")});return f(),m=j(s,{clear:function(t){if("framebuffer"in t)if(t.framebuffer&&"framebufferCube"===t.framebuffer_reglType)for(var e=0;6>e;++e)tt(j({framebuffer:t.framebuffer.faces[e]},t),l);else tt(t,l);else l(0,t)},prop:U.define.bind(null,1),context:U.define.bind(null,2),this:U.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return I.create(t,!1)},texture:R.create2D,cube:R.createCube,renderbuffer:F.create,framebuffer:V.create,framebufferCube:V.createCube,attributes:m,frame:c,on:function(t,e){var r;switch(t){case"frame":return c(e);case"lost":r=J;break;case"restore":r=K;break;case"destroy":r=Q}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:O,hasExtension:function(t){return 0<=O.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){Z.length=0,n(),X&&(X.removeEventListener("webglcontextlost",i),X.removeEventListener("webglcontextrestored",o)),D.clear(),V.clear(),F.clear(),R.clear(),I.clear(),z.clear(),w&&w.clear(),Q.forEach(function(t){t()})},_gl:v,_refresh:f,poll:function(){h(),w&&w.update()},now:g,stats:b}),t.onDone(null,m),m}},"object"==typeof r&&"undefined"!=typeof e?e.exports=a():n.createREGL=a()},{}],501:[function(t,e,r){"use strict";var n,a="";e.exports=function(t,e){if("string"!=typeof t)throw new TypeError("expected a string");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||"undefined"==typeof n)n=t,a="";else if(a.length>=r)return a.substr(0,r);for(;r>a.length&&e>1;)1&e&&(a+=t),e>>=1,t+=t;return a=(a+=t).substr(0,r)}},{}],502:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{}],503:[function(t,e,r){"use strict";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,a=e-2;a>=0;--a){var i=r,o=t[a],s=(r=i+o)-i,l=o-s;l&&(t[--n]=r,r=l)}for(var c=0,a=n;a<e;++a){var i=t[a],o=r,s=(r=i+o)-i,l=o-s;l&&(t[c++]=l)}return t[c++]=r,t.length=c,t}},{}],504:[function(t,e,r){"use strict";var n=t("two-product"),a=t("robust-sum"),i=t("robust-scale"),o=t("robust-compress"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var a=r[n-1]=new Array(t.length-1),i=0,o=0;i<t.length;++i)i!==e&&(a[o++]=t[n][i]);return r}function c(t){if(2===t.length)return["sum(prod(",t[0][0],",",t[1][1],"),prod(-",t[0][1],",",t[1][0],"))"].join("");for(var e=[],r=0;r<t.length;++r)e.push(["scale(",c(l(t,r)),",",(n=r,1&n?"-":""),t[0][r],")"].join(""));return function t(e){if(1===e.length)return e[0];if(2===e.length)return["sum(",e[0],",",e[1],")"].join("");var r=e.length>>1;return["sum(",t(e.slice(0,r)),",",t(e.slice(r)),")"].join("")}(e);var n}function u(t){return new Function("sum","scale","prod","compress",["function robustDeterminant",t,"(m){return compress(",c(function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=["m[",r,"][",n,"]"].join("")}return e}(t)),")};return robustDeterminant",t].join(""))(a,i,n,o)}var h=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;h.length<s;)h.push(u(h.length));for(var t=[],r=["function robustDeterminant(m){switch(m.length){"],n=0;n<s;++n)t.push("det"+n),r.push("case ",n,":return det",n,"(m);");r.push("}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant"),t.push("CACHE","gen",r.join(""));var a=Function.apply(void 0,t);for(e.exports=a.apply(void 0,h.concat([h,u])),n=0;n<h.length;++n)e.exports[n]=h[n]}()},{"robust-compress":503,"robust-scale":510,"robust-sum":513,"two-product":541}],505:[function(t,e,r){"use strict";var n=t("two-product"),a=t("robust-sum");e.exports=function(t,e){for(var r=n(t[0],e[0]),i=1;i<t.length;++i)r=a(r,n(t[i],e[i]));return r}},{"robust-sum":513,"two-product":541}],506:[function(t,e,r){"use strict";var n=t("two-product"),a=t("robust-sum"),i=t("robust-subtract"),o=t("robust-scale"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var a=r[n-1]=new Array(t.length-1),i=0,o=0;i<t.length;++i)i!==e&&(a[o++]=t[n][i]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return["sum(",t[0],",",t[1],")"].join("");var e=t.length>>1;return["sum(",c(t.slice(0,e)),",",c(t.slice(e)),")"].join("")}function u(t,e){if("m"===t.charAt(0)){if("w"===e.charAt(0)){var r=t.split("[");return["w",e.substr(1),"m",r[0].substr(1)].join("")}return["prod(",t,",",e,")"].join("")}return u(e,t)}function h(t){if(2===t.length)return[["diff(",u(t[0][0],t[1][1]),",",u(t[1][0],t[0][1]),")"].join("")];for(var e=[],r=0;r<t.length;++r)e.push(["scale(",c(h(l(t,r))),",",(n=r,!0&n?"-":""),t[0][r],")"].join(""));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push(["prod(m",t,"[",n,"],m",t,"[",n,"])"].join(""));return c(r)}function p(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=["m",n,"[",t-r-2,"]"].join("")}return e}(t),u=0;u<t;++u)s[0][u]="1",s[t-1][u]="w"+u;for(u=0;u<t;++u)0==(1&u)?e.push.apply(e,h(l(s,u))):r.push.apply(r,h(l(s,u)));var p=c(e),d=c(r),g="exactInSphere"+t,v=[];for(u=0;u<t;++u)v.push("m"+u);var m=["function ",g,"(",v.join(),"){"];for(u=0;u<t;++u){m.push("var w",u,"=",f(u,t),";");for(var y=0;y<t;++y)y!==u&&m.push("var w",u,"m",y,"=scale(w",u,",m",y,"[0]);")}return m.push("var p=",p,",n=",d,",d=diff(p,n);return d[d.length-1];}return ",g),new Function("sum","diff","prod","scale",m.join(""))(a,i,n,o)}var d=[function(){return 0},function(){return 0},function(){return 0}];!function(){for(;d.length<=s;)d.push(p(d.length));for(var t=[],r=["slow"],n=0;n<=s;++n)t.push("a"+n),r.push("o"+n);var a=["function testInSphere(",t.join(),"){switch(arguments.length){case 0:case 1:return 0;"];for(n=2;n<=s;++n)a.push("case ",n,":return o",n,"(",t.slice(0,n).join(),");");a.push("}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere"),r.push(a.join(""));var i=Function.apply(void 0,r);for(e.exports=i.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=p(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{"robust-scale":510,"robust-subtract":512,"robust-sum":513,"two-product":541}],507:[function(t,e,r){"use strict";var n=t("robust-determinant"),a=6;function i(t){for(var e="robustLinearSolve"+t+"d",r=["function ",e,"(A,b){return ["],a=0;a<t;++a){r.push("det([");for(var i=0;i<t;++i){i>0&&r.push(","),r.push("[");for(var o=0;o<t;++o)o>0&&r.push(","),o===a?r.push("+b[",i,"]"):r.push("+A[",i,"][",o,"]");r.push("]")}r.push("]),")}r.push("det(A)]}return ",e);var s=new Function("det",r.join(""));return s(t<6?n[t]:n)}var o=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;o.length<a;)o.push(i(o.length));for(var t=[],r=["function dispatchLinearSolve(A,b){switch(A.length){"],n=0;n<a;++n)t.push("s"+n),r.push("case ",n,":return s",n,"(A,b);");r.push("}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve"),t.push("CACHE","g",r.join(""));var s=Function.apply(void 0,t);for(e.exports=s.apply(void 0,o.concat([o,i])),n=0;n<a;++n)e.exports[n]=o[n]}()},{"robust-determinant":504}],508:[function(t,e,r){"use strict";var n=t("two-product"),a=t("robust-sum"),i=t("robust-scale"),o=t("robust-subtract"),s=5;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var a=r[n-1]=new Array(t.length-1),i=0,o=0;i<t.length;++i)i!==e&&(a[o++]=t[n][i]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return["sum(",t[0],",",t[1],")"].join("");var e=t.length>>1;return["sum(",c(t.slice(0,e)),",",c(t.slice(e)),")"].join("")}function u(t){if(2===t.length)return[["sum(prod(",t[0][0],",",t[1][1],"),prod(-",t[0][1],",",t[1][0],"))"].join("")];for(var e=[],r=0;r<t.length;++r)e.push(["scale(",c(u(l(t,r))),",",(n=r,1&n?"-":""),t[0][r],")"].join(""));return e;var n}function h(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=["m",n,"[",t-r-1,"]"].join("")}return e}(t),h=[],f=0;f<t;++f)0==(1&f)?e.push.apply(e,u(l(s,f))):r.push.apply(r,u(l(s,f))),h.push("m"+f);var p=c(e),d=c(r),g="orientation"+t+"Exact",v=["function ",g,"(",h.join(),"){var p=",p,",n=",d,",d=sub(p,n);return d[d.length-1];};return ",g].join("");return new Function("sum","prod","scale","sub",v)(a,n,i,o)}var f=h(3),p=h(4),d=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,a=(t[1]-r[1])*(e[0]-r[0]),i=(t[0]-r[0])*(e[1]-r[1]),o=a-i;if(a>0){if(i<=0)return o;n=a+i}else{if(!(a<0))return o;if(i>=0)return o;n=-(a+i)}var s=3.3306690738754716e-16*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var a=t[0]-n[0],i=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],f=r[2]-n[2],d=i*c,g=o*l,v=o*s,m=a*c,y=a*l,x=i*s,b=u*(d-g)+h*(v-m)+f*(y-x),_=7.771561172376103e-16*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(v)+Math.abs(m))*Math.abs(h)+(Math.abs(y)+Math.abs(x))*Math.abs(f));return b>_||-b>_?b:p(t,e,r,n)}];!function(){for(;d.length<=s;)d.push(h(d.length));for(var t=[],r=["slow"],n=0;n<=s;++n)t.push("a"+n),r.push("o"+n);var a=["function getOrientation(",t.join(),"){switch(arguments.length){case 0:case 1:return 0;"];for(n=2;n<=s;++n)a.push("case ",n,":return o",n,"(",t.slice(0,n).join(),");");a.push("}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation"),r.push(a.join(""));var i=Function.apply(void 0,r);for(e.exports=i.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=h(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{"robust-scale":510,"robust-subtract":512,"robust-sum":513,"two-product":541}],509:[function(t,e,r){"use strict";var n=t("robust-sum"),a=t("robust-scale");e.exports=function(t,e){if(1===t.length)return a(e,t[0]);if(1===e.length)return a(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var i=0;i<t.length;++i)r=n(r,a(e,t[i]));else for(var i=0;i<e.length;++i)r=n(r,a(t,e[i]));return r}},{"robust-scale":510,"robust-sum":513}],510:[function(t,e,r){"use strict";var n=t("two-product"),a=t("two-sum");e.exports=function(t,e){var r=t.length;if(1===r){var i=n(t[0],e);return i[0]?i:[i[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];a(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,g=d-f,v=p-g;s[1]=d,v&&(o[c++]=v)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{"two-product":541,"two-sum":542}],511:[function(t,e,r){"use strict";e.exports=function(t,e,r,a){var i=n(t,r,a),o=n(e,r,a);if(i>0&&o>0||i<0&&o<0)return!1;var s=n(r,t,e),l=n(a,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===i&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var a=0;a<2;++a){var i=t[a],o=e[a],s=Math.min(i,o),l=Math.max(i,o),c=r[a],u=n[a],h=Math.min(c,u),f=Math.max(c,u);if(f<s||l<h)return!1}return!0}(t,e,r,a);return!0};var n=t("robust-orientation")[3]},{"robust-orientation":508}],512:[function(t,e,r){"use strict";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,a=t-(r-n)+(e-n);if(a)return[a,r];return[r]}(t[0],-e[0]);var a,i,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&f<d||c>=n?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,v,m=a+i,y=m-a,x=i-y,b=x,_=m;for(;l<r&&c<n;)f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(i=b)-(y=(m=a+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(i=b)-(y=(m=(a=h)+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(i=b)-(y=(m=(a=p)+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],513:[function(t,e,r){"use strict";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,a=t-(r-n)+(e-n);if(a)return[a,r];return[r]}(t[0],e[0]);var a,i,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&f<d||c>=n?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,v,m=a+i,y=m-a,x=i-y,b=x,_=m;for(;l<r&&c<n;)f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(i=b)-(y=(m=a+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(i=b)-(y=(m=(a=h)+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(i=b)-(y=(m=(a=p)+i)-a))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],514:[function(t,e,r){"use strict";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],515:[function(t,e,r){"use strict";e.exports=function(t){return a(n(t))};var n=t("boundary-cells"),a=t("reduce-simplicial-complex")},{"boundary-cells":96,"reduce-simplicial-complex":490}],516:[function(t,e,r){"use strict";e.exports=function(t,e,r,s){r=r||0,"undefined"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=a.mallocUint8(r),i=0;i<r;++i)n[i]=t[i]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=a.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],e=u.length,h=0;h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}i(n(s,[l/2|0,2]));for(var g=2,c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,i){for(var o=t.data,s=t.shape[0],l=a.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-i)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=a.mallocInt32(2*e),n=t.shape[0],i=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=i[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),a=0;a<e;++a)n[a]=[r[2*a],r[2*a+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return a.free(l),a.free(c.data),a.free(u.data),a.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=t("ndarray"),a=t("typedarray-pool"),i=t("ndarray-sort"),o=t("./lib/codegen")},{"./lib/codegen":517,ndarray:451,"ndarray-sort":449,"typedarray-pool":543}],517:[function(t,e,r){"use strict";e.exports=function(t){var e=i[t];e||(e=i[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var i=1;i<=t;++i)for(var o=r[i]=a(i),s=0;s<o.length;++s)e=Math.max(e,o[i].length);var l=["function B(C,E,i,j){","var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];","while(l<h){","var m=(l+h)>>1,v=E[2*m+1];","if(v===b){return m}","if(b<v){h=m}else{l=m+1}","}","return l;","};","function getContour",t,"d(F,E,C,S){","var n=F.length,R=[];","for(var i=0;i<n;++i){var c=F[i],l=c.length;"];function c(t){if(!(t.length<=0)){l.push("R.push(");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(","),l.push("[");for(var n=0;n<r.length;++n){var a=r[n];n>0&&l.push(","),l.push("B(C,E,c[",a[0],"],c[",a[1],"])")}l.push("]")}l.push(");")}}for(var i=t+1;i>1;--i){i<t+1&&l.push("else "),l.push("if(l===",i,"){");for(var u=[],s=0;s<i;++s)u.push("(S[c["+s+"]]<<"+s+")");l.push("var M=",u.join("+"),";if(M===0||M===",(1<<i)-1,"){continue}switch(M){");for(var o=r[i-1],s=0;s<o.length;++s)l.push("case ",s,":"),c(o[s]),l.push("break;");l.push("}}")}return l.push("}return R;};return getContour",t,"d"),new Function("pool",l.join(""))(n)}(t));return e};var n=t("typedarray-pool"),a=t("marching-simplex-table"),i={}},{"marching-simplex-table":428,"typedarray-pool":543}],518:[function(t,e,r){"use strict";var n=t("bit-twiddle"),a=t("union-find");function i(t,e){var r=t.length,n=t.length-e.length,a=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||a(t[0],t[1])-a(e[0],e[1]);case 3:var i=t[0]+t[1],o=e[0]+e[1];if(s=i+t[2]-(o+e[2]))return s;var s,l=a(t[0],t[1]),c=a(e[0],e[1]);return(s=a(l,t[2])-a(c,e[2]))||a(l+t[2],i)-a(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return i(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),a=0;a<r;++a)n[a]=[t[a],e[a]];n.sort(o);for(a=0;a<r;++a)t[a]=n[a][0],e[a]=n[a][1];return t}return t.sort(i),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var a=t[n];if(i(a,t[n-1])){if(n===e){e++;continue}t[e++]=a}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,a=-1;r<=n;){var o=r+n>>1,s=i(t[o],e);s<=0?(0===s&&(a=o),r=o+1):s>0&&(n=o-1)}return a}function u(t,e){for(var r=new Array(t.length),a=0,o=r.length;a<o;++a)r[a]=[];for(var s=[],l=(a=0,e.length);a<l;++a)for(var u=e[a],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,g=0;g<h;++g)f&1<<g&&(s[d++]=u[g]);var v=c(t,s);if(!(v<0))for(;r[v++].push(a),!(v>=t.length||0!==i(t[v],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],a=(1<<e+1)-1,i=0;i<t.length;++i)for(var o=t[i],l=a;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,a=t.length;n<a;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,a=t.length;n<a;++n)for(var i=t[n],o=0,s=i.length;o<s;++o)e=r(e,i[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=i,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var a=t.length;n<a;++n)for(var i=t[n],o=0,s=i.length;o<s;++o)r[i[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0|a.length,o=1,l=1<<i;o<l;++o){for(var c=[],u=0;u<i;++u)o>>>u&1&&c.push(a[u]);e.push(c)}return s(e)},r.skeleton=h,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var a=t[r],i=0,o=a.length;i<o;++i){for(var l=new Array(a.length-1),c=0,u=0;c<o;++c)c!==i&&(l[u++]=a[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new a(e),n=0;n<t.length;++n)for(var i=t[n],o=0;o<i.length;++o)for(var s=o+1;s<i.length;++s)r.link(i[o],i[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new a(e.length),n=0;n<t.length;++n)for(var i=t[n],o=0;o<i.length;++o)for(var u=c(e,[i[o]]),f=o+1;f<i.length;++f)r.link(u,c(e,[i[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{"bit-twiddle":93,"union-find":544}],519:[function(t,e,r){arguments[4][93][0].apply(r,arguments)},{dup:93}],520:[function(t,e,r){arguments[4][518][0].apply(r,arguments)},{"bit-twiddle":519,dup:518,"union-find":521}],521:[function(t,e,r){"use strict";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var a=this.ranks,i=this.roots,o=a[r],s=a[n];o<s?i[r]=n:s<o?i[n]=r:(i[n]=r,++a[r])}}},{}],522:[function(t,e,r){"use strict";e.exports=function(t,e,r){for(var i=e.length,o=t.length,s=new Array(i),l=new Array(i),c=new Array(i),u=new Array(i),h=0;h<i;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(var h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error("Input must be a graph");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,a,i,o,c,h=s[t],f=l[t];return h<0||f<0?1/0:(r=e[t],a=e[h],i=e[f],o=Math.abs(n(r,a,i)),c=Math.sqrt(Math.pow(a[0]-i[0],2)+Math.pow(a[1]-i[1],2)),o/c)}function v(t,e){var r=T[t],n=T[e];T[t]=n,T[e]=r,A[r]=e,A[n]=t}function m(t){return c[T[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=m(t);;){var r=e,n=2*t+1,a=2*(t+1),i=t;if(n<S){var o=m(n);o<r&&(i=n,r=o)}if(a<S){var s=m(a);s<r&&(i=a)}if(i===t)return t;v(t,i),t=i}}function b(t){for(var e=m(t);t>0;){var r=y(t);if(r>=0){var n=m(r);if(e<n){v(t,r),t=r;continue}}return t}}function _(){if(S>0){var t=T[0];return v(0,S-1),S-=1,x(0),t}return-1}function w(t,e){var r=T[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((S+=1)-1))}function k(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),A[e]>=0&&w(A[e],g(e)),A[r]>=0&&w(A[r],g(r))}}for(var T=[],A=new Array(i),h=0;h<i;++h){var M=c[h]=g(h);M<1/0?(A[h]=T.length,T.push(h)):A[h]=-1}for(var S=T.length,h=S>>1;h>=0;--h)x(h);for(;;){var E=_();if(E<0||c[E]>r)break;k(E)}for(var L=[],h=0;h<i;++h)u[h]||(A[h]=L.length,L.push(e[h].slice()));L.length;function C(t,e){if(t[e]<0)return e;var r=e,n=e;do{var a=t[n];if(!u[n]||a<0||a===n)break;if(a=t[n=a],!u[n]||a<0||a===n)break;n=a,r=t[r]}while(r!==n);for(var i=e;i!==n;i=t[i])t[i]=n;return n}var P=[];return t.forEach(function(t){var e=C(s,t[0]),r=C(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=A[e],a=A[r];n!==a&&P.push([n,a])}}),a.unique(a.normalize(P)),{positions:L,edges:P}};var n=t("robust-orientation"),a=t("simplicial-complex")},{"robust-orientation":508,"simplicial-complex":520}],523:[function(t,e,r){"use strict";e.exports=function(t,e){var r,i,o,s;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0]))return a(e,t);r=e[1],i=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-a(t,e);o=t[1],s=t[0]}var l=n(r,i,s),c=n(r,i,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,i),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return i[0]-s[0]};var n=t("robust-orientation");function a(t,e){var r,a,i,o;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],a=e[0]}t[0][1]<t[1][1]?(i=t[0],o=t[1]):(i=t[1],o=t[0]);var h=n(a,r,i);return h||((h=n(a,r,o))||o-a)}},{"robust-orientation":508}],524:[function(t,e,r){"use strict";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),i=0;i<e;++i){var l=t[i],c=l[0][0]<l[1][0];n[2*i]=new h(l[0][0],l,c,i),n[2*i+1]=new h(l[1][0],l,!c,i)}n.sort(function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))});for(var f=a(o),p=[],d=[],g=[],i=0;i<r;){for(var v=n[i].x,m=[];i<r;){var y=n[i];if(y.x!==v)break;i+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(m.push(new u(y.segment[0][1],y.index,!0,!0)),m.push(new u(y.segment[1][1],y.index,!1,!1))):(m.push(new u(y.segment[1][1],y.index,!0,!1)),m.push(new u(y.segment[0][1],y.index,!1,!0)))):f=y.create?f.insert(y.segment,y.index):f.remove(y.segment)}p.push(f.root),d.push(v),g.push(m)}return new s(p,d,g)};var n=t("binary-search-bounds"),a=t("functional-red-black-tree"),i=t("robust-orientation"),o=t("./lib/order-segments");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,a,o=t.key;o[0][0]<o[1][0]?(n=o[0],a=o[1]):(n=o[1],a=o[0]);var s=i(n,a,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),a=-1;if(r&&(a=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,a=u.value):(a=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return a;p=h[f]}}if(p.start)if(s){var d=i(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(a=p.index)}else a=p.index;else p.y!==t[1]&&(a=p.index)}}}return a}},{"./lib/order-segments":523,"binary-search-bounds":92,"functional-red-black-tree":232,"robust-orientation":508}],525:[function(t,e,r){"use strict";var n=t("robust-dot-product"),a=t("robust-sum");function i(t,e){var r=a(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var a=-e/(n-e);a<0?a=0:a>1&&(a=1);for(var i=1-a,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=a*t[l]+i*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],a=i(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=i(l=t[c],e);if(a<0&&u>0||a>0&&u<0){var h=o(s,u,l,a);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),a=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=i(t[t.length-1],e),a=t[t.length-1],s=t[0],l=0;l<t.length;++l,a=s){var c=i(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(a,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=i(t[t.length-1],e),a=t[t.length-1],s=t[0],l=0;l<t.length;++l,a=s){var c=i(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(a,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{"robust-dot-product":505,"robust-sum":513}],526:[function(t,e,r){!function(){"use strict";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\x25]+/,modulo:/^\x25{2}/,placeholder:/^\x25(?:([1-9]\d*)\$|\(([^)]+)\))?(\+)?(0|'[^$])?(-)?(\d+)?(?:\.(\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\d]*)/i,key_access:/^\.([a-z_][a-z_\d]*)/i,index_access:/^\[(\d+)\]/,sign:/^[+-]/};function e(r){return function(r,n){var a,i,o,s,l,c,u,h,f,p=1,d=r.length,g="";for(i=0;i<d;i++)if("string"==typeof r[i])g+=r[i];else if("object"==typeof r[i]){if((s=r[i]).keys)for(a=n[p],o=0;o<s.keys.length;o++){if(null==a)throw new Error(e('[sprintf] Cannot access property "%s" of undefined value "%s"',s.keys[o],s.keys[o-1]));a=a[s.keys[o]]}else a=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&a instanceof Function&&(a=a()),t.numeric_arg.test(s.type)&&"number"!=typeof a&&isNaN(a))throw new TypeError(e("[sprintf] expecting number but found %T",a));switch(t.number.test(s.type)&&(h=a>=0),s.type){case"b":a=parseInt(a,10).toString(2);break;case"c":a=String.fromCharCode(parseInt(a,10));break;case"d":case"i":a=parseInt(a,10);break;case"j":a=JSON.stringify(a,null,s.width?parseInt(s.width):0);break;case"e":a=s.precision?parseFloat(a).toExponential(s.precision):parseFloat(a).toExponential();break;case"f":a=s.precision?parseFloat(a).toFixed(s.precision):parseFloat(a);break;case"g":a=s.precision?String(Number(a.toPrecision(s.precision))):parseFloat(a);break;case"o":a=(parseInt(a,10)>>>0).toString(8);break;case"s":a=String(a),a=s.precision?a.substring(0,s.precision):a;break;case"t":a=String(!!a),a=s.precision?a.substring(0,s.precision):a;break;case"T":a=Object.prototype.toString.call(a).slice(8,-1).toLowerCase(),a=s.precision?a.substring(0,s.precision):a;break;case"u":a=parseInt(a,10)>>>0;break;case"v":a=a.valueOf(),a=s.precision?a.substring(0,s.precision):a;break;case"x":a=(parseInt(a,10)>>>0).toString(16);break;case"X":a=(parseInt(a,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=a:(!t.number.test(s.type)||h&&!s.sign?f="":(f=h?"+":"-",a=a.toString().replace(t.sign,"")),c=s.pad_char?"0"===s.pad_char?"0":s.pad_char.charAt(1):" ",u=s.width-(f+a).length,l=s.width&&u>0?c.repeat(u):"",g+=s.align?f+a+l:"0"===c?f+l+a:l+f+a)}return g}(function(e){if(a[e])return a[e];var r,n=e,i=[],o=0;for(;n;){if(null!==(r=t.text.exec(n)))i.push(r[0]);else if(null!==(r=t.modulo.exec(n)))i.push("%");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError("[sprintf] unexpected placeholder");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError("[sprintf] failed to parse named argument key");for(s.push(c[1]);""!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError("[sprintf] failed to parse named argument key");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error("[sprintf] mixing positional and named placeholders is not (yet) supported");i.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return a[e]=i}(r),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}var a=Object.create(null);"undefined"!=typeof r&&(r.sprintf=e,r.vsprintf=n),"undefined"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],527:[function(t,e,r){"use strict";var n=t("parenthesis");e.exports=function(t,e,r){if(null==t)throw Error("First argument should be a string");if(null==e)throw Error("Separator should be a string or a RegExp");r?("string"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=["[]","()","{}","<>",'""',"''","``","\u201c\u201d","\xab\xbb"]:("string"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map(function(t){return 1===t.length&&(t+=t),t}));var a=n.parse(t,{flat:!0,brackets:r.ignore}),i=a[0].split(e);if(r.escape){for(var o=[],s=0;s<i.length;s++){var l=i[s],c=i[s+1];"\\"===l[l.length-1]&&"\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}i=o}for(s=0;s<i.length;s++)a[0]=i[s],i[s]=n.stringify(a,{flat:!0});return i}},{parenthesis:459}],528:[function(t,e,r){"use strict";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),a=new Array(e),i=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,a[l]=!1,i[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,a[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(i[e]<p.length){for(var d=i[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,a[g]=!0,u+=1,l.push(g),c.push(g);break}a[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}i[e]=d}else{if(n[e]===r[e]){for(var v=[],m=[],y=0,d=l.length-1;d>=0;--d){var x=l[d];if(a[x]=!1,v.push(x),m.push(s[x]),y+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(v);for(var b=new Array(y),d=0;d<m.length;d++)for(var _=0;_<m[d].length;_++)b[--y]=m[d][_];f.push(b)}c.pop()}}}for(var l=0;l<e;++l)r[l]<0&&p(l);for(var l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort(function(t,e){return t-e}),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);f[l]=c}}return{components:h,adjacencyList:f}}},{}],529:[function(t,e,r){"use strict";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=i(t,e),n=r.length,a=new Array(n),o=new Array(n),s=0;s<n;++s)a[s]=[r[s]],o[s]=[s];return{positions:a,cells:o}}(t,e);var r=t.order.join()+"-"+t.dtype,s=o[r],e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,i=["'use strict';"],o="surfaceNets"+t.join("_")+"d"+e;i.push("var contour=genContour({","order:[",t.join(),"],","scalarArguments: 3,","phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },"),"generic"===e&&i.push("getters:[0],");for(var s=[],l=[],c=0;c<r;++c)s.push("d"+c),l.push("d"+c);for(var c=0;c<1<<r;++c)s.push("v"+c),l.push("v"+c);for(var c=0;c<1<<r;++c)s.push("p"+c),l.push("p"+c);s.push("a","b","c"),l.push("a","c"),i.push("vertex:function vertexFunc(",s.join(),"){");for(var u=[],c=0;c<1<<r;++c)u.push("(p"+c+"<<"+c+")");i.push("var m=(",u.join("+"),")|0;if(m===0||m===",(1<<(1<<r))-1,"){return}");var h=[],f=[];1<<(1<<r)<=128?(i.push("switch(m){"),f=i):i.push("switch(m>>>7){");for(var c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){h.length>0&&f.push("}}");var p="vExtra"+h.length;i.push("case ",c>>>7,":",p,"(m&0x7f,",l.join(),");break;"),f=["function ",p,"(m,",l.join(),"){switch(m){"],h.push(f)}f.push("case ",127&c,":");for(var d=new Array(r),g=new Array(r),v=new Array(r),m=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],v[x]=0,m[x]=0;for(var x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push("v"+_+"-v"+x):(g[b].push("v"+x+"-v"+_),w=-w),w<0?(d[b].push("-v"+x+"-v"+_),v[b]+=2):(d[b].push("v"+x+"+v"+_),v[b]-=2),y+=1;for(var k=0;k<r;++k)k!==b&&(_&1<<k?m[k]+=1:m[k]-=1)}}for(var T=[],b=0;b<r;++b)if(0===d[b].length)T.push("d"+b+"-0.5");else{var A="";v[b]<0?A=v[b]+"*c":v[b]>0&&(A="+"+v[b]+"*c");var M=d[b].length/y*.5,S=.5+m[b]/y*.5;T.push("d"+b+"-"+S+"-"+M+"*("+d[b].join("+")+A+")/("+g[b].join("+")+")")}f.push("a.push([",T.join(),"]);","break;")}i.push("}},"),h.length>0&&f.push("}}");for(var E=[],c=0;c<1<<r-1;++c)E.push("v"+c);E.push("c0","c1","p0","p1","a","b","c"),i.push("cell:function cellFunc(",E.join(),"){");var L=a(r-1);i.push("if(p0){b.push(",L.map(function(t){return"["+t.map(function(t){return"v"+t})+"]"}).join(),")}else{b.push(",L.map(function(t){var e=t.slice();return e.reverse(),"["+e.map(function(t){return"v"+t})+"]"}).join(),")}}});function ",o,"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return ",o,";");for(var c=0;c<h.length;++c)i.push(h[c].join(""));return new Function("genContour",i.join(""))(n)}(t.order,t.dtype));return s(t,e)};var n=t("ndarray-extract-contour"),a=t("triangulate-hypercube"),i=t("zero-crossings");var o={}},{"ndarray-extract-contour":440,"triangulate-hypercube":539,"zero-crossings":572}],530:[function(t,e,r){"use strict";Object.defineProperty(r,"__esModule",{value:!0});var n=function(){return function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,a=!1,i=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){a=!0,i=t}finally{try{!n&&s.return&&s.return()}finally{if(a)throw i}}return r}(t,e);throw new TypeError("Invalid attempt to destructure non-iterable instance")}}(),a=2*Math.PI,i=function(t,e,r,n,a,i,o){var s=t.x,l=t.y;return{x:n*(s*=e)-a*(l*=r)+i,y:a*s+n*l+o}},o=function(t,e){var r=.551915024494*(e<0?-1:1),n=Math.cos(t),a=Math.sin(t),i=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-a*r,y:a+n*r},{x:i+o*r,y:o-i*r},{x:i,y:o}]},s=function(t,e,r,n){var a=t*n-e*r<0?-1:1,i=(t*r+e*n)/(Math.sqrt(t*t+e*e)*Math.sqrt(t*t+e*e));return i>1&&(i=1),i<-1&&(i=-1),a*Math.acos(i)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,h=t.ry,f=t.xAxisRotation,p=void 0===f?0:f,d=t.largeArcFlag,g=void 0===d?0:d,v=t.sweepFlag,m=void 0===v?0:v,y=[];if(0===u||0===h)return[];var x=Math.sin(p*a/360),b=Math.cos(p*a/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),h=Math.abs(h);var k=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(h,2);k>1&&(u*=Math.sqrt(k),h*=Math.sqrt(k));var T=function(t,e,r,n,i,o,l,c,u,h,f,p){var d=Math.pow(i,2),g=Math.pow(o,2),v=Math.pow(f,2),m=Math.pow(p,2),y=d*g-d*m-g*v;y<0&&(y=0),y/=d*m+g*v;var x=(y=Math.sqrt(y)*(l===c?-1:1))*i/o*p,b=y*-o/i*f,_=h*x-u*b+(t+r)/2,w=u*x+h*b+(e+n)/2,k=(f-x)/i,T=(p-b)/o,A=(-f-x)/i,M=(-p-b)/o,S=s(1,0,k,T),E=s(k,T,A,M);return 0===c&&E>0&&(E-=a),1===c&&E<0&&(E+=a),[_,w,S,E]}(e,r,l,c,u,h,g,m,x,b,_,w),A=n(T,4),M=A[0],S=A[1],E=A[2],L=A[3],C=Math.abs(L)/(a/4);Math.abs(1-C)<1e-7&&(C=1);var P=Math.max(Math.ceil(C),1);L/=P;for(var O=0;O<P;O++)y.push(o(E,L)),E+=L;return y.map(function(t){var e=i(t[0],u,h,b,x,M,S),r=e.x,n=e.y,a=i(t[1],u,h,b,x,M,S),o=a.x,s=a.y,l=i(t[2],u,h,b,x,M,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}})},e.exports=r.default},{}],531:[function(t,e,r){"use strict";var n=t("parse-svg-path"),a=t("abs-svg-path"),i=t("normalize-svg-path"),o=t("is-svg-path"),s=t("assert");e.exports=function(t){Array.isArray(t)&&1===t.length&&"string"==typeof t[0]&&(t=t[0]);"string"==typeof t&&(s(o(t),"String is not an SVG path."),t=n(t));if(s(Array.isArray(t),"Argument should be a string or an array of path segments."),t=a(t),!(t=i(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{"abs-svg-path":62,assert:69,"is-svg-path":425,"normalize-svg-path":532,"parse-svg-path":461}],532:[function(t,e,r){"use strict";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,g=t.length;d<g;d++){var v=t[d],m=v[0];switch(m){case"M":l=v[1],c=v[2];break;case"A":var y=n({px:f,py:p,cx:v[6],cy:v[7],rx:v[1],ry:v[2],xAxisRotation:v[3],largeArcFlag:v[4],sweepFlag:v[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],v=["C",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(v);break;case"S":var _=f,w=p;"C"!=e&&"S"!=e||(_+=_-o,w+=w-s),v=["C",_,w,v[1],v[2],v[3],v[4]];break;case"T":"Q"==e||"T"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),v=i(f,p,u,h,v[1],v[2]);break;case"Q":u=v[1],h=v[2],v=i(f,p,v[1],v[2],v[3],v[4]);break;case"L":v=a(f,p,v[1],v[2]);break;case"H":v=a(f,p,v[1],p);break;case"V":v=a(f,p,f,v[1]);break;case"Z":v=a(f,p,l,c)}e=m,f=v[v.length-2],p=v[v.length-1],v.length>4?(o=v[v.length-4],s=v[v.length-3]):(o=f,s=p),r.push(v)}return r};var n=t("svg-arc-to-cubic-bezier");function a(t,e,r,n){return["C",t,e,r,n,r,n]}function i(t,e,r,n,a,i){return["C",t/3+2/3*r,e/3+2/3*n,a/3+2/3*r,i/3+2/3*n,a,i]}},{"svg-arc-to-cubic-bezier":530}],533:[function(t,e,r){"use strict";var n,a=t("svg-path-bounds"),i=t("parse-svg-path"),o=t("draw-svg-path"),s=t("is-svg-path"),l=t("bitmap-sdf"),c=document.createElement("canvas"),u=c.getContext("2d");e.exports=function(t,e){if(!s(t))throw Error("Argument should be valid svg path string");e||(e={});var r,h;e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||a(t),g=[r/(d[2]-d[0]),h/(d[3]-d[1])],v=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle="black",u.fillRect(0,0,r,h),u.fillStyle="white",p&&("number"!=typeof p&&(p=1),u.strokeStyle=p>0?"white":"black",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*h),u.scale(v,v),function(){if(null!=n)return n;var t=document.createElement("canvas").getContext("2d");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D("M0,0h1v1h-1v-1Z");t.fillStyle="black",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var m=new Path2D(t);u.fill(m),p&&u.stroke(m)}else{var y=i(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},{"bitmap-sdf":94,"draw-svg-path":169,"is-svg-path":425,"parse-svg-path":461,"svg-path-bounds":531}],534:[function(t,e,r){(function(r){"use strict";e.exports=function t(e,r,a){var a=a||{};var o=i[e];o||(o=i[e]={" ":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),a=0,i=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[a++]=c[0],n[a++]=c[1]+1.4,i=Math.max(c[0],i)}return{data:n,shape:i}}(n(r,{triangles:!0,font:e,textAlign:a.textAlign||"left",textBaseline:"alphabetic",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\d|\s)/),c=new Array(l.length),u=0,h=0,f=0;f<l.length;++f)c[f]=t(e,l[f]),u+=c[f].data.length,h+=c[f].shape,f>0&&(h+=.02);for(var p=new Float32Array(u),d=0,g=-.5*h,f=0;f<c.length;++f){for(var v=c[f].data,m=0;m<v.length;m+=2)p[d++]=v[m]+g,p[d++]=v[m+1];g+=c[f].shape+.02}s=o[r]={data:p,shape:h}}return s};var n=t("vectorize-text"),a=window||r.global||{},i=a.__TEXT_CACHE||{};a.__TEXT_CACHE={}}).call(this,t("_process"))},{_process:483,"vectorize-text":548}],535:[function(t,e,r){!function(t){var r=/^\s+/,n=/\s+$/,a=0,i=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||"")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var a={r:0,g:0,b:0},i=1,l=null,c=null,u=null,h=!1,f=!1;"string"==typeof e&&(e=function(t){t=t.replace(r,"").replace(n,"").toLowerCase();var e,a=!1;if(S[t])t=S[t],a=!0;else if("transparent"==t)return{r:0,g:0,b:0,a:0,format:"name"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),a:R(e[4]),format:a?"name":"hex8"};if(e=j.hex6.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),format:a?"name":"hex"};if(e=j.hex4.exec(t))return{r:O(e[1]+""+e[1]),g:O(e[2]+""+e[2]),b:O(e[3]+""+e[3]),a:R(e[4]+""+e[4]),format:a?"name":"hex8"};if(e=j.hex3.exec(t))return{r:O(e[1]+""+e[1]),g:O(e[2]+""+e[2]),b:O(e[3]+""+e[3]),format:a?"name":"hex"};return!1}(e));"object"==typeof e&&(V(e.r)&&V(e.g)&&V(e.b)?(p=e.r,d=e.g,g=e.b,a={r:255*C(p,255),g:255*C(d,255),b:255*C(g,255)},h=!0,f="%"===String(e.r).substr(-1)?"prgb":"rgb"):V(e.h)&&V(e.s)&&V(e.v)?(l=I(e.s),c=I(e.v),a=function(e,r,n){e=6*C(e,360),r=C(r,100),n=C(n,100);var a=t.floor(e),i=e-a,o=n*(1-r),s=n*(1-i*r),l=n*(1-(1-i)*r),c=a%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),h=!0,f="hsv"):V(e.h)&&V(e.s)&&V(e.l)&&(l=I(e.s),u=I(e.l),a=function(t,e,r){var n,a,i;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=C(t,360),e=C(e,100),r=C(r,100),0===e)n=a=i=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),a=o(l,s,t),i=o(l,s,t-1/3)}return{r:255*n,g:255*a,b:255*i}}(e.h,l,u),h=!0,f="hsl"),e.hasOwnProperty("a")&&(i=e.a));var p,d,g;return i=L(i),{ok:h,format:e.format||f,r:o(255,s(a.r,0)),g:o(255,s(a.g,0)),b:o(255,s(a.b,0)),a:i}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=i(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=i(this._r)),this._g<1&&(this._g=i(this._g)),this._b<1&&(this._b=i(this._b)),this._ok=u.ok,this._tc_id=a++}function u(t,e,r){t=C(t,255),e=C(e,255),r=C(r,255);var n,a,i=s(t,e,r),l=o(t,e,r),c=(i+l)/2;if(i==l)n=a=0;else{var u=i-l;switch(a=c>.5?u/(2-i-l):u/(i+l),i){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:a,l:c}}function h(t,e,r){t=C(t,255),e=C(e,255),r=C(r,255);var n,a,i=s(t,e,r),l=o(t,e,r),c=i,u=i-l;if(a=0===i?0:u/i,i==l)n=0;else{switch(i){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:a,v:c}}function f(t,e,r,n){var a=[z(i(t).toString(16)),z(i(e).toString(16)),z(i(r).toString(16))];return n&&a[0].charAt(0)==a[0].charAt(1)&&a[1].charAt(0)==a[1].charAt(1)&&a[2].charAt(0)==a[2].charAt(1)?a[0].charAt(0)+a[1].charAt(0)+a[2].charAt(0):a.join("")}function p(t,e,r,n){return[z(D(n)),z(i(t).toString(16)),z(i(e).toString(16)),z(i(r).toString(16))].join("")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function v(t){return c(t).desaturate(100)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-i(-e/100*255))),r.g=s(0,o(255,r.g-i(-e/100*255))),r.b=s(0,o(255,r.b-i(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function A(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),a=360/r,i=[c(t)];for(n.h=(n.h-(a*e>>1)+720)%360;--e;)n.h=(n.h+a)%360,i.push(c(n));return i}function M(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,a=r.s,i=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:a,v:i})),i=(i+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,a=this.toRgb();return e=a.r/255,r=a.g/255,n=a.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=L(t),this._roundA=i(100*this._a)/100,this},toHsv:function(){var t=h(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=h(this._r,this._g,this._b),e=i(360*t.h),r=i(100*t.s),n=i(100*t.v);return 1==this._a?"hsv("+e+", "+r+"%, "+n+"%)":"hsva("+e+", "+r+"%, "+n+"%, "+this._roundA+")"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=i(360*t.h),r=i(100*t.s),n=i(100*t.l);return 1==this._a?"hsl("+e+", "+r+"%, "+n+"%)":"hsla("+e+", "+r+"%, "+n+"%, "+this._roundA+")"},toHex:function(t){return f(this._r,this._g,this._b,t)},toHexString:function(t){return"#"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,a){var o=[z(i(t).toString(16)),z(i(e).toString(16)),z(i(r).toString(16)),z(D(n))];if(a&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join("")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return"#"+this.toHex8(t)},toRgb:function(){return{r:i(this._r),g:i(this._g),b:i(this._b),a:this._a}},toRgbString:function(){return 1==this._a?"rgb("+i(this._r)+", "+i(this._g)+", "+i(this._b)+")":"rgba("+i(this._r)+", "+i(this._g)+", "+i(this._b)+", "+this._roundA+")"},toPercentageRgb:function(){return{r:i(100*C(this._r,255))+"%",g:i(100*C(this._g,255))+"%",b:i(100*C(this._b,255))+"%",a:this._a}},toPercentageRgbString:function(){return 1==this._a?"rgb("+i(100*C(this._r,255))+"%, "+i(100*C(this._g,255))+"%, "+i(100*C(this._b,255))+"%)":"rgba("+i(100*C(this._r,255))+"%, "+i(100*C(this._g,255))+"%, "+i(100*C(this._b,255))+"%, "+this._roundA+")"},toName:function(){return 0===this._a?"transparent":!(this._a<1)&&(E[f(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e="#"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?"GradientType = 1, ":"";if(t){var a=c(t);r="#"+p(a._r,a._g,a._b,a._a)}return"progid:DXImageTransform.Microsoft.gradient("+n+"startColorstr="+e+",endColorstr="+r+")"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||"hex"!==t&&"hex6"!==t&&"hex3"!==t&&"hex4"!==t&&"hex8"!==t&&"name"!==t?("rgb"===t&&(r=this.toRgbString()),"prgb"===t&&(r=this.toPercentageRgbString()),"hex"!==t&&"hex6"!==t||(r=this.toHexString()),"hex3"===t&&(r=this.toHexString(!0)),"hex4"===t&&(r=this.toHex8String(!0)),"hex8"===t&&(r=this.toHex8String()),"name"===t&&(r=this.toName()),"hsl"===t&&(r=this.toHslString()),"hsv"===t&&(r=this.toHsvString()),r||this.toHexString()):"name"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(m,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(v,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(A,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(M,arguments)},splitcomplement:function(){return this._applyCombination(T,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(k,arguments)}},c.fromRatio=function(t,e){if("object"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]="a"===n?t[n]:I(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),a=c(e).toRgb(),i=r/100;return c({r:(a.r-n.r)*i+n.r,g:(a.g-n.g)*i+n.g,b:(a.b-n.b)*i+n.b,a:(a.a-n.a)*i+n.a})},c.readability=function(e,r){var n=c(e),a=c(r);return(t.max(n.getLuminance(),a.getLuminance())+.05)/(t.min(n.getLuminance(),a.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,a,i=c.readability(t,e);switch(a=!1,(n=function(t){var e,r;e=((t=t||{level:"AA",size:"small"}).level||"AA").toUpperCase(),r=(t.size||"small").toLowerCase(),"AA"!==e&&"AAA"!==e&&(e="AA");"small"!==r&&"large"!==r&&(r="small");return{level:e,size:r}}(r)).level+n.size){case"AAsmall":case"AAAlarge":a=i>=4.5;break;case"AAlarge":a=i>=3;break;case"AAAsmall":a=i>=7}return a},c.mostReadable=function(t,e,r){var n,a,i,o,s=null,l=0;a=(r=r||{}).includeFallbackColors,i=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:i,size:o})||!a?s:(r.includeFallbackColors=!1,c.mostReadable(t,["#fff","#000"],r))};var S=c.names={aliceblue:"f0f8ff",antiquewhite:"faebd7",aqua:"0ff",aquamarine:"7fffd4",azure:"f0ffff",beige:"f5f5dc",bisque:"ffe4c4",black:"000",blanchedalmond:"ffebcd",blue:"00f",blueviolet:"8a2be2",brown:"a52a2a",burlywood:"deb887",burntsienna:"ea7e5d",cadetblue:"5f9ea0",chartreuse:"7fff00",chocolate:"d2691e",coral:"ff7f50",cornflowerblue:"6495ed",cornsilk:"fff8dc",crimson:"dc143c",cyan:"0ff",darkblue:"00008b",darkcyan:"008b8b",darkgoldenrod:"b8860b",darkgray:"a9a9a9",darkgreen:"006400",darkgrey:"a9a9a9",darkkhaki:"bdb76b",darkmagenta:"8b008b",darkolivegreen:"556b2f",darkorange:"ff8c00",darkorchid:"9932cc",darkred:"8b0000",darksalmon:"e9967a",darkseagreen:"8fbc8f",darkslateblue:"483d8b",darkslategray:"2f4f4f",darkslategrey:"2f4f4f",darkturquoise:"00ced1",darkviolet:"9400d3",deeppink:"ff1493",deepskyblue:"00bfff",dimgray:"696969",dimgrey:"696969",dodgerblue:"1e90ff",firebrick:"b22222",floralwhite:"fffaf0",forestgreen:"228b22",fuchsia:"f0f",gainsboro:"dcdcdc",ghostwhite:"f8f8ff",gold:"ffd700",goldenrod:"daa520",gray:"808080",green:"008000",greenyellow:"adff2f",grey:"808080",honeydew:"f0fff0",hotpink:"ff69b4",indianred:"cd5c5c",indigo:"4b0082",ivory:"fffff0",khaki:"f0e68c",lavender:"e6e6fa",lavenderblush:"fff0f5",lawngreen:"7cfc00",lemonchiffon:"fffacd",lightblue:"add8e6",lightcoral:"f08080",lightcyan:"e0ffff",lightgoldenrodyellow:"fafad2",lightgray:"d3d3d3",lightgreen:"90ee90",lightgrey:"d3d3d3",lightpink:"ffb6c1",lightsalmon:"ffa07a",lightseagreen:"20b2aa",lightskyblue:"87cefa",lightslategray:"789",lightslategrey:"789",lightsteelblue:"b0c4de",lightyellow:"ffffe0",lime:"0f0",limegreen:"32cd32",linen:"faf0e6",magenta:"f0f",maroon:"800000",mediumaquamarine:"66cdaa",mediumblue:"0000cd",mediumorchid:"ba55d3",mediumpurple:"9370db",mediumseagreen:"3cb371",mediumslateblue:"7b68ee",mediumspringgreen:"00fa9a",mediumturquoise:"48d1cc",mediumvioletred:"c71585",midnightblue:"191970",mintcream:"f5fffa",mistyrose:"ffe4e1",moccasin:"ffe4b5",navajowhite:"ffdead",navy:"000080",oldlace:"fdf5e6",olive:"808000",olivedrab:"6b8e23",orange:"ffa500",orangered:"ff4500",orchid:"da70d6",palegoldenrod:"eee8aa",palegreen:"98fb98",paleturquoise:"afeeee",palevioletred:"db7093",papayawhip:"ffefd5",peachpuff:"ffdab9",peru:"cd853f",pink:"ffc0cb",plum:"dda0dd",powderblue:"b0e0e6",purple:"800080",rebeccapurple:"663399",red:"f00",rosybrown:"bc8f8f",royalblue:"4169e1",saddlebrown:"8b4513",salmon:"fa8072",sandybrown:"f4a460",seagreen:"2e8b57",seashell:"fff5ee",sienna:"a0522d",silver:"c0c0c0",skyblue:"87ceeb",slateblue:"6a5acd",slategray:"708090",slategrey:"708090",snow:"fffafa",springgreen:"00ff7f",steelblue:"4682b4",tan:"d2b48c",teal:"008080",thistle:"d8bfd8",tomato:"ff6347",turquoise:"40e0d0",violet:"ee82ee",wheat:"f5deb3",white:"fff",whitesmoke:"f5f5f5",yellow:"ff0",yellowgreen:"9acd32"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function L(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function C(e,r){(function(t){return"string"==typeof t&&-1!=t.indexOf(".")&&1===parseFloat(t)})(e)&&(e="100%");var n=function(t){return"string"==typeof t&&-1!=t.indexOf("%")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function O(t){return parseInt(t,16)}function z(t){return 1==t.length?"0"+t:""+t}function I(t){return t<=1&&(t=100*t+"%"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return O(t)/255}var F,B,N,j=(B="[\\s|\\(]+("+(F="(?:[-\\+]?\\d*\\.\\d+%?)|(?:[-\\+]?\\d+%?)")+")[,|\\s]+("+F+")[,|\\s]+("+F+")\\s*\\)?",N="[\\s|\\(]+("+F+")[,|\\s]+("+F+")[,|\\s]+("+F+")[,|\\s]+("+F+")\\s*\\)?",{CSS_UNIT:new RegExp(F),rgb:new RegExp("rgb"+B),rgba:new RegExp("rgba"+N),hsl:new RegExp("hsl"+B),hsla:new RegExp("hsla"+N),hsv:new RegExp("hsv"+B),hsva:new RegExp("hsva"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function V(t){return!!j.CSS_UNIT.exec(t)}"undefined"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],536:[function(t,e,r){"use strict";e.exports=a,e.exports.float32=e.exports.float=a,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=a(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return a(t-a(t))};var n=new Float32Array(1);function a(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],537:[function(t,e,r){"use strict";var n=t("parse-unit");e.exports=o;var a=96;function i(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||"px").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case"%":return e.clientHeight/100;case"ch":case"ex":return function(t,e){var r=document.createElement("div");r.style["font-size"]="128"+t,e.appendChild(r);var n=i(r,"font-size")/128;return e.removeChild(r),n}(t,e);case"em":return i(e,"font-size");case"rem":return i(document.body,"font-size");case"vw":return window.innerWidth/100;case"vh":return window.innerHeight/100;case"vmin":return Math.min(window.innerWidth,window.innerHeight)/100;case"vmax":return Math.max(window.innerWidth,window.innerHeight)/100;case"in":return a;case"cm":return a/2.54;case"mm":return a/25.4;case"pt":return a/72;case"pc":return a/6}return 1}},{"parse-unit":462}],538:[function(t,e,r){var n;n=this,function(t){"use strict";var e=function(t){return t},r=function(t){if(null==(r=t.transform))return e;var r,n,a,i=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){return e||(n=a=0),t[0]=(n+=t[0])*i+s,t[1]=(a+=t[1])*o+l,t}},n=function(t){var e=t.bbox;function n(t){l[0]=t[0],l[1]=t[1],s(l),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}function a(t){switch(t.type){case"GeometryCollection":t.geometries.forEach(a);break;case"Point":n(t.coordinates);break;case"MultiPoint":t.coordinates.forEach(n)}}if(!e){var i,o,s=r(t),l=new Array(2),c=1/0,u=c,h=-c,f=-c;for(o in t.arcs.forEach(function(t){for(var e=-1,r=t.length;++e<r;)i=t[e],l[0]=i[0],l[1]=i[1],s(l,e),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}),t.objects)a(t.objects[o]);e=t.bbox=[c,u,h,f]}return e},a=function(t,e){for(var r,n=t.length,a=n-e;a<--n;)r=t[a],t[a++]=t[n],t[n]=r};function i(t,e){var r=e.id,n=e.bbox,a=null==e.properties?{}:e.properties,i=o(t,e);return null==r&&null==n?{type:"Feature",properties:a,geometry:i}:null==n?{type:"Feature",id:r,properties:a,geometry:i}:{type:"Feature",id:r,bbox:n,properties:a,geometry:i}}function o(t,e){var n=r(t),i=t.arcs;function o(t,e){e.length&&e.pop();for(var r=i[t<0?~t:t],o=0,s=r.length;o<s;++o)e.push(n(r[o].slice(),o));t<0&&a(e,s)}function s(t){return n(t.slice())}function l(t){for(var e=[],r=0,n=t.length;r<n;++r)o(t[r],e);return e.length<2&&e.push(e[0].slice()),e}function c(t){for(var e=l(t);e.length<4;)e.push(e[0].slice());return e}function u(t){return t.map(c)}return function t(e){var r,n=e.type;switch(n){case"GeometryCollection":return{type:n,geometries:e.geometries.map(t)};case"Point":r=s(e.coordinates);break;case"MultiPoint":r=e.coordinates.map(s);break;case"LineString":r=l(e.arcs);break;case"MultiLineString":r=e.arcs.map(l);break;case"Polygon":r=u(e.arcs);break;case"MultiPolygon":r=e.arcs.map(u);break;default:return null}return{type:n,coordinates:r}}(e)}var s=function(t,e){var r={},n={},a={},i=[],o=-1;function s(t,e){for(var n in t){var a=t[n];delete e[a.start],delete a.start,delete a.end,a.forEach(function(t){r[t<0?~t:t]=1}),i.push(a)}}return e.forEach(function(r,n){var a,i=t.arcs[r<0?~r:r];i.length<3&&!i[1][0]&&!i[1][1]&&(a=e[++o],e[o]=r,e[n]=a)}),e.forEach(function(e){var r,i,o=function(e){var r,n=t.arcs[e<0?~e:e],a=n[0];t.transform?(r=[0,0],n.forEach(function(t){r[0]+=t[0],r[1]+=t[1]})):r=n[n.length-1];return e<0?[r,a]:[a,r]}(e),s=o[0],l=o[1];if(r=a[s])if(delete a[r.end],r.push(e),r.end=l,i=n[l]){delete n[i.start];var c=i===r?r:r.concat(i);n[c.start=r.start]=a[c.end=i.end]=c}else n[r.start]=a[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,i=a[s]){delete a[i.end];var u=i===r?r:i.concat(r);n[u.start=i.start]=a[u.end=r.end]=u}else n[r.start]=a[r.end]=r;else n[(r=[e]).start=s]=a[r.end=l]=r}),s(a,n),s(n,a),e.forEach(function(t){r[t<0?~t:t]||i.push([t])}),i};function l(t,e,r){var n,a,i;if(arguments.length>1)n=function(t,e,r){var n,a=[],i=[];function o(t){var e=t<0?~t:t;(i[e]||(i[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case"GeometryCollection":e.geometries.forEach(t);break;case"LineString":s(e.arcs);break;case"MultiLineString":case"Polygon":l(e.arcs);break;case"MultiPolygon":e.arcs.forEach(l)}}(e),i.forEach(null==r?function(t){a.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&a.push(t[0].i)}),a}(0,e,r);else for(a=0,n=new Array(i=t.arcs.length);a<i;++a)n[a]=a;return{type:"MultiLineString",arcs:s(t,n)}}function c(t,e){var r={},n=[],a=[];function i(t){t.forEach(function(e){e.forEach(function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)})}),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,a=t[n-1],i=0;++r<n;)e=a,a=t[r],i+=e[0]*a[1]-e[1]*a[0];return Math.abs(i)}(o(t,{type:"Polygon",arcs:[e]}).coordinates[0])}return e.forEach(function t(e){switch(e.type){case"GeometryCollection":e.geometries.forEach(t);break;case"Polygon":i(e.arcs);break;case"MultiPolygon":e.arcs.forEach(i)}}),n.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,a.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),n.forEach(function(t){delete t._}),{type:"MultiPolygon",arcs:a.map(function(e){var n,a=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].length<2&&a.push(t)})})}),(n=(a=s(t,a)).length)>1)for(var i,o,c=1,u=l(a[0]);c<n;++c)(i=l(a[c]))>u&&(o=a[0],a[0]=a[c],a[c]=o,u=i);return a})}}var u=function(t,e){for(var r=0,n=t.length;r<n;){var a=r+n>>>1;t[a]<e?r=a+1:n=a}return r};t.bbox=n,t.feature=function(t,e){return"GeometryCollection"===e.type?{type:"FeatureCollection",features:e.geometries.map(function(e){return i(t,e)})}:i(t,e)},t.mesh=function(t){return o(t,l.apply(this,arguments))},t.meshArcs=l,t.merge=function(t){return o(t,c.apply(this,arguments))},t.mergeArcs=c,t.neighbors=function(t){var e={},r=t.map(function(){return[]});function n(t,r){t.forEach(function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]})}function a(t,e){t.forEach(function(t){n(t,e)})}var i={LineString:n,MultiLineString:a,Polygon:a,MultiPolygon:function(t,e){t.forEach(function(t){a(t,e)})}};for(var o in t.forEach(function t(e,r){"GeometryCollection"===e.type?e.geometries.forEach(function(e){t(e,r)}):e.type in i&&i[e.type](e.arcs,r)}),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var h=c+1;h<l;++h){var f,p=s[c],d=s[h];(f=r[p])[o=u(f,d)]!==d&&f.splice(o,0,d),(f=r[d])[o=u(f,p)]!==p&&f.splice(o,0,p)}return r},t.quantize=function(t,e){if(!((e=Math.floor(e))>=2))throw new Error("n must be \u22652");if(t.transform)throw new Error("already quantized");var r,a=n(t),i=a[0],o=(a[2]-i)/(e-1)||1,s=a[1],l=(a[3]-s)/(e-1)||1;function c(t){t[0]=Math.round((t[0]-i)/o),t[1]=Math.round((t[1]-s)/l)}function u(t){switch(t.type){case"GeometryCollection":t.geometries.forEach(u);break;case"Point":c(t.coordinates);break;case"MultiPoint":t.coordinates.forEach(c)}}for(r in t.arcs.forEach(function(t){for(var e,r,n,a=1,c=1,u=t.length,h=t[0],f=h[0]=Math.round((h[0]-i)/o),p=h[1]=Math.round((h[1]-s)/l);a<u;++a)h=t[a],r=Math.round((h[0]-i)/o),n=Math.round((h[1]-s)/l),r===f&&n===p||((e=t[c++])[0]=r-f,f=r,e[1]=n-p,p=n);c<2&&((e=t[c++])[0]=0,e[1]=0),t.length=c}),t.objects)u(t.objects[r]);return t.transform={scale:[o,l],translate:[i,s]},t},t.transform=r,t.untransform=function(t){if(null==(r=t.transform))return e;var r,n,a,i=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){e||(n=a=0);var r=Math.round((t[0]-s)/i),c=Math.round((t[1]-l)/o);return t[0]=r-n,n=r,t[1]=c-a,a=c,t}},Object.defineProperty(t,"__esModule",{value:!0})}("object"==typeof r&&"undefined"!=typeof e?r:n.topojson=n.topojson||{})},{}],539:[function(t,e,r){"use strict";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(i(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);a(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t("permutation-rank"),a=t("permutation-parity"),i=t("gamma")},{gamma:233,"permutation-parity":464,"permutation-rank":465}],540:[function(t,e,r){"use strict";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),a=t.radius||1,i=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),"eye"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),a=c(d[0],d[1],d[2]);var g=l(r,d)/a,v=l(n,d)/a;u=Math.acos(g),i=Math.acos(v)}return a=Math.log(a),new f(t.zoomMin,t.zoomMax,e,r,n,a,i,u)};var n=t("filtered-vector"),a=t("gl-mat4/invert"),i=t("gl-mat4/rotate"),o=t("gl-vec3/cross"),s=t("gl-vec3/normalize"),l=t("gl-vec3/dot");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),a=[0,0,0];e>Math.max(r,n)?a[2]=1:r>Math.max(e,n)?a[0]=1:a[1]=1;for(var i=0,o=0,l=0;l<3;++l)i+=t[l]*t[l],o+=a[l]*t[l];for(l=0;l<3;++l)a[l]-=o/i*t[l];return s(a,a),a}function f(t,e,r,a,i,o,s,l){this.center=n(r),this.up=n(a),this.right=n(i),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,a=0,i=0;i<3;++i)a+=e[i]*r[i],n+=e[i]*e[i];var l=Math.sqrt(n),u=0;for(i=0;i<3;++i)r[i]-=e[i]*a/n,u+=r[i]*r[i],e[i]/=l;var h=Math.sqrt(u);for(i=0;i<3;++i)r[i]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],v=Math.cos(d),m=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=v*y,w=m*y,k=x,T=-v*x,A=-m*x,M=y,S=this.computedEye,E=this.computedMatrix;for(i=0;i<3;++i){var L=_*r[i]+w*f[i]+k*e[i];E[4*i+1]=T*r[i]+A*f[i]+M*e[i],E[4*i+2]=L,E[4*i+3]=0}var C=E[1],P=E[5],O=E[9],z=E[2],I=E[6],D=E[10],R=P*D-O*I,F=O*z-C*D,B=C*I-P*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(i=0;i<3;++i)S[i]=b[i]+E[2+4*i]*p;for(i=0;i<3;++i){u=0;for(var j=0;j<3;++j)u+=E[i+4*j]*S[j];E[12+i]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var a=this.computedMatrix;d[0]=a[2],d[1]=a[6],d[2]=a[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)a[4*c]=o[c],a[4*c+1]=s[c],a[4*c+2]=l[c];i(a,a,n,d);for(c=0;c<3;++c)o[c]=a[4*c],s[c]=a[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var a=this.computedMatrix,i=(Math.exp(this.computedRadius[0]),a[1]),o=a[5],s=a[9],l=c(i,o,s);i/=l,o/=l,s/=l;var u=a[0],h=a[4],f=a[8],p=u*i+h*o+f*s,d=c(u-=i*p,h-=o*p,f-=s*p),g=(u/=d)*e+i*r,v=(h/=d)*e+o*r,m=(f/=d)*e+s*r;this.center.move(t,g,v,m);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var i=1;"number"==typeof r&&(i=0|r),(i<0||i>3)&&(i=1);var o=(i+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[i],l=e[i+4],h=e[i+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),g=Math.max(f,p,d);f===g?(s=s<0?-1:1,l=h=0):d===g?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var v=c(s,l,h);s/=v,l/=v,h/=v}var m,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*h,k=c(x-=s*w,b-=l*w,_-=h*w),T=l*(_/=k)-h*(b/=k),A=h*(x/=k)-s*_,M=s*b-l*x,S=c(T,A,M);if(T/=S,A/=S,M/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,b,_),2===i){var E=e[1],L=e[5],C=e[9],P=E*x+L*b+C*_,O=E*T+L*A+C*M;m=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(O,P)}else{var z=e[2],I=e[6],D=e[10],R=z*s+I*l+D*h,F=z*x+I*b+D*_,B=z*T+I*A+D*M;m=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,m),this.recalcMatrix(t);var N=e[2],j=e[6],V=e[10],U=this.computedMatrix;a(U,e);var q=U[15],H=U[12]/q,G=U[13]/q,Y=U[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-V*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var a=(n=n||this.computedUp)[0],i=n[1],o=n[2],s=c(a,i,o);if(!(s<1e-6)){a/=s,i/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,g=d[0],v=d[1],m=d[2],y=a*g+i*v+o*m,x=c(g-=y*a,v-=y*i,m-=y*o);if(!(x<.01&&(x=c(g=i*f-o*h,v=o*l-a*f,m=a*h-i*l))<1e-6)){g/=x,v/=x,m/=x,this.up.set(t,a,i,o),this.right.set(t,g,v,m),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=i*m-o*v,_=o*g-a*m,w=a*v-i*g,k=c(b,_,w),T=a*l+i*h+o*f,A=g*l+v*h+m*f,M=(b/=k)*l+(_/=k)*h+(w/=k)*f,S=Math.asin(u(T)),E=Math.atan2(M,A),L=this.angle._state,C=L[L.length-1],P=L[L.length-2];C%=2*Math.PI;var O=Math.abs(C+2*Math.PI-E),z=Math.abs(C-E),I=Math.abs(C-2*Math.PI-E);O<z&&(C+=2*Math.PI),I<z&&(C-=2*Math.PI),this.angle.jump(this.angle.lastT(),C,P),this.angle.set(t,E,S)}}}}},{"filtered-vector":228,"gl-mat4/invert":267,"gl-mat4/rotate":272,"gl-vec3/cross":335,"gl-vec3/dot":340,"gl-vec3/normalize":357}],541:[function(t,e,r){"use strict";e.exports=function(t,e,r){var a=t*e,i=n*t,o=i-(i-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,h=s*u-(a-o*c-s*c-o*u);if(r)return r[0]=h,r[1]=a,r;return[h,a]};var n=+(Math.pow(2,27)+1)},{}],542:[function(t,e,r){"use strict";e.exports=function(t,e,r){var n=t+e,a=n-t,i=e-a,o=t-(n-a);if(r)return r[0]=o+i,r[1]=n,r;return[o+i,n]}},{}],543:[function(t,e,r){(function(e,n){"use strict";var a=t("bit-twiddle"),i=t("dup");e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:i([32,0]),UINT16:i([32,0]),UINT32:i([32,0]),INT8:i([32,0]),INT16:i([32,0]),INT32:i([32,0]),FLOAT:i([32,0]),DOUBLE:i([32,0]),DATA:i([32,0]),UINT8C:i([32,0]),BUFFER:i([32,0])});var o="undefined"!=typeof Uint8ClampedArray,s=e.__TYPEDARRAY_POOL;s.UINT8C||(s.UINT8C=i([32,0])),s.BUFFER||(s.BUFFER=i([32,0]));var l=s.DATA,c=s.BUFFER;function u(t){if(t){var e=t.length||t.byteLength,r=a.log2(e);l[r].push(t)}}function h(t){t=a.nextPow2(t);var e=a.log2(t),r=l[e];return r.length>0?r.pop():new ArrayBuffer(t)}function f(t){return new Uint8Array(h(t),0,t)}function p(t){return new Uint16Array(h(2*t),0,t)}function d(t){return new Uint32Array(h(4*t),0,t)}function g(t){return new Int8Array(h(t),0,t)}function v(t){return new Int16Array(h(2*t),0,t)}function m(t){return new Int32Array(h(4*t),0,t)}function y(t){return new Float32Array(h(4*t),0,t)}function x(t){return new Float64Array(h(8*t),0,t)}function b(t){return o?new Uint8ClampedArray(h(t),0,t):f(t)}function _(t){return new DataView(h(t),0,t)}function w(t){t=a.nextPow2(t);var e=a.log2(t),r=c[e];return r.length>0?r.pop():new n(t)}r.free=function(t){if(n.isBuffer(t))c[a.log2(t.length)].push(t);else{if("[object ArrayBuffer]"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|a.log2(e);l[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeInt8=r.freeInt16=r.freeInt32=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){u(t.buffer)},r.freeArrayBuffer=u,r.freeBuffer=function(t){c[a.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||"arraybuffer"===e)return h(t);switch(e){case"uint8":return f(t);case"uint16":return p(t);case"uint32":return d(t);case"int8":return g(t);case"int16":return v(t);case"int32":return m(t);case"float":case"float32":return y(t);case"double":case"float64":return x(t);case"uint8_clamped":return b(t);case"buffer":return w(t);case"data":case"dataview":return _(t);default:return null}return null},r.mallocArrayBuffer=h,r.mallocUint8=f,r.mallocUint16=p,r.mallocUint32=d,r.mallocInt8=g,r.mallocInt16=v,r.mallocInt32=m,r.mallocFloat32=r.mallocFloat=y,r.mallocFloat64=r.mallocDouble=x,r.mallocUint8Clamped=b,r.mallocDataView=_,r.mallocBuffer=w,r.clearCache=function(){for(var t=0;t<32;++t)s.UINT8[t].length=0,s.UINT16[t].length=0,s.UINT32[t].length=0,s.INT8[t].length=0,s.INT16[t].length=0,s.INT32[t].length=0,s.FLOAT[t].length=0,s.DOUBLE[t].length=0,s.UINT8C[t].length=0,l[t].length=0,c[t].length=0}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{},t("buffer").Buffer)},{"bit-twiddle":93,buffer:106,dup:171}],544:[function(t,e,r){"use strict";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var a=n.prototype;Object.defineProperty(a,"length",{get:function(){return this.roots.length}}),a.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},a.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},a.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var a=this.ranks,i=this.roots,o=a[r],s=a[n];o<s?i[r]=n:s<o?i[n]=r:(i[n]=r,++a[r])}}},{}],545:[function(t,e,r){"use strict";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,a=t[0],i=t[0],o=1;o<n;++o)if(i=a,e(a=t[o],i)){if(o===r){r++;continue}t[r++]=a}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],a=t[0],i=1;i<r;++i,a=n)if(a=n,(n=t[i])!==a){if(i===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],546:[function(t,e,r){var n=/[\'\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):""}},{}],547:[function(t,e,r){"use strict";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,a=r.length;n<a;n++){var i=r[n];for(var o in i)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===i[o])s=e[o];else{if(!1===i[o])continue;if("function"==typeof i[o]&&void 0===(s=i[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],548:[function(t,e,r){"use strict";e.exports=function(t,e){"object"==typeof e&&null!==e||(e={});return n(t,e.canvas||a,e.context||i,e)};var n=t("./lib/vtext"),a=null,i=null;"undefined"!=typeof document&&((a=document.createElement("canvas")).width=8192,a.height=1024,i=a.getContext("2d"))},{"./lib/vtext":549}],549:[function(t,e,r){e.exports=function(t,e,r,n){var i=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(i=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,i+"px",n.font].filter(function(t){return t}).join(" "),r.textAlign="start",r.textBaseline="alphabetic",r.direction="ltr",w(function(t,e,r,n,i,o){r=r.replace(/\n/g,""),r=!0===o.breaklines?r.replace(/\<br\>/g,"\n"):r.replace(/\<br\>/g," ");var s="",l=[];for(k=0;k<r.length;++k)l[k]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(h,f,r,l)),!0===o.superscripts&&(l=x(p,g,r,l)),!0===o.subscripts&&(l=x(v,y,r,l));var b=[],_="";for(k=0;k<r.length;++k)null!==l[k]&&(_+=r[k],b.push(l[k]));var w,k,T,A,M,S=_.split("\n"),E=S.length,L=Math.round(i*n),C=n,P=2*n,O=0,z=E*L+P;t.height<z&&(t.height=z),e.fillStyle="#000",e.fillRect(0,0,t.width,t.height),e.fillStyle="#fff";var I=0,D="";function R(){if(""!==D){var t=e.measureText(D).width;e.fillText(D,C+T,P+A),T+=t}}function F(){return Math.round(M)+"px "}function B(t,r){var n=""+e.font;if(!0===o.subscripts){var a=t.indexOf(m),i=r.indexOf(m),s=a>-1?parseInt(t[1+a]):0,l=i>-1?parseInt(r[1+i]):0;s!==l&&(n=n.replace(F(),"?px "),M*=Math.pow(.75,l-s),n=n.replace("?px ",F())),A+=.25*L*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),h=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,g=h>-1?parseInt(r[1+h]):0;p!==g&&(n=n.replace(F(),"?px "),M*=Math.pow(.75,g-p),n=n.replace("?px ",F())),A-=.25*L*(g-p)}if(!0===o.bolds){var v=t.indexOf(u)>-1,y=r.indexOf(u)>-1;!v&&y&&(n=x?n.replace("italic ","italic bold "):"bold "+n),v&&!y&&(n=n.replace("bold ",""))}if(!0===o.italics){var x=t.indexOf(f)>-1,b=r.indexOf(f)>-1;!x&&b&&(n="italic "+n),x&&!b&&(n=n.replace("italic ",""))}e.font=n}for(w=0;w<E;++w){var N=S[w]+"\n";for(T=0,A=w*L,M=n,D="",k=0;k<N.length;++k){var j=k+I<b.length?b[k+I]:b[b.length-1];s===j?D+=N[k]:(R(),D=N[k],void 0!==j&&(B(s,j),s=j))}R(),I+=N.length;var V=0|Math.round(T+2*C);O<V&&(O=V)}var U=O,q=P+L*E;return a(e.getImageData(0,0,U,q).data,[q,U,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,i,o,s),n,i)},e.exports.processPixels=w;var n=t("surface-nets"),a=t("ndarray"),i=t("simplify-planar-graph"),o=t("clean-pslg"),s=t("cdt2d"),l=t("planar-graph-to-polyline"),c="b",u="b|",h="i",f="i|",p="sup",d="+",g="+1",v="sub",m="-",y="-1";function x(t,e,r,n){for(var a="<"+t+">",i="</"+t+">",o=a.length,s=i.length,l=e[0]===d||e[0]===m,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(a,c))&&-1!==(u=r.indexOf(i,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+" "+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,g=r.substr(p,u-p).indexOf(a);c=-1!==g?g:u+s}return n}function b(t,e){var r=n(t,128);return e?i(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function _(t,e,r,n){var a=b(t,n),i=function(t,e,r){for(var n=e.textAlign||"start",a=e.textBaseline||"alphabetic",i=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)i[u]=0|Math.min(i[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case"center":h=-.5*(i[0]+o[0]);break;case"right":case"end":h=-o[0];break;case"left":case"start":h=-i[0];break;default:throw new Error("vectorize-text: Unrecognized textAlign: '"+n+"'")}var f=0;switch(a){case"hanging":case"top":f=-i[1];break;case"middle":f=-.5*(i[1]+o[1]);break;case"alphabetic":case"ideographic":f=-3*r;break;case"bottom":f=-o[1];break;default:throw new Error("vectorize-text: Unrecoginized textBaseline: '"+a+"'")}var p=1/r;return"lineHeight"in e?p*=+e.lineHeight:"width"in e?p=e.width/(o[0]-i[0]):"height"in e&&(p=e.height/(o[1]-i[1])),t.map(function(t){return[p*(t[0]+h),p*(t[1]+f)]})}(a.positions,e,r),c=a.edges,u="ccw"===e.orientation;if(o(i,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,i),f=new Array(h.length),p=0;p<h.length;++p){for(var d=h[p],g=new Array(d.length),v=0;v<d.length;++v){for(var m=d[v],y=new Array(m.length),x=0;x<m.length;++x)y[x]=i[m[x]].slice();u&&y.reverse(),g[v]=y}f[p]=g}return f}return e.triangles||e.triangulate||e.triangle?{cells:s(i,c,{delaunay:!1,exterior:!1,interior:!0}),positions:i}:{edges:c,positions:i}}function w(t,e,r){try{return _(t,e,r,!0)}catch(t){}try{return _(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:107,"clean-pslg":117,ndarray:451,"planar-graph-to-polyline":469,"simplify-planar-graph":522,"surface-nets":529}],550:[function(t,e,r){!function(){"use strict";if("undefined"==typeof ses||!ses.ok||ses.ok()){"undefined"!=typeof ses&&(ses.weakMapPermitHostObjects=v);var t=!1;if("function"==typeof WeakMap){var r=WeakMap;if("undefined"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,a=Object.freeze({});if(n.set(a,1),1===n.get(a))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var i=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l="weakmap:",c=l+"ident:"+Math.random()+"___";if("undefined"!=typeof crypto&&"function"==typeof crypto.getRandomValues&&"function"==typeof ArrayBuffer&&"function"==typeof Uint8Array){var u=new ArrayBuffer(25),h=new Uint8Array(u);crypto.getRandomValues(h),c=l+"rand:"+Array.prototype.map.call(h,function(t){return(t%36).toString(36)}).join("")+"___"}if(o(Object,"getOwnPropertyNames",{value:function(t){return i(t).filter(m)}}),"getPropertyNames"in Object){var f=Object.getPropertyNames;o(Object,"getPropertyNames",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,"freeze",{value:function(e){return y(e),t(e)}});var e=Object.seal;o(Object,"seal",{value:function(t){return y(t),e(t)}});var r=Object.preventExtensions;o(Object,"preventExtensions",{value:function(t){return y(t),r(t)}})}();var p=!1,d=0,g=function(){this instanceof g||b();var t=[],e=[],r=d++;return Object.create(g.prototype,{get___:{value:x(function(n,a){var i,o=y(n);return o?r in o?o[r]:a:(i=t.indexOf(n))>=0?e[i]:a})},has___:{value:x(function(e){var n=y(e);return n?r in n:t.indexOf(e)>=0})},set___:{value:x(function(n,a){var i,o=y(n);return o?o[r]=a:(i=t.indexOf(n))>=0?e[i]=a:(i=t.length,e[i]=a,t[i]=n),this})},delete___:{value:x(function(n){var a,i,o=y(n);return o?r in o&&delete o[r]:!((a=t.indexOf(n))<0||(i=t.length-1,t[a]=void 0,e[a]=e[i],t[a]=t[i],t.length=i,e.length=i,0))})}})};g.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),"function"==typeof r?function(){function n(){this instanceof g||b();var e,n=new r,a=void 0,i=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(a||(a=new g),a.set(t,e)),this}:function(t,e){if(i)try{n.set(t,e)}catch(r){a||(a=new g),a.set___(t,e)}else n.set(t,e);return this},Object.create(g.prototype,{get___:{value:x(function(t,e){return a?n.has(t)?n.get(t):a.get___(t,e):n.get(t,e)})},has___:{value:x(function(t){return n.has(t)||!!a&&a.has___(t)})},set___:{value:x(e)},delete___:{value:x(function(t){var e=!!n.delete(t);return a&&a.delete___(t)||e})},permitHostObjects___:{value:x(function(t){if(t!==v)throw new Error("bogus call to permitHostObjects___");i=!0})}})}t&&"undefined"!=typeof Proxy&&(Proxy=void 0),n.prototype=g.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,"constructor",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():("undefined"!=typeof Proxy&&(Proxy=void 0),e.exports=g)}function v(t){t.permitHostObjects___&&t.permitHostObjects___(v)}function m(t){return!(t.substr(0,l.length)==l&&"___"===t.substr(t.length-3))}function y(t){if(t!==Object(t))throw new TypeError("Not an object: "+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function b(){p||"undefined"==typeof console||(p=!0,console.warn("WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future."))}}()},{}],551:[function(t,e,r){var n=t("./hidden-store.js");e.exports=function(){var t={};return function(e){if(("object"!=typeof e||null===e)&&"function"!=typeof e)throw new Error("Weakmap-shim: Key must be object");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{"./hidden-store.js":552}],552:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,"valueOf",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],553:[function(t,e,r){var n=t("./create-store.js");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty("value")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return"value"in t(e)},delete:function(e){return delete t(e).value}}}},{"./create-store.js":551}],554:[function(t,e,r){var n=t("get-canvas-context");e.exports=function(t){return n("webgl",t)}},{"get-canvas-context":234}],555:[function(t,e,r){var n=t("../main"),a=t("object-assign"),i=n.instance();function o(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}o.prototype=new n.baseCalendar,a(o.prototype,{name:"Chinese",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{"":{name:"Chinese",epochs:["BEC","EC"],monthNumbers:function(t,e){if("string"==typeof t){var r=t.match(l);return r?r[0]:""}var n=this._validateYear(t),a=t.month(),i=""+this.toChineseMonth(n,a);return e&&i.length<2&&(i="0"+i),this.isIntercalaryMonth(n,a)&&(i+="i"),i},monthNames:function(t){if("string"==typeof t){var e=t.match(c);return e?e[0]:""}var r=this._validateYear(t),n=t.month(),a=["\u4e00\u6708","\u4e8c\u6708","\u4e09\u6708","\u56db\u6708","\u4e94\u6708","\u516d\u6708","\u4e03\u6708","\u516b\u6708","\u4e5d\u6708","\u5341\u6708","\u5341\u4e00\u6708","\u5341\u4e8c\u6708"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(a="\u95f0"+a),a},monthNamesShort:function(t){if("string"==typeof t){var e=t.match(u);return e?e[0]:""}var r=this._validateYear(t),n=t.month(),a=["\u4e00","\u4e8c","\u4e09","\u56db","\u4e94","\u516d","\u4e03","\u516b","\u4e5d","\u5341","\u5341\u4e00","\u5341\u4e8c"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(a="\u95f0"+a),a},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))"\u95f0"===e[0]&&(r=!0,e=e.substring(1)),"\u6708"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+["\u4e00","\u4e8c","\u4e09","\u56db","\u4e94","\u516d","\u4e03","\u516b","\u4e5d","\u5341","\u5341\u4e00","\u5341\u4e8c"].indexOf(e);else{var a=e[e.length-1];r="i"===a||"I"===a}return this.toMonthIndex(t,n,r)},dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),"number"!=typeof t||t<1888||t>2111)throw e.replace(/\{0\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var a=this.intercalaryMonth(t);if(r&&e!==a||e<1||e>12)throw n.local.invalidMonth.replace(/\{0\}/,this.local.name);return a?!r&&e<=a?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\{0\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var a,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(a=i.newDate(l,c,u)).add(4-(a.dayOfWeek()||7),"d");var h=this.toJD(t,e,r)-a.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\{0\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(a.year()),e=a.month(),r=a.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,a){var i,o,s;if("object"==typeof t)o=t,i=e||{};else{var l="number"==typeof t&&t>=1888&&t<=2111;if(!l)throw new Error("Lunar year outside range 1888-2111");var c="number"==typeof e&&e>=1&&e<=12;if(!c)throw new Error("Lunar month outside range 1 - 12");var u,p="number"==typeof r&&r>=1&&r<=30;if(!p)throw new Error("Lunar day outside range 1 - 30");"object"==typeof n?(u=!1,i=n):(u=!!n,i=a||{}),o={year:t,month:e,day:r,isIntercalary:u}}s=o.day-1;var d,g=h[o.year-h[0]],v=g>>13;d=v?o.month>v?o.month:o.isIntercalary?o.month:o.month-1:o.month-1;for(var m=0;m<d;m++){var y=g&1<<12-m?30:29;s+=y}var x=f[o.year-f[0]],b=new Date(x>>9&4095,(x>>5&15)-1,(31&x)+s);return i.year=b.getFullYear(),i.month=1+b.getMonth(),i.day=b.getDate(),i}(t,s,r,o);return i.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=i.fromJD(t),r=function(t,e,r,n){var a,i;if("object"==typeof t)a=t,i=e||{};else{var o="number"==typeof t&&t>=1888&&t<=2111;if(!o)throw new Error("Solar year outside range 1888-2111");var s="number"==typeof e&&e>=1&&e<=12;if(!s)throw new Error("Solar month outside range 1 - 12");var l="number"==typeof r&&r>=1&&r<=31;if(!l)throw new Error("Solar day outside range 1 - 31");a={year:t,month:e,day:r},i=n||{}}var c=f[a.year-f[0]],u=a.year<<9|a.month<<5|a.day;i.year=u>=c?a.year:a.year-1,c=f[i.year-f[0]];var p,d=new Date(c>>9&4095,(c>>5&15)-1,31&c),g=new Date(a.year,a.month-1,a.day);p=Math.round((g-d)/864e5);var v,m=h[i.year-h[0]];for(v=0;v<13;v++){var y=m&1<<12-v?30:29;if(p<y)break;p-=y}var x=m>>13;!x||v<x?(i.isIntercalary=!1,i.month=1+v):v===x?(i.isIntercalary=!0,i.month=v):(i.isIntercalary=!1,i.month=v);return i.day=1+p,i}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],a=!!e[3],i=this.toMonthIndex(r,n,a),o=+e[4];return this.newDate(r,i,o)},add:function(t,e,r){var n=t.year(),a=t.month(),i=this.isIntercalaryMonth(n,a),s=this.toChineseMonth(n,a),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if("y"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=i&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\s*(-?\d\d\d\d|\d\d)[-/](\d?\d)([iI]?)[-/](\d?\d)/m,l=/^\d?\d[iI]?/m,c=/^\u95f0?\u5341?[\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d]?\u6708/m,u=/^\u95f0?\u5341?[\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{"../main":569,"object-assign":455}],556:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Coptic",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Coptic",epochs:["BAM","AM"],monthNames:["Thout","Paopi","Hathor","Koiak","Tobi","Meshir","Paremhat","Paremoude","Pashons","Paoni","Epip","Mesori","Pi Kogi Enavot"],monthNamesShort:["Tho","Pao","Hath","Koi","Tob","Mesh","Pat","Pad","Pash","Pao","Epi","Meso","PiK"],dayNames:["Tkyriaka","Pesnau","Pshoment","Peftoou","Ptiou","Psoou","Psabbaton"],dayNamesShort:["Tky","Pes","Psh","Pef","Pti","Pso","Psa"],dayNamesMin:["Tk","Pes","Psh","Pef","Pt","Pso","Psa"],digits:null,dateFormat:"dd/mm/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[""].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return(t=a.year())<0&&t++,a.day()+30*(a.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,a=e-30*(n-1)+1;return this.newDate(r,n,a)}}),n.calendars.coptic=i},{"../main":569,"object-assign":455}],557:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Discworld",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Discworld",epochs:["BUC","UC"],monthNames:["Ick","Offle","February","March","April","May","June","Grune","August","Spune","Sektober","Ember","December"],monthNamesShort:["Ick","Off","Feb","Mar","Apr","May","Jun","Gru","Aug","Spu","Sek","Emb","Dec"],dayNames:["Sunday","Octeday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Oct","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Oc","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((a.year()-1)/100)+1]||""}},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return t=a.year()+(a.year()<0?1:0),e=a.month(),(r=a.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:"Fruitbat",21:"Anchovy"};n.calendars.discworld=i},{"../main":569,"object-assign":455}],558:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Ethiopian",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Ethiopian",epochs:["BEE","EE"],monthNames:["Meskerem","Tikemet","Hidar","Tahesas","Tir","Yekatit","Megabit","Miazia","Genbot","Sene","Hamle","Nehase","Pagume"],monthNamesShort:["Mes","Tik","Hid","Tah","Tir","Yek","Meg","Mia","Gen","Sen","Ham","Neh","Pag"],dayNames:["Ehud","Segno","Maksegno","Irob","Hamus","Arb","Kidame"],dayNamesShort:["Ehu","Seg","Mak","Iro","Ham","Arb","Kid"],dayNamesMin:["Eh","Se","Ma","Ir","Ha","Ar","Ki"],digits:null,dateFormat:"dd/mm/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[""].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return(t=a.year())<0&&t++,a.day()+30*(a.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,a=e-30*(n-1)+1;return this.newDate(r,n,a)}}),n.calendars.ethiopian=i},{"../main":569,"object-assign":455}],559:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}function o(t,e){return t-e*Math.floor(t/e)}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Hebrew",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{"":{name:"Hebrew",epochs:["BAM","AM"],monthNames:["Nisan","Iyar","Sivan","Tammuz","Av","Elul","Tishrei","Cheshvan","Kislev","Tevet","Shevat","Adar","Adar II"],monthNamesShort:["Nis","Iya","Siv","Tam","Av","Elu","Tis","Che","Kis","Tev","She","Ada","Ad2"],dayNames:["Yom Rishon","Yom Sheni","Yom Shlishi","Yom Revi'i","Yom Chamishi","Yom Shishi","Yom Shabbat"],dayNamesShort:["Ris","She","Shl","Rev","Cha","Shi","Sha"],dayNamesMin:["Ri","She","Shl","Re","Ch","Shi","Sha"],digits:null,dateFormat:"dd/mm/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)?30:8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(a)?"embolismic":"common")+" "+["deficient","regular","complete"][this.daysInYear(a)%10-3]}},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=a.year(),e=a.month(),r=a.day();var i=t<=0?t+1:t,o=this.jdEpoch+this._delay1(i)+this._delay2(i)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=i},{"../main":569,"object-assign":455}],560:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Islamic",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Islamic",epochs:["BH","AH"],monthNames:["Muharram","Safar","Rabi' al-awwal","Rabi' al-thani","Jumada al-awwal","Jumada al-thani","Rajab","Sha'aban","Ramadan","Shawwal","Dhu al-Qi'dah","Dhu al-Hijjah"],monthNamesShort:["Muh","Saf","Rab1","Rab2","Jum1","Jum2","Raj","Sha'","Ram","Shaw","DhuQ","DhuH"],dayNames:["Yawm al-ahad","Yawm al-ithnayn","Yawm ath-thulaathaa'","Yawm al-arbi'aa'","Yawm al-kham\u012bs","Yawm al-jum'a","Yawm as-sabt"],dayNamesShort:["Aha","Ith","Thu","Arb","Kha","Jum","Sab"],dayNamesMin:["Ah","It","Th","Ar","Kh","Ju","Sa"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return t=a.year(),e=a.month(),t=t<=0?t+1:t,(r=a.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=i},{"../main":569,"object-assign":455}],561:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Julian",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Julian",epochs:["BC","AD"],monthNames:["January","February","March","April","May","June","July","August","September","October","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"mm/dd/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return t=a.year(),e=a.month(),r=a.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),a=Math.floor((e-n)/30.6001),i=a-Math.floor(a<14?1:13),o=r-Math.floor(i>2?4716:4715),s=e-n-Math.floor(30.6001*a);return o<=0&&o--,this.newDate(o,i,s)}}),n.calendars.julian=i},{"../main":569,"object-assign":455}],562:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Mayan",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{"":{name:"Mayan",epochs:["",""],monthNames:["0","1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17"],monthNamesShort:["0","1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17"],dayNames:["0","1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19"],dayNamesShort:["0","1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19"],dayNamesMin:["0","1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19"],digits:null,dateFormat:"YYYY.m.d",firstDay:0,isRTL:!1,haabMonths:["Pop","Uo","Zip","Zotz","Tzec","Xul","Yaxkin","Mol","Chen","Yax","Zac","Ceh","Mac","Kankin","Muan","Pax","Kayab","Cumku","Uayeb"],tzolkinMonths:["Imix","Ik","Akbal","Kan","Chicchan","Cimi","Manik","Lamat","Muluc","Oc","Chuen","Eb","Ben","Ix","Men","Cib","Caban","Etznab","Cauac","Ahau"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+"."+Math.floor(t/20)+"."+t%20},forYear:function(t){if((t=t.split(".")).length<3)throw"Invalid Mayan year";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw"Invalid Mayan year";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate).toJD(),i=this._toHaab(a),o=this._toTzolkin(a);return{haabMonthName:this.local.haabMonths[i[0]-1],haabMonth:i[0],haabDay:i[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);return a.day()+20*a.month()+360*a.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=i},{"../main":569,"object-assign":455}],563:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar;var o=n.instance("gregorian");a(i.prototype,{name:"Nanakshahi",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Nanakshahi",epochs:["BN","AN"],monthNames:["Chet","Vaisakh","Jeth","Harh","Sawan","Bhadon","Assu","Katak","Maghar","Poh","Magh","Phagun"],monthNamesShort:["Che","Vai","Jet","Har","Saw","Bha","Ass","Kat","Mgr","Poh","Mgh","Pha"],dayNames:["Somvaar","Mangalvar","Budhvaar","Veervaar","Shukarvaar","Sanicharvaar","Etvaar"],dayNamesShort:["Som","Mangal","Budh","Veer","Shukar","Sanichar","Et"],dayNamesMin:["So","Ma","Bu","Ve","Sh","Sa","Et"],digits:null,dateFormat:"dd-mm-yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[""].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidMonth);(t=a.year())<0&&t++;for(var i=a.day(),s=1;s<a.month();s++)i+=this.daysPerMonth[s-1];return i+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=i},{"../main":569,"object-assign":455}],564:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Nepali",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{"":{name:"Nepali",epochs:["BBS","ABS"],monthNames:["Baisakh","Jestha","Ashadh","Shrawan","Bhadra","Ashwin","Kartik","Mangsir","Paush","Mangh","Falgun","Chaitra"],monthNamesShort:["Bai","Je","As","Shra","Bha","Ash","Kar","Mang","Pau","Ma","Fal","Chai"],dayNames:["Aaitabaar","Sombaar","Manglbaar","Budhabaar","Bihibaar","Shukrabaar","Shanibaar"],dayNamesShort:["Aaita","Som","Mangl","Budha","Bihi","Shukra","Shani"],dayNamesMin:["Aai","So","Man","Bu","Bi","Shu","Sha"],digits:null,dateFormat:"dd/mm/yyyy",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),"undefined"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),"undefined"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=a.year(),e=a.month(),r=a.day();var i=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=i.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],i.newDate(c,1,1).add(o,"d").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),a=e.dayOfYear(),i=r+56;this._createMissingCalendarData(i);for(var o=9,s=this.NEPALI_CALENDAR_DATA[i][0],l=this.NEPALI_CALENDAR_DATA[i][o]-s+1;a>l;)++o>12&&(o=1,i++),l+=this.NEPALI_CALENDAR_DATA[i][o];var c=this.NEPALI_CALENDAR_DATA[i][o]-(l-a);return this.newDate(i,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)"undefined"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2000:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=i},{"../main":569,"object-assign":455}],565:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}function o(t,e){return t-e*Math.floor(t/e)}i.prototype=new n.baseCalendar,a(i.prototype,{name:"Persian",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Persian",epochs:["BP","AP"],monthNames:["Farvardin","Ordibehesht","Khordad","Tir","Mordad","Shahrivar","Mehr","Aban","Azar","Day","Bahman","Esfand"],monthNamesShort:["Far","Ord","Kho","Tir","Mor","Sha","Meh","Aba","Aza","Day","Bah","Esf"],dayNames:["Yekshambe","Doshambe","Seshambe","Ch\xe6harshambe","Panjshambe","Jom'e","Shambe"],dayNamesShort:["Yek","Do","Se","Ch\xe6","Panj","Jom","Sha"],dayNamesMin:["Ye","Do","Se","Ch","Pa","Jo","Sh"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=a.year(),e=a.month(),r=a.day();var i=t-(t>=0?474:473),s=474+o(i,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(i/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),a=2820;if(1029982!==n){var i=Math.floor(n/366),s=o(n,366);a=Math.floor((2134*i+2816*s+2815)/1028522)+i+1}var l=a+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=i,n.calendars.jalali=i},{"../main":569,"object-assign":455}],566:[function(t,e,r){var n=t("../main"),a=t("object-assign"),i=n.instance();function o(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}o.prototype=new n.baseCalendar,a(o.prototype,{name:"Taiwan",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Taiwan",epochs:["BROC","ROC"],monthNames:["January","February","March","April","May","June","July","August","September","October","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return i.leapYear(t)},weekOfYear:function(t,e,r){var a=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(a.year());return i.weekOfYear(t,a.month(),a.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(a.year());return i.toJD(t,a.month(),a.day())},fromJD:function(t){var e=i.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{"../main":569,"object-assign":455}],567:[function(t,e,r){var n=t("../main"),a=t("object-assign"),i=n.instance();function o(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}o.prototype=new n.baseCalendar,a(o.prototype,{name:"Thai",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Thai",epochs:["BBE","BE"],monthNames:["January","February","March","April","May","June","July","August","September","October","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"dd/mm/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return i.leapYear(t)},weekOfYear:function(t,e,r){var a=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(a.year());return i.weekOfYear(t,a.month(),a.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(a.year());return i.toJD(t,a.month(),a.day())},fromJD:function(t){var e=i.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{"../main":569,"object-assign":455}],568:[function(t,e,r){var n=t("../main"),a=t("object-assign");function i(t){this.local=this.regionalOptions[t||""]||this.regionalOptions[""]}i.prototype=new n.baseCalendar,a(i.prototype,{name:"UmmAlQura",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Umm al-Qura",epochs:["BH","AH"],monthNames:["Al-Muharram","Safar","Rabi' al-awwal","Rabi' Al-Thani","Jumada Al-Awwal","Jumada Al-Thani","Rajab","Sha'aban","Ramadan","Shawwal","Dhu al-Qi'dah","Dhu al-Hijjah"],monthNamesShort:["Muh","Saf","Rab1","Rab2","Jum1","Jum2","Raj","Sha'","Ram","Shaw","DhuQ","DhuH"],dayNames:["Yawm al-Ahad","Yawm al-Ithnain","Yawm al-Thal\u0101th\u0101\u2019","Yawm al-Arba\u2018\u0101\u2019","Yawm al-Kham\u012bs","Yawm al-Jum\u2018a","Yawm al-Sabt"],dayNamesMin:["Ah","Ith","Th","Ar","Kh","Ju","Sa"],digits:null,dateFormat:"yyyy/mm/dd",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,a=0,i=0;i<o.length;i++){if(o[i]>r)return o[a]-o[a-1];a++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var a=this._validate(t,e,r,n.local.invalidDate),i=12*(a.year()-1)+a.month()-15292;return a.day()+o[i-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var a=r+15292,i=Math.floor((a-1)/12),s=i+1,l=a-12*i,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var a=n.baseCalendar.prototype.isValid.apply(this,arguments);return a&&(a=(t=null!=t.year?t.year:t)>=1276&&t<=1500),a},_validate:function(t,e,r,a){var i=n.baseCalendar.prototype._validate.apply(this,arguments);if(i.year<1276||i.year>1500)throw a.replace(/\{0\}/,this.local.name);return i}}),n.calendars.ummalqura=i;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{"../main":569,"object-assign":455}],569:[function(t,e,r){var n=t("object-assign");function a(){this.regionalOptions=[],this.regionalOptions[""]={invalidCalendar:"Calendar {0} not found",invalidDate:"Invalid {0} date",invalidMonth:"Invalid {0} month",invalidYear:"Invalid {0} year",differentCalendars:"Cannot mix {0} and {1} dates"},this.local=this.regionalOptions[""],this.calendars={},this._localCals={}}function i(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[""].invalidDate).replace(/\{0\}/,this._calendar.local.name)}function o(t,e){return"000000".substring(0,e-(t=""+t).length)+t}function s(){this.shortYearCutoff="+10"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[""]}n(a.prototype,{instance:function(t,e){t=(t||"gregorian").toLowerCase(),e=e||"";var r=this._localCals[t+"-"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+"-"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[""].invalidCalendar).replace(/\{0\}/,t);return r},newDate:function(t,e,r,n,a){return(n=(null!=t&&t.year?t.calendar():"string"==typeof n?this.instance(n,a):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+"").replace(/[0-9]/g,function(e){return t[e]})}},substituteChineseDigits:function(t,e){return function(r){for(var n="",a=0;r>0;){var i=r%10;n=(0===i?"":t[i]+e[a])+n,a++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(i.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,"y")},month:function(t){return 0===arguments.length?this._month:this.set(t,"m")},day:function(t){return 0===arguments.length?this._day:this.set(t,"d")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[""].invalidDate).replace(/\{0\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[""].differentCalendars).replace(/\{0\}/,this._calendar.local.name).replace(/\{1\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?"-":"")+o(Math.abs(this.year()),4)+"-"+o(this.month(),2)+"-"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate),r=t.day(),e=t.month(),t=t.year()),new i(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[""].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[""].invalidYear);return(e.year()<0?"-":"")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[""].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[""].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[""].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[""].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[""].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,"d"===r||"w"===r){var n=t.toJD()+e*("w"===r?this.daysInWeek():1),a=t.calendar().fromJD(n);return this._validateLevel--,[a.year(),a.month(),a.day()]}try{var i=t.year()+("y"===r?e:0),o=t.monthOfYear()+("m"===r?e:0);a=t.day();"y"===r?(t.month()!==this.fromMonthOfYear(i,o)&&(o=this.newDate(i,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(i)),a=Math.min(a,this.daysInMonth(i,this.fromMonthOfYear(i,o)))):"m"===r&&(!function(t){for(;o<t.minMonth;)i--,o+=t.monthsInYear(i);for(var e=t.monthsInYear(i);o>e-1+t.minMonth;)i++,o-=e,e=t.monthsInYear(i)}(this),a=Math.min(a,this.daysInMonth(i,this.fromMonthOfYear(i,o))));var s=[i,this.fromMonthOfYear(i,o),a];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||"y"!==n&&"m"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var a={y:[1,1,"y"],m:[1,this.monthsInYear(-1),"m"],w:[this.daysInWeek(),this.daysInYear(-1),"d"],d:[1,this.daysInYear(-1),"d"]}[n],i=r<0?-1:1;e=this._add(t,r*a[0]+i*a[1],a[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[""].invalidDate);var n="y"===r?e:t.year(),a="m"===r?e:t.month(),i="d"===r?e:t.day();return"y"!==r&&"m"!==r||(i=Math.min(i,this.daysInMonth(n,a))),t.date(n,a,i)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var a=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(a)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(a)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[""].differentCalendars).replace(/\{0\}/,this.local.name).replace(/\{1\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\{0\}/,this.local.name);var a=this.newDate(t,e,r);return this._validateLevel--,a}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:"Gregorian",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{"":{name:"Gregorian",epochs:["BCE","CE"],monthNames:["January","February","March","April","May","June","July","August","September","October","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],dayNamesMin:["Su","Mo","Tu","We","Th","Fr","Sa"],digits:null,dateFormat:"mm/dd/yyyy",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[""].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),"d"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[""].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var a=Math.floor(t/100),i=2-a+Math.floor(a/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+i-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,a=Math.floor((n-122.1)/365.25),i=Math.floor(365.25*a),o=Math.floor((n-i)/30.6001),s=n-i-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=a-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[""].invalidDate),a=new Date(n.year(),n.month()-1,n.day());return a.setHours(0),a.setMinutes(0),a.setSeconds(0),a.setMilliseconds(0),a.setHours(a.getHours()>12?a.getHours()+2:0),a},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new a;c.cdate=i,c.baseCalendar=s,c.calendars.gregorian=l},{"object-assign":455}],570:[function(t,e,r){var n=t("object-assign"),a=t("./main");n(a.regionalOptions[""],{invalidArguments:"Invalid arguments",invalidFormat:"Cannot format a date from another calendar",missingNumberAt:"Missing number at position {0}",unknownNameAt:"Unknown name at position {0}",unexpectedLiteralAt:"Unexpected literal at position {0}",unexpectedText:"Additional text found at end"}),a.local=a.regionalOptions[""],n(a.cdate.prototype,{formatDate:function(t,e){return"string"!=typeof t&&(e=t,t=""),this._calendar.formatDate(t||"",this,e)}}),n(a.baseCalendar.prototype,{UNIX_EPOCH:a.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:a.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:"yyyy-mm-dd",COOKIE:"D, dd M yyyy",FULL:"DD, MM d, yyyy",ISO_8601:"yyyy-mm-dd",JULIAN:"J",RFC_822:"D, d M yy",RFC_850:"DD, dd-M-yy",RFC_1036:"D, d M yy",RFC_1123:"D, d M yyyy",RFC_2822:"D, d M yyyy",RSS:"D, d M yy",TICKS:"!",TIMESTAMP:"@",W3C:"yyyy-mm-dd",formatDate:function(t,e,r){if("string"!=typeof t&&(r=e,e=t,t=""),!e)return"";if(e.calendar()!==this)throw a.local.invalidFormat||a.regionalOptions[""].invalidFormat;t=t||this.local.dateFormat;for(var n,i,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,h=r.monthNamesShort||this.local.monthNamesShort,f=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var a=""+e;if(p(t,n))for(;a.length<r;)a="0"+a;return a},g=this,v=function(t){return"function"==typeof u?u.call(g,t,p("m")):x(d("m",t.month(),2))},m=function(t,e){return e?"function"==typeof f?f.call(g,t):f[t.month()-g.minMonth]:"function"==typeof h?h.call(g,t):h[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b="",_=!1,w=0;w<t.length;w++)if(_)"'"!==t.charAt(w)||p("'")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case"d":b+=x(d("d",e.day(),2));break;case"D":b+=(n="D",i=e.dayOfWeek(),o=l,s=c,p(n)?s[i]:o[i]);break;case"o":b+=d("o",e.dayOfYear(),3);break;case"w":b+=d("w",e.weekOfYear(),2);break;case"m":b+=v(e);break;case"M":b+=m(e,p("M"));break;case"y":b+=p("y",2)?e.year():(e.year()%100<10?"0":"")+e.year()%100;break;case"Y":p("Y",2),b+=e.formatYear();break;case"J":b+=e.toJD();break;case"@":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case"!":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case"'":p("'")?b+="'":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw a.local.invalidArguments||a.regionalOptions[""].invalidArguments;if(""===(e="object"==typeof e?e.toString():e+""))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n="string"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var i=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,g=-1,v=!1,m=!1,y=function(e,r){for(var n=1;M+n<t.length&&t.charAt(M+n)===e;)n++;return M+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),i=[2,3,n?4:2,n?4:2,10,11,20]["oyYJ@!".indexOf(t)+1],o=new RegExp("^-?\\d{1,"+i+"}"),s=e.substring(A).match(o);if(!s)throw(a.local.missingNumberAt||a.regionalOptions[""].missingNumberAt).replace(/\{0\}/,A);return A+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if("function"==typeof l){y("m");var t=l.call(b,e.substring(A));return A+=t.length,t}return x("m")},w=function(t,r,n,i){for(var o=y(t,i)?n:r,s=0;s<o.length;s++)if(e.substr(A,o[s].length).toLowerCase()===o[s].toLowerCase())return A+=o[s].length,s+b.minMonth;throw(a.local.unknownNameAt||a.regionalOptions[""].unknownNameAt).replace(/\{0\}/,A)},k=function(){if("function"==typeof u){var t=y("M")?u.call(b,e.substring(A)):c.call(b,e.substring(A));return A+=t.length,t}return w("M",c,u)},T=function(){if(e.charAt(A)!==t.charAt(M))throw(a.local.unexpectedLiteralAt||a.regionalOptions[""].unexpectedLiteralAt).replace(/\{0\}/,A);A++},A=0,M=0;M<t.length;M++)if(m)"'"!==t.charAt(M)||y("'")?T():m=!1;else switch(t.charAt(M)){case"d":d=x("d");break;case"D":w("D",i,o);break;case"o":g=x("o");break;case"w":x("w");break;case"m":p=_();break;case"M":p=k();break;case"y":var S=M;v=!y("y",2),M=S,f=x("y",2);break;case"Y":f=x("Y",2);break;case"J":h=x("J")+.5,"."===e.charAt(A)&&(A++,x("J"));break;case"@":h=x("@")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case"!":h=x("!")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case"*":A=e.length;break;case"'":y("'")?T():m=!0;break;default:T()}if(A<e.length)throw a.local.unexpectedText||a.regionalOptions[""].unexpectedText;if(-1===f?f=this.today().year():f<100&&v&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),"string"==typeof p&&(p=s.call(this,f,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,a){r&&"object"!=typeof r&&(a=n,n=r,r=null),"string"!=typeof n&&(a=n,n="");var i=this;return e=e?e.newDate():null,t=null==t?e:"string"==typeof t?function(t){try{return i.parseDate(n,t,a)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||i.today(),o=/([+-]?[0-9]+)\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||"d"),s=o.exec(t);return e}(t):"number"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:i.today().add(t,"d"):i.newDate(t)}})},{"./main":569,"object-assign":455}],571:[function(t,e,r){e.exports=t("cwise-compiler")({args:["array",{offset:[1],array:0},"scalar","scalar","index"],pre:{body:"{}",args:[],thisVars:[],localVars:[]},post:{body:"{}",args:[],thisVars:[],localVars:[]},body:{body:"{\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\n        }\n      }",args:[{name:"_inline_1_arg0_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_1_arg1_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_1_arg2_",lvalue:!1,rvalue:!0,count:1},{name:"_inline_1_arg3_",lvalue:!1,rvalue:!0,count:2},{name:"_inline_1_arg4_",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:["_inline_1_da","_inline_1_db"]},funcName:"zeroCrossings"})},{"cwise-compiler":147}],572:[function(t,e,r){"use strict";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t("./lib/zc-core")},{"./lib/zc-core":571}],573:[function(t,e,r){"use strict";e.exports=[{path:"",backoff:0},{path:"M-2.4,-3V3L0.6,0Z",backoff:.6},{path:"M-3.7,-2.5V2.5L1.3,0Z",backoff:1.3},{path:"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z",backoff:1.55},{path:"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z",backoff:1.6},{path:"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z",backoff:2},{path:"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z",backoff:0,noRotate:!0},{path:"M2,2V-2H-2V2Z",backoff:0,noRotate:!0}]},{}],574:[function(t,e,r){"use strict";var n=t("./arrow_paths"),a=t("../../plots/font_attributes"),i=t("../../plots/cartesian/constants"),o=t("../../plot_api/plot_template").templatedArray;e.exports=o("annotation",{visible:{valType:"boolean",dflt:!0,editType:"calc+arraydraw"},text:{valType:"string",editType:"calc+arraydraw"},textangle:{valType:"angle",dflt:0,editType:"calc+arraydraw"},font:a({editType:"calc+arraydraw",colorEditType:"arraydraw"}),width:{valType:"number",min:1,dflt:null,editType:"calc+arraydraw"},height:{valType:"number",min:1,dflt:null,editType:"calc+arraydraw"},opacity:{valType:"number",min:0,max:1,dflt:1,editType:"arraydraw"},align:{valType:"enumerated",values:["left","center","right"],dflt:"center",editType:"arraydraw"},valign:{valType:"enumerated",values:["top","middle","bottom"],dflt:"middle",editType:"arraydraw"},bgcolor:{valType:"color",dflt:"rgba(0,0,0,0)",editType:"arraydraw"},bordercolor:{valType:"color",dflt:"rgba(0,0,0,0)",editType:"arraydraw"},borderpad:{valType:"number",min:0,dflt:1,editType:"calc+arraydraw"},borderwidth:{valType:"number",min:0,dflt:1,editType:"calc+arraydraw"},showarrow:{valType:"boolean",dflt:!0,editType:"calc+arraydraw"},arrowcolor:{valType:"color",editType:"arraydraw"},arrowhead:{valType:"integer",min:0,max:n.length,dflt:1,editType:"arraydraw"},startarrowhead:{valType:"integer",min:0,max:n.length,dflt:1,editType:"arraydraw"},arrowside:{valType:"flaglist",flags:["end","start"],extras:["none"],dflt:"end",editType:"arraydraw"},arrowsize:{valType:"number",min:.3,dflt:1,editType:"calc+arraydraw"},startarrowsize:{valType:"number",min:.3,dflt:1,editType:"calc+arraydraw"},arrowwidth:{valType:"number",min:.1,editType:"calc+arraydraw"},standoff:{valType:"number",min:0,dflt:0,editType:"calc+arraydraw"},startstandoff:{valType:"number",min:0,dflt:0,editType:"calc+arraydraw"},ax:{valType:"any",editType:"calc+arraydraw"},ay:{valType:"any",editType:"calc+arraydraw"},axref:{valType:"enumerated",dflt:"pixel",values:["pixel",i.idRegex.x.toString()],editType:"calc"},ayref:{valType:"enumerated",dflt:"pixel",values:["pixel",i.idRegex.y.toString()],editType:"calc"},xref:{valType:"enumerated",values:["paper",i.idRegex.x.toString()],editType:"calc"},x:{valType:"any",editType:"calc+arraydraw"},xanchor:{valType:"enumerated",values:["auto","left","center","right"],dflt:"auto",editType:"calc+arraydraw"},xshift:{valType:"number",dflt:0,editType:"calc+arraydraw"},yref:{valType:"enumerated",values:["paper",i.idRegex.y.toString()],editType:"calc"},y:{valType:"any",editType:"calc+arraydraw"},yanchor:{valType:"enumerated",values:["auto","top","middle","bottom"],dflt:"auto",editType:"calc+arraydraw"},yshift:{valType:"number",dflt:0,editType:"calc+arraydraw"},clicktoshow:{valType:"enumerated",values:[!1,"onoff","onout"],dflt:!1,editType:"arraydraw"},xclick:{valType:"any",editType:"arraydraw"},yclick:{valType:"any",editType:"arraydraw"},hovertext:{valType:"string",editType:"arraydraw"},hoverlabel:{bgcolor:{valType:"color",editType:"arraydraw"},bordercolor:{valType:"color",editType:"arraydraw"},font:a({editType:"arraydraw"}),editType:"arraydraw"},captureevents:{valType:"boolean",editType:"arraydraw"},editType:"calc",_deprecated:{ref:{valType:"string",editType:"calc"}}})},{"../../plot_api/plot_template":754,"../../plots/cartesian/constants":770,"../../plots/font_attributes":790,"./arrow_paths":573}],575:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("./draw").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach(function(e){var r=a.getFromId(t,e.xref),n=a.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)})}function s(t,e){var r,n=e._id,i=n.charAt(0),o=t[i],s=t["a"+i],l=t[i+"ref"],c=t["a"+i+"ref"],u=t["_"+i+"padplus"],h=t["_"+i+"padminus"],f={x:1,y:-1}[i]*t[i+"shift"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,g=p-f,v=3*t.startarrowsize*t.arrowwidth||0,m=v+f,y=v-f;if(c===l){var x=a.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=a.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,m),ppadminus:Math.max(h,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else m=s?m+s:m,y=s?y-s:y,r=a.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,m),ppadminus:Math.max(h,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([i,o],t)}},{"../../lib":716,"../../plots/cartesian/axes":764,"./draw":580}],576:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=t("../../plot_api/plot_template").arrayEditor;function o(t,e){var r,n,a,i,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(i=(a=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===a.xref&&c._id===a.yref&&l.d2r(o.x)===s(a._xclick,l)&&c.d2r(o.y)===s(a._yclick,c)){(a.visible?"onout"===i?f:p:h).push(r);break}n===d&&a.visible&&"onout"===i&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return"log"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=i(t.layout,"annotations",f[c[r]])).modifyItem("visible",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=i(t.layout,"annotations",f[u[r]])).modifyItem("visible",!1),n.extendFlat(h,s.getUpdateObj());return a.call("update",t,{},h)}}},{"../../lib":716,"../../plot_api/plot_template":754,"../../registry":845}],577:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../color");e.exports=function(t,e,r,i){i("opacity");var o=i("bgcolor"),s=i("bordercolor"),l=a.opacity(s);i("borderpad");var c=i("borderwidth"),u=i("showarrow");if(i("text",u?" ":r._dfltTitle.annotation),i("textangle"),n.coerceFont(i,"font",r.font),i("width"),i("align"),i("height")&&i("valign"),u){var h,f,p=i("arrowside");-1!==p.indexOf("end")&&(h=i("arrowhead"),f=i("arrowsize")),-1!==p.indexOf("start")&&(i("startarrowhead",h),i("startarrowsize",f)),i("arrowcolor",l?e.bordercolor:a.defaultLine),i("arrowwidth",2*(l&&c||1)),i("standoff"),i("startstandoff")}var d=i("hovertext"),g=r.hoverlabel||{};if(d){var v=i("hoverlabel.bgcolor",g.bgcolor||(a.opacity(o)?a.rgb(o):a.defaultLine)),m=i("hoverlabel.bordercolor",g.bordercolor||a.contrast(v));n.coerceFont(i,"hoverlabel.font",{family:g.font.family,size:g.font.size,color:g.font.color||m})}i("captureevents",!!d)}},{"../../lib":716,"../color":591}],578:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib/to_log_range");e.exports=function(t,e,r,i){e=e||{};var o="log"===r&&"linear"===e.type,s="linear"===r&&"log"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c="annotations["+f+"].",l[h+"ref"]===e._id&&p(h),l["a"+h+"ref"]===e._id&&p("a"+h);function p(t){var r=l[t],s=null;s=o?a(r,e.range):Math.pow(10,r),n(s)||(s=null),i(c+t,s)}}},{"../../lib/to_log_range":742,"fast-isnumeric":227}],579:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../../plots/array_container_defaults"),o=t("./common_defaults"),s=t("./attributes");function l(t,e,r){function i(r,a){return n.coerce(t,e,s,r,a)}var l=i("visible"),c=i("clicktoshow");if(l||c){o(t,e,r,i);for(var u=e.showarrow,h=["x","y"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=h[d],v=a.coerceRef(t,e,p,g,"","paper");if("paper"!==v)a.getFromId(p,v)._annIndices.push(e._index);if(a.coercePosition(e,p,i,v,g,.5),u){var m="a"+g,y=a.coerceRef(t,e,p,m,"pixel");"pixel"!==y&&y!==v&&(y=e[m]="pixel");var x="pixel"===y?f[d]:.4;a.coercePosition(e,p,i,y,m,x)}i(g+"anchor"),i(g+"shift")}if(n.noneOrAll(t,e,["x","y"]),u&&n.noneOrAll(t,e,["ax","ay"]),c){var b=i("xclick"),_=i("yclick");e._xclick=void 0===b?e.x:a.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:a.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){i(t,e,{name:"annotations",handleItemDefaults:l})}},{"../../lib":716,"../../plots/array_container_defaults":760,"../../plots/cartesian/axes":764,"./attributes":574,"./common_defaults":577}],580:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../plots/plots"),o=t("../../lib"),s=t("../../plots/cartesian/axes"),l=t("../color"),c=t("../drawing"),u=t("../fx"),h=t("../../lib/svg_text_utils"),f=t("../../lib/setcursor"),p=t("../dragelement"),d=t("../../plot_api/plot_template").arrayEditor,g=t("./draw_arrow_head");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=s.getFromId(t,r.xref),a=s.getFromId(t,r.yref);n&&n.setScale(),a&&a.setScale(),m(t,r,e,!1,n,a)}function m(t,e,r,i,s,v){var m,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;i?(m="annotation-"+i,y=i+".annotations"):(m="annotation",y="annotations");var w=d(t.layout,y,e),k=w.modifyBase,T=w.modifyItem,A=w.getUpdateObj;x._infolayer.selectAll("."+m+'[data-index="'+r+'"]').remove();var M="clip"+x._uid+"_ann"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},E=+e.textangle||0,L=x._infolayer.append("g").classed(m,!0).attr("data-index",String(r)).style("opacity",e.opacity),C=L.append("g").classed("annotation-text-g",!0),P=_[e.showarrow?"annotationTail":"annotationPosition"],O=e.captureevents||_.annotationText||P,z=C.append("g").style("pointer-events",O?"all":null).call(f,"pointer").on("click",function(){t._dragging=!1,t.emit("plotly_clickannotation",q(n.event))});e.hovertext&&z.on("mouseover",function(){var r=e.hoverlabel,n=r.font,a=this.getBoundingClientRect(),i=t.getBoundingClientRect();u.loneHover({x0:a.left-i.left,x1:a.right-i.left,y:(a.top+a.bottom)/2-i.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})}).on("mouseout",function(){u.loneUnhover(x._hoverlayer.node())});var I=e.borderwidth,D=e.borderpad,R=I+D,F=z.append("rect").attr("class","bg").style("stroke-width",I+"px").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll("#"+M).data(B?[0]:[]);N.enter().append("clipPath").classed("annclip",!0).attr("id",M).append("rect"),N.exit().remove();var j=e.font,V=x._meta?o.templateString(e.text,x._meta):e.text,U=z.append("text").classed("annotation-text",!0).text(V);_.annotationText?U.call(h.makeEditable,{delegate:z,gd:t}).call(H).on("edit",function(r){e.text=r,this.call(H),T("text",r),s&&s.autorange&&k(s._name+".autorange",!0),v&&v.autorange&&k(v._name+".autorange",!0),a.call("_guiRelayout",t,A())}):U.call(H)}else n.selectAll("#"+M).remove();function q(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return i&&(n.subplotId=i),n}function H(r){return r.call(c.font,j).attr({"text-anchor":{left:"start",right:"end"}[e.align]||"middle"}),h.convertToTspans(r,t,G),r}function G(){var r=U.selectAll("a");1===r.size()&&r.text()===U.text()&&z.insert("a",":first-child").attr({"xlink:xlink:href":r.attr("xlink:href"),"xlink:xlink:show":r.attr("xlink:show")}).style({cursor:"pointer"}).node().appendChild(F.node());var n=z.select(".annotation-text-math-group"),u=!n.empty(),d=c.bBox((u?n:U).node()),m=d.width,y=d.height,w=e.width||m,O=e.height||y,D=Math.round(w+2*R),j=Math.round(O+2*R);function V(t,e){return"auto"===e&&(e=t<1/3?"left":t>2/3?"right":"center"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var H=!1,G=["x","y"],Y=0;Y<G.length;Y++){var W,X,Z,J,K,Q=G[Y],$=e[Q+"ref"]||Q,tt=e["a"+Q+"ref"],et={x:s,y:v}[Q],rt=(E+("x"===Q?0:-90))*Math.PI/180,nt=D*Math.cos(rt),at=j*Math.sin(rt),it=Math.abs(nt)+Math.abs(at),ot=e[Q+"anchor"],st=e[Q+"shift"]*("x"===Q?1:-1),lt=S[Q];if(et){var ct=et.r2fraction(e[Q]);(ct<0||ct>1)&&(tt===$?((ct=et.r2fraction(e["a"+Q]))<0||ct>1)&&(H=!0):H=!0),W=et._offset+et.r2p(e[Q]),J=.5}else"x"===Q?(Z=e[Q],W=b.l+b.w*Z):(Z=1-e[Q],W=b.t+b.h*Z),J=e.showarrow?.5:Z;if(e.showarrow){lt.head=W;var ut=e["a"+Q];K=nt*V(.5,e.xanchor)-at*V(.5,e.yanchor),tt===$?(lt.tail=et._offset+et.r2p(ut),X=K):(lt.tail=W+ut,X=K+ut),lt.text=lt.tail+K;var ht=x["x"===Q?"width":"height"];if("paper"===$&&(lt.head=o.constrain(lt.head,1,ht-1)),"pixel"===tt){var ft=-Math.max(lt.tail-3,lt.text),pt=Math.min(lt.tail+3,lt.text)-ht;ft>0?(lt.tail+=ft,lt.text+=ft):pt>0&&(lt.tail-=pt,lt.text-=pt)}lt.tail+=st,lt.head+=st}else X=K=it*V(J,ot),lt.text=W+K;lt.text+=st,K+=st,X+=st,e["_"+Q+"padplus"]=it/2+X,e["_"+Q+"padminus"]=it/2-X,e["_"+Q+"size"]=it,e["_"+Q+"shift"]=K}if(H)z.remove();else{var dt=0,gt=0;if("left"!==e.align&&(dt=(w-m)*("center"===e.align?.5:1)),"top"!==e.valign&&(gt=(O-y)*("middle"===e.valign?.5:1)),u)n.select("svg").attr({x:R+dt-1,y:R+gt}).call(c.setClipUrl,B?M:null,t);else{var vt=R+gt-d.top,mt=R+dt-d.left;U.call(h.positionText,mt,vt).call(c.setClipUrl,B?M:null,t)}N.select("rect").call(c.setRect,R,R,w,O),F.call(c.setRect,I/2,I/2,D-I,j-I),z.call(c.setTranslate,Math.round(S.x.text-D/2),Math.round(S.y.text-j/2)),C.attr({transform:"rotate("+E+","+S.x.text+","+S.y.text+")"});var yt,xt=function(r,n){L.selectAll(".annotation-arrow-g").remove();var u=S.x.head,h=S.y.head,f=S.x.tail+r,d=S.y.tail+n,m=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(E,m,y),w=o.apply2DTransform(x),M=o.apply2DTransform2(x),P=+F.attr("width"),O=+F.attr("height"),I=m-.5*P,D=I+P,R=y-.5*O,B=R+O,N=[[I,R,I,B],[I,B,D,B],[D,B,D,R],[D,R,I,R]].map(M);if(!N.reduce(function(t,e){return t^!!o.segmentsIntersect(u,h,u+1e6,h+1e6,e[0],e[1],e[2],e[3])},!1)){N.forEach(function(t){var e=o.segmentsIntersect(f,d,u,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,d=e.y)});var j=e.arrowwidth,V=e.arrowcolor,U=e.arrowside,q=L.append("g").style({opacity:l.opacity(V)}).classed("annotation-arrow-g",!0),H=q.append("path").attr("d","M"+f+","+d+"L"+u+","+h).style("stroke-width",j+"px").call(l.stroke,l.rgb(V));if(g(H,U,e),_.annotationPosition&&H.node().parentNode&&!i){var G=u,Y=h;if(e.standoff){var W=Math.sqrt(Math.pow(u-f,2)+Math.pow(h-d,2));G+=e.standoff*(f-u)/W,Y+=e.standoff*(d-h)/W}var X,Z,J=q.append("path").classed("annotation-arrow",!0).classed("anndrag",!0).classed("cursor-move",!0).attr({d:"M3,3H-3V-3H3ZM0,0L"+(f-G)+","+(d-Y),transform:"translate("+G+","+Y+")"}).style("stroke-width",j+6+"px").call(l.stroke,"rgba(0,0,0,0)").call(l.fill,"rgba(0,0,0,0)");p.init({element:J.node(),gd:t,prepFn:function(){var t=c.getTranslate(z);X=t.x,Z=t.y,s&&s.autorange&&k(s._name+".autorange",!0),v&&v.autorange&&k(v._name+".autorange",!0)},moveFn:function(t,r){var n=w(X,Z),a=n[0]+t,i=n[1]+r;z.call(c.setTranslate,a,i),T("x",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),T("y",v?v.p2r(v.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&T("ax",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&T("ay",v.p2r(v.r2p(e.ay)+r)),q.attr("transform","translate("+t+","+r+")"),C.attr({transform:"rotate("+E+","+a+","+i+")"})},doneFn:function(){a.call("_guiRelayout",t,A());var e=document.querySelector(".js-notes-box-panel");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&xt(0,0),P)p.init({element:z.node(),gd:t,prepFn:function(){yt=C.attr("transform")},moveFn:function(t,r){var n="pointer";if(e.showarrow)e.axref===e.xref?T("ax",s.p2r(s.r2p(e.ax)+t)):T("ax",e.ax+t),e.ayref===e.yref?T("ay",v.p2r(v.r2p(e.ay)+r)):T("ay",e.ay+r),xt(t,r);else{if(i)return;var a,o;if(s)a=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;a=p.align(c+t/b.w,l,0,1,e.xanchor)}if(v)o=v.p2r(v.r2p(e.y)+r);else{var u=e._ysize/b.h,h=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(h-r/b.h,u,0,1,e.yanchor)}T("x",a),T("y",o),s&&v||(n=p.getCursor(s?.5:a,v?.5:o,e.xanchor,e.yanchor))}C.attr({transform:"translate("+t+","+r+")"+yt}),f(z,n)},clickFn:function(r,n){e.captureevents&&t.emit("plotly_clickannotation",q(n))},doneFn:function(){f(z),a.call("_guiRelayout",t,A());var e=document.querySelector(".js-notes-box-panel");e&&e.redraw(e.selectedObj)}})}}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(".annotation").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return i.previousPromises(t)},drawOne:v,drawRaw:m}},{"../../lib":716,"../../lib/setcursor":736,"../../lib/svg_text_utils":740,"../../plot_api/plot_template":754,"../../plots/cartesian/axes":764,"../../plots/plots":825,"../../registry":845,"../color":591,"../dragelement":609,"../drawing":612,"../fx":629,"./draw_arrow_head":581,d3:164}],581:[function(t,e,r){"use strict";var n=t("d3"),a=t("../color"),i=t("./arrow_paths");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),h=i[r.arrowhead||0],f=i[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf("start")>=0,v=e.indexOf("end")>=0,m=h.backoff*p+r.standoff,y=f.backoff*d+r.startstandoff;if("line"===u.nodeName){o={x:+t.attr("x1"),y:+t.attr("y1")},s={x:+t.attr("x2"),y:+t.attr("y2")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,m&&y&&m+y>Math.sqrt(x*x+b*b))return void P();if(m){if(m*m>x*x+b*b)return void P();var _=m*Math.cos(l),w=m*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void P();var k=y*Math.cos(l),T=y*Math.sin(l);o.x-=k,o.y-=T,t.attr({x1:o.x,y1:o.y})}}else if("path"===u.nodeName){var A=u.getTotalLength(),M="";if(A<m+y)return void P();var S=u.getPointAtLength(0),E=u.getPointAtLength(.1);l=Math.atan2(S.y-E.y,S.x-E.x),o=u.getPointAtLength(Math.min(y,A)),M="0px,"+y+"px,";var L=u.getPointAtLength(A),C=u.getPointAtLength(A-.1);c=Math.atan2(L.y-C.y,L.x-C.x),s=u.getPointAtLength(Math.max(0,A-m)),M+=A-(M?y+m:m)+"px,"+A+"px",t.style("stroke-dasharray",M)}function P(){t.style("stroke-dasharray","0px,100px")}function O(e,i,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append("path").attr({class:t.attr("class"),d:e.path,transform:"translate("+i.x+","+i.y+")"+(o?"rotate("+180*o/Math.PI+")":"")+"scale("+s+")"}).style({fill:a.rgb(r.arrowcolor),"stroke-width":0}))}g&&O(f,o,l,d),v&&O(h,s,c,p)}},{"../color":591,"./arrow_paths":573,d3:164}],582:[function(t,e,r){"use strict";var n=t("./draw"),a=t("./click");e.exports={moduleType:"component",name:"annotations",layoutAttributes:t("./attributes"),supplyLayoutDefaults:t("./defaults"),includeBasePlot:t("../../plots/cartesian/include_components")("annotations"),calcAutorange:t("./calc_autorange"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:a.hasClickToShow,onClick:a.onClick,convertCoords:t("./convert_coords")}},{"../../plots/cartesian/include_components":774,"./attributes":574,"./calc_autorange":575,"./click":576,"./convert_coords":578,"./defaults":579,"./draw":580}],583:[function(t,e,r){"use strict";var n=t("../annotations/attributes"),a=t("../../plot_api/edit_types").overrideAll,i=t("../../plot_api/plot_template").templatedArray;e.exports=a(i("annotation",{visible:n.visible,x:{valType:"any"},y:{valType:"any"},z:{valType:"any"},ax:{valType:"number"},ay:{valType:"number"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),"calc","from-root")},{"../../plot_api/edit_types":747,"../../plot_api/plot_template":754,"../annotations/attributes":574}],584:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes");function i(t,e){var r=e.fullSceneLayout.domain,i=e.fullLayout._size,o={pdata:null,type:"linear",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),a.setConvert(t._xa),t._xa._offset=i.l+r.x[0]*i.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*i.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),a.setConvert(t._ya),t._ya._offset=i.t+(1-r.y[1])*i.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*i.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)i(e[r],t);t.fullLayout._infolayer.selectAll(".annotation-"+t.id).remove()}},{"../../lib":716,"../../plots/cartesian/axes":764}],585:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../../plots/array_container_defaults"),o=t("../annotations/common_defaults"),s=t("./attributes");function l(t,e,r,i){function l(r,a){return n.coerce(t,e,s,r,a)}function c(t){var n=t+"axis",i={_fullLayout:{}};return i._fullLayout[n]=r[n],a.coercePosition(e,i,l,t,t,.5)}l("visible")&&(o(t,e,i.fullLayout,l),c("x"),c("y"),c("z"),n.noneOrAll(t,e,["x","y","z"]),e.xref="x",e.yref="y",e.zref="z",l("xanchor"),l("yanchor"),l("xshift"),l("yshift"),e.showarrow&&(e.axref="pixel",e.ayref="pixel",l("ax",-10),l("ay",-30),n.noneOrAll(t,e,["ax","ay"])))}e.exports=function(t,e,r){i(t,e,{name:"annotations",handleItemDefaults:l,fullLayout:r.fullLayout})}},{"../../lib":716,"../../plots/array_container_defaults":760,"../../plots/cartesian/axes":764,"../annotations/common_defaults":577,"./attributes":583}],586:[function(t,e,r){"use strict";var n=t("../annotations/draw").drawRaw,a=t("../../plots/gl3d/project"),i=["x","y","z"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=i[u],f=l[h],p=e[h+"axis"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(".annotation-"+t.id+'[data-index="'+s+'"]').remove():(l._pdata=a(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{"../../plots/gl3d/project":813,"../annotations/draw":580}],587:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib");e.exports={moduleType:"component",name:"annotations3d",schema:{subplots:{scene:{annotations:t("./attributes")}}},layoutAttributes:t("./attributes"),handleDefaults:t("./defaults"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var i=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];i.test(l)&&(t[l].annotations||[]).length&&(a.pushUnique(e._basePlotModules,r),a.pushUnique(e._subplots.gl3d,l))}},convert:t("./convert"),draw:t("./draw")}},{"../../lib":716,"../../registry":845,"./attributes":583,"./convert":584,"./defaults":585,"./draw":586}],588:[function(t,e,r){"use strict";e.exports=t("world-calendars/dist/main"),t("world-calendars/dist/plus"),t("world-calendars/dist/calendars/chinese"),t("world-calendars/dist/calendars/coptic"),t("world-calendars/dist/calendars/discworld"),t("world-calendars/dist/calendars/ethiopian"),t("world-calendars/dist/calendars/hebrew"),t("world-calendars/dist/calendars/islamic"),t("world-calendars/dist/calendars/julian"),t("world-calendars/dist/calendars/mayan"),t("world-calendars/dist/calendars/nanakshahi"),t("world-calendars/dist/calendars/nepali"),t("world-calendars/dist/calendars/persian"),t("world-calendars/dist/calendars/taiwan"),t("world-calendars/dist/calendars/thai"),t("world-calendars/dist/calendars/ummalqura")},{"world-calendars/dist/calendars/chinese":555,"world-calendars/dist/calendars/coptic":556,"world-calendars/dist/calendars/discworld":557,"world-calendars/dist/calendars/ethiopian":558,"world-calendars/dist/calendars/hebrew":559,"world-calendars/dist/calendars/islamic":560,"world-calendars/dist/calendars/julian":561,"world-calendars/dist/calendars/mayan":562,"world-calendars/dist/calendars/nanakshahi":563,"world-calendars/dist/calendars/nepali":564,"world-calendars/dist/calendars/persian":565,"world-calendars/dist/calendars/taiwan":566,"world-calendars/dist/calendars/thai":567,"world-calendars/dist/calendars/ummalqura":568,"world-calendars/dist/main":569,"world-calendars/dist/plus":570}],589:[function(t,e,r){"use strict";var n=t("./calendars"),a=t("../../lib"),i=t("../../constants/numerical"),o=i.EPOCHJD,s=i.ONEDAY,l={valType:"enumerated",values:Object.keys(n.calendars),editType:"calc",dflt:"gregorian"},c=function(t,e,r,n){var i={};return i[r]=l,a.coerce(t,e,i,r,n)},u="##",h={d:{0:"dd","-":"d"},e:{0:"d","-":"d"},a:{0:"D","-":"D"},A:{0:"DD","-":"DD"},j:{0:"oo","-":"o"},W:{0:"ww","-":"w"},m:{0:"mm","-":"m"},b:{0:"M","-":"M"},B:{0:"MM","-":"MM"},y:{0:"yy","-":"yy"},Y:{0:"yyyy","-":"yyyy"},U:u,w:u,c:{0:"D M d %X yyyy","-":"D M d %X yyyy"},x:{0:"mm/dd/yyyy","-":"mm/dd/yyyy"}};var f={};function p(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function d(t){return a.extendFlat({},l,{description:t})}function g(t){return"Sets the calendar system to use with `"+t+"` date data."}var v={xcalendar:d(g("x"))},m=a.extendFlat({},v,{ycalendar:d(g("y"))}),y=a.extendFlat({},m,{zcalendar:d(g("z"))}),x=d(["Sets the calendar system to use for `range` and `tick0`","if this is a date axis. This does not set the calendar for","interpreting data on this axis, that's specified in the trace","or via the global `layout.calendar`"].join(" "));e.exports={moduleType:"component",name:"calendars",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:y,surface:y,mesh3d:y,scattergl:m,ohlc:v,candlestick:v},layout:{calendar:d(["Sets the default calendar system to use for interpreting and","displaying dates throughout the plot."].join(" "))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d(["Sets the calendar system to use for `value`, if it is a date."].join(" ")),targetcalendar:d(["Sets the calendar system to use for `target`, if it is an","array of dates. If `target` is a string (eg *x*) we use the","corresponding trace attribute (eg `xcalendar`) if it exists,","even if `targetcalendar` is provided."].join(" "))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var a=0;a<r.length;a++)c(t,e,r[a]+"calendar",n.calendar)},CANONICAL_SUNDAY:{chinese:"2000-01-02",coptic:"2000-01-03",discworld:"2000-01-03",ethiopian:"2000-01-05",hebrew:"5000-01-01",islamic:"1000-01-02",julian:"2000-01-03",mayan:"5000-01-01",nanakshahi:"1000-01-05",nepali:"2000-01-05",persian:"1000-01-01",jalali:"1000-01-01",taiwan:"1000-01-04",thai:"2000-01-04",ummalqura:"1400-01-06"},CANONICAL_TICK:{chinese:"2000-01-01",coptic:"2000-01-01",discworld:"2000-01-01",ethiopian:"2000-01-01",hebrew:"5000-01-01",islamic:"1000-01-01",julian:"2000-01-01",mayan:"5000-01-01",nanakshahi:"1000-01-01",nepali:"2000-01-01",persian:"1000-01-01",jalali:"1000-01-01",taiwan:"1000-01-01",thai:"2000-01-01",ummalqura:"1400-01-01"},DFLTRANGE:{chinese:["2000-01-01","2001-01-01"],coptic:["1700-01-01","1701-01-01"],discworld:["1800-01-01","1801-01-01"],ethiopian:["2000-01-01","2001-01-01"],hebrew:["5700-01-01","5701-01-01"],islamic:["1400-01-01","1401-01-01"],julian:["2000-01-01","2001-01-01"],mayan:["5200-01-01","5201-01-01"],nanakshahi:["0500-01-01","0501-01-01"],nepali:["2000-01-01","2001-01-01"],persian:["1400-01-01","1401-01-01"],jalali:["1400-01-01","1401-01-01"],taiwan:["0100-01-01","0101-01-01"],thai:["2500-01-01","2501-01-01"],ummalqura:["1400-01-01","1401-01-01"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,a,i,l,c,f=Math.floor((e+.05)/s)+o,d=p(r).fromJD(f),g=0;-1!==(g=t.indexOf("%",g));)"0"===(n=t.charAt(g+1))||"-"===n||"_"===n?(i=3,a=t.charAt(g+2),"_"===n&&(n="-")):(a=n,n="0",i=2),(l=h[a])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,g)+c+t.substr(g+i),g+=c.length):g+=i;return t}}},{"../../constants/numerical":692,"../../lib":716,"./calendars":588}],590:[function(t,e,r){"use strict";r.defaults=["#1f77b4","#ff7f0e","#2ca02c","#d62728","#9467bd","#8c564b","#e377c2","#7f7f7f","#bcbd22","#17becf"],r.defaultLine="#444",r.lightLine="#eee",r.background="#fff",r.borderLine="#BEC8D9",r.lightFraction=1e3/11},{}],591:[function(t,e,r){"use strict";var n=t("tinycolor2"),a=t("fast-isnumeric"),i=e.exports={},o=t("./attributes");i.defaults=o.defaults;var s=i.defaultLine=o.defaultLine;i.lightLine=o.lightLine;var l=i.background=o.background;function c(t){if(a(t)||"string"!=typeof t)return t;var e=t.trim();if("rgb"!==e.substr(0,3))return t;var r=e.match(/^rgba?\s*\(([^()]*)\)$/);if(!r)return t;var n=r[1].trim().split(/\s*[\s,]\s*/),i="a"===e.charAt(3)&&4===n.length;if(!i&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+", "+Math.round(255*n[1])+", "+Math.round(255*n[2]);return i?"rgba("+s+", "+n[3]+")":"rgb("+s+")"}i.tinyRGB=function(t){var e=t.toRgb();return"rgb("+Math.round(e.r)+", "+Math.round(e.g)+", "+Math.round(e.b)+")"},i.rgb=function(t){return i.tinyRGB(n(t))},i.opacity=function(t){return t?n(t).getAlpha():0},i.addOpacity=function(t,e){var r=n(t).toRgb();return"rgba("+Math.round(r.r)+", "+Math.round(r.g)+", "+Math.round(r.b)+", "+e+")"},i.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var a=n(e||l).toRgb(),i=1===a.a?a:{r:255*(1-a.a)+a.r*a.a,g:255*(1-a.a)+a.g*a.a,b:255*(1-a.a)+a.b*a.a},o={r:i.r*(1-r.a)+r.r*r.a,g:i.g*(1-r.a)+r.g*r.a,b:i.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},i.contrast=function(t,e,r){var a=n(t);return 1!==a.getAlpha()&&(a=n(i.combine(t,l))),(a.isDark()?e?a.lighten(e):l:r?a.darken(r):s).toString()},i.stroke=function(t,e){var r=n(e);t.style({stroke:i.tinyRGB(r),"stroke-opacity":r.getAlpha()})},i.fill=function(t,e){var r=n(e);t.style({fill:i.tinyRGB(r),"fill-opacity":r.getAlpha()})},i.clean=function(t){if(t&&"object"==typeof t){var e,r,n,a,o=Object.keys(t);for(e=0;e<o.length;e++)if(a=t[n=o[e]],"color"===n.substr(n.length-5))if(Array.isArray(a))for(r=0;r<a.length;r++)a[r]=c(a[r]);else t[n]=c(a);else if("colorscale"===n.substr(n.length-10)&&Array.isArray(a))for(r=0;r<a.length;r++)Array.isArray(a[r])&&(a[r][1]=c(a[r][1]));else if(Array.isArray(a)){var s=a[0];if(!Array.isArray(s)&&s&&"object"==typeof s)for(r=0;r<a.length;r++)i.clean(a[r])}else a&&"object"==typeof a&&i.clean(a)}}},{"./attributes":590,"fast-isnumeric":227,tinycolor2:535}],592:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/layout_attributes"),a=t("../../plots/font_attributes"),i=t("../../lib/extend").extendFlat,o=t("../../plot_api/edit_types").overrideAll;e.exports=o({thicknessmode:{valType:"enumerated",values:["fraction","pixels"],dflt:"pixels"},thickness:{valType:"number",min:0,dflt:30},lenmode:{valType:"enumerated",values:["fraction","pixels"],dflt:"fraction"},len:{valType:"number",min:0,dflt:1},x:{valType:"number",dflt:1.02,min:-2,max:3},xanchor:{valType:"enumerated",values:["left","center","right"],dflt:"left"},xpad:{valType:"number",min:0,dflt:10},y:{valType:"number",dflt:.5,min:-2,max:3},yanchor:{valType:"enumerated",values:["top","middle","bottom"],dflt:"middle"},ypad:{valType:"number",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:"number",min:0,dflt:0},bgcolor:{valType:"color",dflt:"rgba(0,0,0,0)"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:i({},n.ticks,{dflt:""}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:a({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,showexponent:n.showexponent,title:{text:{valType:"string"},font:a({}),side:{valType:"enumerated",values:["right","top","bottom"],dflt:"top"}},_deprecated:{title:{valType:"string"},titlefont:a({}),titleside:{valType:"enumerated",values:["right","top","bottom"],dflt:"top"}}},"colorbars","from-root")},{"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plots/cartesian/layout_attributes":776,"../../plots/font_attributes":790}],593:[function(t,e,r){"use strict";e.exports={cn:{colorbar:"colorbar",cbbg:"cbbg",cbfill:"cbfill",cbfills:"cbfills",cbline:"cbline",cblines:"cblines",cbaxis:"cbaxis",cbtitleunshift:"cbtitleunshift",cbtitle:"cbtitle",cboutline:"cboutline",crisp:"crisp",jsPlaceholder:"js-placeholder"}}},{}],594:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plot_api/plot_template"),i=t("../../plots/cartesian/tick_value_defaults"),o=t("../../plots/cartesian/tick_mark_defaults"),s=t("../../plots/cartesian/tick_label_defaults"),l=t("./attributes");e.exports=function(t,e,r){var c=a.newContainer(e,"colorbar"),u=t.colorbar||{};function h(t,e){return n.coerce(u,c,l,t,e)}var f=h("thicknessmode");h("thickness","fraction"===f?30/(r.width-r.margin.l-r.margin.r):30);var p=h("lenmode");h("len","fraction"===p?1:r.height-r.margin.t-r.margin.b),h("x"),h("xanchor"),h("xpad"),h("y"),h("yanchor"),h("ypad"),n.noneOrAll(u,c,["x","y"]),h("outlinecolor"),h("outlinewidth"),h("bordercolor"),h("borderwidth"),h("bgcolor"),i(u,c,h,"linear");var d={outerTicks:!1,font:r.font};s(u,c,h,"linear",d),o(u,c,h,"linear",d),h("title.text",r._dfltTitle.colorbar),n.coerceFont(h,"title.font",r.font),h("title.side")}},{"../../lib":716,"../../plot_api/plot_template":754,"../../plots/cartesian/tick_label_defaults":783,"../../plots/cartesian/tick_mark_defaults":784,"../../plots/cartesian/tick_value_defaults":785,"./attributes":592}],595:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("../../plots/plots"),o=t("../../registry"),s=t("../../plots/cartesian/axes"),l=t("../dragelement"),c=t("../../lib"),u=t("../../lib/extend").extendFlat,h=t("../../lib/setcursor"),f=t("../drawing"),p=t("../color"),d=t("../titles"),g=t("../../lib/svg_text_utils"),v=t("../colorscale/helpers").flipScale,m=t("../../plots/cartesian/axis_defaults"),y=t("../../plots/cartesian/position_defaults"),x=t("../../plots/cartesian/layout_attributes"),b=t("../../constants/alignment"),_=b.LINE_SPACING,w=b.FROM_TL,k=b.FROM_BR,T=t("./constants").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll("g."+T.colorbar).data(function(t){var e,r,n,a,i=t._fullLayout,o=t.calcdata,s=[];function l(t){return u(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){"function"==typeof a.calc?a.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[a.min],r[a.max]])}for(var h=0;h<o.length;h++){var f=o[h],p=(n=f[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(a=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id="cb"+n.uid+(d&&y?"-"+y:""),e._traceIndex=n.index,e._propPrefix=(y?y+".":"")+"colorbar.",e._meta=n._meta,c(),s.push(e))}}for(var x in i._colorAxes)if((r=i[x]).showscale){var b=i._colorAxes[x];(e=l(r.colorbar))._id="cb"+x,e._propPrefix=x+".colorbar.",e._meta=i._meta,a={min:"cmin",max:"cmax"},"heatmap"!==b[0]&&(n=b[1],a.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),function(t){return t._id});e.enter().append("g").attr("class",function(t){return t._id}).classed(T.colorbar,!0),e.each(function(e){var r=n.select(this);c.ensureSingle(r,"rect",T.cbbg),c.ensureSingle(r,"g",T.cbfills),c.ensureSingle(r,"g",T.cblines),c.ensureSingle(r,"g",T.cbaxis,function(t){t.classed(T.crisp,!0)}),c.ensureSingle(r,"g",T.cbtitleunshift,function(t){t.append("g").classed(T.cbtitle,!0)}),c.ensureSingle(r,"rect",T.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,b=e.title,A=b.side,M=e._zrange||n.extent(("function"==typeof h?h:v.color).domain()),S="function"==typeof v.color?v.color:function(){return v.color},E="function"==typeof h?h:function(){return h},L=e._levels,C=function(t,e,r){var n,a,i=e._levels,o=[],s=[],l=i.end+i.size/100,c=i.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(a=0;a<1e5&&(n=i.start+a*c,!(c>0?n>=l:n<=l));a++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if("function"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,a=0;a<1e5&&(n=f.start+a*c,!(c>0?n>=l:n<=l));a++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map(function(t){return t-i.size/2})).push(s[s.length-1]+i.size)}else e._fillcolor&&"string"==typeof e._fillcolor&&(s=[0]);return i.size<0&&(o.reverse(),s.reverse()),{line:o,fill:s}}(0,e,M),P=C.fill,O=C.line,z=Math.round(e.thickness*("fraction"===e.thicknessmode?l.w:1)),I=z/l.w,D=Math.round(e.len*("fraction"===e.lenmode?l.h:1)),R=D/l.h,F=e.xpad/l.w,B=(e.borderwidth+e.outlinewidth)/2,N=e.ypad/l.h,j=Math.round(e.x*l.w+e.xpad),V=e.x-I*({middle:.5,right:1}[e.xanchor]||0),U=e.y+R*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),q=Math.round(l.h*(1-U)),H=q-D;e._lenFrac=R,e._thickFrac=I,e._xLeftFrac=V,e._yBottomFrac=U;var G=e._axis=function(t,e,r){var n=t._fullLayout,a={type:"linear",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:"free",side:"right",position:1},i={type:"linear",_id:"y"+e._id},o={letter:"y",font:n.font,noHover:!0,noTickson:!0,calendar:n.calendar};function s(t,e){return c.coerce(a,i,x,t,e)}return m(a,i,s,o,n),y(a,i,s,o),i}(r,e,M);if(G.position=e.x+F+I,-1!==["top","bottom"].indexOf(A)&&(G.title.side=A,G.titlex=e.x+F,G.titley=U+("top"===b.side?R-N:N)),v.color&&"auto"===e.tickmode){G.tickmode="linear",G.tick0=L.start;var Y=L.size,W=c.constrain((q-H)/50,4,15)+1,X=(M[1]-M[0])/((e.nticks||W)*Y);if(X>1){var Z=Math.pow(10,Math.floor(Math.log(X)/Math.LN10));Y*=Z*c.roundUp(X/Z,[2,5,10]),(Math.abs(L.start)/L.size+1e-6)%1<2e-6&&(G.tick0=0)}G.dtick=Y}G.domain=[U+N,U+R-N],G.setScale(),t.attr("transform","translate("+Math.round(l.l)+","+Math.round(l.t)+")");var J,K=t.select("."+T.cbtitleunshift).attr("transform","translate(-"+Math.round(l.l)+",-"+Math.round(l.t)+")"),Q=t.select("."+T.cbaxis),$=0;function tt(n,a){var i={propContainer:G,propName:e._propPrefix+"title",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select("."+T.cbtitle)},s="h"===n.charAt(0)?n.substr(1):"h"+n;t.selectAll("."+s+",."+s+"-math-group").remove(),d.draw(r,n,u(i,a||{}))}return c.syncOrAsync([i.previousPromises,function(){if(-1!==["top","bottom"].indexOf(A)){var t,r=l.l+(e.x+F)*l.w,n=G.title.font.size;t="top"===A?(1-(U+R-N))*l.h+l.t+3+.75*n:(1-(U+N))*l.h+l.t-3-.25*n,tt(G._id+"title",{attributes:{x:r,y:t,"text-anchor":"start"}})}},function(){if(-1!==["top","bottom"].indexOf(A)){var i=t.select("."+T.cbtitle),o=i.select("text"),u=[-e.outlinewidth/2,e.outlinewidth/2],h=i.select(".h"+G._id+"title-math-group").node(),p=15.6;if(o.node()&&(p=parseInt(o.node().style.fontSize,10)*_),h?($=f.bBox(h).height)>p&&(u[1]-=($-p)/2):o.node()&&!o.classed(T.jsPlaceholder)&&($=f.bBox(o.node()).height),$){if($+=5,"top"===A)G.domain[1]-=$/l.h,u[1]*=-1;else{G.domain[0]+=$/l.h;var d=g.lineCount(o);u[1]+=(1-d)*p}i.attr("transform","translate("+u+")"),G.setScale()}}t.selectAll("."+T.cbfills+",."+T.cblines).attr("transform","translate(0,"+Math.round(l.h*(1-G.domain[1]))+")"),Q.attr("transform","translate(0,"+Math.round(-l.t)+")");var m=t.select("."+T.cbfills).selectAll("rect."+T.cbfill).data(P);m.enter().append("rect").classed(T.cbfill,!0).style("stroke","none"),m.exit().remove();var y=M.map(G.c2p).map(Math.round).sort(function(t,e){return t-e});m.each(function(t,i){var o=[0===i?M[0]:(P[i]+P[i-1])/2,i===P.length-1?M[1]:(P[i]+P[i+1])/2].map(G.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,y[0],y[1]);var s=n.select(this).attr({x:j,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)f.gradient(s,r,e._id,"vertical",e._fillgradient,"fill");else{var l=E(t).replace("e-","");s.attr("fill",a(l).toHexString())}});var x=t.select("."+T.cblines).selectAll("path."+T.cbline).data(v.color&&v.width?O:[]);x.enter().append("path").classed(T.cbline,!0),x.exit().remove(),x.each(function(t){n.select(this).attr("d","M"+j+","+(Math.round(G.c2p(t))+v.width/2%1)+"h"+z).call(f.lineGroupStyle,v.width,S(t),v.dash)}),Q.selectAll("g."+G._id+"tick,path").remove();var b=j+z+(e.outlinewidth||0)/2-("outside"===e.ticks?1:0),w=s.calcTicks(G),k=s.makeTransFn(G),L=s.getTickSigns(G)[2];return s.drawTicks(r,G,{vals:"inside"===G.ticks?s.clipEnds(G,w):w,layer:Q,path:s.makeTickPath(G,b,L),transFn:k}),s.drawLabels(r,G,{vals:w,layer:Q,transFn:k,labelFns:s.makeLabelFns(G,b)})},function(){if(-1===["top","bottom"].indexOf(A)){var t=G.title.font.size,e=G._offset+G._length/2,a=l.l+(G.position||0)*l.w+("right"===G.side?10+t*(G.showticklabels?1:.5):-10-t*(G.showticklabels?.5:0));tt("h"+G._id+"title",{avoid:{selection:n.select(r).selectAll("g."+G._id+"tick"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:a,y:e,"text-anchor":"middle"},transform:{rotate:"-90",offset:0}})}},i.previousPromises,function(){var n=z+e.outlinewidth/2+f.bBox(Q.node()).width;if((J=K.select("text")).node()&&!J.classed(T.jsPlaceholder)){var a,o=K.select(".h"+G._id+"title-math-group").node();a=o&&-1!==["top","bottom"].indexOf(A)?f.bBox(o).width:f.bBox(K.node()).right-j-l.l,n=Math.max(n,a)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=q-H;t.select("."+T.cbbg).attr({x:j-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:H-B,width:Math.max(s,2),height:Math.max(c+2*B,2)}).call(p.fill,e.bgcolor).call(p.stroke,e.bordercolor).style("stroke-width",e.borderwidth),t.selectAll("."+T.cboutline).attr({x:j,y:H+e.ypad+("top"===A?$:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-$,2)}).call(p.stroke,e.outlinecolor).style({fill:"none","stroke-width":e.outlinewidth});var u=({center:.5,right:1}[e.xanchor]||0)*s;t.attr("transform","translate("+(l.l-u)+","+l.t+")");var h={},d=w[e.yanchor],g=k[e.yanchor];"pixels"===e.lenmode?(h.y=e.y,h.t=c*d,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*d,h.yb=e.y-e.len*g);var v=w[e.xanchor],m=k[e.xanchor];if("pixels"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*m;else{var y=s-z;h.l=y*v,h.r=y*m,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*m}i.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,a,i,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr("transform"),h(t)},moveFn:function(r,o){t.attr("transform",n+" translate("+r+","+o+")"),a=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),i=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(a,i,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==a&&void 0!==i){var n={};n[e._propPrefix+"x"]=a,n[e._propPrefix+"y"]=i,void 0!==e._traceIndex?o.call("_guiRestyle",r,n,e._traceIndex):o.call("_guiRelayout",r,n)}}})}(r,e,t)}),e.exit().each(function(e){i.autoMargin(t,e._id)}).remove(),e.order()}}},{"../../constants/alignment":685,"../../lib":716,"../../lib/extend":707,"../../lib/setcursor":736,"../../lib/svg_text_utils":740,"../../plots/cartesian/axes":764,"../../plots/cartesian/axis_defaults":766,"../../plots/cartesian/layout_attributes":776,"../../plots/cartesian/position_defaults":779,"../../plots/plots":825,"../../registry":845,"../color":591,"../colorscale/helpers":602,"../dragelement":609,"../drawing":612,"../titles":678,"./constants":593,d3:164,tinycolor2:535}],596:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{"../../lib":716}],597:[function(t,e,r){"use strict";e.exports={moduleType:"component",name:"colorbar",attributes:t("./attributes"),supplyDefaults:t("./defaults"),draw:t("./draw").draw,hasColorbar:t("./has_colorbar")}},{"./attributes":592,"./defaults":594,"./draw":595,"./has_colorbar":596}],598:[function(t,e,r){"use strict";var n=t("../colorbar/attributes"),a=t("../../lib/regex").counter,i=t("./scales.js").scales;Object.keys(i);function o(t){return"`"+t+"`"}e.exports=function(t,e){t=t||"";var r,s=(e=e||{}).cLetter||"c",l=("onlyIfNumerical"in e?e.onlyIfNumerical:Boolean(t),"noScale"in e?e.noScale:"marker.line"===t),c="showScaleDflt"in e?e.showScaleDflt:"z"===s,u="string"==typeof e.colorscaleDflt?i[e.colorscaleDflt]:null,h=e.editTypeOverride||"",f=t?t+".":"";"colorAttr"in e?(r=e.colorAttr,e.colorAttr):o(f+(r={z:"z",c:"color"}[s]));var p=s+"auto",d=s+"min",g=s+"max",v=s+"mid",m=(o(f+p),o(f+d),o(f+g),{});m[d]=m[g]=void 0;var y={};y[p]=!1;var x={};return"color"===r&&(x.color={valType:"color",arrayOk:!0,editType:h||"style"},e.anim&&(x.color.anim=!0)),x[p]={valType:"boolean",dflt:!0,editType:"calc",impliedEdits:m},x[d]={valType:"number",dflt:null,editType:h||"plot",impliedEdits:y},x[g]={valType:"number",dflt:null,editType:h||"plot",impliedEdits:y},x[v]={valType:"number",dflt:null,editType:"calc",impliedEdits:m},x.colorscale={valType:"colorscale",editType:"calc",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:"boolean",dflt:!1!==e.autoColorDflt,editType:"calc",impliedEdits:{colorscale:void 0}},x.reversescale={valType:"boolean",dflt:!1,editType:"plot"},l||(x.showscale={valType:"boolean",dflt:c,editType:"calc"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:"subplotid",regex:a("coloraxis"),dflt:null,editType:"calc"}),x}},{"../../lib/regex":732,"../colorbar/attributes":592,"./scales.js":606}],599:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("./helpers").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?a.nestedProperty(e,c).get():e,h=i(u),f=!1!==h.auto,p=h.min,d=h.max,g=h.mid,v=function(){return a.aggNums(Math.min,null,l)},m=function(){return a.aggNums(Math.max,null,l)};(void 0===p?p=v():f&&(p=u._colorAx&&n(p)?Math.min(p,v()):v()),void 0===d?d=m():f&&(d=u._colorAx&&n(d)?Math.max(d,m()):m()),f&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),h._sync("min",p),h._sync("max",d),h.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync("colorscale",o))}},{"../../lib":716,"./helpers":602,"fast-isnumeric":227}],600:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./helpers").hasColorscale,i=t("./helpers").extractOpts;e.exports=function(t,e){function r(t,e){var r=t["_"+e];void 0!==r&&(t[e]=r)}function o(t,a){var o=a.container?n.nestedProperty(t,a.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=i(o),l=s.auto;(l||void 0===s.min)&&r(o,a.min),(l||void 0===s.max)&&r(o,a.max),s.autocolorscale&&r(o,"colorscale")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);a(l,"marker.line")&&o(l,{container:"marker.line",min:"cmin",max:"cmax"})}for(var h in e._colorAxes)o(e[h],{min:"cmin",max:"cmax"})}},{"../../lib":716,"./helpers":602}],601:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../colorbar/has_colorbar"),o=t("../colorbar/defaults"),s=t("./scales").isValid,l=t("../../registry").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?a.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,g="_module"in r,v=c(e,p),m=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(g){var b=u._colorAxes||{},_=h(p+"coloraxis");if(_){var w=l(r,"contour")&&a.nestedProperty(r,"contours.coloring").get()||"heatmap",k=b[_];return void(k?(k[2].push(x),k[0]!==w&&(k[0]=!1,a.warn(["Ignoring coloraxis:",_,"setting","as it is linked to incompatible colorscales."].join(" ")))):b[_]=[w,r,[x]])}}var T=v[d+"min"],A=v[d+"max"],M=n(T)&&n(A)&&T<A;h(p+d+"auto",!M)?h(p+d+"mid"):(h(p+d+"min"),h(p+d+"max"));var S,E,L=v.colorscale,C=y.colorscale;(void 0!==L&&(S=!s(L)),void 0!==C&&(S=!s(C)),h(p+"autocolorscale",S),h(p+"colorscale"),h(p+"reversescale"),"marker.line."!==p)&&(p&&g&&(E=i(v)),h(p+"showscale",E)&&o(v,m,u))}},{"../../lib":716,"../../registry":845,"../colorbar/defaults":594,"../colorbar/has_colorbar":596,"./scales":606,"fast-isnumeric":227}],602:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("fast-isnumeric"),o=t("../../lib"),s=t("../color"),l=t("./scales").isValid;var c=["showscale","autocolorscale","colorscale","reversescale","colorbar"],u=["min","max","mid","auto"];function h(t){var e,r,n,a=t._colorAx,i=a||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=i[n];if(a)for(e="c",r=0;r<u.length;r++)o[n=u[r]]=i["c"+n];else{var s;for(r=0;r<u.length;r++)(s="c"+(n=u[r]))in i?o[n]=i[s]:(s="z"+n)in i&&(o[n]=i[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;i[n]=i["_"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,a=e.reversescale?p(e.colorscale):e.colorscale,i=a.length,o=new Array(i),s=new Array(i),l=0;l<i;l++){var c=a[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,a=0;n>=0;n--,a++){var i=t[n];r[a]=[1-i[0],i[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=a(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,v=e.returnArray;return(f=d&&v?p:d?function(t){return g(p(t))}:v?function(t){return i(t)?p(t):a(t).isValid()?t:s.defaultLine}:function(t){return i(t)?g(p(t)):a(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return a(e).toRgbString()}e.exports={hasColorscale:function(t,e,r){var n=e?o.nestedProperty(t,e).get()||{}:t,a=n[r||"color"],s=!1;if(o.isArrayOrTypedArray(a))for(var c=0;c<a.length;c++)if(i(a[c])){s=!0;break}return o.isPlainObject(n)&&(s||!0===n.showscale||i(n.cmin)&&i(n.cmax)||l(n.colorscale)||o.isPlainObject(n.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},{"../../lib":716,"../color":591,"./scales":606,d3:164,"fast-isnumeric":227,tinycolor2:535}],603:[function(t,e,r){"use strict";var n=t("./scales"),a=t("./helpers");e.exports={moduleType:"component",name:"colorscale",attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyLayoutDefaults:t("./layout_defaults"),handleDefaults:t("./defaults"),crossTraceDefaults:t("./cross_trace_defaults"),calc:t("./calc"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:a.hasColorscale,extractOpts:a.extractOpts,extractScale:a.extractScale,flipScale:a.flipScale,makeColorScaleFunc:a.makeColorScaleFunc,makeColorScaleFuncFromTrace:a.makeColorScaleFuncFromTrace}},{"./attributes":598,"./calc":599,"./cross_trace_defaults":600,"./defaults":601,"./helpers":602,"./layout_attributes":604,"./layout_defaults":605,"./scales":606}],604:[function(t,e,r){"use strict";var n=t("../../lib/extend").extendFlat,a=t("./attributes"),i=t("./scales").scales;e.exports={editType:"calc",colorscale:{editType:"calc",sequential:{valType:"colorscale",dflt:i.Reds,editType:"calc"},sequentialminus:{valType:"colorscale",dflt:i.Blues,editType:"calc"},diverging:{valType:"colorscale",dflt:i.RdBu,editType:"calc"}},coloraxis:n({_isSubplotObj:!0,editType:"calc"},a("",{colorAttr:"corresponding trace color array(s)",noColorAxis:!0,showScaleDflt:!0}))}},{"../../lib/extend":707,"./attributes":598,"./scales":606}],605:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plot_api/plot_template"),i=t("./layout_attributes"),o=t("./defaults");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r("colorscale.sequential"),r("colorscale.sequentialminus"),r("colorscale.diverging");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,i.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=a.newContainer(e,h,"coloraxis"))._name=h,o(s,l,e,u,{prefix:"",cLetter:"c"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},{"../../lib":716,"../../plot_api/plot_template":754,"./defaults":601,"./layout_attributes":604}],606:[function(t,e,r){"use strict";var n=t("tinycolor2"),a={Greys:[[0,"rgb(0,0,0)"],[1,"rgb(255,255,255)"]],YlGnBu:[[0,"rgb(8,29,88)"],[.125,"rgb(37,52,148)"],[.25,"rgb(34,94,168)"],[.375,"rgb(29,145,192)"],[.5,"rgb(65,182,196)"],[.625,"rgb(127,205,187)"],[.75,"rgb(199,233,180)"],[.875,"rgb(237,248,217)"],[1,"rgb(255,255,217)"]],Greens:[[0,"rgb(0,68,27)"],[.125,"rgb(0,109,44)"],[.25,"rgb(35,139,69)"],[.375,"rgb(65,171,93)"],[.5,"rgb(116,196,118)"],[.625,"rgb(161,217,155)"],[.75,"rgb(199,233,192)"],[.875,"rgb(229,245,224)"],[1,"rgb(247,252,245)"]],YlOrRd:[[0,"rgb(128,0,38)"],[.125,"rgb(189,0,38)"],[.25,"rgb(227,26,28)"],[.375,"rgb(252,78,42)"],[.5,"rgb(253,141,60)"],[.625,"rgb(254,178,76)"],[.75,"rgb(254,217,118)"],[.875,"rgb(255,237,160)"],[1,"rgb(255,255,204)"]],Bluered:[[0,"rgb(0,0,255)"],[1,"rgb(255,0,0)"]],RdBu:[[0,"rgb(5,10,172)"],[.35,"rgb(106,137,247)"],[.5,"rgb(190,190,190)"],[.6,"rgb(220,170,132)"],[.7,"rgb(230,145,90)"],[1,"rgb(178,10,28)"]],Reds:[[0,"rgb(220,220,220)"],[.2,"rgb(245,195,157)"],[.4,"rgb(245,160,105)"],[1,"rgb(178,10,28)"]],Blues:[[0,"rgb(5,10,172)"],[.35,"rgb(40,60,190)"],[.5,"rgb(70,100,245)"],[.6,"rgb(90,120,245)"],[.7,"rgb(106,137,247)"],[1,"rgb(220,220,220)"]],Picnic:[[0,"rgb(0,0,255)"],[.1,"rgb(51,153,255)"],[.2,"rgb(102,204,255)"],[.3,"rgb(153,204,255)"],[.4,"rgb(204,204,255)"],[.5,"rgb(255,255,255)"],[.6,"rgb(255,204,255)"],[.7,"rgb(255,153,255)"],[.8,"rgb(255,102,204)"],[.9,"rgb(255,102,102)"],[1,"rgb(255,0,0)"]],Rainbow:[[0,"rgb(150,0,90)"],[.125,"rgb(0,0,200)"],[.25,"rgb(0,25,255)"],[.375,"rgb(0,152,255)"],[.5,"rgb(44,255,150)"],[.625,"rgb(151,255,0)"],[.75,"rgb(255,234,0)"],[.875,"rgb(255,111,0)"],[1,"rgb(255,0,0)"]],Portland:[[0,"rgb(12,51,131)"],[.25,"rgb(10,136,186)"],[.5,"rgb(242,211,56)"],[.75,"rgb(242,143,56)"],[1,"rgb(217,30,30)"]],Jet:[[0,"rgb(0,0,131)"],[.125,"rgb(0,60,170)"],[.375,"rgb(5,255,255)"],[.625,"rgb(255,255,0)"],[.875,"rgb(250,0,0)"],[1,"rgb(128,0,0)"]],Hot:[[0,"rgb(0,0,0)"],[.3,"rgb(230,0,0)"],[.6,"rgb(255,210,0)"],[1,"rgb(255,255,255)"]],Blackbody:[[0,"rgb(0,0,0)"],[.2,"rgb(230,0,0)"],[.4,"rgb(230,210,0)"],[.7,"rgb(255,255,255)"],[1,"rgb(160,200,255)"]],Earth:[[0,"rgb(0,0,130)"],[.1,"rgb(0,180,180)"],[.2,"rgb(40,210,40)"],[.4,"rgb(230,230,50)"],[.6,"rgb(120,70,20)"],[1,"rgb(255,255,255)"]],Electric:[[0,"rgb(0,0,0)"],[.15,"rgb(30,0,100)"],[.4,"rgb(120,0,100)"],[.6,"rgb(160,90,0)"],[.8,"rgb(230,200,0)"],[1,"rgb(255,250,220)"]],Viridis:[[0,"#440154"],[.06274509803921569,"#48186a"],[.12549019607843137,"#472d7b"],[.18823529411764706,"#424086"],[.25098039215686274,"#3b528b"],[.3137254901960784,"#33638d"],[.3764705882352941,"#2c728e"],[.4392156862745098,"#26828e"],[.5019607843137255,"#21918c"],[.5647058823529412,"#1fa088"],[.6274509803921569,"#28ae80"],[.6901960784313725,"#3fbc73"],[.7529411764705882,"#5ec962"],[.8156862745098039,"#84d44b"],[.8784313725490196,"#addc30"],[.9411764705882353,"#d8e219"],[1,"#fde725"]],Cividis:[[0,"rgb(0,32,76)"],[.058824,"rgb(0,42,102)"],[.117647,"rgb(0,52,110)"],[.176471,"rgb(39,63,108)"],[.235294,"rgb(60,74,107)"],[.294118,"rgb(76,85,107)"],[.352941,"rgb(91,95,109)"],[.411765,"rgb(104,106,112)"],[.470588,"rgb(117,117,117)"],[.529412,"rgb(131,129,120)"],[.588235,"rgb(146,140,120)"],[.647059,"rgb(161,152,118)"],[.705882,"rgb(176,165,114)"],[.764706,"rgb(192,177,109)"],[.823529,"rgb(209,191,102)"],[.882353,"rgb(225,204,92)"],[.941176,"rgb(243,219,79)"],[1,"rgb(255,233,69)"]]},i=a.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var a=t[r];if(2!==a.length||+a[0]<e||!n(a[1]).isValid())return!1;e=+a[0]}return!0}e.exports={scales:a,defaultScale:i,get:function(t,e){if(e||(e=i),!t)return e;function r(){try{t=a[t]||JSON.parse(t)}catch(r){t=e}}return"string"==typeof t&&(r(),"string"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==a[t]||o(t)}}},{tinycolor2:535}],607:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){var i=(t-r)/(n-r),o=i+e/(n-r),s=(i+o)/2;return"left"===a||"bottom"===a?i:"center"===a||"middle"===a?s:"right"===a||"top"===a?o:i<2/3-s?i:o>4/3-s?o:s}},{}],608:[function(t,e,r){"use strict";var n=t("../../lib"),a=[["sw-resize","s-resize","se-resize"],["w-resize","move","e-resize"],["nw-resize","n-resize","ne-resize"]];e.exports=function(t,e,r,i){return t="left"===r?0:"center"===r?1:"right"===r?2:n.constrain(Math.floor(3*t),0,2),e="bottom"===i?0:"middle"===i?1:"top"===i?2:n.constrain(Math.floor(3*e),0,2),a[e][t]}},{"../../lib":716}],609:[function(t,e,r){"use strict";var n=t("mouse-event-offset"),a=t("has-hover"),i=t("has-passive-events"),o=t("../../lib").removeElement,s=t("../../plots/cartesian/constants"),l=e.exports={};l.align=t("./align"),l.getCursor=t("./cursor");var c=t("./unhover");function u(){var t=document.createElement("div");t.className="dragcover";var e=t.style;return e.position="fixed",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background="none",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,g,v=t.gd,m=1,y=v._context.doubleClickDelay,x=t.element;v._mouseDownTime||(v._mouseDownTime=0),x.style.pointerEvents="all",x.onmousedown=_,i?(x._ontouchstart&&x.removeEventListener("touchstart",x._ontouchstart),x._ontouchstart=_,x.addEventListener("touchstart",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(i){v._dragged=!1,v._dragging=!0;var o=h(i);e=o[0],r=o[1],d=i.target,p=i,g=2===i.buttons||i.ctrlKey,"undefined"==typeof i.clientX&&"undefined"==typeof i.clientY&&(i.clientX=e,i.clientY=r),(n=(new Date).getTime())-v._mouseDownTime<y?m+=1:(m=1,v._mouseDownTime=n),t.prepFn&&t.prepFn(i,e,r),a&&!g?(f=u()).style.cursor=window.getComputedStyle(x).cursor:a||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener("mouseup",k),document.addEventListener("touchend",k),!1!==t.dragmode&&(i.preventDefault(),document.addEventListener("mousemove",w),document.addEventListener("touchmove",w,{passive:!1}))}function w(n){n.preventDefault();var a=h(n),i=t.minDrag||s.MINDRAG,o=b(a[0]-e,a[1]-r,i),c=o[0],u=o[1];(c||u)&&(v._dragged=!0,l.unhover(v)),v._dragged&&t.moveFn&&!g&&(v._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function k(e){if(delete v._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener("mousemove",w),document.removeEventListener("touchmove",w)),document.removeEventListener("mouseup",k),document.removeEventListener("touchend",k),a?o(f):c&&(f.documentElement.style.cursor=c,c=null),v._dragging){if(v._dragging=!1,(new Date).getTime()-v._mouseDownTime>y&&(m=Math.max(m-1,1)),v._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(m,p),!g){var r;try{r=new MouseEvent("click",e)}catch(t){var n=h(e);(r=document.createEvent("MouseEvents")).initMouseEvent("click",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}v._dragging=!1,v._dragged=!1}else v._dragged=!1}},l.coverSlip=u},{"../../lib":716,"../../plots/cartesian/constants":770,"./align":607,"./cursor":608,"./unhover":610,"has-hover":411,"has-passive-events":412,"mouse-event-offset":437}],610:[function(t,e,r){"use strict";var n=t("../../lib/events"),a=t("../../lib/throttle"),i=t("../../lib/dom").getGraphDiv,o=t("../fx/constants"),s=e.exports={};s.wrapped=function(t,e,r){(t=i(t))._fullLayout&&a.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,a=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,"plotly_beforehover",e)||(r._hoverlayer.selectAll("g").remove(),r._hoverlayer.selectAll("line").remove(),r._hoverlayer.selectAll("circle").remove(),t._hoverdata=void 0,e.target&&a&&t.emit("plotly_unhover",{event:e,points:a}))}},{"../../lib/dom":705,"../../lib/events":706,"../../lib/throttle":741,"../fx/constants":624}],611:[function(t,e,r){"use strict";r.dash={valType:"string",values:["solid","dot","dash","longdash","dashdot","longdashdot"],dflt:"solid",editType:"style"}},{}],612:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("tinycolor2"),o=t("../../registry"),s=t("../color"),l=t("../colorscale"),c=t("../../lib"),u=t("../../lib/svg_text_utils"),h=t("../../constants/xmlns_namespaces"),f=t("../../constants/alignment").LINE_SPACING,p=t("../../constants/interactions").DESELECTDIM,d=t("../../traces/scatter/subtypes"),g=t("../../traces/scatter/make_bubble_size_func"),v=t("../../components/fx/helpers").appendArrayPointValue,m=e.exports={};m.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style("font-family",e),r+1&&t.style("font-size",r+"px"),n&&t.call(s.fill,n)},m.setPosition=function(t,e,r){t.attr("x",e).attr("y",r)},m.setSize=function(t,e,r){t.attr("width",e).attr("height",r)},m.setRect=function(t,e,r,n,a){t.call(m.setPosition,e,r).call(m.setSize,n,a)},m.translatePoint=function(t,e,r,n){var i=r.c2p(t.x),o=n.c2p(t.y);return!!(a(i)&&a(o)&&e.node())&&("text"===e.node().nodeName?e.attr("x",i).attr("y",o):e.attr("transform","translate("+i+","+o+")"),!0)},m.translatePoints=function(t,e,r){t.each(function(t){var a=n.select(this);m.translatePoint(t,a,e,r)})},m.hideOutsideRangePoint=function(t,e,r,n,a,i){e.attr("display",r.isPtWithinRange(t,a)&&n.isPtWithinRange(t,i)?null:"none")},m.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,a=e.yaxis;t.each(function(e){var i=e[0].trace,s=i.xcalendar,l=i.ycalendar,c=o.traceIs(i,"bar-like")?".bartext":".point,.textpoint";t.selectAll(c).each(function(t){m.hideOutsideRangePoint(t,n.select(this),r,a,s,l)})})}},m.crispRound=function(t,e,r){return e&&a(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},m.singleLineStyle=function(t,e,r,n,a){e.style("fill","none");var i=(((t||[])[0]||{}).trace||{}).line||{},o=r||i.width||0,l=a||i.dash||"";s.stroke(e,n||i.color),m.dashLine(e,l,o)},m.lineGroupStyle=function(t,e,r,a){t.style("fill","none").each(function(t){var i=(((t||[])[0]||{}).trace||{}).line||{},o=e||i.width||0,l=a||i.dash||"";n.select(this).call(s.stroke,r||i.color).call(m.dashLine,l,o)})},m.dashLine=function(t,e,r){r=+r||0,e=m.dashStyle(e,r),t.style({"stroke-dasharray":e,"stroke-width":r+"px"})},m.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return"solid"===t?t="":"dot"===t?t=r+"px,"+r+"px":"dash"===t?t=3*r+"px,"+3*r+"px":"longdash"===t?t=5*r+"px,"+5*r+"px":"dashdot"===t?t=3*r+"px,"+r+"px,"+r+"px,"+r+"px":"longdashdot"===t&&(t=5*r+"px,"+2*r+"px,"+r+"px,"+2*r+"px"),t},m.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},m.fillGroupStyle=function(t){t.style("stroke-width",0).each(function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)})};var y=t("./symbol_defs");m.symbolNames=[],m.symbolFuncs=[],m.symbolNeedLines={},m.symbolNoDot={},m.symbolNoFill={},m.symbolList=[],Object.keys(y).forEach(function(t){var e=y[t];m.symbolList=m.symbolList.concat([e.n,t,e.n+100,t+"-open"]),m.symbolNames[e.n]=t,m.symbolFuncs[e.n]=e.f,e.needLine&&(m.symbolNeedLines[e.n]=!0),e.noDot?m.symbolNoDot[e.n]=!0:m.symbolList=m.symbolList.concat([e.n+200,t+"-dot",e.n+300,t+"-open-dot"]),e.noFill&&(m.symbolNoFill[e.n]=!0)});var x=m.symbolNames.length,b="M0,0.5L0.5,0L0,-0.5L-0.5,0Z";function _(t,e){var r=t%100;return m.symbolFuncs[r](e)+(t>=200?b:"")}m.symbolNumber=function(t){if("string"==typeof t){var e=0;t.indexOf("-open")>0&&(e=100,t=t.replace("-open","")),t.indexOf("-dot")>0&&(e+=200,t=t.replace("-dot","")),(t=m.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=x||t>=400?0:Math.floor(Math.max(t,0))};var w={x1:1,x2:0,y1:0,y2:0},k={x1:0,x2:0,y1:1,y2:0},T=n.format("~.1f"),A={radial:{node:"radialGradient"},radialreversed:{node:"radialGradient",reversed:!0},horizontal:{node:"linearGradient",attrs:w},horizontalreversed:{node:"linearGradient",attrs:w,reversed:!0},vertical:{node:"linearGradient",attrs:k},verticalreversed:{node:"linearGradient",attrs:k,reversed:!0}};m.gradient=function(t,e,r,a,o,l){for(var u=o.length,h=A[a],f=new Array(u),p=0;p<u;p++)h.reversed?f[u-1-p]=[T(100*(1-o[p][0])),o[p][1]]:f[p]=[T(100*o[p][0]),o[p][1]];var d="g"+e._fullLayout._uid+"-"+r,g=e._fullLayout._defs.select(".gradients").selectAll("#"+d).data([a+f.join(";")],c.identity);g.exit().remove(),g.enter().append(h.node).each(function(){var t=n.select(this);h.attrs&&t.attr(h.attrs),t.attr("id",d);var e=t.selectAll("stop").data(f);e.exit().remove(),e.enter().append("stop"),e.each(function(t){var e=i(t[1]);n.select(this).attr({offset:t[0]+"%","stop-color":s.tinyRGB(e),"stop-opacity":e.getAlpha()})})}),t.style(l,D(d,e)).style(l+"-opacity",null)},m.initGradients=function(t){c.ensureSingle(t._fullLayout._defs,"g","gradients").selectAll("linearGradient,radialGradient").remove()},m.pointStyle=function(t,e,r){if(t.size()){var a=m.makePointStyleFns(e);t.each(function(t){m.singlePointStyle(t,n.select(this),e,a,r)})}},m.singlePointStyle=function(t,e,r,n,a){var i=r.marker,o=i.line;if(e.style("opacity",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?i.opacity:t.mo),n.ms2mrc){var l;l="various"===t.ms||"various"===i.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=m.symbolNumber(t.mx||i.symbol)||0;t.om=u%200>=100,e.attr("d",_(u,l))}var h,f,p,d=!1;if(t.so)p=o.outlierwidth,f=o.outliercolor,h=i.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,f="mlc"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(i.color)&&(h=s.defaultLine,d=!0),h="mc"in t?t.mcc=n.markerScale(t.mc):i.color||"rgba(0,0,0,0)",n.selectedColorFn&&(h=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,h).style({"stroke-width":(p||1)+"px",fill:"none"});else{e.style("stroke-width",(t.isBlank?0:p)+"px");var v=i.gradient,y=t.mgt;if(y?d=!0:y=v&&v.type,Array.isArray(y)&&(y=y[0],A[y]||(y=0)),y&&"none"!==y){var x=t.mgc;x?d=!0:x=v.color;var b=r.uid;d&&(b+="-"+t.i),m.gradient(e,a,b,y,[[0,x],[1,h]],"fill")}else s.fill(e,h);p&&s.stroke(e,f)}},m.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=m.tryColorscale(r,""),e.lineScale=m.tryColorscale(r,"line"),o.traceIs(t,"symbols")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,m.makeSelectedPointStyleFns(t)),e},m.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},a=t.marker||{},i=r.marker||{},s=n.marker||{},l=a.opacity,u=i.opacity,h=s.opacity,f=void 0!==u,d=void 0!==h;(c.isArrayOrTypedArray(l)||f||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?a.opacity:t.mo;return t.selected?f?u:e:d?h:p*e});var g=a.color,v=i.color,m=s.color;(v||m)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?v||e:m||e});var y=a.size,x=i.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,"symbols")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},m.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},a=t.textfont||{},i=r.textfont||{},o=n.textfont||{},l=a.color,c=i.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},m.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=m.makeSelectedPointStyleFns(e),a=e.marker||{},i=[];r.selectedOpacityFn&&i.push(function(t,e){t.style("opacity",r.selectedOpacityFn(e))}),r.selectedColorFn&&i.push(function(t,e){s.fill(t,r.selectedColorFn(e))}),r.selectedSizeFn&&i.push(function(t,e){var n=e.mx||a.symbol||0,i=r.selectedSizeFn(e);t.attr("d",_(m.symbolNumber(n),i)),e.mrc2=i}),i.length&&t.each(function(t){for(var e=n.select(this),r=0;r<i.length;r++)i[r](e,t)})}},m.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var M={start:1,end:-1,middle:0,bottom:1,top:-1};function S(t,e,r,a){var i=n.select(t.node().parentNode),o=-1!==e.indexOf("top")?"top":-1!==e.indexOf("bottom")?"bottom":"middle",s=-1!==e.indexOf("left")?"end":-1!==e.indexOf("right")?"start":"middle",l=a?a/.8+1:0,c=(u.lineCount(t)-1)*f+1,h=M[s]*l,p=.75*r+M[o]*l+(M[o]-1)*c*r/2;t.attr("text-anchor",s),i.attr("transform","translate("+h+","+p+")")}function E(t,e){var r=t.ts||e.textfont.size;return a(r)&&r>0?r:0}m.textPointStyle=function(t,e,r){if(t.size()){var a;if(e.selectedpoints){var i=m.makeSelectedTextStyleFns(e);a=i.selectedTextColorFn}var o=e.texttemplate,s=r._fullLayout;t.each(function(t){var i=n.select(this),l=o?c.extractOption(t,e,"txt","texttemplate"):c.extractOption(t,e,"tx","text");if(l||0===l){if(o){var h=e._module.formatLabels?e._module.formatLabels(t,e,s):{},f={};v(f,e,t.i);var p=e._meta||{};l=c.texttemplateString(l,h,s._d3locale,f,t,p)}var d=t.tp||e.textposition,g=E(t,e),y=a?a(t):t.tc||e.textfont.color;i.call(m.font,t.tf||e.textfont.family,g,y).text(l).call(u.convertToTspans,r).call(S,d,g,t.mrc)}else i.remove()})}},m.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=m.makeSelectedTextStyleFns(e);t.each(function(t){var a=n.select(this),i=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=E(t,e);s.fill(a,i),S(a,o,l,t.mrc2||t.mrc)})}};var L=.5;function C(t,e,r,a){var i=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(i*i+o*o,L/2),u=Math.pow(s*s+l*l,L/2),h=(u*u*i-c*c*s)*a,f=(u*u*o-c*c*l)*a,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&h/p),2),n.round(e[1]+(p&&f/p),2)],[n.round(e[0]-(d&&h/d),2),n.round(e[1]-(d&&f/d),2)]]}m.smoothopen=function(t,e){if(t.length<3)return"M"+t.join("L");var r,n="M"+t[0],a=[];for(r=1;r<t.length-1;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(n+="Q"+a[0][0]+" "+t[1],r=2;r<t.length-1;r++)n+="C"+a[r-2][1]+" "+a[r-1][0]+" "+t[r];return n+="Q"+a[t.length-3][1]+" "+t[t.length-1]},m.smoothclosed=function(t,e){if(t.length<3)return"M"+t.join("L")+"Z";var r,n="M"+t[0],a=t.length-1,i=[C(t[a],t[0],t[1],e)];for(r=1;r<a;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(i.push(C(t[a-1],t[a],t[0],e)),r=1;r<=a;r++)n+="C"+i[r-1][1]+" "+i[r][0]+" "+t[r];return n+="C"+i[a][1]+" "+i[0][0]+" "+t[0]+"Z"};var P={hv:function(t,e){return"H"+n.round(e[0],2)+"V"+n.round(e[1],2)},vh:function(t,e){return"V"+n.round(e[1],2)+"H"+n.round(e[0],2)},hvh:function(t,e){return"H"+n.round((t[0]+e[0])/2,2)+"V"+n.round(e[1],2)+"H"+n.round(e[0],2)},vhv:function(t,e){return"V"+n.round((t[1]+e[1])/2,2)+"H"+n.round(e[0],2)+"V"+n.round(e[1],2)}},O=function(t,e){return"L"+n.round(e[0],2)+","+n.round(e[1],2)};m.steps=function(t){var e=P[t]||O;return function(t){for(var r="M"+n.round(t[0][0],2)+","+n.round(t[0][1],2),a=1;a<t.length;a++)r+=e(t[a-1],t[a]);return r}},m.makeTester=function(){var t=c.ensureSingleById(n.select("body"),"svg","js-plotly-tester",function(t){t.attr(h.svgAttrs).style({position:"absolute",left:"-10000px",top:"-10000px",width:"9000px",height:"9000px","z-index":"1"})}),e=c.ensureSingle(t,"path","js-reference-point",function(t){t.attr("d","M0,0H1V1H0Z").style({"stroke-width":0,fill:"black"})});m.tester=t,m.testref=e},m.savedBBoxes={};var z=0;function I(t){var e=t.getAttribute("data-unformatted");if(null!==e)return e+t.getAttribute("data-math")+t.getAttribute("text-anchor")+t.getAttribute("style")}function D(t,e){if(!t)return null;var r=e._context;return"url('"+(r._exportedPlot?"":r._baseUrl||"")+"#"+t+"')"}m.bBox=function(t,e,r){var a,i,o;if(r||(r=I(t)),r){if(a=m.savedBBoxes[r])return c.extendFlat({},a)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=I(s)){var l=+s.getAttribute("x")||0,h=+s.getAttribute("y")||0,f=s.getAttribute("transform");if(!f){var p=m.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),h&&(p.top+=h,p.bottom+=h),p}if(r+="~"+l+"~"+h+"~"+f,a=m.savedBBoxes[r])return c.extendFlat({},a)}}e?i=t:(o=m.tester.node(),i=t.cloneNode(!0),o.appendChild(i)),n.select(i).attr("transform",null).call(u.positionText,0,0);var d=i.getBoundingClientRect(),g=m.testref.node().getBoundingClientRect();e||o.removeChild(i);var v={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return z>=1e4&&(m.savedBBoxes={},z=0),r&&(m.savedBBoxes[r]=v),z++,c.extendFlat({},v)},m.setClipUrl=function(t,e,r){t.attr("clip-path",D(e,r))},m.getTranslate=function(t){var e=(t[t.attr?"attr":"getAttribute"]("transform")||"").replace(/.*\btranslate\((-?\d*\.?\d*)[^-\d]*(-?\d*\.?\d*)[^\d].*/,function(t,e,r){return[e,r].join(" ")}).split(" ");return{x:+e[0]||0,y:+e[1]||0}},m.setTranslate=function(t,e,r){var n=t.attr?"attr":"getAttribute",a=t.attr?"attr":"setAttribute",i=t[n]("transform")||"";return e=e||0,r=r||0,i=i.replace(/(\btranslate\(.*?\);?)/,"").trim(),i=(i+=" translate("+e+", "+r+")").trim(),t[a]("transform",i),i},m.getScale=function(t){var e=(t[t.attr?"attr":"getAttribute"]("transform")||"").replace(/.*\bscale\((\d*\.?\d*)[^\d]*(\d*\.?\d*)[^\d].*/,function(t,e,r){return[e,r].join(" ")}).split(" ");return{x:+e[0]||1,y:+e[1]||1}},m.setScale=function(t,e,r){var n=t.attr?"attr":"getAttribute",a=t.attr?"attr":"setAttribute",i=t[n]("transform")||"";return e=e||1,r=r||1,i=i.replace(/(\bscale\(.*?\);?)/,"").trim(),i=(i+=" scale("+e+", "+r+")").trim(),t[a]("transform",i),i};var R=/\s*sc.*/;m.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?"":" scale("+e+","+r+")";t.each(function(){var t=(this.getAttribute("transform")||"").replace(R,"");t=(t+=n).trim(),this.setAttribute("transform",t)})}};var F=/translate\([^)]*\)\s*$/;m.setTextPointsScale=function(t,e,r){t&&t.each(function(){var t,a=n.select(this),i=a.select("text");if(i.node()){var o=parseFloat(i.attr("x")||0),s=parseFloat(i.attr("y")||0),l=(a.attr("transform")||"").match(F);t=1===e&&1===r?[]:["translate("+o+","+s+")","scale("+e+","+r+")","translate("+-o+","+-s+")"],l&&t.push(l),a.attr("transform",t.join(" "))}})}},{"../../components/fx/helpers":626,"../../constants/alignment":685,"../../constants/interactions":691,"../../constants/xmlns_namespaces":693,"../../lib":716,"../../lib/svg_text_utils":740,"../../registry":845,"../../traces/scatter/make_bubble_size_func":1135,"../../traces/scatter/subtypes":1142,"../color":591,"../colorscale":603,"./symbol_defs":613,d3:164,"fast-isnumeric":227,tinycolor2:535}],613:[function(t,e,r){"use strict";var n=t("d3");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return"M"+e+",0A"+e+","+e+" 0 1,1 0,-"+e+"A"+e+","+e+" 0 0,1 "+e+",0Z"}},square:{n:1,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"H-"+e+"V-"+e+"H"+e+"Z"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return"M"+e+",0L0,"+e+"L-"+e+",0L0,-"+e+"Z"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return"M"+r+","+e+"H"+e+"V"+r+"H-"+e+"V"+e+"H-"+r+"V-"+e+"H-"+e+"V-"+r+"H"+e+"V-"+e+"H"+r+"Z"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r="l"+e+","+e,a="l"+e+",-"+e,i="l-"+e+",-"+e,o="l-"+e+","+e;return"M0,"+e+r+a+i+a+i+o+i+o+r+o+r+"Z"}},"triangle-up":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return"M-"+e+","+n.round(t/2,2)+"H"+e+"L0,-"+n.round(t,2)+"Z"}},"triangle-down":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return"M-"+e+",-"+n.round(t/2,2)+"H"+e+"L0,"+n.round(t,2)+"Z"}},"triangle-left":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return"M"+n.round(t/2,2)+",-"+e+"V"+e+"L-"+n.round(t,2)+",0Z"}},"triangle-right":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return"M-"+n.round(t/2,2)+",-"+e+"V"+e+"L"+n.round(t,2)+",0Z"}},"triangle-ne":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return"M-"+r+",-"+e+"H"+e+"V"+r+"Z"}},"triangle-se":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return"M"+e+",-"+r+"V"+e+"H-"+r+"Z"}},"triangle-sw":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return"M"+r+","+e+"H-"+e+"V-"+r+"Z"}},"triangle-nw":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return"M-"+e+","+r+"V-"+e+"H"+r+"Z"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),a=n.round(-t,2),i=n.round(-.309*t,2);return"M"+e+","+i+"L"+r+","+n.round(.809*t,2)+"H-"+r+"L-"+e+","+i+"L0,"+a+"Z"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),a=n.round(t*Math.sqrt(3)/2,2);return"M"+a+",-"+r+"V"+r+"L0,"+e+"L-"+a+","+r+"V-"+r+"L0,-"+e+"Z"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),a=n.round(t*Math.sqrt(3)/2,2);return"M-"+r+","+a+"H"+r+"L"+e+",0L"+r+",-"+a+"H-"+r+"L-"+e+",0Z"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return"M-"+r+",-"+e+"H"+r+"L"+e+",-"+r+"V"+r+"L"+r+","+e+"H-"+r+"L-"+e+","+r+"V-"+r+"Z"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),a=n.round(.951*e,2),i=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return"M"+r+","+l+"H"+a+"L"+i+","+c+"L"+o+","+u+"L0,"+n.round(.382*e,2)+"L-"+o+","+u+"L-"+i+","+c+"L-"+a+","+l+"H-"+r+"L0,"+s+"Z"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),a=n.round(.76*t,2);return"M-"+a+",0l-"+r+",-"+e+"h"+a+"l"+r+",-"+e+"l"+r+","+e+"h"+a+"l-"+r+","+e+"l"+r+","+e+"h-"+a+"l-"+r+","+e+"l-"+r+",-"+e+"h-"+a+"Z"}},"star-triangle-up":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),a=n.round(1.6*t,2),i=n.round(4*t,2),o="A "+i+","+i+" 0 0 1 ";return"M-"+e+","+r+o+e+","+r+o+"0,-"+a+o+"-"+e+","+r+"Z"}},"star-triangle-down":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),a=n.round(1.6*t,2),i=n.round(4*t,2),o="A "+i+","+i+" 0 0 1 ";return"M"+e+",-"+r+o+"-"+e+",-"+r+o+"0,"+a+o+e+",-"+r+"Z"}},"star-square":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),a="A "+r+","+r+" 0 0 1 ";return"M-"+e+",-"+e+a+"-"+e+","+e+a+e+","+e+a+e+",-"+e+a+"-"+e+",-"+e+"Z"}},"star-diamond":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),a="A "+r+","+r+" 0 0 1 ";return"M-"+e+",0"+a+"0,"+e+a+e+",0"+a+"0,-"+e+a+"-"+e+",0Z"}},"diamond-tall":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return"M0,"+r+"L"+e+",0L0,-"+r+"L-"+e+",0Z"}},"diamond-wide":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return"M0,"+r+"L"+e+",0L0,-"+r+"L-"+e+",0Z"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"H-"+e+"L"+e+",-"+e+"H-"+e+"Z"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"V-"+e+"L-"+e+","+e+"V-"+e+"Z"},noDot:!0},"circle-cross":{n:27,f:function(t){var e=n.round(t,2);return"M0,"+e+"V-"+e+"M"+e+",0H-"+e+"M"+e+",0A"+e+","+e+" 0 1,1 0,-"+e+"A"+e+","+e+" 0 0,1 "+e+",0Z"},needLine:!0,noDot:!0},"circle-x":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return"M"+r+","+r+"L-"+r+",-"+r+"M"+r+",-"+r+"L-"+r+","+r+"M"+e+",0A"+e+","+e+" 0 1,1 0,-"+e+"A"+e+","+e+" 0 0,1 "+e+",0Z"},needLine:!0,noDot:!0},"square-cross":{n:29,f:function(t){var e=n.round(t,2);return"M0,"+e+"V-"+e+"M"+e+",0H-"+e+"M"+e+","+e+"H-"+e+"V-"+e+"H"+e+"Z"},needLine:!0,noDot:!0},"square-x":{n:30,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"L-"+e+",-"+e+"M"+e+",-"+e+"L-"+e+","+e+"M"+e+","+e+"H-"+e+"V-"+e+"H"+e+"Z"},needLine:!0,noDot:!0},"diamond-cross":{n:31,f:function(t){var e=n.round(1.3*t,2);return"M"+e+",0L0,"+e+"L-"+e+",0L0,-"+e+"ZM0,-"+e+"V"+e+"M-"+e+",0H"+e},needLine:!0,noDot:!0},"diamond-x":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return"M"+e+",0L0,"+e+"L-"+e+",0L0,-"+e+"ZM-"+r+",-"+r+"L"+r+","+r+"M-"+r+","+r+"L"+r+",-"+r},needLine:!0,noDot:!0},"cross-thin":{n:33,f:function(t){var e=n.round(1.4*t,2);return"M0,"+e+"V-"+e+"M"+e+",0H-"+e},needLine:!0,noDot:!0,noFill:!0},"x-thin":{n:34,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"L-"+e+",-"+e+"M"+e+",-"+e+"L-"+e+","+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return"M0,"+e+"V-"+e+"M"+e+",0H-"+e+"M"+r+","+r+"L-"+r+",-"+r+"M"+r+",-"+r+"L-"+r+","+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return"M"+e+","+r+"V-"+r+"m-"+r+",0V"+r+"M"+r+","+e+"H-"+r+"m0,-"+r+"H"+r},needLine:!0,noFill:!0},"y-up":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return"M-"+e+","+a+"L0,0M"+e+","+a+"L0,0M0,-"+r+"L0,0"},needLine:!0,noDot:!0,noFill:!0},"y-down":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return"M-"+e+",-"+a+"L0,0M"+e+",-"+a+"L0,0M0,"+r+"L0,0"},needLine:!0,noDot:!0,noFill:!0},"y-left":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return"M"+a+","+e+"L0,0M"+a+",-"+e+"L0,0M-"+r+",0L0,0"},needLine:!0,noDot:!0,noFill:!0},"y-right":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),a=n.round(.8*t,2);return"M-"+a+","+e+"L0,0M-"+a+",-"+e+"L0,0M"+r+",0L0,0"},needLine:!0,noDot:!0,noFill:!0},"line-ew":{n:41,f:function(t){var e=n.round(1.4*t,2);return"M"+e+",0H-"+e},needLine:!0,noDot:!0,noFill:!0},"line-ns":{n:42,f:function(t){var e=n.round(1.4*t,2);return"M0,"+e+"V-"+e},needLine:!0,noDot:!0,noFill:!0},"line-ne":{n:43,f:function(t){var e=n.round(t,2);return"M"+e+",-"+e+"L-"+e+","+e},needLine:!0,noDot:!0,noFill:!0},"line-nw":{n:44,f:function(t){var e=n.round(t,2);return"M"+e+","+e+"L-"+e+",-"+e},needLine:!0,noDot:!0,noFill:!0}}},{d3:164}],614:[function(t,e,r){"use strict";e.exports={visible:{valType:"boolean",editType:"calc"},type:{valType:"enumerated",values:["percent","constant","sqrt","data"],editType:"calc"},symmetric:{valType:"boolean",editType:"calc"},array:{valType:"data_array",editType:"calc"},arrayminus:{valType:"data_array",editType:"calc"},value:{valType:"number",min:0,dflt:10,editType:"calc"},valueminus:{valType:"number",min:0,dflt:10,editType:"calc"},traceref:{valType:"integer",min:0,dflt:0,editType:"style"},tracerefminus:{valType:"integer",min:0,dflt:0,editType:"style"},copy_ystyle:{valType:"boolean",editType:"plot"},copy_zstyle:{valType:"boolean",editType:"style"},color:{valType:"color",editType:"style"},thickness:{valType:"number",min:0,dflt:2,editType:"style"},width:{valType:"number",min:0,editType:"plot"},editType:"calc",_deprecated:{opacity:{valType:"number",editType:"style"}}}},{}],615:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../registry"),i=t("../../plots/cartesian/axes"),o=t("../../lib"),s=t("./compute_error");function l(t,e,r,a){var l=e["error_"+a]||{},c=[];if(l.visible&&-1!==["linear","log"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[a];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var v=f[a+"s"]=d-g[0],m=f[a+"h"]=d+g[1];c.push(v,m)}}}var y=r._id,x=e._extremes[y],b=i.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&a.traceIs(o,"errorBarsOK")){var s=i.getFromId(t,o.xaxis),c=i.getFromId(t,o.yaxis);l(n,o,s,"x"),l(n,o,c,"y")}}}},{"../../lib":716,"../../plots/cartesian/axes":764,"../../registry":845,"./compute_error":616,"fast-isnumeric":227}],616:[function(t,e,r){"use strict";function n(t,e){return"percent"===t?function(t){return Math.abs(t*e/100)}:"constant"===t?function(){return Math.abs(e)}:"sqrt"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if("data"===e){var a=t.array||[];if(r)return function(t,e){var r=+a[e];return[r,r]};var i=t.arrayminus||[];return function(t,e){var r=+a[e],n=+i[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],617:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../registry"),i=t("../../lib"),o=t("../../plot_api/plot_template"),s=t("./attributes");e.exports=function(t,e,r,l){var c="error_"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return i.coerce(h,u,s,t,e)}if(!1!==f("visible",void 0!==h.array||void 0!==h.value||"sqrt"===h.type)){var p=f("type","array"in h?"data":"percent"),d=!0;"sqrt"!==p&&(d=f("symmetric",!(("data"===p?"arrayminus":"valueminus")in h))),"data"===p?(f("array"),f("traceref"),d||(f("arrayminus"),f("tracerefminus"))):"percent"!==p&&"constant"!==p||(f("value"),d||f("valueminus"));var g="copy_"+l.inherit+"style";if(l.inherit)(e["error_"+l.inherit]||{}).visible&&f(g,!(h.color||n(h.thickness)||n(h.width)));l.inherit&&u[g]||(f("color",r),f("thickness"),f("width",a.traceIs(e,"gl3d")?0:4))}}},{"../../lib":716,"../../plot_api/plot_template":754,"../../registry":845,"./attributes":614,"fast-isnumeric":227}],618:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plot_api/edit_types").overrideAll,i=t("./attributes"),o={error_x:n.extendFlat({},i),error_y:n.extendFlat({},i)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},i),error_y:n.extendFlat({},i),error_z:n.extendFlat({},i)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:"component",name:"errorbars",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:a(s,"calc","nested"),scattergl:a(o,"calc","nested")}},supplyDefaults:t("./defaults"),calc:t("./calc"),makeComputeError:t("./compute_error"),plot:t("./plot"),style:t("./style"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{"../../lib":716,"../../plot_api/edit_types":747,"./attributes":614,"./calc":615,"./compute_error":616,"./defaults":617,"./plot":619,"./style":620}],619:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../drawing"),o=t("../../traces/scatter/subtypes");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each(function(e){var h,f=e[0].trace,p=f.error_x||{},d=f.error_y||{};f.ids&&(h=function(t){return t.id});var g=o.hasMarkers(f)&&f.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var v=n.select(this).selectAll("g.errorbar").data(e,h);if(v.exit().remove(),e.length){p.visible||v.selectAll("path.xerror").remove(),d.visible||v.selectAll("path.yerror").remove(),v.style("opacity",1);var m=v.enter().append("g").classed("errorbar",!0);u&&m.style("opacity",0).transition().duration(s.duration).style("opacity",1),i.setClipUrl(v,r.layerClipId,t),v.each(function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),a(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),a(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var i,o=e.select("path.yerror");if(d.visible&&a(r.x)&&a(r.yh)&&a(r.ys)){var h=d.width;i="M"+(r.x-h)+","+r.yh+"h"+2*h+"m-"+h+",0V"+r.ys,r.noYS||(i+="m-"+h+",0h"+2*h),!o.size()?o=e.append("path").style("vector-effect","non-scaling-stroke").classed("yerror",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr("d",i)}else o.remove();var f=e.select("path.xerror");if(p.visible&&a(r.y)&&a(r.xh)&&a(r.xs)){var v=(p.copy_ystyle?d:p).width;i="M"+r.xh+","+(r.y-v)+"v"+2*v+"m0,-"+v+"H"+r.xs,r.noXS||(i+="m0,-"+v+"v"+2*v),!f.size()?f=e.append("path").style("vector-effect","non-scaling-stroke").classed("xerror",!0):u&&(f=f.transition().duration(s.duration).ease(s.easing)),f.attr("d",i)}else f.remove()}})}})}},{"../../traces/scatter/subtypes":1142,"../drawing":612,d3:164,"fast-isnumeric":227}],620:[function(t,e,r){"use strict";var n=t("d3"),a=t("../color");e.exports=function(t){t.each(function(t){var e=t[0].trace,r=e.error_y||{},i=e.error_x||{},o=n.select(this);o.selectAll("path.yerror").style("stroke-width",r.thickness+"px").call(a.stroke,r.color),i.copy_ystyle&&(i=r),o.selectAll("path.xerror").style("stroke-width",i.thickness+"px").call(a.stroke,i.color)})}},{"../color":591,d3:164}],621:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("./layout_attributes").hoverlabel,i=t("../../lib/extend").extendFlat;e.exports={hoverlabel:{bgcolor:i({},a.bgcolor,{arrayOk:!0}),bordercolor:i({},a.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:"none"}),align:i({},a.align,{arrayOk:!0}),namelength:i({},a.namelength,{arrayOk:!0}),editType:"none"}}},{"../../lib/extend":707,"../../plots/font_attributes":790,"./layout_attributes":630}],622:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry");function i(t,e,r,a){a=a||n.identity,Array.isArray(t)&&(e[0][r]=a(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!a.traceIs(c,"pie-like")){var u=a.traceIs(c,"2dMap")?i:n.fillArray;u(c.hoverinfo,l,"hi",o(c)),c.hovertemplate&&u(c.hovertemplate,l,"ht"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,"hbg"),u(c.hoverlabel.bordercolor,l,"hbc"),u(c.hoverlabel.font.size,l,"hts"),u(c.hoverlabel.font.color,l,"htc"),u(c.hoverlabel.font.family,l,"htf"),u(c.hoverlabel.namelength,l,"hnl"),u(c.hoverlabel.align,l,"hta"))}}}},{"../../lib":716,"../../registry":845}],623:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("./hover").hover;e.exports=function(t,e,r){var i=n.getComponentMethod("annotations","onClick")(t,t._hoverdata);function o(){t.emit("plotly_click",{points:t._hoverdata,event:e})}void 0!==r&&a(t,e,r,!0),t._hoverdata&&e&&e.target&&(i&&i.then?i.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{"../../registry":845,"./hover":627}],624:[function(t,e,r){"use strict";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:"Arial, sans-serif",HOVERMINTIME:50,HOVERID:"-hover"}},{}],625:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("./hoverlabel_defaults");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),i(t,e,function(r,i){return n.coerce(t,e,a,r,i)},s)}},{"../../lib":716,"./attributes":621,"./hoverlabel_defaults":628}],626:[function(t,e,r){"use strict";var n=t("../../lib");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if("splom"===t.type){for(var n=t.xaxes||[],a=t.yaxes||[],i=0;i<n.length;i++)for(var o=0;o<a.length;o++)if(-1!==e.indexOf(n[i]+a[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,a){return"closest"===t?a||r.quadrature(e,n):"x"===t?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var a=e(t[n]);a<=r.distance&&(r.index=n,r.distance=a)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),a=e(r);return Math.sqrt(n*n+a*a)}},r.makeEventData=function(t,e,n){var a="index"in t?t.index:t.pointNumber,i={data:e._input,fullData:e,curveNumber:e.index,pointNumber:a};if(e._indexToPoints){var o=e._indexToPoints[a];1===o.length?i.pointIndex=o[0]:i.pointIndices=o}else i.pointIndex=a;return e._module.eventData?i=e._module.eventData(i,t,e,n,a):("xVal"in t?i.x=t.xVal:"x"in t&&(i.x=t.x),"yVal"in t?i.y=t.yVal:"y"in t&&(i.y=t.y),t.xa&&(i.xaxis=t.xa),t.ya&&(i.yaxis=t.ya),void 0!==t.zLabelVal&&(i.z=t.zLabelVal)),r.appendArrayPointValue(i,e,a),i},r.appendArrayPointValue=function(t,e,r){var a=e._arrayAttrs;if(a)for(var s=0;s<a.length;s++){var l=a[s],c=i(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var a=e._arrayAttrs;if(a)for(var s=0;s<a.length;s++){var l=a[s],c=i(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var a={ids:"id",locations:"location",labels:"label",values:"value","marker.colors":"color",parents:"parent"};function i(t){return a[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}},{"../../lib":716}],627:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("tinycolor2"),o=t("../../lib"),s=t("../../lib/events"),l=t("../../lib/svg_text_utils"),c=t("../../lib/override_cursor"),u=t("../drawing"),h=t("../color"),f=t("../dragelement"),p=t("../../plots/cartesian/axes"),d=t("../../registry"),g=t("./helpers"),v=t("./constants"),m=v.YANGLE,y=Math.PI*m/180,x=1/Math.sin(y),b=Math.cos(y),_=Math.sin(y),w=v.HOVERARROWSIZE,k=v.HOVERTEXTPAD;r.hover=function(t,e,r,i){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+v.HOVERID,v.HOVERMINTIME,function(){!function(t,e,r,i){r||(r="xy");var l=Array.isArray(r)?r:[r],u=t._fullLayout,p=u._plots||[],v=p[r],m=u._has("cartesian");if(v){var y=v.overlays.map(function(t){return t.id});l=l.concat(y)}for(var b=l.length,_=new Array(b),w=new Array(b),k=!1,T=0;T<b;T++){var C=l[T];if(p[C])k=!0,_[T]=p[C].xaxis,w[T]=p[C].yaxis;else{if(!u[C]||!u[C]._subplot)return void o.warn("Unrecognized subplot: "+C);var P=u[C]._subplot;_[T]=P.xaxis,w[T]=P.yaxis}}var O=e.hovermode||u.hovermode;O&&!k&&(O="closest");if(-1===["x","y","closest"].indexOf(O)||!t.calcdata||t.querySelector(".zoombox")||t._dragging)return f.unhoverRaw(t,e);var z,I,D,R,F,B,N,j,V,U,q,H,G,Y=-1===u.hoverdistance?1/0:u.hoverdistance,W=-1===u.spikedistance?1/0:u.spikedistance,X=[],Z=[],J={hLinePoint:null,vLinePoint:null},K=!1;if(Array.isArray(e))for(O="array",D=0;D<e.length;D++)(F=t.calcdata[e[D].curveNumber||0])&&(B=F[0].trace,"skip"!==F[0].trace.hoverinfo&&(Z.push(F),"h"===B.orientation&&(K=!0)));else{for(R=0;R<t.calcdata.length;R++)F=t.calcdata[R],"skip"!==(B=F[0].trace).hoverinfo&&g.isTraceInSubplots(B,l)&&(Z.push(F),"h"===B.orientation&&(K=!0));var Q,$,tt=!e.target;if(tt)Q="xpx"in e?e.xpx:_[0]._length/2,$="ypx"in e?e.ypx:w[0]._length/2;else{if(!1===s.triggerHandler(t,"plotly_beforehover",e))return;var et=e.target.getBoundingClientRect();if(Q=e.clientX-et.left,$=e.clientY-et.top,Q<0||Q>_[0]._length||$<0||$>w[0]._length)return f.unhoverRaw(t,e)}if(e.pointerX=Q+_[0]._offset,e.pointerY=$+w[0]._offset,z="xval"in e?g.flat(l,e.xval):g.p2c(_,Q),I="yval"in e?g.flat(l,e.yval):g.p2c(w,$),!a(z[0])||!a(I[0]))return o.warn("Fx.hover failed",e,t),f.unhoverRaw(t,e)}var rt=1/0;for(R=0;R<Z.length;R++)if((F=Z[R])&&F[0]&&F[0].trace&&!0===(B=F[0].trace).visible&&0!==B._length&&-1===["carpet","contourcarpet"].indexOf(B._module.name)){if("splom"===B.type?N=l[j=0]:(N=g.getSubplot(B),j=l.indexOf(N)),V=O,H={cd:F,trace:B,xa:_[j],ya:w[j],maxHoverDistance:Y,maxSpikeDistance:W,index:!1,distance:Math.min(rt,Y),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:h.defaultLine,name:B.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[N]&&(H.subplot=u[N]._subplot),u._splomScenes&&u._splomScenes[B.uid]&&(H.scene=u._splomScenes[B.uid]),G=X.length,"array"===V){var nt=e[R];"pointNumber"in nt?(H.index=nt.pointNumber,V="closest"):(V="","xval"in nt&&(U=nt.xval,V="x"),"yval"in nt&&(q=nt.yval,V=V?"closest":"y"))}else U=z[j],q=I[j];if(0!==Y)if(B._module&&B._module.hoverPoints){var at=B._module.hoverPoints(H,U,q,V,u._hoverlayer);if(at)for(var it,ot=0;ot<at.length;ot++)it=at[ot],a(it.x0)&&a(it.y0)&&X.push(S(it,O))}else o.log("Unrecognized trace type in hover:",B);if("closest"===O&&X.length>G&&(X.splice(0,G),rt=X[0].distance),m&&0!==W&&0===X.length){H.distance=W,H.index=!1;var st=B._module.hoverPoints(H,U,q,"closest",u._hoverlayer);if(st&&(st=st.filter(function(t){return t.spikeDistance<=W})),st&&st.length){var lt,ct=st.filter(function(t){return t.xa.showspikes});if(ct.length){var ut=ct[0];a(ut.x0)&&a(ut.y0)&&(lt=dt(ut),(!J.vLinePoint||J.vLinePoint.spikeDistance>lt.spikeDistance)&&(J.vLinePoint=lt))}var ht=st.filter(function(t){return t.ya.showspikes});if(ht.length){var ft=ht[0];a(ft.x0)&&a(ft.y0)&&(lt=dt(ft),(!J.hLinePoint||J.hLinePoint.spikeDistance>lt.spikeDistance)&&(J.hLinePoint=lt))}}}}function pt(t,e){for(var r,n=null,a=1/0,i=0;i<t.length;i++)(r=t[i].spikeDistance)<a&&r<=e&&(n=t[i],a=r);return n}function dt(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}var gt={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},vt=t._spikepoints,mt={vLinePoint:J.vLinePoint,hLinePoint:J.hLinePoint};if(t._spikepoints=mt,m&&0!==W&&0!==X.length){var yt=X.filter(function(t){return t.ya.showspikes}),xt=pt(yt,W);J.hLinePoint=dt(xt);var bt=X.filter(function(t){return t.xa.showspikes}),_t=pt(bt,W);J.vLinePoint=dt(_t)}if(0===X.length){var wt=f.unhoverRaw(t,e);return!m||null===J.hLinePoint&&null===J.vLinePoint||L(vt)&&E(t,J,gt),wt}m&&L(vt)&&E(t,J,gt);X.sort(function(t,e){return t.distance-e.distance});var kt=t._hoverdata,Tt=[];for(D=0;D<X.length;D++){var At=X[D],Mt=g.makeEventData(At,At.trace,At.cd);if(!1!==At.hovertemplate){var St=!1;At.cd[At.index]&&At.cd[At.index].ht&&(St=At.cd[At.index].ht),At.hovertemplate=St||At.trace.hovertemplate||!1}At.eventData=[Mt],Tt.push(Mt)}t._hoverdata=Tt;var Et="y"===O&&(Z.length>1||X.length>1)||"closest"===O&&K&&X.length>1,Lt=h.combine(u.plot_bgcolor||h.background,u.paper_bgcolor),Ct={hovermode:O,rotateLabels:Et,bgColor:Lt,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},Pt=A(X,Ct,t);if(function(t,e,r){var n,a,i,o,s,l,c,u=0,h=1,f=t.size(),p=new Array(f),d=0;function g(t){var e=t[0],r=t[t.length-1];if(a=e.pmin-e.pos-e.dp+e.size,i=r.pos+r.dp+r.size-e.pmax,a>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=a;n=!1}if(!(i<.01)){if(a<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=i;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,i=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=i;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}for(t.each(function(t){var n=t[e],a="x"===n._id.charAt(0),i=n.range;0===d&&i&&i[0]>i[1]!==a&&(h=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(a?x:1)/2,pmin:0,pmax:a?r.width:r.height}]}),p.sort(function(t,e){return t[0].posref-e[0].posref||h*(e[0].traceIndex-t[0].traceIndex)});!n&&u<=f;){for(u++,n=!0,o=0;o<p.length-1;){var v=p[o],m=p[o+1],y=v[v.length-1],b=m[0];if((a=y.pos+y.dp+y.size-b.pos-b.dp+b.size)>.01&&y.pmin===b.pmin&&y.pmax===b.pmax){for(s=m.length-1;s>=0;s--)m[s].dp+=a;for(v.push.apply(v,m),p.splice(o+1,1),c=0,s=v.length-1;s>=0;s--)c+=v[s].dp;for(i=c/v.length,s=v.length-1;s>=0;s--)v[s].dp-=i;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var _=p[o];for(s=_.length-1;s>=0;s--){var w=_[s],k=w.datum;k.offset=w.dp,k.del=w.del}}}(Pt,Et?"xa":"ya",u),M(Pt,Et),e.target&&e.target.tagName){var Ot=d.getComponentMethod("annotations","hasClickToShow")(t,Tt);c(n.select(e.target),Ot?"pointer":"")}if(!e.target||i||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var a=r[n],i=t._hoverdata[n];if(a.curveNumber!==i.curveNumber||String(a.pointNumber)!==String(i.pointNumber)||String(a.pointNumbers)!==String(i.pointNumbers))return!0}return!1}(t,0,kt))return;kt&&t.emit("plotly_unhover",{event:e,points:kt});t.emit("plotly_hover",{event:e,points:t._hoverdata,xaxes:_,yaxes:w,xvals:z,yvals:I})}(t,e,r,i)})},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var a=t.map(function(t){return{color:t.color||h.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:""},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}}),i=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):i,s={hovermode:"closest",rotateLabels:!1,bgColor:e.bgColor||h.background,container:i,outerContainer:o},l=A(a,s,e.gd),c=0,u=0;return l.sort(function(t,e){return t.y0-e.y0}).each(function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)}).each(function(t){t.offset-=u}),M(l,s.rotateLabels),r?l:l.node()};var T=/<extra>([\s\S]*)<\/extra>/;function A(t,e,r){var a=r._fullLayout,i=e.hovermode,s=e.rotateLabels,c=e.bgColor,f=e.container,p=e.outerContainer,d=e.commonLabelOpts||{},g=e.fontFamily||v.HOVERFONT,y=e.fontSize||v.HOVERFONTSIZE,x=t[0],b=x.xa,_=x.ya,A="y"===i?"yLabel":"xLabel",M=x[A],S=(String(M)||"").split(" ")[0],E=p.node().getBoundingClientRect(),L=E.top,P=E.width,O=E.height,z=void 0!==M&&x.distance<=e.hoverdistance&&("x"===i||"y"===i);if(z){var I,D,R=!0;for(I=0;I<t.length;I++)if(R&&void 0===t[I].zLabel&&(R=!1),D=t[I].hoverinfo||t[I].trace.hoverinfo){var F=Array.isArray(D)?D:D.split("+");if(-1===F.indexOf("all")&&-1===F.indexOf(i)){z=!1;break}}R&&(z=!1)}var B=f.selectAll("g.axistext").data(z?[0]:[]);B.enter().append("g").classed("axistext",!0),B.exit().remove(),B.each(function(){var e=n.select(this),s=o.ensureSingle(e,"path","",function(t){t.style({"stroke-width":"1px"})}),c=o.ensureSingle(e,"text","",function(t){t.attr("data-notex",1)}),f=d.bgcolor||h.defaultLine,p=d.bordercolor||h.contrast(f),v=h.contrast(f),m={family:d.font.family||g,size:d.font.size||y,color:d.font.color||v};s.style({fill:f,stroke:p}),c.text(M).call(u.font,m).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr("transform","");var T,E,C=c.node().getBoundingClientRect();if("x"===i){var P="top"===b.side?"-":"";c.attr("text-anchor","middle").call(l.positionText,0,"top"===b.side?L-C.bottom-w-k:L-C.top+w+k),T=b._offset+(x.x0+x.x1)/2,E=_._offset+("top"===b.side?0:_._length);var O=C.width/2+k;T<O?(T=O,s.attr("d","M-"+(O-w)+",0L-"+(O-2*w)+","+P+w+"H"+(k+C.width/2)+"v"+P+(2*k+C.height)+"H-"+O+"V"+P+w+"Z")):T>a.width-O?(T=a.width-O,s.attr("d","M"+(O-w)+",0L"+O+","+P+w+"v"+P+(2*k+C.height)+"H-"+O+"V"+P+w+"H"+(O-2*w)+"Z")):s.attr("d","M0,0L"+w+","+P+w+"H"+(k+C.width/2)+"v"+P+(2*k+C.height)+"H-"+(k+C.width/2)+"V"+P+w+"H-"+w+"Z")}else{var z,I,D;"right"===_.side?(z="start",I=1,D="",T=b._offset+b._length):(z="end",I=-1,D="-",T=b._offset),E=_._offset+(x.y0+x.y1)/2,c.attr("text-anchor",z),s.attr("d","M0,0L"+D+w+","+w+"V"+(k+C.height/2)+"h"+D+(2*k+C.width)+"V-"+(k+C.height/2)+"H"+D+w+"V-"+w+"Z");var R,F=C.height/2,B=L-C.top-F,N="clip"+a._uid+"commonlabel"+_._id;if(T<C.width+2*k+w){R="M-"+(w+k)+"-"+F+"h-"+(C.width-k)+"V"+F+"h"+(C.width-k)+"Z";var j=C.width-T+k;l.positionText(c,j,B),"end"===z&&c.selectAll("tspan").each(function(){var t=n.select(this),e=u.tester.append("text").text(t.text()).call(u.font,m),r=e.node().getBoundingClientRect();Math.round(r.width)<Math.round(C.width)&&t.attr("x",j-r.width),e.remove()})}else l.positionText(c,I*(k+w),B),R=null;var V=a._topclips.selectAll("#"+N).data(R?[0]:[]);V.enter().append("clipPath").attr("id",N).append("path"),V.exit().remove(),V.select("path").attr("d",R),u.setClipUrl(c,R?N:null,r)}e.attr("transform","translate("+T+","+E+")"),t=t.filter(function(t){return void 0!==t.zLabelVal||(t[A]||"").split(" ")[0]===S})});var N=f.selectAll("g.hovertext").data(t,function(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||""].join(",")});return N.enter().append("g").classed("hovertext",!0).each(function(){var t=n.select(this);t.append("rect").call(h.fill,h.addOpacity(c,.8)),t.append("text").classed("name",!0),t.append("path").style("stroke-width","1px"),t.append("text").classed("nums",!0).call(u.font,g,y)}),N.exit().remove(),N.each(function(t){var e=n.select(this).attr("transform",""),f="",p="",d=t.bgcolor||t.color,v=h.combine(h.opacity(d)?d:h.defaultLine,c),x=h.combine(h.opacity(t.color)?t.color:h.defaultLine,c),b=t.borderColor||h.contrast(v);void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),f=C(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(p+="x: "+t.xLabel+"<br>"),void 0!==t.yLabel&&(p+="y: "+t.yLabel+"<br>"),"choropleth"!==t.trace.type&&"choroplethmapbox"!==t.trace.type&&(p+=(p?"z: ":"")+t.zLabel)):z&&t[i+"Label"]===M?p=t[("x"===i?"y":"x")+"Label"]||"":void 0===t.xLabel?void 0!==t.yLabel&&"scattercarpet"!==t.trace.type&&(p=t.yLabel):p=void 0===t.yLabel?t.xLabel:"("+t.xLabel+", "+t.yLabel+")",!t.text&&0!==t.text||Array.isArray(t.text)||(p+=(p?"<br>":"")+t.text),void 0!==t.extraText&&(p+=(p?"<br>":"")+t.extraText),""!==p||t.hovertemplate||(""===f&&e.remove(),p=f);var _=a._d3locale,A=t.hovertemplate||!1,S=t.hovertemplateLabels||t,E=t.eventData[0]||{};A&&(p=(p=o.hovertemplateString(A,S,_,E,t.trace._meta)).replace(T,function(e,r){return f=C(r,t.nameLength),""}));var I=e.select("text.nums").call(u.font,t.fontFamily||g,t.fontSize||y,t.fontColor||b).text(p).attr("data-notex",1).call(l.positionText,0,0).call(l.convertToTspans,r),D=e.select("text.name"),R=0,F=0;if(f&&f!==p){D.call(u.font,t.fontFamily||g,t.fontSize||y,x).text(f).attr("data-notex",1).call(l.positionText,0,0).call(l.convertToTspans,r);var B=D.node().getBoundingClientRect();R=B.width+2*k,F=B.height+2*k}else D.remove(),e.select("rect").remove();e.select("path").style({fill:v,stroke:b});var N,j,V=I.node().getBoundingClientRect(),U=t.xa._offset+(t.x0+t.x1)/2,q=t.ya._offset+(t.y0+t.y1)/2,H=Math.abs(t.x1-t.x0),G=Math.abs(t.y1-t.y0),Y=V.width+w+k+R;if(t.ty0=L-V.top,t.bx=V.width+2*k,t.by=Math.max(V.height+2*k,F),t.anchor="start",t.txwidth=V.width,t.tx2width=R,t.offset=0,s)t.pos=U,N=q+G/2+Y<=O,j=q-G/2-Y>=0,"top"!==t.idealAlign&&N||!j?N?(q+=G/2,t.anchor="start"):t.anchor="middle":(q-=G/2,t.anchor="end");else if(t.pos=q,N=U+H/2+Y<=P,j=U-H/2-Y>=0,"left"!==t.idealAlign&&N||!j)if(N)U+=H/2,t.anchor="start";else{t.anchor="middle";var W=Y/2,X=U+W-P,Z=U-W;X>0&&(U-=X),Z<0&&(U+=-Z)}else U-=H/2,t.anchor="end";I.attr("text-anchor",t.anchor),R&&D.attr("text-anchor",t.anchor),e.attr("transform","translate("+U+","+q+")"+(s?"rotate("+m+")":""))}),N}function M(t,e){t.each(function(t){var r=n.select(this);if(t.del)return r.remove();var a=r.select("text.nums"),i=t.anchor,o="end"===i?-1:1,s={start:1,end:-1,middle:0}[i],c=s*(w+k),h=c+s*(t.txwidth+k),f=0,p=t.offset;"middle"===i&&(c-=t.tx2width/2,h+=t.txwidth/2+k),e&&(p*=-_,f=t.offset*b),r.select("path").attr("d","middle"===i?"M-"+(t.bx/2+t.tx2width/2)+","+(p-t.by/2)+"h"+t.bx+"v"+t.by+"h-"+t.bx+"Z":"M0,0L"+(o*w+f)+","+(w+p)+"v"+(t.by/2-w)+"h"+o*t.bx+"v-"+t.by+"H"+(o*w+f)+"V"+(p-w)+"Z");var d=c+f,g=p+t.ty0-t.by/2+k,v=t.textAlign||"auto";"auto"!==v&&("left"===v&&"start"!==i?(a.attr("text-anchor","start"),d="middle"===i?-t.bx/2-t.tx2width/2+k:-t.bx-k):"right"===v&&"end"!==i&&(a.attr("text-anchor","end"),d="middle"===i?t.bx/2-t.tx2width/2-k:t.bx+k)),a.call(l.positionText,d,g),t.tx2width&&(r.select("text.name").call(l.positionText,h+s*k+f,p+t.ty0-t.by/2+k),r.select("rect").call(u.setRect,h+(s-1)*t.tx2width/2+f,p-t.by/2-1,t.tx2width,t.by+2))})}function S(t,e){var r=t.index,n=t.trace||{},i=t.cd[0],s=t.cd[r]||{};function l(t){return t||a(t)&&0===t}var c=Array.isArray(r)?function(t,e){var a=o.castOption(i,r,t);return l(a)?a:o.extractOption({},n,"",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var a=c(r,n);l(a)&&(t[e]=a)}if(u("hoverinfo","hi","hoverinfo"),u("bgcolor","hbg","hoverlabel.bgcolor"),u("borderColor","hbc","hoverlabel.bordercolor"),u("fontFamily","htf","hoverlabel.font.family"),u("fontSize","hts","hoverlabel.font.size"),u("fontColor","htc","hoverlabel.font.color"),u("nameLength","hnl","hoverlabel.namelength"),u("textAlign","hta","hoverlabel.align"),t.posref="y"===e||"closest"===e&&"h"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel="xLabel"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel="yLabel"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||"log"===t.xa.type&&t.xerr<=0)){var h=p.tickText(t.xa,t.xa.c2l(t.xerr),"hover").text;void 0!==t.xerrneg?t.xLabel+=" +"+h+" / -"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),"hover").text:t.xLabel+=" \xb1 "+h,"x"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||"log"===t.ya.type&&t.yerr<=0)){var f=p.tickText(t.ya,t.ya.c2l(t.yerr),"hover").text;void 0!==t.yerrneg?t.yLabel+=" +"+f+" / -"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),"hover").text:t.yLabel+=" \xb1 "+f,"y"===e&&(t.distance+=1)}var d=t.hoverinfo||t.trace.hoverinfo;return d&&"all"!==d&&(-1===(d=Array.isArray(d)?d:d.split("+")).indexOf("x")&&(t.xLabel=void 0),-1===d.indexOf("y")&&(t.yLabel=void 0),-1===d.indexOf("z")&&(t.zLabel=void 0),-1===d.indexOf("text")&&(t.text=void 0),-1===d.indexOf("name")&&(t.name=void 0)),t}function E(t,e,r){var n,a,o=r.container,s=r.fullLayout,l=s._size,c=r.event,f=!!e.hLinePoint,d=!!e.vLinePoint;if(o.selectAll(".spikeline").remove(),d||f){var g=h.combine(s.plot_bgcolor,s.paper_bgcolor);if(f){var v,m,y=e.hLinePoint;n=y&&y.xa,"cursor"===(a=y&&y.ya).spikesnap?(v=c.pointerX,m=c.pointerY):(v=n._offset+y.x,m=a._offset+y.y);var x,b,_=i.readability(y.color,g)<1.5?h.contrast(g):y.color,w=a.spikemode,k=a.spikethickness,T=a.spikecolor||_,A=p.getPxPosition(t,a);if(-1!==w.indexOf("toaxis")||-1!==w.indexOf("across")){if(-1!==w.indexOf("toaxis")&&(x=A,b=v),-1!==w.indexOf("across")){var M=a._counterDomainMin,S=a._counterDomainMax;"free"===a.anchor&&(M=Math.min(M,a.position),S=Math.max(S,a.position)),x=l.l+M*l.w,b=l.l+S*l.w}o.insert("line",":first-child").attr({x1:x,x2:b,y1:m,y2:m,"stroke-width":k,stroke:T,"stroke-dasharray":u.dashStyle(a.spikedash,k)}).classed("spikeline",!0).classed("crisp",!0),o.insert("line",":first-child").attr({x1:x,x2:b,y1:m,y2:m,"stroke-width":k+2,stroke:g}).classed("spikeline",!0).classed("crisp",!0)}-1!==w.indexOf("marker")&&o.insert("circle",":first-child").attr({cx:A+("right"!==a.side?k:-k),cy:m,r:k,fill:T}).classed("spikeline",!0)}if(d){var E,L,C=e.vLinePoint;n=C&&C.xa,a=C&&C.ya,"cursor"===n.spikesnap?(E=c.pointerX,L=c.pointerY):(E=n._offset+C.x,L=a._offset+C.y);var P,O,z=i.readability(C.color,g)<1.5?h.contrast(g):C.color,I=n.spikemode,D=n.spikethickness,R=n.spikecolor||z,F=p.getPxPosition(t,n);if(-1!==I.indexOf("toaxis")||-1!==I.indexOf("across")){if(-1!==I.indexOf("toaxis")&&(P=F,O=L),-1!==I.indexOf("across")){var B=n._counterDomainMin,N=n._counterDomainMax;"free"===n.anchor&&(B=Math.min(B,n.position),N=Math.max(N,n.position)),P=l.t+(1-N)*l.h,O=l.t+(1-B)*l.h}o.insert("line",":first-child").attr({x1:E,x2:E,y1:P,y2:O,"stroke-width":D,stroke:R,"stroke-dasharray":u.dashStyle(n.spikedash,D)}).classed("spikeline",!0).classed("crisp",!0),o.insert("line",":first-child").attr({x1:E,x2:E,y1:P,y2:O,"stroke-width":D+2,stroke:g}).classed("spikeline",!0).classed("crisp",!0)}-1!==I.indexOf("marker")&&o.insert("circle",":first-child").attr({cx:E,cy:F-("top"!==n.side?D:-D),r:D,fill:R}).classed("spikeline",!0)}}}function L(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function C(t,e){return l.plainText(t||"",{len:e,allowedTags:["br","sub","sup","b","i","em"]})}},{"../../lib":716,"../../lib/events":706,"../../lib/override_cursor":727,"../../lib/svg_text_utils":740,"../../plots/cartesian/axes":764,"../../registry":845,"../color":591,"../dragelement":609,"../drawing":612,"./constants":624,"./helpers":626,d3:164,"fast-isnumeric":227,tinycolor2:535}],628:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e,r,a){r("hoverlabel.bgcolor",(a=a||{}).bgcolor),r("hoverlabel.bordercolor",a.bordercolor),r("hoverlabel.namelength",a.namelength),n.coerceFont(r,"hoverlabel.font",a.font),r("hoverlabel.align",a.align)}},{"../../lib":716}],629:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../dragelement"),o=t("./helpers"),s=t("./layout_attributes"),l=t("./hover");e.exports={moduleType:"component",name:"fx",constants:t("./constants"),schema:{layout:s},attributes:t("./attributes"),layoutAttributes:s,supplyLayoutGlobalDefaults:t("./layout_global_defaults"),supplyDefaults:t("./defaults"),supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return a.castOption(t,e,"hoverlabel."+r)},castHoverinfo:function(t,e,r){return a.castOption(t,r,"hoverinfo",function(r){return a.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)})},hover:l.hover,unhover:i.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=a.isD3Selection(t)?t:n.select(t);e.selectAll("g.hovertext").remove(),e.selectAll(".spikeline").remove()},click:t("./click")}},{"../../lib":716,"../dragelement":609,"./attributes":621,"./calc":622,"./click":623,"./constants":624,"./defaults":625,"./helpers":626,"./hover":627,"./layout_attributes":630,"./layout_defaults":631,"./layout_global_defaults":632,d3:164}],630:[function(t,e,r){"use strict";var n=t("./constants"),a=t("../../plots/font_attributes")({editType:"none"});a.family.dflt=n.HOVERFONT,a.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:"flaglist",flags:["event","select"],dflt:"event",editType:"plot",extras:["none"]},dragmode:{valType:"enumerated",values:["zoom","pan","select","lasso","orbit","turntable",!1],dflt:"zoom",editType:"modebar"},hovermode:{valType:"enumerated",values:["x","y","closest",!1],editType:"modebar"},hoverdistance:{valType:"integer",min:-1,dflt:20,editType:"none"},spikedistance:{valType:"integer",min:-1,dflt:20,editType:"none"},hoverlabel:{bgcolor:{valType:"color",editType:"none"},bordercolor:{valType:"color",editType:"none"},font:a,align:{valType:"enumerated",values:["left","right","auto"],dflt:"auto",editType:"none"},namelength:{valType:"integer",min:-1,dflt:15,editType:"none"},editType:"none"},selectdirection:{valType:"enumerated",values:["h","v","d","any"],dflt:"any",editType:"none"}}},{"../../plots/font_attributes":790,"./constants":624}],631:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e,r){function i(r,i){return n.coerce(t,e,a,r,i)}var o,s=i("clickmode");"select"===i("dragmode")&&i("selectdirection"),e._has("cartesian")?s.indexOf("select")>-1?o="closest":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var a=t[n],i=a.xaxis+a.yaxis,o=r[i]||{},s=o[a.stackgroup]||{};if("h"!==a.orientation&&"h"!==s.orientation)return!1}return!0}(r,e),o=e._isHoriz?"y":"x"):o="closest",i("hovermode",o)&&(i("hoverdistance"),i("spikedistance"));var l=e._has("mapbox"),c=e._has("geo"),u=e._basePlotModules.length;"zoom"===e.dragmode&&((l||c)&&1===u||l&&c&&2===u)&&(e.dragmode="pan")}},{"../../lib":716,"./layout_attributes":630}],632:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./hoverlabel_defaults"),i=t("./layout_attributes");e.exports=function(t,e){a(t,e,function(r,a){return n.coerce(t,e,i,r,a)})}},{"../../lib":716,"./hoverlabel_defaults":628,"./layout_attributes":630}],633:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../lib/regex").counter,i=t("../../plots/domain").attributes,o=t("../../plots/cartesian/constants").idRegex,s=t("../../plot_api/plot_template"),l={rows:{valType:"integer",min:1,editType:"plot"},roworder:{valType:"enumerated",values:["top to bottom","bottom to top"],dflt:"top to bottom",editType:"plot"},columns:{valType:"integer",min:1,editType:"plot"},subplots:{valType:"info_array",freeLength:!0,dimensions:2,items:{valType:"enumerated",values:[a("xy").toString(),""],editType:"plot"},editType:"plot"},xaxes:{valType:"info_array",freeLength:!0,items:{valType:"enumerated",values:[o.x.toString(),""],editType:"plot"},editType:"plot"},yaxes:{valType:"info_array",freeLength:!0,items:{valType:"enumerated",values:[o.y.toString(),""],editType:"plot"},editType:"plot"},pattern:{valType:"enumerated",values:["independent","coupled"],dflt:"coupled",editType:"plot"},xgap:{valType:"number",min:0,max:1,editType:"plot"},ygap:{valType:"number",min:0,max:1,editType:"plot"},domain:i({name:"grid",editType:"plot",noGridCell:!0},{}),xside:{valType:"enumerated",values:["bottom","bottom plot","top plot","top"],dflt:"bottom plot",editType:"plot"},yside:{valType:"enumerated",values:["left","left plot","right plot","right"],dflt:"left plot",editType:"plot"},editType:"plot"};function c(t,e,r){var n=e[r+"axes"],a=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:a.length?a:void 0}function u(t,e,r,n,a,i){var o=e(t+"gap",r),s=e("domain."+t);e(t+"side",n);for(var l=new Array(a),c=s[0],u=(s[1]-c)/(a-o),h=u*(1-o),f=0;f<a;f++){var p=c+u*f;l[i?a-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,a){var i,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=""}if(Array.isArray(t))for(i=0;i<r;i++)s(i,t[i]);else for(s(0,a),i=1;i<r;i++)s(i,a+(i+1));return o}e.exports={moduleType:"component",name:"grid",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},a=c(e,r,"x"),i=c(e,r,"y");if(t.grid||a||i){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(a),d=Array.isArray(i),g=p&&a!==r.xaxes&&d&&i!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=i.length),p&&(h=a.length));var v=s.newContainer(e,"grid"),m=T("rows",o),y=T("columns",h);if(m*y>1){f||p||d||"independent"===T("pattern")&&(f=!0),v._hasSubplotGrid=f;var x,b,_="top to bottom"===T("roworder"),w=f?.2:.1,k=f?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),v._domains={x:u("x",T,w,x,y),y:u("y",T,k,b,m,_)}}else delete e.grid}function T(t,e){return n.coerce(r,v,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,a,i,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,v=r.columns,m="independent"===r.pattern,y=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(v),w=x[n]||[];for(a=0;a<v;a++)if(m?(s=1===b?"xy":"x"+b+"y"+b,b++):s=w[a],_[a]="",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf("y"),i=s.slice(0,u),o=s.slice(u),void 0!==y[i]&&y[i]!==a||void 0!==y[o]&&y[o]!==n)continue;_[a]=s,y[i]=a,y[o]=n}}}else{var k=c(e,f,"x"),T=c(e,f,"y");r.xaxes=h(k,p.xaxis,v,y,"x"),r.yaxes=h(T,p.yaxis,g,y,"y")}var A=r._anchors={},M="top to bottom"===r.roworder;for(var S in y){var E,L,C,P=S.charAt(0),O=r[P+"side"];if(O.length<8)A[S]="free";else if("x"===P){if("t"===O.charAt(0)===M?(E=0,L=1,C=g):(E=g-1,L=-1,C=-1),d){var z=y[S];for(n=E;n!==C;n+=L)if((s=l[n][z])&&(u=s.indexOf("y"),s.slice(0,u)===S)){A[S]=s.slice(u);break}}else for(n=E;n!==C;n+=L)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){A[S]=o;break}}else if("l"===O.charAt(0)?(E=0,L=1,C=v):(E=v-1,L=-1,C=-1),d){var I=y[S];for(n=E;n!==C;n+=L)if((s=l[I][n])&&(u=s.indexOf("y"),s.slice(u)===S)){A[S]=s.slice(0,u);break}}else for(n=E;n!==C;n+=L)if(i=r.xaxes[n],-1!==p.cartesian.indexOf(i+S)){A[S]=i;break}}}}}},{"../../lib":716,"../../lib/regex":732,"../../plot_api/plot_template":754,"../../plots/cartesian/constants":770,"../../plots/domain":789}],634:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/constants"),a=t("../../plot_api/plot_template").templatedArray;e.exports=a("image",{visible:{valType:"boolean",dflt:!0,editType:"arraydraw"},source:{valType:"string",editType:"arraydraw"},layer:{valType:"enumerated",values:["below","above"],dflt:"above",editType:"arraydraw"},sizex:{valType:"number",dflt:0,editType:"arraydraw"},sizey:{valType:"number",dflt:0,editType:"arraydraw"},sizing:{valType:"enumerated",values:["fill","contain","stretch"],dflt:"contain",editType:"arraydraw"},opacity:{valType:"number",min:0,max:1,dflt:1,editType:"arraydraw"},x:{valType:"any",dflt:0,editType:"arraydraw"},y:{valType:"any",dflt:0,editType:"arraydraw"},xanchor:{valType:"enumerated",values:["left","center","right"],dflt:"left",editType:"arraydraw"},yanchor:{valType:"enumerated",values:["top","middle","bottom"],dflt:"top",editType:"arraydraw"},xref:{valType:"enumerated",values:["paper",n.idRegex.x.toString()],dflt:"paper",editType:"arraydraw"},yref:{valType:"enumerated",values:["paper",n.idRegex.y.toString()],dflt:"paper",editType:"arraydraw"},editType:"arraydraw"})},{"../../plot_api/plot_template":754,"../../plots/cartesian/constants":770}],635:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib/to_log_range");e.exports=function(t,e,r,i){e=e||{};var o="log"===r&&"linear"===e.type,s="linear"===r&&"log"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c="images["+f+"].",(l=u[f])[h+"ref"]===e._id){var p=l[h],d=l["size"+h],g=null,v=null;if(o){g=a(p,e.range);var m=d/Math.pow(10,g)/2;v=2*Math.log(m+Math.sqrt(1+m*m))/Math.LN10}else v=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(v)||(v=null):(g=null,v=null),i(c+h,g),i(c+"size"+h,v)}}},{"../../lib/to_log_range":742,"fast-isnumeric":227}],636:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../../plots/array_container_defaults"),o=t("./attributes");function s(t,e,r){function i(r,a){return n.coerce(t,e,o,r,a)}var s=i("source");if(!i("visible",!!s))return e;i("layer"),i("xanchor"),i("yanchor"),i("sizex"),i("sizey"),i("sizing"),i("opacity");for(var l={_fullLayout:r},c=["x","y"],u=0;u<2;u++){var h=c[u],f=a.coerceRef(t,e,l,h,"paper");if("paper"!==f)a.getFromId(l,f)._imgIndices.push(e._index);a.coercePosition(e,l,i,f,h,0)}return e}e.exports=function(t,e){i(t,e,{name:"images",handleItemDefaults:s})}},{"../../lib":716,"../../plots/array_container_defaults":760,"../../plots/cartesian/axes":764,"./attributes":634}],637:[function(t,e,r){"use strict";var n=t("d3"),a=t("../drawing"),i=t("../../plots/cartesian/axes"),o=t("../../constants/xmlns_namespaces");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var h=s.images[r];if(h.visible)if("below"===h.layer&&"paper"!==h.xref&&"paper"!==h.yref){e=h.xref+h.yref;var f=s._plots[e];if(!f){u.push(h);continue}f.mainplot&&(e=f.mainplot.id),c[e]||(c[e]=[]),c[e].push(h)}else"above"===h.layer?l.push(h):u.push(h)}var p={x:{left:{sizing:"xMin",offset:0},center:{sizing:"xMid",offset:-.5},right:{sizing:"xMax",offset:-1}},y:{top:{sizing:"YMin",offset:0},middle:{sizing:"YMid",offset:-.5},bottom:{sizing:"YMax",offset:-1}}};function d(e){var r=n.select(this);if(this._imgSrc!==e.source)if(r.attr("xmlns",o.svg),e.source&&"data:"===e.source.slice(0,5))r.attr("xlink:href",e.source),this._imgSrc=e.source;else{var a=new Promise(function(t){var n=new Image;function a(){r.remove(),t()}this.img=n,n.setAttribute("crossOrigin","anonymous"),n.onerror=a,n.onload=function(){var e=document.createElement("canvas");e.width=this.width,e.height=this.height,e.getContext("2d").drawImage(this,0,0);var n=e.toDataURL("image/png");r.attr("xlink:href",n),t()},r.on("error",a),n.src=e.source,this._imgSrc=e.source}.bind(this));t._promises.push(a)}}function g(e){var r=n.select(this),o=i.getFromId(t,e.xref),l=i.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,h=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,f=u*p.x[e.xanchor].offset,d=h*p.y[e.yanchor].offset,g=p.x[e.xanchor].sizing+p.y[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+f,m=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+d;switch(e.sizing){case"fill":g+=" slice";break;case"stretch":g="none"}r.attr({x:v,y:m,width:u,height:h,preserveAspectRatio:g,opacity:e.opacity});var y=(o?o._id:"")+(l?l._id:"");a.setClipUrl(r,y?"clip"+s._uid+y:null,t)}var v=s._imageLowerLayer.selectAll("image").data(u),m=s._imageUpperLayer.selectAll("image").data(l);v.enter().append("image"),m.enter().append("image"),v.exit().remove(),m.exit().remove(),v.each(function(t){d.bind(this)(t),g.bind(this)(t)}),m.each(function(t){d.bind(this)(t),g.bind(this)(t)});var y=Object.keys(s._plots);for(r=0;r<y.length;r++){e=y[r];var x=s._plots[e];if(x.imagelayer){var b=x.imagelayer.selectAll("image").data(c[e]||[]);b.enter().append("image"),b.exit().remove(),b.each(function(t){d.bind(this)(t),g.bind(this)(t)})}}}},{"../../constants/xmlns_namespaces":693,"../../plots/cartesian/axes":764,"../drawing":612,d3:164}],638:[function(t,e,r){"use strict";e.exports={moduleType:"component",name:"images",layoutAttributes:t("./attributes"),supplyLayoutDefaults:t("./defaults"),includeBasePlot:t("../../plots/cartesian/include_components")("images"),draw:t("./draw"),convertCoords:t("./convert_coords")}},{"../../plots/cartesian/include_components":774,"./attributes":634,"./convert_coords":635,"./defaults":636,"./draw":637}],639:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../color/attributes");e.exports={bgcolor:{valType:"color",editType:"legend"},bordercolor:{valType:"color",dflt:a.defaultLine,editType:"legend"},borderwidth:{valType:"number",min:0,dflt:0,editType:"legend"},font:n({editType:"legend"}),orientation:{valType:"enumerated",values:["v","h"],dflt:"v",editType:"legend"},traceorder:{valType:"flaglist",flags:["reversed","grouped"],extras:["normal"],editType:"legend"},tracegroupgap:{valType:"number",min:0,dflt:10,editType:"legend"},itemsizing:{valType:"enumerated",values:["trace","constant"],dflt:"trace",editType:"legend"},itemclick:{valType:"enumerated",values:["toggle","toggleothers",!1],dflt:"toggle",editType:"legend"},itemdoubleclick:{valType:"enumerated",values:["toggle","toggleothers",!1],dflt:"toggleothers",editType:"legend"},x:{valType:"number",min:-2,max:3,editType:"legend"},xanchor:{valType:"enumerated",values:["auto","left","center","right"],dflt:"left",editType:"legend"},y:{valType:"number",min:-2,max:3,editType:"legend"},yanchor:{valType:"enumerated",values:["auto","top","middle","bottom"],editType:"legend"},uirevision:{valType:"any",editType:"none"},valign:{valType:"enumerated",values:["top","middle","bottom"],dflt:"middle",editType:"legend"},editType:"legend"}},{"../../plots/font_attributes":790,"../color/attributes":590}],640:[function(t,e,r){"use strict";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:"#808BA4",scrollBarMargin:4,scrollBarEnterAttrs:{rx:20,ry:3,width:0,height:0},textGap:40,itemGap:5}},{}],641:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../plot_api/plot_template"),o=t("./attributes"),s=t("../../plots/layout_attributes"),l=t("./helpers");e.exports=function(t,e,r){for(var c=t.legend||{},u=0,h=!1,f="normal",p=0;p<r.length;p++){var d=r[p];d.visible&&((d.showlegend||d._dfltShowLegend)&&(u++,d.showlegend&&(h=!0,(n.traceIs(d,"pie-like")||!0===d._input.showlegend)&&u++)),(n.traceIs(d,"bar")&&"stack"===e.barmode||-1!==["tonextx","tonexty"].indexOf(d.fill))&&(f=l.isGrouped({traceorder:f})?"grouped+reversed":"reversed"),void 0!==d.legendgroup&&""!==d.legendgroup&&(f=l.isReversed({traceorder:f})?"reversed+grouped":"grouped"))}var g=a.coerce(t,e,s,"showlegend",h&&u>1);if(!1!==g||c.uirevision){var v,m,y,x=i.newContainer(e,"legend");if(b("uirevision",e.uirevision),!1!==g)b("bgcolor",e.paper_bgcolor),b("bordercolor"),b("borderwidth"),a.coerceFont(b,"font",e.font),"h"===b("orientation")?(v=0,n.getComponentMethod("rangeslider","isVisible")(t.xaxis)?(m=1.1,y="bottom"):(m=-.1,y="top")):(v=1.02,m=1,y="auto"),b("traceorder",f),l.isGrouped(e.legend)&&b("tracegroupgap"),b("itemsizing"),b("itemclick"),b("itemdoubleclick"),b("x",v),b("xanchor"),b("y",m),b("yanchor",y),b("valign"),a.noneOrAll(c,x,["x","y"])}function b(t,e){return a.coerce(c,x,o,t,e)}}},{"../../lib":716,"../../plot_api/plot_template":754,"../../plots/layout_attributes":816,"../../registry":845,"./attributes":639,"./helpers":645}],642:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../plots/plots"),o=t("../../registry"),s=t("../../lib/events"),l=t("../dragelement"),c=t("../drawing"),u=t("../color"),h=t("../../lib/svg_text_utils"),f=t("./handle_click"),p=t("./constants"),d=t("../../constants/alignment"),g=d.LINE_SPACING,v=d.FROM_TL,m=d.FROM_BR,y=t("./get_legend_data"),x=t("./style"),b=t("./helpers");function _(t,e,r,n,a){var i=r.data()[0][0].trace,l={event:a,node:r.node(),curveNumber:i.index,expandedIndex:i._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(i._group&&(l.group=i._group),o.traceIs(i,"pie-like")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,"plotly_legendclick",l))if(1===n)e._clickTimeout=setTimeout(function(){f(r,t,n)},t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,"plotly_legenddoubleclick",l)&&f(r,t,n)}}function w(t,e){var r=t.data()[0][0],n=e._fullLayout,i=n.legend,s=r.trace,l=o.traceIs(s,"pie-like"),u=s.index,f=e._context.edits.legendText&&!l,d=i._maxNameLength,v=l?r.label:s.name;s._meta&&(v=a.templateString(v,s._meta));var m=a.ensureSingle(t,"text","legendtext");function y(r){h.convertToTspans(r,e,function(){!function(t,e){var r=t.data()[0][0];if(!r.trace.showlegend)return void t.remove();var n,a,i=t.select("g[class*=math-group]"),o=i.node(),s=e._fullLayout.legend.font.size*g;if(o){var l=c.bBox(o);n=l.height,a=l.width,c.setTranslate(i,0,n/4)}else{var u=t.select(".legendtext"),f=h.lineCount(u),d=u.node();n=s*f,a=d?c.bBox(d).width:0;var v=s*(.3+(1-f)/2);h.positionText(u,p.textGap,v)}r.lineHeight=s,r.height=Math.max(n,16)+3,r.width=a}(t,e)})}m.attr("text-anchor","start").classed("user-select-none",!0).call(c.font,n.legend.font).text(f?k(v,d):v),h.positionText(m,p.textGap,0),f?m.call(h.makeEditable,{gd:e,text:v}).call(y).on("edit",function(t){this.text(k(t,d)).call(y);var n=r.trace._fullInput||{},i={};if(o.hasTransform(n,"groupby")){var s=o.getTransformIndices(n,"groupby"),l=s[s.length-1],c=a.keyedContainer(n,"transforms["+l+"].styles","target","value.name");c.set(r.trace._group,t),i=c.constructUpdate()}else i.name=t;return o.call("_guiRestyle",e,i,u)}):y(m)}function k(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||"").length;n>0;n--)t+=" ";return t}function T(t,e){var r,i=e._context.doubleClickDelay,o=1,s=a.ensureSingle(t,"rect","legendtoggle",function(t){t.style("cursor","pointer").attr("pointer-events","all").call(u.fill,"rgba(0,0,0,0)")});s.on("mousedown",function(){(r=(new Date).getTime())-e._legendMouseDownTime<i?o+=1:(o=1,e._legendMouseDownTime=r)}),s.on("mouseup",function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>i&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})}function A(t){return a.isRightAnchor(t)?"right":a.isCenterAnchor(t)?"center":"left"}function M(t){return a.isBottomAnchor(t)?"bottom":a.isMiddleAnchor(t)?"middle":"top"}e.exports=function(t){var e=t._fullLayout,r="legend"+e._uid;if(e._infolayer&&t.calcdata){t._legendMouseDownTime||(t._legendMouseDownTime=0);var s=e.legend,h=e.showlegend&&y(t.calcdata,s),f=e.hiddenlabels||[];if(!e.showlegend||!h.length)return e._infolayer.selectAll(".legend").remove(),e._topdefs.select("#"+r).remove(),i.autoMargin(t,"legend");var d=a.ensureSingle(e._infolayer,"g","legend",function(t){t.attr("pointer-events","all")}),g=a.ensureSingleById(e._topdefs,"clipPath",r,function(t){t.append("rect")}),k=a.ensureSingle(d,"rect","bg",function(t){t.attr("shape-rendering","crispEdges")});k.call(u.stroke,s.bordercolor).call(u.fill,s.bgcolor).style("stroke-width",s.borderwidth+"px");var S=a.ensureSingle(d,"g","scrollbox"),E=a.ensureSingle(d,"rect","scrollbar",function(t){t.attr(p.scrollBarEnterAttrs).call(u.fill,p.scrollBarColor)}),L=S.selectAll("g.groups").data(h);L.enter().append("g").attr("class","groups"),L.exit().remove();var C=L.selectAll("g.traces").data(a.identity);C.enter().append("g").attr("class","traces"),C.exit().remove(),C.style("opacity",function(t){var e=t[0].trace;return o.traceIs(e,"pie-like")?-1!==f.indexOf(t[0].label)?.5:1:"legendonly"===e.visible?.5:1}).each(function(){n.select(this).call(w,t)}).call(x,t).each(function(){n.select(this).call(T,t)}),a.syncOrAsync([i.previousPromises,function(){return function(t,e,r){var a=t._fullLayout,i=a.legend,o=a._size,s=b.isVertical(i),l=b.isGrouped(i),u=i.borderwidth,h=2*u,f=p.textGap,d=p.itemGap,g=2*(u+d),v=M(i),m=i.y<0||0===i.y&&"top"===v,y=i.y>1||1===i.y&&"bottom"===v;i._maxHeight=Math.max(m||y?a.height/2:o.h,30);var x=0;if(i._width=0,i._height=0,s)r.each(function(t){var e=t[0].height;c.setTranslate(this,u,d+u+i._height+e/2),i._height+=e,i._width=Math.max(i._width,t[0].width)}),x=f+i._width,i._width+=d+f+h,i._height+=g,l&&(e.each(function(t,e){c.setTranslate(this,0,e*i.tracegroupgap)}),i._height+=(i._lgroupsLength-1)*i.tracegroupgap);else{var _=A(i),w=i.x<0||0===i.x&&"right"===_,k=i.x>1||1===i.x&&"left"===_,T=y||m,S=a.width/2;i._maxWidth=Math.max(w?T&&"left"===_?o.l+o.w:S:k?T&&"right"===_?o.r+o.w:S:o.w,2*f);var E=0,L=0;r.each(function(t){var e=t[0].width+f;E=Math.max(E,e),L+=e}),x=null;var C=0;if(l){var P=0,O=0,z=0;e.each(function(){var t=0,e=0;n.select(this).selectAll("g.traces").each(function(r){var n=r[0].height;c.setTranslate(this,0,d+u+n/2+e),e+=n,t=Math.max(t,f+r[0].width)}),P=Math.max(P,e);var r=t+d;r+u+O>i._maxWidth&&(C=Math.max(C,O),O=0,z+=P+i.tracegroupgap,P=e),c.setTranslate(this,O,z),O+=r}),i._width=Math.max(C,O)+u,i._height=z+P+g}else{var I=r.size(),D=L+h+(I-1)*d<i._maxWidth,R=0,F=0,B=0,N=0;r.each(function(t){var e=t[0].height,r=f+t[0].width,n=(D?r:E)+d;n+u+F>i._maxWidth&&(C=Math.max(C,N),F=0,B+=R,i._height+=R,R=0),c.setTranslate(this,u+F,d+u+e/2+B),N=F+r+d,F+=n,R=Math.max(R,e)}),D?(i._width=F+h,i._height=R+g):(i._width=Math.max(C,N)+h,i._height+=R+g)}}i._width=Math.ceil(i._width),i._height=Math.ceil(i._height),i._effHeight=Math.min(i._height,i._maxHeight);var j=t._context.edits,V=j.legendText||j.legendPosition;r.each(function(t){var e=n.select(this).select(".legendtoggle"),r=t[0].height,a=V?f:x||f+t[0].width;s||(a+=d/2),c.setRect(e,0,-r/2,a,r)})}(t,L,C)},function(){if(!function(t){var e=t._fullLayout.legend,r=A(e),n=M(e);return i.autoMargin(t,"legend",{x:e.x,y:e.y,l:e._width*v[r],r:e._width*m[r],b:e._effHeight*m[n],t:e._effHeight*v[n]})}(t)){var u,h,f,y,x=e._size,b=s.borderwidth,w=x.l+x.w*s.x-v[A(s)]*s._width,T=x.t+x.h*(1-s.y)-v[M(s)]*s._effHeight;if(e.margin.autoexpand){var L=w,C=T;w=a.constrain(w,0,e.width-s._width),T=a.constrain(T,0,e.height-s._effHeight),w!==L&&a.log("Constrain legend.x to make legend fit inside graph"),T!==C&&a.log("Constrain legend.y to make legend fit inside graph")}if(c.setTranslate(d,w,T),E.on(".drag",null),d.on("wheel",null),s._height<=s._maxHeight||t._context.staticPlot)k.attr({width:s._width-b,height:s._effHeight-b,x:b/2,y:b/2}),c.setTranslate(S,0,0),g.select("rect").attr({width:s._width-2*b,height:s._effHeight-2*b,x:b,y:b}),c.setClipUrl(S,r,t),c.setRect(E,0,0,0,0),delete s._scrollY;else{var P,O,z,I=Math.max(p.scrollBarMinHeight,s._effHeight*s._effHeight/s._height),D=s._effHeight-I-2*p.scrollBarMargin,R=s._height-s._effHeight,F=D/R,B=Math.min(s._scrollY||0,R);k.attr({width:s._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:s._effHeight-b,x:b/2,y:b/2}),g.select("rect").attr({width:s._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:s._effHeight-2*b,x:b,y:b+B}),c.setClipUrl(S,r,t),V(B,I,F),d.on("wheel",function(){V(B=a.constrain(s._scrollY+n.event.deltaY/D*R,0,R),I,F),0!==B&&B!==R&&n.event.preventDefault()});var N=n.behavior.drag().on("dragstart",function(){var t=n.event.sourceEvent;P="touchstart"===t.type?t.changedTouches[0].clientY:t.clientY,z=B}).on("drag",function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||(O="touchmove"===t.type?t.changedTouches[0].clientY:t.clientY,V(B=function(t,e,r){var n=(r-e)/F+t;return a.constrain(n,0,R)}(z,P,O),I,F))});E.call(N);var j=n.behavior.drag().on("dragstart",function(){var t=n.event.sourceEvent;"touchstart"===t.type&&(P=t.changedTouches[0].clientY,z=B)}).on("drag",function(){var t=n.event.sourceEvent;"touchmove"===t.type&&(O=t.changedTouches[0].clientY,V(B=function(t,e,r){var n=(e-r)/F+t;return a.constrain(n,0,R)}(z,P,O),I,F))});S.call(j)}if(t._context.edits.legendPosition)d.classed("cursor-move",!0),l.init({element:d.node(),gd:t,prepFn:function(){var t=c.getTranslate(d);f=t.x,y=t.y},moveFn:function(t,e){var r=f+t,n=y+e;c.setTranslate(d,r,n),u=l.align(r,0,x.l,x.l+x.w,s.xanchor),h=l.align(n,0,x.t+x.h,x.t,s.yanchor)},doneFn:function(){void 0!==u&&void 0!==h&&o.call("_guiRelayout",t,{"legend.x":u,"legend.y":h})},clickFn:function(r,n){var a=e._infolayer.selectAll("g.traces").filter(function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom});a.size()>0&&_(t,d,a,r,n)}})}function V(e,r,n){s._scrollY=t._fullLayout.legend._scrollY=e,c.setTranslate(S,0,-e),c.setRect(E,s._width,p.scrollBarMargin+e*n,p.scrollBarWidth,r),g.select("rect").attr("y",b+e)}}],t)}}},{"../../constants/alignment":685,"../../lib":716,"../../lib/events":706,"../../lib/svg_text_utils":740,"../../plots/plots":825,"../../registry":845,"../color":591,"../dragelement":609,"../drawing":612,"./constants":640,"./get_legend_data":643,"./handle_click":644,"./helpers":645,"./style":647,d3:164}],643:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("./helpers");e.exports=function(t,e){var r,i,o={},s=[],l=!1,c={},u=0,h=0;function f(t,r){if(""!==t&&a.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n="~~i"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var p=t[r],d=p[0],g=d.trace,v=g.legendgroup;if(g.visible&&g.showlegend)if(n.traceIs(g,"pie-like"))for(c[v]||(c[v]={}),i=0;i<p.length;i++){var m=p[i].label;c[v][m]||(f(v,{label:m,color:p[i].color,i:p[i].i,trace:g,pts:p[i].pts}),c[v][m]=!0,h=Math.max(h,(m||"").length))}else f(v,d),h=Math.max(h,(g.name||"").length)}if(!s.length)return[];var y,x,b=s.length;if(l&&a.isGrouped(e))for(x=new Array(b),r=0;r<b;r++)y=o[s[r]],x[r]=a.isReversed(e)?y.reverse():y;else{for(x=[new Array(b)],r=0;r<b;r++)y=o[s[r]][0],x[0][a.isReversed(e)?b-r-1:r]=y;b=1}return e._lgroupsLength=b,e._maxNameLength=h,x}},{"../../registry":845,"./helpers":645}],644:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&"toggle"===l&&"toggleothers"===c&&i&&e.data&&e._context.showTips?(n.notifier(n._(e,"Double-click on legend to isolate one trace"),"long"),i=!1):i=!1,1===r?s=l:2===r&&(s=c),s){var u,h,f,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],v=t.data()[0][0],m=e._fullData,y=v.trace,x=y.legendgroup,b={},_=[],w=[],k=[];if(a.traceIs(y,"pie-like")){var T=v.label,A=g.indexOf(T);"toggle"===s?-1===A?g.push(T):g.splice(A,1):"toggleothers"===s&&(g=[],e.calcdata[0].forEach(function(t){T!==t.label&&g.push(t.label)}),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===A&&(g=[])),a.call("_guiRelayout",e,"hiddenlabels",g)}else{var M,S=x&&x.length,E=[];if(S)for(u=0;u<m.length;u++)(M=m[u]).visible&&M.legendgroup===x&&E.push(u);if("toggle"===s){var L;switch(y.visible){case!0:L="legendonly";break;case!1:L=!1;break;case"legendonly":L=!0}if(S)for(u=0;u<m.length;u++)!1!==m[u].visible&&m[u].legendgroup===x&&R(m[u],L);else R(y,L)}else if("toggleothers"===s){var C,P,O=!0;for(u=0;u<m.length;u++)if(!(m[u]===y)&&!(C=S&&m[u].legendgroup===x)&&!0===m[u].visible&&!a.traceIs(m[u],"notLegendIsolatable")){O=!1;break}for(u=0;u<m.length;u++)if(!1!==m[u].visible&&!a.traceIs(m[u],"notLegendIsolatable"))switch(y.visible){case"legendonly":R(m[u],!0);break;case!0:P=!!O||"legendonly",C=m[u]===y||S&&m[u].legendgroup===x,R(m[u],!!C||P)}}for(u=0;u<w.length;u++)if(f=w[u]){var z=f.constructUpdate(),I=Object.keys(z);for(h=0;h<I.length;h++)p=I[h],(b[p]=b[p]||[])[k[u]]=z[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],h=0;h<_.length;h++)b[p].hasOwnProperty(h)||(b[p][h]=void 0);a.call("_guiRestyle",e,b,_)}}}function D(t,e,r){var n=_.indexOf(t),a=b[e];return a||(a=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),a[n]=r,n}function R(t,e){var r=t._fullInput;if(a.hasTransform(r,"groupby")){var i=w[r.index];if(!i){var o=a.getTransformIndices(r,"groupby"),s=o[o.length-1];i=n.keyedContainer(r,"transforms["+s+"].styles","target","value.visible"),w[r.index]=i}var l=i.get(t._group);void 0===l&&(l=!0),!1!==l&&i.set(t._group,e),k[r.index]=D(r.index,"visible",!1!==r.visible)}else{var c=!1!==r.visible&&e;D(r.index,"visible",c)}}}},{"../../lib":716,"../../registry":845}],645:[function(t,e,r){"use strict";r.isGrouped=function(t){return-1!==(t.traceorder||"").indexOf("grouped")},r.isVertical=function(t){return"h"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||"").indexOf("reversed")}},{}],646:[function(t,e,r){"use strict";e.exports={moduleType:"component",name:"legend",layoutAttributes:t("./attributes"),supplyLayoutDefaults:t("./defaults"),draw:t("./draw"),style:t("./style")}},{"./attributes":639,"./defaults":641,"./draw":642,"./style":647}],647:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../lib"),o=t("../drawing"),s=t("../color"),l=t("../colorscale/helpers").extractOpts,c=t("../../traces/scatter/subtypes"),u=t("../../traces/pie/style_one"),h=t("../../traces/pie/helpers").castOption,f=12,p=5,d=2,g=10,v=5;function m(t){return t?"horizontal":"horizontalreversed"}e.exports=function(t,e){var r=e._fullLayout.legend,y="constant"===r.itemsizing,x=function(t,e,r,n){var a;if(t+1)a=t;else{if(!(e&&e.width>0))return 0;a=e.width}return y?n:Math.min(a,r)};function b(t,e,r){var i=t[0].trace,o=i.marker||{},l=o.line||{},c=r?i.visible&&i.type===r:a.traceIs(i,"bar"),u=n.select(e).select("g.legendpoints").selectAll("path.legend"+r).data(c?[t]:[]);u.enter().append("path").classed("legend"+r,!0).attr("d","M6,6H-6V-6H6Z").attr("transform","translate(20,0)"),u.exit().remove(),u.each(function(t){var e=n.select(this),r=t[0],a=x(r.mlw,o.line,v,d);e.style("stroke-width",a+"px").call(s.fill,r.mc||o.color),a&&s.stroke(e,r.mlc||l.color)})}function _(t,e,r){var o=t[0],s=o.trace,l=r?s.visible&&s.type===r:a.traceIs(s,r),c=n.select(e).select("g.legendpoints").selectAll("path.legend"+r).data(l?[t]:[]);if(c.enter().append("path").classed("legend"+r,!0).attr("d","M6,6H-6V-6H6Z").attr("transform","translate(20,0)"),c.exit().remove(),c.size()){var f=(s.marker||{}).line,p=x(h(f.width,o.pts),f,v,d),g=i.minExtend(s,{marker:{line:{width:p}}});g.marker.line.color=f.color;var m=i.minExtend(o,{trace:g});u(c,m,g)}}t.each(function(t){var e=n.select(this),a=i.ensureSingle(e,"g","layers");a.style("opacity",t[0].trace.opacity);var o=r.valign,s=t[0].lineHeight,l=t[0].height;if("middle"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));a.attr("transform","translate(0,"+c+")")}else a.attr("transform",null);a.selectAll("g.legendfill").data([t]).enter().append("g").classed("legendfill",!0),a.selectAll("g.legendlines").data([t]).enter().append("g").classed("legendlines",!0);var u=a.selectAll("g.legendsymbols").data([t]);u.enter().append("g").classed("legendsymbols",!0),u.selectAll("g.legendpoints").data([t]).enter().append("g").classed("legendpoints",!0)}).each(function(t){var e=t[0].trace,r=[];e.visible&&"waterfall"===e.type&&(r=t[0].hasTotals?[["increasing","M-6,-6V6H0Z"],["totals","M6,6H0L-6,-6H-0Z"],["decreasing","M6,6V-6H0Z"]]:[["increasing","M-6,-6V6H6Z"],["decreasing","M6,6V-6H-6Z"]]);var a=n.select(this).select("g.legendpoints").selectAll("path.legendwaterfall").data(r);a.enter().append("path").classed("legendwaterfall",!0).attr("transform","translate(20,0)").style("stroke-miterlimit",1),a.exit().remove(),a.each(function(t){var r=n.select(this),a=e[t[0]].marker,i=x(void 0,a.line,v,d);r.attr("d",t[1]).style("stroke-width",i+"px").call(s.fill,a.color),i&&r.call(s.stroke,a.line.color)})}).each(function(t){b(t,this,"funnel")}).each(function(t){b(t,this)}).each(function(t){var r=t[0].trace,l=n.select(this).select("g.legendpoints").selectAll("path.legendbox").data(r.visible&&a.traceIs(r,"box-violin")?[t]:[]);l.enter().append("path").classed("legendbox",!0).attr("d","M6,6H-6V-6H6Z").attr("transform","translate(20,0)"),l.exit().remove(),l.each(function(){var t=n.select(this);if("all"!==r.boxpoints&&"all"!==r.points||0!==s.opacity(r.fillcolor)||0!==s.opacity((r.line||{}).color)){var a=x(void 0,r.line,v,d);t.style("stroke-width",a+"px").call(s.fill,r.fillcolor),a&&s.stroke(t,r.line.color)}else{var c=i.minExtend(r,{marker:{size:y?f:i.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:"diameter"}});l.call(o.pointStyle,c,e)}})}).each(function(t){_(t,this,"funnelarea")}).each(function(t){_(t,this,"pie")}).each(function(t){var r,a,s=t[0],u=s.trace,h=u.visible&&u.fill&&"none"!==u.fill,f=c.hasLines(u),d=u.contours,v=!1,y=!1,b=l(u),_=b.colorscale,w=b.reversescale;if(d){var k=d.coloring;"lines"===k?v=!0:f="none"===k||"heatmap"===k||d.showlines,"constraint"===d.type?h="="!==d._operation:"fill"!==k&&"heatmap"!==k||(y=!0)}var T=c.hasMarkers(u)||c.hasText(u),A=h||y,M=f||v,S=T||!A?"M5,0":M?"M5,-2":"M5,-3",E=n.select(this),L=E.select(".legendfill").selectAll("path").data(h||y?[t]:[]);if(L.enter().append("path").classed("js-fill",!0),L.exit().remove(),L.attr("d",S+"h30v6h-30z").call(h?o.fillGroupStyle:function(t){if(t.size()){var r="legendfill-"+u.uid;o.gradient(t,e,r,m(w),_,"fill")}}),f||v){var C=x(void 0,u.line,g,p);a=i.minExtend(u,{line:{width:C}}),r=[i.minExtend(s,{trace:a})]}var P=E.select(".legendlines").selectAll("path").data(f||v?[r]:[]);P.enter().append("path").classed("js-line",!0),P.exit().remove(),P.attr("d",S+(v?"l30,0.0001":"h30")).call(f?o.lineGroupStyle:function(t){if(t.size()){var r="legendline-"+u.uid;o.lineGroupStyle(t),o.gradient(t,e,r,m(w),_,"stroke")}})}).each(function(t){var r,a,s=t[0],l=s.trace,u=c.hasMarkers(l),h=c.hasText(l),g=c.hasLines(l);function v(t,e,r,n){var a=i.nestedProperty(l,t).get(),o=i.isArrayOrTypedArray(a)&&e?e(a):a;if(y&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function m(t){return t[0]}if(u||h||g){var x={},b={};if(u){x.mc=v("marker.color",m),x.mx=v("marker.symbol",m),x.mo=v("marker.opacity",i.mean,[.2,1]),x.mlc=v("marker.line.color",m),x.mlw=v("marker.line.width",i.mean,[0,5],d),b.marker={sizeref:1,sizemin:1,sizemode:"diameter"};var _=v("marker.size",i.mean,[2,16],f);x.ms=_,b.marker.size=_}g&&(b.line={width:v("line.width",m,[0,10],p)}),h&&(x.tx="Aa",x.tp=v("textposition",m),x.ts=10,x.tc=v("textfont.color",m),x.tf=v("textfont.family",m)),r=[i.minExtend(s,x)],(a=i.minExtend(l,b)).selectedpoints=null,a.texttemplate=null}var w=n.select(this).select("g.legendpoints"),k=w.selectAll("path.scatterpts").data(u?r:[]);k.enter().insert("path",":first-child").classed("scatterpts",!0).attr("transform","translate(20,0)"),k.exit().remove(),k.call(o.pointStyle,a,e),u&&(r[0].mrc=3);var T=w.selectAll("g.pointtext").data(h?r:[]);T.enter().append("g").classed("pointtext",!0).append("text").attr("transform","translate(20,0)"),T.exit().remove(),T.selectAll("text").call(o.textPointStyle,a,e)}).each(function(t){var e=t[0].trace,r=n.select(this).select("g.legendpoints").selectAll("path.legendcandle").data(e.visible&&"candlestick"===e.type?[t,t]:[]);r.enter().append("path").classed("legendcandle",!0).attr("d",function(t,e){return e?"M-15,0H-8M-8,6V-6H8Z":"M15,0H8M8,-6V6H-8Z"}).attr("transform","translate(20,0)").style("stroke-miterlimit",1),r.exit().remove(),r.each(function(t,r){var a=n.select(this),i=e[r?"increasing":"decreasing"],o=x(void 0,i.line,v,d);a.style("stroke-width",o+"px").call(s.fill,i.fillcolor),o&&s.stroke(a,i.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select("g.legendpoints").selectAll("path.legendohlc").data(e.visible&&"ohlc"===e.type?[t,t]:[]);r.enter().append("path").classed("legendohlc",!0).attr("d",function(t,e){return e?"M-15,0H0M-8,-6V0":"M15,0H0M8,6V0"}).attr("transform","translate(20,0)").style("stroke-miterlimit",1),r.exit().remove(),r.each(function(t,r){var a=n.select(this),i=e[r?"increasing":"decreasing"],l=x(void 0,i.line,v,d);a.style("fill","none").call(o.dashLine,i.line.dash,l),l&&s.stroke(a,i.line.color)})})}},{"../../lib":716,"../../registry":845,"../../traces/pie/helpers":1097,"../../traces/pie/style_one":1103,"../../traces/scatter/subtypes":1142,"../color":591,"../colorscale/helpers":602,"../drawing":612,d3:164}],648:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../plots/plots"),i=t("../../plots/cartesian/axis_ids"),o=t("../../lib"),s=t("../../fonts/ploticon"),l=o._,c=e.exports={};function u(t,e){var r,a,o=e.currentTarget,s=o.getAttribute("data-attr"),l=o.getAttribute("data-val")||!0,c=t._fullLayout,u={},h=i.list(t,null,!0),f=c._cartesianSpikesEnabled;if("zoom"===s){var p,d="in"===l?.5:2,g=(1+d)/2,v=(1-d)/2;for(a=0;a<h.length;a++)if(!(r=h[a]).fixedrange)if(p=r._name,"auto"===l)u[p+".autorange"]=!0;else if("reset"===l){if(void 0===r._rangeInitial)u[p+".autorange"]=!0;else{var m=r._rangeInitial.slice();u[p+".range[0]"]=m[0],u[p+".range[1]"]=m[1]}void 0!==r._showSpikeInitial&&(u[p+".showspikes"]=r._showSpikeInitial,"on"!==f||r._showSpikeInitial||(f="off"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+v*y[1],g*y[1]+v*y[0]];u[p+".range[0]"]=r.l2r(x[0]),u[p+".range[1]"]=r.l2r(x[1])}}else"hovermode"!==s||"x"!==l&&"y"!==l||(l=c._isHoriz?"y":"x",o.setAttribute("data-val",l)),u[s]=l;c._cartesianSpikesEnabled=f,n.call("_guiRelayout",t,u)}function h(t,e){for(var r=e.currentTarget,a=r.getAttribute("data-attr"),i=r.getAttribute("data-val")||!0,o=t._fullLayout._subplots.gl3d,s={},l=a.split("."),c=0;c<o.length;c++)s[o[c]+"."+l[1]]=i;var u="pan"===i?i:"zoom";s.dragmode=u,n.call("_guiRelayout",t,s)}function f(t,e){for(var r=e.currentTarget.getAttribute("data-attr"),a=t._fullLayout,i=a._subplots.gl3d||[],o={},s=0;s<i.length;s++){var l,c=i[s],u=c+".camera",h=c+".aspectratio",f=a[c]._scene;"resetLastSave"===r?(o[u+".up"]=f.viewInitial.up,o[u+".eye"]=f.viewInitial.eye,o[u+".center"]=f.viewInitial.center,l=!0):"resetDefault"===r&&(o[u+".up"]=null,o[u+".eye"]=null,o[u+".center"]=null,l=!0),l&&(o[h+".x"]=f.viewInitial.aspectratio.x,o[h+".y"]=f.viewInitial.aspectratio.y,o[h+".z"]=f.viewInitial.aspectratio.z)}n.call("_guiRelayout",t,o)}function p(t,e){var r=e.currentTarget,n=r._previousVal,a=t._fullLayout,i=a._subplots.gl3d||[],o=["xaxis","yaxis","zaxis"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<i.length;c++){var u=i[c],h=a[u],f=u+".hovermode";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+"."+d+".showspikes";l[g]=!1,s[g]=h[d].showspikes}}r._previousVal=s}return l}function d(t,e){for(var r=e.currentTarget,a=r.getAttribute("data-attr"),i=r.getAttribute("data-val")||!0,o=t._fullLayout,s=o._subplots.geo,l=0;l<s.length;l++){var c=s[l],u=o[c];if("zoom"===a){var h=u.projection.scale,f="in"===i?2*h:.5*h;n.call("_guiRelayout",t,c+".projection.scale",f)}else"reset"===a&&m(t,"geo")}}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has("cartesian")?e._isHoriz?"y":"x":"closest")}function v(t){var e=g(t);n.call("_guiRelayout",t,"hovermode",e)}function m(t,e){for(var r=t._fullLayout,a=r._subplots[e]||[],i={},o=0;o<a.length;o++)for(var s=a[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];i[s+"."+h]=l[h]}n.call("_guiRelayout",t,i)}c.toImage={name:"toImage",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||"png";return l(t,"png"===e?"Download plot as a png":"Download plot")},icon:s.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||"png"};o.notifier(l(t,"Taking snapshot - this may take a few seconds"),"long"),"svg"!==r.format&&o.isIE()&&(o.notifier(l(t,"IE only supports svg.  Changing format to svg."),"long"),r.format="svg"),["filename","width","height","scale"].forEach(function(t){t in e&&(r[t]=e[t])}),n.call("downloadImage",t,r).then(function(e){o.notifier(l(t,"Snapshot succeeded")+" - "+e,"long")}).catch(function(){o.notifier(l(t,"Sorry, there was a problem downloading your snapshot!"),"long")})}},c.sendDataToCloud={name:"sendDataToCloud",title:function(t){return l(t,"Edit in Chart Studio")},icon:s.disk,click:function(t){a.sendDataToCloud(t)}},c.editInChartStudio={name:"editInChartStudio",title:function(t){return l(t,"Edit in Chart Studio")},icon:s.pencil,click:function(t){a.sendDataToCloud(t)}},c.zoom2d={name:"zoom2d",title:function(t){return l(t,"Zoom")},attr:"dragmode",val:"zoom",icon:s.zoombox,click:u},c.pan2d={name:"pan2d",title:function(t){return l(t,"Pan")},attr:"dragmode",val:"pan",icon:s.pan,click:u},c.select2d={name:"select2d",title:function(t){return l(t,"Box Select")},attr:"dragmode",val:"select",icon:s.selectbox,click:u},c.lasso2d={name:"lasso2d",title:function(t){return l(t,"Lasso Select")},attr:"dragmode",val:"lasso",icon:s.lasso,click:u},c.zoomIn2d={name:"zoomIn2d",title:function(t){return l(t,"Zoom in")},attr:"zoom",val:"in",icon:s.zoom_plus,click:u},c.zoomOut2d={name:"zoomOut2d",title:function(t){return l(t,"Zoom out")},attr:"zoom",val:"out",icon:s.zoom_minus,click:u},c.autoScale2d={name:"autoScale2d",title:function(t){return l(t,"Autoscale")},attr:"zoom",val:"auto",icon:s.autoscale,click:u},c.resetScale2d={name:"resetScale2d",title:function(t){return l(t,"Reset axes")},attr:"zoom",val:"reset",icon:s.home,click:u},c.hoverClosestCartesian={name:"hoverClosestCartesian",title:function(t){return l(t,"Show closest data on hover")},attr:"hovermode",val:"closest",icon:s.tooltip_basic,gravity:"ne",click:u},c.hoverCompareCartesian={name:"hoverCompareCartesian",title:function(t){return l(t,"Compare data on hover")},attr:"hovermode",val:function(t){return t._fullLayout._isHoriz?"y":"x"},icon:s.tooltip_compare,gravity:"ne",click:u},c.zoom3d={name:"zoom3d",title:function(t){return l(t,"Zoom")},attr:"scene.dragmode",val:"zoom",icon:s.zoombox,click:h},c.pan3d={name:"pan3d",title:function(t){return l(t,"Pan")},attr:"scene.dragmode",val:"pan",icon:s.pan,click:h},c.orbitRotation={name:"orbitRotation",title:function(t){return l(t,"Orbital rotation")},attr:"scene.dragmode",val:"orbit",icon:s["3d_rotate"],click:h},c.tableRotation={name:"tableRotation",title:function(t){return l(t,"Turntable rotation")},attr:"scene.dragmode",val:"turntable",icon:s["z-axis"],click:h},c.resetCameraDefault3d={name:"resetCameraDefault3d",title:function(t){return l(t,"Reset camera to default")},attr:"resetDefault",icon:s.home,click:f},c.resetCameraLastSave3d={name:"resetCameraLastSave3d",title:function(t){return l(t,"Reset camera to last save")},attr:"resetLastSave",icon:s.movie,click:f},c.hoverClosest3d={name:"hoverClosest3d",title:function(t){return l(t,"Toggle show closest data on hover")},attr:"hovermode",val:null,toggle:!0,icon:s.tooltip_basic,gravity:"ne",click:function(t,e){var r=p(t,e);n.call("_guiRelayout",t,r)}},c.zoomInGeo={name:"zoomInGeo",title:function(t){return l(t,"Zoom in")},attr:"zoom",val:"in",icon:s.zoom_plus,click:d},c.zoomOutGeo={name:"zoomOutGeo",title:function(t){return l(t,"Zoom out")},attr:"zoom",val:"out",icon:s.zoom_minus,click:d},c.resetGeo={name:"resetGeo",title:function(t){return l(t,"Reset")},attr:"reset",val:null,icon:s.autoscale,click:d},c.hoverClosestGeo={name:"hoverClosestGeo",title:function(t){return l(t,"Toggle show closest data on hover")},attr:"hovermode",val:null,toggle:!0,icon:s.tooltip_basic,gravity:"ne",click:v},c.hoverClosestGl2d={name:"hoverClosestGl2d",title:function(t){return l(t,"Toggle show closest data on hover")},attr:"hovermode",val:null,toggle:!0,icon:s.tooltip_basic,gravity:"ne",click:v},c.hoverClosestPie={name:"hoverClosestPie",title:function(t){return l(t,"Toggle show closest data on hover")},attr:"hovermode",val:"closest",icon:s.tooltip_basic,gravity:"ne",click:v},c.resetViewSankey={name:"resetSankeyGroup",title:function(t){return l(t,"Reset view")},icon:s.home,click:function(t){for(var e={"node.groups":[],"node.x":[],"node.y":[]},r=0;r<t._fullData.length;r++){var a=t._fullData[r]._viewInitial;e["node.groups"].push(a.node.groups.slice()),e["node.x"].push(a.node.x.slice()),e["node.y"].push(a.node.y.slice())}n.call("restyle",t,e)}},c.toggleHover={name:"toggleHover",title:function(t){return l(t,"Toggle show closest data on hover")},attr:"hovermode",val:null,toggle:!0,icon:s.tooltip_basic,gravity:"ne",click:function(t,e){var r=p(t,e);r.hovermode=g(t),n.call("_guiRelayout",t,r)}},c.resetViews={name:"resetViews",title:function(t){return l(t,"Reset views")},icon:s.home,click:function(t,e){var r=e.currentTarget;r.setAttribute("data-attr","zoom"),r.setAttribute("data-val","reset"),u(t,e),r.setAttribute("data-attr","resetLastSave"),f(t,e),m(t,"geo"),m(t,"mapbox")}},c.toggleSpikelines={name:"toggleSpikelines",title:function(t){return l(t,"Toggle Spike Lines")},icon:s.spikeline,attr:"_cartesianSpikesEnabled",val:"on",click:function(t){var e=t._fullLayout,r=e._cartesianSpikesEnabled;e._cartesianSpikesEnabled="on"===r?"off":"on",n.call("_guiRelayout",t,function(t){for(var e="on"===t._fullLayout._cartesianSpikesEnabled,r=i.list(t,null,!0),n={},a=0;a<r.length;a++){var o=r[a];n[o._name+".showspikes"]=!!e||o._showSpikeInitial}return n}(t))}},c.resetViewMapbox={name:"resetViewMapbox",title:function(t){return l(t,"Reset view")},attr:"reset",icon:s.home,click:function(t){m(t,"mapbox")}}},{"../../fonts/ploticon":696,"../../lib":716,"../../plots/cartesian/axis_ids":767,"../../plots/plots":825,"../../registry":845}],649:[function(t,e,r){"use strict";r.manage=t("./manage")},{"./manage":650}],650:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axis_ids"),a=t("../../traces/scatter/subtypes"),i=t("../../registry"),o=t("./modebar"),s=t("./buttons");e.exports=function(t){var e=t._fullLayout,r=t._context,l=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error(["*modeBarButtonsToRemove* configuration options","must be an array."].join(" "));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error(["*modeBarButtonsToAdd* configuration options","must be an array."].join(" "));var c,u=r.modeBarButtons;c=Array.isArray(u)&&u.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var a=r[n];if("string"==typeof a){if(void 0===s[a])throw new Error(["*modeBarButtons* configuration options","invalid button name"].join(" "));t[e][n]=s[a]}}return t}(u):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,o=t._context,l=o.modeBarButtonsToRemove,c=o.modeBarButtonsToAdd,u=e._has("cartesian"),h=e._has("gl3d"),f=e._has("geo"),p=e._has("pie"),d=e._has("funnelarea"),g=e._has("gl2d"),v=e._has("ternary"),m=e._has("mapbox"),y=e._has("polar"),x=e._has("sankey"),b=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),_=[];function w(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===l.indexOf(n)&&e.push(s[n])}_.push(e)}}var k=["toImage"];o.showEditInChartStudio?k.push("editInChartStudio"):o.showSendToCloud&&k.push("sendDataToCloud");w(k);var T=[],A=[],M=[],S=[];(u||g||p||d||v)+f+h+m+y>1?(A=["toggleHover"],M=["resetViews"]):f?(T=["zoomInGeo","zoomOutGeo"],A=["hoverClosestGeo"],M=["resetGeo"]):h?(A=["hoverClosest3d"],M=["resetCameraDefault3d","resetCameraLastSave3d"]):m?(A=["toggleHover"],M=["resetViewMapbox"]):g?A=["hoverClosestGl2d"]:p?A=["hoverClosestPie"]:x?(A=["hoverClosestCartesian","hoverCompareCartesian"],M=["resetViewSankey"]):A=["toggleHover"];u&&(A=["toggleSpikelines","hoverClosestCartesian","hoverCompareCartesian"]);(function(t){for(var e=0;e<t.length;e++)if(!i.traceIs(t[e],"noHover"))return!1;return!0})(r)&&(A=[]);!u&&!g||b||(T=["zoomIn2d","zoomOut2d","autoScale2d"],"resetViews"!==M[0]&&(M=["resetScale2d"]));h?S=["zoom3d","pan3d","orbitRotation","tableRotation"]:(u||g)&&!b||v?S=["zoom2d","pan2d"]:m||f?S=["pan2d"]:y&&(S=["zoom2d"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(i.traceIs(n,"scatter-like")?(a.hasMarkers(n)||a.hasText(n))&&(e=!0):i.traceIs(n,"box-violin")&&"all"!==n.boxpoints&&"all"!==n.points||(e=!0))}return e})(r)&&S.push("select2d","lasso2d");return w(S),w(T.concat(M)),w(A),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(_,c)}(t),l?l.update(t,c):e._modeBar=o(t,c)}else l&&(l.destroy(),delete e._modeBar)}},{"../../plots/cartesian/axis_ids":767,"../../registry":845,"../../traces/scatter/subtypes":1142,"./buttons":648,"./modebar":651}],651:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../lib"),o=t("../../fonts/ploticon"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement("div"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,a="modebar-"+n._uid;this.element.setAttribute("id",a),this._uid=a,this.element.className="modebar","hover"===r.displayModeBar&&(this.element.className+=" modebar--hover ease-bg"),"v"===n.modebar.orientation&&(this.element.className+=" vertical",e=e.reverse());var o=n.modebar,s="hover"===r.displayModeBar?".js-plotly-plot .plotly:hover ":"";i.deleteRelatedStyleRule(a),i.addRelatedStyleRule(a,s+"#"+a+" .modebar-group","background-color: "+o.bgcolor),i.addRelatedStyleRule(a,"#"+a+" .modebar-btn .icon path","fill: "+o.color),i.addRelatedStyleRule(a,"#"+a+" .modebar-btn:hover .icon path","fill: "+o.activecolor),i.addRelatedStyleRule(a,"#"+a+" .modebar-btn.active .icon path","fill: "+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+" watermark"),"v"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach(function(t){var r=e.createGroup();t.forEach(function(t){var n=t.name;if(!n)throw new Error("must provide button 'name' in button config");if(-1!==e.buttonsNames.indexOf(n))throw new Error("button name '"+n+"' is taken");e.buttonsNames.push(n);var a=e.createButton(t);e.buttonElements.push(a),r.appendChild(a)}),e.element.appendChild(r)})},c.createGroup=function(){var t=document.createElement("div");return t.className="modebar-group",t},c.createButton=function(t){var e=this,r=document.createElement("a");r.setAttribute("rel","tooltip"),r.className="modebar-btn";var a=t.title;void 0===a?a=t.name:"function"==typeof a&&(a=a(this.graphInfo)),(a||0===a)&&r.setAttribute("data-title",a),void 0!==t.attr&&r.setAttribute("data-attr",t.attr);var i=t.val;if(void 0!==i&&("function"==typeof i&&(i=i(this.graphInfo)),r.setAttribute("data-val",i)),"function"!=typeof t.click)throw new Error("must provide button 'click' function in button config");r.addEventListener("click",function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)}),r.setAttribute("data-toggle",t.toggle||!1),t.toggle&&n.select(r).classed("active",!0);var s=t.icon;return"function"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute("data-gravity",t.gravity||"n"),r},c.createIcon=function(t){var e,r=a(t.height)?Number(t.height):t.ascent-t.descent,n="http://www.w3.org/2000/svg";if(t.path){(e=document.createElementNS(n,"svg")).setAttribute("viewBox",[0,0,t.width,r].join(" ")),e.setAttribute("class","icon");var i=document.createElementNS(n,"path");i.setAttribute("d",t.path),t.transform?i.setAttribute("transform",t.transform):void 0!==t.ascent&&i.setAttribute("transform","matrix(1 0 0 -1 0 "+t.ascent+")"),e.appendChild(i)}t.svg&&(e=s.parseFromString(t.svg,"application/xml").childNodes[0]);return e.setAttribute("height","1em"),e.setAttribute("width","1em"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute("data-attr"):null;this.buttonElements.forEach(function(t){var a=t.getAttribute("data-val")||!0,o=t.getAttribute("data-attr"),s="true"===t.getAttribute("data-toggle"),l=n.select(t);if(s)o===r&&l.classed("active",!l.classed("active"));else{var c=null===o?o:i.nestedProperty(e,o).get();l.classed("active",c===a)}})},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement("a");return e.href="https://plot.ly/",e.target="_blank",e.setAttribute("data-title",i._(this.graphInfo,"Produced with Plotly")),e.className="modebar-btn plotlyjsicon modebar-btn--logo",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){i.removeElement(this.container.querySelector(".modebar")),i.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,a=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(a.element).append("span").classed("badge-private float--left",!0).text("PRIVATE"),a}},{"../../fonts/ploticon":696,"../../lib":716,d3:164,"fast-isnumeric":227}],652:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../color/attributes"),i=(0,t("../../plot_api/plot_template").templatedArray)("button",{visible:{valType:"boolean",dflt:!0,editType:"plot"},step:{valType:"enumerated",values:["month","year","day","hour","minute","second","all"],dflt:"month",editType:"plot"},stepmode:{valType:"enumerated",values:["backward","todate"],dflt:"backward",editType:"plot"},count:{valType:"number",min:0,dflt:1,editType:"plot"},label:{valType:"string",editType:"plot"},editType:"plot"});e.exports={visible:{valType:"boolean",editType:"plot"},buttons:i,x:{valType:"number",min:-2,max:3,editType:"plot"},xanchor:{valType:"enumerated",values:["auto","left","center","right"],dflt:"left",editType:"plot"},y:{valType:"number",min:-2,max:3,editType:"plot"},yanchor:{valType:"enumerated",values:["auto","top","middle","bottom"],dflt:"bottom",editType:"plot"},font:n({editType:"plot"}),bgcolor:{valType:"color",dflt:a.lightLine,editType:"plot"},activecolor:{valType:"color",editType:"plot"},bordercolor:{valType:"color",dflt:a.defaultLine,editType:"plot"},borderwidth:{valType:"number",min:0,dflt:0,editType:"plot"},editType:"plot"}},{"../../plot_api/plot_template":754,"../../plots/font_attributes":790,"../color/attributes":590}],653:[function(t,e,r){"use strict";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],654:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../color"),i=t("../../plot_api/plot_template"),o=t("../../plots/array_container_defaults"),s=t("./attributes"),l=t("./constants");function c(t,e,r,a){var i=a.calendar;function o(r,a){return n.coerce(t,e,s.buttons,r,a)}if(o("visible")){var l=o("step");"all"!==l&&(!i||"gregorian"===i||"month"!==l&&"year"!==l?o("stepmode"):e.stepmode="backward",o("count")),o("label")}}e.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=i.newContainer(e,"rangeselector");function d(t,e){return n.coerce(f,p,s,t,e)}if(d("visible",o(f,p,{name:"buttons",handleItemDefaults:c,calendar:h}).length>0)){var g=function(t,e,r){for(var n=r.filter(function(r){return e[r].anchor===t._id}),a=0,i=0;i<n.length;i++){var o=e[n[i]].domain;o&&(a=Math.max(o[1],a))}return[t.domain[0],a+l.yPad]}(e,r,u);d("x",g[0]),d("y",g[1]),n.noneOrAll(t,e,["x","y"]),d("xanchor"),d("yanchor"),n.coerceFont(d,"font",r.font);var v=d("bgcolor");d("activecolor",a.contrast(v,l.lightAmount,l.darkAmount)),d("bordercolor"),d("borderwidth")}}},{"../../lib":716,"../../plot_api/plot_template":754,"../../plots/array_container_defaults":760,"../color":591,"./attributes":652,"./constants":653}],655:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../plots/plots"),o=t("../color"),s=t("../drawing"),l=t("../../lib"),c=t("../../lib/svg_text_utils"),u=t("../../plots/cartesian/axis_ids"),h=t("../../constants/alignment"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR,g=t("./constants"),v=t("./get_update_object");function m(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,"rect","selector-rect",function(t){t.attr("shape-rendering","crispEdges")});n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style("stroke-width",e.borderwidth+"px")}function x(t,e,r,n){l.ensureSingle(t,"text","selector-text",function(t){t.classed("user-select-none",!0).attr("text-anchor","middle")}).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return"all"===t.step?"all":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call(function(t){c.convertToTspans(t,n)})}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(".rangeselector").data(function(t){for(var e=u.list(t,"x",!0),r=[],n=0;n<e.length;n++){var a=e[n];a.rangeselector&&a.rangeselector.visible&&r.push(a)}return r}(t),m);e.enter().append("g").classed("rangeselector",!0),e.exit().remove(),e.style({cursor:"pointer","pointer-events":"all"}),e.each(function(e){var r=n.select(this),o=e,u=o.rangeselector,h=r.selectAll("g.button").data(l.filterVisible(u.buttons));h.enter().append("g").classed("button",!0),h.exit().remove(),h.each(function(e){var r=n.select(this),i=v(o,e);e._isActive=function(t,e,r){if("all"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,i),r.call(y,u,e),r.call(x,u,e,t),r.on("click",function(){t._dragged||a.call("_guiRelayout",t,i)}),r.on("mouseover",function(){e._isHovered=!0,r.call(y,u,e)}),r.on("mouseout",function(){e._isHovered=!1,r.call(y,u,e)})}),function(t,e,r,a,o){var u=0,h=0,v=r.borderwidth;e.each(function(){var t=n.select(this),e=t.select(".selector-text"),a=r.font.size*f,i=Math.max(a*c.lineCount(e),16)+3;h=Math.max(h,i)}),e.each(function(){var t=n.select(this),e=t.select(".selector-rect"),a=t.select(".selector-text"),i=a.node()&&s.bBox(a.node()).width,o=r.font.size*f,l=c.lineCount(a),p=Math.max(i+10,g.minButtonWidth);t.attr("transform","translate("+(v+u)+","+v+")"),e.attr({x:0,y:0,width:p,height:h}),c.positionText(a,p/2,h/2-(l-1)*o/2+3),u+=p+5});var m=t._fullLayout._size,y=m.l+m.w*r.x,x=m.t+m.h*(1-r.y),b="left";l.isRightAnchor(r)&&(y-=u,b="right");l.isCenterAnchor(r)&&(y-=u/2,b="center");var _="top";l.isBottomAnchor(r)&&(x-=h,_="bottom");l.isMiddleAnchor(r)&&(x-=h/2,_="middle");u=Math.ceil(u),h=Math.ceil(h),y=Math.round(y),x=Math.round(x),i.autoMargin(t,a+"-range-selector",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:h*d[_],t:h*p[_]}),o.attr("transform","translate("+y+","+x+")")}(t,h,u,o._name,r)})}},{"../../constants/alignment":685,"../../lib":716,"../../lib/svg_text_utils":740,"../../plots/cartesian/axis_ids":767,"../../plots/plots":825,"../../registry":845,"../color":591,"../drawing":612,"./constants":653,"./get_update_object":656,d3:164}],656:[function(t,e,r){"use strict";var n=t("d3");e.exports=function(t,e){var r=t._name,a={};if("all"===e.step)a[r+".autorange"]=!0;else{var i=function(t,e){var r,a=t.range,i=new Date(t.r2l(a[1])),o=e.step,s=e.count;switch(e.stepmode){case"backward":r=t.l2r(+n.time[o].utc.offset(i,-s));break;case"todate":var l=n.time[o].utc.offset(i,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=a[1];return[r,c]}(t,e);a[r+".range[0]"]=i[0],a[r+".range[1]"]=i[1]}return a}},{d3:164}],657:[function(t,e,r){"use strict";e.exports={moduleType:"component",name:"rangeselector",schema:{subplots:{xaxis:{rangeselector:t("./attributes")}}},layoutAttributes:t("./attributes"),handleDefaults:t("./defaults"),draw:t("./draw")}},{"./attributes":652,"./defaults":654,"./draw":655}],658:[function(t,e,r){"use strict";var n=t("../color/attributes");e.exports={bgcolor:{valType:"color",dflt:n.background,editType:"plot"},bordercolor:{valType:"color",dflt:n.defaultLine,editType:"plot"},borderwidth:{valType:"integer",dflt:0,min:0,editType:"plot"},autorange:{valType:"boolean",dflt:!0,editType:"calc",impliedEdits:{"range[0]":void 0,"range[1]":void 0}},range:{valType:"info_array",items:[{valType:"any",editType:"calc",impliedEdits:{"^autorange":!1}},{valType:"any",editType:"calc",impliedEdits:{"^autorange":!1}}],editType:"calc",impliedEdits:{autorange:!1}},thickness:{valType:"number",dflt:.15,min:0,max:1,editType:"plot"},visible:{valType:"boolean",dflt:!0,editType:"calc"},editType:"calc"}},{"../color/attributes":590}],659:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axis_ids").list,a=t("../../plots/cartesian/autorange").getAutoRange,i=t("./constants");e.exports=function(t){for(var e=n(t,"x",!0),r=0;r<e.length;r++){var o=e[r],s=o[i.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=a(t,o))}}},{"../../plots/cartesian/autorange":763,"../../plots/cartesian/axis_ids":767,"./constants":660}],660:[function(t,e,r){"use strict";e.exports={name:"rangeslider",containerClassName:"rangeslider-container",bgClassName:"rangeslider-bg",rangePlotClassName:"rangeslider-rangeplot",maskMinClassName:"rangeslider-mask-min",maskMaxClassName:"rangeslider-mask-max",slideBoxClassName:"rangeslider-slidebox",grabberMinClassName:"rangeslider-grabber-min",grabAreaMinClassName:"rangeslider-grabarea-min",handleMinClassName:"rangeslider-handle-min",grabberMaxClassName:"rangeslider-grabber-max",grabAreaMaxClassName:"rangeslider-grabarea-max",handleMaxClassName:"rangeslider-handle-max",maskMinOppAxisClassName:"rangeslider-mask-min-opp-axis",maskMaxOppAxisClassName:"rangeslider-mask-max-opp-axis",maskColor:"rgba(0,0,0,0.4)",maskOppAxisColor:"rgba(0,0,0,0.2)",slideBoxFill:"transparent",slideBoxCursor:"ew-resize",grabAreaFill:"transparent",grabAreaCursor:"col-resize",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],661:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plot_api/plot_template"),i=t("../../plots/cartesian/axis_ids"),o=t("./attributes"),s=t("./oppaxis_attributes");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=a.newContainer(c,"rangeslider");if(_("visible")){_("bgcolor",e.plot_bgcolor),_("bordercolor"),_("borderwidth"),_("thickness"),_("autorange",!c.isValidRange(f.range)),_("range");var d=e._subplots;if(d)for(var g=d.cartesian.filter(function(t){return t.substr(0,t.indexOf("y"))===i.name2id(r)}).map(function(t){return t.substr(t.indexOf("y"),t.length)}),v=n.simpleMap(g,i.id2name),m=0;m<v.length;m++){var y=v[m];u=f[y]||{},h=a.newContainer(p,y,"yaxis");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x="fixed"),"match"!==w("rangemode",x)&&w("range",b.range.slice())}p._input=f}}function _(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},{"../../lib":716,"../../plot_api/plot_template":754,"../../plots/cartesian/axis_ids":767,"./attributes":658,"./oppaxis_attributes":665}],662:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../plots/plots"),o=t("../../lib"),s=t("../drawing"),l=t("../color"),c=t("../titles"),u=t("../../plots/cartesian"),h=t("../../plots/cartesian/axis_ids"),f=t("../dragelement"),p=t("../../lib/setcursor"),d=t("./constants");function g(t,e,r,n){var a=o.ensureSingle(t,"rect",d.bgClassName,function(t){t.attr({x:0,y:0,"shape-rendering":"crispEdges"})}),i=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);a.attr({width:n._width+i,height:n._height+i,transform:"translate("+l+","+l+")",fill:n.bgcolor,stroke:n.bordercolor,"stroke-width":c})}function v(t,e,r,n){var a=e._fullLayout;o.ensureSingleById(a._topdefs,"clipPath",n._clipId,function(t){t.append("rect").attr({x:0,y:0})}).select("rect").attr({width:n._width,height:n._height})}function m(t,e,r,a){var l,c=e.calcdata,f=t.selectAll("g."+d.rangePlotClassName).data(r._subplotsWith,o.identity);f.enter().append("g").attr("class",function(t){return d.rangePlotClassName+" "+t}).call(s.setClipUrl,a._clipId,e),f.order(),f.exit().remove(),f.each(function(t,o){var s=n.select(this),f=0===o,p=h.getFromId(e,t,"y"),d=p._name,g=a[d],v={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:a.range.slice(),calendar:r.calendar},width:a._width,height:a._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};v.layout[d]={type:p.type,domain:[0,1],range:"match"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},i.supplyDefaults(v);var m=v._fullLayout.xaxis,y=v._fullLayout[d];m.clearCalc(),m.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:m,yaxis:y,isRangePlot:!0};f?l=x:(x.mainplot="xy",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var a=t[n],i=a[0].trace;i.xaxis+i.yaxis===e&&r.push(a)}return r}(c,t))})}function y(t,e,r,n,a){(o.ensureSingle(t,"rect",d.maskMinClassName,function(t){t.attr({x:0,y:0,"shape-rendering":"crispEdges"})}).attr("height",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,"rect",d.maskMaxClassName,function(t){t.attr({y:0,"shape-rendering":"crispEdges"})}).attr("height",n._height).call(l.fill,d.maskColor),"match"!==a.rangemode)&&(o.ensureSingle(t,"rect",d.maskMinOppAxisClassName,function(t){t.attr({y:0,"shape-rendering":"crispEdges"})}).attr("width",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,"rect",d.maskMaxOppAxisClassName,function(t){t.attr({y:0,"shape-rendering":"crispEdges"})}).attr("width",n._width).style("border-top",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,"rect",d.slideBoxClassName,function(t){t.attr({y:0,cursor:d.slideBoxCursor,"shape-rendering":"crispEdges"})}).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var a=o.ensureSingle(t,"g",d.grabberMinClassName),i=o.ensureSingle(t,"g",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,"stroke-width":d.handleStrokeWidth,"shape-rendering":"crispEdges"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(a,"rect",d.handleMinClassName,function(t){t.attr(s)}).attr(c),o.ensureSingle(i,"rect",d.handleMaxClassName,function(t){t.attr(s)}).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(a,"rect",d.grabAreaMinClassName,function(t){t.attr(u)}).attr("height",n._height),o.ensureSingle(i,"rect",d.grabAreaMaxClassName,function(t){t.attr(u)}).attr("height",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,i=0;i<r.length;i++){var s=r[i][d.name];s._clipId=s._id+"-"+e._uid}var l=e._infolayer.selectAll("g."+d.containerClassName).data(r,function(t){return t._name});l.exit().each(function(t){var r=t[d.name];e._topdefs.select("#"+r._clipId).remove()}).remove(),0!==r.length&&(l.enter().append("g").classed(d.containerClassName,!0).attr("pointer-events","all"),l.each(function(r){var i=n.select(this),s=r[d.name],l=e[h.id2name(r.anchor)],u=s[h.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),k=o.simpleMap(r.range,r.r2l);_=k[0]<k[1]?[Math.min(w[0],k[0]),Math.max(w[1],k[1])]:[Math.max(w[0],k[0]),Math.min(w[1],k[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange("rangeslider.range");var T=e._size,A=r.domain;s._width=T.w*(A[1]-A[0]);var M=Math.round(T.l+T.w*A[0]),S=Math.round(T.t+T.h*(1-r._counterDomainMin)+("bottom"===r.side?r._depth:0)+s._offsetShift+d.extraPad);i.attr("transform","translate("+M+","+S+")");var E=r.r2l(s.range[0]),L=r.r2l(s.range[1]),C=L-E;if(s.p2d=function(t){return t/s._width*C+E},s.d2p=function(t){return(t-E)/C*s._width},s._rl=[E,L],"match"!==u.rangemode){var P=l.r2l(u.range[0]),O=l.r2l(u.range[1])-P;s.d2pOppAxis=function(t){return(t-P)/O*s._height}}i.call(g,t,r,s).call(v,t,r,s).call(m,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,i){var s=t.select("rect."+d.slideBoxClassName).node(),l=t.select("rect."+d.grabAreaMinClassName).node(),c=t.select("rect."+d.grabAreaMaxClassName).node();t.on("mousedown",function(){var u=n.event,h=u.target,d=u.clientX,g=d-t.node().getBoundingClientRect().left,v=i.d2p(r._rl[0]),m=i.d2p(r._rl[1]),y=f.coverSlip();function x(t){var u,f,x,b=+t.clientX-d;switch(h){case s:x="ew-resize",u=v+b,f=m+b;break;case l:x="col-resize",u=v+b,f=m;break;case c:x="col-resize",u=v,f=m+b;break;default:x="ew-resize",u=g,f=g+b}if(f<u){var _=f;f=u,u=_}i._pixelMin=u,i._pixelMax=f,p(n.select(y),x),function(t,e,r,n){function i(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=i(n.p2d(n._pixelMin)),l=i(n.p2d(n._pixelMax));window.requestAnimationFrame(function(){a.call("_guiRelayout",e,r._name+".range",[s,l])})}(0,e,r,i)}y.addEventListener("mousemove",x),y.addEventListener("mouseup",function t(){y.removeEventListener("mousemove",x);y.removeEventListener("mouseup",t);o.removeElement(y)})})}(i,t,r,s),function(t,e,r,n,a,i){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var h=l(n.d2p(r._rl[0])),f=l(n.d2p(r._rl[1]));if(t.select("rect."+d.slideBoxClassName).attr("x",h).attr("width",f-h),t.select("rect."+d.maskMinClassName).attr("width",h),t.select("rect."+d.maskMaxClassName).attr("x",f).attr("width",n._width-f),"match"!==i.rangemode){var p=n._height-c(n.d2pOppAxis(a._rl[1])),g=n._height-c(n.d2pOppAxis(a._rl[0]));t.select("rect."+d.maskMinOppAxisClassName).attr("x",h).attr("height",p).attr("width",f-h),t.select("rect."+d.maskMaxOppAxisClassName).attr("x",h).attr("y",g).attr("height",n._height-g).attr("width",f-h),t.select("rect."+d.slideBoxClassName).attr("y",p).attr("height",g-p)}var v=Math.round(u(h-s))-.5,m=Math.round(u(f-s))+.5;t.select("g."+d.grabberMinClassName).attr("transform","translate("+v+",0.5)"),t.select("g."+d.grabberMaxClassName).attr("transform","translate("+m+",0.5)")}(i,0,r,s,l,u),"bottom"===r.side&&c.draw(t,r._id+"title",{propContainer:r,propName:r._name+".title",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:S+s._height+s._offsetShift+10+1.5*r.title.font.size,"text-anchor":"middle"}})}))}},{"../../lib":716,"../../lib/setcursor":736,"../../plots/cartesian":775,"../../plots/cartesian/axis_ids":767,"../../plots/plots":825,"../../registry":845,"../color":591,"../dragelement":609,"../drawing":612,"../titles":678,"./constants":660,d3:164}],663:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axis_ids"),a=t("../../lib/svg_text_utils"),i=t("./constants"),o=t("../../constants/alignment").LINE_SPACING,s=i.name;function l(t){var e=t&&t[s];return e&&e.visible}r.isVisible=l,r.makeData=function(t){var e=n.list({_fullLayout:t},"x",!0),r=t.margin,a=[];if(!t._has("gl2d"))for(var i=0;i<e.length;i++){var o=e[i];if(l(o)){a.push(o);var c=o[s];c._id=s+o._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=a},r.autoMarginOpts=function(t,e){var r=t._fullLayout,n=e[s],l=e._id.charAt(0),c=0,u=0;"bottom"===e.side&&(c=e._depth,e.title.text!==r._dfltTitle[l]&&(u=1.5*e.title.font.size+10+n._offsetShift,u+=(e.title.text.match(a.BR_TAG_ALL)||[]).length*e.title.font.size*o));return{x:0,y:e._counterDomainMin,l:0,r:0,t:0,b:n._height+c+Math.max(r.margin.b,u),pad:i.extraPad+2*n._offsetShift}}},{"../../constants/alignment":685,"../../lib/svg_text_utils":740,"../../plots/cartesian/axis_ids":767,"./constants":660}],664:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("./oppaxis_attributes"),o=t("./helpers");e.exports={moduleType:"component",name:"rangeslider",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},a,{yaxis:i})}}},layoutAttributes:t("./attributes"),handleDefaults:t("./defaults"),calcAutorange:t("./calc_autorange"),draw:t("./draw"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{"../../lib":716,"./attributes":658,"./calc_autorange":659,"./defaults":661,"./draw":662,"./helpers":663,"./oppaxis_attributes":665}],665:[function(t,e,r){"use strict";e.exports={_isSubplotObj:!0,rangemode:{valType:"enumerated",values:["auto","fixed","match"],dflt:"match",editType:"calc"},range:{valType:"info_array",items:[{valType:"any",editType:"plot"},{valType:"any",editType:"plot"}],editType:"plot"},editType:"calc"}},{}],666:[function(t,e,r){"use strict";var n=t("../annotations/attributes"),a=t("../../traces/scatter/attributes").line,i=t("../drawing/attributes").dash,o=t("../../lib/extend").extendFlat,s=t("../../plot_api/plot_template").templatedArray;e.exports=s("shape",{visible:{valType:"boolean",dflt:!0,editType:"calc+arraydraw"},type:{valType:"enumerated",values:["circle","rect","path","line"],editType:"calc+arraydraw"},layer:{valType:"enumerated",values:["below","above"],dflt:"above",editType:"arraydraw"},xref:o({},n.xref,{}),xsizemode:{valType:"enumerated",values:["scaled","pixel"],dflt:"scaled",editType:"calc+arraydraw"},xanchor:{valType:"any",editType:"calc+arraydraw"},x0:{valType:"any",editType:"calc+arraydraw"},x1:{valType:"any",editType:"calc+arraydraw"},yref:o({},n.yref,{}),ysizemode:{valType:"enumerated",values:["scaled","pixel"],dflt:"scaled",editType:"calc+arraydraw"},yanchor:{valType:"any",editType:"calc+arraydraw"},y0:{valType:"any",editType:"calc+arraydraw"},y1:{valType:"any",editType:"calc+arraydraw"},path:{valType:"string",editType:"calc+arraydraw"},opacity:{valType:"number",min:0,max:1,dflt:1,editType:"arraydraw"},line:{color:o({},a.color,{editType:"arraydraw"}),width:o({},a.width,{editType:"calc+arraydraw"}),dash:o({},i,{editType:"arraydraw"}),editType:"calc+arraydraw"},fillcolor:{valType:"color",dflt:"rgba(0,0,0,0)",editType:"arraydraw"},editType:"arraydraw"})},{"../../lib/extend":707,"../../plot_api/plot_template":754,"../../traces/scatter/attributes":1118,"../annotations/attributes":574,"../drawing/attributes":611}],667:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("./constants"),o=t("./helpers");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,a,s,l){var c=t/2,u=l;if("pixel"===e){var h=s?o.extractPathCoords(s,l?i.paramIsY:i.paramIsX):[r,a],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,g=f>0?f+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,a){var s="category"===t.type||"multicategory"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,h,f=1/0,p=-1/0,d=n.match(i.segmentRE);for("date"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=a[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(i.paramRE))||u.length<c||((h=s(u[c]))<f&&(f=h),h>p&&(p=h)));return p>=f?[f,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];if(f._extremes={},"paper"!==f.xref){var p="pixel"===f.xsizemode?f.xanchor:f.x0,d="pixel"===f.xsizemode?f.xanchor:f.x1;(h=u(c=a.getFromId(t,f.xref),p,d,f.path,i.paramIsX))&&(f._extremes[c._id]=a.findExtremes(c,h,s(f)))}if("paper"!==f.yref){var g="pixel"===f.ysizemode?f.yanchor:f.y0,v="pixel"===f.ysizemode?f.yanchor:f.y1;(h=u(c=a.getFromId(t,f.yref),g,v,f.path,i.paramIsY))&&(f._extremes[c._id]=a.findExtremes(c,h,l(f)))}}}},{"../../lib":716,"../../plots/cartesian/axes":764,"./constants":668,"./helpers":671}],668:[function(t,e,r){"use strict";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],669:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../../plots/array_container_defaults"),o=t("./attributes"),s=t("./helpers");function l(t,e,r){function i(r,a){return n.coerce(t,e,o,r,a)}if(i("visible")){i("layer"),i("opacity"),i("fillcolor"),i("line.color"),i("line.width"),i("line.dash");for(var l=i("type",t.path?"path":"rect"),c=i("xsizemode"),u=i("ysizemode"),h=["x","y"],f=0;f<2;f++){var p,d,g,v=h[f],m=v+"anchor",y="x"===v?c:u,x={_fullLayout:r},b=a.coerceRef(t,e,x,v,"","paper");if("paper"!==b?((p=a.getFromId(x,b))._shapeIndices.push(e._index),g=s.rangeToShapePosition(p),d=s.shapePositionToRange(p)):d=g=n.identity,"path"!==l){var _=v+"0",w=v+"1",k=t[_],T=t[w];t[_]=d(t[_],!0),t[w]=d(t[w],!0),"pixel"===y?(i(_,0),i(w,10)):(a.coercePosition(e,x,i,b,_,.25),a.coercePosition(e,x,i,b,w,.75)),e[_]=g(e[_]),e[w]=g(e[w]),t[_]=k,t[w]=T}if("pixel"===y){var A=t[m];t[m]=d(t[m],!0),a.coercePosition(e,x,i,b,m,.25),e[m]=g(e[m]),t[m]=A}}"path"===l?i("path"):n.noneOrAll(t,e,["x0","x1","y0","y1"])}}e.exports=function(t,e){i(t,e,{name:"shapes",handleItemDefaults:l})}},{"../../lib":716,"../../plots/array_container_defaults":760,"../../plots/cartesian/axes":764,"./attributes":666,"./helpers":671}],670:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../plots/cartesian/axes"),o=t("../color"),s=t("../drawing"),l=t("../../plot_api/plot_template").arrayEditor,c=t("../dragelement"),u=t("../../lib/setcursor"),h=t("./constants"),f=t("./helpers");function p(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index="'+e+'"]').remove();var r=t._fullLayout.shapes[e]||{};if(r._input&&!1!==r.visible)if("below"!==r.layer)m(t._fullLayout._shapeUpperLayer);else if("paper"===r.xref||"paper"===r.yref)m(t._fullLayout._shapeLowerLayer);else{var p=t._fullLayout._plots[r.xref+r.yref];if(p)m((p.mainplotinfo||p).shapelayer);else m(t._fullLayout._shapeLowerLayer)}function m(p){var m={"data-index":e,"fill-rule":"evenodd",d:g(t,r)},y=r.line.width?r.line.color:"rgba(0,0,0,0)",x=p.append("path").attr(m).style("opacity",r.opacity).call(o.stroke,y).call(o.fill,r.fillcolor).call(s.dashLine,r.line.dash,r.line.width);d(x,t,r),t._context.edits.shapePosition&&function(t,e,r,o,p){var m,y,x,b,_,w,k,T,A,M,S,E,L,C,P,O,z=10,I=10,D="pixel"===r.xsizemode,R="pixel"===r.ysizemode,F="line"===r.type,B="path"===r.type,N=l(t.layout,"shapes",r),j=N.modifyItem,V=i.getFromId(t,r.xref),U=i.getFromId(t,r.yref),q=f.getDataToPixel(t,V),H=f.getDataToPixel(t,U,!0),G=f.getPixelToData(t,V),Y=f.getPixelToData(t,U,!0),W=F?function(){var t=Math.max(r.line.width,10),n=p.append("g").attr("data-index",o);n.append("path").attr("d",e.attr("d")).style({cursor:"move","stroke-width":t,"stroke-opacity":"0"});var a={"fill-opacity":"0"},i=t/2>10?t/2:10;return n.append("circle").attr({"data-line-point":"start-point",cx:D?q(r.xanchor)+r.x0:q(r.x0),cy:R?H(r.yanchor)-r.y0:H(r.y0),r:i}).style(a).classed("cursor-grab",!0),n.append("circle").attr({"data-line-point":"end-point",cx:D?q(r.xanchor)+r.x1:q(r.x1),cy:R?H(r.yanchor)-r.y1:H(r.y1),r:i}).style(a).classed("cursor-grab",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){D&&(_=q(r.xanchor));R&&(w=H(r.yanchor));"path"===r.type?P=r.path:(m=D?r.x0:q(r.x0),y=R?r.y0:H(r.y0),x=D?r.x1:q(r.x1),b=R?r.y1:H(r.y1));m<x?(A=m,L="x0",M=x,C="x1"):(A=x,L="x1",M=m,C="x0");!R&&y<b||R&&y>b?(k=y,S="y0",T=b,E="y1"):(k=b,S="y1",T=y,E="y0");Z(n),Q(p,r),function(t,e,r){var n=e.xref,a=e.yref,o=i.getFromId(r,n),l=i.getFromId(r,a),c="";"paper"===n||o.autorange||(c+=n);"paper"===a||l.autorange||(c+=a);s.setClipUrl(t,c?"clip"+r._fullLayout._uid+c:null,r)}(e,r,t),X.moveFn="move"===O?J:K},doneFn:function(){u(e),$(p),d(e,t,r),n.call("_guiRelayout",t,N.getUpdateObj())},clickFn:function(){$(p)}};function Z(t){if(F)O="path"===t.target.tagName?"move":"start-point"===t.target.attributes["data-line-point"].value?"resize-over-start-point":"resize-over-end-point";else{var r=X.element.getBoundingClientRect(),n=r.right-r.left,a=r.bottom-r.top,i=t.clientX-r.left,o=t.clientY-r.top,s=!B&&n>z&&a>I&&!t.shiftKey?c.getCursor(i/n,1-o/a):"move";u(e,s),O=s.split("-")[0]}}function J(n,a){if("path"===r.type){var i=function(t){return t},o=i,s=i;D?j("xanchor",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},V&&"date"===V.type&&(o=f.encodeDate(o))),R?j("yanchor",r.yanchor=Y(w+a)):(s=function(t){return Y(H(t)+a)},U&&"date"===U.type&&(s=f.encodeDate(s))),j("path",r.path=v(P,o,s))}else D?j("xanchor",r.xanchor=G(_+n)):(j("x0",r.x0=G(m+n)),j("x1",r.x1=G(x+n))),R?j("yanchor",r.yanchor=Y(w+a)):(j("y0",r.y0=Y(y+a)),j("y1",r.y1=Y(b+a)));e.attr("d",g(t,r)),Q(p,r)}function K(n,a){if(B){var i=function(t){return t},o=i,s=i;D?j("xanchor",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},V&&"date"===V.type&&(o=f.encodeDate(o))),R?j("yanchor",r.yanchor=Y(w+a)):(s=function(t){return Y(H(t)+a)},U&&"date"===U.type&&(s=f.encodeDate(s))),j("path",r.path=v(P,o,s))}else if(F){if("resize-over-start-point"===O){var l=m+n,c=R?y-a:y+a;j("x0",r.x0=D?l:G(l)),j("y0",r.y0=R?c:Y(c))}else if("resize-over-end-point"===O){var u=x+n,h=R?b-a:b+a;j("x1",r.x1=D?u:G(u)),j("y1",r.y1=R?h:Y(h))}}else{var d=~O.indexOf("n")?k+a:k,N=~O.indexOf("s")?T+a:T,W=~O.indexOf("w")?A+n:A,X=~O.indexOf("e")?M+n:M;~O.indexOf("n")&&R&&(d=k-a),~O.indexOf("s")&&R&&(N=T-a),(!R&&N-d>I||R&&d-N>I)&&(j(S,r[S]=R?d:Y(d)),j(E,r[E]=R?N:Y(N))),X-W>z&&(j(L,r[L]=D?W:G(W)),j(C,r[C]=D?X:G(X)))}e.attr("d",g(t,r)),Q(p,r)}function Q(t,e){(D||R)&&function(){var r="path"!==e.type,n=t.selectAll(".visual-cue").data([0]);n.enter().append("path").attr({fill:"#fff","fill-rule":"evenodd",stroke:"#000","stroke-width":1}).classed("visual-cue",!0);var i=q(D?e.xanchor:a.midRange(r?[e.x0,e.x1]:f.extractPathCoords(e.path,h.paramIsX))),o=H(R?e.yanchor:a.midRange(r?[e.y0,e.y1]:f.extractPathCoords(e.path,h.paramIsY)));if(i=f.roundPositionForSharpStrokeRendering(i,1),o=f.roundPositionForSharpStrokeRendering(o,1),D&&R){var s="M"+(i-1-1)+","+(o-1-1)+"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z";n.attr("d",s)}else if(D){var l="M"+(i-1-1)+","+(o-9-1)+"v18 h2 v-18 Z";n.attr("d",l)}else{var c="M"+(i-9-1)+","+(o-1-1)+"h18 v2 h-18 Z";n.attr("d",c)}}()}function $(t){t.selectAll(".visual-cue").remove()}c.init(X),W.node().onmousemove=Z}(t,x,r,e,p)}}function d(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,"");s.setClipUrl(t,n?"clip"+e._fullLayout._uid+n:null,e)}function g(t,e){var r,n,o,s,l,c,u,p,d=e.type,g=i.getFromId(t,e.xref),v=i.getFromId(t,e.yref),m=t._fullLayout._size;if(g?(r=f.shapePositionToRange(g),n=function(t){return g._offset+g.r2p(r(t,!0))}):n=function(t){return m.l+m.w*t},v?(o=f.shapePositionToRange(v),s=function(t){return v._offset+v.r2p(o(t,!0))}):s=function(t){return m.t+m.h*(1-t)},"path"===d)return g&&"date"===g.type&&(n=f.decodeDate(n)),v&&"date"===v.type&&(s=f.decodeDate(s)),function(t,e,r){var n=t.path,i=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(h.segmentRE,function(t){var n=0,c=t.charAt(0),u=h.paramIsX[c],f=h.paramIsY[c],p=h.numParams[c],d=t.substr(1).replace(h.paramRE,function(t){return u[n]?t="pixel"===i?e(s)+Number(t):e(t):f[n]&&(t="pixel"===o?r(l)-Number(t):r(t)),++n>p&&(t="X"),t});return n>p&&(d=d.replace(/[\s,]*X.*/,""),a.log("Ignoring extra params in segment "+t)),c+d})}(e,n,s);if("pixel"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if("pixel"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,p=x-e.y1}else u=s(e.y0),p=s(e.y1);if("line"===d)return"M"+l+","+u+"L"+c+","+p;if("rect"===d)return"M"+l+","+u+"H"+c+"V"+p+"H"+l+"Z";var b=(l+c)/2,_=(u+p)/2,w=Math.abs(b-l),k=Math.abs(_-u),T="A"+w+","+k,A=b+w+","+_;return"M"+A+T+" 0 1,1 "+(b+","+(_-k))+T+" 0 0,1 "+A+"Z"}function v(t,e,r){return t.replace(h.segmentRE,function(t){var n=0,a=t.charAt(0),i=h.paramIsX[a],o=h.paramIsY[a],s=h.numParams[a];return a+t.substr(1).replace(h.paramRE,function(t){return n>=s?t:(i[n]?t=e(t):o[n]&&(t=r(t)),n++,t)})})}e.exports={draw:function(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll("path").remove(),e._shapeLowerLayer.selectAll("path").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll("path").remove()}for(var a=0;a<e.shapes.length;a++)e.shapes[a].visible&&p(t,a)},drawOne:p}},{"../../lib":716,"../../lib/setcursor":736,"../../plot_api/plot_template":754,"../../plots/cartesian/axes":764,"../../registry":845,"../color":591,"../dragelement":609,"../drawing":612,"./constants":668,"./helpers":671}],671:[function(t,e,r){"use strict";var n=t("./constants"),a=t("../../lib");r.rangeToShapePosition=function(t){return"log"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return"log"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace("_"," ")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(" ","_")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach(function(t){var i=e[t.charAt(0)].drawn;if(void 0!==i){var o=t.substr(1).match(n.paramRE);!o||o.length<i||r.push(a.cleanNumber(o[i]))}}),r},r.getDataToPixel=function(t,e,n){var a,i=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);a=function(t){return e._offset+e.r2p(o(t,!0))},"date"===e.type&&(a=r.decodeDate(a))}else a=n?function(t){return i.t+i.h*(1-t)}:function(t){return i.l+i.w*t};return a},r.getPixelToData=function(t,e,n){var a,i=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);a=function(t){return o(e.p2r(t-e._offset))}}else a=n?function(t){return 1-(t-i.t)/i.h}:function(t){return(t-i.l)/i.w};return a},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n}},{"../../lib":716,"./constants":668}],672:[function(t,e,r){"use strict";var n=t("./draw");e.exports={moduleType:"component",name:"shapes",layoutAttributes:t("./attributes"),supplyLayoutDefaults:t("./defaults"),includeBasePlot:t("../../plots/cartesian/include_components")("shapes"),calcAutorange:t("./calc_autorange"),draw:n.draw,drawOne:n.drawOne}},{"../../plots/cartesian/include_components":774,"./attributes":666,"./calc_autorange":667,"./defaults":669,"./draw":670}],673:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../../plots/pad_attributes"),i=t("../../lib/extend").extendDeepAll,o=t("../../plot_api/edit_types").overrideAll,s=t("../../plots/animation_attributes"),l=t("../../plot_api/plot_template").templatedArray,c=t("./constants"),u=l("step",{visible:{valType:"boolean",dflt:!0},method:{valType:"enumerated",values:["restyle","relayout","animate","update","skip"],dflt:"restyle"},args:{valType:"info_array",freeLength:!0,items:[{valType:"any"},{valType:"any"},{valType:"any"}]},label:{valType:"string"},value:{valType:"string"},execute:{valType:"boolean",dflt:!0}});e.exports=o(l("slider",{visible:{valType:"boolean",dflt:!0},active:{valType:"number",min:0,dflt:0},steps:u,lenmode:{valType:"enumerated",values:["fraction","pixels"],dflt:"fraction"},len:{valType:"number",min:0,dflt:1},x:{valType:"number",min:-2,max:3,dflt:0},pad:i(a({editType:"arraydraw"}),{},{t:{dflt:20}}),xanchor:{valType:"enumerated",values:["auto","left","center","right"],dflt:"left"},y:{valType:"number",min:-2,max:3,dflt:0},yanchor:{valType:"enumerated",values:["auto","top","middle","bottom"],dflt:"top"},transition:{duration:{valType:"number",min:0,dflt:150},easing:{valType:"enumerated",values:s.transition.easing.values,dflt:"cubic-in-out"}},currentvalue:{visible:{valType:"boolean",dflt:!0},xanchor:{valType:"enumerated",values:["left","center","right"],dflt:"left"},offset:{valType:"number",dflt:10},prefix:{valType:"string"},suffix:{valType:"string"},font:n({})},font:n({}),activebgcolor:{valType:"color",dflt:c.gripBgActiveColor},bgcolor:{valType:"color",dflt:c.railBgColor},bordercolor:{valType:"color",dflt:c.railBorderColor},borderwidth:{valType:"number",min:0,dflt:c.railBorderWidth},ticklen:{valType:"number",min:0,dflt:c.tickLength},tickcolor:{valType:"color",dflt:c.tickColor},tickwidth:{valType:"number",min:0,dflt:1},minorticklen:{valType:"number",min:0,dflt:c.minorTickLength}}),"arraydraw","from-root")},{"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plot_api/plot_template":754,"../../plots/animation_attributes":759,"../../plots/font_attributes":790,"../../plots/pad_attributes":824,"./constants":674}],674:[function(t,e,r){"use strict";e.exports={name:"sliders",containerClassName:"slider-container",groupClassName:"slider-group",inputAreaClass:"slider-input-area",railRectClass:"slider-rail-rect",railTouchRectClass:"slider-rail-touch-rect",gripRectClass:"slider-grip-rect",tickRectClass:"slider-tick-rect",inputProxyClass:"slider-input-proxy",labelsClass:"slider-labels",labelGroupClass:"slider-label-group",labelClass:"slider-label",currentValueClass:"slider-current-value",railHeight:5,menuIndexAttrName:"slider-active-index",autoMarginIdRoot:"slider-",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:"#bec8d9",railBgColor:"#f8fafc",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:"#bec8d9",gripBgColor:"#f6f8fa",gripBgActiveColor:"#dbdde0",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:"#333",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:"#333",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],675:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/array_container_defaults"),i=t("./attributes"),o=t("./constants").name,s=i.steps;function l(t,e,r){function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=a(t,e,{name:"steps",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o("visible")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o("active")]||{}).visible||(e.active=h[0]._index),o("x"),o("y"),n.noneOrAll(t,e,["x","y"]),o("xanchor"),o("yanchor"),o("len"),o("lenmode"),o("pad.t"),o("pad.r"),o("pad.b"),o("pad.l"),n.coerceFont(o,"font",r.font),o("currentvalue.visible")&&(o("currentvalue.xanchor"),o("currentvalue.prefix"),o("currentvalue.suffix"),o("currentvalue.offset"),n.coerceFont(o,"currentvalue.font",e.font)),o("transition.duration"),o("transition.easing"),o("bgcolor"),o("activebgcolor"),o("bordercolor"),o("borderwidth"),o("ticklen"),o("tickwidth"),o("tickcolor"),o("minorticklen")}}function c(t,e){function r(r,a){return n.coerce(t,e,s,r,a)}if("skip"===t.method||Array.isArray(t.args)?r("visible"):e.visible=!1){r("method"),r("args");var a=r("label","step-"+e._index);r("value",a),r("execute")}}e.exports=function(t,e){a(t,e,{name:o,handleItemDefaults:l})}},{"../../lib":716,"../../plots/array_container_defaults":760,"./attributes":673,"./constants":674}],676:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../plots/plots"),i=t("../color"),o=t("../drawing"),s=t("../../lib"),l=t("../../lib/svg_text_utils"),c=t("../../plot_api/plot_template").arrayEditor,u=t("./constants"),h=t("../../constants/alignment"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function v(t){return t._index}function m(t,e){var r=o.tester.selectAll("g."+u.labelGroupClass).data(e._visibleSteps);r.enter().append("g").classed(u.labelGroupClass,!0);var i=0,c=0;r.each(function(t){var r=b(n.select(this),{step:t},e).node();if(r){var a=o.bBox(r);c=Math.max(c,a.height),i=Math.max(i,a.width)}}),r.remove();var h=e._dims={};h.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var f=t._fullLayout._size;h.lx=f.l+f.w*e.x,h.ly=f.t+f.h*(1-e.y),"fraction"===e.lenmode?h.outerLength=Math.round(f.w*e.len):h.outerLength=e.len,h.inputAreaStart=0,h.inputAreaLength=Math.round(h.outerLength-e.pad.l-e.pad.r);var v=(h.inputAreaLength-2*u.stepInset)/(e._stepCount-1),m=i+u.labelPadding;if(h.labelStride=Math.max(1,Math.ceil(m/v)),h.labelHeight=c,h.currentValueMaxWidth=0,h.currentValueHeight=0,h.currentValueTotalHeight=0,h.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append("g");r.each(function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},a=l.lineCount(r);h.currentValueMaxWidth=Math.max(h.currentValueMaxWidth,Math.ceil(n.width)),h.currentValueHeight=Math.max(h.currentValueHeight,Math.ceil(n.height)),h.currentValueMaxLines=Math.max(h.currentValueMaxLines,a)}),h.currentValueTotalHeight=h.currentValueHeight+e.currentvalue.offset,x.remove()}h.height=h.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+h.labelHeight+e.pad.t+e.pad.b;var _="left";s.isRightAnchor(e)&&(h.lx-=h.outerLength,_="right"),s.isCenterAnchor(e)&&(h.lx-=h.outerLength/2,_="center");var w="top";s.isBottomAnchor(e)&&(h.ly-=h.height,w="bottom"),s.isMiddleAnchor(e)&&(h.ly-=h.height/2,w="middle"),h.outerLength=Math.ceil(h.outerLength),h.height=Math.ceil(h.height),h.lx=Math.round(h.lx),h.ly=Math.round(h.ly);var k={y:e.y,b:h.height*d[w],t:h.height*p[w]};"fraction"===e.lenmode?(k.l=0,k.xl=e.x-e.len*p[_],k.r=0,k.xr=e.x+e.len*d[_]):(k.x=e.x,k.l=h.outerLength*p[_],k.r=h.outerLength*d[_]),a.autoMargin(t,g(e),k)}function y(t,e,r){if(e.currentvalue.visible){var n,a,i=e._dims;switch(e.currentvalue.xanchor){case"right":n=i.inputAreaLength-u.currentValueInset-i.currentValueMaxWidth,a="left";break;case"center":n=.5*i.inputAreaLength,a="middle";break;default:n=u.currentValueInset,a="left"}var c=s.ensureSingle(t,"text",u.labelClass,function(t){t.classed("user-select-none",!0).attr({"text-anchor":a,"data-notex":1})}),h=e.currentvalue.prefix?e.currentvalue.prefix:"";if("string"==typeof r)h+=r;else{var p=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(p=s.templateString(p,d)),h+=p}e.currentvalue.suffix&&(h+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(h).call(l.convertToTspans,e._gd);var g=l.lineCount(c),v=(i.currentValueMaxLines+1-g)*e.currentvalue.font.size*f;return l.positionText(c,n,v),c}}function x(t,e,r){s.ensureSingle(t,"rect",u.gripRectClass,function(n){n.call(T,e,t,r).style("pointer-events","all")}).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(i.stroke,r.bordercolor).call(i.fill,r.bgcolor).style("stroke-width",r.borderwidth+"px")}function b(t,e,r){var n=s.ensureSingle(t,"text",u.labelClass,function(t){t.classed("user-select-none",!0).attr({"text-anchor":"middle","data-notex":1})}),a=e.step.label,i=r._gd._fullLayout._meta;return i&&(a=s.templateString(a,i)),n.call(o.font,r.font).text(a).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,"g",u.labelsClass),a=e._dims,i=r.selectAll("g."+u.labelGroupClass).data(a.labelSteps);i.enter().append("g").classed(u.labelGroupClass,!0),i.exit().remove(),i.each(function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*f+u.labelOffset+a.currentValueTotalHeight)})}function w(t,e,r,n,a){var i=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[i]._index;o!==r.active&&k(t,e,r,o,!0,a)}function k(t,e,r,n,i,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate("active",n);var l=r.steps[r.active];e.call(M,r,o),e.call(y,r),t.emit("plotly_sliderchange",{slider:r,step:r.steps[r.active],interaction:i,previousActive:s}),l&&l.method&&i&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=i,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:i,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame(function(){var r=e._nextMethod.step;r.method&&(r.execute&&a.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)})))}function T(t,e,r){var a=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on("mousedown",function(){var t=s();e.emit("plotly_sliderstart",{slider:t});var l=r.select("."+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(i.fill,t.activebgcolor);var c=E(t,n.mouse(a)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on("mousemove",function(){var t=s(),i=E(t,n.mouse(a)[0]);w(e,r,t,i,!1)}),o.on("mouseup",function(){var t=s();t._dragging=!1,l.call(i.fill,t.bgcolor),o.on("mouseup",null),o.on("mousemove",null),e.emit("plotly_sliderend",{slider:t,step:t.steps[t.active]})})})}function A(t,e){var r=t.selectAll("rect."+u.tickRectClass).data(e._visibleSteps),a=e._dims;r.enter().append("rect").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+"px","shape-rendering":"crispEdges"}),r.each(function(t,r){var s=r%a.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(i.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+a.currentValueTotalHeight)})}function M(t,e,r){for(var n=t.select("rect."+u.gripRectClass),a=0,i=0;i<e._stepCount;i++)if(e._visibleSteps[i]._index===e.active){a=i;break}var o=S(e,a/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr("transform","translate("+(o-.5*u.gripWidth)+","+e._dims.currentValueTotalHeight+")")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function E(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function L(t,e,r){var n=r._dims,a=s.ensureSingle(t,"rect",u.railTouchRectClass,function(n){n.call(T,e,t,r).style("pointer-events","all")});a.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(i.fill,r.bgcolor).attr("opacity",0),o.setTranslate(a,0,n.currentValueTotalHeight)}function C(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,a=s.ensureSingle(t,"rect",u.railRectClass);a.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,"shape-rendering":"crispEdges"}).call(i.stroke,e.bordercolor).call(i.fill,e.bgcolor).style("stroke-width",e.borderwidth+"px"),o.setTranslate(a,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],a=0;a<r.length;a++){var i=r[a];i.visible&&(i._gd=e,n.push(i))}return n}(e,t),i=e._infolayer.selectAll("g."+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),a.autoMargin(t,g(e))}if(i.enter().append("g").classed(u.containerClassName,!0).style("cursor","ew-resize"),i.exit().each(function(){n.select(this).selectAll("g."+u.groupClassName).each(s)}).remove(),0!==r.length){var l=i.selectAll("g."+u.groupClassName).data(r,v);l.enter().append("g").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var h=r[c];m(t,h)}l.each(function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),a.manageCommandObserver(t,e,e._visibleSteps,function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))}),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(C,r).call(_,r).call(A,r).call(L,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(M,r,!1),e.call(y,r)}(t,n.select(this),e)})}}},{"../../constants/alignment":685,"../../lib":716,"../../lib/svg_text_utils":740,"../../plot_api/plot_template":754,"../../plots/plots":825,"../color":591,"../drawing":612,"./constants":674,d3:164}],677:[function(t,e,r){"use strict";var n=t("./constants");e.exports={moduleType:"component",name:n.name,layoutAttributes:t("./attributes"),supplyLayoutDefaults:t("./defaults"),draw:t("./draw")}},{"./attributes":673,"./constants":674,"./defaults":675,"./draw":676}],678:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../plots/plots"),o=t("../../registry"),s=t("../../lib"),l=t("../drawing"),c=t("../color"),u=t("../../lib/svg_text_utils"),h=t("../../constants/interactions"),f=t("../../constants/alignment").OPPOSITE_SIDE,p=/ [XY][0-9]* /;e.exports={draw:function(t,e,r){var d,g=r.propContainer,v=r.propName,m=r.placeholder,y=r.traceIndex,x=r.avoid||{},b=r.attributes,_=r.transform,w=r.containerGroup,k=t._fullLayout,T=1,A=!1,M=g.title,S=(M&&M.text?M.text:"").trim(),E=M&&M.font?M.font:{},L=E.family,C=E.size,P=E.color;"title.text"===v?d="titleText":-1!==v.indexOf("axis")?d="axisTitleText":v.indexOf(!0)&&(d="colorbarTitleText");var O=t._context.edits[d];""===S?T=0:S.replace(p," % ")===m.replace(p," % ")&&(T=.2,A=!0,O||(S="")),r._meta?S=s.templateString(S,r._meta):k._meta&&(S=s.templateString(S,k._meta));var z=S||O;w||(w=s.ensureSingle(k._infolayer,"g","g-"+e));var I=w.selectAll("text").data(z?[0]:[]);if(I.enter().append("text"),I.text(S).attr("class",e),I.exit().remove(),!z)return w;function D(t){s.syncOrAsync([R,F],t)}function R(e){var r;return _?(r="",_.rotate&&(r+="rotate("+[_.rotate,b.x,b.y]+")"),_.offset&&(r+="translate(0, "+_.offset+")")):r=null,e.attr("transform",r),e.style({"font-family":L,"font-size":n.round(C,2)+"px",fill:c.rgb(P),opacity:T*c.opacity(P),"font-weight":i.fontWeight}).attr(b).call(u.convertToTspans,t),i.previousPromises(t)}function F(t){var e=n.select(t.node().parentNode);if(x&&x.selection&&x.side&&S){e.attr("transform",null);var r=f[x.side],i="left"===x.side||"top"===x.side?-1:1,o=a(x.pad)?x.pad:2,c=l.bBox(e.node()),u={left:0,top:0,right:k.width,bottom:k.height},h=x.maxShift||i*(u[x.side]-c[x.side]),p=0;if(h<0)p=h;else{var d=x.offsetLeft||0,g=x.offsetTop||0;c.left-=d,c.right-=d,c.top-=g,c.bottom-=g,x.selection.each(function(){var t=l.bBox(this);s.bBoxIntersect(c,t,o)&&(p=Math.max(p,i*(t[x.side]-c[r])+o))}),p=Math.min(h,p)}if(p>0||h<0){var v={left:[-p,0],right:[p,0],top:[0,-p],bottom:[0,p]}[x.side];e.attr("transform","translate("+v+")")}}}return I.call(D),O&&(S?I.on(".opacity",null):(T=0,A=!0,I.text(m).on("mouseover.opacity",function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style("opacity",1)}).on("mouseout.opacity",function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style("opacity",0)})),I.call(u.makeEditable,{gd:t}).on("edit",function(e){void 0!==y?o.call("_guiRestyle",t,v,e,y):o.call("_guiRelayout",t,v,e)}).on("cancel",function(){this.text(this.attr("data-unformatted")).call(D)}).on("input",function(t){this.text(t||" ").call(u.positionText,b.x,b.y)})),I.classed("js-placeholder",A),w}}},{"../../constants/alignment":685,"../../constants/interactions":691,"../../lib":716,"../../lib/svg_text_utils":740,"../../plots/plots":825,"../../registry":845,"../color":591,"../drawing":612,d3:164,"fast-isnumeric":227}],679:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../color/attributes"),i=t("../../lib/extend").extendFlat,o=t("../../plot_api/edit_types").overrideAll,s=t("../../plots/pad_attributes"),l=t("../../plot_api/plot_template").templatedArray,c=l("button",{visible:{valType:"boolean"},method:{valType:"enumerated",values:["restyle","relayout","animate","update","skip"],dflt:"restyle"},args:{valType:"info_array",freeLength:!0,items:[{valType:"any"},{valType:"any"},{valType:"any"}]},args2:{valType:"info_array",freeLength:!0,items:[{valType:"any"},{valType:"any"},{valType:"any"}]},label:{valType:"string",dflt:""},execute:{valType:"boolean",dflt:!0}});e.exports=o(l("updatemenu",{_arrayAttrRegexps:[/^updatemenus\[(0|[1-9][0-9]+)\]\.buttons/],visible:{valType:"boolean"},type:{valType:"enumerated",values:["dropdown","buttons"],dflt:"dropdown"},direction:{valType:"enumerated",values:["left","right","up","down"],dflt:"down"},active:{valType:"integer",min:-1,dflt:0},showactive:{valType:"boolean",dflt:!0},buttons:c,x:{valType:"number",min:-2,max:3,dflt:-.05},xanchor:{valType:"enumerated",values:["auto","left","center","right"],dflt:"right"},y:{valType:"number",min:-2,max:3,dflt:1},yanchor:{valType:"enumerated",values:["auto","top","middle","bottom"],dflt:"top"},pad:i(s({editType:"arraydraw"}),{}),font:n({}),bgcolor:{valType:"color"},bordercolor:{valType:"color",dflt:a.borderLine},borderwidth:{valType:"number",min:0,dflt:1,editType:"arraydraw"}}),"arraydraw","from-root")},{"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plot_api/plot_template":754,"../../plots/font_attributes":790,"../../plots/pad_attributes":824,"../color/attributes":590}],680:[function(t,e,r){"use strict";e.exports={name:"updatemenus",containerClassName:"updatemenu-container",headerGroupClassName:"updatemenu-header-group",headerClassName:"updatemenu-header",headerArrowClassName:"updatemenu-header-arrow",dropdownButtonGroupClassName:"updatemenu-dropdown-button-group",dropdownButtonClassName:"updatemenu-dropdown-button",buttonClassName:"updatemenu-button",itemRectClassName:"updatemenu-item-rect",itemTextClassName:"updatemenu-item-text",menuIndexAttrName:"updatemenu-active-index",autoMarginIdRoot:"updatemenu-",blankHeaderOpts:{label:"  "},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:"#F4FAFF",hoverColor:"#F4FAFF",arrowSymbol:{left:"\u25c4",right:"\u25ba",up:"\u25b2",down:"\u25bc"}}},{}],681:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/array_container_defaults"),i=t("./attributes"),o=t("./constants").name,s=i.buttons;function l(t,e,r){function o(r,a){return n.coerce(t,e,i,r,a)}o("visible",a(t,e,{name:"buttons",handleItemDefaults:c}).length>0)&&(o("active"),o("direction"),o("type"),o("showactive"),o("x"),o("y"),n.noneOrAll(t,e,["x","y"]),o("xanchor"),o("yanchor"),o("pad.t"),o("pad.r"),o("pad.b"),o("pad.l"),n.coerceFont(o,"font",r.font),o("bgcolor",r.paper_bgcolor),o("bordercolor"),o("borderwidth"))}function c(t,e){function r(r,a){return n.coerce(t,e,s,r,a)}r("visible","skip"===t.method||Array.isArray(t.args))&&(r("method"),r("args"),r("args2"),r("label"),r("execute"))}e.exports=function(t,e){a(t,e,{name:o,handleItemDefaults:l})}},{"../../lib":716,"../../plots/array_container_defaults":760,"./attributes":679,"./constants":680}],682:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../plots/plots"),i=t("../color"),o=t("../drawing"),s=t("../../lib"),l=t("../../lib/svg_text_utils"),c=t("../../plot_api/plot_template").arrayEditor,u=t("../../constants/alignment").LINE_SPACING,h=t("./constants"),f=t("./scrollbox");function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function g(t,e,r,n,a,i,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate("active",o),"buttons"===e.type?m(t,n,null,null,e):"dropdown"===e.type&&(a.attr(h.menuIndexAttrName,"-1"),v(t,n,a,i,e),s||m(t,n,a,i,e))}function v(t,e,r,n,a){var i=s.ensureSingle(e,"g",h.headerClassName,function(t){t.style("pointer-events","all")}),l=a._dims,c=a.active,u=a.buttons[c]||h.blankHeaderOpts,f={y:a.pad.t,yPad:0,x:a.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};i.call(y,a,u,t).call(M,a,f,p),s.ensureSingle(e,"text",h.headerArrowClassName,function(t){t.classed("user-select-none",!0).attr("text-anchor","end").call(o.font,a.font).text(h.arrowSymbol[a.direction])}).attr({x:l.headerWidth-h.arrowOffsetX+a.pad.l,y:l.headerHeight/2+h.textOffsetY+a.pad.t}),i.on("click",function(){r.call(S,String(d(r,a)?-1:a._index)),m(t,e,r,n,a)}),i.on("mouseover",function(){i.call(w)}),i.on("mouseout",function(){i.call(k,a)}),o.setTranslate(e,l.lx,l.ly)}function m(t,e,r,i,o){r||(r=e).attr("pointer-events","all");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&"buttons"!==o.type?[]:o.buttons,c="dropdown"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll("g."+c).data(s.filterVisible(l)),f=u.enter().append("g").classed(c,!0),p=u.exit();"dropdown"===o.type?(f.attr("opacity","0").transition().attr("opacity","1"),p.transition().attr("opacity","0").remove()):p.remove();var d=0,v=0,m=o._dims,x=-1!==["up","down"].indexOf(o.direction);"dropdown"===o.type&&(x?v=m.headerHeight+h.gapButtonHeader:d=m.headerWidth+h.gapButtonHeader),"dropdown"===o.type&&"up"===o.direction&&(v=-h.gapButtonHeader+h.gapButton-m.openHeight),"dropdown"===o.type&&"left"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-m.openWidth);var b={x:m.lx+d+o.pad.l,y:m.ly+v+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},T={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each(function(s,l){var c=n.select(this);c.call(y,o,s,t).call(M,o,b),c.on("click",function(){n.event.defaultPrevented||(s.execute&&(s.args2&&o.active===l?(g(t,o,0,e,r,i,-1),a.executeAPICommand(t,s.method,s.args2)):(g(t,o,0,e,r,i,l),a.executeAPICommand(t,s.method,s.args))),t.emit("plotly_buttonclicked",{menu:o,button:s,active:o.active}))}),c.on("mouseover",function(){c.call(w)}),c.on("mouseout",function(){c.call(k,o),u.call(_,o)})}),u.call(_,o),x?(T.w=Math.max(m.openWidth,m.headerWidth),T.h=b.y-T.t):(T.w=b.x-T.l,T.h=Math.max(m.openHeight,m.headerHeight)),T.direction=o.direction,i&&(u.size()?function(t,e,r,n,a,i){var o,s,l,c=a.direction,u="up"===c||"down"===c,f=a._dims,p=a.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(i,o,s),n.hbar&&n.hbar.attr("opacity","0").transition().attr("opacity","1");n.vbar&&n.vbar.attr("opacity","0").transition().attr("opacity","1")}(0,0,0,i,o,T):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr("opacity","0").each("end",function(){e=!1,r||t.disable()});r&&t.vbar.transition().attr("opacity","0").each("end",function(){r=!1,e||t.disable()})}(i))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,"rect",h.itemRectClassName,function(t){t.attr({rx:h.rx,ry:h.ry,"shape-rendering":"crispEdges"})}).call(i.stroke,e.bordercolor).call(i.fill,e.bgcolor).style("stroke-width",e.borderwidth+"px")}function b(t,e,r,n){var a=s.ensureSingle(t,"text",h.itemTextClassName,function(t){t.classed("user-select-none",!0).attr({"text-anchor":"start","data-notex":1})}),i=r.label,c=n._fullLayout._meta;c&&(i=s.templateString(i,c)),a.call(o.font,e.font).text(i).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each(function(t,a){var o=n.select(this);a===r&&e.showactive&&o.select("rect."+h.itemRectClassName).call(i.fill,h.activeColor)})}function w(t){t.select("rect."+h.itemRectClassName).call(i.fill,h.hoverColor)}function k(t,e){t.select("rect."+h.itemRectClassName).call(i.fill,e.bgcolor)}function T(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},i=o.tester.selectAll("g."+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));i.enter().append("g").classed(h.dropdownButtonClassName,!0);var c=-1!==["up","down"].indexOf(e.direction);i.each(function(a,i){var s=n.select(this);s.call(y,e,a,t);var f=s.select("."+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),g=e.font.size*u,v=l.lineCount(f),m=Math.max(g*v,h.minHeight)+h.textOffsetY;m=Math.ceil(m),d=Math.ceil(d),r.widths[i]=d,r.heights[i]=m,r.height1=Math.max(r.height1,m),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=m+h.gapButton,r.openHeight+=m+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,m),r.openHeight=r.totalHeight)}),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,"dropdown"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),i.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g="left";s.isRightAnchor(e)&&(r.lx-=f,g="right"),s.isCenterAnchor(e)&&(r.lx-=f/2,g="center");var v="top";s.isBottomAnchor(e)&&(r.ly-=p,v="bottom"),s.isMiddleAnchor(e)&&(r.ly-=p/2,v="middle"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),a.autoMargin(t,A(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[g]||0),r:f*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[v]||0),t:p*({bottom:1,middle:.5}[v]||0)})}function A(t){return h.autoMarginIdRoot+t._index}function M(t,e,r,n){n=n||{};var a=t.select("."+h.itemRectClassName),i=t.select("."+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==["up","down"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);a.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var g=e.font.size*u,v=(l.lineCount(i)-1)*g/2;l.positionText(i,h.textOffsetX,d/2-v+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||"-1").selectAll("g."+h.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function i(e){a.autoMargin(t,A(e))}var o=e._menulayer.selectAll("g."+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append("g").classed(h.containerClassName,!0).style("cursor","pointer"),o.exit().each(function(){n.select(this).selectAll("g."+h.headerGroupClassName).each(i)}).remove(),0!==r.length){var l=o.selectAll("g."+h.headerGroupClassName).data(r,p);l.enter().append("g").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,"g",h.dropdownButtonGroupClassName,function(t){t.style("pointer-events","all")}),u=0;u<r.length;u++){var y=r[u];T(t,y)}var x="updatemenus"+e._uid,b=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each(function(t){c.call(S),i(t)}).remove(),l.each(function(e){var r=n.select(this),i="dropdown"===e.type?c:null;a.manageCommandObserver(t,e,e.buttons,function(n){g(t,e,e.buttons[n.index],r,i,b,n.index,!0)}),"dropdown"===e.type?(v(t,r,c,b,e),d(c,e)&&m(t,r,c,b,e)):m(t,r,null,null,e)})}}},{"../../constants/alignment":685,"../../lib":716,"../../lib/svg_text_utils":740,"../../plot_api/plot_template":754,"../../plots/plots":825,"../color":591,"../drawing":612,"./constants":680,"./scrollbox":684,d3:164}],683:[function(t,e,r){arguments[4][677][0].apply(r,arguments)},{"./attributes":679,"./constants":680,"./defaults":681,"./draw":682,dup:677}],684:[function(t,e,r){"use strict";e.exports=s;var n=t("d3"),a=t("../color"),i=t("../drawing"),o=t("../../lib");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll("rect.scrollbox-bg").data([0]),this.bg.exit().on(".drag",null).on("wheel",null).remove(),this.bg.enter().append("rect").classed("scrollbox-bg",!0).style("pointer-events","all").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor="#808BA4",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,g=this.position.w,v=this.position.t,m=this.position.h,y=this.position.direction,x="down"===y,b="left"===y,_="up"===y,w=g,k=m;x||b||"right"===y||_||(this.position.direction="down",x=!0),x||_?(h=(u=d)+w,x?(f=v,k=(p=Math.min(f+k,c))-f):k=(p=v+k)-(f=Math.max(p-k,0))):(p=(f=v)+k,b?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:k};var T=g>w,A=s.barLength+2*s.barPad,M=s.barWidth+2*s.barPad,S=d,E=v+m;E+M>c&&(E=c-M);var L=this.container.selectAll("rect.scrollbar-horizontal").data(T?[0]:[]);L.exit().on(".drag",null).remove(),L.enter().append("rect").classed("scrollbar-horizontal",!0).call(a.fill,s.barColor),T?(this.hbar=L.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:A,height:M}),this._hbarXMin=S+A/2,this._hbarTranslateMax=w-A):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var C=m>k,P=s.barWidth+2*s.barPad,O=s.barLength+2*s.barPad,z=d+g,I=v;z+P>l&&(z=l-P);var D=this.container.selectAll("rect.scrollbar-vertical").data(C?[0]:[]);D.exit().on(".drag",null).remove(),D.enter().append("rect").classed("scrollbar-vertical",!0).call(a.fill,s.barColor),C?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:I,width:P,height:O}),this._vbarYMin=I+O/2,this._vbarTranslateMax=k-O):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=C?h+P+.5:h+.5,N=f-.5,j=T?p+M+.5:p+.5,V=o._topdefs.selectAll("#"+R).data(T||C?[0]:[]);if(V.exit().remove(),V.enter().append("clipPath").attr("id",R).append("rect"),T||C?(this._clipRect=V.select("rect").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(i.setClipUrl,R,this.gd),this.bg.attr({x:d,y:v,width:g,height:m})):(this.bg.attr({width:0,height:0}),this.container.on("wheel",null).on(".drag",null).call(i.setClipUrl,null),delete this._clipRect),T||C){var U=n.behavior.drag().on("dragstart",function(){n.event.sourceEvent.preventDefault()}).on("drag",this._onBoxDrag.bind(this));this.container.on("wheel",null).on("wheel",this._onBoxWheel.bind(this)).on(".drag",null).call(U);var q=n.behavior.drag().on("dragstart",function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()}).on("drag",this._onBarDrag.bind(this));T&&this.hbar.on(".drag",null).call(q),C&&this.vbar.on(".drag",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on("wheel",null).on(".drag",null).call(i.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(".drag",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(".drag",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,a=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,a)-r)/(a-r)*(this.position.w-this._box.w)}if(this.vbar){var i=e+this._vbarYMin,s=i+this._vbarTranslateMax;e=(o.constrain(n.event.y,i,s)-i)/(s-i)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(i.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var a=t/r;this.hbar.call(i.setTranslate,t+a*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(i.setTranslate,t,e+s*this._vbarTranslateMax)}}},{"../../lib":716,"../color":591,"../drawing":612,d3:164}],685:[function(t,e,r){"use strict";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:"right",right:"left",top:"bottom",bottom:"top"}}},{}],686:[function(t,e,r){"use strict";e.exports={INCREASING:{COLOR:"#3D9970",SYMBOL:"\u25b2"},DECREASING:{COLOR:"#FF4136",SYMBOL:"\u25bc"}}},{}],687:[function(t,e,r){"use strict";e.exports={FORMAT_LINK:"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format",DATE_FORMAT_LINK:"https://github.com/d3/d3-3.x-api-reference/blob/master/Time-Formatting.md#format"}},{}],688:[function(t,e,r){"use strict";e.exports={COMPARISON_OPS:["=","!=","<",">=",">","<="],COMPARISON_OPS2:["=","<",">=",">","<="],INTERVAL_OPS:["[]","()","[)","(]","][",")(","](",")["],SET_OPS:["{}","}{"],CONSTRAINT_REDUCTION:{"=":"=","<":"<","<=":"<",">":">",">=":">","[]":"[]","()":"[]","[)":"[]","(]":"[]","][":"][",")(":"][","](":"][",")[":"]["}}},{}],689:[function(t,e,r){"use strict";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],690:[function(t,e,r){"use strict";e.exports={circle:"\u25cf","circle-open":"\u25cb",square:"\u25a0","square-open":"\u25a1",diamond:"\u25c6","diamond-open":"\u25c7",cross:"+",x:"\u274c"}},{}],691:[function(t,e,r){"use strict";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],692:[function(t,e,r){"use strict";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEAVGYEAR:315576e5,ONEAVGMONTH:26298e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:1-1e-6,LOG_CLIP:10,MINUS_SIGN:"\u2212"}},{}],693:[function(t,e,r){"use strict";r.xmlns="http://www.w3.org/2000/xmlns/",r.svg="http://www.w3.org/2000/svg",r.xlink="http://www.w3.org/1999/xlink",r.svgAttrs={xmlns:r.svg,"xmlns:xlink":r.xlink}},{}],694:[function(t,e,r){"use strict";r.version="1.51.2",t("es6-promise").polyfill(),t("../build/plotcss"),t("./fonts/mathjax_config")();for(var n=t("./registry"),a=r.register=n.register,i=t("./plot_api"),o=Object.keys(i),s=0;s<o.length;s++){var l=o[s];"_"!==l.charAt(0)&&(r[l]=i[l]),a({moduleType:"apiMethod",name:l,fn:i[l]})}a(t("./traces/scatter")),a([t("./components/fx"),t("./components/legend"),t("./components/annotations"),t("./components/annotations3d"),t("./components/shapes"),t("./components/images"),t("./components/updatemenus"),t("./components/sliders"),t("./components/rangeslider"),t("./components/rangeselector"),t("./components/grid"),t("./components/errorbars"),t("./components/colorscale"),t("./components/colorbar")]),a([t("./locale-en"),t("./locale-en-us")]),r.Icons=t("./fonts/ploticon"),r.Plots=t("./plots/plots"),r.Fx=t("./components/fx"),r.Snapshot=t("./snapshot"),r.PlotSchema=t("./plot_api/plot_schema"),r.Queue=t("./lib/queue"),r.d3=t("d3")},{"../build/plotcss":1,"./components/annotations":582,"./components/annotations3d":587,"./components/colorbar":597,"./components/colorscale":603,"./components/errorbars":618,"./components/fx":629,"./components/grid":633,"./components/images":638,"./components/legend":646,"./components/rangeselector":657,"./components/rangeslider":664,"./components/shapes":672,"./components/sliders":677,"./components/updatemenus":683,"./fonts/mathjax_config":695,"./fonts/ploticon":696,"./lib/queue":731,"./locale-en":745,"./locale-en-us":744,"./plot_api":749,"./plot_api/plot_schema":753,"./plots/plots":825,"./registry":845,"./snapshot":850,"./traces/scatter":1130,d3:164,"es6-promise":220}],695:[function(t,e,r){"use strict";e.exports=function(){"undefined"!=typeof MathJax&&("local"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:"none",skipStartupTypeset:!0,displayAlign:"left",tex2jax:{inlineMath:[["$","$"],["\\(","\\)"]]}}),MathJax.Hub.Configured()))}},{}],696:[function(t,e,r){"use strict";e.exports={undo:{width:857.1,height:1e3,path:"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z",transform:"matrix(1 0 0 -1 0 850)"},home:{width:928.6,height:1e3,path:"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z",transform:"matrix(1 0 0 -1 0 850)"},"camera-retro":{width:1e3,height:1e3,path:"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z",transform:"matrix(1 0 0 -1 0 850)"},zoombox:{width:1e3,height:1e3,path:"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z",transform:"matrix(1 0 0 -1 0 850)"},pan:{width:1e3,height:1e3,path:"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z",transform:"matrix(1 0 0 -1 0 850)"},zoom_plus:{width:875,height:1e3,path:"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z",transform:"matrix(1 0 0 -1 0 850)"},zoom_minus:{width:875,height:1e3,path:"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z",transform:"matrix(1 0 0 -1 0 850)"},autoscale:{width:1e3,height:1e3,path:"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z",transform:"matrix(1 0 0 -1 0 850)"},tooltip_basic:{width:1500,height:1e3,path:"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z",transform:"matrix(1 0 0 -1 0 850)"},tooltip_compare:{width:1125,height:1e3,path:"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z",transform:"matrix(1 0 0 -1 0 850)"},plotlylogo:{width:1542,height:1e3,path:"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z",transform:"matrix(1 0 0 -1 0 850)"},"z-axis":{width:1e3,height:1e3,path:"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z",transform:"matrix(1 0 0 -1 0 850)"},"3d_rotate":{width:1e3,height:1e3,path:"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z",transform:"matrix(1 0 0 -1 0 850)"},camera:{width:1e3,height:1e3,path:"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z",transform:"matrix(1 0 0 -1 0 850)"},movie:{width:1e3,height:1e3,path:"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z",transform:"matrix(1 0 0 -1 0 850)"},question:{width:857.1,height:1e3,path:"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z",transform:"matrix(1 0 0 -1 0 850)"},disk:{width:857.1,height:1e3,path:"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z",transform:"matrix(1 0 0 -1 0 850)"},lasso:{width:1031,height:1e3,path:"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z",transform:"matrix(1 0 0 -1 0 850)"},selectbox:{width:1e3,height:1e3,path:"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z",transform:"matrix(1 0 0 -1 0 850)"},spikeline:{width:1e3,height:1e3,path:"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z",transform:"matrix(1.5 0 0 -1.5 0 850)"},pencil:{width:1792,height:1792,path:"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z",transform:"matrix(1 0 0 1 0 1)"},newplotlylogo:{name:"newplotlylogo",svg:"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #119dff;} .cls-2 {fill: #25fefd;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>"}}},{}],697:[function(t,e,r){"use strict";r.isLeftAnchor=function(t){return"left"===t.xanchor||"auto"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return"center"===t.xanchor||"auto"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return"right"===t.xanchor||"auto"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return"top"===t.yanchor||"auto"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return"middle"===t.yanchor||"auto"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return"bottom"===t.yanchor||"auto"===t.yanchor&&t.y<=1/3}},{}],698:[function(t,e,r){"use strict";var n=t("./mod"),a=n.mod,i=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return i(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=a(r,s))>(n=a(n,s))&&(n+=s);var i=a(t,s),o=i+s;return i>=r&&i<=n||o>=r&&o<=n}function h(t,e,r,n,a,i,c){a=a||0,i=i||0;var u,h,f,p,d,g=l([r,n]);function v(t,e){return[t*Math.cos(e)+a,i-t*Math.sin(e)]}g?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var m,y=Math.abs(f-u)<=o?0:1;function x(t,e,r){return"A"+[t,t]+" "+[0,y,r]+" "+v(t,e)}return g?m=null===p?"M"+v(d,u)+x(d,h,0)+x(d,f,0)+"Z":"M"+v(p,u)+x(p,h,0)+x(p,f,0)+"ZM"+v(d,u)+x(d,h,1)+x(d,f,1)+"Z":null===p?(m="M"+v(d,u)+x(d,f,0),c&&(m+="L0,0Z")):m="M"+v(p,u)+"L"+v(d,u)+x(d,f,0)+"L"+v(p,f)+x(p,u,1)+"Z",m}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(a=r[0],i=r[1]):(a=r[1],i=r[0]),t>=a&&t<=i);var a,i},pathArc:function(t,e,r,n,a){return h(null,t,e,r,n,a,0)},pathSector:function(t,e,r,n,a){return h(null,t,e,r,n,a,1)},pathAnnulus:function(t,e,r,n,a,i){return h(t,e,r,n,a,i,1)}}},{"./mod":723}],699:[function(t,e,r){"use strict";var n=Array.isArray,a="undefined"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},i="undefined"==typeof DataView?function(){}:DataView;function o(t){return a.isView(t)&&!(t instanceof i)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,a=0;a<t.length;a++)n=e(n,t[a].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,a,i,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(a=arguments[r]).length)&&(e?c.push(a):(e=a,i=o),n(a)?t=!1:(u=!1,h?t!==a.constructor&&(t=!1):t=a.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)a=c[r],s.set(a,i),i+=a.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(a=c[r],l=0;l<a.length;l++)s[i+l]=a[l];i+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],700:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../constants/numerical").BADNUM,i=/^['"%,$#\s']+|[, ]|['"%,$#\s']+$/g;e.exports=function(t){return"string"==typeof t&&(t=t.replace(i,"")),n(t)?Number(t):a}},{"../constants/numerical":692,"fast-isnumeric":227}],701:[function(t,e,r){"use strict";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each(function(t){t.regl&&t.regl.clear({color:!0,depth:!0})})}},{}],702:[function(t,e,r){"use strict";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener("resize",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],703:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("tinycolor2"),i=t("../plots/attributes"),o=t("../components/colorscale/scales"),s=t("../constants/interactions").DESELECTDIM,l=t("./nested_property"),c=t("./regex").counter,u=t("./mod").modHalf,h=t("./array").isArrayOrTypedArray;function f(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var a={},i=a,o={set:function(t){i=t}};return n.coerceFunction(t,o,a,e),i!==a}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var a=String(r[n]);if("/"===a.charAt(0)&&"/"===a.charAt(a.length-1)){if(new RegExp(a.substr(1,a.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,a){!n(t)||void 0!==a.min&&t<a.min||void 0!==a.max&&t>a.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,a){t%1||!n(t)||void 0!==a.min&&t<a.min||void 0!==a.max&&t>a.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if("string"!=typeof t){var a="number"==typeof t;!0!==n.strict&&a?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){a(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every(function(t){return a(t).isValid()})?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){"auto"===t?e.set("auto"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var a=n.regex||c(r);"string"==typeof t&&a.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||"string"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if("string"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var a=t.split("+"),i=0;i<a.length;){var o=a[i];-1===n.flags.indexOf(o)||a.indexOf(o)<i?a.splice(i,1):i++}a.length?e.set(a.join("+")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,a){function i(t,e,n){var a,i={set:function(t){a=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,i,n,e),a}var o=2===a.dimensions||"1-2"===a.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,h,f,p=a.items,d=[],g=Array.isArray(p),v=g&&o&&Array.isArray(p[0]),m=o&&g&&!v,y=g&&!m?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],h=m?p.length:g?p[s].length:c.length,l=0;l<h;l++)u=m?p[l]:g?p[s][l]:p,void 0!==(f=i(c[l],u,(n[s]||[])[l]))&&(d[s][l]=f);else for(s=0;s<y;s++)void 0!==(f=i(t[s],g?p[s]:p,n[s]))&&(d[s]=f);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),a=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var i=0;i<t.length;i++)if(a){if(!Array.isArray(t[i])||!e.freeLength&&t[i].length!==r[i].length)return!1;for(var o=0;o<t[i].length;o++)if(!f(t[i][o],n?r[i][o]:r))return!1}else if(!f(t[i],n?r[i]:r))return!1;return!0}}},r.coerce=function(t,e,n,a,i){var o=l(n,a).get(),s=l(t,a),c=l(e,a),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,a).get(),p=0),void 0===i&&(i=o.dflt),o.arrayOk&&h(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,i,o);var g=c.get();return p&&g===i&&!f(u,o)&&(d(u=l(p,a).get(),c,i,o),g=c.get()),g},r.coerce2=function(t,e,n,a,i){var o=l(t,a),s=r.coerce(t,e,n,a,i),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+".family",r.family),n.size=t(e+".size",r.size),n.color=t(e+".color",r.color),n},r.coerceHoverinfo=function(t,e,n){var a,o=e._module.attributes,s=o.hoverinfo?o:i,l=s.hoverinfo;if(1===n._dataLength){var c="all"===l.dflt?l.flags.slice():l.dflt.split("+");c.splice(c.indexOf("name"),1),a=c.join("+")}return r.coerce(t,e,s,"hoverinfo",a)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,a=t.marker.opacity;if(void 0!==a)h(a)||t.selected||t.unselected||(r=a,n=s*a),e("selected.marker.opacity",r),e("unselected.marker.opacity",n)}},r.validate=f},{"../components/colorscale/scales":606,"../constants/interactions":691,"../plots/attributes":761,"./array":699,"./mod":723,"./nested_property":724,"./regex":732,"fast-isnumeric":227,tinycolor2:535}],704:[function(t,e,r){"use strict";var n,a,i=t("d3"),o=t("fast-isnumeric"),s=t("./loggers"),l=t("./mod").mod,c=t("../constants/numerical"),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,v=t("../registry"),m=i.time.format.utc,y=/^\s*(-?\d\d\d\d|\d\d)(-(\d?\d)(-(\d?\d)([ Tt]([01]?\d|2[0-3])(:([0-5]\d)(:([0-5]\d(\.\d+)?))?(Z|z|[+\-]\d\d:?\d\d)?)?)?)?)?\s*$/m,x=/^\s*(-?\d\d\d\d|\d\d)(-(\d?\di?)(-(\d?\d)([ Tt]([01]?\d|2[0-3])(:([0-5]\d)(:([0-5]\d(\.\d+)?))?(Z|z|[+\-]\d\d:?\d\d)?)?)?)?)?\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&v.componentsRegistry.calendars&&"string"==typeof t&&"gregorian"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){return _(t)?e?v.getComponentMethod("calendars","CANONICAL_SUNDAY")[t]:v.getComponentMethod("calendars","CANONICAL_TICK")[t]:e?"2000-01-02":"2000-01-01"},r.dfltRange=function(t){return _(t)?v.getComponentMethod("calendars","DFLTRANGE")[t]:["2000-01-01","2001-01-01"]},r.isJSDate=function(t){return"object"==typeof t&&null!==t&&"function"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var i=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;i=i-s/2+l(o-i+s/2,s)}return(t=Number(t)-i)>=n&&t<=a?t:u}if("string"!=typeof t&&"number"!=typeof t)return u;t=String(t);var c=_(e),m=t.charAt(0);!c||"G"!==m&&"g"!==m||(t=t.substr(1),e="");var w=c&&"chinese"===e.substr(0,7),k=t.match(w?x:y);if(!k)return u;var T=k[1],A=k[3]||"1",M=Number(k[5]||1),S=Number(k[7]||0),E=Number(k[9]||0),L=Number(k[11]||0);if(c){if(2===T.length)return u;var C;T=Number(T);try{var P=v.getComponentMethod("calendars","getCal")(e);if(w){var O="i"===A.charAt(A.length-1);A=parseInt(A,10),C=P.newDate(T,P.toMonthIndex(T,A,O),M)}else C=P.newDate(T,Number(A),M)}catch(t){return u}return C?(C.toJD()-g)*h+S*f+E*p+L*d:u}T=2===T.length?(Number(T)+2e3-b)%100+b:Number(T),A-=1;var z=new Date(Date.UTC(2e3,A,M,S,E));return z.setUTCFullYear(T),z.getUTCMonth()!==A?u:z.getUTCDate()!==M?u:z.getTime()+L*d},n=r.MIN_MS=r.dateTime2ms("-9999"),a=r.MAX_MS=r.dateTime2ms("9999-12-31 23:59:59.9999"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var k=90*h,T=3*f,A=5*p;function M(t,e,r,n,a){if((e||r||n||a)&&(t+=" "+w(e,2)+":"+w(r,2),(n||a)&&(t+=":"+w(n,2),a))){for(var i=4;a%10==0;)i-=1,a/=10;t+="."+w(a,i)}return t}r.ms2DateTime=function(t,e,r){if("number"!=typeof t||!(t>=n&&t<=a))return u;e||(e=0);var i,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/h)+g,E=Math.floor(l(t,h));try{i=v.getComponentMethod("calendars","getCal")(r).fromJD(S).formatDate("yyyy-mm-dd")}catch(t){i=m("G%Y-%m-%d")(new Date(w))}if("-"===i.charAt(0))for(;i.length<11;)i="-0"+i.substr(1);else for(;i.length<10;)i="0"+i;o=e<k?Math.floor(E/f):0,s=e<k?Math.floor(E%f/p):0,c=e<T?Math.floor(E%p/d):0,y=e<A?E%d*10+b:0}else x=new Date(w),i=m("%Y-%m-%d")(x),o=e<k?x.getUTCHours():0,s=e<k?x.getUTCMinutes():0,c=e<T?x.getUTCSeconds():0,y=e<A?10*x.getUTCMilliseconds()+b:0;return M(i,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=a-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return M(i.time.format("%Y-%m-%d")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||"number"==typeof t&&isFinite(t)){if(_(n))return s.error("JS Dates and milliseconds are incompatible with world calendars",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error("unrecognized date",t),e;return t};var S=/%\d?f/g;function E(t,e,r,n){t=t.replace(S,function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,"")||"0"});var a=new Date(Math.floor(e+.05));if(_(n))try{t=v.getComponentMethod("calendars","worldCalFmt")(t,e,n)}catch(t){return"Invalid"}return r(t)(a)}var L=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,a,i){if(a=_(a)&&a,!e)if("y"===r)e=i.year;else if("m"===r)e=i.month;else{if("d"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+":"+w(l(Math.floor(r/p),60),2);if("M"!==e){o(e)||(e=0);var a=(100+Math.min(l(t/d,60),L[e])).toFixed(e).substr(1);e>0&&(a=a.replace(/0+$/,"").replace(/[\.]$/,"")),n+=":"+a}return n}(t,r)+"\n"+E(i.dayMonthYear,t,n,a);e=i.dayMonth+"\n"+i.year}return E(e,t,n,a)};var C=3*h;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var a=Math.round(t/h)+g,i=v.getComponentMethod("calendars","getCal")(r),o=i.fromJD(a);return e%12?i.add(o,e,"m"):i.add(o,e/12,"y"),(o.toJD()-g)*h+n}catch(e){s.error("invalid ms "+t+" in calendar "+r)}var c=new Date(t+C);return c.setUTCMonth(c.getUTCMonth()+e)+n-C},r.findExactDates=function(t,e){for(var r,n,a=0,i=0,s=0,l=0,c=_(e)&&v.getComponentMethod("calendars","getCal")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+g)).day()?1===r.month()?a++:i++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?a++:i++:s++}else l++;s+=i+=a;var f=t.length-l;return{exactYears:a/f,exactMonths:i/f,exactDays:s/f}}},{"../constants/numerical":692,"../registry":845,"./loggers":720,"./mod":723,d3:164,"fast-isnumeric":227}],705:[function(t,e,r){"use strict";var n=t("d3"),a=t("./loggers");function i(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function o(t,e,r){var n="plotly.js-style-"+t,i=document.getElementById(n);i||((i=document.createElement("style")).setAttribute("id",n),i.appendChild(document.createTextNode("")),document.head.appendChild(i));var o=i.sheet;o.insertRule?o.insertRule(e+"{"+r+"}",0):o.addRule?o.addRule(e,r,0):a.warn("addStyleRule failed")}e.exports={getGraphDiv:function(t){var e;if("string"==typeof t){if(null===(e=document.getElementById(t)))throw new Error("No DOM element with id '"+t+"' exists on the page.");return e}if(null==t)throw new Error("DOM element provided is null or undefined");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed("js-plotly-plot")},removeElement:i,addStyleRule:function(t,e){o("global",t,e)},addRelatedStyleRule:o,deleteRelatedStyleRule:function(t){var e="plotly.js-style-"+t,r=document.getElementById(e);r&&i(r)}}},{"./loggers":720,d3:164}],706:[function(t,e,r){"use strict";var n=t("events").EventEmitter,a={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,a){"undefined"!=typeof jQuery&&jQuery(t).trigger(n,a),e.emit(n,a),r.emit(n,a)},t},triggerHandler:function(t,e,r){var n,a;"undefined"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var i=t._ev;if(!i)return n;var o,s=i._events[e];if(!s)return n;function l(t){return t.listener?(i.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(i,[r]))):t.apply(i,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return a=l(s[o]),void 0!==n?n:a},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=a},{events:105}],707:[function(t,e,r){"use strict";var n=t("./is_plain_object.js"),a=Array.isArray;function i(t,e,r,o){var s,l,c,u,h,f,p=t[0],d=t.length;if(2===d&&a(p)&&a(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&"object"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&a(u)?p[l]=u:e&&u&&(n(u)||(h=a(u)))?(h?(h=!1,f=c&&a(c)?c:[]):f=c&&n(c)?c:{},p[l]=i([f,u],e,r,o)):("undefined"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return i(arguments,!1,!1,!1)},r.extendDeep=function(){return i(arguments,!0,!1,!1)},r.extendDeepAll=function(){return i(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return i(arguments,!0,!1,!0)}},{"./is_plain_object.js":717}],708:[function(t,e,r){"use strict";e.exports=function(t){for(var e={},r=[],n=0,a=0;a<t.length;a++){var i=t[a];1!==e[i]&&(e[i]=1,r[n++]=i)}return r}},{}],709:[function(t,e,r){"use strict";function n(t){return!0===t.visible}function a(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?a:n),i=[],o=0;o<t.length;o++){var s=t[o];r(s)&&i.push(s)}return i}},{}],710:[function(t,e,r){"use strict";var n=t("country-regex"),a=t("../lib"),i=Object.keys(n),o={"ISO-3":a.identity,"USA-states":a.identity,"country names":function(t){for(var e=0;e<i.length;e++){var r=i[e],o=new RegExp(n[r]);if(o.test(t.trim().toLowerCase()))return r}return a.log("Unrecognized country name: "+t+"."),!1}};e.exports={locationToFeature:function(t,e,r){if(!e||"string"!=typeof e)return!1;var n,i,s,l=o[t](e);if(l){if("USA-states"===t)for(n=[],s=0;s<r.length;s++)(i=r[s]).properties&&i.properties.gu&&"USA"===i.properties.gu&&n.push(i);else n=r;for(s=0;s<n.length;s++)if((i=n[s]).id===l)return i;a.log(["Location with id",l,"does not have a matching topojson feature at this resolution."].join(" "))}return!1}}},{"../lib":716,"country-regex":135}],711:[function(t,e,r){"use strict";var n=t("../constants/numerical").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],a=[],i=0;i<t.length;i++){var o=t[i].lonlat;o[0]!==n?a.push(o):!e&&a.length>0&&(r.push(a),a=[])}return a.length>0&&r.push(a),r},r.makeLine=function(t){return 1===t.length?{type:"LineString",coordinates:t[0]}:{type:"MultiLineString",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:"Polygon",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:"MultiPolygon",coordinates:e}},r.makeBlank=function(){return{type:"Point",coordinates:[]}}},{"../constants/numerical":692}],712:[function(t,e,r){"use strict";var n,a,i,o=t("./mod").mod;function s(t,e,r,n,a,i,o,s){var l=r-t,c=a-t,u=o-a,h=n-e,f=i-e,p=s-i,d=l*p-u*h;if(0===d)return null;var g=(c*p-u*f)/d,v=(c*h-l*f)/d;return v<0||v>1||g<0||g>1?null:{x:t+l*g,y:e+h*g}}function l(t,e,r,n,a){var i=n*t+a*e;if(i<0)return n*n+a*a;if(i>r){var o=n-t,s=a-e;return o*o+s*s}var l=n*e-a*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,a,i,o,c){if(s(t,e,r,n,a,i,o,c))return 0;var u=r-t,h=n-e,f=o-a,p=c-i,d=u*u+h*h,g=f*f+p*p,v=Math.min(l(u,h,d,a-t,i-e),l(u,h,d,o-t,c-e),l(f,p,g,t-a,e-i),l(f,p,g,r-a,n-i));return Math.sqrt(v)},r.getTextLocation=function(t,e,r,s){if(t===a&&s===i||(n={},a=t,i=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},r.clearLocationCache=function(){a=null},r.getVisibleSegment=function(t,e,r){var n,a,i=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(a=r);var c=r.x<i?i-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-a.x)<.1&&Math.abs(n.y-a.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var a,i,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(a=(f+p)/2,o=(i=t.getPointAtLength(a))[r]-e,Math.abs(o)<l)return i;u*o>0?p=a:f=a,h++}return i}},{"./mod":723}],713:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("tinycolor2"),i=t("color-normalize"),o=t("../components/colorscale"),s=t("../components/color/attributes").defaultLine,l=t("./array").isArrayOrTypedArray,c=i(s),u=1;function h(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=i(t);return e.length?e:c}function p(t){return n(t)?t:u}e.exports={formatColor:function(t,e,r){var n,a,s,d,g,v=t.color,m=l(v),y=l(e),x=o.extractOpts(t),b=[];if(n=void 0!==x.colorscale?o.makeColorScaleFuncFromTrace(t):f,a=m?function(t,e){return void 0===t[e]?c:i(n(t[e]))}:f,s=y?function(t,e){return void 0===t[e]?u:p(t[e])}:p,m||y)for(var _=0;_<r;_++)d=a(v,_),g=s(e,_),b[_]=h(d,g);else b=h(i(v),e);return b},parseColorScale:function(t,e){void 0===e&&(e=1);var r=o.extractOpts(t);return(r.reversescale?o.flipScale(r.colorscale):r.colorscale).map(function(t){var r=t[0],n=a(t[1]).toRgb();return{index:r,rgb:[n.r,n.g,n.b,e]}})}}},{"../components/color/attributes":590,"../components/colorscale":603,"./array":699,"color-normalize":121,"fast-isnumeric":227,tinycolor2:535}],714:[function(t,e,r){"use strict";var n=t("./identity");function a(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:a,descend:n,wrap:a,unwrap:function(t){return t[0]}}},{"./identity":715}],715:[function(t,e,r){"use strict";e.exports=function(t){return t}},{}],716:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../constants/numerical"),o=i.FP_SAFE,s=i.BADNUM,l=e.exports={};l.nestedProperty=t("./nested_property"),l.keyedContainer=t("./keyed_container"),l.relativeAttr=t("./relative_attr"),l.isPlainObject=t("./is_plain_object"),l.toLogRange=t("./to_log_range"),l.relinkPrivateKeys=t("./relink_private");var c=t("./array");l.isTypedArray=c.isTypedArray,l.isArrayOrTypedArray=c.isArrayOrTypedArray,l.isArray1D=c.isArray1D,l.ensureArray=c.ensureArray,l.concat=c.concat,l.maxRowLength=c.maxRowLength,l.minRowLength=c.minRowLength;var u=t("./mod");l.mod=u.mod,l.modHalf=u.modHalf;var h=t("./coerce");l.valObjectMeta=h.valObjectMeta,l.coerce=h.coerce,l.coerce2=h.coerce2,l.coerceFont=h.coerceFont,l.coerceHoverinfo=h.coerceHoverinfo,l.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,l.validate=h.validate;var f=t("./dates");l.dateTime2ms=f.dateTime2ms,l.isDateTime=f.isDateTime,l.ms2DateTime=f.ms2DateTime,l.ms2DateTimeLocal=f.ms2DateTimeLocal,l.cleanDate=f.cleanDate,l.isJSDate=f.isJSDate,l.formatDate=f.formatDate,l.incrementMonth=f.incrementMonth,l.dateTick0=f.dateTick0,l.dfltRange=f.dfltRange,l.findExactDates=f.findExactDates,l.MIN_MS=f.MIN_MS,l.MAX_MS=f.MAX_MS;var p=t("./search");l.findBin=p.findBin,l.sorterAsc=p.sorterAsc,l.sorterDes=p.sorterDes,l.distinctVals=p.distinctVals,l.roundUp=p.roundUp,l.sort=p.sort,l.findIndexOfMin=p.findIndexOfMin;var d=t("./stats");l.aggNums=d.aggNums,l.len=d.len,l.mean=d.mean,l.median=d.median,l.midRange=d.midRange,l.variance=d.variance,l.stdev=d.stdev,l.interp=d.interp;var g=t("./matrix");l.init2dArray=g.init2dArray,l.transposeRagged=g.transposeRagged,l.dot=g.dot,l.translationMatrix=g.translationMatrix,l.rotationMatrix=g.rotationMatrix,l.rotationXYMatrix=g.rotationXYMatrix,l.apply2DTransform=g.apply2DTransform,l.apply2DTransform2=g.apply2DTransform2;var v=t("./angles");l.deg2rad=v.deg2rad,l.rad2deg=v.rad2deg,l.angleDelta=v.angleDelta,l.angleDist=v.angleDist,l.isFullCircle=v.isFullCircle,l.isAngleInsideSector=v.isAngleInsideSector,l.isPtInsideSector=v.isPtInsideSector,l.pathArc=v.pathArc,l.pathSector=v.pathSector,l.pathAnnulus=v.pathAnnulus;var m=t("./anchor_utils");l.isLeftAnchor=m.isLeftAnchor,l.isCenterAnchor=m.isCenterAnchor,l.isRightAnchor=m.isRightAnchor,l.isTopAnchor=m.isTopAnchor,l.isMiddleAnchor=m.isMiddleAnchor,l.isBottomAnchor=m.isBottomAnchor;var y=t("./geometry2d");l.segmentsIntersect=y.segmentsIntersect,l.segmentDistance=y.segmentDistance,l.getTextLocation=y.getTextLocation,l.clearLocationCache=y.clearLocationCache,l.getVisibleSegment=y.getVisibleSegment,l.findPointOnPath=y.findPointOnPath;var x=t("./extend");l.extendFlat=x.extendFlat,l.extendDeep=x.extendDeep,l.extendDeepAll=x.extendDeepAll,l.extendDeepNoArrays=x.extendDeepNoArrays;var b=t("./loggers");l.log=b.log,l.warn=b.warn,l.error=b.error;var _=t("./regex");l.counterRegex=_.counter;var w=t("./throttle");l.throttle=w.throttle,l.throttleDone=w.done,l.clearThrottle=w.clear;var k=t("./dom");function T(t){var e={};for(var r in t)for(var n=t[r],a=0;a<n.length;a++)e[n[a]]=+r;return e}l.getGraphDiv=k.getGraphDiv,l.isPlotDiv=k.isPlotDiv,l.removeElement=k.removeElement,l.addStyleRule=k.addStyleRule,l.addRelatedStyleRule=k.addRelatedStyleRule,l.deleteRelatedStyleRule=k.deleteRelatedStyleRule,l.clearResponsive=t("./clear_responsive"),l.makeTraceGroups=t("./make_trace_groups"),l._=t("./localize"),l.notifier=t("./notifier"),l.filterUnique=t("./filter_unique"),l.filterVisible=t("./filter_visible"),l.pushUnique=t("./push_unique"),l.cleanNumber=t("./clean_number"),l.ensureNumber=function(t){return a(t)?(t=Number(t))<-o||t>o?s:a(t)?Number(t):s:s},l.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(a(t)&&t>=0&&t%1==0)},l.noop=t("./noop"),l.identity=t("./identity"),l.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},l.swapAttrs=function(t,e,r,n){r||(r="x"),n||(n="y");for(var a=0;a<e.length;a++){var i=e[a],o=l.nestedProperty(t,i.replace("?",r)),s=l.nestedProperty(t,i.replace("?",n)),c=o.get();o.set(s.get()),s.set(c)}},l.raiseToTop=function(t){t.parentNode.appendChild(t)},l.cancelTransition=function(t){return t.transition().duration(0)},l.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},l.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},l.simpleMap=function(t,e,r,n){for(var a=t.length,i=new Array(a),o=0;o<a;o++)i[o]=e(t[o],r,n);return i},l.randstr=function t(e,r,n,a){if(n||(n=16),void 0===r&&(r=24),r<=0)return"0";var i,o,s=Math.log(Math.pow(2,r))/Math.log(n),c="";for(i=2;s===1/0;i*=2)s=Math.log(Math.pow(2,r/i))/Math.log(n)*i;var u=s-Math.floor(s);for(i=0;i<Math.floor(s);i++)c=Math.floor(Math.random()*n).toString(n)+c;u&&(o=Math.pow(n,u),c=Math.floor(Math.random()*o).toString(n)+c);var h=parseInt(c,n);return e&&e[c]||h!==1/0&&h>=Math.pow(2,r)?a>10?(l.warn("randstr failed uniqueness"),c):t(e,r,n,(a||0)+1):c},l.OptionControl=function(t,e){t||(t={}),e||(e="opt");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r["_"+e]=t,r},l.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,a,i,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(i=0,n=0;n<l;n++)(a=r+n+1-e)<-o?a-=s*Math.round(a/s):a>=s&&(a-=s*Math.floor(a/s)),a<0?a=-1-a:a>=o&&(a=s-1-a),i+=t[a]*c[n];u[r]=i}return u},l.syncOrAsync=function(t,e,r){var n;function a(){return l.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(a).then(void 0,l.promiseError);return r&&r(e)},l.stripTrailingSlash=function(t){return"/"===t.substr(-1)?t.substr(0,t.length-1):t},l.noneOrAll=function(t,e,r){if(t){var n,a=!1,i=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?a=!0:i=!1;if(a&&!i)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},l.mergeArray=function(t,e,r,n){var a="function"==typeof n;if(l.isArrayOrTypedArray(t))for(var i=Math.min(t.length,e.length),o=0;o<i;o++){var s=t[o];e[o][r]=a?n(s):s}},l.mergeArrayCastPositive=function(t,e,r){return l.mergeArray(t,e,r,function(t){var e=+t;return isFinite(e)&&e>0?e:0})},l.fillArray=function(t,e,r,n){if(n=n||l.identity,l.isArrayOrTypedArray(t))for(var a=0;a<e.length;a++)e[a][r]=n(t[a])},l.castOption=function(t,e,r,n){n=n||l.identity;var a=l.nestedProperty(t,r).get();return l.isArrayOrTypedArray(a)?Array.isArray(e)&&l.isArrayOrTypedArray(a[e[0]])?n(a[e[0]][e[1]]):n(a[e]):a},l.extractOption=function(t,e,r,n){if(r in t)return t[r];var a=l.nestedProperty(e,n).get();return Array.isArray(a)?void 0:a},l.tagSelected=function(t,e,r){var n,a,i=e.selectedpoints,o=e._indexToPoints;o&&(n=T(o));for(var s=0;s<i.length;s++){var c=i[s];if(l.isIndex(c)){var u=n?n[c]:c,h=r?r[u]:u;void 0!==(a=h)&&a<t.length&&(t[h].selected=1)}}},l.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=T(r),a=[],i=0;i<e.length;i++){var o=e[i];if(l.isIndex(o)){var s=n[o];l.isIndex(s)&&a.push(s)}}return a}return e},l.getTargetArray=function(t,e){var r=e.target;if("string"==typeof r&&r){var n=l.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},l.minExtend=function(t,e){var r={};"object"!=typeof e&&(e={});var n,a,i,o=Object.keys(t);for(n=0;n<o.length;n++)i=t[a=o[n]],"_"!==a.charAt(0)&&"function"!=typeof i&&("module"===a?r[a]=i:Array.isArray(i)?r[a]="colorscale"===a?i.slice():i.slice(0,3):l.isTypedArray(i)?r[a]=i.subarray(0,3):r[a]=i&&"object"==typeof i?l.minExtend(t[a],e[a]):i);for(o=Object.keys(e),n=0;n<o.length;n++)"object"==typeof(i=e[a=o[n]])&&a in r&&"object"==typeof r[a]||(r[a]=i);return r},l.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},l.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},l.isIE=function(){return"undefined"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\./;l.isIE9orBelow=function(){return l.isIE()&&A.test(window.navigator.userAgent)};var M=/Version\/[\d\.]+.*Safari/;l.isSafari=function(){return M.test(window.navigator.userAgent)},l.isD3Selection=function(t){return t&&"function"==typeof t.classed},l.ensureSingle=function(t,e,r,n){var a=t.select(e+(r?"."+r:""));if(a.size())return a;var i=t.append(e);return r&&i.classed(r,!0),n&&i.call(n),i},l.ensureSingleById=function(t,e,r,n){var a=t.select(e+"#"+r);if(a.size())return a;var i=t.append(e).attr("id",r);return n&&i.call(n),i},l.objectFromPath=function(t,e){for(var r,n=t.split("."),a=r={},i=0;i<n.length;i++){var o=n[i],s=null,l=n[i].match(/(.*)\[([0-9]+)\]/);l?(o=l[1],s=l[2],r=r[o]=[],i===n.length-1?r[s]=e:r[s]={},r=r[s]):(i===n.length-1?r[o]=e:r[o]={},r=r[o])}return a};var S=/^([^\[\.]+)\.(.+)?/,E=/^([^\.]+)\[([0-9]+)\](\.)?(.+)?/;l.expandObjectPaths=function(t){var e,r,n,a,i,o,s;if("object"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(S))?(a=t[r],n=e[1],delete t[r],t[n]=l.extendDeepNoArrays(t[n]||{},l.objectFromPath(r,l.expandObjectPaths(a))[n])):(e=r.match(E))?(a=t[r],n=e[1],i=parseInt(e[2]),delete t[r],t[n]=t[n]||[],"."===e[3]?(s=e[4],o=t[n][i]=t[n][i]||{},l.extendDeepNoArrays(o,l.objectFromPath(s,l.expandObjectPaths(a)))):t[n][i]=l.expandObjectPaths(a)):t[r]=l.expandObjectPaths(t[r]));return t},l.numSeparate=function(t,e,r){if(r||(r=!1),"string"!=typeof e||0===e.length)throw new Error("Separator string required for formatting!");"number"==typeof t&&(t=String(t));var n=/(\d+)(\d{3})/,a=e.charAt(0),i=e.charAt(1),o=t.split("."),s=o[0],l=o.length>1?a+o[1]:"";if(i&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,"$1"+i+"$2");return s+l},l.TEMPLATE_STRING_REGEX=/%{([^\s%{}:]*)([:|\|][^}]*)?}/g;var L=/^\w*$/;l.templateString=function(t,e){var r={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,n){return L.test(n)?e[n]||"":(r[n]=r[n]||l.nestedProperty(e,n).get,r[n]()||"")})};var C={max:10,count:0,name:"hovertemplate"};l.hovertemplateString=function(){return z.apply(C,arguments)};var P={max:10,count:0,name:"texttemplate"};l.texttemplateString=function(){return z.apply(P,arguments)};var O=/^[:|\|]/;function z(t,e,r){var a=this,i=arguments;e||(e={});var o={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,s,c){var u,h,f,p;for(f=3;f<i.length;f++)if(u=i[f]){if(u.hasOwnProperty(s)){h=u[s];break}if(L.test(s)||(h=o[s]||l.nestedProperty(u,s).get())&&(o[s]=h),void 0!==h)break}if(void 0===h&&a)return a.count<a.max&&(l.warn("Variable '"+s+"' in "+a.name+" could not be found!"),h=t),a.count===a.max&&l.warn("Too many "+a.name+" warnings - additional warnings will be suppressed"),a.count++,t;if(c){if(":"===c[0]&&(h=(p=r?r.numberFormat:n.format)(c.replace(O,""))(h)),"|"===c[0]){p=r?r.timeFormat.utc:n.time.format.utc;var d=l.dateTime2ms(h);h=l.formatDate(d,c.replace(O,""),!1,p)}}else e.hasOwnProperty(s+"Label")&&(h=e[s+"Label"]);return h})}l.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,a=0,i=0;i<r;i++){var o=t.charCodeAt(i)||0,s=e.charCodeAt(i)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(a=10*a+s-48),!l||!c){if(n!==a)return n-a;if(o!==s)return o-s}}return a-n};var I=2e9;l.seedPseudoRandom=function(){I=2e9},l.pseudoRandom=function(){var t=I;return I=(69069*I+1)%4294967296,Math.abs(I-t)<429496729?l.pseudoRandom():I/4294967296},l.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},a=l.extractOption(t,e,"htx","hovertext");if(l.isValidTextValue(a))return n(a);var i=l.extractOption(t,e,"tx","text");return l.isValidTextValue(i)?n(i):void 0},l.isValidTextValue=function(t){return t||0===t},l.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+"%",n=0;n<e;n++)-1!==r.indexOf(".")&&(r=(r=r.replace("0%","%")).replace(".%","%"));return r},l.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||"none"===e},l.getTextTransform=function(t){var e,r=t.textX,n=t.textY,a=t.targetX,i=t.targetY,o=t.scale,s=t.rotate;return o<1?e="scale("+o+") ":(o=1,e=""),"translate("+(a-o*r)+" "+(i-o*n)+")"+e+(s?"rotate("+s+" "+r+" "+n+") ":"")}},{"../constants/numerical":692,"./anchor_utils":697,"./angles":698,"./array":699,"./clean_number":700,"./clear_responsive":702,"./coerce":703,"./dates":704,"./dom":705,"./extend":707,"./filter_unique":708,"./filter_visible":709,"./geometry2d":712,"./identity":715,"./is_plain_object":717,"./keyed_container":718,"./localize":719,"./loggers":720,"./make_trace_groups":721,"./matrix":722,"./mod":723,"./nested_property":724,"./noop":725,"./notifier":726,"./push_unique":730,"./regex":732,"./relative_attr":733,"./relink_private":734,"./search":735,"./stats":738,"./throttle":741,"./to_log_range":742,d3:164,"fast-isnumeric":227}],717:[function(t,e,r){"use strict";e.exports=function(t){return window&&window.process&&window.process.versions?"[object Object]"===Object.prototype.toString.call(t):"[object Object]"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],718:[function(t,e,r){"use strict";var n=t("./nested_property"),a=/^\w*$/;e.exports=function(t,e,r,i){var o,s,l;r=r||"name",i=i||"value";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||"";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=a.test(i),f={set:function(t,e){var a=null===e?4:0;if(!s){if(!l||4===a)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===a)return;a|=3,o=s.length,u[t]=o}else e!==(h?s[o][i]:n(s[o],i).get())&&(a|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[i]=e:n(p,i).set(e),null!==e&&(a&=-5),c[o]=c[o]|a,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][i]:n(s[e],i).get()}},rename:function(t,e){var n=u[t];return void 0===n?f:(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e,f)},remove:function(t){var e=u[t];if(void 0===e)return f;var a=s[e];if(Object.keys(a).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(a,i).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,a,o={},l=Object.keys(c),u=0;u<l.length;u++)a=l[u],t=e+"["+a+"]",s[a]?(1&c[a]&&(o[t+"."+r]=s[a][r]),2&c[a]&&(o[t+"."+i]=h?4&c[a]?null:s[a][i]:4&c[a]?null:n(s[a],i).get())):o[t]=null;return o}};return f}},{"./nested_property":724}],719:[function(t,e,r){"use strict";var n=t("../registry");e.exports=function(t,e){for(var r=t._context.locale,a=0;a<2;a++){for(var i=t._context.locales,o=0;o<2;o++){var s=(i[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}i=n.localeRegistry}var c=r.split("-")[0];if(c===r)break;r=c}return e}},{"../registry":845}],720:[function(t,e,r){"use strict";var n=t("../plot_api/plot_config").dfltConfig,a=e.exports={};function i(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}a.log=function(){if(n.logging>1){for(var t=["LOG:"],e=0;e<arguments.length;e++)t.push(arguments[e]);i(console.trace||console.log,t)}},a.warn=function(){if(n.logging>0){for(var t=["WARN:"],e=0;e<arguments.length;e++)t.push(arguments[e]);i(console.trace||console.log,t)}},a.error=function(){if(n.logging>0){for(var t=["ERROR:"],e=0;e<arguments.length;e++)t.push(arguments[e]);i(console.error,t)}}},{"../plot_api/plot_config":752}],721:[function(t,e,r){"use strict";var n=t("d3");e.exports=function(t,e,r){var a=t.selectAll("g."+r.replace(/\s/g,".")).data(e,function(t){return t[0].trace.uid});a.exit().remove(),a.enter().append("g").attr("class",r),a.order();var i=t.classed("rangeplot")?"nodeRangePlot3":"node3";return a.each(function(t){t[0][i]=n.select(this)}),a}},{d3:164}],722:[function(t,e,r){"use strict";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,a=t.length;for(e=0;e<a;e++)n=Math.max(n,t[e].length);var i=new Array(n);for(e=0;e<n;e++)for(i[e]=new Array(a),r=0;r<a;r++)i[e][r]=t[r][e];return i},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,a,i=t.length;if(t[0].length)for(n=new Array(i),a=0;a<i;a++)n[a]=r.dot(t[a],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),a=0;a<o.length;a++)n[a]=r.dot(t,o[a])}else for(n=0,a=0;a<i;a++)n+=t[a]*e[a];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],723:[function(t,e,r){"use strict";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],724:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("./array").isArrayOrTypedArray;e.exports=function(t,e){if(n(e))e=String(e);else if("string"!=typeof e||"[-1]"===e.substr(e.length-4))throw"bad property string";for(var r,i,o,l=0,c=e.split(".");l<c.length;){if(r=String(c[l]).match(/^([^\[\]]*)((\[\-?[0-9]*\])+)$/)){if(r[1])c[l]=r[1];else{if(0!==l)throw"bad property string";c.splice(0,1)}for(i=r[2].substr(1,r[2].length-2).split("]["),o=0;o<i.length;o++)l++,c.splice(l,0,Number(i[o]))}l++}return"object"!=typeof t?function(t,e,r){return{set:function(){throw"bad container"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:s(t,c,e),get:function t(e,r){return function(){var n,i,o,s,l,c=e;for(s=0;s<r.length-1;s++){if(-1===(n=r[s])){for(i=!0,o=[],l=0;l<c.length;l++)o[l]=t(c[l],r.slice(s+1))(),o[l]!==o[0]&&(i=!1);return i?o[0]:o}if("number"==typeof n&&!a(c))return;if("object"!=typeof(c=c[n])||null===c)return}if("object"==typeof c&&null!==c&&null!==(o=c[r[s]]))return o}}(t,c),astr:e,parts:c,obj:t}};var i=/(^|\.)args\[/;function o(t,e){return void 0===t||null===t&&!e.match(i)}function s(t,e,r){return function(n){var i,s,h=t,f="",p=[[t,f]],d=o(n,r);for(s=0;s<e.length-1;s++){if("number"==typeof(i=e[s])&&!a(h))throw"array index but container is not an array";if(-1===i){if(d=!c(h,e.slice(s+1),n,r))break;return}if(!u(h,i,e[s+1],d))break;if("object"!=typeof(h=h[i])||null===h)throw"container is not an object";f=l(f,i),p.push([h,f])}if(d){if(s===e.length-1&&(delete h[e[s]],Array.isArray(h)&&+e[s]==h.length-1))for(;h.length&&void 0===h[h.length-1];)h.pop()}else h[e[s]]=n}}function l(t,e){var r=e;return n(e)?r="["+e+"]":t&&(r="."+e),t+r}function c(t,e,r,n){var i,l=a(r),c=!0,h=r,f=n.replace("-1",0),p=!l&&o(r,f),d=e[0];for(i=0;i<t.length;i++)f=n.replace("-1",i),l&&(p=o(h=r[i%r.length],f)),p&&(c=!1),u(t,i,d,p)&&s(t[i],e,n.replace("-1",i))(h);return c}function u(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]="number"==typeof r?[]:{}}return!0}},{"./array":699,"fast-isnumeric":227}],725:[function(t,e,r){"use strict";e.exports=function(){}},{}],726:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=[];e.exports=function(t,e){if(-1===i.indexOf(t)){i.push(t);var r=1e3;a(e)?r=e:"long"===e&&(r=3e3);var o=n.select("body").selectAll(".plotly-notifier").data([0]);o.enter().append("div").classed("plotly-notifier",!0),o.selectAll(".notifier-note").data(i).enter().append("div").classed("notifier-note",!0).style("opacity",0).each(function(t){var e=n.select(this);e.append("button").classed("notifier-close",!0).html("&times;").on("click",function(){e.transition().call(s)});for(var a=e.append("p"),i=t.split(/<br\s*\/?>/g),o=0;o<i.length;o++)o&&a.append("br"),a.append("span").text(i[o]);e.transition().duration(700).style("opacity",1).transition().delay(r).call(s)})}function s(t){t.duration(700).style("opacity",0).each("end",function(t){var e=i.indexOf(t);-1!==e&&i.splice(e,1),n.select(this).remove()})}}},{d3:164,"fast-isnumeric":227}],727:[function(t,e,r){"use strict";var n=t("./setcursor"),a="data-savedcursor";e.exports=function(t,e){var r=t.attr(a);if(e){if(!r){for(var i=(t.attr("class")||"").split(" "),o=0;o<i.length;o++){var s=i[o];0===s.indexOf("cursor-")&&t.attr(a,s.substr(7)).classed(s,!1)}t.attr(a)||t.attr(a,"!!")}n(t,e)}else r&&(t.attr(a,null),"!!"===r?n(t):n(t,r))}},{"./setcursor":736}],728:[function(t,e,r){"use strict";var n=t("./matrix").dot,a=t("../constants/numerical").BADNUM,i=e.exports={};i.tester=function(t){var e,r=t.slice(),n=r[0][0],i=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),i=Math.max(i,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:i,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===a||r<n||r>i||c===a||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===a||l<n||l>i||c===a||c<o||c>s)return!1;var u,h,f,p,d,g=r.length,v=r[0][0],m=r[0][1],y=0;for(u=1;u<g;u++)if(h=v,f=m,v=r[u][0],m=r[u][1],!(l<(p=Math.min(h,v))||l>Math.max(h,v)||c>Math.max(f,m)))if(c<Math.min(f,m))l!==p&&y++;else{if(c===(d=v===h?c:f+(l-h)*(m-f)/(v-h)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},i.isSegmentBent=function(t,e,r,a){var i,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(i=e+1;i<r;i++)if(o=[t[i][0]-l[0],t[i][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>a)return!0;return!1},i.filter=function(t,e){var r=[t[0]],n=0,a=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(a+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||i.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,a=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{"../constants/numerical":692,"./matrix":722}],729:[function(t,e,r){(function(r){"use strict";var n=t("./show_no_webgl_msg"),a=t("regl");e.exports=function(t,e){var i=t._fullLayout,o=!0;return i._glcanvas.each(function(n){if(!n.regl&&(!n.pick||i._has("parcoords"))){try{n.regl=a({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}o&&this.addEventListener("webglcontextlost",function(e){t&&t.emit&&t.emit("plotly_webglcontextlost",{event:e,layer:n.key})},!1)}}),o||n({container:i._glcontainer.node()}),o}}).call(this,"undefined"!=typeof global?global:"undefined"!=typeof self?self:"undefined"!=typeof window?window:{})},{"./show_no_webgl_msg":737,regl:500}],730:[function(t,e,r){"use strict";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],731:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plot_api/plot_config").dfltConfig;var i={add:function(t,e,r,n,i){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(i)),t.undoQueue.queue.length>a.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)i.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)i.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};i.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,a=[],i=0;i<e.length;i++)r=e[i],a[i]=r===t?r:"object"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return a}(t,r),e.apply(null,r)},e.exports=i},{"../lib":716,"../plot_api/plot_config":752}],732:[function(t,e,r){"use strict";r.counter=function(t,e,r,n){var a=(e||"")+(r?"":"$"),i=!1===n?"":"^";return"xy"===t?new RegExp(i+"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?"+a):new RegExp(i+t+"([2-9]|[1-9][0-9]+)?"+a)}},{}],733:[function(t,e,r){"use strict";var n=/^(.*)(\.[^\.\[\]]+|\[\d\])$/,a=/^[^\.\[\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(a))throw new Error("bad relativeAttr call:"+[t,e]);t=""}if("^"!==e.charAt(0))break;e=e.slice(1)}return t&&"["!==e.charAt(0)?t+"."+e:t+e}},{}],734:[function(t,e,r){"use strict";var n=t("./array").isArrayOrTypedArray,a=t("./is_plain_object");e.exports=function t(e,r){for(var i in r){var o=r[i],s=e[i];if(s!==o)if("_"===i.charAt(0)||"function"==typeof o){if(i in e)continue;e[i]=o}else if(n(o)&&n(s)&&a(o[0])){if("customdata"===i||"ids"===i)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&a(o[c])&&a(s[c])&&t(s[c],o[c])}else a(o)&&a(s)&&(t(s,o),Object.keys(s).length||delete e[i])}}},{"./array":699,"./is_plain_object":717}],735:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("./loggers"),i=t("./identity");function o(t,e){return t<e}function s(t,e){return t<=e}function l(t,e){return t>e}function c(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var i,u,h=0,f=e.length,p=0,d=f>1?(e[f-1]-e[0])/(f-1):1;for(u=d>=0?r?o:s:r?c:l,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);h<f&&p++<100;)u(e[i=Math.floor((h+f)/2)],t)?h=i+1:f=i;return p>90&&a.log("Long binary search..."),h-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e=t.slice();e.sort(r.sorterAsc);for(var n=e.length-1,a=e[n]-e[0]||1,i=a/(n||1)/1e4,o=[e[0]],s=0;s<n;s++)e[s+1]>e[s]+i&&(a=Math.min(a,e[s+1]-e[s]),o.push(e[s+1]));return{vals:o,minDiff:a}},r.roundUp=function(t,e,r){for(var n,a=0,i=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;a<i&&o++<100;)e[n=c((a+i)/2)]<=t?a=n+s:i=n-l;return e[a]},r.sort=function(t,e){for(var r=0,n=0,a=1;a<t.length;a++){var i=e(t[a],t[a-1]);if(i<0?r=1:i>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||i;for(var r,n=1/0,a=0;a<t.length;a++){var o=e(t[a]);o<n&&(n=o,r=a)}return r}},{"./identity":715,"./loggers":720,"fast-isnumeric":227}],736:[function(t,e,r){"use strict";e.exports=function(t,e){(t.attr("class")||"").split(" ").forEach(function(e){0===e.indexOf("cursor-")&&t.classed(e,!1)}),e&&t.classed("cursor-"+e,!0)}},{}],737:[function(t,e,r){"use strict";var n=t("../components/color"),a=function(){};e.exports=function(t){for(var e in t)"function"==typeof t[e]&&(t[e]=a);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement("div");r.className="no-webgl",r.style.cursor="pointer",r.style.fontSize="24px",r.style.color=n.defaults[0],r.style.position="absolute",r.style.left=r.style.top="0px",r.style.width=r.style.height="100%",r.style["background-color"]=n.lightLine,r.style["z-index"]=30;var i=document.createElement("p");return i.textContent="WebGL is not supported by your browser - visit https://get.webgl.org for more info",i.style.position="relative",i.style.top="50%",i.style.left="50%",i.style.height="30%",i.style.width="50%",i.style.margin="-15% 0 0 -25%",r.appendChild(i),t.container.appendChild(r),t.container.style.background="#FFFFFF",t.container.onclick=function(){window.open("https://get.webgl.org")},!1}},{"../components/color":591}],738:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("./array").isArrayOrTypedArray;r.aggNums=function(t,e,i,o){var s,l;if((!o||o>i.length)&&(o=i.length),n(e)||(e=!1),a(i[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,i[s]);i=l}for(s=0;s<o;s++)n(e)?n(i[s])&&(e=t(+e,+i[s])):e=i[s];return e},r.len=function(t){return r.aggNums(function(t){return t+1},0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums(function(t,e){return t+e},0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,a){return e||(e=r.len(t)),n(a)||(a=r.mean(t,e)),r.aggNums(function(t,e){return t+Math.pow(e-a,2)},0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw"n should be a finite number";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{"./array":699,"fast-isnumeric":227}],739:[function(t,e,r){"use strict";var n=t("color-normalize");e.exports=function(t){return t?n(t):[0,0,0,1]}},{"color-normalize":121}],740:[function(t,e,r){"use strict";var n=t("d3"),a=t("../lib"),i=t("../constants/xmlns_namespaces"),o=t("../constants/alignment").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,M){var S=t.text(),L=!t.attr("data-notex")&&"undefined"!=typeof MathJax&&S.match(l),C=n.select(t.node().parentNode);if(!C.empty()){var P=t.attr("class")?t.attr("class").split(" ")[0]:"text";return P+="-math",C.selectAll("svg."+P).remove(),C.selectAll("g."+P+"-group").remove(),t.style("display",null).attr({"data-unformatted":S,"data-math":"N"}),L?(e&&e._promises||[]).push(new Promise(function(e){t.style("display","none");var r=parseInt(t.node().style.fontSize,10),i={fontSize:r};!function(t,e,r){var i,o,s,l;MathJax.Hub.Queue(function(){return o=a.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:"none",tex2jax:{inlineMath:[["$","$"],["\\(","\\)"]]},displayAlign:"left"})},function(){if("SVG"!==(i=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer("SVG")},function(){var r="math-output-"+a.randstr({},64);return l=n.select("body").append("div").attr({id:r}).style({visibility:"hidden",position:"absolute"}).style({"font-size":e.fontSize+"px"}).text(t.replace(c,"\\lt ").replace(u,"\\gt ")),MathJax.Hub.Typeset(l.node())},function(){var e=n.select("body").select("#MathJax_SVG_glyphs");if(l.select(".MathJax_SVG").empty()||!l.select("svg").node())a.log("There was an error in the tex syntax.",t),r();else{var o=l.select("svg").node().getBoundingClientRect();r(l.select(".MathJax_SVG"),e,o)}if(l.remove(),"SVG"!==i)return MathJax.Hub.setRenderer(i)},function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})}(L[2],i,function(n,a,i){C.selectAll("svg."+P).remove(),C.selectAll("g."+P+"-group").remove();var o=n&&n.select("svg");if(!o||!o.node())return O(),void e();var l=C.append("g").classed(P+"-group",!0).attr({"pointer-events":"none","data-unformatted":S,"data-math":"Y"});l.node().appendChild(o.node()),a&&a.node()&&o.node().insertBefore(a.node().cloneNode(!0),o.node().firstChild),o.attr({class:P,height:i.height,preserveAspectRatio:"xMinYMin meet"}).style({overflow:"visible","pointer-events":"none"});var c=t.node().style.fill||"black",u=o.select("g");u.attr({fill:c,stroke:c});var h=s(u,"width"),f=s(u,"height"),p=+t.attr("x")-h*{start:0,middle:.5,end:1}[t.attr("text-anchor")||"start"],d=-(r||s(t,"height"))/4;"y"===P[0]?(l.attr({transform:"rotate("+[-90,+t.attr("x"),+t.attr("y")]+") translate("+[-h/2,d-f/2]+")"}),o.attr({x:+t.attr("x"),y:+t.attr("y")})):"l"===P[0]?o.attr({x:t.attr("x"),y:d-f/2}):"a"===P[0]&&0!==P.indexOf("atitle")?o.attr({x:0,y:d}):o.attr({x:p,y:+t.attr("y")+d-f/2}),M&&M.call(t,l),e(l)})})):O(),t}function O(){C.empty()||(P=t.attr("class")+"-math",C.select("svg."+P).remove()),t.text("").style("white-space","pre"),function(t,e){e=e.replace(v," ");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(i.svg,"tspan");n.select(e).attr({class:"line",dy:c*o+"em"}),t.appendChild(e),r=e;var a=l;if(l=[{node:e}],a.length>1)for(var s=1;s<a.length;s++)M(a[s])}function M(t){var e,a=t.type,o={};if("a"===a){e="a";var s=t.target,c=t.href,u=t.popup;c&&(o={"xlink:xlink:show":"_blank"===s||"_"!==s.charAt(0)?"new":"replace",target:s,"xlink:xlink:href":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,"'+u+'");return false;'))}else e="tspan";t.style&&(o.style=t.style);var h=document.createElementNS(i.svg,e);if("sup"===a||"sub"===a){S(r,d),r.appendChild(h);var g=document.createElementNS(i.svg,"tspan");S(g,d),n.select(g).attr("dy",p[a]),o.dy=f[a],r.appendChild(h),r.appendChild(g)}else r.appendChild(h);n.select(h).attr(o),r=t.node=h,l.push(t)}function S(t,e){t.appendChild(document.createTextNode(e))}function L(t){if(1!==l.length){var n=l.pop();t!==n.type&&a.log("Start tag <"+n.type+"> doesnt match end tag <"+t+">. Pretending it did match.",e),r=l[l.length-1].node}else a.log("Ignoring unexpected end tag </"+t+">.",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var C=e.split(m),P=0;P<C.length;P++){var O=C[P],z=O.match(y),I=z&&z[2].toLowerCase(),D=h[I];if("br"===I)u();else if(void 0===D)S(r,E(O));else if(z[1])L(I);else{var R=z[4],F={type:I},B=T(R,b);if(B?(B=B.replace(A,"$1 fill:"),D&&(B+=";"+D)):D&&(B=D),B&&(F.style=B),"a"===I){s=!0;var N=T(R,_);if(N){var j=document.createElement("a");j.href=N,-1!==g.indexOf(j.protocol)&&(F.href=encodeURI(decodeURI(N)),F.target=T(R,w)||"_blank",F.popup=T(R,k))}}M(F)}}return s}(t.node(),S)&&t.style("pointer-events","all"),r.positionText(t),M&&M.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var h={sup:"font-size:70%",sub:"font-size:70%",b:"font-weight:bold",i:"font-style:italic",a:"cursor:pointer",span:"",em:"font-style:italic;font-weight:bold"},f={sub:"0.3em",sup:"-0.6em"},p={sub:"-0.21em",sup:"0.42em"},d="\u200b",g=["http:","https:","mailto:","",void 0,":"],v=r.NEWLINES=/(\r\n?|\n)/g,m=/(<[^<>]*>)/,y=/<(\/?)([^ >]*)(\s+(.*))?>/i,x=/<br(\s+.*)?>/i;r.BR_TAG_ALL=/<br(\s+.*)?>/gi;var b=/(^|[\s"'])style\s*=\s*("([^"]*);?"|'([^']*);?')/i,_=/(^|[\s"'])href\s*=\s*("([^"]*)"|'([^']*)')/i,w=/(^|[\s"'])target\s*=\s*("([^"\s]*)"|'([^'\s]*)')/i,k=/(^|[\s"'])popup\s*=\s*("([\w=,]*)"|'([\w=,]*)')/i;function T(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var A=/(^|;)\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:["br"],a="...".length,i=t.split(m),o=[],s="",l=0,c=0;c<i.length;c++){var u=i[c],h=u.match(y),f=h&&h[2].toLowerCase();if(f)-1!==n.indexOf(f)&&(o.push(u),s=f);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&("br"!==s||d<=a||p<=a)&&o.pop(),r>a?o.push(u.substr(0,d-a)+"..."):o.push(u.substr(0,d));break}s=""}}return o.join("")};var M={mu:"\u03bc",amp:"&",lt:"<",gt:">",nbsp:"\xa0",times:"\xd7",plusmn:"\xb1",deg:"\xb0"},S=/&(#\d+|#x[\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,function(t,e){return("#"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}("x"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):M[e])||t})}function L(t,e,r){var n,a,i,o=r.horizontalAlign,s=r.verticalAlign||"top",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return a="bottom"===s?function(){return l.bottom-n.height}:"middle"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},i="right"===o?function(){return l.right-n.width}:"center"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:a()-c.top+"px",left:i()-c.left+"px","z-index":1e3}),this}}r.convertEntities=E,r.lineCount=function(t){return t.selectAll("tspan.line").size()||1},r.positionText=function(t,e,r){return t.each(function(){var t=n.select(this);function a(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var i=a("x",e),o=a("y",r);"text"===this.nodeName&&t.selectAll("tspan.line").attr({x:i,y:o})})},r.makeEditable=function(t,e){var r=e.gd,a=e.delegate,i=n.dispatch("edit","input","cancel"),o=a||t;if(t.style({"pointer-events":a?"none":"all"}),1!==t.size())throw new Error("boo");function s(){!function(){var a=n.select(r).select(".svg-container"),o=a.append("div"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr("data-unformatted"));o.classed("plugin-editable editable",!0).style({position:"absolute","font-family":s.fontFamily||"Arial","font-size":c,color:e.fill||s.fill||"black",opacity:1,"background-color":e.background||"transparent",outline:"#ffffff33 1px solid",margin:[-c/8+1,0,0,-1].join("px ")+"px",padding:"0","box-sizing":"border-box"}).attr({contenteditable:!0}).text(u).call(L(t,a,e)).on("blur",function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,a=n.select(this).attr("class");(e=a?"."+a.split(" ")[0]+"-math-group":"[class*=-math-group]")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on("mouseup",null),i.edit.call(t,o)}).on("focus",function(){var t=this;r._editing=!0,n.select(document).on("mouseup",function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()})}).on("keyup",function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on("blur",function(){return!1}).transition().remove(),i.cancel.call(t,this.textContent)):(i.input.call(t,this.textContent),n.select(this).call(L(t,a,e)))}).on("keydown",function(){13===n.event.which&&this.blur()}).call(l)}(),t.style({opacity:0});var a,s=o.attr("class");(a=s?"."+s.split(" ")[0]+"-math-group":"[class*=-math-group]")&&n.select(t.node().parentNode).select(a).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on("click",s),n.rebind(t,i,"on")}},{"../constants/alignment":685,"../constants/xmlns_namespaces":693,"../lib":716,d3:164}],741:[function(t,e,r){"use strict";var n={};function a(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var i=n[t],o=Date.now();if(!i){for(var s in n)n[s].ts<o-6e4&&delete n[s];i=n[t]={ts:0,timer:null}}function l(){r(),i.ts=Date.now(),i.onDone&&(i.onDone(),i.onDone=null)}a(i),o>i.ts+e?l():i.timer=setTimeout(function(){l(),i.timer=null},e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise(function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}}):Promise.resolve()},r.clear=function(t){if(t)a(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],742:[function(t,e,r){"use strict";var n=t("fast-isnumeric");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{"fast-isnumeric":227}],743:[function(t,e,r){"use strict";var n=e.exports={},a=t("../plots/geo/constants").locationmodeToLayer,i=t("topojson-client").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,"-"),"_",t.resolution.toString(),"m"].join("")},n.getTopojsonPath=function(t,e){return t+e+".json"},n.getTopojsonFeatures=function(t,e){var r=a[t.locationmode],n=e.objects[r];return i(e,n).features}},{"../plots/geo/constants":792,"topojson-client":538}],744:[function(t,e,r){"use strict";e.exports={moduleType:"locale",name:"en-US",dictionary:{"Click to enter Colorscale title":"Click to enter Colorscale title"},format:{date:"%m/%d/%Y"}}},{}],745:[function(t,e,r){"use strict";e.exports={moduleType:"locale",name:"en",dictionary:{"Click to enter Colorscale title":"Click to enter Colourscale title"},format:{days:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],shortDays:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],months:["January","February","March","April","May","June","July","August","September","October","November","December"],shortMonths:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],periods:["AM","PM"],dateTime:"%a %b %e %X %Y",date:"%d/%m/%Y",time:"%H:%M:%S",decimal:".",thousands:",",grouping:[3],currency:["$",""],year:"%Y",month:"%b %Y",dayMonth:"%b %-d",dayMonthYear:"%b %-d, %Y"}}},{}],746:[function(t,e,r){"use strict";var n=t("../registry");e.exports=function(t){for(var e,r,a=n.layoutArrayContainers,i=n.layoutArrayRegexes,o=t.split("[")[0],s=0;s<i.length;s++)if((r=t.match(i[s]))&&0===r.index){e=r[0];break}if(e||(e=a[a.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\[(0|[1-9][0-9]*)\](\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||""}:{array:e,index:"",property:""}}},{"../registry":845}],747:[function(t,e,r){"use strict";var n=t("../lib"),a=n.extendFlat,i=n.isPlainObject,o={valType:"flaglist",extras:["none"],flags:["calc","clearAxisTypes","plot","style","markerSize","colorbars"]},s={valType:"flaglist",extras:["none"],flags:["calc","plot","legend","ticks","axrange","layoutstyle","modebar","camera","arraydraw","colorbars"]},l=o.flags.slice().concat(["fullReplot"]),c=s.flags.slice().concat("layoutReplot");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function h(t,e,r){var n=a({},t);for(var o in n){var s=n[o];i(s)&&(n[o]=f(s,e,r,o))}return"from-root"===r&&(n.editType=e),n}function f(t,e,r,n){if(t.valType){var i=a({},t);if(i.editType=e,Array.isArray(t.items)){i.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)i.items[o]=f(t.items[o],e,"from-root")}return i}return h(t,e,"_"===n.charAt(0)?"nested":"from-root")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&"none"!==r)for(var n=r.split("+"),a=0;a<n.length;a++)t[n[a]]=!0},overrideAll:h}},{"../lib":716}],748:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("gl-mat4/fromQuat"),i=t("../registry"),o=t("../lib"),s=t("../plots/plots"),l=t("../plots/cartesian/axis_ids"),c=t("../components/color"),u=l.cleanId,h=l.getFromTrace,f=i.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&"paper"!==r&&(t[e]=u(r,n))}function d(t){function e(e,r){var n=t[e],a=t.title&&t.title[r];n&&!a&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&("string"!=typeof t.title&&"number"!=typeof t.title||(t.title={text:t.title}),e("titlefont","font"),e("titleposition","position"),e("titleside","side"),e("titleoffset","offset"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,("string"==typeof e||"number"==typeof e)&&String(e)}function v(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var a,i=Math.min(t.length,e.length);for(a=0;a<i&&t.charAt(a)===e.charAt(a);a++);return t.substr(0,a).trim()}function m(t){var e="middle",r="center";return"string"==typeof t&&(-1!==t.indexOf("top")?e="top":-1!==t.indexOf("bottom")&&(e="bottom"),-1!==t.indexOf("left")?r="left":-1!==t.indexOf("right")&&(r="right")),e+" "+r}function y(t,e){return e in t&&"object"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log("Clearing previous rejected promises from queue."),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var i=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var v=g[e];if(i&&i.test(v)){var m=t[v];m.anchor&&"free"!==m.anchor&&(m.anchor=u(m.anchor)),m.overlaying&&(m.overlaying=u(m.overlaying)),m.type||(m.isdate?m.type="date":m.islog?m.type="log":!1===m.isdate&&!1===m.islog&&(m.type="linear")),"withzero"!==m.autorange&&"tozero"!==m.autorange||(m.autorange=!0,m.rangemode="tozero"),delete m.islog,delete m.isdate,delete m.categories,y(m,"domain")&&delete m.domain,void 0!==m.autotick&&(void 0===m.tickmode&&(m.tickmode=m.autotick?"auto":"linear"),delete m.autotick),d(m)}else if(l&&l.test(v)){d(t[v].radialaxis)}else if(h&&h.test(v)){var x=t[v];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(v)){var b=t[v],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],k=_[1],T=_[2],A=a([],w),M=[];for(n=0;n<3;++n)M[n]=k[n]+T*A[2+4*n];b.camera={eye:{x:M[0],y:M[1],z:M[2]},center:{x:k[0],y:k[1],z:k[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&("paper"===E.ref?(E.xref="paper",E.yref="paper"):"data"===E.ref&&(E.xref="x",E.yref="y"),delete E.ref),p(E,"xref"),p(E,"yref"))}var L=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<L;e++){var C=t.shapes[e];o.isPlainObject(C)&&(p(C,"xref"),p(C,"yref"))}var P=t.legend;return P&&(P.x>3?(P.x=1.02,P.xanchor="left"):P.x<-2&&(P.x=-.02,P.xanchor="right"),P.y>3?(P.y=1.02,P.yanchor="bottom"):P.y<-2&&(P.y=-.02,P.yanchor="top")),d(t),"rotate"===t.dragmode&&(t.dragmode="orbit"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,a=t[e];if("histogramy"===a.type&&"xbins"in a&&!("ybins"in a)&&(a.ybins=a.xbins,delete a.xbins),a.error_y&&"opacity"in a.error_y){var l=c.defaults,h=a.error_y.color||(f(a,"bar")?c.defaultLine:l[e%l.length]);a.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*a.error_y.opacity),delete a.error_y.opacity}if("bardir"in a&&("h"!==a.bardir||!f(a,"bar")&&"histogram"!==a.type.substr(0,9)||(a.orientation="h",r.swapXYData(a)),delete a.bardir),"histogramy"===a.type&&r.swapXYData(a),"histogramx"!==a.type&&"histogramy"!==a.type||(a.type="histogram"),"scl"in a&&!("colorscale"in a)&&(a.colorscale=a.scl,delete a.scl),"reversescl"in a&&!("reversescale"in a)&&(a.reversescale=a.reversescl,delete a.reversescl),a.xaxis&&(a.xaxis=u(a.xaxis,"x")),a.yaxis&&(a.yaxis=u(a.yaxis,"y")),f(a,"gl3d")&&a.scene&&(a.scene=s.subplotsRegistry.gl3d.cleanId(a.scene)),!f(a,"pie-like")&&!f(a,"bar-like"))if(Array.isArray(a.textposition))for(n=0;n<a.textposition.length;n++)a.textposition[n]=m(a.textposition[n]);else a.textposition&&(a.textposition=m(a.textposition));var p=i.getModule(a);if(p&&p.colorbar){var x=p.colorbar.container,b=x?a[x]:a;b&&b.colorscale&&("YIGnBu"===b.colorscale&&(b.colorscale="YlGnBu"),"YIOrRd"===b.colorscale&&(b.colorscale="YlOrRd"))}if("surface"===a.type&&o.isPlainObject(a.contours)){var _=["x","y","z"];for(n=0;n<_.length;n++){var w=a.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if("candlestick"===a.type||"ohlc"===a.type){var k=!1!==(a.increasing||{}).showlegend,T=!1!==(a.decreasing||{}).showlegend,A=g(a.increasing),M=g(a.decreasing);if(!1!==A&&!1!==M){var S=v(A,M,k,T);S&&(a.name=S)}else!A&&!M||a.name||(a.name=A||M)}if(Array.isArray(a.transforms)){var E=a.transforms;for(n=0;n<E.length;n++){var L=E[n];if(o.isPlainObject(L))switch(L.type){case"filter":L.filtersrc&&(L.target=L.filtersrc,delete L.filtersrc),L.calendar&&(L.valuecalendar||(L.valuecalendar=L.calendar),delete L.calendar);break;case"groupby":if(L.styles=L.styles||L.style,L.styles&&!Array.isArray(L.styles)){var C=L.styles,P=Object.keys(C);L.styles=[];for(var O=0;O<P.length;O++)L.styles.push({target:P[O],value:C[P[O]]})}}}}y(a,"line")&&delete a.line,"marker"in a&&(y(a.marker,"line")&&delete a.marker.line,y(a,"marker")&&delete a.marker),c.clean(a),a.autobinx&&(delete a.autobinx,delete a.xbins),a.autobiny&&(delete a.autobiny,delete a.ybins),d(a),a.colorbar&&d(a.colorbar),a.marker&&a.marker.colorbar&&d(a.marker.colorbar),a.line&&a.line.colorbar&&d(a.line.colorbar),a.aaxis&&d(a.aaxis),a.baxis&&d(a.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,["?","?0","d?","?bins","nbins?","autobin?","?src","error_?"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n="copy_ystyle"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,["error_?.copy_ystyle"]),n&&o.swapAttrs(t,["error_?.color","error_?.thickness","error_?.width"])}if("string"==typeof t.hoverinfo){var a=t.hoverinfo.split("+");for(e=0;e<a.length;e++)"x"===a[e]?a[e]="y":"y"===a[e]&&(a[e]="x");t.hoverinfo=a.join("+")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map(function(t,e){return e});if(Array.isArray(e)){for(var r=[],a=0;a<e.length;a++)o.isIndex(e[a],t.data.length)?r.push(e[a]):o.warn("trace index (",e[a],") is not a number or is out of bounds");return r}return e},r.manageArrayContainers=function(t,e,r){var a=t.obj,i=t.parts,s=i.length,l=i[s-1],c=n(l);if(c&&null===e){var u=i.slice(0,s-1).join(".");o.nestedProperty(a,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\.[^\[\]\.]+|\[[^\[\]\.]+\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=["x","y","z"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var a=t._fullData[n],i=0;i<3;i++){var s=h(t,a,_[i]);if(s&&"log"!==s.type){var l=s._name,c=s._id.substr(1);if("scene"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+"."+l}var u=l+".type";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{"../components/color":591,"../lib":716,"../plots/cartesian/axis_ids":767,"../plots/plots":825,"../registry":845,"fast-isnumeric":227,"gl-mat4/fromQuat":264}],749:[function(t,e,r){"use strict";var n=t("./plot_api");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t("./to_image"),r.validate=t("./validate"),r.downloadImage=t("../snapshot/download");var a=t("./template_api");r.makeTemplate=a.makeTemplate,r.validateTemplate=a.validateTemplate},{"../snapshot/download":847,"./plot_api":751,"./template_api":756,"./to_image":757,"./validate":758}],750:[function(t,e,r){"use strict";var n=t("../lib/is_plain_object"),a=t("../lib/noop"),i=t("../lib/loggers"),o=t("../lib/search").sorterAsc,s=t("../registry");r.containerArrayMatch=t("./container_array_match");var l=r.isAddVal=function(t){return"add"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||"remove"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,"supplyLayoutDefaults"),p=s.getComponentMethod(h,"draw"),d=s.getComponentMethod(h,"drawOne"),g=n.replot||n.recalc||f===a||p===a,v=t.layout,m=t._fullLayout;if(r[""]){Object.keys(r).length>1&&i.warn("Full array edits are incompatible with other edits",h);var y=r[""][""];if(c(y))e.set(null);else{if(!Array.isArray(y))return i.warn("Unrecognized full array edit value",h,y),!0;e.set(y)}return!g&&(f(v,m),p(t),!0)}var x,b,_,w,k,T,A,M,S=Object.keys(r).map(Number).sort(o),E=e.get(),L=E||[],C=u(m,h).get(),P=[],O=-1,z=L.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],k=Object.keys(w),T=w[""],A=l(T),_<0||_>L.length-(A?0:1))i.warn("index out of range",h,_);else if(void 0!==T)k.length>1&&i.warn("Insertion & removal are incompatible with edits to the same index.",h,_),c(T)?P.push(_):A?("add"===T&&(T={}),L.splice(_,0,T),C&&C.splice(_,0,{})):i.warn("Unrecognized full object edit value",h,_,T),-1===O&&(O=_);else for(b=0;b<k.length;b++)M=h+"["+_+"].",u(L[_],k[b],M).set(w[k[b]]);for(x=P.length-1;x>=0;x--)L.splice(P[x],1),C&&C.splice(P[x],1);if(L.length?E||e.set(L):e.set(null),g)return!1;if(f(v,m),d!==a){var I;if(-1===O)I=S;else{for(z=Math.max(L.length,z),I=[],x=0;x<S.length&&!((_=S[x])>=O);x++)I.push(_);for(x=O;x<z;x++)I.push(x)}for(x=0;x<I.length;x++)d(t,I[x])}else p(t);return!0}},{"../lib/is_plain_object":717,"../lib/loggers":720,"../lib/noop":725,"../lib/search":735,"../registry":845,"./container_array_match":746}],751:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("has-hover"),o=t("../lib"),s=o.nestedProperty,l=t("../lib/events"),c=t("../lib/queue"),u=t("../registry"),h=t("./plot_schema"),f=t("../plots/plots"),p=t("../plots/polar/legacy"),d=t("../plots/cartesian/axes"),g=t("../components/drawing"),v=t("../components/color"),m=t("../plots/cartesian/graph_interact").initInteractions,y=t("../constants/xmlns_namespaces"),x=t("../lib/svg_text_utils"),b=t("../plots/cartesian/select").clearSelect,_=t("./plot_config").dfltConfig,w=t("./manage_arrays"),k=t("./helpers"),T=t("./subroutines"),A=t("./edit_types"),M=t("../plots/cartesian/constants").AX_NAME_PATTERN,S=0,E=5;function L(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit("plotly_afterplot")}function C(t,e){try{t._fullLayout._paper.style("background",e)}catch(t){o.error(t)}}function P(t,e){C(t,v.combine(e,"white"))}function O(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select("base");t._context._baseUrl=r.size()&&r.attr("href")?window.location.href.split("#")[0]:""}var a,s,l,c=t._context;if(e){for(s=Object.keys(e),a=0;a<s.length;a++)"editable"!==(l=s[a])&&"edits"!==l&&l in c&&("setBackground"===l&&"opaque"===e[l]?c[l]=P:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),a=0;a<s.length;a++)c.edits[s[a]]=u;if(e.edits)for(s=Object.keys(e.edits),a=0;a<s.length;a++)(l=s[a])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),"hover"!==c.displayModeBar||i||(c.displayModeBar=!0),"transparent"!==c.setBackground&&"function"==typeof c.setBackground||(c.setBackground=C),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1;else if("string"==typeof h){var p=h.split("+");for(a=0;a<p.length;a++)f[p[a]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1)}function z(t,e){var r,n,a=e+1,i=[];for(r=0;r<t.length;r++)(n=t[r])<0?i.push(a+n):i.push(n);return i}function I(t,e,r){var n,a;for(n=0;n<e.length;n++){if((a=e[n])!==parseInt(a,10))throw new Error("all values in "+r+" must be integers");if(a>=t.data.length||a<-t.data.length)throw new Error(r+" must be valid indices for gd.data.");if(e.indexOf(a,n+1)>-1||a>=0&&e.indexOf(-t.data.length+a)>-1||a<0&&e.indexOf(t.data.length+a)>-1)throw new Error("each index in "+r+" must be unique.")}}function D(t,e,r){if(!Array.isArray(t.data))throw new Error("gd.data must be an array.");if("undefined"==typeof e)throw new Error("currentIndices is a required argument.");if(Array.isArray(e)||(e=[e]),I(t,e,"currentIndices"),"undefined"==typeof r||Array.isArray(r)||(r=[r]),"undefined"!=typeof r&&I(t,r,"newIndices"),"undefined"!=typeof r&&e.length!==r.length)throw new Error("current and new indices must be of equal length.")}function R(t,e,r,n,i){!function(t,e,r,n){var a=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error("gd.data must be an array");if(!o.isPlainObject(e))throw new Error("update must be a key:value object");if("undefined"==typeof r)throw new Error("indices must be an integer or array of integers");for(var i in I(t,r,"indices"),e){if(!Array.isArray(e[i])||e[i].length!==r.length)throw new Error("attribute "+i+" must be an array of length equal to indices array length");if(a&&(!(i in n)||!Array.isArray(n[i])||n[i].length!==e[i].length))throw new Error("when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object")}}(t,e,r,n);for(var l=function(t,e,r,n){var i,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=z(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(i=t.data[r[g]],l=(c=s(i,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error("attribute: "+d+" index: "+g+" must be an array");if(!o.isArrayOrTypedArray(l))throw new Error("cannot extend missing or non-array attribute: "+d);if(l.constructor!==u.constructor)throw new Error("cannot extend array with an array of a different type: "+d);h=f?n[d][g]:n,a(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=i(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function F(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function B(t,e,n,a){t=o.getGraphDiv(t),k.clearPromiseQueue(t);var i={};if("string"==typeof e)i[e]=n;else{if(!o.isPlainObject(e))return o.warn("Restyle fail.",e,n,a),Promise.reject();i=o.extendFlat({},e),void 0===a&&(a=n)}Object.keys(i).length&&(t.changed=!0);var s=k.coerceTraceIndices(t,a),l=U(t,i,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&k.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(r.plot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),Y(h)),u.style&&h.push(T.doTraceStyle),u.colorbars&&h.push(T.doColorBars),h.push(L)),h.push(f.rehover,f.redrag),c.add(t,B,[t,l.undoit,l.traces],B,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then(function(){return t.emit("plotly_restyle",l.eventData),t})}function N(t){return void 0===t?null:t}function j(t,e){return e?function(e,r,n){var a=s(e,r),i=a.set;return a.set=function(e){V((n||"")+r,a.get(),e,t),i(e)},a}:s}function V(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var a=Array.isArray(e)?e:[],i=Array.isArray(r)?r:[],s=Math.max(a.length,i.length),l=0;l<s;l++)V(t+"["+l+"]",a[l],i[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)V(t+"."+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=N(e))}function U(t,e,r){var n,a=t._fullLayout,i=t._fullData,l=t.data,c=a._guiEditing,p=j(a._preGUI,c),g=o.extendDeepAll({},e);q(e);var v,m=A.traceFlags(),y={},x={};function b(){return r.map(function(){})}function _(t){var e=d.id2name(t);-1===v.indexOf(e)&&v.push(e)}function w(t){return"LAYOUT"+t+".autorange"}function T(t){return"LAYOUT"+t+".range"}function M(t){for(var e=t;e<i.length;e++)if(i[e]._input===l[t])return i[e]}function S(n,i,o){if(Array.isArray(n))n.forEach(function(t){S(t,i,o)});else if(!(n in e||k.hasParent(e,n))){var s;if("LAYOUT"===n.substr(0,6))s=p(t.layout,n.replace("LAYOUT",""));else{var u=r[o];s=j(a._tracePreGUI[M(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=N(s.get())),void 0!==i&&s.set(i)}}function E(t){return function(e){return i[e][t]}}function L(t){return function(e,n){return!1===e?i[r[n]][t]:null}}for(var C in e){if(k.hasParent(e,C))throw new Error("cannot set "+C+" and a parent attribute simultaneously");var P,O,z,I,D,R,F=e[C];if("autobinx"!==C&&"autobiny"!==C||(C=C.charAt(C.length-1)+"bins",F=Array.isArray(F)?F.map(L(C)):!1===F?r.map(E(C)):null),y[C]=F,"LAYOUT"!==C.substr(0,6)){for(x[C]=b(),n=0;n<r.length;n++){if(P=l[r[n]],O=M(r[n]),I=(z=j(a._tracePreGUI[O._fullInput.uid],c)(P,C)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var B=z.parts[z.parts.length-1],V=C.substr(0,C.length-B.length-1),U=V?V+".":"",H=V?s(O,V).get():O;if((R=h.getTraceValObject(O,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(C,G),R.impliedEdits[G],n);else if("thicknessmode"!==B&&"lenmode"!==B||I===D||"fraction"!==D&&"pixels"!==D||!H){if("type"===C&&("pie"===D!=("pie"===I)||"funnelarea"===D!=("funnelarea"===I))){var Y="x",W="y";"bar"!==D&&"bar"!==I||"h"!==P.orientation||(Y="y",W="x"),o.swapAttrs(P,["?","?src"],"labels",Y),o.swapAttrs(P,["d?","?0"],"label",Y),o.swapAttrs(P,["?","?src"],"values",W),"pie"===I||"funnelarea"===I?(s(P,"marker.color").set(s(P,"marker.colors").get()),a._pielayer.selectAll("g.trace").remove()):u.traceIs(P,"cartesian")&&s(P,"marker.colors").set(s(P,"marker.color").get())}}else{var X=a._size,Z=H.orient,J="top"===Z||"bottom"===Z;if("thicknessmode"===B){var K=J?X.h:X.w;S(U+"thickness",H.thickness*("fraction"===D?1/K:K),n)}else{var Q=J?X.w:X.h;S(U+"len",H.len*("fraction"===D?1/Q:Q),n)}}x[C][n]=N(I);if(-1!==["swapxy","swapxyaxes","orientation","orientationaxes"].indexOf(C)){if("orientation"===C){z.set(D);var $=P.x&&!P.y?"h":"v";if((z.get()||$)===O.orientation)continue}else"orientationaxes"===C&&(P.orientation={v:"h",h:"v"}[O.orientation]);k.swapXYData(P),m.calc=m.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(k.manageArrayContainers(z,D,x),m.calc=!0):(R?R.arrayOk&&!u.traceIs(O,"regl")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(I))?m.calc=!0:A.update(m,R):m.calc=!0,z.set(D))}}if(-1!==["swapxyaxes","orientationaxes"].indexOf(C)&&d.swap(t,r),"orientationaxes"===C){var tt=s(t.layout,"hovermode");"x"===tt.get()?tt.set("y"):"y"===tt.get()&&tt.set("x")}if(-1!==["orientation","type"].indexOf(C)){for(v=[],n=0;n<r.length;n++){var et=l[r[n]];u.traceIs(et,"cartesian")&&(_(et.xaxis||"x"),_(et.yaxis||"y"))}S(v.map(w),!0,0),S(v.map(T),[0,1],0)}}else z=p(t.layout,C.replace("LAYOUT","")),x[C]=[N(z.get())],z.set(Array.isArray(F)?F[0]:F),m.calc=!0}return(m.calc||m.plot)&&(m.fullReplot=!0),{flags:m,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function q(t){var e,r,n,a=o.counterRegex("axis",".title",!1,!1),i=/colorbar\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],"title"!==r&&!a.test(r)&&!i.test(r)||"string"!=typeof n&&"number"!=typeof n?r.indexOf("titlefont")>-1?l(r,r.replace("titlefont","title.font")):r.indexOf("titleposition")>-1?l(r,r.replace("titleposition","title.position")):r.indexOf("titleside")>-1?l(r,r.replace("titleside","title.side")):r.indexOf("titleoffset")>-1&&l(r,r.replace("titleoffset","title.offset")):l(r,r.replace("title","title.text"));function l(e,r){t[r]=t[e],delete t[e]}}function H(t,e,r){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if("string"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn("Relayout fail.",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var a=J(t,n),i=a.flags;i.calc&&(t.calcdata=void 0);var s=[f.previousPromises];i.layoutReplot?s.push(T.layoutReplot):Object.keys(n).length&&(G(t,i,a)||f.supplyDefaults(t),i.legend&&s.push(T.doLegend),i.layoutstyle&&s.push(T.layoutStyles),i.axrange&&Y(s,a.rangesAltered),i.ticks&&s.push(T.doTicksRelayout),i.modebar&&s.push(T.doModeBar),i.camera&&s.push(T.doCamera),i.colorbars&&s.push(T.doColorBars),s.push(L)),s.push(f.rehover,f.redrag),c.add(t,H,[t,a.undoit],H,[t,a.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then(function(){return t.emit("plotly_relayout",a.eventData),t})}function G(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var a in e)if("axrange"!==a&&e[a])return!1;for(var i in r.rangesAltered){var o=d.id2name(i),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,l.range=s.range.slice(),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==i){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function Y(t,e){var r=e?function(t){var r=[],n=!0;for(var a in e){var i=d.getFromId(t,a);if(r.push(a),i._matchGroup)for(var o in i._matchGroup)e[o]||r.push(o);i.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,"redraw")};t.push(b,T.doAutoRangeAndConstraints,r,T.drawData,T.finalDraw)}var W=/^[xyz]axis[0-9]*\.range(\[[0|1]\])?$/,X=/^[xyz]axis[0-9]*\.autorange$/,Z=/^[xyz]axis[0-9]*\.domain(\[[0|1]\])?$/;function J(t,e){var r,n,a,i=t.layout,l=t._fullLayout,c=l._guiEditing,f=j(l._preGUI,c),p=Object.keys(e),g=d.list(t),v=o.extendDeepAll({},e),m={};for(q(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf("allaxes")){for(a=0;a<g.length;a++){var y=g[a]._id.substr(1),x=-1!==y.indexOf("scene")?y+".":"",b=p[n].replace("allaxes",x+g[a]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=A.layoutFlags(),T={},S={};function E(t,r){if(Array.isArray(t))t.forEach(function(t){E(t,r)});else if(!(t in e||k.hasParent(e,t))){var n=f(i,t);t in S||(S[t]=N(n.get())),void 0!==r&&n.set(r)}}var L,C={};function P(t){var e=d.name2id(t.split(".")[0]);return C[e]=1,e}for(var O in e){if(k.hasParent(e,O))throw new Error("cannot set "+O+" and a parent attribute simultaneously");for(var z=f(i,O),I=e[O],D=z.parts.length-1;D>0&&"string"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+"."+R,B=z.parts.slice(0,D).join("."),V=s(t.layout,B).get(),U=s(l,B).get(),H=z.get();if(void 0!==I){T[O]=I,S[O]="reverse"===R?I:N(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==I)for(var Y in G.impliedEdits)E(o.relativeAttr(O,Y),G.impliedEdits[Y]);if(-1!==["width","height"].indexOf(O))if(I){E("autosize",null);var J="height"===O?"width":"height";E(J,l[J])}else l[O]=t._initialAutoSize[O];else if("autosize"===O)E("width",I?null:l.width),E("height",I?null:l.height);else if(F.match(W))P(F),s(l,B+"._inputRange").set(null);else if(F.match(X)){P(F),s(l,B+"._inputRange").set(null);var Q=s(l,B).get();Q._inputDomain&&(Q._input.domain=Q._inputDomain.slice())}else F.match(Z)&&s(l,B+"._inputDomain").set(null);if("type"===R){var $=V,tt="linear"===U.type&&"log"===I,et="log"===U.type&&"linear"===I;if(tt||et){if($&&$.range)if(U.autorange)tt&&($.range=$.range[1]>$.range[0]?[1,2]:[2,1]);else{var rt=$.range[0],nt=$.range[1];tt?(rt<=0&&nt<=0&&E(B+".autorange",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),E(B+".range[0]",Math.log(rt)/Math.LN10),E(B+".range[1]",Math.log(nt)/Math.LN10)):(E(B+".range[0]",Math.pow(10,rt)),E(B+".range[1]",Math.pow(10,nt)))}else E(B+".autorange",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&"radialaxis"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial["radialaxis.range"],u.getComponentMethod("annotations","convertCoords")(t,U,I,E),u.getComponentMethod("images","convertCoords")(t,U,I,E)}else E(B+".autorange",!0),E(B+".range",null);s(l,B+"._inputRange").set(null)}else if(R.match(M)){var at=s(l,O).get(),it=(I||{}).type;it&&"-"!==it||(it="linear"),u.getComponentMethod("annotations","convertCoords")(t,at,it,E),u.getComponentMethod("images","convertCoords")(t,at,it,E)}var ot=w.containerArrayMatch(O);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:"calc"};""!==n&&""===st&&(w.isAddVal(I)?S[O]=null:w.isRemoveVal(I)?S[O]=(s(i,r).get()||[])[n]:o.warn("unrecognized full object value",e)),A.update(_,lt),m[r]||(m[r]={});var ct=m[r][n];ct||(ct=m[r][n]={}),ct[st]=I,delete e[O]}else"reverse"===R?(V.range?V.range.reverse():(E(B+".autorange",!0),V.range=[1,0]),U.autorange?_.calc=!0:_.plot=!0):(l._has("scatter-like")&&l._has("regl")&&"dragmode"===O&&("lasso"===I||"select"===I)&&"lasso"!==H&&"select"!==H?_.plot=!0:l._has("gl2d")?_.plot=!0:G?A.update(_,G):_.calc=!0,z.set(I))}}for(r in m){w.applyContainerArrayChanges(t,f(i,r),m[r],_,f)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(L in C)for(n=0;n<ut.length;n++){var ht=ut[n];if(ht[L])for(var ft in _.calc=!0,ht)C[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(K(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:C,undoit:S,redoit:T,eventData:v}}function K(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function Q(t,e,n,a){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var i=k.coerceTraceIndices(t,a),s=U(t,o.extendFlat({},e),i),l=s.flags,u=J(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&k.clearAxisTypes(t,i,n);var p=[];h.layoutReplot?p.push(T.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(f.previousPromises),G(t,h,u)||f.supplyDefaults(t),l.style&&p.push(T.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(T.doColorBars),h.legend&&p.push(T.doLegend),h.layoutstyle&&p.push(T.layoutStyles),h.axrange&&Y(p,u.rangesAltered),h.ticks&&p.push(T.doTicksRelayout),h.modebar&&p.push(T.doModeBar),h.camera&&p.push(T.doCamera),p.push(L)),p.push(f.rehover,f.redrag),c.add(t,Q,[t,s.undoit,u.undoit,s.traces],Q,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then(function(){return t.emit("plotly_update",{data:s.eventData,layout:u.eventData}),t})}function $(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var tt=[{pattern:/^hiddenlabels/,attr:"legend.uirevision"},{pattern:/^((x|y)axis\d*)\.((auto)?range|title\.text)/},{pattern:/axis\d*\.showspikes$/,attr:"modebar.uirevision"},{pattern:/(hover|drag)mode$/,attr:"modebar.uirevision"},{pattern:/^(scene\d*)\.camera/},{pattern:/^(geo\d*)\.(projection|center)/},{pattern:/^(ternary\d*\.[abc]axis)\.(min|title\.text)$/},{pattern:/^(polar\d*\.radialaxis)\.((auto)?range|angle|title\.text)/},{pattern:/^(polar\d*\.angularaxis)\.rotation/},{pattern:/^(mapbox\d*)\.(center|zoom|bearing|pitch)/},{pattern:/^legend\.(x|y)$/,attr:"editrevision"},{pattern:/^(shapes|annotations)/,attr:"editrevision"},{pattern:/^title\.text$/,attr:"editrevision"}],et=[{pattern:/^selectedpoints$/,attr:"selectionrevision"},{pattern:/(^|value\.)visible$/,attr:"legend.uirevision"},{pattern:/^dimensions\[\d+\]\.constraintrange/},{pattern:/^node\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\.)name$/},{pattern:/colorbar\.title\.text$/},{pattern:/colorbar\.(x|y)$/,attr:"editrevision"}];function rt(t,e){for(var r=0;r<e.length;r++){var n=e[r],a=t.match(n.pattern);if(a)return{head:a[1],attr:n.attr}}}function nt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(".");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(".")+".uirevision").get()))return r;return e.uirevision}function at(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function it(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function ot(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function st(t,e,r,n){var a,i,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=a.editType;f&&-1!==t.indexOf("arraydraw")?o.pushUnique(u.arrays[f],p):(A.update(u,a),"none"!==t&&u.nChanges++,n.transition&&a.anim&&u.nChangesAnim++,(W.test(l)||X.test(l))&&(u.rangesAltered[r[0]]=1),Z.test(l)&&s(e,"_inputDomain").set(null),"datarevision"===i&&(u.newDataRevision=1))}function g(t){return"data_array"===t.valType||t.arrayOk}for(i in t){if(u.calc&&!n.transition)return;var v=t[i],m=e[i],y=r.concat(i);if(l=y.join("."),"_"!==i.charAt(0)&&"function"!=typeof v&&v!==m){if(("tick0"===i||"dtick"===i)&&"geo"!==r[0]){var x=e.tickmode;if("auto"===x||"array"===x||!x)continue}if(("range"!==i||!e.autorange)&&("zmin"!==i&&"zmax"!==i||"contourcarpet"!==e.type)&&(a=c(y))&&(!a._compareAsJSON||JSON.stringify(v)!==JSON.stringify(m))){var b,_=a.valType,w=g(a),k=Array.isArray(v),T=Array.isArray(m);if(k&&T){var M="_input_"+i,S=t[M],E=e[M];if(Array.isArray(S)&&S===E)continue}if(void 0===m)w&&k?u.calc=!0:d();else if(a._isLinkedToArray){var L=[],C=!1;f||(u.arrays[i]=L);var P=Math.min(v.length,m.length),O=Math.max(v.length,m.length);if(P!==O){if("arraydraw"!==a.editType){d();continue}C=!0}for(b=0;b<P;b++)st(v[b],m[b],y.concat(b),o.extendFlat({inArray:i,arrayIndex:b},n));if(C)for(b=P;b<O;b++)L.push(b)}else!_&&o.isPlainObject(v)?st(v,m,y,n):w?k&&T?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):k!==T?u.calc=!0:d():k&&T&&v.length===m.length&&String(v)===String(m)||d()}}}for(i in e)if(!(i in t||"_"===i.charAt(0)||"function"==typeof e[i])){if(g(a=c(r.concat(i)))&&Array.isArray(e[i]))return void(u.calc=!0);d()}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(".plot-container").data([0]),r._container.enter().insert("div",":first-child").classed("plot-container",!0).classed("plotly",!0),r._paperdiv=r._container.selectAll(".svg-container").data([0]),r._paperdiv.enter().append("div").classed("svg-container",!0).style("position","relative"),r._glcontainer=r._paperdiv.selectAll(".gl-container").data([{}]),r._glcontainer.enter().append("div").classed("gl-container",!0),r._paperdiv.selectAll(".main-svg").remove(),r._paperdiv.select(".modebar-container").remove(),r._paper=r._paperdiv.insert("svg",":first-child").classed("main-svg",!0),r._toppaper=r._paperdiv.append("svg").classed("main-svg",!0),r._modebardiv=r._paperdiv.append("div"),r._hoverpaper=r._paperdiv.append("svg").classed("main-svg",!0),!r._uid){var a={};n.selectAll("defs").each(function(){this.id&&(a[this.id.split("-")[1]]=1)}),r._uid=o.randstr(a)}r._paperdiv.selectAll(".main-svg").attr(y.svgAttrs),r._defs=r._paper.append("defs").attr("id","defs-"+r._uid),r._clips=r._defs.append("g").classed("clips",!0),r._topdefs=r._toppaper.append("defs").attr("id","topdefs-"+r._uid),r._topclips=r._topdefs.append("g").classed("clips",!0),r._bgLayer=r._paper.append("g").classed("bglayer",!0),r._draggers=r._paper.append("g").classed("draglayer",!0);var i=r._paper.append("g").classed("layer-below",!0);r._imageLowerLayer=i.append("g").classed("imagelayer",!0),r._shapeLowerLayer=i.append("g").classed("shapelayer",!0),r._cartesianlayer=r._paper.append("g").classed("cartesianlayer",!0),r._polarlayer=r._paper.append("g").classed("polarlayer",!0),r._ternarylayer=r._paper.append("g").classed("ternarylayer",!0),r._geolayer=r._paper.append("g").classed("geolayer",!0),r._funnelarealayer=r._paper.append("g").classed("funnelarealayer",!0),r._pielayer=r._paper.append("g").classed("pielayer",!0),r._treemaplayer=r._paper.append("g").classed("treemaplayer",!0),r._sunburstlayer=r._paper.append("g").classed("sunburstlayer",!0),r._indicatorlayer=r._toppaper.append("g").classed("indicatorlayer",!0),r._glimages=r._paper.append("g").classed("glimages",!0);var s=r._toppaper.append("g").classed("layer-above",!0);r._imageUpperLayer=s.append("g").classed("imagelayer",!0),r._shapeUpperLayer=s.append("g").classed("shapelayer",!0),r._infolayer=r._toppaper.append("g").classed("infolayer",!0),r._menulayer=r._toppaper.append("g").classed("menulayer",!0),r._zoomlayer=r._toppaper.append("g").classed("zoomlayer",!0),r._hoverlayer=r._hoverpaper.append("g").classed("hoverlayer",!0),r._modebardiv.classed("modebar-container",!0).style("position","absolute").style("top","0px").style("right","0px"),t.emit("plotly_framework")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error("This element is not a Plotly plot: "+t+". It's likely that you've failed to create a plot before animating it. For more details, see https://plot.ly/javascript/animations/");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var a=(r=f.supplyAnimationDefaults(r)).transition,i=r.frame;function s(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function l(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise(function(i,u){function h(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,k.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then(function(){e.onComplete&&e.onComplete()}),t.emit("plotly_animatingframe",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit("plotly_animated"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit("plotly_animating"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&h()};e()}var d,g,v=0;function m(t){return Array.isArray(a)?v>=a.length?t.transitionOpts=a[v]:t.transitionOpts=a[0]:t.transitionOpts=a,v++,t}var y=[],x=null==e,b=Array.isArray(e);if(x||b||!o.isPlainObject(e)){if(x||-1!==["string","number"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:"byname",name:String(g.name),data:m({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==["number","string"].indexOf(typeof _)?(_=String(_),y.push({type:"byname",name:_,data:m({name:_})})):o.isPlainObject(_)&&y.push({type:"object",data:m(o.extendFlat({},_))})}}else y.push({type:"object",data:m(o.extendFlat({},e))});for(d=0;d<y.length;d++)if("byname"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: "'+g.data.name+'"'),void u();-1!==["next","immediate"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit("plotly_animationinterrupted",[])}}(),"reverse"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var T=-1;for(d=0;d<y.length;d++)if("byname"===(g=y[d]).type&&g.name===w){T=d;break}if(T>0&&T<y.length-1){var A=[];for(d=0;d<y.length;d++)g=y[d],("byname"!==y[d].type||d>T)&&A.push(g);y=A}}y.length>0?function(e){if(0!==e.length){for(var a=0;a<e.length;a++){var o;o="byname"===e[a].type?f.computeFrame(t,e[a].name):e[a].data;var h=l(a),d=s(a);d.duration=Math.min(d.duration,h.duration);var g={frame:o,name:e[a].name,frameOpts:h,transitionOpts:d};a===e.length-1&&(g.onComplete=c(i,2),g.onInterrupt=u),n._frameQueue.push(g)}"immediate"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit("plotly_animated"),i())})},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error("This element is not a Plotly plot: "+t+". It's likely that you've failed to create a plot before adding frames. For more details, see https://plot.ly/javascript/animations/");var n,a,i,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error("addFrames failure: frameList must be an Array of frame definitions"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,v=(u[g]||d[g]||{}).name,m=e[n].name,y=u[v]||d[v];v&&m&&"number"==typeof m&&y&&S<E&&(S++,o.warn('addFrames: overwriting frame "'+(u[v]||d[v]).name+'" with a frame whose name of type "number" also equates to "'+v+'". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),S===E&&o.warn("addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.")),d[g]={name:g},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort(function(t,e){return t.index>e.index?-1:t.index<e.index?1:0});var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if("number"==typeof(a=p[n].frame).name&&o.warn("Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings"),!a.name)for(;u[a.name="frame "+t._transitionData._counter++];);if(u[a.name]){for(i=0;i<l.length&&(l[i]||{}).name!==a.name;i++);x.push({type:"replace",index:i,value:a}),b.unshift({type:"replace",index:i,value:l[i]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:"insert",index:s,value:a}),b.unshift({type:"delete",index:s}),_++}var w=f.modifyFrames,k=f.modifyFrames,T=[t,b],A=[t,x];return c&&c.add(t,w,T,k,A),f.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error("This element is not a Plotly plot: "+t);var r,n,a=t._transitionData._frames,i=[],s=[];if(!e)for(e=[],r=0;r<a.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],i.push({type:"delete",index:n}),s.unshift({type:"insert",index:n,value:a[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,i];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,i)},r.addTraces=function t(e,n,a){e=o.getGraphDiv(e);var i,s,l=[],u=r.deleteTraces,h=t,f=[e,l],p=[e,n];for(function(t,e,r){var n,a;if(!Array.isArray(t.data))throw new Error("gd.data must be an array.");if("undefined"==typeof e)throw new Error("traces must be defined.");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if("object"!=typeof(a=e[n])||Array.isArray(a)||null===a)throw new Error("all values in traces array must be non-array objects");if("undefined"==typeof r||Array.isArray(r)||(r=[r]),"undefined"!=typeof r&&r.length!==e.length)throw new Error("if indices is specified, traces.length must equal indices.length")}(e,n,a),Array.isArray(n)||(n=[n]),n=n.map(function(t){return o.extendFlat({},t)}),k.cleanData(n),i=0;i<n.length;i++)e.data.push(n[i]);for(i=0;i<n.length;i++)l.push(-n.length+i);if("undefined"==typeof a)return s=r.redraw(e),c.add(e,u,f,h,p),s;Array.isArray(a)||(a=[a]);try{D(e,l,a)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,f,h,p),s=r.moveTraces(e,l,a),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var a,i,s=[],l=r.addTraces,u=t,h=[e,s,n],f=[e,n];if("undefined"==typeof n)throw new Error("indices must be an integer or array of integers.");for(Array.isArray(n)||(n=[n]),I(e,n,"indices"),(n=z(n,e.data.length-1)).sort(o.sorterDes),a=0;a<n.length;a+=1)i=e.data.splice(n[a],1)[0],s.push(i);var p=r.redraw(e);return c.add(e,l,h,u,f),p},r.extendTraces=function t(e,n,a,i){var s=R(e=o.getGraphDiv(e),n,a,i,function(t,e,r){var n,a;if(o.isTypedArray(t))if(r<0){var i=new t.constructor(0),s=F(t,e);r<0?(n=s,a=i):(n=i,a=s)}else if(n=new t.constructor(r),a=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),a.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),a.set(t),a.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),a.set(t.subarray(0,u))}else n=t.concat(e),a=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,a]}),l=r.redraw(e),u=[e,s.update,a,s.maxPoints];return c.add(e,r.prependTraces,u,t,arguments),l},r.moveTraces=function t(e,n,a){var i,s=[],l=[],u=t,h=t,f=[e=o.getGraphDiv(e),a,n],p=[e,n,a];if(D(e,n,a),n=Array.isArray(n)?n:[n],"undefined"==typeof a)for(a=[],i=0;i<n.length;i++)a.push(-n.length+i);for(a=Array.isArray(a)?a:[a],n=z(n,e.data.length-1),a=z(a,e.data.length-1),i=0;i<e.data.length;i++)-1===n.indexOf(i)&&s.push(e.data[i]);for(i=0;i<n.length;i++)l.push({newIndex:a[i],trace:e.data[n[i]]});for(l.sort(function(t,e){return t.newIndex-e.newIndex}),i=0;i<l.length;i+=1)s.splice(l[i].newIndex,0,l[i].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,f,h,p),d},r.prependTraces=function t(e,n,a,i){var s=R(e=o.getGraphDiv(e),n,a,i,function(t,e,r){var n,a;if(o.isTypedArray(t))if(r<=0){var i=new t.constructor(0),s=F(e,t);r<0?(n=s,a=i):(n=i,a=s)}else if(n=new t.constructor(r),a=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),a.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),a.set(e.subarray(l)),a.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),a.set(t.subarray(c))}else n=e.concat(t),a=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,a]}),l=r.redraw(e),u=[e,s.update,a,s.maxPoints];return c.add(e,r.extendTraces,u,t,arguments),l},r.newPlot=function(t,e,n,a){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),r.plot(t,e,n,a)},r.plot=function(t,e,a,i){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,a=c.layout,i=c.config,s=c.frames}if(!1===l.triggerHandler(t,"plotly_beforeplot",[e,a,i]))return Promise.reject();e||a||o.isPlotDiv(t)||o.warn("Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.",t),O(t,i),a||(a={}),n.select(t).classed("js-plotly-plot",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(k.cleanData(e),h?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!h||(t.layout=k.cleanLayout(a)),f.supplyDefaults(t);var v=t._fullLayout,y=v._has("cartesian");if(!v._has("polar")&&e&&e[0]&&e[0].r)return o.log("Legacy polar charts are deprecated!"),function(t,e,r){var a=n.select(t).selectAll(".plot-container").data([0]);a.enter().insert("div",":first-child").classed("plot-container plotly",!0);var i=a.selectAll(".svg-container").data([0]);i.enter().append("div").classed("svg-container",!0).style("position","relative"),i.html(""),e&&(t.data=e),r&&(t.layout=r),p.manager.fillLayout(t),i.style({width:t._fullLayout.width+"px",height:t._fullLayout.height+"px"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},i.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:"";""!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},h=s.select(".title-group text").call(u);if(t._context.edits.titleText){var d=o._(t,"Click to enter Plot title");c&&c!==d||(l=.2,h.attr({"data-unformatted":d}).text(d).style({opacity:l}).on("mouseover.opacity",function(){n.select(this).transition().duration(100).style("opacity",1)}).on("mouseout.opacity",function(){n.select(this).transition().duration(1e3).style("opacity",0)}));var g=function(){this.call(x.makeEditable,{gd:t}).on("edit",function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)}).on("cancel",function(){var t=this.attr("data-unformatted");this.text(t).call(u)})};h.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),f.addLinks(t),Promise.resolve()}(t,e,a);v._replotting=!0,h&&lt(t),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),h&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener("resize",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},v._size),A=0;function M(){if(f.clearAutoMarginIds(t),T.drawMarginPushers(t),d.allowAutoMargin(t),v._has("pie"))for(var e=t._fullData,r=0;r<e.length;r++){var n=e[r];"pie"===n.type&&n.automargin&&f.allowAutoMargin(t,"pie."+n.uid+".automargin")}return f.doAutoMargin(t),f.previousPromises(t)}function S(){t._transitioning||(T.doAutoRangeAndConstraints(t),h&&d.saveRangeInitial(t),u.getComponentMethod("rangeslider","calcAutorange")(t))}var E=[f.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=v._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!v._glcanvas&&v._has("gl")&&(v._glcanvas=v._glcontainer.selectAll(".gl-canvas").data([{key:"contextLayer",context:!0,pick:!1},{key:"focusLayer",context:!1,pick:!1},{key:"pickLayer",context:!1,pick:!0}],function(t){return t.key}),v._glcanvas.enter().append("canvas").attr("class",function(t){return"gl-canvas gl-canvas-"+t.key.replace("Layer","")}).style({position:"absolute",top:0,left:0,overflow:"visible","pointer-events":"none"})),v._glcanvas){v._glcanvas.attr("width",v.width).attr("height",v.height);var a=v._glcanvas.data()[0].regl;if(a&&(Math.floor(v.width)!==a._gl.drawingBufferWidth||Math.floor(v.height)!==a._gl.drawingBufferHeight)){var i="WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.";if(!A)return o.log(i+" Clearing graph and plotting again."),f.cleanPlot([],{},t._fullData,v),f.supplyDefaults(t),v=t._fullLayout,f.doCalcdata(t),A++,e();o.error(i)}}return"h"===v.modebar.orientation?v._modebardiv.style("height",null).style("width","100%"):v._modebardiv.style("width",null).style("height",v.height+"px"),f.previousPromises(t)},M,function(){if(f.didMarginChange(w,v._size))return o.syncOrAsync([M,T.layoutStyles],t)}];y&&E.push(function(){if(b)return o.syncOrAsync([u.getComponentMethod("shapes","calcAutorange"),u.getComponentMethod("annotations","calcAutorange"),S],t);S()}),E.push(T.layoutStyles),y&&E.push(function(){return d.draw(t,h?"":"redraw")}),E.push(T.drawData,T.finalDraw,m,f.addLinks,f.rehover,f.redrag,f.doAutoMargin,f.previousPromises);var C=o.syncOrAsync(E,t);return C&&C.then||(C=Promise.resolve()),C.then(function(){return L(t),t})},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,a){var i,l;t=o.getGraphDiv(t),k.clearPromiseQueue(t);var c=t._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,a=d.config,i=d.frames}var g=!1;if(a){var v=o.extendDeep({},t._context);t._context=void 0,O(t,a),g=function t(e,r){var n;for(n in e)if("_"!==n.charAt(0)){var a=e[n],i=r[n];if(a!==i)if(o.isPlainObject(a)&&o.isPlainObject(i)){if(t(a,i))return!0}else{if(!Array.isArray(a)||!Array.isArray(i))return!0;if(a.length!==i.length)return!0;for(var s=0;s<a.length;s++)if(a[s]!==i[s]){if(!o.isPlainObject(a[s])||!o.isPlainObject(i[s]))return!0;if(t(a[s],i[s]))return!0}}}}(v,t._context)}t.data=e||[],k.cleanData(t.data),t.layout=n||{},k.cleanLayout(t.layout),function(t,e,r,n){var a,i,l,c,u,h,f,p,d=n._preGUI,g=[],v={};for(a in d){if(u=rt(a,tt)){if(i=u.attr||u.head+".uirevision",(c=(l=s(n,i).get())&&nt(i,e))&&c===l&&(null===(h=d[a])&&(h=void 0),ot(p=(f=s(e,a)).get(),h))){void 0===p&&"autorange"===a.substr(a.length-9)&&g.push(a.substr(0,a.length-10)),f.set(N(s(n,a).get()));continue}}else o.warn("unrecognized GUI edit: "+a);delete d[a],"range["===a.substr(a.length-8,6)&&(v[a.substr(0,a.length-9)]=1)}for(var m=0;m<g.length;m++){var y=g[m];if(v[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,k=b[_],T=null;for(a in k){if(!T){var A=at(_,r);if(A<0){delete b[_];break}var M=it(_,t,(w=r[A]._fullInput).index);if(M<0){delete b[_];break}T=t[M]}if(u=rt(a,et)){if(u.attr?c=(l=s(n,u.attr).get())&&nt(u.attr,e):(l=w.uirevision,void 0===(c=T.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=k[a])&&(h=void 0),ot(p=(f=s(T,a)).get(),h))){f.set(N(s(w,a).get()));continue}}else o.warn("unrecognized GUI edit: "+a+" in trace uid "+_);delete k[a]}}}(t.data,t.layout,c,p),f.supplyDefaults(t,{skipUpdateCalc:!0});var m=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,a){var i=A.layoutFlags();return i.arrays={},i.rangesAltered={},i.nChanges=0,i.nChangesAnim=0,st(e,r,[],{getValObject:function(t){return h.getLayoutValObject(r,t)},flags:i,immutable:n,transition:a,gd:t}),(i.plot||i.calc)&&(i.layoutReplot=!0),a&&i.nChanges&&i.nChangesAnim&&(i.anim=i.nChanges===i.nChangesAnim?"all":"some"),i}(t,p,y,x,b),w=_.newDataRevision,M=function(t,e,r,n,a,i){var o=e.length===r.length;if(!a&&!o)return{fullReplot:!0,calc:!0};var s,l,c=A.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:a,newDataRevision:i,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,st(e[s]._fullInput,l,[],u)}return(c.calc||c.plot)&&(c.fullReplot=!0),a&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?"all":"some"),c}(t,c,m,x,b,w);K(t)&&(_.layoutReplot=!0),M.calc||_.calc?t.calcdata=void 0:f.supplyDefaultsUpdateCalc(t.calcdata,m);var S=[];if(i&&(t._transitionData={},f.createTransitionData(t),S.push(function(){return r.addFrames(t,i)})),y.transition&&!g&&(M.anim||_.anim))f.doCalcdata(t),T.doAutoRangeAndConstraints(t),S.push(function(){return f.transitionFromReact(t,M,_,p)});else if(M.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,S.push(r.plot);else{for(var E in _.arrays){var C=_.arrays[E];if(C.length){var P=u.getComponentMethod(E,"drawOne");if(P!==o.noop)for(var z=0;z<C.length;z++)P(t,C[z]);else{var I=u.getComponentMethod(E,"draw");if(I===o.noop)throw new Error("cannot draw components: "+E);I(t)}}}S.push(f.previousPromises),M.style&&S.push(T.doTraceStyle),(M.colorbars||_.colorbars)&&S.push(T.doColorBars),_.legend&&S.push(T.doLegend),_.layoutstyle&&S.push(T.layoutStyles),_.axrange&&Y(S),_.ticks&&S.push(T.doTicksRelayout),_.modebar&&S.push(T.doModeBar),_.camera&&S.push(T.doCamera),S.push(L)}S.push(f.rehover,f.redrag),(l=o.syncOrAsync(S,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,a);return l.then(function(){return t.emit("plotly_react",{data:e,layout:n}),t})},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error("This element is not a Plotly plot: "+t);return k.cleanData(t.data),k.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then(function(){return t.emit("plotly_redraw"),t})},r.relayout=H,r.restyle=B,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=Q,r._guiRelayout=$(H),r._guiRestyle=$(B),r._guiUpdate=$(Q),r._storeDirectGUIEdit=function(t,e,r){for(var n in r)V(n,s(t,n).get(),r[n],e)}},{"../components/color":591,"../components/drawing":612,"../constants/xmlns_namespaces":693,"../lib":716,"../lib/events":706,"../lib/queue":731,"../lib/svg_text_utils":740,"../plots/cartesian/axes":764,"../plots/cartesian/constants":770,"../plots/cartesian/graph_interact":773,"../plots/cartesian/select":781,"../plots/plots":825,"../plots/polar/legacy":833,"../registry":845,"./edit_types":747,"./helpers":748,"./manage_arrays":750,"./plot_config":752,"./plot_schema":753,"./subroutines":755,d3:164,"fast-isnumeric":227,"has-hover":411}],752:[function(t,e,r){"use strict";var n={staticPlot:{valType:"boolean",dflt:!1},plotlyServerURL:{valType:"string",dflt:"https://plot.ly"},editable:{valType:"boolean",dflt:!1},edits:{annotationPosition:{valType:"boolean",dflt:!1},annotationTail:{valType:"boolean",dflt:!1},annotationText:{valType:"boolean",dflt:!1},axisTitleText:{valType:"boolean",dflt:!1},colorbarPosition:{valType:"boolean",dflt:!1},colorbarTitleText:{valType:"boolean",dflt:!1},legendPosition:{valType:"boolean",dflt:!1},legendText:{valType:"boolean",dflt:!1},shapePosition:{valType:"boolean",dflt:!1},titleText:{valType:"boolean",dflt:!1}},autosizable:{valType:"boolean",dflt:!1},responsive:{valType:"boolean",dflt:!1},fillFrame:{valType:"boolean",dflt:!1},frameMargins:{valType:"number",dflt:0,min:0,max:.5},scrollZoom:{valType:"flaglist",flags:["cartesian","gl3d","geo","mapbox"],extras:[!0,!1],dflt:"gl3d+geo+mapbox"},doubleClick:{valType:"enumerated",values:[!1,"reset","autosize","reset+autosize"],dflt:"reset+autosize"},doubleClickDelay:{valType:"number",dflt:300,min:0},showAxisDragHandles:{valType:"boolean",dflt:!0},showAxisRangeEntryBoxes:{valType:"boolean",dflt:!0},showTips:{valType:"boolean",dflt:!0},showLink:{valType:"boolean",dflt:!1},linkText:{valType:"string",dflt:"Edit chart",noBlank:!0},sendData:{valType:"boolean",dflt:!0},showSources:{valType:"any",dflt:!1},displayModeBar:{valType:"enumerated",values:["hover",!0,!1],dflt:"hover"},showSendToCloud:{valType:"boolean",dflt:!1},showEditInChartStudio:{valType:"boolean",dflt:!1},modeBarButtonsToRemove:{valType:"any",dflt:[]},modeBarButtonsToAdd:{valType:"any",dflt:[]},modeBarButtons:{valType:"any",dflt:!1},toImageButtonOptions:{valType:"any",dflt:{}},displaylogo:{valType:"boolean",dflt:!0},watermark:{valType:"boolean",dflt:!1},plotGlPixelRatio:{valType:"number",dflt:2,min:1,max:4},setBackground:{valType:"any",dflt:"transparent"},topojsonURL:{valType:"string",noBlank:!0,dflt:"https://cdn.plot.ly/"},mapboxAccessToken:{valType:"string",dflt:null},logging:{valType:"boolean",dflt:1},queueLength:{valType:"integer",min:0,dflt:0},globalTransforms:{valType:"any",dflt:[]},locale:{valType:"string",dflt:"en-US"},locales:{valType:"any",dflt:{}}},a={};!function t(e,r){for(var n in e){var a=e[n];a.valType?r[n]=a.dflt:(r[n]||(r[n]={}),t(a,r[n]))}}(n,a),e.exports={configAttributes:n,dfltConfig:a}},{}],753:[function(t,e,r){"use strict";var n=t("../registry"),a=t("../lib"),i=t("../plots/attributes"),o=t("../plots/layout_attributes"),s=t("../plots/frame_attributes"),l=t("../plots/animation_attributes"),c=t("./plot_config").configAttributes,u=t("../plots/polar/legacy/area_attributes"),h=t("../plots/polar/legacy/axis_attributes"),f=t("./edit_types"),p=a.extendFlat,d=a.extendDeepAll,g=a.isPlainObject,v=a.isArrayOrTypedArray,m=a.nestedProperty,y=a.valObjectMeta,x="_isSubplotObj",b="_isLinkedToArray",_=[x,b,"_arrayAttrRegexps","_deprecated"];function w(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(k(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!k(e[++r]))return!1}else if("info_array"===t.valType){var a=e[++r];if(!k(a))return!1;var i=t.items;if(Array.isArray(i)){if(a>=i.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!k(o))return!1;t=i[a][o]}else t=i[a]}else t=i}}return t}function k(t){return t===Math.round(t)&&t>=0}function T(t){return function(t){r.crawl(t,function(t,e,n){r.isValObject(t)?"data_array"===t.valType?(t.role="data",n[e+"src"]={valType:"string",editType:"none"}):!0===t.arrayOk&&(n[e+"src"]={valType:"string",editType:"none"}):g(t)&&(t.role="object")})}(t),function(t){r.crawl(t,function(t,e,r){if(!t)return;var n=t[b];if(!n)return;delete t[b],r[e]={items:{}},r[e].items[n]=t,r[e].role="object"})}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function A(t,e,r){var n=m(t,r),a=d({},e.layoutAttributes);a[x]=!0,n.set(a)}function M(t,e,r){var n=m(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=x,r.IS_LINKED_TO_ARRAY=b,r.DEPRECATED="_deprecated",r.UNDERSCORE_ATTRS=_,r.get=function(){var t={};n.allTypes.concat("area").forEach(function(e){t[e]=function(t){var e,a;"area"===t?(e={attributes:u},a={}):(e=n.modules[t]._module,a=e.basePlotModule);var o={type:null},s=d({},i),l=d({},e.attributes);r.crawl(l,function(t,e,r,n,a){m(s,a).set(void 0),void 0===t&&m(l,a).set(void 0)}),d(o,s),n.traceIs(t,"noOpacity")&&delete o.opacity;n.traceIs(t,"showLegend")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,"noHover")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),a.attributes&&d(o,a.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:T(o)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),c.layoutAttributes=T(h)}e.animatable||r.crawl(c,function(t){r.isValObject(t)&&"anim"in t&&delete t.anim});return c}(e)});var e,a={};return Object.keys(n.transformsRegistry).forEach(function(t){a[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach(function(e){var a=n.componentsRegistry[e];a.schema&&a.schema.transforms&&a.schema.transforms[t]&&Object.keys(a.schema.transforms[t]).forEach(function(e){M(r,a.schema.transforms[t][e],e)})}),{attributes:T(r)}}(t)}),{defs:{valObjects:y,metaKeys:_.concat(["description","role","editType","impliedEdits"]),editType:{traces:f.traces,layout:f.layout},impliedEdits:{}},traces:t,layout:function(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry)if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var a=0;a<e.attr.length;a++)A(r,e,e.attr[a]);else{var i="subplot"===e.attr?e.name:e.attr;A(r,e,i)}for(t in r=function(t){return p(t,{radialaxis:h.radialaxis,angularaxis:h.angularaxis}),p(t,h.layout),t}(r),n.componentsRegistry){var s=(e=n.componentsRegistry[t]).schema;if(s&&(s.subplots||s.layout)){var l=s.subplots;if(l&&l.xaxis&&!l.yaxis)for(var c in l.xaxis)delete r.yaxis[c]}else"colorscale"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&M(r,e.layoutAttributes,e.name)}return{layoutAttributes:T(r)}}(),transforms:a,frames:(e={frames:d({},s)},T(e),e.frames),animation:T(l),config:T(c)}},r.crawl=function(t,e,n,a){var i=n||0;a=a||"",Object.keys(t).forEach(function(n){var o=t[n];if(-1===_.indexOf(n)){var s=(a?a+".":"")+n;e(o,n,t,i,s),r.isValObject(o)||g(o)&&"impliedEdits"!==n&&r.crawl(o,e,i+1,s)}})},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,a=[],o=[],s=[];function l(t,r,i,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&("data_array"===t.valType||!0===t.arrayOk)&&!("colorbar"===o[l-1]&&("ticktext"===r||"tickvals"===r))&&function t(e,r,i){var l=e[o[r]];var c=i+o[r];if(r===o.length-1)v(l)&&a.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+"["+u+"].")}else g(l)&&t(l,r+1,c+".")}(e,0,"")}e=t,n="",r.crawl(i,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var h=c[u],f=h._module;f&&(n="transforms["+u+"].",e=h,r.crawl(f.attributes,l))}return a},r.getTraceValObject=function(t,e){var r,a,o=e[0],s=1;if("transforms"===o){if(1===e.length)return i.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!k(c)||c>=l.length)return!1;a=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if("area"===t.type)a=u[o];else{var h=t._module;if(h||(h=(n.modules[t.type||i.type.dflt]||{})._module),!h)return!1;if(!(a=(r=h.attributes)&&r[o])){var f=h.basePlotModule;f&&f.attributes&&(a=f.attributes[o])}a||(a=i[o])}return w(a,e,s)},r.getLayoutValObject=function(t,e){return w(function(t,e){var r,a,i,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((i=l[r]).attrRegex&&i.attrRegex.test(e)){if(i.layoutAttrOverrides)return i.layoutAttrOverrides;!c&&i.layoutAttributes&&(c=i.layoutAttributes)}var u=i.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(a in n.componentsRegistry){if("colorscale"===(i=n.componentsRegistry[a]).name&&0===e.indexOf("coloraxis"))return i.layoutAttributes[e];if(!i.schema&&e===i.name)return i.layoutAttributes}if(e in o)return o[e];if("radialaxis"===e||"angularaxis"===e)return h[e];return h.layout[e]||!1}(t,e[0]),e,1)}},{"../lib":716,"../plots/animation_attributes":759,"../plots/attributes":761,"../plots/frame_attributes":791,"../plots/layout_attributes":816,"../plots/polar/legacy/area_attributes":831,"../plots/polar/legacy/axis_attributes":832,"../registry":845,"./edit_types":747,"./plot_config":752}],754:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plots/attributes"),i="templateitemname",o={name:{valType:"string",editType:"none"}};function s(t){return t&&"string"==typeof t}function l(t){var e=t.length-1;return"s"!==t.charAt(e)&&n.warn("bad argument to arrayDefaultKey: "+t),t.substr(0,t.length-1)+"defaults"}o[i]={valType:"string",editType:"calc"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[i]=o[i],e},r.traceTemplater=function(t){var e,r,i={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(i[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},a,"type"),_template:null};if(e in i){r=t[e];var l=i[e]%r.length;i[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var a=t._template,i=a&&(a[e]||r&&a[r]);return n.isPlainObject(i)||(i=null),t[e]={_template:i}},r.arrayTemplater=function(t,e,r){var n=t._template,a=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[i]=t[i];if(!s(n))return e._template=a,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var a={_template:r,name:n,_input:{_templateitemname:n}};a[i]=r[i],t.push(a),c[n]=1}}return t}}},r.arrayDefaultKey=l,r.arrayEditor=function(t,e,r){var a=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=a&&(r._input||{})._templateitemname;s&&(o=a);var l,c=e+"["+o+"]";function u(){l={},s&&(l[c]={},l[c][i]=s)}function h(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+"."+t]=e}function f(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:h,getUpdateObj:f,applyUpdate:function(e,r){e&&h(e,r);var a=f();for(var i in a)n.nestedProperty(t,i).set(a[i])}}}},{"../lib":716,"../plots/attributes":761}],755:[function(t,e,r){"use strict";var n=t("d3"),a=t("../registry"),i=t("../plots/plots"),o=t("../lib"),s=t("../lib/clear_gl_canvases"),l=t("../components/color"),c=t("../components/drawing"),u=t("../components/titles"),h=t("../components/modebar"),f=t("../plots/cartesian/axes"),p=t("../constants/alignment"),d=t("../plots/cartesian/constraints"),g=d.enforce,v=d.clean,m=t("../plots/cartesian/autorange").doAutoRange,y="start",x="middle",b="end";function _(t,e,r){for(var n=0;n<r.length;n++){var a=r[n][0],i=r[n][1];if(!(a[0]>=t[1]||a[1]<=t[0])&&(i[0]<e[1]&&i[1]>e[0]))return!0}return!1}function w(t){var e,a,s,u,d,g,v=t._fullLayout,m=v._size,y=m.p,x=f.list(t,"",!0);if(v._paperdiv.style({width:t._context.responsive&&v.autosize&&!t._context._hasZeroWidth&&!t.layout.width?"100%":v.width+"px",height:t._context.responsive&&v.autosize&&!t._context._hasZeroHeight&&!t.layout.height?"100%":v.height+"px"}).selectAll(".main-svg").call(c.setSize,v.width,v.height),t._context.setBackground(t,v.paper_bgcolor),r.drawMainTitle(t),h.manage(t),!v._has("cartesian"))return i.previousPromises(t);function b(t,e,r){var n=t._lw/2;return"x"===t._id.charAt(0)?e?"top"===r?e._offset-y-n:e._offset+e._length+y+n:m.t+m.h*(1-(t.position||0))+n%1:e?"right"===r?e._offset+e._length+y+n:e._offset-y-n:m.l+m.w*(t.position||0)+n%1}for(e=0;e<x.length;e++){var w=(u=x[e])._anchorAxis;u._linepositions={},u._lw=c.crispRound(t,u.linewidth,1),u._mainLinePosition=b(u,w,u.side),u._mainMirrorPosition=u.mirror&&w?b(u,w,p.OPPOSITE_SIDE[u.side]):null}var T=[],M=[],S=[],E=1===l.opacity(v.paper_bgcolor)&&1===l.opacity(v.plot_bgcolor)&&v.paper_bgcolor===v.plot_bgcolor;for(a in v._plots)if((s=v._plots[a]).mainplot)s.bg&&s.bg.remove(),s.bg=void 0;else{var L=s.xaxis.domain,C=s.yaxis.domain,P=s.plotgroup;if(_(L,C,S)){var O=P.node(),z=s.bg=o.ensureSingle(P,"rect","bg");O.insertBefore(z.node(),O.childNodes[0]),M.push(a)}else P.select("rect.bg").remove(),S.push([L,C]),E||(T.push(a),M.push(a))}var I,D,R,F,B,N,j,V,U,q,H,G,Y,W=v._bgLayer.selectAll(".bg").data(T);for(W.enter().append("rect").classed("bg",!0),W.exit().remove(),W.each(function(t){v._plots[t].bg=n.select(this)}),e=0;e<M.length;e++)s=v._plots[M[e]],d=s.xaxis,g=s.yaxis,s.bg&&s.bg.call(c.setRect,d._offset-y,g._offset-y,d._length+2*y,g._length+2*y).call(l.fill,v.plot_bgcolor).style("stroke-width",0);if(!v._hasOnlyLargeSploms)for(a in v._plots){s=v._plots[a],d=s.xaxis,g=s.yaxis;var X,Z,J=s.clipId="clip"+v._uid+a+"plot",K=o.ensureSingleById(v._clips,"clipPath",J,function(t){t.classed("plotclip",!0).append("rect")});s.clipRect=K.select("rect").attr({width:d._length,height:g._length}),c.setTranslate(s.plot,d._offset,g._offset),s._hasClipOnAxisFalse?(X=null,Z=J):(X=J,Z=null),c.setClipUrl(s.plot,X,t),s.layerClipId=Z}function Q(t){return"M"+I+","+t+"H"+D}function $(t){return"M"+d._offset+","+t+"h"+d._length}function tt(t){return"M"+t+","+V+"V"+j}function et(t){return"M"+t+","+g._offset+"v"+g._length}function rt(t,e,r){if(!t.showline||a!==t._mainSubplot)return"";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(a in v._plots){s=v._plots[a],d=s.xaxis,g=s.yaxis;var nt="M0,0";k(d,a)&&(B=A(d,"left",g,x),I=d._offset-(B?y+B:0),N=A(d,"right",g,x),D=d._offset+d._length+(N?y+N:0),R=b(d,g,"bottom"),F=b(d,g,"top"),!(Y=!d._anchorAxis||a!==d._mainSubplot)||"allticks"!==d.mirror&&"all"!==d.mirror||(d._linepositions[a]=[R,F]),nt=rt(d,Q,$),Y&&d.showline&&("all"===d.mirror||"allticks"===d.mirror)&&(nt+=Q(R)+Q(F)),s.xlines.style("stroke-width",d._lw+"px").call(l.stroke,d.showline?d.linecolor:"rgba(0,0,0,0)")),s.xlines.attr("d",nt);var at="M0,0";k(g,a)&&(H=A(g,"bottom",d,x),j=g._offset+g._length+(H?y:0),G=A(g,"top",d,x),V=g._offset-(G?y:0),U=b(g,d,"left"),q=b(g,d,"right"),!(Y=!g._anchorAxis||a!==g._mainSubplot)||"allticks"!==g.mirror&&"all"!==g.mirror||(g._linepositions[a]=[U,q]),at=rt(g,tt,et),Y&&g.showline&&("all"===g.mirror||"allticks"===g.mirror)&&(at+=tt(U)+tt(q)),s.ylines.style("stroke-width",g._lw+"px").call(l.stroke,g.showline?g.linecolor:"rgba(0,0,0,0)")),s.ylines.attr("d",at)}return f.makeClipPaths(t),i.previousPromises(t)}function k(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||"all"===t.mirror||"allticks"===t.mirror)}function T(t,e,r){if(!r.showline||!r._lw)return!1;if("all"===r.mirror||"allticks"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var a=p.FROM_BL[e];return r.side===e?n.domain[a]===t.domain[a]:r.mirror&&n.domain[1-a]===t.domain[1-a]}function A(t,e,r,n){if(T(t,e,r))return r._lw;for(var a=0;a<n.length;a++){var i=n[a];if(i._mainAxis===r._mainAxis&&T(t,e,i))return i._lw}return 0}r.layoutStyles=function(t){return o.syncOrAsync([i.doAutoMargin,w],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=x;o.isRightAnchor(e)?r=b:o.isLeftAnchor(e)&&(r=y);return r}(e),n=function(t){var e=t.title,r="0em";o.isTopAnchor(e)?r=p.CAP_SHIFT+"em":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+"em");return r}(e);u.draw(t,"gtitle",{propContainer:e,propName:"title.text",placeholder:e._dfltTitle.plot,attributes:{x:function(t,e){var r=t.title,n=t._size,a=0;e===y?a=r.pad.l:e===b&&(a=-r.pad.r);switch(r.xref){case"paper":return n.l+n.w*r.x+a;case"container":default:return t.width*r.x+a}}(e,r),y:function(t,e){var r=t.title,n=t._size,a=0;"0em"!==e&&e?e===p.CAP_SHIFT+"em"&&(a=r.pad.t):a=-r.pad.b;if("auto"===r.y)return n.t/2;switch(r.yref){case"paper":return n.t+n.h-n.h*r.y+a;case"container":default:return t.height-t.height*r.y+a}}(e,n),"text-anchor":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(l,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return i.style(t),a.getComponentMethod("legend","draw")(t),i.previousPromises(t)},r.doColorBars=function(t){return a.getComponentMethod("colorbar","draw")(t),i.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,a.call("plot",t,"",e)},r.doLegend=function(t){return a.getComponentMethod("legend","draw")(t),i.previousPromises(t)},r.doTicksRelayout=function(t){return f.draw(t,"redraw"),t._fullLayout._hasOnlyLargeSploms&&(a.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),i.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;h.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return i.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var a=e[r[n]];a._scene.setViewport(a)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),i.style(t),a.getComponentMethod("shapes","draw")(t),a.getComponentMethod("annotations","draw")(t),a.getComponentMethod("images","draw")(t),e._replotting=!1,i.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has("regl")){var r,n,a=t._fullData,i=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<a.length;r++){var l=a[r];!0===l.visible&&0!==l._length&&("splom"===l.type?e._splomScenes[l.uid].draw():"scattergl"===l.type?o.pushUnique(i,l.xaxis+l.yaxis):"scatterpolargl"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<i.length;r++)(n=e._plots[i[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r,n=t._fullLayout,a=f.list(t,"",!0),i=n._axisMatchGroups||[],s=0;s<a.length;s++)e=a[s],v(t,e),m(t,e);g(t);t:for(var l=0;l<i.length;l++){var c,u=i[l],h=null;for(c in u){if(!1===(e=f.getFromId(t,c)).autorange)continue t;r=o.simpleMap(e.range,e.r2l),h?h[0]<h[1]?(h[0]=Math.min(h[0],r[0]),h[1]=Math.max(h[1],r[1])):(h[0]=Math.max(h[0],r[0]),h[1]=Math.min(h[1],r[1])):h=r}for(c in u)(e=f.getFromId(t,c)).range=o.simpleMap(h,e.l2r),e._input.range=e.range.slice(),e.setScale()}},r.finalDraw=function(t){a.getComponentMethod("rangeslider","draw")(t),a.getComponentMethod("rangeselector","draw")(t)},r.drawMarginPushers=function(t){a.getComponentMethod("legend","draw")(t),a.getComponentMethod("rangeselector","draw")(t),a.getComponentMethod("sliders","draw")(t),a.getComponentMethod("updatemenus","draw")(t),a.getComponentMethod("colorbar","draw")(t)}},{"../components/color":591,"../components/drawing":612,"../components/modebar":649,"../components/titles":678,"../constants/alignment":685,"../lib":716,"../lib/clear_gl_canvases":701,"../plots/cartesian/autorange":763,"../plots/cartesian/axes":764,"../plots/cartesian/constraints":771,"../plots/plots":825,"../registry":845,d3:164}],756:[function(t,e,r){"use strict";var n=t("../lib"),a=n.isPlainObject,i=t("./plot_schema"),o=t("../plots/plots"),s=t("../plots/attributes"),l=t("./plot_template"),c=t("./plot_config").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,i,o=Object.keys(t).sort();function s(e,r,n){if(a(r)&&a(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(i=0;i<r.length;i++){var s=r[i],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(i=0;i<h.length;i++)r.push(h[i]._template);for(i=0;i<r.length;i++)delete r[i].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,"")}function f(t,e,r,i,o){var s=o&&r(o);for(var c in t){var u=t[c],d=p(t,c,i),g=p(t,c,o),v=r(g);if(!v){var m=h(c);m!==c&&(v=r(g=p(t,m,o)))}if((!s||s!==v)&&!(!v||v._noTemplating||"data_array"===v.valType||v.arrayOk&&Array.isArray(u)))if(!v.valType&&a(u))f(u,e,r,d,g);else if(v._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(a(w)){var k=w.name;if(k)b[k]||(f(w,e,r,p(u,x,d),p(u,x,g)),x++,b[k]=1);else if(!y){var T=p(t,l.arrayDefaultKey(c),i),A=p(u,x,d);f(w,e,r,A,p(u,x,g));var M=n.nestedProperty(e,A);n.nestedProperty(e,T).set(M.get()),M.set(null),y=!0}}}else{n.nestedProperty(e,d).set(u)}}}function p(t,e,r){return r?Array.isArray(t)?r+"["+e+"]":r+"."+e:e}function d(t){for(var e=0;e<t.length;e++)if(a(t[e]))return!0}function g(t){var e;switch(t.code){case"data":e="The template has no key data.";break;case"layout":e="The template has no key layout.";break;case"missing":e=t.path?"There are no templates for item "+t.path+" with name "+t.templateitemname:"There are no templates for trace "+t.index+", of type "+t.traceType+".";break;case"unused":e=t.path?"The template item at "+t.path+" was not used in constructing the plot.":t.dataCount?"Some of the templates of type "+t.traceType+" were not used. The template has "+t.templateCount+" traces, the data only has "+t.dataCount+" of this type.":"The template has "+t.templateCount+" traces of type "+t.traceType+" but there are none in the data.";break;case"reused":e="Some of the templates of type "+t.traceType+" were used more than once. The template has "+t.templateCount+" traces, the data has "+t.dataCount+" of this type."}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var l={data:{},layout:{}};e.forEach(function(t){var e={};f(t,e,function(t,e){return i.getTraceValObject(t,n.nestedProperty({},e).parts)}.bind(null,t));var r=n.coerce(t,{},s,"type"),a=l.data[r];a||(a=l.data[r]=[]),a.push(e)}),f(r,l.layout,function(t,e){return i.getLayoutValObject(t,n.nestedProperty({},e).parts)}.bind(null,r)),delete l.layout.template;var h=r.template;if(a(h)){var p,d,g,v,m,y,x=h.layout;a(x)&&u(x,l.layout);var b=h.data;if(a(b)){for(d in l.data)if(g=b[d],Array.isArray(g)){for(y=(m=l.data[d]).length,v=g.length,p=0;p<y;p++)u(g[p%v],m[p]);for(p=y;p<v;p++)m.push(n.extendDeep({},g[p]))}for(d in b)d in l.data||(l.data[d]=n.extendDeep([],b[d]))}}return l},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),i=r.layout||{};a(e)||(e=i.template||{});var s=e.layout,l=e.data,u=[];r.layout=i,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,v=r._fullData,m={};if(a(s)?(!function t(e,r){for(var n in e)if("_"!==n.charAt(0)&&a(e[n])){var i,o=h(n),s=[];for(i=0;i<r.length;i++)s.push(p(e,n,r[i])),o!==n&&s.push(p(e,o,r[i]));for(i=0;i<s.length;i++)m[s[i]]=1;t(e[n],s)}}(f,["layout"]),function t(e,r){for(var n in e)if(-1===n.indexOf("defaults")&&a(e[n])){var i=p(e,n,r);m[i]?t(e[n],i):u.push({code:"unused",path:i})}}(s,"layout")):u.push({code:"layout"}),a(l)){for(var y,x={},b=0;b<v.length;b++){var _=v[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:"missing",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,k=x[y]||0;w>k?u.push({code:"unused",traceType:y,templateCount:w,dataCount:k}):k>w&&u.push({code:"reused",traceType:y,templateCount:w,dataCount:k})}}else u.push({code:"data"});if(function t(e,r){for(var n in e)if("_"!==n.charAt(0)){var i=e[n],o=p(e,n,r);a(i)?(Array.isArray(e)&&!1===i._template&&i.templateitemname&&u.push({code:"missing",path:o,templateitemname:i.templateitemname}),t(i,o)):Array.isArray(i)&&d(i)&&t(i,o)}}({data:v,layout:f},""),u.length)return u.map(g)}},{"../lib":716,"../plots/attributes":761,"../plots/plots":825,"./plot_config":752,"./plot_schema":753,"./plot_template":754}],757:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("./plot_api"),i=t("../lib"),o=t("../snapshot/helpers"),s=t("../snapshot/tosvg"),l=t("../snapshot/svgtoimg"),c={format:{valType:"enumerated",values:["png","jpeg","webp","svg"],dflt:"png"},width:{valType:"number",min:1},height:{valType:"number",min:1},scale:{valType:"number",min:0,dflt:1},setBackground:{valType:"any",dflt:!1},imageDataOnly:{valType:"boolean",dflt:!1}};e.exports=function(t,e){var r,u,h,f;function p(t){return!(t in e)||i.validate(e[t],c[t])}if(e=e||{},i.isPlainObject(t)?(r=t.data||[],u=t.layout||{},h=t.config||{},f={}):(t=i.getGraphDiv(t),r=i.extendDeep([],t.data),u=i.extendDeep({},t.layout),h=t._context,f=t._fullLayout||{}),!p("width")&&null!==e.width||!p("height")&&null!==e.height)throw new Error("Height and width should be pixel values.");if(!p("format"))throw new Error("Image format is not jpeg, png, svg or webp.");var d={};function g(t,r){return i.coerce(e,d,c,t,r)}var v=g("format"),m=g("width"),y=g("height"),x=g("scale"),b=g("setBackground"),_=g("imageDataOnly"),w=document.createElement("div");w.style.position="absolute",w.style.left="-5000px",document.body.appendChild(w);var k=i.extendFlat({},u);m?k.width=m:null===e.width&&n(f.width)&&(k.width=f.width),y?k.height=y:null===e.height&&n(f.height)&&(k.height=f.height);var T=i.extendFlat({},h,{_exportedPlot:!0,staticPlot:!0,setBackground:b}),A=o.getRedrawFunc(w);function M(){return new Promise(function(t){setTimeout(t,o.getDelay(w._fullLayout))})}function S(){return new Promise(function(t,e){var r=s(w,v,x),n=w._fullLayout.width,c=w._fullLayout.height;if(a.purge(w),document.body.removeChild(w),"svg"===v)return t(_?r:o.encodeSVG(r));var u=document.createElement("canvas");u.id=i.randstr(),l({format:v,width:n,height:c,scale:x,canvas:u,svg:r,promise:!0}).then(t).catch(e)})}return new Promise(function(t,e){a.plot(w,r,k,T).then(A).then(M).then(S).then(function(e){t(function(t){return _?t.replace(o.IMAGE_URL_PREFIX,""):t}(e))}).catch(function(t){e(t)})})}},{"../lib":716,"../snapshot/helpers":849,"../snapshot/svgtoimg":851,"../snapshot/tosvg":853,"./plot_api":751,"fast-isnumeric":227}],758:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plots/plots"),i=t("./plot_schema"),o=t("./plot_config").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,a,i,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var v=h[f];if("transforms"!==v){var m=o.slice();m.push(v);var y=t[v],x=e[v],b=g(r,v),_="info_array"===(b||{}).valType,w="colorscale"===(b||{}).valType,k=(b||{}).items;if(d(r,v))if(s(y)&&s(x))u(y,x,b,a,i,m);else if(_&&l(y)){y.length>x.length&&a.push(p("unused",i,m.concat(x.length)));var T,A,M,S,E,L=x.length,C=Array.isArray(k);if(C&&(L=Math.min(L,k.length)),2===b.dimensions)for(A=0;A<L;A++)if(l(y[A])){y[A].length>x[A].length&&a.push(p("unused",i,m.concat(A,x[A].length)));var P=x[A].length;for(T=0;T<(C?Math.min(P,k[A].length):P);T++)M=C?k[A][T]:k,S=y[A][T],E=x[A][T],n.validate(S,M)?E!==S&&E!==+S&&a.push(p("dynamic",i,m.concat(A,T),S,E)):a.push(p("value",i,m.concat(A,T),S))}else a.push(p("array",i,m.concat(A),y[A]));else for(A=0;A<L;A++)M=C?k[A]:k,S=y[A],E=x[A],n.validate(S,M)?E!==S&&E!==+S&&a.push(p("dynamic",i,m.concat(A),S,E)):a.push(p("value",i,m.concat(A),S))}else if(b.items&&!_&&l(y)){var O,z,I=k[Object.keys(k)[0]],D=[];for(O=0;O<x.length;O++){var R=x[O]._index||O;if((z=m.slice()).push(R),s(y[R])&&s(x[O])){D.push(R);var F=y[R],B=x[O];s(F)&&!1!==F.visible&&!1===B.visible?a.push(p("invisible",i,z)):u(F,B,I,a,i,z)}}for(O=0;O<y.length;O++)(z=m.slice()).push(O),s(y[O])?-1===D.indexOf(O)&&a.push(p("unused",i,z)):a.push(p("object",i,z,y[O]))}else!s(y)&&s(x)?a.push(p("object",i,m,y)):c(y)||!c(x)||_||w?v in e?n.validate(y,b)?"enumerated"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&a.push(p("dynamic",i,m,y,x)):a.push(p("value",i,m,y)):a.push(p("unused",i,m,y)):a.push(p("array",i,m,y));else a.push(p("schema",i,m))}}return a}e.exports=function(t,e){var r,c,h=i.get(),f=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],f.push(p("array","data"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&f.push(p("object","layout"))),a.supplyDefaults(d);for(var g=d._fullData,v=r.length,m=0;m<v;m++){var y=r[m],x=["data",m];if(s(y)){var b=g[m],_=b.type,w=h.traces[_].attributes;w.type={valType:"enumerated",values:[_]},!1===b.visible&&!1!==y.visible&&f.push(p("invisible",x)),u(y,b,w,f,x);var k=y.transforms,T=b.transforms;if(k){l(k)||f.push(p("array",x,["transforms"])),x.push("transforms");for(var A=0;A<k.length;A++){var M=["transforms",A],S=k[A].type;if(s(k[A])){var E=h.transforms[S]?h.transforms[S].attributes:{};E.type={valType:"enumerated",values:Object.keys(h.transforms)},u(k[A],T[A],E,f,x,M)}else f.push(p("object",x,M))}}}else f.push(p("object",x))}return u(c,d._fullLayout,function(t,e){for(var r=t.layout.layoutAttributes,a=0;a<e.length;a++){var i=e[a],o=t.traces[i.type],s=o.layoutAttributes;s&&(i.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(h,g),f,"layout"),0===f.length?void 0:f};var h={object:function(t,e){return("layout"===t&&""===e?"The layout argument":"data"===t[0]&&""===e?"Trace "+t[1]+" in the data argument":f(t)+"key "+e)+" must be linked to an object container"},array:function(t,e){return("data"===t?"The data argument":f(t)+"key "+e)+" must be linked to an array container"},schema:function(t,e){return f(t)+"key "+e+" is not part of the schema"},unused:function(t,e,r){var n=s(r)?"container":"key";return f(t)+n+" "+e+" did not get coerced"},dynamic:function(t,e,r,n){return[f(t)+"key",e,"(set to '"+r+"')","got reset to","'"+n+"'","during defaults."].join(" ")},invisible:function(t,e){return(e?f(t)+"item "+e:"Trace "+t[1])+" got defaulted to be not visible"},value:function(t,e,r){return[f(t)+"key "+e,"is set to an invalid value ("+r+")"].join(" ")}};function f(t){return l(t)?"In data trace "+t[1]+", ":"In "+t+", "}function p(t,e,r,a,i){var o,s;r=r||"",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e="",r=0;r<t.length;r++){var n=t[r];"number"==typeof n?e=e.substr(0,e.length-1)+"["+n+"]":e+=n,r<t.length-1&&(e+=".")}return e}(r),u=h[t](e,c,a,i);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=m(e),n=r.keyMinusId,a=r.id;return!!(n in t&&t[n]._isSubplotObj&&a)||e in t}function g(t,e){return e in t?t[e]:t[m(e).keyMinusId]}var v=n.counterRegex("([a-z]+)");function m(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{"../lib":716,"../plots/plots":825,"./plot_config":752,"./plot_schema":753}],759:[function(t,e,r){"use strict";e.exports={mode:{valType:"enumerated",dflt:"afterall",values:["immediate","next","afterall"]},direction:{valType:"enumerated",values:["forward","reverse"],dflt:"forward"},fromcurrent:{valType:"boolean",dflt:!1},frame:{duration:{valType:"number",min:0,dflt:500},redraw:{valType:"boolean",dflt:!0}},transition:{duration:{valType:"number",min:0,dflt:500,editType:"none"},easing:{valType:"enumerated",dflt:"cubic-in-out",values:["linear","quad","cubic","sin","exp","circle","elastic","back","bounce","linear-in","quad-in","cubic-in","sin-in","exp-in","circle-in","elastic-in","back-in","bounce-in","linear-out","quad-out","cubic-out","sin-out","exp-out","circle-out","elastic-out","back-out","bounce-out","linear-in-out","quad-in-out","cubic-in-out","sin-in-out","exp-in-out","circle-in-out","elastic-in-out","back-in-out","bounce-in-out"],editType:"none"},ordering:{valType:"enumerated",values:["layout first","traces first"],dflt:"layout first",editType:"none"}}}},{}],760:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plot_api/plot_template");e.exports=function(t,e,r){var i,o,s=r.name,l=r.inclusionAttr||"visible",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=a.arrayTemplater(e,s,l);for(i=0;i<u.length;i++){var p=u[i];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=i,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(i=0;i<d.length;i++)(o=d[i])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,h.length);for(i=0;i<g;i++)n.relinkPrivateKeys(h[i],c[i])}return h}},{"../lib":716,"../plot_api/plot_template":754}],761:[function(t,e,r){"use strict";var n=t("../components/fx/attributes");e.exports={type:{valType:"enumerated",values:[],dflt:"scatter",editType:"calc+clearAxisTypes",_noTemplating:!0},visible:{valType:"enumerated",values:[!0,!1,"legendonly"],dflt:!0,editType:"calc"},showlegend:{valType:"boolean",dflt:!0,editType:"style"},legendgroup:{valType:"string",dflt:"",editType:"style"},opacity:{valType:"number",min:0,max:1,dflt:1,editType:"style"},name:{valType:"string",editType:"style"},uid:{valType:"string",editType:"plot",anim:!0},ids:{valType:"data_array",editType:"calc",anim:!0},customdata:{valType:"data_array",editType:"calc"},meta:{valType:"any",arrayOk:!0,editType:"plot"},selectedpoints:{valType:"any",editType:"calc"},hoverinfo:{valType:"flaglist",flags:["x","y","z","text","name"],extras:["all","none","skip"],arrayOk:!0,dflt:"all",editType:"none"},hoverlabel:n.hoverlabel,stream:{token:{valType:"string",noBlank:!0,strict:!0,editType:"calc"},maxpoints:{valType:"number",min:0,max:1e4,dflt:500,editType:"calc"},editType:"calc"},transforms:{_isLinkedToArray:"transform",editType:"calc"},uirevision:{valType:"any",editType:"none"}}},{"../components/fx/attributes":621}],762:[function(t,e,r){"use strict";e.exports={xaxis:{valType:"subplotid",dflt:"x",editType:"calc+clearAxisTypes"},yaxis:{valType:"subplotid",dflt:"y",editType:"calc+clearAxisTypes"}}},{}],763:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../constants/numerical").FP_SAFE,o=t("../../registry");function s(t,e){var r,n,i=[],o=l(e),s=c(t,e),u=s.min,h=s.max;if(0===u.length||0===h.length)return a.simpleMap(e.range,e.r2l);var f=u[0].val,p=h[0].val;for(r=1;r<u.length&&f===p;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===p;r++)p=Math.max(p,h[r].val);var d=!1;if(e.range){var g=a.simpleMap(e.range,e.r2l);d=g[1]<g[0]}"reversed"===e.autorange&&(d=!0,e.autorange=!0);var v,m,y,x,b,_,w=e.rangemode,k="tozero"===w,T="nonnegative"===w,A=e._length,M=A/10,S=0;for(r=0;r<u.length;r++)for(v=u[r],n=0;n<h.length;n++)(_=(m=h[n]).val-v.val)>0&&((b=A-o(v)-o(m))>M?_/b>S&&(y=v,x=m,S=_/b):_/A>S&&(y={val:v.val,pad:0},x={val:m.val,pad:0},S=_/A));if(f===p){var E=f-1,L=f+1;if(k)if(0===f)i=[0,1];else{var C=(f>0?h:u).reduce(function(t,e){return Math.max(t,o(e))},0),P=f/(1-Math.min(.5,C/A));i=f>0?[0,P]:[P,0]}else i=T?[Math.max(0,E),Math.max(1,L)]:[E,L]}else k?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):T&&(y.val-S*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),S=(x.val-y.val)/(A-o(y)-o(x)),i=[y.val-S*o(y),x.val+S*o(x)];return d&&i.reverse(),a.simpleMap(i,e.l2r||Number)}function l(t){var e=t._length/20;return"domain"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,a,i=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function f(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[i];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)a=s.min[n],u(l,a.val,a.pad,{extrapad:a.extrapad});for(n=0;n<s.max.length;n++)a=s.max[n],h(c,a.val,a.pad,{extrapad:a.extrapad})}}}return f(o,e._traceIndices),f(s.annotations||[],e._annIndices||[]),f(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){f(t,e,r,n,d)}function h(t,e,r,n){f(t,e,r,n,g)}function f(t,e,r,n,a){for(var i=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(a(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}a(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=i&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<i}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.setScale(),e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=a.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+".range"]=e.range,n[e._attr+".autorange"]=e.autorange,o.call("_storeDirectGUIEdit",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var i=e._anchorAxis;if(i&&i.rangeslider){var l=i.rangeslider[e._name];l&&"auto"===l.rangemode&&(l.range=s(t,e)),i._input.rangeslider[e._name]=a.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var a,o,s,l,c,f,d,g,v,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&("linear"===t.type||"-"===t.type),w="log"===t.type,k=!1,T=r.vpadLinearized||!1;function A(t){if(Array.isArray(t))return k=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var M=A((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),S=A((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),E=A(r.vpadplus||r.vpad),L=A(r.vpadminus||r.vpad);if(!k){if(g=1/0,v=-1/0,w)for(a=0;a<x;a++)(o=e[a])<g&&o>0&&(g=o),o>v&&o<i&&(v=o);else for(a=0;a<x;a++)(o=e[a])<g&&o>-i&&(g=o),o>v&&o<i&&(v=o);e=[g,v],x=2}var C={tozero:_,extrapad:b};function P(r){s=e[r],n(s)&&(f=M(r),d=S(r),T?(l=t.c2l(s)-L(r),c=t.c2l(s)+E(r)):(g=s-L(r),v=s+E(r),w&&g<v/10&&(g=v/10),l=t.c2l(g),c=t.c2l(v)),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(m,l,d,C),p(c)&&h(y,c,f,C))}var O=Math.min(6,x);for(a=0;a<O;a++)P(a);for(a=x-1;a>=O;a--)P(a);return{min:m,max:y,opts:r}},concatExtremes:c}},{"../../constants/numerical":692,"../../lib":716,"../../registry":845,"fast-isnumeric":227}],764:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../plots/plots"),o=t("../../registry"),s=t("../../lib"),l=t("../../lib/svg_text_utils"),c=t("../../components/titles"),u=t("../../components/color"),h=t("../../components/drawing"),f=t("./layout_attributes"),p=t("./clean_ticks"),d=t("../../constants/numerical"),g=d.ONEAVGYEAR,v=d.ONEAVGMONTH,m=d.ONEDAY,y=d.ONEHOUR,x=d.ONEMIN,b=d.ONESEC,_=d.MINUS_SIGN,w=d.BADNUM,k=t("../../constants/alignment"),T=k.MID_SHIFT,A=k.CAP_SHIFT,M=k.LINE_SPACING,S=k.OPPOSITE_SIDE,E=e.exports={};E.setConvert=t("./set_convert");var L=t("./axis_autotype"),C=t("./axis_ids");E.id2name=C.id2name,E.name2id=C.name2id,E.cleanId=C.cleanId,E.list=C.list,E.listIds=C.listIds,E.getFromId=C.getFromId,E.getFromTrace=C.getFromTrace;var P=t("./autorange");E.getAutoRange=P.getAutoRange,E.findExtremes=P.findExtremes,E.coerceRef=function(t,e,r,n,a,i){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+"axis"],c=n+"ref",u={};return a||(a=l[0]||i),i||(i=a),u[c]={valType:"enumerated",values:l.concat(i?[i]:[]),dflt:a},s.coerce(t,e,u,c)},E.coercePosition=function(t,e,r,n,a,i){var o,l;if("paper"===n||"pixel"===n)o=s.ensureNumber,l=r(a,i);else{var c=E.getFromId(e,n);l=r(a,i=c.fraction2r(i)),o=c.cleanPos}t[a]=o(l)},E.cleanPosition=function(t,e,r){return("paper"===r||"pixel"===r?s.ensureNumber:E.getFromId(e,r).cleanPos)(t)},E.redrawComponents=function(t,e){e=e||E.listIds(t);var r=t._fullLayout;function n(n,a,i,s){for(var l=o.getComponentMethod(n,a),c={},u=0;u<e.length;u++)for(var h=r[E.id2name(e[u])][i],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n("annotations","drawOne","_annIndices"),n("shapes","drawOne","_shapeIndices"),n("images","draw","_imgIndices",!0)};var O=E.getDataConversions=function(t,e,r,n){var a,i="x"===r||"y"===r||"z"===r?r:n;if(Array.isArray(i)){if(a={type:L(n),_categories:[]},E.setConvert(a),"category"===a.type)for(var o=0;o<n.length;o++)a.d2c(n[o])}else a=E.getFromTrace(t,e,i);return a?{d2c:a.d2c,c2d:a.c2d}:"ids"===i?{d2c:I,c2d:I}:{d2c:z,c2d:z}};function z(t){return+t}function I(t){return String(t)}E.getDataToCoordFunc=function(t,e,r,n){return O(t,e,r,n).d2c},E.counterLetter=function(t){var e=t.charAt(0);return"x"===e?"y":"y"===e?"x":void 0},E.minDtick=function(t,e,r,n){-1===["log","category","multicategory"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},E.saveRangeInitial=function(t,e){for(var r=E.list(t,"",!0),n=!1,a=0;a<r.length;a++){var i=r[a],o=void 0===i._rangeInitial,s=o||!(i.range[0]===i._rangeInitial[0]&&i.range[1]===i._rangeInitial[1]);(o&&!1===i.autorange||e&&s)&&(i._rangeInitial=i.range.slice(),n=!0)}return n},E.saveShowSpikeInitial=function(t,e){for(var r=E.list(t,"",!0),n=!1,a="on",i=0;i<r.length;i++){var o=r[i],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),"on"!==a||o.showspikes||(a="off")}return t._fullLayout._cartesianSpikesEnabled=a,n},E.autoBin=function(t,e,r,n,i,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if("category"===e.type||"multicategory"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(i||(i=e.calendar),l="log"===e.type?{type:"linear",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,i),calendar:i},E.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,i);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),g=d*s.roundUp(f.minDiff/d,[.9,1.9,4.9,9.9],!0);h=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),a(h)||(h=1)}E.autoTicks(l,h)}var v,y=l.dtick,x=E.tickIncrement(E.tickFirst(l),y,"reverse",i);if("number"==typeof y)v=(x=function(t,e,r,n,i){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:a(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&"date"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(i))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(x,t,l,c,u))+(1+Math.floor((u-x)/y))*y;else for("M"===l.dtick.charAt(0)&&(x=function(t,e,r,n,a){var i=s.findExactDates(e,a);if(i.exactDays>.8){var o=Number(r.substr(1));i.exactYears>.8&&o%12==0?t=E.tickIncrement(t,"M6","reverse")+1.5*m:i.exactMonths>.8?t=E.tickIncrement(t,"M1","reverse")+15.5*m:t-=m/2;var l=E.tickIncrement(t,r);if(l<=n)return l}return t}(x,t,y,c,i)),v=x,0;v<=u;)v=E.tickIncrement(v,y,!1,i),0;return{start:e.c2r(x,0,i),end:e.c2r(v,0,i),size:y,_dataSpan:u-c}},E.prepTicks=function(t){var e=s.simpleMap(t.range,t.r2l);if("auto"===t.tickmode||!t.dtick){var r,n=t.nticks;n||("category"===t.type||"multicategory"===t.type?(r=t.tickfont?1.2*(t.tickfont.size||12):15,n=t._length/r):(r="y"===t._id.charAt(0)?40:80,n=s.constrain(t._length/r,4,9)+1),"radialaxis"===t._name&&(n*=2)),"array"===t.tickmode&&(n*=100),E.autoTicks(t,Math.abs(e[1]-e[0])/n),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0="date"===t.type?"2000-01-01":0),"date"===t.type&&t.dtick<.1&&(t.dtick=.1),q(t)},E.calcTicks=function(t){E.prepTicks(t);var e=s.simpleMap(t.range,t.r2l);if("array"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),a=s.simpleMap(t.range,t.r2l),i=1.0001*a[0]-1e-4*a[1],o=1.0001*a[1]-1e-4*a[0],l=Math.min(i,o),c=Math.max(i,o),u=0;Array.isArray(r)||(r=[]);var h="category"===t.type?t.d2l_noadd:t.d2l;"log"===t.type&&"L"!==String(t.dtick).charAt(0)&&(t.dtick="L"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var f=0;f<e.length;f++){var p=h(e[f]);p>l&&p<c&&(void 0===r[f]?n[u]=E.tickText(t,p):n[u]=H(t,p,String(r[f])),u++)}u<e.length&&n.splice(u,e.length-u);return n}(t);t._tmin=E.tickFirst(t);var r=1.0001*e[0]-1e-4*e[1],n=1.0001*e[1]-1e-4*e[0],i=e[1]<e[0];if(t._tmin<r!==i)return[];var o=[];"category"!==t.type&&"multicategory"!==t.type||(n=i?Math.max(-.5,n):Math.min(t._categories.length-.5,n));for(var l="log"===t.type&&!(a(t.dtick)||"L"===t.dtick.charAt(0)),c=null,u=Math.max(1e3,t._length||0),h=t._tmin;(i?h>=n:h<=n)&&!(o.length>u||h===c);h=E.tickIncrement(h,t.dtick,i,t.calendar)){c=h;var f=!1;l&&h!==(0|h)&&(f=!0),o.push({minor:f,value:h})}it(t)&&360===Math.abs(e[1]-e[0])&&o.pop(),t._tmax=(o[o.length-1]||{}).value,t._prevDateHead="",t._inCalcTicks=!0;for(var p=new Array(o.length),d=0;d<o.length;d++)p[d]=E.tickText(t,o[d].value,!1,o[d].minor);return t._inCalcTicks=!1,p};var D=[2,5,10],R=[1,2,3,6,12],F=[1,2,5,10,15,30],B=[1,2,3,7,14],N=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],j=[-.301,0,.301,.699,1],V=[15,30,45,90,180];function U(t,e,r){return e*s.roundUp(t/e,r)}function q(t){var e=t.dtick;if(t._tickexponent=0,a(e)||"string"==typeof e||(e=1),"category"!==t.type&&"multicategory"!==t.type||(t._tickround=null),"date"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,""),i=n.length;if("M"===String(e).charAt(0))i>10||"01-01"!==n.substr(5)?t._tickround="d":t._tickround=+e.substr(1)%12==0?"y":"m";else if(e>=m&&i<=10||e>=15*m)t._tickround="d";else if(e>=x&&i<=16||e>=y)t._tickround="M";else if(e>=b&&i<=19||e>=x)t._tickround="S";else{var o=t.l2r(r+e).replace(/^-/,"").length;t._tickround=Math.max(i,o)-20,t._tickround<0&&(t._tickround=4)}}else if(a(e)||"L"===e.charAt(0)){var s=t.range.map(t.r2d||Number);a(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01);Math.abs(c)>3&&(Y(t.exponentformat)&&!W(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function H(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||"",fontSize:n.size,font:n.family,fontColor:n.color}}E.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if("date"===t.type){t.tick0=s.dateTick0(t.calendar);var i=2*e;i>g?(e/=g,r=n(10),t.dtick="M"+12*U(e,r,D)):i>v?(e/=v,t.dtick="M"+U(e,1,R)):i>m?(t.dtick=U(e,m,B),t.tick0=s.dateTick0(t.calendar,!0)):i>y?t.dtick=U(e,y,R):i>x?t.dtick=U(e,x,F):i>b?t.dtick=U(e,b,F):(r=n(10),t.dtick=U(e,r,D))}else if("log"===t.type){t.tick0=0;var o=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(o[1]-o[0])<1){var l=1.5*Math.abs((o[1]-o[0])/e);e=Math.abs(Math.pow(10,o[1])-Math.pow(10,o[0]))/l,r=n(10),t.dtick="L"+U(e,r,D)}else t.dtick=e>.3?"D2":"D1"}else"category"===t.type||"multicategory"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):it(t)?(t.tick0=0,r=1,t.dtick=U(e,r,V)):(t.tick0=0,r=n(10),t.dtick=U(e,r,D));if(0===t.dtick&&(t.dtick=1),!a(t.dtick)&&"string"!=typeof t.dtick){var c=t.dtick;throw t.dtick=1,"ax.dtick error: "+String(c)}},E.tickIncrement=function(t,e,r,i){var o=r?-1:1;if(a(e))return t+o*e;var l=e.charAt(0),c=o*Number(e.substr(1));if("M"===l)return s.incrementMonth(t,c,i);if("L"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if("D"===l){var u="D2"===e?j:N,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw"unrecognized dtick "+String(e)},E.tickFirst=function(t){var e=t.r2l||Number,r=s.simpleMap(t.range,e),i=r[1]<r[0],o=i?Math.floor:Math.ceil,l=1.0001*r[0]-1e-4*r[1],c=t.dtick,u=e(t.tick0);if(a(c)){var h=o((l-u)/c)*c+u;return"category"!==t.type&&"multicategory"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var f=c.charAt(0),p=Number(c.substr(1));if("M"===f){for(var d,g,v,m=0,y=u;m<10;){if(((d=E.tickIncrement(y,c,i,t.calendar))-l)*(y-l)<=0)return i?Math.min(y,d):Math.max(y,d);g=(l-(y+d)/2)/(d-y),v=f+(Math.abs(Math.round(g))||1)*p,y=E.tickIncrement(y,v,g<0?!i:i,t.calendar),m++}return s.error("tickFirst did not converge",t),y}if("L"===f)return Math.log(o((Math.pow(10,l)-u)/p)*p+u)/Math.LN10;if("D"===f){var x="D2"===c?j:N,b=s.roundUp(s.mod(l,1),x,i);return Math.floor(l)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw"unrecognized dtick "+String(c)},E.tickText=function(t,e,r,n){var i,o=H(t,e),l="array"===t.tickmode,c=r||l,u=t.type,h="category"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),p=Math.abs(f[1]-f[0])/1e4;for(i=0;i<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[i]))<p);i++);if(i<t.ticktext.length)return o.text=String(t.ticktext[i]),o}function d(n){if(void 0===n)return!0;if(r)return"none"===n;var a={first:t._tmin,last:t._tmax}[n];return"all"!==n&&e!==a}var g=r?"never":"none"!==t.exponentformat&&d(t.showexponent)?"hide":"";if("date"===u?function(t,e,r,n){var i=t._tickround,o=r&&t.hoverformat||E.getTickFormat(t);n&&(i=a(i)?4:{y:"m",m:"d",d:"M",M:"S",S:4}[i]);var l,c=s.formatDate(e.x,o,i,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf("\n");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&("00:00:00"===c||"00:00"===c?(c=l,l=""):8===c.length&&(c=c.replace(/:00$/,"")));l&&(r?"d"===i?c+=", "+l:c=l+(c?", "+c:""):t._inCalcTicks&&l===t._prevDateHead||(c+="<br>"+l,t._prevDateHead=l));e.text=c}(t,o,r,c):"log"===u?function(t,e,r,n,i){var o=t.dtick,l=e.x,c=t.tickformat,u="string"==typeof o&&o.charAt(0);"never"===i&&(i="");n&&"L"!==u&&(o="L3",u="L");if(c||"L"===u)e.text=X(Math.pow(10,l),t,i,n);else if(a(o)||"D"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;"power"===p||Y(p)&&W(h)?(e.text=0===h?1:1===h?"10":"10<sup>"+(h>1?"":_)+f+"</sup>",e.fontSize*=1.25):("e"===p||"E"===p)&&f>2?e.text="1"+p+(h>0?"+":_)+f:(e.text=X(Math.pow(10,l),t,"","fakehover"),"D1"===o&&"y"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if("D"!==u)throw"unrecognized dtick "+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if("D1"===t.dtick){var d=String(e.text).charAt(0);"0"!==d&&"1"!==d||("y"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):"category"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r="");e.text=String(r)}(t,o):"multicategory"===u?function(t,e,r){var n=Math.round(e.x),a=t._categories[n]||[],i=void 0===a[1]?"":String(a[1]),o=void 0===a[0]?"":String(a[0]);r?e.text=o+" - "+i:(e.text=i,e.text2=o)}(t,o,r):it(t)?function(t,e,r,n,a){if("radians"!==t.thetaunit||r)e.text=X(e.x,t,a,n);else{var i=e.x/180;if(0===i)e.text="0";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){var r=1;for(;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,a=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/a),Math.round(r/a)]}(i);if(o[1]>=100)e.text=X(s.deg2rad(e.x),t,a,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text="\u03c0":e.text=o[0]+"\u03c0":e.text=["<sup>",o[0],"</sup>","\u2044","<sub>",o[1],"</sub>","\u03c0"].join(""),l&&(e.text=_+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,a){"never"===a?a="":"all"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(a="hide");e.text=X(e.x,t,a,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),"boundaries"===t.tickson||t.showdividers){var v=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[v(o.x-.5),v(o.x+t.dtick-.5)]}return o},E.hoverLabelText=function(t,e,r){if(r!==w&&r!==e)return E.hoverLabelText(t,e)+" - "+E.hoverLabelText(t,r);var n="log"===t.type&&e<=0,a=E.tickText(t,t.c2l(n?-e:e),"hover").text;return n?0===e?"0":_+a:a};var G=["f","p","n","\u03bc","m","","k","M","G","T"];function Y(t){return"SI"===t||"B"===t}function W(t){return t>14||t<-15}function X(t,e,r,n){var i=t<0,o=e._tickround,l=r||e.exponentformat||"B",c=e._tickexponent,u=E.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,dtick:"none"===e.showexponent?e.dtick:a(t)&&Math.abs(t)||1,range:"none"===e.showexponent?e.range.map(e.r2d):[0,t||1]};q(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,_);var p,d=Math.pow(10,-o)/2;if("none"===l&&(c=0),(t=Math.abs(t))<d)t="0",i=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+="0"}else{var v=(t=String(t)).indexOf(".")+1;v&&(t=t.substr(0,v+o).replace(/\.?0+$/,""))}t=s.numSeparate(t,e._separators,h)}c&&"hide"!==l&&(Y(l)&&W(c)&&(l="power"),p=c<0?_+-c:"power"!==l?"+"+c:String(c),"e"===l||"E"===l?t+=l+p:"power"===l?t+="\xd710<sup>"+p+"</sup>":"B"===l&&9===c?t+="B":Y(l)&&(t+=G[c/3+5]));return i?_+t:t}function Z(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join("_")}function J(t){var e=t.title.font.size,r=(t.title.text.match(l.BR_TAG_ALL)||[]).length;return t.title.hasOwnProperty("standoff")?r?e*(A+r*M):e*A:r?e*(r+1)*M:e}function K(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function Q(t){var e=n.select(t),r=e.select(".text-math-group");return r.empty()?e.select("text"):r}function $(t){return t._id+".automargin"}function tt(t){return $(t)+".mirror"}function et(t){return t._id+".rangeslider"}function rt(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function nt(t,e,r){var n,a,i=[],o=[],l=t.layout;for(n=0;n<e.length;n++)i.push(E.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(E.getFromId(t,r[n]));var c=Object.keys(f),u=["anchor","domain","overlaying","position","side","tickangle","editType"],h=["linear","log"];for(n=0;n<c.length;n++){var p=c[n],d=i[0][p],g=o[0][p],v=!0,m=!1,y=!1;if("_"!==p.charAt(0)&&"function"!=typeof d&&-1===u.indexOf(p)){for(a=1;a<i.length&&v;a++){var x=i[a][p];"type"===p&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?m=!0:x!==d&&(v=!1)}for(a=1;a<o.length&&v;a++){var b=o[a][p];"type"===p&&-1!==h.indexOf(g)&&-1!==h.indexOf(b)&&g!==b?y=!0:o[a][p]!==g&&(v=!1)}v&&(m&&(l[i[0]._name].type="linear"),y&&(l[o[0]._name].type="linear"),at(l,p,i,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],["?"])}}function at(t,e,r,n,a){var i,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for("title"===e&&(l&&l.text===a.x&&(l.text=a.y),c&&c.text===a.y&&(c.text=a.x)),i=0;i<r.length;i++)o(t,r[i]._name+"."+e).set(c);for(i=0;i<n.length;i++)o(t,n[i]._name+"."+e).set(l)}function it(t){return"angularaxis"===t._id}E.getTickFormat=function(t){var e,r,n,a,i,o,s,l;function c(t){return"string"!=typeof t?t:Number(t.replace("M",""))*v}function u(t,e){var r=["L","D"];if(typeof t==typeof e){if("number"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),a=r.indexOf(e.charAt(0));return n===a?Number(t.replace(/(L|D)/g,""))-Number(e.replace(/(L|D)/g,"")):n-a}return"number"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],a=u(t,e[0])>=0,i=u(t,e[1])<=0;return(r||a)&&(n||i)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case"date":case"linear":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(a=t.dtick,i=n.dtickrange,o=void 0,void 0,void 0,o=c||function(t){return t},s=i[0],l=i[1],(!s&&"number"!=typeof s||o(s)<=o(a))&&(!l&&"number"!=typeof l||o(l)>=o(a)))){r=n;break}break;case"log":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},E.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),a=e?E.findSubplotsWithAxis(n,e):n;return a.sort(function(t,e){var r=t.substr(1).split("y"),n=e.substr(1).split("y");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]}),a},E.findSubplotsWithAxis=function(t,e){for(var r=new RegExp("x"===e._id.charAt(0)?"^"+e._id+"y":e._id+"$"),n=[],a=0;a<t.length;a++){var i=t[a];r.test(i)&&n.push(i)}return n},E.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,a,i={_offset:0,_length:e.width,_id:""},o={_offset:0,_length:e.height,_id:""},s=E.list(t,"x",!0),l=E.list(t,"y",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),a=0;a<l.length;a++)0===r&&c.push({x:i,y:l[a]}),c.push({x:s[r],y:l[a]});var u=e._clips.selectAll(".axesclip").data(c,function(t){return t.x._id+t.y._id});u.enter().append("clipPath").classed("axesclip",!0).attr("id",function(t){return"clip"+e._uid+t.x._id+t.y._id}).append("rect"),u.exit().remove(),u.each(function(t){n.select(this).select("rect").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})})}},E.draw=function(t,e,r){var n=t._fullLayout;"redraw"===e&&n._paper.selectAll("g.subplot").each(function(t){var e=t[0],r=n._plots[e],a=r.xaxis,i=r.yaxis;r.xaxislayer.selectAll("."+a._id+"tick").remove(),r.yaxislayer.selectAll("."+i._id+"tick").remove(),r.xaxislayer.selectAll("."+a._id+"tick2").remove(),r.yaxislayer.selectAll("."+i._id+"tick2").remove(),r.xaxislayer.selectAll("."+a._id+"divider").remove(),r.yaxislayer.selectAll("."+i._id+"divider").remove(),r.gridlayer&&r.gridlayer.selectAll("path").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll("path").remove(),n._infolayer.select(".g-"+a._id+"title").remove(),n._infolayer.select(".g-"+i._id+"title").remove()});var a=e&&"redraw"!==e?e:E.listIds(t);return s.syncOrAsync(a.map(function(e){return function(){if(e){var n=E.getFromId(t,e),a=E.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),a}}}))},E.drawOne=function(t,e,r){var n,a,l;r=r||{},e.setScale();var f=t._fullLayout,p=e._id,d=p.charAt(0),g=E.counterLetter(p),v=e._mainLinePosition,m=e._mainMirrorPosition,y=f._plots[e._mainSubplot][d+"axislayer"],x=e._vals=E.calcTicks(e),b=[e.mirror,v,m].join("_");for(n=0;n<x.length;n++)x[n].axInfo=b;e._selections={},e._tickAngles&&(e._prevTickAngles=e._tickAngles),e._tickAngles={},e._depth=null;var _={};function w(t){var r=p+(t||"tick");return _[r]||(_[r]=function(t,e){var r,n,a,i;t._selections[e].size()?(r=1/0,n=-1/0,a=1/0,i=-1/0,t._selections[e].each(function(){var t=Q(this),e=h.bBox(t.node().parentNode);r=Math.min(r,e.top),n=Math.max(n,e.bottom),a=Math.min(a,e.left),i=Math.max(i,e.right)})):(r=0,n=0,a=0,i=0);return{top:r,bottom:n,left:a,right:i,height:n-r,width:i-a}}(e,r)),_[r]}if(e.visible){var k,T,A=E.makeTransFn(e);if("boundaries"===e.tickson){var L=function(t,e){var r,n=[],a=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)a(e[r],0);a(e[r-1],1)}return n}(0,x);T=E.clipEnds(e,L),k="inside"===e.ticks?T:L}else T=E.clipEnds(e,x),k="inside"===e.ticks?T:x;var C=e._gridVals=T,P=function(t,e){var r,n,a=[],i=function(t,e){var r=t.xbnd[e];null!==r&&a.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var o=e[r];o.text2!==n&&i(o,0),n=o.text2}i(e[r-1],1)}return a}(e,x);if(!f._hasOnlyLargeSploms){var O=e._subplotsWith,z={};for(n=0;n<O.length;n++){a=O[n];var I=(l=f._plots[a])[g+"axis"],D=I._mainAxis._id;if(!z[D]){z[D]=1;var R="x"===d?"M0,"+I._offset+"v"+I._length:"M"+I._offset+",0h"+I._length;E.drawGrid(t,e,{vals:C,counterAxis:I,layer:l.gridlayer.select("."+p),path:R,transFn:A}),E.drawZeroLine(t,e,{counterAxis:I,layer:l.zerolinelayer,path:R,transFn:A})}}}var F=E.getTickSigns(e),B=[];if(e.ticks){var N,j,V,U=E.makeTickPath(e,v,F[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(N=E.makeTickPath(e,m,F[3]),j=U+N):(N="",j=U),e.showdividers&&"outside"===e.ticks&&"boundaries"===e.tickson){var q={};for(n=0;n<P.length;n++)q[P[n].x]=1;V=function(t){return q[t.x]?N:j}}else V=j;E.drawTicks(t,e,{vals:k,layer:y,path:V,transFn:A}),"allticks"===e.mirror&&(B=Object.keys(e._linepositions||{}))}for(n=0;n<B.length;n++){a=B[n],l=f._plots[a];var G=e._linepositions[a]||[],Y=E.makeTickPath(e,G[0],F[0])+E.makeTickPath(e,G[1],F[1]);E.drawTicks(t,e,{vals:k,layer:l[d+"axislayer"],path:Y,transFn:A})}var W=[];if(W.push(function(){return E.drawLabels(t,e,{vals:x,layer:y,transFn:A,labelFns:E.makeLabelFns(e,v)})}),"multicategory"===e.type){var X={x:2,y:10}[d];W.push(function(){var r={x:"height",y:"width"}[d],n=w()[r]+X+(e._tickAngles[p+"tick"]?e.tickfont.size*M:0);return E.drawLabels(t,e,{vals:function(t,e){for(var r=[],n={},a=0;a<e.length;a++){var i=e[a];n[i.text2]?n[i.text2].push(i.x):n[i.text2]=[i.x]}for(var o in n)r.push(H(t,s.interp(n[o],.5),o));return r}(e,x),layer:y,cls:p+"tick2",repositionOnUpdate:!0,secondary:!0,transFn:A,labelFns:E.makeLabelFns(e,v+n*F[4])})}),W.push(function(){return e._depth=F[4]*(w("tick2")[e.side]-v),function(t,e,r){var n=e._id+"divider",a=r.vals,i=r.layer.selectAll("path."+n).data(a,Z);i.exit().remove(),i.enter().insert("path",":first-child").classed(n,1).classed("crisp",1).call(u.stroke,e.dividercolor).style("stroke-width",h.crispRound(t,e.dividerwidth,1)+"px"),i.attr("transform",r.transFn).attr("d",r.path)}(t,e,{vals:P,layer:y,path:E.makeTickPath(e,v,F[4],e._depth),transFn:A})})}else e.title.hasOwnProperty("standoff")&&W.push(function(){e._depth=F[4]*(w()[e.side]-v)});var K=o.getComponentMethod("rangeslider","isVisible")(e);return W.push(function(){var r,n,a,s,l=e.side.charAt(0),c=S[e.side].charAt(0),u=E.getPxPosition(t,e),h="outside"===e.ticks?e.ticklen:0;if((e.automargin||K)&&("multicategory"===e.type?r=w("tick2"):(r=w(),"x"===d&&"b"===l&&(e._depth=Math.max(r.width>0?r.bottom-u:0,h)))),e.automargin){n={x:0,y:0,r:0,l:0,t:0,b:0};var p=[0,1];if("x"===d){if("b"===l?n[l]=e._depth:(n[l]=e._depth=Math.max(r.width>0?u-r.top:0,h),p.reverse()),r.width>0){var v=r.right-(e._offset+e._length);v>0&&(n.xr=1,n.r=v);var m=e._offset-r.left;m>0&&(n.xl=0,n.l=m)}}else if("l"===l?n[l]=e._depth=Math.max(r.height>0?u-r.left:0,h):(n[l]=e._depth=Math.max(r.height>0?r.right-u:0,h),p.reverse()),r.height>0){var y=r.bottom-(e._offset+e._length);y>0&&(n.yb=0,n.b=y);var x=e._offset-r.top;x>0&&(n.yt=1,n.t=x)}n[g]="free"===e.anchor?e.position:e._anchorAxis.domain[p[0]],e.title.text!==f._dfltTitle[d]&&(n[l]+=J(e)+(e.title.standoff||0)),e.mirror&&"free"!==e.anchor&&((a={x:0,y:0,r:0,l:0,t:0,b:0})[c]=e.linewidth,e.mirror&&!0!==e.mirror&&(a[c]+=h),!0===e.mirror||"ticks"===e.mirror?a[g]=e._anchorAxis.domain[p[1]]:"all"!==e.mirror&&"allticks"!==e.mirror||(a[g]=[e._counterDomainMin,e._counterDomainMax][p[1]]))}K&&(s=o.getComponentMethod("rangeslider","autoMarginOpts")(t,e)),i.autoMargin(t,$(e),n),i.autoMargin(t,tt(e),a),i.autoMargin(t,et(e),s)}),r.skipTitle||K&&"bottom"===e.side||W.push(function(){return function(t,e){var r,n=t._fullLayout,a=e._id,i=a.charAt(0),o=e.title.font.size;if(e.title.hasOwnProperty("standoff"))r=e._depth+e.title.standoff+J(e);else{if("multicategory"===e.type)r=e._depth;else{r=10+1.5*o+(e.linewidth?e.linewidth-1:0)}r+="x"===i?"top"===e.side?o*(e.showticklabels?1:0):o*(e.showticklabels?1.5:.5):"right"===e.side?o*(e.showticklabels?1:.5):o*(e.showticklabels?.5:0)}var s,l,u,f,p=E.getPxPosition(t,e);"x"===i?(l=e._offset+e._length/2,u="top"===e.side?p-r:p+r):(u=e._offset+e._length/2,l="right"===e.side?p+r:p-r,s={rotate:"-90",offset:0});if("multicategory"!==e.type){var d=e._selections[e._id+"tick"];if(f={selection:d,side:e.side},d&&d.node()&&d.node().parentNode){var g=h.getTranslate(d.node().parentNode);f.offsetLeft=g.x,f.offsetTop=g.y}e.title.hasOwnProperty("standoff")&&(f.pad=0)}return c.draw(t,a+"title",{propContainer:e,propName:e._name+".title.text",placeholder:n._dfltTitle[i],avoid:f,transform:s,attributes:{x:l,y:u,"text-anchor":"middle"}})}(t,e)}),s.syncOrAsync(W)}},E.getTickSigns=function(t){var e=t._id.charAt(0),r={x:"top",y:"right"}[e],n=t.side===r?1:-1,a=[-1,1,n,-n];return"inside"!==t.ticks==("x"===e)&&(a=a.map(function(t){return-t})),t.side&&a.push({l:-1,t:-1,r:1,b:1}[t.side.charAt(0)]),a},E.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return"x"===e?function(e){return"translate("+(r+t.l2p(e.x))+",0)"}:function(e){return"translate(0,"+(r+t.l2p(e.x))+")"}},E.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var a=t._id.charAt(0),i=(t.linewidth||1)/2;return"x"===a?"M0,"+(e+i*r)+"v"+n*r:"M"+(e+i*r)+",0h"+n*r},E.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),i="boundaries"!==t.tickson&&"outside"===t.ticks,o=0,l=0;if(i&&(o+=t.ticklen),r&&"outside"===t.ticks){var c=s.deg2rad(r);o=t.ticklen*Math.cos(c)+1,l=t.ticklen*Math.sin(c)}t.showticklabels&&(i||t.showline)&&(o+=.2*t.tickfont.size);var u,h,f,p,d={labelStandoff:o+=(t.linewidth||1)/2,labelShift:l};return"x"===n?(p="bottom"===t.side?1:-1,u=l*p,h=e+o*p,f="bottom"===t.side?1:-.2,d.xFn=function(t){return t.dx+u},d.yFn=function(t){return t.dy+h+t.fontSize*f},d.anchorFn=function(t,e){return a(e)&&0!==e&&180!==e?e*p<0?"end":"start":"middle"},d.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:"top"===t.side?-n:0}):"y"===n&&(p="right"===t.side?1:-1,u=o,h=-l*p,f=90===Math.abs(t.tickangle)?.5:0,d.xFn=function(t){return t.dx+e+(u+t.fontSize*f)*p},d.yFn=function(t){return t.dy+h+t.fontSize*T},d.anchorFn=function(e,r){return a(r)&&90===Math.abs(r)?"middle":"right"===t.side?"start":"end"},d.heightFn=function(e,r,n){return(r*="left"===t.side?1:-1)<-30?-n:r<30?-.5*n:0}),d},E.drawTicks=function(t,e,r){r=r||{};var n=e._id+"tick",a=r.layer.selectAll("path."+n).data(e.ticks?r.vals:[],Z);a.exit().remove(),a.enter().append("path").classed(n,1).classed("ticks",1).classed("crisp",!1!==r.crisp).call(u.stroke,e.tickcolor).style("stroke-width",h.crispRound(t,e.tickwidth,1)+"px").attr("d",r.path),a.attr("transform",r.transFn)},E.drawGrid=function(t,e,r){r=r||{};var n=e._id+"grid",a=r.vals,i=r.counterAxis;if(!1===e.showgrid)a=[];else if(i&&E.shouldShowZeroLine(t,e,i))for(var o="array"===e.tickmode,s=0;s<a.length;s++){var l=a[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(a=a.slice(0,s).concat(a.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll("path."+n).data(a,Z);c.exit().remove(),c.enter().append("path").classed(n,1).classed("crisp",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr("transform",r.transFn).attr("d",r.path).call(u.stroke,e.gridcolor||"#ddd").style("stroke-width",e._gw+"px"),"function"==typeof r.path&&c.attr("d",r.path)},E.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+"zl",a=E.shouldShowZeroLine(t,e,r.counterAxis),i=r.layer.selectAll("path."+n).data(a?[{x:0,id:e._id}]:[]);i.exit().remove(),i.enter().append("path").classed(n,1).classed("zl",1).classed("crisp",!1!==r.crisp).each(function(){r.layer.selectAll("path").sort(function(t,e){return C.idSort(t.id,e.id)})}),i.attr("transform",r.transFn).attr("d",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style("stroke-width",h.crispRound(t,e.zerolinewidth,e._gw||1)+"px")},E.drawLabels=function(t,e,r){r=r||{};var i=t._fullLayout,o=e._id,c=o.charAt(0),u=r.cls||o+"tick",f=r.vals,p=r.labelFns,d=r.secondary?0:e.tickangle,g=(e._prevTickAngles||{})[u],v=r.layer.selectAll("g."+u).data(e.showticklabels?f:[],Z),m=[];function y(t,e){t.each(function(t){var i=n.select(this),o=i.select(".text-math-group"),s=p.anchorFn(t,e),c=r.transFn.call(i.node(),t)+(a(e)&&0!=+e?" rotate("+e+","+p.xFn(t)+","+(p.yFn(t)-t.fontSize/2)+")":""),u=l.lineCount(i),f=M*t.fontSize,d=p.heightFn(t,a(e)?+e:0,(u-1)*f);if(d&&(c+=" translate(0, "+d+")"),o.empty())i.select("text").attr({transform:c,"text-anchor":s});else{var g=h.bBox(o.node()).width*{end:-.5,start:.5}[s];o.attr("transform",c+(g?"translate("+g+",0)":""))}})}v.enter().append("g").classed(u,1).append("text").attr("text-anchor","middle").each(function(e){var r=n.select(this),a=t._promises.length;r.call(l.positionText,p.xFn(e),p.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[a]?m.push(t._promises.pop().then(function(){y(r,d)})):y(r,d)}),v.exit().remove(),r.repositionOnUpdate&&v.each(function(t){n.select(this).select("text").call(l.positionText,p.xFn(t),p.yFn(t))}),y(v,g+1?g:d);var x=null;e._selections&&(e._selections[u]=v);var b=[function(){return m.length&&Promise.all(m)}];e.automargin&&i._redrawFromAutoMarginCount&&90===g?(x=90,b.push(function(){y(v,g)})):b.push(function(){if(y(v,d),f.length&&"x"===c&&!a(d)&&("log"!==e.type||"D"!==String(e.dtick).charAt(0))){x=0;var t,n=0,i=[];if(v.each(function(t){n=Math.max(n,t.fontSize);var r=e.l2p(t.x),a=Q(this),o=h.bBox(a.node());i.push({top:0,bottom:10,height:10,left:r-o.width/2,right:r+o.width/2+2,width:o.width+2})}),"boundaries"!==e.tickson&&!e.showdividers||r.secondary){var o=f.length,l=Math.abs((f[o-1].x-f[0].x)*e._m)/(o-1)<2.5*n||"multicategory"===e.type;for(t=0;t<i.length-1;t++)if(s.bBoxIntersect(i[t],i[t+1])){x=l?90:30;break}}else{var u=2;for(e.ticks&&(u+=e.tickwidth/2),t=0;t<i.length;t++){var p=f[t].xbnd,g=i[t];if(null!==p[0]&&g.left-e.l2p(p[0])<u||null!==p[1]&&e.l2p(p[1])-g.right<u){x=90;break}}}x&&y(v,x)}}),e._tickAngles&&b.push(function(){e._tickAngles[u]=null===x?a(d)?d:0:x});var _=s.syncOrAsync(b);return _&&_.then&&t._promises.push(_),_},E.getPxPosition=function(t,e){var r,n=t._fullLayout._size,a=e._id.charAt(0),i=e.side;return"free"!==e.anchor?r=e._anchorAxis:"x"===a?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:"y"===a&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),"top"===i||"left"===i?r._offset:"bottom"===i||"right"===i?r._offset+r._length:void 0},E.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&("linear"===e.type||"-"===e.type)&&(K(e,0)||!function(t,e,r,n){var a=r._mainAxis;if(!a)return;var i=t._fullLayout,o=e._id.charAt(0),s=E.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==("x"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return"number"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var a=t._linepositions||{};for(var i in a)if(n(a[i][0])||n(a[i][1]))return!0}var u=i._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var h=E.list(t,s),f=0;f<h.length;f++){var p=h[f];if(p._mainAxis===a&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,a=e._id.charAt(0),i=0;i<r.length;i++){var s=r[i];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,"bar-like")&&s.orientation==={x:"h",y:"v"}[a])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===a)return!0}}return!1}(t,e))},E.clipEnds=function(t,e){return e.filter(function(e){return K(t,e.x)})},E.allowAutoMargin=function(t){for(var e=E.list(t,"",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&(i.allowAutoMargin(t,$(n)),n.mirror&&i.allowAutoMargin(t,tt(n))),o.getComponentMethod("rangeslider","isVisible")(n)&&i.allowAutoMargin(t,et(n))}},E.swap=function(t,e){for(var r=function(t,e){var r,n,a=[];for(r=0;r<e.length;r++){var i=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<a.length;n++)-1===a[n].x.indexOf(o)&&-1===a[n].y.indexOf(s)||i.push(n);if(i.length){var l,c=a[i[0]];if(i.length>1)for(n=1;n<i.length;n++)l=a[i[n]],rt(c.x,l.x),rt(c.y,l.y);rt(c.x,[o]),rt(c.y,[s])}else a.push({x:[o],y:[s]})}}return a}(t,e),n=0;n<r.length;n++)nt(t,r[n].x,r[n].y)}},{"../../components/color":591,"../../components/drawing":612,"../../components/titles":678,"../../constants/alignment":685,"../../constants/numerical":692,"../../lib":716,"../../lib/svg_text_utils":740,"../../plots/plots":825,"../../registry":845,"./autorange":763,"./axis_autotype":765,"./axis_ids":767,"./clean_ticks":769,"./layout_attributes":776,"./set_convert":782,d3:164,"fast-isnumeric":227}],765:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../constants/numerical").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,a.isArrayOrTypedArray(o[0])&&a.isArrayOrTypedArray(o[1]))?"multicategory":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),i=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,a.isDateTime(c,e)&&(i+=1),n(c)&&(o+=1))}return i>2*o}(t,e)?"date":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,"boolean"==typeof l?n++:a.cleanNumber(l)!==i?r++:"string"==typeof l&&n++)}return n>2*r}(t)?"category":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?"linear":"-";var o}},{"../../constants/numerical":692,"../../lib":716,"fast-isnumeric":227}],766:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("./layout_attributes"),o=t("./tick_value_defaults"),s=t("./tick_mark_defaults"),l=t("./tick_label_defaults"),c=t("./category_order_defaults"),u=t("./line_grid_defaults"),h=t("./set_convert");e.exports=function(t,e,r,f,p){var d=f.letter,g=f.font||{},v=f.splomStash||{},m=r("visible",!f.visibleDflt),y=e.type;"date"===y&&n.getComponentMethod("calendars","handleDefaults")(t,e,"calendar",f.calendar);h(e,p);var x=!e.isValidRange(t.range);x&&f.reverseDflt&&(x="reversed"),!r("autorange",x)||"linear"!==y&&"-"!==y||r("rangemode"),r("range"),e.cleanRange(),c(t,e,r,f),"category"===y||f.noHover||r("hoverformat");var b=r("color"),_=b!==i.color.dflt?b:g.color,w=v.label||p._dfltTitle[d];if(l(t,e,r,y,f,{pass:1}),!m)return e;r("title.text",w),a.coerceFont(r,"title.font",{family:g.family,size:Math.round(1.2*g.size),color:_}),o(t,e,r,y),l(t,e,r,y,f,{pass:2}),s(t,e,r,f),u(t,e,r,{dfltColor:b,bgColor:f.bgColor,showGrid:f.showGrid,attributes:i}),(e.showline||e.ticks)&&r("mirror"),f.automargin&&r("automargin");var k,T="multicategory"===e.type;f.noTickson||"category"!==e.type&&!T||!e.ticks&&!e.showgrid||(T&&(k="boundaries"),r("tickson",k));T&&(r("showdividers")&&(r("dividercolor"),r("dividerwidth")));return e}},{"../../lib":716,"../../registry":845,"./category_order_defaults":768,"./layout_attributes":776,"./line_grid_defaults":778,"./set_convert":782,"./tick_label_defaults":783,"./tick_mark_defaults":784,"./tick_value_defaults":785}],767:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("./constants");r.id2name=function(t){if("string"==typeof t&&t.match(a.AX_ID_PATTERN)){var e=t.substr(1);return"1"===e&&(e=""),t.charAt(0)+"axis"+e}},r.name2id=function(t){if(t.match(a.AX_NAME_PATTERN)){var e=t.substr(5);return"1"===e&&(e=""),t.charAt(0)+e}},r.cleanId=function(t,e){if(t.match(a.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,"");return"1"===r&&(r=""),t.charAt(0)+r}},r.list=function(t,e,n){var a=t._fullLayout;if(!a)return[];var i,o=r.listIds(t,e),s=new Array(o.length);for(i=0;i<o.length;i++){var l=o[i];s[i]=a[l.charAt(0)+"axis"+l.substr(1)]}if(!n){var c=a._subplots.gl3d||[];for(i=0;i<c.length;i++){var u=a[c[i]];e?s.push(u[e+"axis"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+"axis"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var a=t._fullLayout;return"x"===n?e=e.replace(/y[0-9]*/,""):"y"===n&&(e=e.replace(/x[0-9]*/,"")),a[r.id2name(e)]},r.getFromTrace=function(t,e,a){var i=t._fullLayout,o=null;if(n.traceIs(e,"gl3d")){var s=e.scene;"scene"===s.substr(0,5)&&(o=i[s][a+"axis"])}else o=r.getFromId(t,e[a+"axis"]||a);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return"g"+n}return e}},{"../../registry":845,"./constants":770}],768:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){if("category"===e.type){var a,i=t.categoryarray,o=Array.isArray(i)&&i.length>0;o&&(a="array");var s,l=r("categoryorder",a);"array"===l&&(s=r("categoryarray")),o||"array"!==l||(l=e.categoryorder="trace"),"trace"===l?e._initialCategories=[]:"array"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,a,i=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[i+"axis"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][i];for(a=0;a<l.length;a++){var c=l[a];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),"category ascending"===l?e._initialCategories=s:"category descending"===l&&(e._initialCategories=s.reverse()))}}},{}],769:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../constants/numerical").ONEDAY;r.dtick=function(t,e){var r="log"===e,a="date"===e,o="category"===e,s=a?i:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:o?Math.max(1,Math.round(t)):a?Math.max(.1,t):t;if("string"!=typeof t||!a&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(a&&"M"===l&&c===Math.round(c)||r&&"L"===l||r&&"D"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,i){return"date"===e?a.cleanDate(t,a.dateTick0(r)):"D1"!==i&&"D2"!==i?n(t)?Number(t):0:void 0}},{"../../constants/numerical":692,"../../lib":716,"fast-isnumeric":227}],770:[function(t,e,r){"use strict";var n=t("../../lib/regex").counter;e.exports={idRegex:{x:n("x"),y:n("y")},attrRegex:n("[xy]axis"),xAxisMatch:n("xaxis"),yAxisMatch:n("yaxis"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:"-select",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:["imagelayer","heatmaplayer","contourcarpetlayer","contourlayer","funnellayer","waterfalllayer","barlayer","carpetlayer","violinlayer","boxlayer","ohlclayer","scattercarpetlayer","scatterlayer"],clipOnAxisFalseQuery:[".scatterlayer",".barlayer",".funnellayer",".waterfalllayer"],layerValue2layerClass:{"above traces":"above","below traces":"below"}}},{"../../lib/regex":732}],771:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./axis_ids").id2name,i=t("./scale_zoom"),o=t("./autorange").makePadFn,s=t("./autorange").concatExtremes,l=t("../../constants/numerical").ALMOST_EQUAL,c=t("../../constants/alignment").FROM_BL;function u(t,e,r,n,i){var o,s,l,c,u="range"!==i,h=n[a(e)].type,f=[];for(s=0;s<r.length;s++)if((l=r[s])!==e&&(c=n[a(l)]).type===h)if(c.fixedrange){if(u&&c.anchor){n[a(c.anchor)].fixedrange&&f.push(l)}}else f.push(l);for(o=0;o<t.length;o++)if(t[o][e]){var p=t[o],d=[];for(s=0;s<f.length;s++)p[l=f[s]]||d.push(l);return{linkableAxes:d,thisGroup:p}}return{linkableAxes:f,thisGroup:null}}function h(t,e,r,n,a){var i,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(i=0;i<t.length;i++)if(s=t[i],i!==c&&s[n]){var h=s[n];for(o=0;o<u.length;o++)s[l=u[o]]=h*a*e[l];return void t.splice(c,1)}if(1!==a)for(o=0;o<u.length;o++)e[u[o]]*=a;e[n]=1}function f(t,e){var r=t._inputDomain,n=c[t.constraintoward],a=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[a+(r[0]-a)/e,a+(r[1]-a)/e],t.setScale()}r.handleConstraintDefaults=function(t,e,r,a){var i,o,s,l,c=a.allAxisIds,f=a.layoutOut,p=a.scaleanchorDflt,d=a.constrainDflt,g=f._axisConstraintGroups,v=f._axisMatchGroups,m=e._id,y=m.charAt(0),x=((f._splomAxes||{})[y]||{})[m]||{},b=e._id,_=b.charAt(0),w=r("constrain",d);if(n.coerce(t,e,{constraintoward:{valType:"enumerated",values:"x"===_?["left","center","right"]:["bottom","middle","top"],dflt:"x"===_?"center":"middle"}},"constraintoward"),!t.matches&&!x.matches||e.fixedrange||(o=u(v,b,c,f),i=n.coerce(t,e,{matches:{valType:"enumerated",values:o.linkableAxes||[],dflt:x.matches}},"matches")),i||e.fixedrange&&"domain"!==w||!t.scaleanchor&&!p||(l=u(g,b,c,f,w),s=n.coerce(t,e,{scaleanchor:{valType:"enumerated",values:l.linkableAxes||[]}},"scaleanchor",p)),i?(delete e.constrain,h(v,o.thisGroup,b,i,1)):-1!==c.indexOf(t.matches)&&n.warn("ignored "+e._name+'.matches: "'+t.matches+'" to avoid either an infinite loop or because the target axis has fixed range.'),s){var k=r("scaleratio");k||(k=e.scaleratio=1),h(g,l.thisGroup,b,s,k)}else-1!==c.indexOf(t.scaleanchor)&&n.warn("ignored "+e._name+'.scaleanchor: "'+t.scaleanchor+'" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the target axis has fixed range or this axis declares a *matches* constraint.')},r.enforce=function(t){var e,r,n,c,u,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var v=g[e],m=Object.keys(v),y=1/0,x=0,b=1/0,_={},w={},k=!1;for(r=0;r<m.length;r++)w[n=m[r]]=c=d[a(n)],c._inputDomain?c.domain=c._inputDomain.slice():c._inputDomain=c.domain.slice(),c._inputRange||(c._inputRange=c.range.slice()),c.setScale(),_[n]=u=Math.abs(c._m)/v[n],y=Math.min(y,u),"domain"!==c.constrain&&c._constraintShrinkable||(b=Math.min(b,u)),delete c._constraintShrinkable,x=Math.max(x,u),"domain"===c.constrain&&(k=!0);if(!(y>l*x)||k)for(r=0;r<m.length;r++)if(u=_[n=m[r]],h=(c=w[n]).constrain,u!==b||"domain"===h)if(p=u/b,"range"===h)i(c,p);else{var T=c._inputDomain,A=(c.domain[1]-c.domain[0])/(T[1]-T[0]),M=(c.r2l(c.range[1])-c.r2l(c.range[0]))/(c.r2l(c._inputRange[1])-c.r2l(c._inputRange[0]));if((p/=A)*M<1){c.domain=c._input.domain=T.slice(),i(c,p);continue}if(M<1&&(c.range=c._input.range=c._inputRange.slice(),p*=M),c.autorange){var S=c.r2l(c.range[0]),E=c.r2l(c.range[1]),L=(S+E)/2,C=L,P=L,O=Math.abs(E-L),z=L-O*p*1.0001,I=L+O*p*1.0001,D=o(c);f(c,p);var R,F,B=Math.abs(c._m),N=s(t,c),j=N.min,V=N.max;for(F=0;F<j.length;F++)(R=j[F].val-D(j[F])/B)>z&&R<C&&(C=R);for(F=0;F<V.length;F++)(R=V[F].val+D(V[F])/B)<I&&R>P&&(P=R);p/=(P-C)/(2*O),C=c.l2r(C),P=c.l2r(P),c.range=c._input.range=S<E?[C,P]:[P,C]}f(c,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,a=t._fullLayout._axisConstraintGroups,i=0;i<a.length;i++)if(a[i][n]){r=!0;break}r&&"domain"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{"../../constants/alignment":685,"../../constants/numerical":692,"../../lib":716,"./autorange":763,"./axis_ids":767,"./scale_zoom":780}],772:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("has-passive-events"),o=t("../../registry"),s=t("../../lib"),l=t("../../lib/svg_text_utils"),c=t("../../components/color"),u=t("../../components/drawing"),h=t("../../components/fx"),f=t("./axes"),p=t("../../lib/setcursor"),d=t("../../components/dragelement"),g=t("../../constants/alignment").FROM_TL,v=t("../../lib/clear_gl_canvases"),m=t("../../plot_api/subroutines").redrawReglTraces,y=t("../plots"),x=t("./axis_ids").getFromId,b=t("./select").prepSelect,_=t("./select").clearSelect,w=t("./select").selectOnClick,k=t("./scale_zoom"),T=t("./constants"),A=T.MINDRAG,M=T.MINZOOM,S=!0;function E(t,e,r,n){var a=s.ensureSingle(t.draglayer,e,r,function(e){e.classed("drag",!0).style({fill:"transparent","stroke-width":0}).attr("data-subplot",t.id)});return a.call(p,n),a.node()}function L(t,e,r,a,i,o,s){var l=E(t,"rect",e,r);return n.select(l).call(u.setRect,a,i,o,s),l}function C(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return""}function P(t,e,r,n,a){for(var i=0;i<t.length;i++){var o=t[i];if(!o.fixedrange){var s=o._rl[0],l=o._rl[1]-s;n[o._name+".range[0]"]=o.l2r(s+l*e),n[o._name+".range[1]"]=o.l2r(s+l*r)}}if(a&&a.length){var c=(e+(1-r))/2;P(a,c,1-c,n,[])}}function O(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.fixedrange||(n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)])}}function z(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function I(t,e,r,n,a){return t.append("path").attr("class","zoombox").style({fill:e>.2?"rgba(0,0,0,0)":"rgba(255,255,255,0)","stroke-width":0}).attr("transform","translate("+r+", "+n+")").attr("d",a+"Z")}function D(t,e,r){return t.append("path").attr("class","zoombox-corners").style({fill:c.background,stroke:c.defaultLine,"stroke-width":1,opacity:0}).attr("transform","translate("+e+", "+r+")").attr("d","M0,0Z")}function R(t,e,r,n,a,i){t.attr("d",n+"M"+r.l+","+r.t+"v"+r.h+"h"+r.w+"v-"+r.h+"h-"+r.w+"Z"),F(t,e,a,i)}function F(t,e,r,n){r||(t.transition().style("fill",n>.2?"rgba(0,0,0,0.4)":"rgba(255,255,255,0.3)").duration(200),e.transition().style("opacity",1).duration(200))}function B(t){n.select(t).selectAll(".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners").remove()}function N(t){S&&t.data&&t._context.showTips&&(s.notifier(s._(t,"Double-click to zoom back out"),"long"),S=!1)}function j(t){return"lasso"===t||"select"===t}function V(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,M)/2);return"M"+(t.l-3.5)+","+(t.t-.5+e)+"h3v"+-e+"h"+e+"v-3h-"+(e+3)+"ZM"+(t.r+3.5)+","+(t.t-.5+e)+"h-3v"+-e+"h"+-e+"v-3h"+(e+3)+"ZM"+(t.r+3.5)+","+(t.b+.5-e)+"h-3v"+e+"h"+-e+"v3h"+(e+3)+"ZM"+(t.l-3.5)+","+(t.b+.5-e)+"h3v"+e+"h"+e+"v3h-"+(e+3)+"Z"}function U(t,e,r,n){for(var a,i,o,l,c=!1,u={},h={},f=0;f<e.length;f++){var p=e[f];for(a in r)if(p[a]){for(o in p)("x"===o.charAt(0)?r:n)[o]||(u[o]=a);for(i in n)p[i]&&(c=!0)}for(i in n)if(p[i])for(l in p)("x"===l.charAt(0)?r:n)[l]||(h[l]=i)}c&&(s.extendFlat(u,h),h={});var d={},g=[];for(o in u){var v=x(t,o);g.push(v),d[v._id]=v}var m={},y=[];for(l in h){var b=x(t,l);y.push(b),m[b._id]=b}return{xaHash:d,yaHash:m,xaxes:g,yaxes:y,xLinks:u,yLinks:h,isSubplotConstrained:c}}function q(t,e){if(i){var r=void 0!==t.onwheel?"wheel":"mousewheel";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel&&(t.onmousewheel=e)}function H(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,i,c,p,S,E){var F,G,Y,W,X,Z,J,K,Q,$,tt,et,rt,nt,at,it,ot,st,lt,ct,ut,ht=t._fullLayout._zoomlayer,ft=S+E==="nsew",pt=1===(S+E).length;function dt(){if(F=e.xaxis,G=e.yaxis,Q=F._length,$=G._length,J=F._offset,K=G._offset,(Y={})[F._id]=F,(W={})[G._id]=G,S&&E)for(var r=e.overlays,n=0;n<r.length;n++){var a=r[n].xaxis;Y[a._id]=a;var i=r[n].yaxis;W[i._id]=i}X=H(Y),Z=H(W),rt=C(X,E),nt=C(Z,S),at=!nt&&!rt,tt=U(t,t._fullLayout._axisConstraintGroups,Y,W),et=U(t,t._fullLayout._axisMatchGroups,Y,W),it=E||tt.isSubplotConstrained||et.isSubplotConstrained,ot=S||tt.isSubplotConstrained||et.isSubplotConstrained;var o=t._fullLayout;st=o._has("scattergl"),lt=o._has("splom"),ct=o._has("svg")}dt();var gt=function(t,e,r){return t?"nsew"===t?r?"":"pan"===e?"move":"crosshair":t.toLowerCase()+"-resize":"pointer"}(nt+rt,t._fullLayout.dragmode,ft),vt=L(e,S+E+"drag",gt,r,i,c,p);if(at&&!ft)return vt.onmousedown=null,vt.style.pointerEvents="none",vt;var mt,yt,xt,bt,_t,wt,kt,Tt,At,Mt,St={element:vt,gd:t,plotinfo:e};function Et(){St.plotinfo.selection=!1,_(t)}function Lt(r,a){var i=t._fullLayout.clickmode;if(B(t),2!==r||pt||function(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];rt&&(r=r.concat(X)),nt&&(r=r.concat(Z)),et.xaxes&&(r=r.concat(et.xaxes)),et.yaxes&&(r=r.concat(et.yaxes));var n,a,i,s={};if("reset+autosize"===e)for(e="autosize",a=0;a<r.length;a++)if((n=r[a])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e="reset";break}if("autosize"===e)for(a=0;a<r.length;a++)(n=r[a]).fixedrange||(s[n._name+".autorange"]=!0);else if("reset"===e)for((rt||tt.isSubplotConstrained)&&(r=r.concat(tt.xaxes)),nt&&!tt.isSubplotConstrained&&(r=r.concat(tt.yaxes)),tt.isSubplotConstrained&&(rt?nt||(r=r.concat(Z)):r=r.concat(X)),a=0;a<r.length;a++)(n=r[a]).fixedrange||(n._rangeInitial?(i=n._rangeInitial,s[n._name+".range[0]"]=i[0],s[n._name+".range[1]"]=i[1]):s[n._name+".autorange"]=!0);t.emit("plotly_doubleclick",null),o.call("_guiRelayout",t,s)}}(),ft)i.indexOf("select")>-1&&w(a,t,X,Z,e.id,St),i.indexOf("event")>-1&&h.click(t,a,e.id);else if(1===r&&pt){var s=S?G:F,c="s"===S||"w"===E?0:1,u=s._name+".range["+c+"]",f=function(t,e){var r,a=t.range[e],i=Math.abs(a-t.range[1-e]);return"date"===t.type?a:"log"===t.type?(r=Math.ceil(Math.max(0,-Math.log(i)/Math.LN10))+3,n.format("."+r+"g")(Math.pow(10,a))):(r=Math.floor(Math.log(Math.abs(a))/Math.LN10)-Math.floor(Math.log(i)/Math.LN10)+4,n.format("."+String(r)+"g")(a))}(s,c),p="left",d="middle";if(s.fixedrange)return;S?(d="n"===S?"top":"bottom","right"===s.side&&(p="right")):"e"===E&&(p="right"),t._context.showAxisRangeEntryBoxes&&n.select(vt).call(l.makeEditable,{gd:t,immediate:!0,background:t._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:"#444",horizontalAlign:p,verticalAlign:d}).on("edit",function(e){var r=s.d2r(e);void 0!==r&&o.call("_guiRelayout",t,u,r)})}}function Ct(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min(Q,e+mt)),a=Math.max(0,Math.min($,r+yt)),i=Math.abs(n-mt),o=Math.abs(a-yt);function s(){kt="",xt.r=xt.l,xt.t=xt.b,At.attr("d","M0,0Z")}if(xt.l=Math.min(mt,n),xt.r=Math.max(mt,n),xt.t=Math.min(yt,a),xt.b=Math.max(yt,a),tt.isSubplotConstrained)i>M||o>M?(kt="xy",i/Q>o/$?(o=i*$/Q,yt>a?xt.t=yt-o:xt.b=yt+o):(i=o*Q/$,mt>n?xt.l=mt-i:xt.r=mt+i),At.attr("d",V(xt))):s();else if(et.isSubplotConstrained)if(i>M||o>M){kt="xy";var l=Math.min(xt.l/Q,($-xt.b)/$),c=Math.max(xt.r/Q,($-xt.t)/$);xt.l=l*Q,xt.r=c*Q,xt.b=(1-l)*$,xt.t=(1-c)*$,At.attr("d",V(xt))}else s();else!nt||o<Math.min(Math.max(.6*i,A),M)?i<A||!rt?s():(xt.t=0,xt.b=$,kt="x",At.attr("d",function(t,e){return"M"+(t.l-.5)+","+(e-M-.5)+"h-3v"+(2*M+1)+"h3ZM"+(t.r+.5)+","+(e-M-.5)+"h3v"+(2*M+1)+"h-3Z"}(xt,yt))):!rt||i<Math.min(.6*o,M)?(xt.l=0,xt.r=Q,kt="y",At.attr("d",function(t,e){return"M"+(e-M-.5)+","+(t.t-.5)+"v-3h"+(2*M+1)+"v3ZM"+(e-M-.5)+","+(t.b+.5)+"v3h"+(2*M+1)+"v-3Z"}(xt,mt))):(kt="xy",At.attr("d",V(xt)));xt.w=xt.r-xt.l,xt.h=xt.b-xt.t,kt&&(Mt=!0),t._dragged=Mt,R(Tt,At,xt,_t,wt,bt),Pt(),t.emit("plotly_relayouting",ut),wt=!0}function Pt(){ut={},"xy"!==kt&&"x"!==kt||(P(X,xt.l/Q,xt.r/Q,ut,tt.xaxes),Bt("x",ut)),"xy"!==kt&&"y"!==kt||(P(Z,($-xt.b)/$,($-xt.t)/$,ut,tt.yaxes),Bt("y",ut))}function Ot(){Pt(),B(t),jt(),N(t)}St.prepFn=function(e,r,n){var i=St.dragmode,o=t._fullLayout.dragmode;o!==i&&(St.dragmode=o),dt(),at||(ft?e.shiftKey?"pan"===o?o="zoom":j(o)||(o="pan"):e.ctrlKey&&(o="pan"):o="pan"),St.minDrag="lasso"===o?1:void 0,j(o)?(St.xaxes=X,St.yaxes=Z,b(e,r,n,St,o)):(St.clickFn=Lt,j(i)&&Et(),at||("zoom"===o?(St.moveFn=Ct,St.doneFn=Ot,St.minDrag=1,function(e,r,n){var i=vt.getBoundingClientRect();mt=r-i.left,yt=n-i.top,xt={l:mt,r:mt,w:0,t:yt,b:yt,h:0},bt=t._hmpixcount?t._hmlumcount/t._hmpixcount:a(t._fullLayout.plot_bgcolor).getLuminance(),wt=!1,kt="xy",Mt=!1,Tt=I(ht,bt,J,K,_t="M0,0H"+Q+"V"+$+"H0V0"),At=D(ht,J,K)}(0,r,n)):"pan"===o&&(St.moveFn=Ft,St.doneFn=jt))),t._fullLayout._redrag=function(){var e=t._dragdata;e&&e.element===vt&&(j(t._fullLayout.dragmode)||(dt(),Vt([0,0,Q,$]),St.moveFn(e.dx,e.dy)))}},d.init(St);var zt=[0,0,Q,$],It=null,Dt=T.REDRAWDELAY,Rt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ft(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,"ew"===rt||"ns"===nt)return rt&&(O(X,e),Bt("x")),nt&&(O(Z,r),Bt("y")),Vt([rt?-e:0,nt?-r:0,Q,$]),Nt(),void t.emit("plotly_relayouting",ut);if(tt.isSubplotConstrained&&rt&&nt){var n="w"===rt==("n"===nt)?1:-1,a=(e/Q+n*r/$)/2;e=a*Q,r=n*a*$}"w"===rt?e=l(X,0,e):"e"===rt?e=l(X,1,-e):rt||(e=0),"n"===nt?r=l(Z,1,r):"s"===nt?r=l(Z,0,-r):nt||(r=0);var i="w"===rt?e:0,o="n"===nt?r:0;if(tt.isSubplotConstrained){var s;if(!rt&&1===nt.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),k(X[s],1-r/$);i=(e=r*Q/$)/2}if(!nt&&1===rt.length){for(s=0;s<Z.length;s++)Z[s].range=Z[s]._r.slice(),k(Z[s],1-e/Q);o=(r=e*$/Q)/2}}Bt("x"),Bt("y"),Vt([i,o,Q-e,$-r]),Nt(),t.emit("plotly_relayouting",ut)}function l(t,e,r){for(var n,a,i=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,a=s._rl[i]+(s._rl[e]-s._rl[i])/z(r/s._length);var l=s.l2r(a);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-a)/(n._rl[e]-n._rl[i])}}function Bt(t,e){for(var r=et.isSubplotConstrained?{x:Z,y:X}[t]:et[t+"axes"],n=et.isSubplotConstrained?{x:X,y:Z}[t]:[],a=0;a<r.length;a++){var i=r[a],o=i._id,s=et.xLinks[o]||et.yLinks[o],l=n[0]||Y[s]||W[s];l&&(e?(e[i._name+".range[0]"]=e[l._name+".range[0]"],e[i._name+".range[1]"]=e[l._name+".range[1]"]):i.range=l.range.slice())}}function Nt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(it&&(n(X),n(tt.xaxes),n(et.xaxes)),ot&&(n(Z),n(tt.yaxes),n(et.yaxes)),ut={},e=0;e<r.length;e++){var a=r[e],i=x(t,a);f.drawOne(t,i,{skipTitle:!0}),ut[i._name+".range[0]"]=i.range[0],ut[i._name+".range[1]"]=i.range[1]}f.redrawComponents(t,r)}function jt(){Vt([0,0,Q,$]),s.syncOrAsync([y.previousPromises,function(){t._fullLayout._replotting=!1,o.call("_guiRelayout",t,ut)}],t)}function Vt(e){var r,n,a,i,l=t._fullLayout,c=l._plots,h=l._subplots.cartesian;if(lt&&o.subplotsRegistry.splom.drag(t),st)for(r=0;r<h.length;r++)if(a=(n=c[h[r]]).xaxis,i=n.yaxis,n._scene){var f=s.simpleMap(a.range,a.r2l),p=s.simpleMap(i.range,i.r2l);n._scene.update({range:[f[0],p[0],f[1],p[1]]})}if((lt||st)&&(v(t),m(t)),ct){var d=e[2]/F._length,g=e[3]/G._length;for(r=0;r<h.length;r++){a=(n=c[h[r]]).xaxis,i=n.yaxis;var y,x,b,_,w=it&&!a.fixedrange&&Y[a._id],k=ot&&!i.fixedrange&&W[i._id];if(w?(y=d,b=E?e[0]:Ht(a,y)):et.xaHash[a._id]?(y=d,b=e[0]*a._length/F._length):et.yaHash[a._id]?(y=g,b="ns"===nt?-e[1]*a._length/G._length:Ht(a,y,{n:"top",s:"bottom"}[nt])):b=qt(a,y=Ut(a,d,g)),k?(x=g,_=S?e[1]:Ht(i,x)):et.yaHash[i._id]?(x=g,_=e[1]*i._length/G._length):et.xaHash[i._id]?(x=d,_="ew"===rt?-e[0]*i._length/F._length:Ht(i,x,{e:"right",w:"left"}[rt])):_=qt(i,x=Ut(i,d,g)),y||x){y||(y=1),x||(x=1);var T=a._offset-b/y,A=i._offset-_/x;n.clipRect.call(u.setTranslate,b,_).call(u.setScale,y,x),n.plot.call(u.setTranslate,T,A).call(u.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(u.setPointGroupScale(n.zoomScalePts,y,x),u.setTextPointsScale(n.zoomScaleTxt,y,x)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Ut(t,e,r){return t.fixedrange?0:it&&tt.xaHash[t._id]?e:ot&&(tt.isSubplotConstrained?tt.xaHash:tt.yaHash)[t._id]?r:0}function qt(t,e){return e?(t.range=t._r.slice(),k(t,e),Ht(t,e)):0}function Ht(t,e,r){return t._length*(1-e)*g[r||t.constraintoward||"middle"]}return S.length*E.length!=1&&q(vt,function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Et(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();dt(),clearTimeout(It);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,a=Math.exp(-Math.min(Math.max(r,-20),20)/200),i=Rt.draglayer.select(".nsewdrag").node().getBoundingClientRect(),o=(e.clientX-i.left)/i.width,l=(i.bottom-e.clientY)/i.height;if(it){for(E||(o=.5),n=0;n<X.length;n++)c(X[n],o,a);Bt("x"),zt[2]*=a,zt[0]+=zt[2]*o*(1/a-1)}if(ot){for(S||(l=.5),n=0;n<Z.length;n++)c(Z[n],l,a);Bt("y"),zt[3]*=a,zt[1]+=zt[3]*(1-l)*(1/a-1)}Vt(zt),Nt(),t.emit("plotly_relayouting",ut),It=setTimeout(function(){zt=[0,0,Q,$],jt()},Dt),e.preventDefault()}else s.log("Did not find wheel motion attributes: ",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),a=n[0]+(n[1]-n[0])*e;t.range=n.map(function(e){return t.l2r(a+(e-a)*r)})}}}),vt},makeDragger:E,makeRectDragger:L,makeZoombox:I,makeCorners:D,updateZoombox:R,xyCorners:V,transitionZoombox:F,removeZoombox:B,showDoubleClickNotifier:N,attachWheelEventHandler:q}},{"../../components/color":591,"../../components/dragelement":609,"../../components/drawing":612,"../../components/fx":629,"../../constants/alignment":685,"../../lib":716,"../../lib/clear_gl_canvases":701,"../../lib/setcursor":736,"../../lib/svg_text_utils":740,"../../plot_api/subroutines":755,"../../registry":845,"../plots":825,"./axes":764,"./axis_ids":767,"./constants":770,"./scale_zoom":780,"./select":781,d3:164,"has-passive-events":412,tinycolor2:535}],773:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/fx"),i=t("../../components/dragelement"),o=t("../../lib/setcursor"),s=t("./dragbox").makeDragBox,l=t("./constants").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(".drag").remove();else if(e._has("cartesian")||e._has("splom")){Object.keys(e._plots||{}).sort(function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split("y"),a=r.split("y");return n[0]===a[0]?Number(n[1]||1)-Number(a[1]||1):Number(n[0]||1)-Number(a[0]||1)}return e._plots[t].mainplot?1:-1}).forEach(function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,"ns","ew");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&t._fullLayout._plots[r]&&a.hover(t,e,r)},a.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,i.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,"n","w"),s(t,n,o._offset+o._length,c._offset-l,l,l,"n","e"),s(t,n,o._offset-l,c._offset+c._length,l,l,"s","w"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,"s","e"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var h=o._mainLinePosition;"top"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,"","ew"),s(t,n,o._offset,h,.1*o._length,l,"","w"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,"","e")}if(r===c._mainSubplot){var f=c._mainLinePosition;"right"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,"ns",""),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,"s",""),s(t,n,f,c._offset,l,.1*c._length,"n","")}}});var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,a.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,a.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r="pan"===e.dragmode?"move":"crosshair";o(e._draggers,r)}},{"../../components/dragelement":609,"../../components/fx":629,"../../lib/setcursor":736,"./constants":770,"./dragbox":772,d3:164}],774:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib");e.exports=function(t){return function(e,r){var i=e[t];if(Array.isArray(i))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,h=l.cartesian,f=r._has("cartesian")||r._has("gl2d"),p=0;p<i.length;p++){var d=i[p];if(a.isPlainObject(d)){var g=d.xref,v=d.yref,m=s.x.test(g),y=s.y.test(v);if(m||y){f||a.pushUnique(r._basePlotModules,o);var x=!1;m&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(v)&&(u.push(v),x=!0),x&&m&&y&&h.push(g+v)}}}}}},{"../../lib":716,"../../registry":845}],775:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../lib"),o=t("../plots"),s=t("../../components/drawing"),l=t("../get_data").getModuleCalcData,c=t("./axis_ids"),u=t("./constants"),h=t("../../constants/xmlns_namespaces"),f=i.ensureSingle;function p(t,e,r){return i.ensureSingle(t,e,r,function(t){t.datum(r)})}function d(t,e,r,i,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,v=[],m=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=a.modules[x].categories;if(b.svg){var _=c.layerName||x+"layer",w=c.plot;f=(h=l(r,w))[0],r=h[1],f.length&&v.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:f}),b.zoomScale&&m.push("."+_)}}v.sort(function(t,e){return t.i-e.i});var k=e.plot.selectAll("g.mlayer").data(v,function(t){return t.className});if(k.enter().append("g").attr("class",function(t){return t.className}).classed("mlayer",!0).classed("rangeplot",e.isRangePlot),k.exit().remove(),k.order(),k.each(function(r){var a=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,a,i,o),-1===u.clipOnAxisFalseQuery.indexOf("."+l)&&s.setClipUrl(a,e.layerClipId,t)}),d._has("scattergl")&&(c=a.getModule("scattergl"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(",")).selectAll(".trace")),m.length)){var T=e.plot.selectAll(m.join(",")).selectAll(".trace");e.zoomScalePts=T.selectAll("path.point"),e.zoomScaleTxt=T.selectAll(".textpoint")}}function g(t,e){var r=e.plotgroup,n=e.id,a=u.layerValue2layerClass[e.xaxis.layer],i=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,h=n+"-x",d=n+"-y";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,f(s.overlinesBelow,"path",h),f(s.overlinesBelow,"path",d),f(s.overaxesBelow,"g",h),f(s.overaxesBelow,"g",d),e.plot=f(s.overplot,"g",n),f(s.overlinesAbove,"path",h),f(s.overlinesAbove,"path",d),f(s.overaxesAbove,"g",h),f(s.overaxesAbove,"g",d),e.xlines=l.select(".overlines-"+a).select("."+h),e.ylines=l.select(".overlines-"+i).select("."+d),e.xaxislayer=l.select(".overaxes-"+a).select("."+h),e.yaxislayer=l.select(".overaxes-"+i).select("."+d)}else if(o)e.xlines=f(r,"path","xlines-above"),e.ylines=f(r,"path","ylines-above"),e.xaxislayer=f(r,"g","xaxislayer-above"),e.yaxislayer=f(r,"g","yaxislayer-above");else{var g=f(r,"g","layer-subplot");e.shapelayer=f(g,"g","shapelayer"),e.imagelayer=f(g,"g","imagelayer"),e.gridlayer=f(r,"g","gridlayer"),e.zerolinelayer=f(r,"g","zerolinelayer"),f(r,"path","xlines-below"),f(r,"path","ylines-below"),e.overlinesBelow=f(r,"g","overlines-below"),f(r,"g","xaxislayer-below"),f(r,"g","yaxislayer-below"),e.overaxesBelow=f(r,"g","overaxes-below"),e.plot=f(r,"g","plot"),e.overplot=f(r,"g","overplot"),e.xlines=f(r,"path","xlines-above"),e.ylines=f(r,"path","ylines-above"),e.overlinesAbove=f(r,"g","overlines-above"),f(r,"g","xaxislayer-above"),f(r,"g","yaxislayer-above"),e.overaxesAbove=f(r,"g","overaxes-above"),e.xlines=r.select(".xlines-"+a),e.ylines=r.select(".ylines-"+i),e.xaxislayer=r.select(".xaxislayer-"+a),e.yaxislayer=r.select(".yaxislayer-"+i)}o||(p(e.gridlayer,"g",e.xaxis._id),p(e.gridlayer,"g",e.yaxis._id),e.gridlayer.selectAll("g").map(function(t){return t[0]}).sort(c.idSort)),e.xlines.style("fill","none").classed("crisp",!0),e.ylines.style("fill","none").classed("crisp",!0)}function v(t,e){if(t){var r={};for(var a in t.each(function(t){var a=t[0];n.select(this).remove(),m(a,e),r[a]=!0}),e._plots)for(var i=e._plots[a].overlays||[],o=0;o<i.length;o++){var s=i[o];r[s.id]&&s.plot.selectAll(".trace").remove()}}}function m(t,e){e._draggers.selectAll("g."+t).remove(),e._defs.select("#clip"+e._uid+t+"plot").remove()}r.name="cartesian",r.attr=["xaxis","yaxis"],r.idRoot=["x","y"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t("./attributes"),r.layoutAttributes=t("./layout_attributes"),r.supplyLayoutDefaults=t("./layout_defaults"),r.transitionAxes=t("./transition_axes"),r.finalizeSubplots=function(t,e){var r,n,a,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var g=f[r].split("y");p[g[0]]=1,d["y"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(a=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(a)||(a="y"),h.push(n+a),f.push(n+a),d[a]||(d[a]=1,i.pushUnique(l,a)));for(r=0;r<l.length;r++)d[a=l[r]]||(n=(t[c.id2name(a)]||{}).anchor,u.idRegex.x.test(n)||(n="x"),h.push(n+a),f.push(n+a),p[n]||(p[n]=1,i.pushUnique(s,n)));if(!f.length){for(var v in n="",a="",t){if(u.attrRegex.test(v))"x"===v.charAt(0)?(!n||+v.substr(5)<+n.substr(5))&&(n=v):(!a||+v.substr(5)<+a.substr(5))&&(a=v)}n=n?c.name2id(n):"x",a=a?c.name2id(a):"y",s.push(n),l.push(a),h.push(n+a)}},r.plot=function(t,e,r,n){var a,i=t._fullLayout,o=i._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],a=0;a<s.length;a++)e.push(a);for(a=0;a<o.length;a++){for(var l,c=o[a],u=i._plots[c],h=[],f=0;f<s.length;f++){var p=s[f],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==["tonextx","tonexty","tonext"].indexOf(g.fill)&&-1===h.indexOf(l)&&h.push(l),h.push(p)),l=p)}d(t,u,h,r,n)}},r.clean=function(t,e,r,n){var a,i,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(a=s[o]).plotgroup&&a.plotgroup.remove();var h=n._has&&n._has("gl"),f=e._has&&e._has("gl");if(h&&!f)for(o in s)(a=s[o])._scene&&a._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(i=0;i<p.length;i++){var d=p[i];e[c.id2name(d)]||n._infolayer.selectAll(".g-"+d+"title").remove()}}var g=n._has&&n._has("cartesian"),y=e._has&&e._has("cartesian");if(g&&!y)v(n._cartesianlayer.selectAll(".subplot"),n),n._defs.selectAll(".axesclip").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(i=0;i<u.cartesian.length;i++){var x=u.cartesian[i];if(!l[x]){var b="."+x+",."+x+"-x,."+x+"-y";n._cartesianlayer.selectAll(b).remove(),m(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,a,i,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],h=[];for(e=0;e<c;e++){n=l[e],a=s._plots[n],i=a.xaxis,o=a.yaxis;var f=i._mainAxis,p=o._mainAxis,d=f._id+p._id,g=s._plots[d];a.overlays=[],d!==n&&g?(a.mainplot=d,a.mainplotinfo=g,h.push(n)):(a.mainplot=void 0,a.mainPlotinfo=void 0,u.push(n))}for(e=0;e<h.length;e++)n=h[e],(a=s._plots[n]).mainplotinfo.overlays.push(a);var v=u.concat(h),m=new Array(c);for(e=0;e<c;e++){n=v[e],a=s._plots[n],i=a.xaxis,o=a.yaxis;var y=[n,i.layer,o.layer,i.overlaying||"",o.overlaying||""];for(r=0;r<a.overlays.length;r++)y.push(a.overlays[r].id);m[e]=y}return m}(t),a=e._cartesianlayer.selectAll(".subplot").data(r,String);a.enter().append("g").attr("class",function(t){return"subplot "+t[0]}),a.order(),a.exit().call(v,e),a.each(function(r){var a=r[0],i=e._plots[a];i.plotgroup=n.select(this),g(t,i),i.draglayer=f(e._draggers,"g",a)})},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(".svg-container");r.filter(function(t,e){return e===r.size()-1}).selectAll(".gl-canvas-context, .gl-canvas-focus").each(function(){var t=this.toDataURL("image/png");e.append("svg:image").attr({xmlns:h.svg,"xlink:href":t,preserveAspectRatio:"none",x:0,y:0,width:this.width,height:this.height})})},r.updateFx=t("./graph_interact").updateFx},{"../../components/drawing":612,"../../constants/xmlns_namespaces":693,"../../lib":716,"../../registry":845,"../get_data":799,"../plots":825,"./attributes":762,"./axis_ids":767,"./constants":770,"./graph_interact":773,"./layout_attributes":776,"./layout_defaults":777,"./transition_axes":786,d3:164}],776:[function(t,e,r){"use strict";var n=t("../font_attributes"),a=t("../../components/color/attributes"),i=t("../../components/drawing/attributes").dash,o=t("../../lib/extend").extendFlat,s=t("../../plot_api/plot_template").templatedArray,l=(t("../../constants/docs").FORMAT_LINK,t("../../constants/docs").DATE_FORMAT_LINK,t("./constants"));e.exports={visible:{valType:"boolean",editType:"plot"},color:{valType:"color",dflt:a.defaultLine,editType:"ticks"},title:{text:{valType:"string",editType:"ticks"},font:n({editType:"ticks"}),standoff:{valType:"number",min:0,editType:"ticks"},editType:"ticks"},type:{valType:"enumerated",values:["-","linear","log","date","category","multicategory"],dflt:"-",editType:"calc",_noTemplating:!0},autorange:{valType:"enumerated",values:[!0,!1,"reversed"],dflt:!0,editType:"axrange",impliedEdits:{"range[0]":void 0,"range[1]":void 0}},rangemode:{valType:"enumerated",values:["normal","tozero","nonnegative"],dflt:"normal",editType:"plot"},range:{valType:"info_array",items:[{valType:"any",editType:"axrange",impliedEdits:{"^autorange":!1},anim:!0},{valType:"any",editType:"axrange",impliedEdits:{"^autorange":!1},anim:!0}],editType:"axrange",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:"boolean",dflt:!1,editType:"calc"},scaleanchor:{valType:"enumerated",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:"plot"},scaleratio:{valType:"number",min:0,dflt:1,editType:"plot"},constrain:{valType:"enumerated",values:["range","domain"],dflt:"range",editType:"plot"},constraintoward:{valType:"enumerated",values:["left","center","right","top","middle","bottom"],editType:"plot"},matches:{valType:"enumerated",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:"calc"},tickmode:{valType:"enumerated",values:["auto","linear","array"],editType:"ticks",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:"integer",min:0,dflt:0,editType:"ticks"},tick0:{valType:"any",editType:"ticks",impliedEdits:{tickmode:"linear"}},dtick:{valType:"any",editType:"ticks",impliedEdits:{tickmode:"linear"}},tickvals:{valType:"data_array",editType:"ticks"},ticktext:{valType:"data_array",editType:"ticks"},ticks:{valType:"enumerated",values:["outside","inside",""],editType:"ticks"},tickson:{valType:"enumerated",values:["labels","boundaries"],dflt:"labels",editType:"ticks"},mirror:{valType:"enumerated",values:[!0,"ticks",!1,"all","allticks"],dflt:!1,editType:"ticks+layoutstyle"},ticklen:{valType:"number",min:0,dflt:5,editType:"ticks"},tickwidth:{valType:"number",min:0,dflt:1,editType:"ticks"},tickcolor:{valType:"color",dflt:a.defaultLine,editType:"ticks"},showticklabels:{valType:"boolean",dflt:!0,editType:"ticks"},automargin:{valType:"boolean",dflt:!1,editType:"ticks"},showspikes:{valType:"boolean",dflt:!1,editType:"modebar"},spikecolor:{valType:"color",dflt:null,editType:"none"},spikethickness:{valType:"number",dflt:3,editType:"none"},spikedash:o({},i,{dflt:"dash",editType:"none"}),spikemode:{valType:"flaglist",flags:["toaxis","across","marker"],dflt:"toaxis",editType:"none"},spikesnap:{valType:"enumerated",values:["data","cursor"],dflt:"data",editType:"none"},tickfont:n({editType:"ticks"}),tickangle:{valType:"angle",dflt:"auto",editType:"ticks"},tickprefix:{valType:"string",dflt:"",editType:"ticks"},showtickprefix:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"ticks"},ticksuffix:{valType:"string",dflt:"",editType:"ticks"},showticksuffix:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"ticks"},showexponent:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"ticks"},exponentformat:{valType:"enumerated",values:["none","e","E","power","SI","B"],dflt:"B",editType:"ticks"},separatethousands:{valType:"boolean",dflt:!1,editType:"ticks"},tickformat:{valType:"string",dflt:"",editType:"ticks"},tickformatstops:s("tickformatstop",{enabled:{valType:"boolean",dflt:!0,editType:"ticks"},dtickrange:{valType:"info_array",items:[{valType:"any",editType:"ticks"},{valType:"any",editType:"ticks"}],editType:"ticks"},value:{valType:"string",dflt:"",editType:"ticks"},editType:"ticks"}),hoverformat:{valType:"string",dflt:"",editType:"none"},showline:{valType:"boolean",dflt:!1,editType:"ticks+layoutstyle"},linecolor:{valType:"color",dflt:a.defaultLine,editType:"layoutstyle"},linewidth:{valType:"number",min:0,dflt:1,editType:"ticks+layoutstyle"},showgrid:{valType:"boolean",editType:"ticks"},gridcolor:{valType:"color",dflt:a.lightLine,editType:"ticks"},gridwidth:{valType:"number",min:0,dflt:1,editType:"ticks"},zeroline:{valType:"boolean",editType:"ticks"},zerolinecolor:{valType:"color",dflt:a.defaultLine,editType:"ticks"},zerolinewidth:{valType:"number",dflt:1,editType:"ticks"},showdividers:{valType:"boolean",dflt:!0,editType:"ticks"},dividercolor:{valType:"color",dflt:a.defaultLine,editType:"ticks"},dividerwidth:{valType:"number",dflt:1,editType:"ticks"},anchor:{valType:"enumerated",values:["free",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:"plot"},side:{valType:"enumerated",values:["top","bottom","left","right"],editType:"plot"},overlaying:{valType:"enumerated",values:["free",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:"plot"},layer:{valType:"enumerated",values:["above traces","below traces"],dflt:"above traces",editType:"plot"},domain:{valType:"info_array",items:[{valType:"number",min:0,max:1,editType:"plot"},{valType:"number",min:0,max:1,editType:"plot"}],dflt:[0,1],editType:"plot"},position:{valType:"number",min:0,max:1,dflt:0,editType:"plot"},categoryorder:{valType:"enumerated",values:["trace","category ascending","category descending","array","total ascending","total descending","min ascending","min descending","max ascending","max descending","sum ascending","sum descending","mean ascending","mean descending","median ascending","median descending"],dflt:"trace",editType:"calc"},categoryarray:{valType:"data_array",editType:"calc"},uirevision:{valType:"any",editType:"none"},editType:"calc",_deprecated:{autotick:{valType:"boolean",editType:"ticks"},title:{valType:"string",editType:"ticks"},titlefont:n({editType:"ticks"})}}},{"../../components/color/attributes":590,"../../components/drawing/attributes":611,"../../constants/docs":687,"../../lib/extend":707,"../../plot_api/plot_template":754,"../font_attributes":790,"./constants":770}],777:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../../plot_api/plot_template"),o=t("../layout_attributes"),s=t("./layout_attributes"),l=t("./type_defaults"),c=t("./axis_defaults"),u=t("./constraints").handleConstraintDefaults,h=t("./position_defaults"),f=t("./axis_ids"),p=f.id2name,d=f.name2id,g=t("../../registry"),v=g.traceIs,m=g.getComponentMethod;function y(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var f,g,x={},b={},_={},w={},k={},T={},A={},M={},S={},E={};for(f=0;f<r.length;f++){var L=r[f];if(v(L,"cartesian")||v(L,"gl2d")){var C,P;if(L.xaxis)y(x,C=p(L.xaxis),L);else if(L.xaxes)for(g=0;g<L.xaxes.length;g++)y(x,p(L.xaxes[g]),L);if(L.yaxis)y(x,P=p(L.yaxis),L);else if(L.yaxes)for(g=0;g<L.yaxes.length;g++)y(x,p(L.yaxes[g]),L);if("funnel"===L.type?"h"===L.orientation?(C&&(b[C]=!0),P&&(A[P]=!0)):P&&(_[P]=!0):"image"===L.type?(P&&(M[P]=!0),C&&(M[C]=!0)):(P&&(k[P]=!0,T[P]=!0),v(L,"carpet")&&("carpet"!==L.type||L._cheater)||C&&(w[C]=!0)),"carpet"===L.type&&L._cheater&&C&&(b[C]=!0),v(L,"2dMap")&&(S[C]=!0,S[P]=!0),v(L,"oriented"))E["h"===L.orientation?P:C]=!0}}var O=e._subplots,z=O.xaxis,I=O.yaxis,D=n.simpleMap(z,p),R=n.simpleMap(I,p),F=D.concat(R),B=a.background;z.length&&I.length&&(B=n.coerce(t,e,o,"plot_bgcolor"));var N,j,V,U,q=a.combine(B,e.paper_bgcolor);function H(t,e){return n.coerce(V,U,s,t,e)}function G(t,e){return n.coerce2(V,U,s,t,e)}function Y(t){return"x"===t?I:z}var W={x:Y("x"),y:Y("y")},X=W.x.concat(W.y);function Z(e,r){for(var n="x"===e?D:R,a=[],i=0;i<n.length;i++){var o=n[i];o===r||(t[o]||{}).overlaying||a.push(d(o))}return a}for(f=0;f<F.length;f++){j=(N=F[f]).charAt(0),n.isPlainObject(t[N])||(t[N]={}),V=t[N],U=i.newContainer(e,N,j+"axis");var J=x[N]||[];U._traceIndices=J.map(function(t){return t._expandedIndex}),U._annIndices=[],U._shapeIndices=[],U._imgIndices=[],U._subplotsWith=[],U._counterAxes=[],U._name=U._attr=N;var K=U._id=d(N),Q=Z(j,N),$="x"===j&&!w[N]&&b[N]||"y"===j&&!k[N]&&_[N],tt="y"===j&&(!T[N]&&A[N]||M[N]),et={letter:j,font:e.font,outerTicks:S[N],showGrid:!E[N],data:J,bgColor:q,calendar:e.calendar,automargin:!0,visibleDflt:$,reverseDflt:tt,splomStash:((e._splomAxes||{})[j]||{})[K]};H("uirevision",e.uirevision),l(V,U,H,et),c(V,U,H,et,e);var rt=G("spikecolor"),nt=G("spikethickness"),at=G("spikedash"),it=G("spikemode"),ot=G("spikesnap");H("showspikes",!!(rt||nt||at||it||ot))||(delete U.spikecolor,delete U.spikethickness,delete U.spikedash,delete U.spikemode,delete U.spikesnap),h(V,U,H,{letter:j,counterAxes:W[j],overlayableAxes:Q,grid:e.grid}),H("title.standoff"),U._input=V}var st=m("rangeslider","handleDefaults"),lt=m("rangeselector","handleDefaults");for(f=0;f<D.length;f++)N=D[f],V=t[N],U=e[N],st(t,e,N),"date"===U.type&&lt(V,U,e,R,U.calendar),H("fixedrange");for(f=0;f<R.length;f++){N=R[f],V=t[N],U=e[N];var ct=e[p(U.anchor)];H("fixedrange",m("rangeslider","isVisible")(ct))}var ut=e._axisConstraintGroups=[],ht=e._axisMatchGroups=[];for(f=0;f<F.length;f++){var ft,pt;j=(N=F[f]).charAt(0),V=t[N],U=e[N],ft="y"===j&&!V.hasOwnProperty("scaleanchor")&&M[N]?U.anchor:void 0,pt=!V.hasOwnProperty("constrain")&&M[N]?"domain":void 0,u(V,U,H,{allAxisIds:X,layoutOut:e,scaleanchorDflt:ft,constrainDflt:pt})}for(f=0;f<ht.length;f++){var dt,gt=ht[f],vt=null,mt=null;for(dt in gt)(U=e[p(dt)]).matches||(vt=U.range,mt=U.autorange);if(null===vt||null===mt)for(dt in gt){vt=(U=e[p(dt)]).range,mt=U.autorange;break}for(dt in gt)(U=e[p(dt)]).matches&&(U.range=vt.slice(),U.autorange=mt),U._matchGroup=gt;if(ut.length)for(dt in gt)for(g=0;g<ut.length;g++){var yt=ut[g];for(var xt in yt)dt===xt&&(n.warn("Axis "+xt+" is set with both a *scaleanchor* and *matches* constraint; ignoring the scale constraint."),delete yt[xt],Object.keys(yt).length<2&&ut.splice(g,1))}}}},{"../../components/color":591,"../../lib":716,"../../plot_api/plot_template":754,"../../registry":845,"../layout_attributes":816,"./axis_defaults":766,"./axis_ids":767,"./constraints":771,"./layout_attributes":776,"./position_defaults":779,"./type_defaults":787}],778:[function(t,e,r){"use strict";var n=t("tinycolor2").mix,a=t("../../components/color/attributes").lightFraction,i=t("../../lib");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return i.coerce2(t,e,o.attributes,r,n)}var c=l("linecolor",s),u=l("linewidth");r("showline",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l("gridcolor",n(s,o.bgColor,o.blend||a).toRgbString()),f=l("gridwidth");if(r("showgrid",o.showGrid||!!h||!!f)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l("zerolinecolor",s),d=l("zerolinewidth");r("zeroline",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{"../../components/color/attributes":590,"../../lib":716,tinycolor2:535}],779:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib");e.exports=function(t,e,r,i){var o,s,l,c,u=i.counterAxes||[],h=i.overlayableAxes||[],f=i.letter,p=i.grid;p&&(s=p._domains[f][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[f+"side"].split(" ")[0],c=p.domain[f]["right"===l||"top"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?"free":u[0]||"free"),l=l||("x"===f?"bottom":"left"),c=c||0,"free"===a.coerce(t,e,{anchor:{valType:"enumerated",values:["free"].concat(u),dflt:o}},"anchor")&&r("position",c),a.coerce(t,e,{side:{valType:"enumerated",values:"x"===f?["bottom","top"]:["left","right"],dflt:l}},"side");var d=!1;if(h.length&&(d=a.coerce(t,e,{overlaying:{valType:"enumerated",values:[!1].concat(h),dflt:!1}},"overlaying")),!d){var g=r("domain",s);g[0]>g[1]-1/4096&&(e.domain=s),a.noneOrAll(t.domain,e.domain,s)}return r("layer"),e}},{"../../lib":716,"fast-isnumeric":227}],780:[function(t,e,r){"use strict";var n=t("../../constants/alignment").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||"center"]);var a=[t.r2l(t.range[0]),t.r2l(t.range[1])],i=a[0]+(a[1]-a[0])*r;t.range=t._input.range=[t.l2r(i+(a[0]-i)*e),t.l2r(i+(a[1]-i)*e)]}},{"../../constants/alignment":685}],781:[function(t,e,r){"use strict";var n=t("polybooljs"),a=t("../../registry"),i=t("../../components/color"),o=t("../../components/fx"),s=t("../../lib"),l=t("../../lib/polygon"),c=t("../../lib/throttle"),u=t("../../components/fx/helpers").makeEventData,h=t("./axis_ids").getFromId,f=t("../../lib/clear_gl_canvases"),p=t("../../plot_api/subroutines").redrawReglTraces,d=t("./constants"),g=d.MINSELECT,v=l.filter,m=l.tester;function y(t){return t._id}function x(t,e,r,n,a,i,o){var s,l,c,u,h,f,p,d,g,v=e._hoverdata,m=e._fullLayout.clickmode.indexOf("event")>-1,y=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(v)){k(t,e,i);var x=function(t,e){var r,n,a=t[0],i=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],a.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===a.hoverOnBox)break;void 0!==a.pointNumber?i=a.pointNumber:void 0!==a.binNumber&&(i=a.binNumber,o=a.pointNumbers);break}return{pointNumber:i,pointNumbers:o,searchInfo:r}}(v,s=A(e,r,n,a));if(x.pointNumbers.length>0?function(t,e){var r,n,a,i=[];for(a=0;a<t.length;a++)(r=t[a]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&i.push(r);if(1===i.length&&i[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(a=0;a<e.pointNumbers.length;a++)if(n.selectedpoints.indexOf(e.pointNumbers[a])<0)return!1;return!0}return!1}(s,x):function(t){var e,r,n,a=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((a+=r.selectedpoints.length)>1)return!1}return 1===a}(s)&&(f=S(x))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);E(e,s),T(i),m&&e.emit("plotly_deselect",null)}else{for(p=t.shiftKey&&(void 0!==f?f:S(x)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(x.pointNumber,x.searchInfo,p),u=w(i.selectionDefs.concat([c])),g=0;g<s.length;g++)if(h=L(s[g]._module.selectPoints(s[g],u),s[g]),y.length)for(var b=0;b<h.length;b++)y.push(h[b]);else y=h;E(e,s,d={points:y}),c&&i&&i.selectionDefs.push(c),o&&M(i.mergedPolygons,o),m&&e.emit("plotly_selected",d)}}}function b(t){return"pointNumber"in t&&"searchInfo"in t}function _(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,a){var i=t.searchInfo.cd[0].trace._expandedIndex;return a.cd[0].trace._expandedIndex===i&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function w(t){for(var e=[],r=b(t[0])?0:t[0][0][0],n=r,a=b(t[0])?0:t[0][0][1],i=a,o=0;o<t.length;o++)if(b(t[o]))e.push(_(t[o]));else{var s=l.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),a=Math.min(a,s.ymin),i=Math.max(i,s.ymax)}return{xmin:r,xmax:n,ymin:a,ymax:i,pts:[],contains:function(t,r,n,a){for(var i=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,a)&&(i=!1===e[o].subtract);return i},isRect:!1,degenerate:!1}}function k(t,e,r){var n=e._fullLayout,a=r.plotinfo,i=n._lastSelectedSubplot&&n._lastSelectedSubplot===a.id,o=t.shiftKey||t.altKey;i&&o&&a.selection&&a.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=a.selection.selectionDefs,r.mergedPolygons=a.selection.mergedPolygons):o&&a.selection||T(r),i||(C(e),n._lastSelectedSubplot=a.id)}function T(t){var e=t.plotinfo;e.selection={},e.selection.selectionDefs=t.selectionDefs=[],e.selection.mergedPolygons=t.mergedPolygons=[]}function A(t,e,r,n){var a,i,o,s=[],l=e.map(y),c=r.map(y);for(o=0;o<t.calcdata.length;o++)if(!0===(i=(a=t.calcdata[o])[0].trace).visible&&i._module&&i._module.selectPoints)if(!n||i.subplot!==n&&i.geo!==n)if("splom"===i.type&&i._xaxes[l[0]]&&i._yaxes[c[0]]){var u=p(i._module,a,e[0],r[0]);u.scene=t._fullLayout._splomScenes[i.uid],s.push(u)}else if("sankey"===i.type){var f=p(i._module,a,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(i.xaxis))continue;if(-1===c.indexOf(i.yaxis))continue;s.push(p(i._module,a,h(t,i.xaxis),h(t,i.yaxis)))}else s.push(p(i._module,a,e[0],r[0]));return s;function p(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function M(t,e){var r,n,a=[];for(r=0;r<t.length;r++){var i=t[r];a.push(i.join("L")+"L"+i[0])}n=t.length>0?"M"+a.join("M")+"Z":"M0,0Z",e.attr("d",n)}function S(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,a=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(a)>-1}function E(t,e,r){var n,i,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var h=u[n],d=h.data,g=h.fullData;h.pointIndices?([].push.apply(d.selectedpoints,h.pointIndices),s._fullInput!==s&&[].push.apply(g.selectedpoints,h.pointIndices)):(d.selectedpoints.push(h.pointIndex),s._fullInput!==s&&g.selectedpoints.push(h.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var v=!1;for(n=0;n<e.length;n++){s=(o=(i=e[n]).cd)[0].trace,a.traceIs(s,"regl")&&(v=!0);var m=i._module,y=m.styleOnSelect||m.style;y&&(y(t,o,o[0].node3),o[0].nodeRangePlot3&&y(t,o,o[0].nodeRangePlot3))}v&&(f(t),p(t))}function L(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,a=0;a<t.length;a++)t[a]=u(t[a],n,r);return t}function C(t){var e=(t._fullLayout||{})._zoomlayer;e&&e.selectAll(".select-outline").remove()}e.exports={prepSelect:function(t,e,r,a,l){var u,h,f,p,y,b,_,S=a.gd,C=S._fullLayout,P=C._zoomlayer,O=a.element.getBoundingClientRect(),z=a.plotinfo,I=z.xaxis._offset,D=z.yaxis._offset,R=e-O.left,F=r-O.top,B=R,N=F,j="M"+R+","+F,V=a.xaxes[0]._length,U=a.yaxes[0]._length,q=a.xaxes.concat(a.yaxes),H=t.altKey;k(t,S,a),"lasso"===l&&(u=v([[R,F]],d.BENDPX));var G=P.selectAll("path.select-outline-"+z.id).data([1,2]);G.enter().append("path").attr("class",function(t){return"select-outline select-outline-"+t+" select-outline-"+z.id}).attr("transform","translate("+I+", "+D+")").attr("d",j+"Z");var Y,W=P.append("path").attr("class","zoombox-corners").style({fill:i.background,stroke:i.defaultLine,"stroke-width":1}).attr("transform","translate("+I+", "+D+")").attr("d","M0,0Z"),X=C._uid+d.SELECTID,Z=[],J=A(S,a.xaxes,a.yaxes,a.subplot);function K(t,e){return"log"===t.type?t.p2d(e):t.p2r(e)}function Q(t){var e="y"===t._id.charAt(0)?1:0;return function(r){return K(t,r[e])}}function $(t,e){return t-e}Y=z.fillRangeItems?z.fillRangeItems:"select"===l?function(t,e){var r=t.range={};for(y=0;y<q.length;y++){var n=q[y],a=n._id.charAt(0);r[n._id]=[K(n,e[a+"min"]),K(n,e[a+"max"])].sort($)}}:function(t,e,r){var n=t.lassoPoints={};for(y=0;y<q.length;y++){var a=q[y];n[a._id]=r.filtered.map(Q(a))}},a.moveFn=function(t,e){B=Math.max(0,Math.min(V,t+R)),N=Math.max(0,Math.min(U,e+F));var r=Math.abs(B-R),i=Math.abs(N-F);if("select"===l){var o=C.selectdirection;"h"===(o="any"===C.selectdirection?i<Math.min(.6*r,g)?"h":r<Math.min(.6*i,g)?"v":"d":C.selectdirection)?((p=[[R,0],[R,U],[B,U],[B,0]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(0,U),p.ymax=Math.max(0,U),W.attr("d","M"+p.xmin+","+(F-g)+"h-4v"+2*g+"h4ZM"+(p.xmax-1)+","+(F-g)+"h4v"+2*g+"h-4Z")):"v"===o?((p=[[0,F],[0,N],[V,N],[V,F]]).xmin=Math.min(0,V),p.xmax=Math.max(0,V),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr("d","M"+(R-g)+","+p.ymin+"v-4h"+2*g+"v4ZM"+(R-g)+","+(p.ymax-1)+"v4h"+2*g+"v-4Z")):"d"===o&&((p=[[R,F],[R,N],[B,N],[B,F]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr("d","M0,0Z"))}else"lasso"===l&&(u.addPt([B,N]),p=u.filtered);a.selectionDefs&&a.selectionDefs.length?(f=function(t,e,r){return r?n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions:n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(a.mergedPolygons,p,H),p.subtract=H,h=w(a.selectionDefs.concat([p]))):(f=[p],h=m(p)),M(f,G),c.throttle(X,d.SELECTDELAY,function(){var t;Z=[];var e,r=[];for(y=0;y<J.length;y++)if(e=(b=J[y])._module.selectPoints(b,h),r.push(e),t=L(e,b),Z.length)for(var n=0;n<t.length;n++)Z.push(t[n]);else Z=t;E(S,J,_={points:Z}),Y(_,p,u),a.gd.emit("plotly_selecting",_)})},a.clickFn=function(t,e){var r=C.clickmode;W.remove(),c.done(X).then(function(){if(c.clear(X),2===t){for(G.remove(),y=0;y<J.length;y++)(b=J[y])._module.selectPoints(b,!1);E(S,J),T(a),S.emit("plotly_deselect",null)}else r.indexOf("select")>-1&&x(e,S,a.xaxes,a.yaxes,a.subplot,a,G),"event"===r&&S.emit("plotly_selected",void 0);o.click(S,e)}).catch(s.error)},a.doneFn=function(){W.remove(),c.done(X).then(function(){c.clear(X),a.gd.emit("plotly_selected",_),p&&a.selectionDefs&&(p.subtract=H,a.selectionDefs.push(p),a.mergedPolygons.length=0,[].push.apply(a.mergedPolygons,f)),a.doneFnCompleted&&a.doneFnCompleted(Z)}).catch(s.error)}},clearSelect:C,selectOnClick:x}},{"../../components/color":591,"../../components/fx":629,"../../components/fx/helpers":626,"../../lib":716,"../../lib/clear_gl_canvases":701,"../../lib/polygon":728,"../../lib/throttle":741,"../../plot_api/subroutines":755,"../../registry":845,"./axis_ids":767,"./constants":770,polybooljs:474}],782:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../lib"),o=i.cleanNumber,s=i.ms2DateTime,l=i.dateTime2ms,c=i.ensureNumber,u=i.isArrayOrTypedArray,h=t("../../constants/numerical"),f=h.FP_SAFE,p=h.BADNUM,d=h.LOG_CLIP,g=t("./constants"),v=t("./axis_ids");function m(t){return Math.pow(10,t)}function y(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||"x",h=r.charAt(0);function x(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],a=t.range[1];return.5*(n+a-2*d*Math.abs(n-a))}return p}function b(e,r,n){var o=l(e,n||t.calendar);if(o===p){if(!a(e))return p;e=+e;var s=Math.floor(10*i.mod(e+.05,1)),c=Math.round(e-s/10);o=l(new Date(c))+s/10}return o}function _(e,r,n){return s(e,r,n||t.calendar)}function w(e){return t._categories[Math.round(e)]}function k(e){if(y(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push("number"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return p}function T(e){if(t._categoriesMap)return t._categoriesMap[e]}function A(t){var e=T(t);return void 0!==e?e:a(t)?+t:void 0}function M(e){return a(e)?n.round(t._b+t._m*e,2):p}function S(e){return(e-t._b)/t._m}t.c2l="log"===t.type?x:c,t.l2c="log"===t.type?m:c,t.l2p=M,t.p2l=S,t.c2p="log"===t.type?function(t,e){return M(x(t,e))}:M,t.p2c="log"===t.type?function(t){return m(S(t))}:S,-1!==["linear","-"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=o,t.c2d=t.c2r=t.l2d=t.l2r=c,t.d2p=t.r2p=function(e){return t.l2p(o(e))},t.p2d=t.p2r=S,t.cleanPos=c):"log"===t.type?(t.d2r=t.d2l=function(t,e){return x(o(t),e)},t.r2d=t.r2c=function(t){return m(o(t))},t.d2c=t.r2l=o,t.c2d=t.l2r=c,t.c2r=x,t.l2d=m,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return m(S(t))},t.r2p=function(e){return t.l2p(o(e))},t.p2r=S,t.cleanPos=c):"date"===t.type?(t.d2r=t.r2d=i.identity,t.d2c=t.r2c=t.d2l=t.r2l=b,t.c2d=t.c2r=t.l2d=t.l2r=_,t.d2p=t.r2p=function(e,r,n){return t.l2p(b(e,0,n))},t.p2d=t.p2r=function(t,e,r){return _(S(t),e,r)},t.cleanPos=function(e){return i.cleanDate(e,p,t.calendar)}):"category"===t.type?(t.d2c=t.d2l=k,t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return"string"==typeof t&&""!==t?t:c(t)}):"multicategory"===t.type&&(t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=T,t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return Array.isArray(t)||"string"==typeof t&&""!==t?t:c(t)},t.setupMultiCategory=function(n){var a,o,s=t._traceIndices,l=e._axisMatchGroups;if(l&&l.length&&0===t._categories.length)for(a=0;a<l.length;a++){var c=l[a];if(c[r])for(var f in c)if(f!==r){var p=e[v.id2name(f)];s=s.concat(p._traceIndices)}}var d=[[0,{}],[0,{}]],g=[];for(a=0;a<s.length;a++){var m=n[s[a]];if(h in m){var x=m[h],b=m._length||i.minRowLength(x);if(u(x[0])&&u(x[1]))for(o=0;o<b;o++){var _=x[0][o],w=x[1][o];y(_)&&y(w)&&(g.push([_,w]),_ in d[0][1]||(d[0][1][_]=d[0][0]++),w in d[1][1]||(d[1][1][w]=d[1][0]++))}}}for(g.sort(function(t,e){var r=d[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var a=d[1][1];return a[t[1]]-a[e[1]]}),a=0;a<g.length;a++)k(g[a])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e="range");var n,o,s=i.nestedProperty(t,e).get();if(o=(o="date"===t.type?i.dfltRange(t.calendar):"y"===h?g.DFLTRANGEY:r.dfltRange||g.DFLTRANGEX).slice(),"tozero"!==t.rangemode&&"nonnegative"!==t.rangemode||(o[0]=0),s&&2===s.length)for("date"!==t.type||t.autorange||(s[0]=i.cleanDate(s[0],p,t.calendar),s[1]=i.cleanDate(s[1],p,t.calendar)),n=0;n<2;n++)if("date"===t.type){if(!i.isDateTime(s[n],t.calendar)){t[e]=o;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=i.constrain(t.r2l(s[0]),i.MIN_MS+1e3,i.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!a(s[n])){if(!a(s[1-n])){t[e]=o;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-f?s[n]=-f:s[n]>f&&(s[n]=f),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else i.nestedProperty(t,e).set(o)},t.setScale=function(r){var n=e._size;if(t.overlaying){var a=v.getFromId({_fullLayout:e},t.overlaying);t.domain=a.domain}var i=r&&t._r?"_r":"range",o=t.calendar;t.cleanRange(i);var s=t.r2l(t[i][0],o),l=t.r2l(t[i][1],o);if("y"===h?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(s-l),t._b=-t._m*l):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(l-s),t._b=-t._m*s),!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error("Something went wrong with axis scaling")},t.makeCalcdata=function(e,r){var n,a,o,s,l=t.type,c="date"===l&&e[r+"calendar"];if(r in e){if(n=e[r],s=e._length||i.minRowLength(n),i.isTypedArray(n)&&("linear"===l||"log"===l)){if(s===n.length)return n;if(n.subarray)return n.subarray(0,s)}if("multicategory"===l)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var a=(t[0]||[])[n],i=(t[1]||[])[n];r[n]=T([a,i])}return r}(n,s);for(a=new Array(s),o=0;o<s;o++)a[o]=t.d2c(n[o],0,c)}else{var u=r+"0"in e?t.d2c(e[r+"0"],0,c):0,h=e["d"+r]?Number(e["d"+r]):1;for(n=e[{x:"y",y:"x"}[r]],s=e._length||n.length,a=new Array(s),o=0;o<s;o++)a[o]=u+o*h}return a},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&a(t.r2l(e[0]))&&a(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),a=t.r2l(t.range[0]),i=t.r2l(t.range[1]);return a<i?a<=n&&n<=i:i<=n&&n<=a},t.clearCalc=function(){var n=function(){t._categories=[],t._categoriesMap={}},a=e._axisMatchGroups;if(a&&a.length){for(var i=!1,o=0;o<a.length;o++){var s=a[o];if(s[r]){i=!0;var l=null,c=null;for(var u in s){var h=e[v.id2name(u)];if(h._categories){l=h._categories,c=h._categoriesMap;break}}l&&c?(t._categories=l,t._categoriesMap=c):n();break}}i||n()}else n();if(t._initialCategories)for(var f=0;f<t._initialCategories.length;f++)k(t._initialCategories[f])},t.sortByInitialCategories=function(){var n=[];if(t._categories=[],t._categoriesMap={},t._initialCategories)for(var a=0;a<t._initialCategories.length;a++)k(t._initialCategories[a]);n=n.concat(t._traceIndices);var i=t._matchGroup;for(var o in i)if(r!==o){var s=e[v.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var E=e._d3locale;"date"===t.type&&(t._dateFormat=E?E.timeFormat.utc:n.time.format.utc,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=E?E.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{"../../constants/numerical":692,"../../lib":716,"./axis_ids":767,"./constants":770,d3:164,"fast-isnumeric":227}],783:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes"),i=t("../array_container_defaults");function o(t){var e=["showexponent","showtickprefix","showticksuffix"].filter(function(e){return void 0!==t[e]});if(e.every(function(r){return t[r]===t[e[0]]})||1===e.length)return t[e[0]]}function s(t,e){function r(r,i){return n.coerce(t,e,a.tickformatstops,r,i)}r("enabled")&&(r("dtickrange"),r("value"))}e.exports=function(t,e,r,l,c,u){u&&1!==u.pass||function(t,e,r,n,a){var i=o(t);r("tickprefix")&&r("showtickprefix",i);r("ticksuffix",a.tickSuffixDflt)&&r("showticksuffix",i)}(t,0,r,0,c),u&&2!==u.pass||function(t,e,r,l,c){var u=o(t);r("tickprefix")&&r("showtickprefix",u);r("ticksuffix",c.tickSuffixDflt)&&r("showticksuffix",u);if(r("showticklabels")){var h=c.font||{},f=e.color,p=f&&f!==a.color.dflt?f:h.color;if(n.coerceFont(r,"tickfont",{family:h.family,size:h.size,color:p}),r("tickangle"),"category"!==l){var d=r("tickformat"),g=t.tickformatstops;Array.isArray(g)&&g.length&&i(t,e,{name:"tickformatstops",inclusionAttr:"enabled",handleItemDefaults:s}),d||"date"===l||(r("showexponent",u),r("exponentformat"),r("separatethousands"))}}}(t,e,r,l,c)}},{"../../lib":716,"../array_container_defaults":760,"./layout_attributes":776}],784:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e,r,i){var o=n.coerce2(t,e,a,"ticklen"),s=n.coerce2(t,e,a,"tickwidth"),l=n.coerce2(t,e,a,"tickcolor",e.color);r("ticks",i.outerTicks||o||s||l?"outside":"")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{"../../lib":716,"./layout_attributes":776}],785:[function(t,e,r){"use strict";var n=t("./clean_ticks");e.exports=function(t,e,r,a){var i;"array"!==t.tickmode||"log"!==a&&"date"!==a?i=r("tickmode",Array.isArray(t.tickvals)?"array":t.dtick?"linear":"auto"):i=e.tickmode="auto";if("auto"===i)r("nticks");else if("linear"===i){var o=e.dtick=n.dtick(t.dtick,a);e.tick0=n.tick0(t.tick0,a,e.calendar,o)}else if("multicategory"!==a){void 0===r("tickvals")?e.tickmode="auto":r("ticktext")}}},{"./clean_ticks":769}],786:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../lib"),o=t("../../components/drawing"),s=t("./axes");e.exports=function(t,e,r,l){var c=t._fullLayout;if(0!==e.length){var u,h,f,p;l&&(u=l());var d=n.ease(r.easing);return t._transitionData._interruptCallbacks.push(function(){return window.cancelAnimationFrame(p),p=null,function(){for(var r={},n=0;n<e.length;n++){var i=e[n],o=i.plotinfo.xaxis,s=i.plotinfo.yaxis;i.xr0&&(r[o._name+".range"]=i.xr0.slice()),i.yr0&&(r[s._name+".range"]=i.yr0.slice())}return a.call("relayout",t,r).then(function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)})}()}),h=Date.now(),p=window.requestAnimationFrame(function n(){f=Date.now();for(var i=Math.min(1,(f-h)/r.duration),o=d(i),s=0;s<e.length;s++)v(e[s],o);f-h>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var i=e[n],o=i.plotinfo.xaxis,s=i.plotinfo.yaxis;i.xr1&&(r[o._name+".range"]=i.xr1.slice()),i.yr1&&(r[s._name+".range"]=i.yr1.slice())}u&&u(),a.call("relayout",t,r).then(function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)})}(),p=window.cancelAnimationFrame(n)):p=window.requestAnimationFrame(n)}),Promise.resolve()}function g(t){var e=t.xaxis,r=t.yaxis;c._defs.select("#"+t.clipId+"> rect").call(o.setTranslate,0,0).call(o.setScale,1,1),t.plot.call(o.setTranslate,e._offset,r._offset).call(o.setScale,1,1);var n=t.plot.selectAll(".scatterlayer .trace");n.selectAll(".point").call(o.setPointGroupScale,1,1),n.selectAll(".textpoint").call(o.setTextPointsScale,1,1),n.call(o.hideOutsideRangePoints,t)}function v(e,r){var n=e.plotinfo,a=n.xaxis,l=n.yaxis,c=a._length,u=l._length,h=!!e.xr1,f=!!e.yr1,p=[];if(h){var d=i.simpleMap(e.xr0,a.r2l),g=i.simpleMap(e.xr1,a.r2l),v=d[1]-d[0],m=g[1]-g[0];p[0]=(d[0]*(1-r)+r*g[0]-d[0])/(d[1]-d[0])*c,p[2]=c*(1-r+r*m/v),a.range[0]=a.l2r(d[0]*(1-r)+r*g[0]),a.range[1]=a.l2r(d[1]*(1-r)+r*g[1])}else p[0]=0,p[2]=c;if(f){var y=i.simpleMap(e.yr0,l.r2l),x=i.simpleMap(e.yr1,l.r2l),b=y[1]-y[0],_=x[1]-x[0];p[1]=(y[1]*(1-r)+r*x[1]-y[1])/(y[0]-y[1])*u,p[3]=u*(1-r+r*_/b),l.range[0]=a.l2r(y[0]*(1-r)+r*x[0]),l.range[1]=l.l2r(y[1]*(1-r)+r*x[1])}else p[1]=0,p[3]=u;s.drawOne(t,a,{skipTitle:!0}),s.drawOne(t,l,{skipTitle:!0}),s.redrawComponents(t,[a._id,l._id]);var w=h?c/p[2]:1,k=f?u/p[3]:1,T=h?p[0]:0,A=f?p[1]:0,M=h?p[0]/p[2]*c:0,S=f?p[1]/p[3]*u:0,E=a._offset-M,L=l._offset-S;n.clipRect.call(o.setTranslate,T,A).call(o.setScale,1/w,1/k),n.plot.call(o.setTranslate,E,L).call(o.setScale,w,k),o.setPointGroupScale(n.zoomScalePts,1/w,1/k),o.setTextPointsScale(n.zoomScaleTxt,1/w,1/k)}s.redrawComponents(t)}},{"../../components/drawing":612,"../../lib":716,"../../registry":845,"./axes":764,d3:164}],787:[function(t,e,r){"use strict";var n=t("../../registry").traceIs,a=t("./axis_autotype");function i(t){return{v:"x",h:"y"}[t.orientation||"v"]}function o(t,e){var r=i(t),a=n(t,"box-violin"),o=n(t._fullInput||{},"candlestick");return a&&!o&&e===r&&void 0===t[r]&&void 0===t[r+"0"]}e.exports=function(t,e,r,s){"-"===r("type",(s.splomStash||{}).type)&&(!function(t,e){if("-"!==t.type)return;var r=t._id,s=r.charAt(0);-1!==r.indexOf("scene")&&(r=s);var l=function(t,e,r){for(var n=0;n<t.length;n++){var a=t[n];if("splom"===a.type&&a._length>0&&(a["_"+r+"axes"]||{})[e])return a;if((a[r+"axis"]||r)===e){if(o(a,r))return a;if((a[r]||[]).length||a[r+"0"])return a}}}(e,r,s);if(!l)return;if("histogram"===l.type&&s==={v:"y",h:"x"}[l.orientation||"v"])return void(t.type="linear");var c,u=s+"calendar",h=l[u],f={noMultiCategory:!n(l,"cartesian")||n(l,"noMultiCategory")};if(o(l,s)){var p=i(l),d=[];for(c=0;c<e.length;c++){var g=e[c];n(g,"box-violin")&&(g[s+"axis"]||s)===r&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push("text"),g[u]!==h&&(h=void 0))}t.type=a(d,h,f)}else if("splom"===l.type){var v=l.dimensions,m=v[l._axesDim[r]];m.visible&&(t.type=a(m.values,h,f))}else t.type=a(l[s]||[l[s+"0"]],h,f)}(e,s.data),"-"===e.type?e.type="linear":t.type=e.type)}},{"../../registry":845,"./axis_autotype":765}],788:[function(t,e,r){"use strict";var n=t("../registry"),a=t("../lib");function i(t,e,r){var n,i,o,s=!1;if("data"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if("layout"!==e.type)return!1;n=t._fullLayout}return i=a.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==i&&(s=!0),o[e.prop]=i,{changed:s,value:i}}function o(t,e){var r=[],n=e[0],i={};if("string"==typeof n)i[n]=e[1];else{if(!a.isPlainObject(n))return r;i=n}return l(i,function(t,e,n){r.push({type:"layout",prop:t,value:n})},"",0),r}function s(t,e){var r,n,i,o,s=[];if(n=e[0],i=e[1],r=e[2],o={},"string"==typeof n)o[n]=i;else{if(!a.isPlainObject(n))return s;o=n,void 0===r&&(r=i)}return void 0===r&&(r=null),l(o,function(e,n,a){var i,o;if(Array.isArray(a)){o=a.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),i=[];for(var c=0;c<l;c++)i[c]=r?r[c]:c}else o=a,i=r?r.slice():null;if(null===i)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(i)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<i.length;h++)o[h]=u}o.length=Math.min(i.length,o.length)}s.push({type:"data",prop:e,traces:i,value:o})},"",0),s}function l(t,e,r,n){Object.keys(t).forEach(function(i){var o=t[i];if("_"!==i[0]){var s=r+(n>0?".":"")+i;a.isPlainObject(o)?l(o,e,s,n+1):e(s,i,o)}})}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){i(t,c,s.cache),s.check=function(){if(l){var e=i(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=["plotly_relayout","plotly_redraw","plotly_restyle","plotly_update","plotly_animatingframe","plotly_afterplot"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else a.log("Unable to automatically bind plot updates to API command"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var a,i,o=e.length;for(a=0;a<o;a++){var s,l=e[a],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=r.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(i){if((s=h[0]).type!==i.type)return!1;if(s.prop!==i.prop)return!1;if(Array.isArray(i.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<i.traces.length;f++)if(i.traces[f]!==s.traces[f])return!1}else if(s.prop!==i.prop)return!1}else i=h[0],Array.isArray(i.traces)&&i.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=a)}return i},r.executeAPICommand=function(t,e,r){if("skip"===e)return Promise.resolve();var i=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return i.apply(null,o).catch(function(t){return a.warn("API call to Plotly."+e+" rejected.",t),Promise.reject(t)})},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case"restyle":n=s(t,r);break;case"relayout":n=o(t,r);break;case"update":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case"animate":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==["string","number"].indexOf(typeof e[0][0])?[{type:"layout",prop:"_currentFrame",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{"../lib":716,"../registry":845}],789:[function(t,e,r){"use strict";var n=t("../lib/extend").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:"info_array",editType:(t=t||{}).editType,items:[{valType:"number",min:0,max:1,editType:t.editType},{valType:"number",min:0,max:1,editType:t.editType}],dflt:[0,1]},a=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(a.row={valType:"integer",min:0,dflt:0,editType:t.editType},a.column={valType:"integer",min:0,dflt:0,editType:t.editType}),a},r.defaults=function(t,e,r,n){var a=n&&n.x||[0,1],i=n&&n.y||[0,1],o=e.grid;if(o){var s=r("domain.column");void 0!==s&&(s<o.columns?a=o._domains.x[s]:delete t.domain.column);var l=r("domain.row");void 0!==l&&(l<o.rows?i=o._domains.y[l]:delete t.domain.row)}var c=r("domain.x",a),u=r("domain.y",i);c[0]<c[1]||(t.domain.x=a.slice()),u[0]<u[1]||(t.domain.y=i.slice())}},{"../lib/extend":707}],790:[function(t,e,r){"use strict";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:"string",noBlank:!0,strict:!0,editType:e},size:{valType:"number",min:1,editType:e},color:{valType:"color",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],791:[function(t,e,r){"use strict";e.exports={_isLinkedToArray:"frames_entry",group:{valType:"string"},name:{valType:"string"},traces:{valType:"any"},baseframe:{valType:"string"},data:{valType:"any"},layout:{valType:"any"}}},{}],792:[function(t,e,r){"use strict";r.projNames={equirectangular:"equirectangular",mercator:"mercator",orthographic:"orthographic","natural earth":"naturalEarth",kavrayskiy7:"kavrayskiy7",miller:"miller",robinson:"robinson",eckert4:"eckert4","azimuthal equal area":"azimuthalEqualArea","azimuthal equidistant":"azimuthalEquidistant","conic equal area":"conicEqualArea","conic conformal":"conicConformal","conic equidistant":"conicEquidistant",gnomonic:"gnomonic",stereographic:"stereographic",mollweide:"mollweide",hammer:"hammer","transverse mercator":"transverseMercator","albers usa":"albersUsa","winkel tripel":"winkel3",aitoff:"aitoff",sinusoidal:"sinusoidal"},r.axesNames=["lonaxis","lataxis"],r.lonaxisSpan={orthographic:180,"azimuthal equal area":360,"azimuthal equidistant":360,"conic conformal":180,gnomonic:160,stereographic:180,"transverse mercator":180,"*":360},r.lataxisSpan={"conic conformal":150,stereographic:179.5,"*":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:"equirectangular",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:"albers usa"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:"conic conformal",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:"mercator",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:"mercator",projRotate:[0,0,0]},"north america":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:"conic conformal",projRotate:[-100,0,0],projParallels:[29.5,45.5]},"south america":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:"mercator",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor="#F0DC82",r.waterColor="#3399FF",r.locationmodeToLayer={"ISO-3":"countries","USA-states":"subunits","country names":"countries"},r.sphereSVG={type:"Sphere"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=["bg","ocean","land","lakes","subunits","countries","coastlines","rivers","lataxis","lonaxis","frame","backplot","frontplot"],r.layersForChoropleth=["bg","ocean","land","subunits","countries","coastlines","lataxis","lonaxis","frame","backplot","rivers","lakes","frontplot"],r.layerNameToAdjective={ocean:"ocean",land:"land",lakes:"lake",subunits:"subunit",countries:"country",coastlines:"coastline",rivers:"river",frame:"frame"}},{}],793:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../lib"),o=t("../../components/color"),s=t("../../components/drawing"),l=t("../../components/fx"),c=t("../plots"),u=t("../cartesian/axes"),h=t("../../components/dragelement"),f=t("../cartesian/select").prepSelect,p=t("../cartesian/select").selectOnClick,d=t("./zoom"),g=t("./constants"),v=t("../../lib/topojson_utils"),m=t("topojson-client").feature;function y(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t("./projections")(n);var x=y.prototype;e.exports=function(t){return new y(t)},x.plot=function(t,e,r){var n=this,a=e[this.id],i=!1;for(var o in g.layerNameToAdjective)if("frame"!==o&&a["show"+o]){i=!0;break}for(var s=0;s<t.length;s++)if(t[0][0].trace.locationmode){i=!0;break}if(!i)return n.update(t,e);var l=v.getTopojsonName(a);null===n.topojson||l!==n.topojsonName?(n.topojsonName=l,void 0===PlotlyGeoAssets.topojson[n.topojsonName]?r.push(n.fetchTopojson().then(function(r){PlotlyGeoAssets.topojson[n.topojsonName]=r,n.topojson=r,n.update(t,e)})):(n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e))):n.update(t,e)},x.fetchTopojson=function(){var t=v.getTopojsonPath(this.topojsonURL,this.topojsonName);return new Promise(function(e,r){n.json(t,function(n,a){if(n)return 404===n.status?r(new Error(["plotly.js could not find topojson file at",t,".","Make sure the *topojsonURL* plot config option","is set properly."].join(" "))):r(new Error(["unexpected error while fetching topojson file at",t].join(" ")));e(a)})})},x.update=function(t,e){var r=e[this.id];if(!this.updateProjection(e,r)){this.hasChoropleth=!1;for(var n=0;n<t.length;n++)if("choropleth"===t[n][0].trace.type){this.hasChoropleth=!0;break}this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var a=this.layers.frontplot.select(".scatterlayer");this.dataPoints.point=a.selectAll(".point"),this.dataPoints.text=a.selectAll("text"),this.dataPaths.line=a.selectAll(".js-line");var i=this.layers.backplot.select(".choroplethlayer");this.dataPaths.choropleth=i.selectAll("path"),this.render()}},x.updateProjection=function(t,e){var r=t._size,o=e.domain,s=e.projection,l=s.rotation||{},c=e.center||{},u=this.projection=function(t){for(var e=t.projection.type,r=n.geo[g.projNames[e]](),a=t._isClipped?g.lonaxisSpan[e]/2:null,i=["center","rotate","parallels","clipExtent"],o=function(t){return t?r:[]},s=0;s<i.length;s++){var l=i[s];"function"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(a){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>a*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],a=t[1][1]-t[0][1],i=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),i&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),a/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(a-s*(o[1][1]+o[0][1]))/2;return i&&r.clipExtent(i),r.scale(150*s).translate([l,c])},r.precision(g.precision),a&&r.clipAngle(a-g.clipPad);return r}(e);u.center([c.lon-l.lon,c.lat-l.lat]).rotate([-l.lon,-l.lat,l.roll]).parallels(s.parallels);var h=[[r.l+r.w*o.x[0],r.t+r.h*(1-o.y[1])],[r.l+r.w*o.x[1],r.t+r.h*(1-o.y[0])]],f=e.lonaxis,p=e.lataxis,d=function(t,e){var r=g.clipPad,n=t[0]+r,a=t[1]-r,i=e[0]+r,o=e[1]-r;n>0&&a<0&&(a+=360);var s=(a-n)/4;return{type:"Polygon",coordinates:[[[n,i],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[a,o],[a,i],[a-s,i],[a-2*s,i],[a-3*s,i],[n,i]]]}}(f.range,p.range);u.fitExtent(h,d);var v=this.bounds=u.getBounds(d),m=this.fitScale=u.scale(),y=u.translate();if(!isFinite(v[0][0])||!isFinite(v[0][1])||!isFinite(v[1][0])||!isFinite(v[1][1])||isNaN(y[0])||isNaN(y[0])){for(var x=this.graphDiv,b=["projection.rotation","center","lonaxis.range","lataxis.range"],_="Invalid geo settings, relayout'ing to default view.",w={},k=0;k<b.length;k++)w[this.id+"."+b[k]]=null;return this.viewInitial=null,i.warn(_),x._promises.push(a.call("relayout",x,w)),_}var T=this.midPt=[(v[0][0]+v[1][0])/2,(v[0][1]+v[1][1])/2];if(u.scale(s.scale*m).translate([y[0]+(T[0]-y[0]),y[1]+(T[1]-y[1])]).clipExtent(v),e._isAlbersUsa){var A=u([c.lon,c.lat]),M=u.translate();u.translate([M[0]-(A[0]-M[0]),M[1]-(A[1]-M[1])])}},x.updateBaseLayers=function(t,e){var r=this,a=r.topojson,i=r.layers,l=r.basePaths;function c(t){return"lonaxis"===t||"lataxis"===t}function h(t){return Boolean(g.lineLayers[t])}function f(t){return Boolean(g.fillLayers[t])}var p=(this.hasChoropleth?g.layersForChoropleth:g.layers).filter(function(t){return h(t)||f(t)?e["show"+t]:!c(t)||e[t].showgrid}),d=r.framework.selectAll(".layer").data(p,String);d.exit().each(function(t){delete i[t],delete l[t],n.select(this).remove()}),d.enter().append("g").attr("class",function(t){return"layer "+t}).each(function(t){var e=i[t]=n.select(this);"bg"===t?r.bgRect=e.append("rect").style("pointer-events","all"):c(t)?l[t]=e.append("path").style("fill","none"):"backplot"===t?e.append("g").classed("choroplethlayer",!0):"frontplot"===t?e.append("g").classed("scatterlayer",!0):h(t)?l[t]=e.append("path").style("fill","none").style("stroke-miterlimit",2):f(t)&&(l[t]=e.append("path").style("stroke","none"))}),d.order(),d.each(function(r){var n=l[r],i=g.layerNameToAdjective[r];"frame"===r?n.datum(g.sphereSVG):h(r)||f(r)?n.datum(m(a,a.objects[r])):c(r)&&n.datum(function(t,e,r){var n,a,i,o=e[t],s=g.scopeDefaults[e.scope];"lonaxis"===t?(n=s.lonaxisRange,a=s.lataxisRange,i=function(t,e){return[t,e]}):"lataxis"===t&&(n=s.lataxisRange,a=s.lonaxisRange,i=function(t,e){return[e,t]});var l={type:"linear",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};u.setConvert(l,r);var c=u.calcTicks(l);e.isScoped||"lonaxis"!==t||c.pop();for(var h=c.length,f=new Array(h),p=0;p<h;p++)for(var d=c[p].x,v=f[p]=[],m=a[0];m<a[1]+2.5;m+=2.5)v.push(i(d,m));return{type:"MultiLineString",coordinates:f}}(r,e,t)).call(o.stroke,e[r].gridcolor).call(s.dashLine,"",e[r].gridwidth),h(r)?n.call(o.stroke,e[i+"color"]).call(s.dashLine,"",e[i+"width"]):f(r)&&n.call(o.fill,e[i+"color"])})},x.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,a=r[0][0]-n,i=r[0][1]-n,l=r[1][0]-a+n,c=r[1][1]-i+n;s.setRect(this.clipRect,a,i,l,c),this.bgRect.call(s.setRect,a,i,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=a,this.xaxis._length=l,this.yaxis._offset=i,this.yaxis._length=c},x.updateFx=function(t,e){var r=this,i=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;"select"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:"lasso"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var g={element:r.bgRect.node(),gd:i,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(e){2===e&&t._zoomlayer.selectAll(".select-outline").remove()}};"pan"===s?(o.node().onmousedown=null,o.call(d(r,e)),o.on("dblclick.zoom",function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+"."+n]=t[n];a.call("_guiRelayout",i,e),i.emit("plotly_doubleclick",null)}),i._context._scrollZoom.geo||o.on("wheel.zoom",null)):"select"!==s&&"lasso"!==s||(o.on(".zoom",null),g.prepFn=function(t,e,r){f(t,e,r,g,s)},h.init(g)),o.on("mousemove",function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return h.unhover(i,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(i,n.event,r.id)}),o.on("mouseout",function(){i._dragging||h.unhover(i,n.event)}),o.on("click",function(){"select"!==s&&"lasso"!==s&&(c.indexOf("select")>-1&&p(n.event,i,[r.xaxis],[r.yaxis],r.id,g),c.indexOf("event")>-1&&l.click(i,n.event))})}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},x.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,a="clip"+r._uid+t.id;t.clipDef=r._clips.append("clipPath").attr("id",a),t.clipRect=t.clipDef.append("rect"),t.framework=n.select(t.container).append("g").attr("class","geo "+t.id).call(s.setClipUrl,a,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:"x",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:"y",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:"linear",showexponent:"all",exponentformat:"B"},u.setConvert(t.mockAxis,r)},x.saveViewInitial=function(t){var e=t.center||{},r=t.projection,n=r.rotation||{};t._isScoped?this.viewInitial={"center.lon":e.lon,"center.lat":e.lat,"projection.scale":r.scale}:t._isClipped?this.viewInitial={"projection.scale":r.scale,"projection.rotation.lon":n.lon,"projection.rotation.lat":n.lat}:this.viewInitial={"center.lon":e.lon,"center.lat":e.lat,"projection.scale":r.scale,"projection.rotation.lon":n.lon}},x.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?"translate("+r[0]+","+r[1]+")":null}function a(t){return e.isLonLatOverEdges(t.lonlat)?"none":null}for(t in this.basePaths)this.basePaths[t].attr("d",r);for(t in this.dataPaths)this.dataPaths[t].attr("d",function(t){return r(t.geojson)});for(t in this.dataPoints)this.dataPoints[t].attr("display",a).attr("transform",n)}},{"../../components/color":591,"../../components/dragelement":609,"../../components/drawing":612,"../../components/fx":629,"../../lib":716,"../../lib/topojson_utils":743,"../../registry":845,"../cartesian/axes":764,"../cartesian/select":781,"../plots":825,"./constants":792,"./projections":797,"./zoom":798,d3:164,"topojson-client":538}],794:[function(t,e,r){"use strict";var n=t("../../plots/get_data").getSubplotCalcData,a=t("../../lib").counterRegex,i=t("./geo"),o="geo",s=a(o),l={};l[o]={valType:"subplotid",dflt:o,editType:"calc"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t("./layout_attributes"),supplyLayoutDefaults:t("./layout_defaults"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots[o],s=0;s<a.length;s++){var l=a[s],c=n(r,o,l),u=e[l]._subplot;u||(u=i({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots[o],n=0;n<r.length;n++){var a=e[r[n]];a._subplot.updateFx(e,a)}},clean:function(t,e,r,n){for(var a=n._subplots[o]||[],i=0;i<a.length;i++){var s=a[i],l=n[s]._subplot;!e[s]&&l&&(l.framework.remove(),l.clipDef.remove())}}}},{"../../lib":716,"../../plots/get_data":799,"./geo":793,"./layout_attributes":795,"./layout_defaults":796}],795:[function(t,e,r){"use strict";var n=t("../../components/color/attributes"),a=t("../domain").attributes,i=t("./constants"),o=t("../../plot_api/edit_types").overrideAll,s={range:{valType:"info_array",items:[{valType:"number"},{valType:"number"}]},showgrid:{valType:"boolean",dflt:!1},tick0:{valType:"number",dflt:0},dtick:{valType:"number"},gridcolor:{valType:"color",dflt:n.lightLine},gridwidth:{valType:"number",min:0,dflt:1}};(e.exports=o({domain:a({name:"geo"},{}),resolution:{valType:"enumerated",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:"enumerated",values:Object.keys(i.scopeDefaults),dflt:"world"},projection:{type:{valType:"enumerated",values:Object.keys(i.projNames)},rotation:{lon:{valType:"number"},lat:{valType:"number"},roll:{valType:"number"}},parallels:{valType:"info_array",items:[{valType:"number"},{valType:"number"}]},scale:{valType:"number",min:0,dflt:1}},center:{lon:{valType:"number"},lat:{valType:"number"}},showcoastlines:{valType:"boolean"},coastlinecolor:{valType:"color",dflt:n.defaultLine},coastlinewidth:{valType:"number",min:0,dflt:1},showland:{valType:"boolean",dflt:!1},landcolor:{valType:"color",dflt:i.landColor},showocean:{valType:"boolean",dflt:!1},oceancolor:{valType:"color",dflt:i.waterColor},showlakes:{valType:"boolean",dflt:!1},lakecolor:{valType:"color",dflt:i.waterColor},showrivers:{valType:"boolean",dflt:!1},rivercolor:{valType:"color",dflt:i.waterColor},riverwidth:{valType:"number",min:0,dflt:1},showcountries:{valType:"boolean"},countrycolor:{valType:"color",dflt:n.defaultLine},countrywidth:{valType:"number",min:0,dflt:1},showsubunits:{valType:"boolean"},subunitcolor:{valType:"color",dflt:n.defaultLine},subunitwidth:{valType:"number",min:0,dflt:1},showframe:{valType:"boolean"},framecolor:{valType:"color",dflt:n.defaultLine},framewidth:{valType:"number",min:0,dflt:1},bgcolor:{valType:"color",dflt:n.background},lonaxis:s,lataxis:s},"plot","from-root")).uirevision={valType:"any",editType:"none"}},{"../../components/color/attributes":590,"../../plot_api/edit_types":747,"../domain":789,"./constants":792}],796:[function(t,e,r){"use strict";var n=t("../subplot_defaults"),a=t("./constants"),i=t("./layout_attributes"),o=a.axesNames;function s(t,e,r){var n=r("resolution"),i=r("scope"),s=a.scopeDefaults[i],l=r("projection.type",s.projType),c=e._isAlbersUsa="albers usa"===l;c&&(i=e.scope="usa");var u=e._isScoped="world"!==i,h=e._isConic=-1!==l.indexOf("conic");e._isClipped=!!a.lonaxisSpan[l];for(var f=0;f<o.length;f++){var p,d=o[f],g=[30,10][f];if(u)p=s[d+"Range"];else{var v=a[d+"Span"],m=(v[l]||v["*"])/2,y=r("projection.rotation."+d.substr(0,3),s.projRotate[f]);p=[y-m,y+m]}r(d+".range",p),r(d+".tick0"),r(d+".dtick",g),r(d+".showgrid")&&(r(d+".gridcolor"),r(d+".gridwidth"))}var x=e.lonaxis.range,b=e.lataxis.range,_=x[0],w=x[1];_>0&&w<0&&(w+=360);var k,T,A,M=(_+w)/2;if(!c){var S=u?s.projRotate:[M,0,0];k=r("projection.rotation.lon",S[0]),r("projection.rotation.lat",S[1]),r("projection.rotation.roll",S[2]),r("showcoastlines",!u)&&(r("coastlinecolor"),r("coastlinewidth")),r("showocean")&&r("oceancolor")}(c?(T=-96.6,A=38.7):(T=u?M:k,A=(b[0]+b[1])/2),r("center.lon",T),r("center.lat",A),h)&&r("projection.parallels",s.projParallels||[0,60]);r("projection.scale"),r("showland")&&r("landcolor"),r("showlakes")&&r("lakecolor"),r("showrivers")&&(r("rivercolor"),r("riverwidth")),r("showcountries",u&&"usa"!==i)&&(r("countrycolor"),r("countrywidth")),("usa"===i||"north america"===i&&50===n)&&(r("showsubunits",!0),r("subunitcolor"),r("subunitwidth")),u||r("showframe",!0)&&(r("framecolor"),r("framewidth")),r("bgcolor")}e.exports=function(t,e,r){n(t,e,r,{type:"geo",attributes:i,handleDefaults:s,partition:"y"})}},{"../subplot_defaults":839,"./constants":792,"./layout_attributes":795}],797:[function(t,e,r){"use strict";e.exports=function(t){function e(t,e){return{type:"Feature",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if("GeometryCollection"===e.type)return{type:"GeometryCollection",geometries:object.geometries.map(function(t){return r(t,n)})};if(!c.hasOwnProperty(e.type))return null;var a=c[e.type];return t.geo.stream(e,n(a)),a.result()}t.geo.project=function(t,e){var a=e.stream;if(!a)throw new Error("not yet supported");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,a)};var n={Feature:e,FeatureCollection:function(t,r){return{type:"FeatureCollection",features:t.features.map(function(t){return e(t,r)})}}},a=[],i=[],o={point:function(t,e){a.push([t,e])},result:function(){var t=a.length?a.length<2?{type:"Point",coordinates:a[0]}:{type:"MultiPoint",coordinates:a}:null;return a=[],t}},s={lineStart:u,point:function(t,e){a.push([t,e])},lineEnd:function(){a.length&&(i.push(a),a=[])},result:function(){var t=i.length?i.length<2?{type:"LineString",coordinates:i[0]}:{type:"MultiLineString",coordinates:i}:null;return i=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){a.push([t,e])},lineEnd:function(){var t=a.length;if(t){do{a.push(a[0].slice())}while(++t<4);i.push(a),a=[]}},polygonEnd:u,result:function(){if(!i.length)return null;var t=[],e=[];return i.forEach(function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])}),e.forEach(function(e){var r=e[0];t.some(function(t){if(function(t,e){for(var r=e[0],n=e[1],a=!1,i=0,o=t.length,s=o-1;i<o;s=i++){var l=t[i],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(a=!a)}return a}(t[0],r))return t.push(e),!0})||t.push([e])}),i=[],t.length?t.length>1?{type:"MultiPolygon",coordinates:t}:{type:"Polygon",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var h=1e-6,f=h*h,p=Math.PI,d=p/2,g=(Math.sqrt(p),p/180),v=180/p;function m(t){return t>1?d:t<-1?-d:Math.asin(t)}function y(t){return t>1?0:t<-1?p:Math.acos(t)}var x=t.geo.projection,b=t.geo.projectionMutator;function _(t,e){var r=(2+d)*Math.sin(e);e/=2;for(var n=0,a=1/0;n<10&&Math.abs(a)>h;n++){var i=Math.cos(e);e-=a=(e+Math.sin(e)*(i+2)-r)/(2*i*(1+i))}return[2/Math.sqrt(p*(4+p))*t*(1+Math.cos(e)),2*Math.sqrt(p/(4+p))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-p,0],[0,d],[p,0]]],[[[-p,0],[0,-d],[p,0]]]];function a(t,r){for(var a=r<0?-1:1,i=n[+(r<0)],o=0,s=i.length-1;o<s&&t>i[o][2][0];++o);var l=e(t-i[o][1][0],r);return l[0]+=e(i[o][1][0],a*r>a*i[o][0][1]?i[o][0][1]:r)[0],l}e.invert&&(a.invert=function(t,i){for(var o=r[+(i<0)],s=n[+(i<0)],c=0,u=o.length;c<u;++c){var h=o[c];if(h[0][0]<=t&&t<h[1][0]&&h[0][1]<=i&&i<h[1][1]){var f=e.invert(t-e(s[c][1][0],0)[0],i);return f[0]+=s[c][1][0],l(a(f[0],f[1]),[t,i])?f:null}}});var i=t.geo.projection(a),o=i.stream;function s(t,e){for(var r,n,a,i=-1,o=t.length,s=t[0],l=[];++i<o;){n=((r=t[i])[0]-s[0])/e,a=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*a]);s=r}return l.push(r),l}function l(t,e){return Math.abs(t[0]-e[0])<h&&Math.abs(t[1]-e[1])<h}return i.stream=function(e){var r=i.rotate(),a=o(e),l=(i.rotate([0,0]),o(e));return i.rotate(r),a.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],a=0,i=n[0].length;a<i;++a){var o=n[0][a],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[l+e,c+e],[l+e,u-e],[h-e,u-e],[h-e,f+e]],30))}for(var a=n[1].length-1;a>=0;--a){var o=n[1][a],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[h-e,f-e],[h-e,u+e],[l+e,u+e],[l+e,c-e]],30))}return{type:"Polygon",coordinates:[t.merge(r)]}}(),l)},a},i.lobes=function(t){return arguments.length?(n=t.map(function(t){return t.map(function(t){return[[t[0][0]*p/180,t[0][1]*p/180],[t[1][0]*p/180,t[1][1]*p/180],[t[2][0]*p/180,t[2][1]*p/180]]})}),r=n.map(function(t){return t.map(function(t){var r,n=e(t[0][0],t[0][1])[0],a=e(t[2][0],t[2][1])[0],i=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return i>o&&(r=i,i=o,o=r),[[n,i],[a,o]]})}),i):n.map(function(t){return t.map(function(t){return[[180*t[0][0]/p,180*t[0][1]/p],[180*t[1][0]/p,180*t[1][1]/p],[180*t[2][0]/p,180*t[2][1]/p]]})})},i},_.invert=function(t,e){var r=.5*e*Math.sqrt((4+p)/p),n=m(r),a=Math.cos(n);return[t/(2/Math.sqrt(p*(4+p))*(1+a)),m((n+r*(a+2))/(2+d))]},(t.geo.eckert4=function(){return x(_)}).raw=_;var w=t.geo.azimuthalEqualArea.raw;function k(t,e){if(arguments.length<2&&(e=t),1===e)return w;if(e===1/0)return T;function r(r,n){var a=w(r/e,n);return a[0]*=t,a}return r.invert=function(r,n){var a=w.invert(r/t,n);return a[0]*=e,a},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function A(t,e){return[3*t/(2*p)*Math.sqrt(p*p/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(p/4+.4*e))]}function S(t){return function(e){var r,n=t*Math.sin(e),a=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>h&&--a>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=b(k),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=k,A.invert=function(t,e){return[2/3*p*t/Math.sqrt(p*p/3-e*e),e]},(t.geo.kavrayskiy7=function(){return x(A)}).raw=A,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*p]},(t.geo.miller=function(){return x(M)}).raw=M,S(p);var E=function(t,e,r){var n=S(r);function a(r,a){return[t*r*Math.cos(a=n(a)),e*Math.sin(a)]}return a.invert=function(n,a){var i=m(a/e);return[n/(t*Math.cos(i)),m((2*i+Math.sin(2*i))/r)]},a}(Math.SQRT2/d,Math.SQRT2,p);function L(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return x(E)}).raw=E,L.invert=function(t,e){var r,n=e,a=25;do{var i=n*n,o=i*i;n-=r=(n*(1.007226+i*(.015085+o*(.028874*i-.044475-.005916*o)))-e)/(1.007226+i*(.045255+o*(.259866*i-.311325-.005916*11*o)))}while(Math.abs(r)>h&&--a>0);return[t/(.8707+(i=n*n)*(i*(i*i*i*(.003971-.001529*i)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return x(L)}).raw=L;var C=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function P(t,e){var r,n=Math.min(18,36*Math.abs(e)/p),a=Math.floor(n),i=n-a,o=(r=C[a])[0],s=r[1],l=(r=C[++a])[0],c=r[1],u=(r=C[Math.min(19,++a)])[0],h=r[1];return[t*(l+i*(u-o)/2+i*i*(u-2*l+o)/2),(e>0?d:-d)*(c+i*(h-s)/2+i*i*(h-2*c+s)/2)]}function O(t,e){return[t*Math.cos(e),e]}function z(t,e){var r,n=Math.cos(e),a=(r=y(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*a,Math.sin(e)*a]}function I(t,e){var r=z(t,e);return[(r[0]+t/d)/2,(r[1]+e)/2]}C.forEach(function(t){t[1]*=1.0144}),P.invert=function(t,e){var r=e/d,n=90*r,a=Math.min(18,Math.abs(n/5)),i=Math.max(0,Math.floor(a));do{var o=C[i][1],s=C[i+1][1],l=C[Math.min(19,i+2)][1],c=l-o,u=l-2*s+o,h=2*(Math.abs(r)-s)/c,p=u/c,m=h*(1-p*h*(1-2*p*h));if(m>=0||1===i){n=(e>=0?5:-5)*(m+a);var y,x=50;do{m=(a=Math.min(18,Math.abs(n)/5))-(i=Math.floor(a)),o=C[i][1],s=C[i+1][1],l=C[Math.min(19,i+2)][1],n-=(y=(e>=0?d:-d)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*v}while(Math.abs(y)>f&&--x>0);break}}while(--i>=0);var b=C[i][0],_=C[i+1][0],w=C[Math.min(19,i+2)][0];return[t/(_+m*(w-b)/2+m*m*(w-2*_+b)/2),n*g]},(t.geo.robinson=function(){return x(P)}).raw=P,O.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return x(O)}).raw=O,z.invert=function(t,e){if(!(t*t+4*e*e>p*p+h)){var r=t,n=e,a=25;do{var i,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),f=Math.sin(2*n),d=c*c,g=u*u,v=s*s,m=1-g*l*l,x=m?y(u*l)*Math.sqrt(i=1/m):i=0,b=2*x*u*s-t,_=x*c-e,w=i*(g*v+x*u*l*d),k=i*(.5*o*f-2*x*c*s),T=.25*i*(f*s-x*c*g*o),A=i*(d*l+x*v*u),M=k*T-A*w;if(!M)break;var S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--a>0);return[r,n]}},(t.geo.aitoff=function(){return x(z)}).raw=z,I.invert=function(t,e){var r=t,n=e,a=25;do{var i,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,f=Math.sin(r),p=Math.cos(r/2),g=Math.sin(r/2),v=g*g,m=1-u*p*p,x=m?y(o*p)*Math.sqrt(i=1/m):i=0,b=.5*(2*x*o*g+r/d)-t,_=.5*(x*s+n)-e,w=.5*i*(u*v+x*o*p*c)+.5/d,k=i*(f*l/4-x*s*g),T=.125*i*(l*g-x*s*u*f),A=.5*i*(c*p+x*v*o)+.5,M=k*T-A*w,S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--a>0);return[r,n]},(t.geo.winkel3=function(){return x(I)}).raw=I}},{}],798:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../registry"),o=Math.PI/180,s=180/Math.PI,l={cursor:"pointer"},c={cursor:"auto"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+"."+t]=a.nestedProperty(l,t).get(),i.call("_storeDirectGUIEdit",s,c._preGUI,h);var r=a.nestedProperty(u,t);r.get()!==e&&(r.set(e),a.nestedProperty(l,t).set(e),f[n+"."+t]=e)}r(p),p("projection.scale",e.scale()/t.fitScale),o.emit("plotly_relayout",f)}function f(t,e){var r=u(0,e);function a(r){var n=e.invert(t.midPt);r("center.lon",n[0]),r("center.lat",n[1])}return r.on("zoomstart",function(){n.select(this).style(l)}).on("zoom",function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit("plotly_relayouting",{"geo.projection.scale":e.scale()/t.fitScale,"geo.center.lon":r[0],"geo.center.lat":r[1]})}).on("zoomend",function(){n.select(this).style(c),h(t,e,a)}),r}function p(t,e){var r,a,i,o,s,f,p,d,g,v=u(0,e),m=2;function y(t){return e.invert(t)}function x(r){var n=e.rotate(),a=e.invert(t.midPt);r("projection.rotation.lon",-n[0]),r("center.lon",a[0]),r("center.lat",a[1])}return v.on("zoomstart",function(){n.select(this).style(l),r=n.mouse(this),a=e.rotate(),i=e.translate(),o=a,s=y(r)}).on("zoom",function(){if(f=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>m||Math.abs(n[1]-t[1])>m}(r))return v.scale(e.scale()),void v.translate(e.translate());e.scale(n.event.scale),e.translate([i[0],n.event.translate[1]]),s?y(f)&&(d=y(f),p=[o[0]+(d[0]-s[0]),a[1],a[2]],e.rotate(p),o=p):s=y(r=f),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit("plotly_relayouting",{"geo.projection.scale":e.scale()/t.fitScale,"geo.center.lon":c[0],"geo.center.lat":c[1],"geo.projection.rotation.lon":-l[0]})}).on("zoomend",function(){n.select(this).style(c),g&&h(t,e,x)}),v}function d(t,e){var r,a={r:e.rotate(),k:e.scale()},i=u(0,e),f=function(t){var e=0,r=arguments.length,a=[];for(;++e<r;)a.push(arguments[e]);var i=n.dispatch.apply(null,a);return i.of=function(e,r){return function(a){var o;try{o=a.sourceEvent=n.event,a.target=t,n.event=a,i[a.type].apply(e,r)}finally{n.event=o}}},i}(i,"zoomstart","zoom","zoomend"),p=0,d=i.on;function m(t){var r=e.rotate();t("projection.rotation.lon",-r[0]),t("projection.rotation.lat",-r[1])}return i.on("zoomstart",function(){n.select(this).style(l);var t,c,u,h,m,b,_,w,k,T,A,M=n.mouse(this),S=e.rotate(),E=S,L=e.translate(),C=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,h=.5*t[2]*o,m=Math.sin(c),b=Math.cos(c),_=Math.sin(u),w=Math.cos(u),k=Math.sin(h),T=Math.cos(h),[b*w*T+m*_*k,m*w*T-b*_*k,b*_*T+m*w*k,b*w*k-m*_*T]);r=g(e,M),d.call(i,"zoom",function(){var t,i,o,l,c,u,h,p,d,m,b=n.mouse(this);if(e.scale(a.k=n.event.scale),r){if(g(e,b)){e.rotate(S).translate(L);var _=g(e,b),w=function(t,e){if(!t||!e)return;var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),a=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),i=Math.sin(a)/n;return n&&[Math.cos(a),r[2]*i,-r[1]*i,r[0]*i]}(r,_),k=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((i=w,o=(t=C)[0],l=t[1],c=t[2],u=t[3],h=i[0],p=i[1],d=i[2],m=i[3],[o*h-l*p-c*d-u*m,o*p+l*h+c*m-u*d,o*d-l*m+c*h+u*p,o*m+l*d-c*p+u*h])),T=a.r=function(t,e,r){var n=y(e,2,t[0]);n=y(n,1,t[1]),n=y(n,0,t[2]-r[2]);var a,i,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(i=(h>0?90:-90)-p,a=0):(i=Math.asin(h/d)*s-p,a=Math.sqrt(d*d-h*h));var g=180-i-2*p,m=(Math.atan2(f,u)-Math.atan2(c,a))*s,x=(Math.atan2(f,u)-Math.atan2(c,-a))*s,b=v(r[0],r[1],i,m),_=v(r[0],r[1],g,x);return b<=_?[i,m,r[2]]:[g,x,r[2]]}(k,r,E);isFinite(T[0])&&isFinite(T[1])&&isFinite(T[2])||(T=E),e.rotate(T),E=T}}else r=g(e,M=b);f.of(this,arguments)({type:"zoom"})}),A=f.of(this,arguments),p++||A({type:"zoomstart"})}).on("zoomend",function(){var r;n.select(this).style(c),d.call(i,"zoom",null),r=f.of(this,arguments),--p||r({type:"zoomend"}),h(t,e,m)}).on("zoom.redraw",function(){t.render();var r=e.rotate();t.graphDiv.emit("plotly_relayouting",{"geo.projection.scale":e.scale()/t.fitScale,"geo.projection.rotation.lon":-r[0],"geo.projection.rotation.lat":-r[1]})}),n.rebind(i,f,"on")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function v(t,e,r,n){var a=m(r-t),i=m(n-e);return Math.sqrt(a*a+i*i)}function m(t){return(t%360+540)%360-180}function y(t,e,r){var n=r*o,a=t.slice(),i=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return a[i]=t[i]*l-t[s]*c,a[s]=t[s]*l+t[i]*c,a}function x(t,e){for(var r=0,n=0,a=t.length;n<a;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},{"../../lib":716,"../../registry":845,d3:164}],799:[function(t,e,r){"use strict";var n=t("../registry"),a=t("./cartesian/constants").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var a=n.subplotsRegistry[e];if(!a)return[];for(var i=a.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[i]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,a=[],i=[];if(!(r="string"==typeof e?n.getModule(e).plot:"function"==typeof e?e:e.plot))return[a,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?a.push(s):i.push(s))}return[a,i]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var i,o,s,l=n.subplotsRegistry[e].attr,c=[];if("gl2d"===e){var u=r.match(a);o="x"+u[1],s="y"+u[2]}for(var h=0;h<t.length;h++)i=t[h],"gl2d"===e&&n.traceIs(i,"gl2d")?i[l[0]]===o&&i[l[1]]===s&&c.push(i):i[l]===r&&c.push(i);return c}},{"../registry":845,"./cartesian/constants":770}],800:[function(t,e,r){"use strict";var n=t("mouse-change"),a=t("mouse-wheel"),i=t("mouse-event-offset"),o=t("../cartesian/constants"),s=t("has-passive-events");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,a){var i,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function v(e,r,n){var a=Math.min(r,n),i=Math.max(r,n);a!==i?(l[e]=a,l[e+2]=i,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,a*=r.pixelRatio,a=h[3]-h[1]-a,t.fullLayout.dragmode){case"zoom":if(e){var m=n/(h[2]-h[0])*(l[2]-l[0])+l[0],y=a/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=m,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=a),c.boxEnd[0]=m,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-a)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,a=0;a<e.length;a++)if(-1!==e[a][r]){if(-1!==e[a][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{i=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(i*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(i)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(i>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(i=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],i||s?(i&&(v(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(v(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case"pan":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=a),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-a)<d&&(a=c.dragStart[1]),i=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-a)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=i,l[2]+=i,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=a}return c.mouseListener=n(e,h),e.addEventListener("touchstart",function(t){var r=i(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener("touchmove",function(t){t.preventDefault();var r=i(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener("touchend",function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()},!!s&&{passive:!1}),c.wheelListener=a(e,function(e,n){if(!t.scrollZoom)return!1;var a=t.calcDataBox(),i=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(i[3]-i[1])),h=o/(i[2]-i[0])*(a[2]-a[0])+a[0],f=s/(i[3]-i[1])*(a[3]-a[1])+a[1];return a[0]=(a[0]-h)*l+h,a[2]=(a[2]-h)*l+h,a[1]=(a[1]-f)*l+f,a[3]=(a[3]-f)*l+f,t.setRanges(a),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0},!0),c}},{"../cartesian/constants":770,"has-passive-events":412,"mouse-change":436,"mouse-event-offset":437,"mouse-wheel":439}],801:[function(t,e,r){"use strict";var n=t("../cartesian/axes"),a=t("../../lib/str2rgbarray");function i(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=["x","y"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=["sans-serif","sans-serif"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title="",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont="sans-serif",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=i.prototype,s=["xaxis","yaxis"];o.merge=function(t){var e,r,n,i,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=a(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?"":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=a(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=a((r.tickfont||{}).color),this.tickAngle[f+p]="auto"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=a(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=a(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,i=r.mirror||!1,u=c?-1!==String(i).indexOf("all"):!!i,h=c?"allticks"===i:-1!==String(i).indexOf("ticks"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=a(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=a(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return"xaxis"===t?"bottom"===r:"yaxis"===t?"left"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return"xaxis"===t?"top"===r:"yaxis"===t?"right"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return"xaxis"===t?"top"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:"yaxis"===t?"right"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return"outside"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return"inside"===t.ticks?-e:e},e.exports=function(t){return new i(t)}},{"../../lib/str2rgbarray":739,"../cartesian/axes":764}],802:[function(t,e,r){"use strict";var n=t("../../plot_api/edit_types").overrideAll,a=t("./scene2d"),i=t("../layout_attributes"),o=t("../../constants/xmlns_namespaces"),s=t("../cartesian/constants"),l=t("../cartesian"),c=t("../../components/fx/layout_attributes"),u=t("../get_data").getSubplotData;r.name="gl2d",r.attr=["xaxis","yaxis"],r.idRoot=["x","y"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t("../cartesian/attributes"),r.supplyLayoutDefaults=function(t,e,r){e._has("cartesian")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,"plot","from-root"),r.baseLayoutAttrOverrides=n({plot_bgcolor:i.plot_bgcolor,hoverlabel:c.hoverlabel},"plot","nested"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,i=0;i<n.length;i++){var o=n[i],s=e._plots[o],l=u(r,"gl2d",o),c=s._scene2d;void 0===c&&(c=new a({id:o,graphDiv:t,container:t.querySelector(".gl-container"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var a=n._subplots.gl2d||[],i=0;i<a.length;i++){var o=a[i],s=n._plots[o];if(s._scene2d)0===u(t,"gl2d",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var a=e._plots[r[n]]._scene2d,i=a.toImage("png");e._glimages.append("svg:image").attr({xmlns:o.svg,"xlink:href":i,x:0,y:0,width:"100%",height:"100%",preserveAspectRatio:"none"}),a.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{"../../components/fx/layout_attributes":630,"../../constants/xmlns_namespaces":693,"../../plot_api/edit_types":747,"../cartesian":775,"../cartesian/attributes":762,"../cartesian/constants":770,"../get_data":799,"../layout_attributes":816,"./scene2d":803}],803:[function(t,e,r){"use strict";var n,a,i=t("../../registry"),o=t("../../plots/cartesian/axes"),s=t("../../components/fx"),l=t("gl-plot2d"),c=t("gl-spikes2d"),u=t("gl-select-box"),h=t("webgl-context"),f=t("./convert"),p=t("./camera"),d=t("../../lib/show_no_webgl_msg"),g=t("../cartesian/constraints"),v=g.enforce,m=g.clean,y=t("../cartesian/autorange").doAutoRange,x=["xaxis","yaxis"],b=t("../cartesian/constants").SUBPLOT_PATTERN;function _(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=_;var w=_.prototype;w.makeFramework=function(){if(this.staticPlot){if(!(a||(n=document.createElement("canvas"),a=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error("Error creating static canvas/context for image server");this.canvas=n,this.gl=a}else{var t=this.container.querySelector(".gl-canvas-focus"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width="100%",r.style.height="100%",r.style.position="absolute",r.style.top="0px",r.style.left="0px",r.style["pointer-events"]="none",this.updateSize(r),r.className+=" user-select-none";var i=this.svgContainer=document.createElementNS("http://www.w3.org/2000/svg","svg");i.style.position="absolute",i.style.top=i.style.left="0px",i.style.width=i.style.height="100%",i.style["z-index"]=20,i.style["pointer-events"]="none";var o=this.mouseContainer=document.createElement("div");o.style.position="absolute",o.style["pointer-events"]="auto",this.pickCanvas=this.container.querySelector(".gl-canvas-pick");var s=this.container;s.appendChild(i),s.appendChild(o);var l=this;o.addEventListener("mouseout",function(){l.isMouseOver=!1,l.unhover()}),o.addEventListener("mouseover",function(){l.isMouseOver=!0})},w.toImage=function(t){t||(t="png"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,a=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var i=new Uint8Array(r*a*4);e.readPixels(0,0,r,a,e.RGBA,e.UNSIGNED_BYTE,i);for(var o=0,s=a-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=i[4*(r*o+l)+c];i[4*(r*o+l)+c]=i[4*(r*s+l)+c],i[4*(r*s+l)+c]=u}var h=document.createElement("canvas");h.width=r,h.height=a;var f,p=h.getContext("2d"),d=p.createImageData(r,a);switch(d.data.set(i),p.putImageData(d,0,0),t){case"jpeg":f=h.toDataURL("image/jpeg");break;case"webp":f=h.toDataURL("image/webp");break;default:f=h.toDataURL("image/png")}return this.staticPlot&&this.container.removeChild(n),f},w.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,a=r.height,i=0|Math.ceil(e*n),o=0|Math.ceil(e*a);return t.width===i&&t.height===o||(t.width=i,t.height=o),t},w.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+"";return t},w.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(b),r="xaxis"+e[1],n="yaxis"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},w.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,a={},o=a[e._name+".range"]=e.range.slice(),s=a[r._name+".range"]=r.range.slice();a[e._name+".autorange"]=e.autorange,a[r._name+".autorange"]=r.autorange,i.call("_storeDirectGUIEdit",t.layout,t._fullLayout._preGUI,a);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,a.lastInputTime=this.camera.lastInputTime,t.emit("plotly_relayout",a)},w.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],a=e[r];if(n.length!==a.length)return!0;for(var i=0;i<n.length;++i)if(n[i].x!==a[i].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},w.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&i.getComponentMethod("annotations","drawOne")(t,r)}},w.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map(function(e){t[e].dispose(),delete t[e]}),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener("wheel",this.camera.wheelListener),this.camera=null}},w.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var a=r.width,i=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,a,i];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};m(s,this.xaxis),m(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,a-u.r-(1-h[1])*u.w,i-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+"px",this.mouseContainer.style.height=u.h*(f[1]-f[0])+"px",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+"px",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+"px",c=0;c<2;++c)(l=this[x[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();v(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},w.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,a=t.r2l,i=e.r2l;return[a(r[0]),i(n[0]),a(r[1]),i(n[1])]},w.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,a=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[a(t[1]),a(t[3])]},w.updateTraces=function(t,e){var r,n,a,i=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<i.length;r++){var o=i[r],s=this.traces[o];for(n=0;n<t.length;n++)if((a=t[n]).uid===o&&a.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){a=t[r];var l=e[r],c=this.traces[a.uid];c?c.update(a,l):(c=a._module.plot(this,a,l),this.traces[a.uid]=c)}this.glplot.objects.sort(function(t,e){return t._trace.index-e._trace.index})},w.updateFx=function(t){"lasso"===t||"select"===t?(this.pickCanvas.style["pointer-events"]="none",this.mouseContainer.style["pointer-events"]="none"):(this.pickCanvas.style["pointer-events"]="auto",this.mouseContainer.style["pointer-events"]="auto"),this.mouseContainer.style.cursor="pan"===t?"move":"zoom"===t?"crosshair":null},w.emitPointAction=function(t,e){for(var r,n=t.trace.uid,a=t.pointIndex,i=0;i<this.fullData.length;i++)this.fullData[i].uid===n&&(r=this.fullData[i]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:a,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,a),this.graphDiv.emit(e,{points:[o]})},w.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,a=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var i,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&"zoom"===a.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=a._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(i=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&i.object._trace.handlePick(i);if(d&&n&&this.emitPointAction(d,"plotly_click"),i&&"skip"!==i.object._trace.hoverinfo&&a.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:i.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(i.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(i.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,"plotly_hover");var v=this.fullData[g.trace.index]||{},m=g.pointIndex,y=s.castHoverinfo(v,a,m);if(y&&"all"!==y){var x=y.split("+");-1===x.indexOf("x")&&(g.traceCoord[0]=void 0),-1===x.indexOf("y")&&(g.traceCoord[1]=void 0),-1===x.indexOf("z")&&(g.traceCoord[2]=void 0),-1===x.indexOf("text")&&(g.textLabel=void 0),-1===x.indexOf("name")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter("xaxis",g.traceCoord[0]),yLabel:this.hoverFormatter("yaxis",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(v,m,"bgcolor")||g.color,borderColor:s.castHoverOption(v,m,"bordercolor"),fontFamily:s.castHoverOption(v,m,"font.family"),fontSize:s.castHoverOption(v,m,"font.size"),fontColor:s.castHoverOption(v,m,"font.color"),nameLength:s.castHoverOption(v,m,"namelength"),textAlign:s.castHoverOption(v,m,"align")},{container:this.svgContainer,gd:this.graphDiv})}}i||this.unhover(),t.draw()}},w.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit("plotly_unhover"),s.loneUnhover(this.svgContainer))},w.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),"hover").text}}},{"../../components/fx":629,"../../lib/show_no_webgl_msg":737,"../../plots/cartesian/axes":764,"../../registry":845,"../cartesian/autorange":763,"../cartesian/constants":770,"../cartesian/constraints":771,"./camera":800,"./convert":801,"gl-plot2d":289,"gl-select-box":301,"gl-spikes2d":310,"webgl-context":554}],804:[function(t,e,r){"use strict";var n=t("../../plot_api/edit_types").overrideAll,a=t("../../components/fx/layout_attributes"),i=t("./scene"),o=t("../get_data").getSubplotData,s=t("../../lib"),l=t("../../constants/xmlns_namespaces");r.name="gl3d",r.attr="scene",r.idRoot="scene",r.idRegex=r.attrRegex=s.counterRegex("scene"),r.attributes=t("./layout/attributes"),r.layoutAttributes=t("./layout/layout_attributes"),r.baseLayoutAttrOverrides=n({hoverlabel:a.hoverlabel},"plot","nested"),r.supplyLayoutDefaults=t("./layout/defaults"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,a=0;a<n.length;a++){var s=n[a],l=o(r,"gl3d",s),c=e[s],u=c.camera,h=c._scene;h||(h=new i({id:s,graphDiv:t,container:t.querySelector(".gl-container"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=h),h.viewInitial||(h.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),h.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var a=n._subplots.gl3d||[],i=0;i<a.length;i++){var o=a[i];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(".annotation-"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,a=0;a<r.length;a++){var i=e[r[a]],o=i.domain,s=i._scene,c=s.toImage("png");e._glimages.append("svg:image").attr({xmlns:l.svg,"xlink:href":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:"none"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return"1"===e&&(e=""),"scene"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{"../../components/fx/layout_attributes":630,"../../constants/xmlns_namespaces":693,"../../lib":716,"../../plot_api/edit_types":747,"../get_data":799,"./layout/attributes":805,"./layout/defaults":809,"./layout/layout_attributes":810,"./scene":814}],805:[function(t,e,r){"use strict";e.exports={scene:{valType:"subplotid",dflt:"scene",editType:"calc+clearAxisTypes"}}},{}],806:[function(t,e,r){"use strict";var n=t("../../../components/color"),a=t("../../cartesian/layout_attributes"),i=t("../../../lib/extend").extendFlat,o=t("../../../plot_api/edit_types").overrideAll;e.exports=o({visible:a.visible,showspikes:{valType:"boolean",dflt:!0},spikesides:{valType:"boolean",dflt:!0},spikethickness:{valType:"number",min:0,dflt:2},spikecolor:{valType:"color",dflt:n.defaultLine},showbackground:{valType:"boolean",dflt:!1},backgroundcolor:{valType:"color",dflt:"rgba(204, 204, 204, 0.5)"},showaxeslabels:{valType:"boolean",dflt:!0},color:a.color,categoryorder:a.categoryorder,categoryarray:a.categoryarray,title:{text:a.title.text,font:a.title.font},type:i({},a.type,{values:["-","linear","log","date","category"]}),autorange:a.autorange,rangemode:a.rangemode,range:i({},a.range,{items:[{valType:"any",editType:"plot",impliedEdits:{"^autorange":!1}},{valType:"any",editType:"plot",impliedEdits:{"^autorange":!1}}],anim:!1}),tickmode:a.tickmode,nticks:a.nticks,tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,mirror:a.mirror,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,tickfont:a.tickfont,tickangle:a.tickangle,tickprefix:a.tickprefix,showtickprefix:a.showtickprefix,ticksuffix:a.ticksuffix,showticksuffix:a.showticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:a.showline,linecolor:a.linecolor,linewidth:a.linewidth,showgrid:a.showgrid,gridcolor:i({},a.gridcolor,{dflt:"rgb(204, 204, 204)"}),gridwidth:a.gridwidth,zeroline:a.zeroline,zerolinecolor:a.zerolinecolor,zerolinewidth:a.zerolinewidth,_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},"plot","from-root")},{"../../../components/color":591,"../../../lib/extend":707,"../../../plot_api/edit_types":747,"../../cartesian/layout_attributes":776}],807:[function(t,e,r){"use strict";var n=t("tinycolor2").mix,a=t("../../../lib"),i=t("../../../plot_api/plot_template"),o=t("./axis_attributes"),s=t("../../cartesian/type_defaults"),l=t("../../cartesian/axis_defaults"),c=["xaxis","yaxis","zaxis"];e.exports=function(t,e,r){var u,h;function f(t,e){return a.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=i.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f("gridcolor",n(h.color,r.bgColor,13600/187).toRgbString()),f("title.text",d[0]),h.setScale=a.noop,f("showspikes")&&(f("spikesides"),f("spikethickness"),f("spikecolor",h.color)),f("showaxeslabels"),f("showbackground")&&f("backgroundcolor")}}},{"../../../lib":716,"../../../plot_api/plot_template":754,"../../cartesian/axis_defaults":766,"../../cartesian/type_defaults":787,"./axis_attributes":806,tinycolor2:535}],808:[function(t,e,r){"use strict";var n=t("../../../lib/str2rgbarray"),a=t("../../../lib"),i=["xaxis","yaxis","zaxis"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=["sans-serif","sans-serif","sans-serif"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=["x","y","z"],this.labelEnable=[!0,!0,!0],this.labelFont=["Open Sans","Open Sans","Open Sans"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[i[r]];o.visible?(this.labels[r]=t._meta?a.templateString(o.title.text,t._meta):o.title.text,"font"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),"showline"in o&&(this.lineEnable[r]=o.showline),"linecolor"in o&&(this.lineColor[r]=n(o.linecolor)),"linewidth"in o&&(this.lineWidth[r]=o.linewidth),"showgrid"in o&&(this.gridEnable[r]=o.showgrid),"gridcolor"in o&&(this.gridColor[r]=n(o.gridcolor)),"gridwidth"in o&&(this.gridWidth[r]=o.gridwidth),"log"===o.type?this.zeroEnable[r]=!1:"zeroline"in o&&(this.zeroEnable[r]=o.zeroline),"zerolinecolor"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),"zerolinewidth"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),"ticks"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,"ticklen"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),"tickcolor"in o&&(this.lineTickColor[r]=n(o.tickcolor)),"tickwidth"in o&&(this.lineTickWidth[r]=o.tickwidth),"tickangle"in o&&(this.tickAngle[r]="auto"===o.tickangle?-3600:Math.PI*-o.tickangle/180),"showticklabels"in o&&(this.tickEnable[r]=o.showticklabels),"tickfont"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),"mirror"in o?-1!==["ticks","all","allticks"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,"showbackground"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{"../../../lib":716,"../../../lib/str2rgbarray":739}],809:[function(t,e,r){"use strict";var n=t("../../../lib"),a=t("../../../components/color"),i=t("../../../registry"),o=t("../../subplot_defaults"),s=t("./axis_defaults"),l=t("./layout_attributes"),c=t("../../get_data").getSubplotData,u="gl3d";function h(t,e,r,n){for(var o=r("bgcolor"),l=a.combine(o,n.paper_bgcolor),h=["up","center","eye"],f=0;f<h.length;f++)r("camera."+h[f]+".x"),r("camera."+h[f]+".y"),r("camera."+h[f]+".z");r("camera.projection.type");var p=!!r("aspectratio.x")&&!!r("aspectratio.y")&&!!r("aspectratio.z"),d=r("aspectmode",p?"manual":"auto");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},"manual"===d&&(e.aspectmode="auto"),t.aspectmode=e.aspectmode);var g=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:g,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),i.getComponentMethod("annotations3d","handleDefaults")(t,e,n);var v=n.getDfltFromLayout("dragmode");if(!1!==v&&!v)if(v="orbit",t.camera&&t.camera.up){var m=t.camera.up.x,y=t.camera.up.y,x=t.camera.up.z;0!==x&&(m&&y&&x?x/Math.sqrt(m*m+y*y+x*x)>.999&&(v="turntable"):v="turntable")}else v="turntable";r("dragmode",v),r("hovermode",n.getDfltFromLayout("hovermode"))}e.exports=function(t,e,r){var a=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:h,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!a)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{"../../../components/color":591,"../../../lib":716,"../../../registry":845,"../../get_data":799,"../../subplot_defaults":839,"./axis_defaults":807,"./layout_attributes":810}],810:[function(t,e,r){"use strict";var n=t("./axis_attributes"),a=t("../../domain").attributes,i=t("../../../lib/extend").extendFlat,o=t("../../../lib").counterRegex;function s(t,e,r){return{x:{valType:"number",dflt:t,editType:"camera"},y:{valType:"number",dflt:e,editType:"camera"},z:{valType:"number",dflt:r,editType:"camera"},editType:"camera"}}e.exports={_arrayAttrRegexps:[o("scene",".annotations",!0)],bgcolor:{valType:"color",dflt:"rgba(0,0,0,0)",editType:"plot"},camera:{up:i(s(0,0,1),{}),center:i(s(0,0,0),{}),eye:i(s(1.25,1.25,1.25),{}),projection:{type:{valType:"enumerated",values:["perspective","orthographic"],dflt:"perspective",editType:"calc"},editType:"calc"},editType:"camera"},domain:a({name:"scene",editType:"plot"}),aspectmode:{valType:"enumerated",values:["auto","cube","data","manual"],dflt:"auto",editType:"plot",impliedEdits:{"aspectratio.x":void 0,"aspectratio.y":void 0,"aspectratio.z":void 0}},aspectratio:{x:{valType:"number",min:0,editType:"plot",impliedEdits:{"^aspectmode":"manual"}},y:{valType:"number",min:0,editType:"plot",impliedEdits:{"^aspectmode":"manual"}},z:{valType:"number",min:0,editType:"plot",impliedEdits:{"^aspectmode":"manual"}},editType:"plot",impliedEdits:{aspectmode:"manual"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:"enumerated",values:["orbit","turntable","zoom","pan",!1],editType:"plot"},hovermode:{valType:"enumerated",values:["closest",!1],dflt:"closest",editType:"modebar"},uirevision:{valType:"any",editType:"none"},editType:"plot",_deprecated:{cameraposition:{valType:"info_array",editType:"camera"}}}},{"../../../lib":716,"../../../lib/extend":707,"../../domain":789,"./axis_attributes":806}],811:[function(t,e,r){"use strict";var n=t("../../../lib/str2rgbarray"),a=["xaxis","yaxis","zaxis"];function i(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}i.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[a[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new i;return e.merge(t),e}},{"../../../lib/str2rgbarray":739}],812:[function(t,e,r){"use strict";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[i[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if("auto"===u.tickmode){u.tickmode="linear";var f=u.nticks||a.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],"date"===u.type&&(p[d].text=p[d].text.replace(/\<br\>/g," "));l[c]=p,u.tickmode=h}}e.ticks=l;for(var c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(var d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],a=new Array(n.length),i=0;i<n.length;++i)a[i]=n[i].x;e[r]=a}return e}(l)};var n=t("../../cartesian/axes"),a=t("../../../lib"),i=["xaxis","yaxis","zaxis"],o=[0,0,0]},{"../../../lib":716,"../../cartesian/axes":764}],813:[function(t,e,r){"use strict";function n(t,e){var r,n,a=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)a[n]+=t[4*r+n]*e[r];return a}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],814:[function(t,e,r){"use strict";var n,a,i=t("gl-plot3d"),o=i.createCamera,s=i.createScene,l=t("webgl-context"),c=t("has-passive-events"),u=t("../../registry"),h=t("../../lib"),f=t("../../plots/cartesian/axes"),p=t("../../components/fx"),d=t("../../lib/str2rgbarray"),g=t("../../lib/show_no_webgl_msg"),v=t("./project"),m=t("./layout/convert"),y=t("./layout/spikes"),x=t("./layout/tick_marks");function b(t,e,r){if(t.initializeGLCamera(),!function(t,e,r,i,o){var c={canvas:i,gl:o,container:t.container,axes:t.axesOptions,spikes:t.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:e,pixelRatio:r};if(t.staticMode){if(!(a||(n=document.createElement("canvas"),a=l({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error("error creating static canvas/context for image server");c.pixelRatio=t.pixelRatio,c.gl=a,c.canvas=n}var u=0;try{t.glplot=s(c)}catch(e){u++;try{t.glplot=s(c)}catch(t){u++}}return u<2}(t,t.camera,t.pixelRatio,e,r))return g(t);var i=t.graphDiv,o=i.layout,u=function(){var e={};return t.isCameraChanged(o)&&(e[t.id+".camera"]=t.getCamera()),t.isAspectChanged(o)&&(e[t.id+".aspectratio"]=t.glplot.getAspectratio()),e},d=function(t){if(!1!==t.fullSceneLayout.dragmode){var e=u();t.saveLayout(o),t.graphDiv.emit("plotly_relayout",e)}};return t.glplot.canvas.addEventListener("mouseup",function(){d(t)}),t.glplot.canvas.addEventListener("wheel",function(e){if(i._context._scrollZoom.gl3d){if(t.glplot.camera._ortho){var r=e.deltaX>e.deltaY?1.1:1/1.1,n=t.glplot.getAspectratio();t.glplot.setAspectratio({x:r*n.x,y:r*n.y,z:r*n.z})}d(t)}},!!c&&{passive:!1}),t.glplot.canvas.addEventListener("mousemove",function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e=u();t.graphDiv.emit("plotly_relayouting",e)}}),t.staticMode||t.glplot.canvas.addEventListener("webglcontextlost",function(e){i&&i.emit&&i.emit("plotly_webglcontextlost",{event:e,layer:t.id})},!1),t.glplot.camera=t.camera,t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(t){var e,r=t.graphDiv,n=t.svgContainer,a=t.container.getBoundingClientRect(),i=a.width,o=a.height;n.setAttributeNS(null,"viewBox","0 0 "+i+" "+o),n.setAttributeNS(null,"width",i),n.setAttributeNS(null,"height",o),x(t),t.glplot.axes.update(t.axesOptions);for(var s,l=Object.keys(t.traces),c=null,u=t.glplot.selection,d=0;d<l.length;++d)"skip"!==(e=t.traces[l[d]]).data.hoverinfo&&e.handlePick(u)&&(c=e),e.setContourLevels&&e.setContourLevels();function g(e,r){var n=t.fullSceneLayout[e];return f.tickText(n,n.d2l(r),"hover").text}if(null!==c){var m=v(t.glplot.cameraParams,u.dataCoordinate);e=c.data;var y,b=r._fullData[e.index],_=u.index,w={xLabel:g("xaxis",u.traceCoordinate[0]),yLabel:g("yaxis",u.traceCoordinate[1]),zLabel:g("zaxis",u.traceCoordinate[2])},k=p.castHoverinfo(b,t.fullLayout,_),T=(k||"").split("+"),A=k&&"all"===k;b.hovertemplate||A||(-1===T.indexOf("x")&&(w.xLabel=void 0),-1===T.indexOf("y")&&(w.yLabel=void 0),-1===T.indexOf("z")&&(w.zLabel=void 0),-1===T.indexOf("text")&&(u.textLabel=void 0),-1===T.indexOf("name")&&(c.name=void 0));var M=[];"cone"===e.type||"streamtube"===e.type?(w.uLabel=g("xaxis",u.traceCoordinate[3]),(A||-1!==T.indexOf("u"))&&M.push("u: "+w.uLabel),w.vLabel=g("yaxis",u.traceCoordinate[4]),(A||-1!==T.indexOf("v"))&&M.push("v: "+w.vLabel),w.wLabel=g("zaxis",u.traceCoordinate[5]),(A||-1!==T.indexOf("w"))&&M.push("w: "+w.wLabel),w.normLabel=u.traceCoordinate[6].toPrecision(3),(A||-1!==T.indexOf("norm"))&&M.push("norm: "+w.normLabel),"streamtube"===e.type&&(w.divergenceLabel=u.traceCoordinate[7].toPrecision(3),(A||-1!==T.indexOf("divergence"))&&M.push("divergence: "+w.divergenceLabel)),u.textLabel&&M.push(u.textLabel),y=M.join("<br>")):"isosurface"===e.type||"volume"===e.type?(w.valueLabel=f.tickText(t.mockAxis,t.mockAxis.d2l(u.traceCoordinate[3]),"hover").text,M.push("value: "+w.valueLabel),u.textLabel&&M.push(u.textLabel),y=M.join("<br>")):y=u.textLabel;var S={x:u.traceCoordinate[0],y:u.traceCoordinate[1],z:u.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:_};p.appendArrayPointValue(S,b,_),e._module.eventData&&(S=b._module.eventData(S,u,b,{},_));var E={points:[S]};t.fullSceneLayout.hovermode&&p.loneHover({trace:b,x:(.5+.5*m[0]/m[3])*i,y:(.5-.5*m[1]/m[3])*o,xLabel:w.xLabel,yLabel:w.yLabel,zLabel:w.zLabel,text:y,name:c.name,color:p.castHoverOption(b,_,"bgcolor")||c.color,borderColor:p.castHoverOption(b,_,"bordercolor"),fontFamily:p.castHoverOption(b,_,"font.family"),fontSize:p.castHoverOption(b,_,"font.size"),fontColor:p.castHoverOption(b,_,"font.color"),nameLength:p.castHoverOption(b,_,"namelength"),textAlign:p.castHoverOption(b,_,"align"),hovertemplate:h.castOption(b,_,"hovertemplate"),hovertemplateLabels:h.extendFlat({},S,w),eventData:[S]},{container:n,gd:r}),u.buttons&&u.distance<5?r.emit("plotly_click",E):r.emit("plotly_hover",E),s=E}else p.loneUnhover(n),r.emit("plotly_unhover",s);t.drawAnnotations(t)}.bind(null,t),t.traces={},t.make4thDimension(),!0}function _(t,e){var r=document.createElement("div"),n=t.container;this.graphDiv=t.graphDiv;var a=document.createElementNS("http://www.w3.org/2000/svg","svg");a.style.position="absolute",a.style.top=a.style.left="0px",a.style.width=a.style.height="100%",a.style["z-index"]=20,a.style["pointer-events"]="none",r.appendChild(a),this.svgContainer=a,r.id=t.id,r.style.position="absolute",r.style.top=r.style.left="0px",r.style.width=r.style.height="100%",n.appendChild(r),this.fullLayout=e,this.id=t.id||"scene",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=m(e,e[this.id]),this.spikeOptions=y(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=u.getComponentMethod("annotations3d","convert"),this.drawAnnotations=u.getComponentMethod("annotations3d","draw"),b(this)}var w=_.prototype;w.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e="orthographic"===t.projection.type;this.camera=o(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:"orbit"})},w.recoverContext=function(){var t=this,e=this.glplot.gl,r=this.glplot.canvas;this.glplot.dispose(),requestAnimationFrame(function n(){e.isContextLost()?requestAnimationFrame(n):b(t,r,e)?t.plot.apply(t,t.plotArgs):h.error("Catastrophic and unrecoverable WebGL error. Context lost.")})};var k=["xaxis","yaxis","zaxis"];function T(t,e,r){for(var n=t.fullSceneLayout,a=0;a<3;a++){var i=k[a],o=i.charAt(0),s=n[i],l=e[o],c=e[o+"calendar"],u=e["_"+o+"length"];if(h.isArrayOrTypedArray(l))for(var f,p=0;p<(u||l.length);p++)if(h.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][a]=Math.min(r[0][a],f),r[1][a]=Math.max(r[1][a],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][a]=Math.min(r[0][a],f),r[1][a]=Math.max(r[1][a],f));else r[0][a]=Math.min(r[0][a],0),r[1][a]=Math.max(r[1][a],u-1)}}w.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,a,i,o,s,l,c=e[this.id],u=r[this.id];c.bgcolor?this.glplot.clearColor=d(c.bgcolor):this.glplot.clearColor=[0,0,0,0],this.glplot.snapToData=!0,this.fullLayout=e,this.fullSceneLayout=c,this.glplotLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setViewport(c),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.update({}),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(i=0;i<t.length;++i)!0===(n=t[i]).visible&&0!==n._length&&T(this,n,h);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],a=0;a<3;a++)for(var i=k[a],o=i.charAt(0),s=r[i],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][a]=Math.min(e[0][a],u),e[1][a]=Math.max(e[1][a],u))}}}(this,h);var f=[1,1,1];for(o=0;o<3;++o)h[1][o]===h[0][o]?f[o]=1:f[o]=1/(h[1][o]-h[0][o]);for(this.dataScale=f,this.convertAnnotations(this),i=0;i<t.length;++i)!0===(n=t[i]).visible&&0!==n._length&&((a=this.traces[n.uid])?a.data.type===n.type?a.update(n):(a.dispose(),a=n._module.plot(this,n),this.traces[n.uid]=a):(a=n._module.plot(this,n),this.traces[n.uid]=a),a.name=n.name);var p=Object.keys(this.traces);t:for(i=0;i<p.length;++i){for(o=0;o<t.length;++o)if(t[o].uid===p[i]&&!0===t[o].visible&&0!==t[o]._length)continue t;(a=this.traces[p[i]]).dispose(),delete this.traces[p[i]]}this.glplot.objects.sort(function(t,e){return t._trace.data.index-e._trace.data.index});var g=[[0,0,0],[0,0,0]],v=[],m={};for(i=0;i<3;++i){if((l=(s=c[k[i]]).type)in m?(m[l].acc*=f[i],m[l].count+=1):m[l]={acc:f[i],count:1},s.autorange){g[0][i]=1/0,g[1][i]=-1/0;var y=this.glplot.objects,x=this.fullSceneLayout.annotations||[],b=s._name.charAt(0);for(o=0;o<y.length;o++){var _=y[o],w=_.bounds,A=_._trace.data._pad||0;"ErrorBars"===_.constructor.name&&s._lowerLogErrorBound?g[0][i]=Math.min(g[0][i],s._lowerLogErrorBound):g[0][i]=Math.min(g[0][i],w[0][i]/f[i]-A),g[1][i]=Math.max(g[1][i],w[1][i]/f[i]+A)}for(o=0;o<x.length;o++){var M=x[o];if(M.visible){var S=s.r2l(M[b]);g[0][i]=Math.min(g[0][i],S),g[1][i]=Math.max(g[1][i],S)}}if("rangemode"in s&&"tozero"===s.rangemode&&(g[0][i]=Math.min(g[0][i],0),g[1][i]=Math.max(g[1][i],0)),g[0][i]>g[1][i])g[0][i]=-1,g[1][i]=1;else{var E=g[1][i]-g[0][i];g[0][i]-=E/32,g[1][i]+=E/32}if("reversed"===s.autorange){var L=g[0][i];g[0][i]=g[1][i],g[1][i]=L}}else{var C=s.range;g[0][i]=s.r2l(C[0]),g[1][i]=s.r2l(C[1])}g[0][i]===g[1][i]&&(g[0][i]-=1,g[1][i]+=1),v[i]=g[1][i]-g[0][i],this.glplot.bounds[0][i]=g[0][i]*f[i],this.glplot.bounds[1][i]=g[1][i]*f[i]}var P=[1,1,1];for(i=0;i<3;++i){var O=m[l=(s=c[k[i]]).type];P[i]=Math.pow(O.acc,1/O.count)/f[i]}var z;if("auto"===c.aspectmode)z=Math.max.apply(null,P)/Math.min.apply(null,P)<=4?P:[1,1,1];else if("cube"===c.aspectmode)z=[1,1,1];else if("data"===c.aspectmode)z=P;else{if("manual"!==c.aspectmode)throw new Error("scene.js aspectRatio was not one of the enumerated types");var I=c.aspectratio;z=[I.x,I.y,I.z]}c.aspectratio.x=u.aspectratio.x=z[0],c.aspectratio.y=u.aspectratio.y=z[1],c.aspectratio.z=u.aspectratio.z=z[2],this.glplot.setAspectratio(c.aspectratio),this.viewInitial.aspectratio||(this.viewInitial.aspectratio={x:c.aspectratio.x,y:c.aspectratio.y,z:c.aspectratio.z});var D=c.domain||null,R=e._size||null;if(D&&R){var F=this.container.style;F.position="absolute",F.left=R.l+D.x[0]*R.w+"px",F.top=R.t+(1-D.y[1])*R.h+"px",F.width=R.w*(D.x[1]-D.x[0])+"px",F.height=R.h*(D.y[1]-D.y[0])+"px"}this.glplot.redraw()}},w.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener("wheel",this.camera.wheelListener),this.camera=this.glplot.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},w.getCamera=function(){return this.glplot.camera.view.recalcMatrix(this.camera.view.lastT()),{up:{x:(t=this.glplot.camera).up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?"orthographic":"perspective"}};var t},w.setViewport=function(t){var e,r=t.camera;this.glplot.camera.lookAt.apply(this,[[(e=r).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]),this.glplot.setAspectratio(t.aspectratio);var n="orthographic"===r.projection.type;if(n!==this.glplot.camera._ortho){this.glplot.redraw();var a=this.glplot.clearColor;this.glplot.gl.clearColor(a[0],a[1],a[2],a[3]),this.glplot.gl.clear(this.glplot.gl.DEPTH_BUFFER_BIT|this.glplot.gl.COLOR_BUFFER_BIT),this.glplot.dispose(),b(this),this.glplot.camera._ortho=n}},w.isCameraChanged=function(t){var e=this.getCamera(),r=h.nestedProperty(t,this.id+".camera").get();function n(t,e,r,n){var a=["up","center","eye"],i=["x","y","z"];return e[a[r]]&&t[a[r]][i[n]]===e[a[r]][i[n]]}var a=!1;if(void 0===r)a=!0;else{for(var i=0;i<3;i++)for(var o=0;o<3;o++)if(!n(e,r,i,o)){a=!0;break}(!r.projection||e.projection&&e.projection.type!==r.projection.type)&&(a=!0)}return a},w.isAspectChanged=function(t){var e=this.glplot.getAspectratio(),r=h.nestedProperty(t,this.id+".aspectratio").get();return void 0===r||r.x!==e.x||r.y!==e.y||r.z!==e.z},w.saveLayout=function(t){var e,r,n,a,i,o,s=this.fullLayout,l=this.isCameraChanged(t),c=this.isAspectChanged(t),f=l||c;if(f){var p={};if(l&&(e=this.getCamera(),n=(r=h.nestedProperty(t,this.id+".camera")).get(),p[this.id+".camera"]=n),c&&(a=this.glplot.getAspectratio(),o=(i=h.nestedProperty(t,this.id+".aspectratio")).get(),p[this.id+".aspectratio"]=o),u.call("_storeDirectGUIEdit",t,s._preGUI,p),l)r.set(e),h.nestedProperty(s,this.id+".camera").set(e);if(c)i.set(a),h.nestedProperty(s,this.id+".aspectratio").set(a),this.glplot.redraw()}return f},w.updateFx=function(t,e){var r=this.camera;if(r)if("orbit"===t)r.mode="orbit",r.keyBindingMode="rotate";else if("turntable"===t){r.up=[0,0,1],r.mode="turntable",r.keyBindingMode="rotate";var n=this.graphDiv,a=n._fullLayout,i=this.fullSceneLayout.camera,o=i.up.x,s=i.up.y,l=i.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var c=this.id+".camera.up",f={x:0,y:0,z:1},p={};p[c]=f;var d=n.layout;u.call("_storeDirectGUIEdit",d,a._preGUI,p),i.up=f,h.nestedProperty(d,c).set(f)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},w.toImage=function(t){t||(t="png"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,a=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var i=new Uint8Array(r*a*4);e.readPixels(0,0,r,a,e.RGBA,e.UNSIGNED_BYTE,i);for(var o=0,s=a-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=i[4*(r*o+l)+c];i[4*(r*o+l)+c]=i[4*(r*s+l)+c],i[4*(r*s+l)+c]=u}var h=document.createElement("canvas");h.width=r,h.height=a;var f,p=h.getContext("2d"),d=p.createImageData(r,a);switch(d.data.set(i),p.putImageData(d,0,0),t){case"jpeg":f=h.toDataURL("image/jpeg");break;case"webp":f=h.toDataURL("image/webp");break;default:f=h.toDataURL("image/png")}return this.staticMode&&this.container.removeChild(n),f},w.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[k[t]];f.setConvert(e,this.fullLayout),e.setScale=h.noop}},w.make4thDimension=function(){var t=this.graphDiv._fullLayout;this.mockAxis={type:"linear",showexponent:"all",exponentformat:"B"},f.setConvert(this.mockAxis,t)},e.exports=_},{"../../components/fx":629,"../../lib":716,"../../lib/show_no_webgl_msg":737,"../../lib/str2rgbarray":739,"../../plots/cartesian/axes":764,"../../registry":845,"./layout/convert":808,"./layout/spikes":811,"./layout/tick_marks":812,"./project":813,"gl-plot3d":292,"has-passive-events":412,"webgl-context":554}],815:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){n=n||t.length;for(var a=new Array(n),i=0;i<n;i++)a[i]=[t[i],e[i],r[i]];return a}},{}],816:[function(t,e,r){"use strict";var n=t("./font_attributes"),a=t("./animation_attributes"),i=t("../components/color/attributes"),o=t("./pad_attributes"),s=t("../lib/extend").extendFlat,l=n({editType:"calc"});l.family.dflt='"Open Sans", verdana, arial, sans-serif',l.size.dflt=12,l.color.dflt=i.defaultLine,e.exports={font:l,title:{text:{valType:"string",editType:"layoutstyle"},font:n({editType:"layoutstyle"}),xref:{valType:"enumerated",dflt:"container",values:["container","paper"],editType:"layoutstyle"},yref:{valType:"enumerated",dflt:"container",values:["container","paper"],editType:"layoutstyle"},x:{valType:"number",min:0,max:1,dflt:.5,editType:"layoutstyle"},y:{valType:"number",min:0,max:1,dflt:"auto",editType:"layoutstyle"},xanchor:{valType:"enumerated",dflt:"auto",values:["auto","left","center","right"],editType:"layoutstyle"},yanchor:{valType:"enumerated",dflt:"auto",values:["auto","top","middle","bottom"],editType:"layoutstyle"},pad:s(o({editType:"layoutstyle"}),{}),editType:"layoutstyle"},autosize:{valType:"boolean",dflt:!1,editType:"none"},width:{valType:"number",min:10,dflt:700,editType:"plot"},height:{valType:"number",min:10,dflt:450,editType:"plot"},margin:{l:{valType:"number",min:0,dflt:80,editType:"plot"},r:{valType:"number",min:0,dflt:80,editType:"plot"},t:{valType:"number",min:0,dflt:100,editType:"plot"},b:{valType:"number",min:0,dflt:80,editType:"plot"},pad:{valType:"number",min:0,dflt:0,editType:"plot"},autoexpand:{valType:"boolean",dflt:!0,editType:"plot"},editType:"plot"},paper_bgcolor:{valType:"color",dflt:i.background,editType:"plot"},plot_bgcolor:{valType:"color",dflt:i.background,editType:"layoutstyle"},separators:{valType:"string",editType:"plot"},hidesources:{valType:"boolean",dflt:!1,editType:"plot"},showlegend:{valType:"boolean",editType:"legend"},colorway:{valType:"colorlist",dflt:i.defaults,editType:"calc"},datarevision:{valType:"any",editType:"calc"},uirevision:{valType:"any",editType:"none"},editrevision:{valType:"any",editType:"none"},selectionrevision:{valType:"any",editType:"none"},template:{valType:"any",editType:"calc"},modebar:{orientation:{valType:"enumerated",values:["v","h"],dflt:"h",editType:"modebar"},bgcolor:{valType:"color",editType:"modebar"},color:{valType:"color",editType:"modebar"},activecolor:{valType:"color",editType:"modebar"},uirevision:{valType:"any",editType:"none"},editType:"modebar"},meta:{valType:"any",arrayOk:!0,editType:"plot"},transition:s({},a.transition,{editType:"none"}),_deprecated:{title:{valType:"string",editType:"layoutstyle"},titlefont:n({editType:"layoutstyle"})}}},{"../components/color/attributes":590,"../lib/extend":707,"./animation_attributes":759,"./font_attributes":790,"./pad_attributes":824}],817:[function(t,e,r){"use strict";var n={"open-street-map":{id:"osm",version:8,sources:{"plotly-osm-tiles":{type:"raster",attribution:'<a href="http://www.openstreetmap.org/about/" target="_blank">\xa9 OpenStreetMap</a>',tiles:["https://a.tile.openstreetmap.org/{z}/{x}/{y}.png","https://b.tile.openstreetmap.org/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-osm-tiles",type:"raster",source:"plotly-osm-tiles",minzoom:0,maxzoom:22}]},"white-bg":{id:"white-bg",version:8,sources:{},layers:[{id:"white-bg",type:"background",paint:{"background-color":"#FFFFFF"},minzoom:0,maxzoom:22}]},"carto-positron":{id:"carto-positron",version:8,sources:{"plotly-carto-positron":{type:"raster",attribution:'<a href="https://carto.com/" target="_blank">\xa9 CARTO</a>',tiles:["https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-carto-positron",type:"raster",source:"plotly-carto-positron",minzoom:0,maxzoom:22}]},"carto-darkmatter":{id:"carto-darkmatter",version:8,sources:{"plotly-carto-darkmatter":{type:"raster",attribution:'<a href="https://carto.com/" target="_blank">\xa9 CARTO</a>',tiles:["https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-carto-darkmatter",type:"raster",source:"plotly-carto-darkmatter",minzoom:0,maxzoom:22}]},"stamen-terrain":{id:"stamen-terrain",version:8,sources:{"plotly-stamen-terrain":{type:"raster",attribution:'Map tiles by <a href="http://stamen.com">Stamen Design</a>, under <a href="http://creativecommons.org/licenses/by/3.0">CC BY 3.0</a> | Data by <a href="http://openstreetmap.org">OpenStreetMap</a>, under <a href="http://www.openstreetmap.org/copyright">ODbL</a>.',tiles:["https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-stamen-terrain",type:"raster",source:"plotly-stamen-terrain",minzoom:0,maxzoom:22}]},"stamen-toner":{id:"stamen-toner",version:8,sources:{"plotly-stamen-toner":{type:"raster",attribution:'Map tiles by <a href="http://stamen.com">Stamen Design</a>, under <a href="http://creativecommons.org/licenses/by/3.0">CC BY 3.0</a> | Data by <a href="http://openstreetmap.org">OpenStreetMap</a>, under <a href="http://www.openstreetmap.org/copyright">ODbL</a>.',tiles:["https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-stamen-toner",type:"raster",source:"plotly-stamen-toner",minzoom:0,maxzoom:22}]},"stamen-watercolor":{id:"stamen-watercolor",version:8,sources:{"plotly-stamen-watercolor":{type:"raster",attribution:'Map tiles by <a href="http://stamen.com">Stamen Design</a>, under <a href="http://creativecommons.org/licenses/by/3.0">CC BY 3.0</a> | Data by <a href="http://openstreetmap.org">OpenStreetMap</a>, under <a href="http://creativecommons.org/licenses/by-sa/3.0">CC BY SA</a>.',tiles:["https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png"],tileSize:256}},layers:[{id:"plotly-stamen-watercolor",type:"raster",source:"plotly-stamen-watercolor",minzoom:0,maxzoom:22}]}},a=Object.keys(n);e.exports={requiredVersion:"1.3.2",styleUrlPrefix:"mapbox://styles/mapbox/",styleUrlSuffix:"v9",styleValuesMapbox:["basic","streets","outdoors","light","dark","satellite","satellite-streets"],styleValueDflt:"basic",stylesNonMapbox:n,styleValuesNonMapbox:a,traceLayerPrefix:"plotly-trace-layer-",layoutLayerPrefix:"plotly-layout-layer-",wrongVersionErrorMsg:["Your custom plotly.js bundle is not using the correct mapbox-gl version","Please install mapbox-gl@1.3.2."].join("\n"),noAccessTokenErrorMsg:["Missing Mapbox access token.","Mapbox trace type require a Mapbox access token to be registered.","For example:","  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });","More info here: https://www.mapbox.com/help/define-access-token/"].join("\n"),missingStyleErrorMsg:["No valid mapbox style found, please set `mapbox.style` to one of:",a.join(", "),"or register a Mapbox access token to use a Mapbox-served style."].join("\n"),multipleTokensErrorMsg:["Set multiple mapbox access token across different mapbox subplot,","using first token found as mapbox-gl does not allow multipleaccess tokens on the same page."].join("\n"),mapOnErrorMsg:"Mapbox error.",mapboxLogo:{path0:"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z",path1:"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z",path2:"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z",polygon:"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34"},styleRules:{map:"overflow:hidden;position:relative;","missing-css":"display:none;",canary:"background-color:salmon;","ctrl-bottom-left":"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;","ctrl-bottom-right":"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;",ctrl:"clear: both; pointer-events: auto; transform: translate(0, 0);","ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner":"display: none;","ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner":"display: block; margin-top:2px","ctrl-attrib.mapboxgl-compact:hover":"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;","ctrl-attrib.mapboxgl-compact::after":'content: ""; cursor: pointer; position: absolute; background-image: url(\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg"%3E %3Cpath fill="%23333333" fill-rule="evenodd" d="M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0"/%3E %3C/svg%3E\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',"ctrl-attrib.mapboxgl-compact":"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;","ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after":"bottom: 0; right: 0","ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after":"bottom: 0; left: 0","ctrl-bottom-left .mapboxgl-ctrl":"margin: 0 0 10px 10px; float: left;","ctrl-bottom-right .mapboxgl-ctrl":"margin: 0 10px 10px 0; float: right;","ctrl-attrib":"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px","ctrl-attrib a":"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px","ctrl-attrib a:hover":"color: inherit; text-decoration: underline;","ctrl-attrib .mapbox-improve-map":"font-weight: bold; margin-left: 2px;","attrib-empty":"display: none;","ctrl-logo":'display:block; width: 21px; height: 21px; background-image: url(\'data:image/svg+xml;charset=utf-8,%3C?xml version="1.0" encoding="utf-8"?%3E %3Csvg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 21 21" style="enable-background:new 0 0 21 21;" xml:space="preserve"%3E%3Cg transform="translate(0,0.01)"%3E%3Cpath d="m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z" style="opacity:0.9;fill:%23ffffff;enable-background:new" class="st0"/%3E%3Cpath d="M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z" style="opacity:0.35;enable-background:new" class="st1"/%3E%3Cpath d="M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z" style="opacity:0.35;enable-background:new" class="st1"/%3E%3Cpolygon points="11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 " style="opacity:0.9;fill:%23ffffff;enable-background:new" class="st0"/%3E%3C/g%3E%3C/svg%3E\')'}}},{}],818:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){var r=t.split(" "),a=r[0],i=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=["",""],u=[0,0];switch(a){case"top":c[0]="top",u[1]=-l;break;case"bottom":c[0]="bottom",u[1]=l}switch(i){case"left":c[1]="right",u[0]=-s;break;case"right":c[1]="left",u[0]=s}return{anchor:c[0]&&c[1]?c.join("-"):c[0]?c[0]:c[1]?c[1]:"center",offset:u}}},{"../../lib":716}],819:[function(t,e,r){"use strict";var n=t("mapbox-gl"),a=t("../../lib"),i=t("../../plots/get_data").getSubplotCalcData,o=t("../../constants/xmlns_namespaces"),s=t("d3"),l=t("../../components/drawing"),c=t("../../lib/svg_text_utils"),u=t("./mapbox"),h=r.constants=t("./constants");function f(t){return"string"==typeof t&&(-1!==h.styleValuesMapbox.indexOf(t)||0===t.indexOf("mapbox://"))}r.name="mapbox",r.attr="subplot",r.idRoot="mapbox",r.idRegex=r.attrRegex=a.counterRegex("mapbox"),r.attributes={subplot:{valType:"subplotid",dflt:"mapbox",editType:"calc"}},r.layoutAttributes=t("./layout_attributes"),r.supplyLayoutDefaults=t("./layout_defaults"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==h.requiredVersion)throw new Error(h.wrongVersionErrorMsg);var s=function(t,e){var r=t._fullLayout;if(""===t._context.mapboxAccessToken)return"";for(var n=[],i=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;f(c.style)&&(u?a.pushUnique(n,u):(f(c._input.style)&&(a.error("Uses Mapbox map style, but did not set an access token."),o=!0),s=!0)),u&&a.pushUnique(i,u)}if(s){var p=o?h.noAccessTokenErrorMsg:h.missingStyleErrorMsg;throw new Error(p)}return n.length?(n.length>1&&a.warn(h.multipleTokensErrorMsg),n[0]):(i.length&&a.log(["Listed mapbox access token(s)",i.join(","),"but did not use a Mapbox map style, ignoring token(s)."].join(" ")),"")}(t,o);n.accessToken=s;for(var l=0;l<o.length;l++){var c=o[l],p=i(r,"mapbox",c),d=e[c],g=d._subplot;g||(g=new u(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:a.extendFlat({},d.center),zoom:d.zoom,bearing:d.bearing,pitch:d.pitch}),g.plot(p,e,t._promises)}},r.clean=function(t,e,r,n){for(var a=n._subplots.mapbox||[],i=0;i<a.length;i++){var o=a[i];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,a=0;a<r.length;a++){var i=e[r[a]],u=i.domain,f=i._subplot.toImage("png");e._glimages.append("svg:image").attr({xmlns:o.svg,"xlink:href":f,x:n.l+n.w*u.x[0],y:n.t+n.h*(1-u.y[1]),width:n.w*(u.x[1]-u.x[0]),height:n.h*(u.y[1]-u.y[0]),preserveAspectRatio:"none"});var p=s.select(i._subplot.div);if(!(null===p.select(".mapboxgl-ctrl-logo").node().offsetParent)){var d=e._glimages.append("g");d.attr("transform","translate("+(n.l+n.w*u.x[0]+10)+", "+(n.t+n.h*(1-u.y[0])-31)+")"),d.append("path").attr("d",h.mapboxLogo.path0).style({opacity:.9,fill:"#ffffff","enable-background":"new"}),d.append("path").attr("d",h.mapboxLogo.path1).style("opacity",.35).style("enable-background","new"),d.append("path").attr("d",h.mapboxLogo.path2).style("opacity",.35).style("enable-background","new"),d.append("polygon").attr("points",h.mapboxLogo.polygon).style({opacity:.9,fill:"#ffffff","enable-background":"new"})}var g=p.select(".mapboxgl-ctrl-attrib").text().replace("Improve this map",""),v=e._glimages.append("g"),m=v.append("text");m.text(g).classed("static-attribution",!0).attr({"font-size":12,"font-family":"Arial",color:"rgba(0, 0, 0, 0.75)","text-anchor":"end","data-unformatted":g});var y=l.bBox(m.node()),x=n.w*(u.x[1]-u.x[0]);if(y.width>x/2){var b=g.split("|").join("<br>");m.text(b).attr("data-unformatted",b).call(c.convertToTspans,t),y=l.bBox(m.node())}m.attr("transform","translate(-3, "+(8-y.height)+")"),v.insert("rect",".static-attribution").attr({x:-y.width-6,y:-y.height-3,width:y.width+6,height:y.height+3,fill:"rgba(255, 255, 255, 0.75)"});var _=1;y.width+6>x&&(_=x/(y.width+6));var w=[n.l+n.w*u.x[1],n.t+n.h*(1-u.y[0])];v.attr("transform","translate("+w[0]+","+w[1]+") scale("+_+")")}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{"../../components/drawing":612,"../../constants/xmlns_namespaces":693,"../../lib":716,"../../lib/svg_text_utils":740,"../../plots/get_data":799,"./constants":817,"./layout_attributes":821,"./layout_defaults":822,"./mapbox":823,d3:164,"mapbox-gl":427}],820:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./convert_text_opts"),i=t("./constants");function o(t,e){this.subplot=t,this.uid=t.uid+"-"+e,this.index=e,this.idSource="source-"+this.uid,this.idLayer=i.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var s=o.prototype;function l(t){if(!t.visible)return!1;var e=t.source;if(Array.isArray(e)&&e.length>0){for(var r=0;r<e.length;r++)if("string"!=typeof e[r]||0===e[r].length)return!1;return!0}return n.isPlainObject(e)||"string"==typeof e&&e.length>0}function c(t){var e={},r={};switch(t.type){case"circle":n.extendFlat(r,{"circle-radius":t.circle.radius,"circle-color":t.color,"circle-opacity":t.opacity});break;case"line":n.extendFlat(r,{"line-width":t.line.width,"line-color":t.color,"line-opacity":t.opacity,"line-dasharray":t.line.dash});break;case"fill":n.extendFlat(r,{"fill-color":t.color,"fill-outline-color":t.fill.outlinecolor,"fill-opacity":t.opacity});break;case"symbol":var i=t.symbol,o=a(i.textposition,i.iconsize);n.extendFlat(e,{"icon-image":i.icon+"-15","icon-size":i.iconsize/10,"text-field":i.text,"text-size":i.textfont.size,"text-anchor":o.anchor,"text-offset":o.offset,"symbol-placement":i.placement}),n.extendFlat(r,{"icon-color":t.color,"text-color":i.textfont.color,"text-opacity":t.opacity})}return{layout:e,paint:r}}s.update=function(t){this.visible?this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=l(t)},s.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},s.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup["layout-"+this.index]},s.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,l(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,a={type:r};"geojson"===r?e="data":"vector"===r?e="string"==typeof n?"url":"tiles":"raster"===r?(e="tiles",a.tileSize=256):"image"===r&&(e="url",a.coordinates=t.coordinates);a[e]=n,t.sourceattribution&&(a.attribution=t.sourceattribution);return a}(t);e.addSource(this.idSource,r)}},s.updateLayer=function(t){var e,r=this.subplot,n=c(t),a=this.subplot.belowLookup["layout-"+this.index];if("traces"===a)for(var o=r.getMapLayers(),s=0;s<o.length;s++){var u=o[s].id;if("string"==typeof u&&0===u.indexOf(i.traceLayerPrefix)){e=u;break}}else e=a;this.removeLayer(),l(t)&&r.addLayer({id:this.idLayer,source:this.idSource,"source-layer":t.sourcelayer||"",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:n.layout,paint:n.paint},e),this.layerType=t.type,this.below=a},s.updateStyle=function(t){if(l(t)){var e=c(t);this.subplot.setOptions(this.idLayer,"setLayoutProperty",e.layout),this.subplot.setOptions(this.idLayer,"setPaintProperty",e.paint)}},s.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},s.dispose=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer),t.getSource(this.idSource)&&t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new o(t,e);return n.update(r),n}},{"../../lib":716,"./constants":817,"./convert_text_opts":818}],821:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color").defaultLine,i=t("../domain").attributes,o=t("../font_attributes"),s=t("../../traces/scatter/attributes").textposition,l=t("../../plot_api/edit_types").overrideAll,c=t("../../plot_api/plot_template").templatedArray,u=t("./constants"),h=o({});h.family.dflt="Open Sans Regular, Arial Unicode MS Regular",(e.exports=l({_arrayAttrRegexps:[n.counterRegex("mapbox",".layers",!0)],domain:i({name:"mapbox"}),accesstoken:{valType:"string",noBlank:!0,strict:!0},style:{valType:"any",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:"number",dflt:0},lat:{valType:"number",dflt:0}},zoom:{valType:"number",dflt:1},bearing:{valType:"number",dflt:0},pitch:{valType:"number",dflt:0},layers:c("layer",{visible:{valType:"boolean",dflt:!0},sourcetype:{valType:"enumerated",values:["geojson","vector","raster","image"],dflt:"geojson"},source:{valType:"any"},sourcelayer:{valType:"string",dflt:""},sourceattribution:{valType:"string"},type:{valType:"enumerated",values:["circle","line","fill","symbol","raster"],dflt:"circle"},coordinates:{valType:"any"},below:{valType:"string"},color:{valType:"color",dflt:a},opacity:{valType:"number",min:0,max:1,dflt:1},minzoom:{valType:"number",min:0,max:24,dflt:0},maxzoom:{valType:"number",min:0,max:24,dflt:24},circle:{radius:{valType:"number",dflt:15}},line:{width:{valType:"number",dflt:2},dash:{valType:"data_array"}},fill:{outlinecolor:{valType:"color",dflt:a}},symbol:{icon:{valType:"string",dflt:"marker"},iconsize:{valType:"number",dflt:10},text:{valType:"string",dflt:""},placement:{valType:"enumerated",values:["point","line","line-center"],dflt:"point"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},"plot","from-root")).uirevision={valType:"any",editType:"none"}},{"../../components/color":591,"../../lib":716,"../../plot_api/edit_types":747,"../../plot_api/plot_template":754,"../../traces/scatter/attributes":1118,"../domain":789,"../font_attributes":790,"./constants":817}],822:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../subplot_defaults"),i=t("../array_container_defaults"),o=t("./layout_attributes");function s(t,e,r,n){r("accesstoken",n.accessToken),r("style"),r("center.lon"),r("center.lat"),r("zoom"),r("bearing"),r("pitch"),i(t,e,{name:"layers",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,a){return n.coerce(t,e,o.layers,r,a)}if(r("visible")){var a,i=r("sourcetype"),s="raster"===i||"image"===i;r("source"),r("sourceattribution"),"vector"===i&&r("sourcelayer"),"image"===i&&r("coordinates"),s&&(a="raster");var l=r("type",a);s&&"raster"!==l&&(l=e.type="raster",n.log("Source types *raster* and *image* must drawn *raster* layer type.")),r("below"),r("color"),r("opacity"),r("minzoom"),r("maxzoom"),"circle"===l&&r("circle.radius"),"line"===l&&(r("line.width"),r("line.dash")),"fill"===l&&r("fill.outlinecolor"),"symbol"===l&&(r("symbol.icon"),r("symbol.iconsize"),r("symbol.text"),n.coerceFont(r,"symbol.textfont"),r("symbol.textposition"),r("symbol.placement"))}}e.exports=function(t,e,r){a(t,e,r,{type:"mapbox",attributes:o,handleDefaults:s,partition:"y",accessToken:e._mapboxAccessToken})}},{"../../lib":716,"../array_container_defaults":760,"../subplot_defaults":839,"./layout_attributes":821}],823:[function(t,e,r){"use strict";var n=t("mapbox-gl"),a=t("d3"),i=t("../../components/fx"),o=t("../../lib"),s=t("../../registry"),l=t("../cartesian/axes"),c=t("../../components/dragelement"),u=t("../cartesian/select").prepSelect,h=t("../cartesian/select").selectOnClick,f=t("./constants"),p=t("./layers");function d(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+"-"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={}}var g=d.prototype;g.plot=function(t,e,r){var n,a=this,i=e[a.id];a.map&&i.accesstoken!==a.accessToken&&(a.map.remove(),a.map=null,a.styleObj=null,a.traceHash=[],a.layerList={}),n=a.map?new Promise(function(r,n){a.updateMap(t,e,r,n)}):new Promise(function(r,n){a.createMap(t,e,r,n)}),r.push(n)},g.createMap=function(t,e,r,a){var i=this,o=e[i.id],s=i.styleObj=m(o.style);i.accessToken=o.accesstoken;var l=i.map=new n.Map({container:i.div,style:s.style,center:x(o.center),zoom:o.zoom,bearing:o.bearing,pitch:o.pitch,interactive:!i.isStatic,preserveDrawingBuffer:i.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));l._canvas.style.left="0px",l._canvas.style.top="0px",i.rejectOnError(a),i.isStatic||i.initFx(t,e);var c=[];c.push(new Promise(function(t){l.once("load",t)})),c=c.concat(i.fetchMapData(t,e)),Promise.all(c).then(function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)}).catch(a)},g.fetchMapData=function(t){var e=[];function r(t){return new Promise(function(e,r){a.json(t,function(n,a){if(n){delete PlotlyGeoAssets[t];var i=404===n.status?'GeoJSON at URL "'+t+'" does not exist.':"Unexpected error while fetching from "+t;return r(new Error(i))}PlotlyGeoAssets[t]=a,e(a)})})}for(var n=0;n<t.length;n++){var i=t[n][0].trace.geojson;"string"!=typeof i||PlotlyGeoAssets[i]||(PlotlyGeoAssets[i]="pending",e.push(r(i)))}return e},g.updateMap=function(t,e,r,n){var a=this,i=a.map,o=e[this.id];a.rejectOnError(n);var s=[],l=m(o.style);a.styleObj.id!==l.id&&(a.styleObj=l,i.setStyle(l.style),a.traceHash={},s.push(new Promise(function(t){i.once("styledata",t)}))),s=s.concat(a.fetchMapData(t,e)),Promise.all(s).then(function(){a.fillBelowLookup(t,e),a.updateData(t),a.updateLayout(e),a.resolveOnRender(r)}).catch(n)},g.fillBelowLookup=function(t,e){var r,n,a=e[this.id].layers,i=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;"string"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),""===n&&(o=!0),i["trace-"+s.uid]=n||""}for(r=0;r<a.length;r++){var c=a[r];n="string"==typeof c.below?c.below:o?"traces":"",i["layout-"+r]=n}var u,h,f={};for(u in i)f[n=i[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf("trace-")?(h=u.split("trace-")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf("layout-")&&(h=u.split("layout-")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var v={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function m(t){var e={};return o.isPlainObject(t)?(e.id=t.id,e.style=t):"string"==typeof t?(e.id=t,-1!==f.styleValuesMapbox.indexOf(t)?e.style=y(t):f.stylesNonMapbox[t]?e.style=f.stylesNonMapbox[t]:e.style=t):(e.id=f.styleValueDflt,e.style=y(f.styleValueDflt)),e.transition={duration:0,delay:0},e}function y(t){return f.styleUrlPrefix+t+"-"+f.styleUrlSuffix}function x(t){return[t.lon,t.lat]}g.updateData=function(t){var e,r,n,a,i=this.traceHash,o=t.slice().sort(function(t,e){return v[t[0].trace.type]-v[e[0].trace.type]});for(n=0;n<o.length;n++){var s=o[n],l=!1;(e=i[(r=s[0].trace).uid])&&(e.type===r.type?(e.update(s),l=!0):e.dispose()),!l&&r._module&&(i[r.uid]=r._module.plot(this,s))}var c=Object.keys(i);t:for(n=0;n<c.length;n++){var u=c[n];for(a=0;a<t.length;a++)if(u===(r=t[a][0].trace).uid)continue t;(e=i[u]).dispose(),delete i[u]}},g.updateLayout=function(t){var e=this.map,r=t[this.id];e.setCenter(x(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},g.resolveOnRender=function(t){var e=this.map;e.on("render",function r(){e.loaded()&&(e.off("render",r),setTimeout(t,10))})},g.rejectOnError=function(t){var e=this.map;function r(){t(new Error(f.mapOnErrorMsg))}e.once("error",r),e.once("style.error",r),e.once("source.error",r),e.once("tile.error",r),e.once("layer.error",r)},g.createFramework=function(t){var e=this,r=e.div=document.createElement("div");r.id=e.uid,r.style.position="absolute",e.container.appendChild(r),e.xaxis={_id:"x",c2p:function(t){return e.project(t).x}},e.yaxis={_id:"y",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:"linear",showexponent:"all",exponentformat:"B"},l.setConvert(e.mockAxis,t)},g.initFx=function(t,e){var r=this,n=r.gd,a=r.map,o=!1;function l(){i.loneUnhover(e._hoverlayer)}function c(){var t=r.getView();n.emit("plotly_relayouting",r.getViewEdits(t))}a.on("moveend",function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||o){var a=e[r.id];s.call("_storeDirectGUIEdit",n.layout,e._preGUI,r.getViewEdits(a));var i=r.getView();a._input.center=a.center=i.center,a._input.zoom=a.zoom=i.zoom,a._input.bearing=a.bearing=i.bearing,a._input.pitch=a.pitch=i.pitch,n.emit("plotly_relayout",r.getViewEdits(i))}o=!1,e._rehover&&e._rehover()}}),a.on("wheel",function(){o=!0}),a.on("mousemove",function(t){var e=r.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return t.lngLat.lng},r.yaxis.p2c=function(){return t.lngLat.lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&n._fullLayout[r.id]&&i.hover(n,t,r.id)},i.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id}),a.on("dragstart",l),a.on("zoomstart",l),a.on("mouseout",function(){n._fullLayout._hoversubplot=null}),a.on("drag",c),a.on("zoom",c),a.on("dblclick",function(){var t=n._fullLayout[r.id];s.call("_storeDirectGUIEdit",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;a.setCenter(x(e.center)),a.setZoom(e.zoom),a.setBearing(e.bearing),a.setPitch(e.pitch);var i=r.getView();t._input.center=t.center=i.center,t._input.zoom=t.zoom=i.zoom,t._input.bearing=t.bearing=i.bearing,t._input.pitch=t.pitch=i.pitch,n.emit("plotly_doubleclick",null),n.emit("plotly_relayout",r.getViewEdits(i))}),r.clearSelect=function(){n._fullLayout._zoomlayer.selectAll(".select-outline").remove()},r.onClickInPanFn=function(t){return function(e){var a=n._fullLayout.clickmode;a.indexOf("select")>-1&&h(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),a.indexOf("event")>-1&&i.click(n,e.originalEvent)}}},g.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var a,i=t.dragmode;a="select"===i?function(t,r){(t.range={})[e.id]=[l([r.xmin,r.ymin]),l([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(l)};var s=e.dragOptions;e.dragOptions=o.extendDeep(s||{},{element:e.div,gd:n,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:a},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off("click",e.onClickInPanHandler),"select"===i||"lasso"===i?(r.dragPan.disable(),r.on("zoomstart",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){u(t,r,n,e.dragOptions,i)},c.init(e.dragOptions)):(r.dragPan.enable(),r.off("zoomstart",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on("click",e.onClickInPanHandler))}function l(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},g.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+"px",n.height=r.h*(e.y[1]-e.y[0])+"px",n.left=r.l+e.x[0]*r.w+"px",n.top=r.t+(1-e.y[1])*r.h+"px",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},g.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(p(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},g.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},g.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},g.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},g.getMapLayers=function(){return this.map.getStyle().layers},g.addLayer=function(t,e){var r=this.map;if("string"==typeof e){if(""===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),a=0;a<n.length;a++)if(e===n[a].id)return void r.addLayer(t,e);o.warn(["Trying to add layer with *below* value",e,"referencing a layer that does not exist","or that does not yet exist."].join(" "))}r.addLayer(t)},g.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},g.getView=function(){var t=this.map,e=t.getCenter();return{center:{lon:e.lng,lat:e.lat},zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch()}},g.getViewEdits=function(t){for(var e=this.id,r=["center","zoom","bearing","pitch"],n={},a=0;a<r.length;a++){var i=r[a];n[e+"."+i]=t[i]}return n},e.exports=d},{"../../components/dragelement":609,"../../components/fx":629,"../../lib":716,"../../registry":845,"../cartesian/axes":764,"../cartesian/select":781,"./constants":817,"./layers":820,d3:164,"mapbox-gl":427}],824:[function(t,e,r){"use strict";e.exports=function(t){var e=t.editType;return{t:{valType:"number",dflt:0,editType:e},r:{valType:"number",dflt:0,editType:e},b:{valType:"number",dflt:0,editType:e},l:{valType:"number",dflt:0,editType:e},editType:e}}},{}],825:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../registry"),o=t("../plot_api/plot_schema"),s=t("../plot_api/plot_template"),l=t("../lib"),c=t("../components/color"),u=t("../constants/numerical").BADNUM,h=t("./cartesian/axis_ids"),f=t("./animation_attributes"),p=t("./frame_attributes"),d=t("../plots/get_data").getModuleCalcData,g=l.relinkPrivateKeys,v=l._,m=e.exports={};l.extendFlat(m,i),m.attributes=t("./attributes"),m.attributes.type.values=m.allTypes,m.fontAttrs=t("./font_attributes"),m.layoutAttributes=t("./layout_attributes"),m.fontWeight="normal";var y=m.transformsRegistry,x=t("./command");m.executeAPICommand=x.executeAPICommand,m.computeAPICommandBindings=x.computeAPICommandBindings,m.manageCommandObserver=x.manageCommandObserver,m.hasSimpleAPICommandBindings=x.hasSimpleAPICommandBindings,m.redrawText=function(t){var e=(t=l.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has("polar"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise(function(e){setTimeout(function(){i.getComponentMethod("annotations","draw")(t),i.getComponentMethod("legend","draw")(t),i.getComponentMethod("colorbar","draw")(t),e(m.previousPromises(t))},300)})},m.resize=function(t){return t=l.getGraphDiv(t),new Promise(function(e,r){t&&!l.isHidden(t)||r(new Error("Resize must be passed a displayed plot div element.")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._redrawTimer=setTimeout(function(){if(!t.layout||t.layout.width&&t.layout.height||l.isHidden(t))e(t);else{delete t.layout.width,delete t.layout.height;var r=t.changed;t.autoplay=!0,i.call("relayout",t,{autosize:!0}).then(function(){t.changed=r,e(t)})}},100)})},m.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then(function(){t._promises=[]})},m.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=l.ensureSingle(e._paper,"text","js-plot-link-container",function(t){t.style({"font-family":'"Open Sans", Arial, sans-serif',"font-size":"12px",fill:c.defaultLine,"pointer-events":"all"}).each(function(){var t=n.select(this);t.append("tspan").classed("js-link-to-tool",!0),t.append("tspan").classed("js-link-spacer",!0),t.append("tspan").classed("js-sourcelinks",!0)})}),a=r.node(),i={y:e._paper.attr("height")-9};document.body.contains(a)&&a.getComputedTextLength()>=e.width-20?(i["text-anchor"]="start",i.x=5):(i["text-anchor"]="end",i.x=e._paper.attr("width")-7),r.attr(i);var o=r.select(".js-link-to-tool"),s=r.select(".js-link-spacer"),u=r.select(".js-sourcelinks");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text("");var r=e.append("a").attr({"xlink:xlink:href":"#",class:"link--impt link--embedview","font-weight":"bold"}).text(t._context.linkText+" "+String.fromCharCode(187));if(t._context.sendData)r.on("click",function(){m.sendDataToCloud(t)});else{var n=window.location.pathname.split("/"),a=window.location.search;r.attr({"xlink:xlink:show":"new","xlink:xlink:href":"/"+n[2].split(".")[0]+"/"+n[1]+a})}}(t,o),s.text(o.text()&&u.text()?" - ":"")}},m.sendDataToCloud=function(t){t.emit("plotly_beforeexport");var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL,r=n.select(t).append("div").attr("id","hiddenform").style("display","none"),a=r.append("form").attr({action:e+"/external",method:"post",target:"_blank"});return a.append("input").attr({type:"text",name:"data"}).node().value=m.graphJson(t,!1,"keepdata"),a.node().submit(),r.remove(),t.emit("plotly_afterexport"),!1};var b=["days","shortDays","months","shortMonths","periods","dateTime","date","time","decimal","thousands","grouping","currency"],_=["year","month","dayMonth","dayMonthYear"];function w(t,e){var r=t._context.locale,n=!1,a={};function o(t){for(var r=!0,i=0;i<e.length;i++){var o=e[i];a[o]||(t[o]?a[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(o(u),n))break;l=i.localeRegistry}var h=r.split("-")[0];if(n||h===r)break;r=h}return n||o(i.localeRegistry.en.format),a}function k(t,e){var r={_fullLayout:e},n="x"===t._id.charAt(0),a=t._mainAxis._anchorAxis,i="",o="",s="";if(a&&(s=a._mainAxis._id,i=n?t._id+s:s+t._id),!i||!e._plots[i]){i="";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){i=f;break}}}return i||o}function T(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],a=n._module||y[n.type];if(a&&a.makesData)return!0}return!1}function A(t,e,r,n){for(var a=t.transforms,i=[t],o=0;o<a.length;o++){var s=a[o],l=y[s.type];l&&l.transform&&(i=l.transform(i,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return i}function M(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}m.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,a=t._fullLayout||{};if(a._skipDefaults)delete a._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],h=t._fullData=[],f=t.data||[],p=t.calcdata||[],d=t._context||{};t._transitionData||m.createTransitionData(t),s._dfltTitle={plot:v(t,"Click to enter Plot title"),x:v(t,"Click to enter X axis title"),y:v(t,"Click to enter Y axis title"),colorbar:v(t,"Click to enter Colorscale title"),annotation:v(t,"new text")},s._traceWord=v(t,"trace");var y=w(t,b);if(s._mapboxAccessToken=d.mapboxAccessToken,a._initialAutoSizeIsDone){var x=a.width,k=a.height;m.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=x),c.height||(s.height=k),m.sanitizeMargins(s)}else{m.supplyLayoutGlobalDefaults(c,s,y);var T=!c.width||!c.height,A=s.autosize,S=d.autosizable;T&&(A||S)?m.plotAutoSize(t,c,s):T&&m.sanitizeMargins(s),!A&&T&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),n.locale(t)}(y,s.separators),s._extraFormat=w(t,_),s._initialAutoSizeIsDone=!0,s._dataLength=f.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var E=s._subplots=function(){var t,e,r=i.collectableSubplotTypes,n={};if(!r){r=[];var a=i.subplotsRegistry;for(var o in a){var s=a[o],c=s.attr;if(c&&(r.push(o),Array.isArray(c)))for(e=0;e<c.length;e++)l.pushUnique(r,c[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),L=s._splomAxes={x:{},y:{}},C=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._alignmentOpts={},s._colorAxes={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,a=e.length,i=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&i.push(o),n=o}var s=i.length,c=new Array(a),u={};function h(t,e){c[e]=t,u[t]=1}function f(t,e){if(t&&"string"==typeof t&&!u[t])return h(t,e),!0}for(r=0;r<a;r++){var p=e[r].uid;"number"==typeof p&&(p=String(p)),f(p,r)||(r<s&&f(i[r].uid,r)||h(l.randstr(u),r))}return c}(u,f),s._globalTransforms=(t._context||{}).globalTransforms,m.supplyDataDefaults(f,h,c,s);var P=Object.keys(L.x),O=Object.keys(L.y);if(P.length>1&&O.length>1){for(i.getComponentMethod("grid","sizeDefaults")(c,s),o=0;o<P.length;o++)l.pushUnique(E.xaxis,P[o]);for(o=0;o<O.length;o++)l.pushUnique(E.yaxis,O[o]);for(var z in C)l.pushUnique(E.cartesian,z)}if(s._has=m._hasPlotType.bind(s),u.length===h.length)for(o=0;o<h.length;o++)g(h[o],u[o]);m.supplyLayoutModuleDefaults(c,s,h,t._transitionData);var I=s._visibleModules,D=[];for(o=0;o<I.length;o++){var R=I[o].crossTraceDefaults;R&&l.pushUnique(D,R)}for(o=0;o<D.length;o++)D[o](h,s);s._hasOnlyLargeSploms=1===s._basePlotModules.length&&"splom"===s._basePlotModules[0].name&&P.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,s._hasCartesian=s._has("cartesian"),s._hasGeo=s._has("geo"),s._hasGL3D=s._has("gl3d"),s._hasGL2D=s._has("gl2d"),s._hasTernary=s._has("ternary"),s._hasPie=s._has("pie"),m.linkSubplots(h,s,u,a),m.cleanPlot(h,s,u,a),a._zoomlayer&&!t._dragging&&a._zoomlayer.selectAll(".select-outline").remove(),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var a=0;a<t.length;a++){var i=t[a];i.meta?n[i.index]=i._meta={meta:i.meta}:e.meta&&(i._meta={meta:e.meta}),e.meta&&(i._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,s),g(s,a),i.getComponentMethod("colorscale","crossTraceDefaults")(h,s),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var F,B=s._tracePreGUI,N={};for(F in B)N[F]="old";for(o=0;o<h.length;o++)N[F=h[o]._fullInput.uid]||(B[F]={}),N[F]="new";for(F in N)"old"===N[F]&&delete B[F];M(s),i.getComponentMethod("rangeslider","makeData")(s),r||p.length!==h.length||m.supplyDefaultsUpdateCalc(p,h)}},m.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],a=(t[r]||[])[0];if(a&&a.trace){var i=a.trace;if(i._hasCalcTransform){var o,s,c,u=i._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],c=l.nestedProperty(i,s).get().slice(),l.nestedProperty(n,s).set(c)}a.trace=n}}},m.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},m._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var a=n[e].name;if(a===t)return!0;var o=i.modules[a];if(o&&o.categories[t])return!0}return!1},m.cleanPlot=function(t,e,r,n){var a,i,o=n._basePlotModules||[];for(a=0;a<o.length;a++){var s=o[a];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has("gl"),c=e._has&&e._has("gl");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(".gl-canvas").remove(),n._glcontainer.selectAll(".no-webgl").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(a=0;a<r.length;a++){var h=r[a].uid;for(i=0;i<t.length;i++){if(h===t[i].uid)continue t}u&&n._infolayer.select(".cb"+h).remove()}},m.linkSubplots=function(t,e,r,n){var a,o,s=n._plots||{},c=e._plots={},u=e._subplots,f={_fullData:t,_fullLayout:e},p=u.cartesian.concat(u.gl2d||[]);for(a=0;a<p.length;a++){var d,g=p[a],v=s[g],m=h.getFromId(f,g,"x"),y=h.getFromId(f,g,"y");for(v?d=c[g]=v:(d=c[g]={}).id=g,m._counterAxes.push(y._id),y._counterAxes.push(m._id),m._subplotsWith.push(g),y._subplotsWith.push(g),d.xaxis=m,d.yaxis=y,d._hasClipOnAxisFalse=!1,o=0;o<t.length;o++){var x=t[o];if(x.xaxis===d.xaxis._id&&x.yaxis===d.yaxis._id&&!1===x.cliponaxis){d._hasClipOnAxisFalse=!0;break}}}var b,_=h.list(f,null,!0);for(a=0;a<_.length;a++){var w=null;(b=_[a]).overlaying&&(w=h.getFromId(f,b.overlaying))&&w.overlaying&&(b.overlaying=!1,w=null),b._mainAxis=w||b,w&&(b.domain=w.domain.slice()),b._anchorAxis="free"===b.anchor?null:h.getFromId(f,b.anchor)}for(a=0;a<_.length;a++)if((b=_[a])._counterAxes.sort(h.idSort),b._subplotsWith.sort(l.subplotSort),b._mainSubplot=k(b,e),b._counterAxes.length&&(b.spikemode&&-1!==b.spikemode.indexOf("across")||b.automargin&&b.mirror&&"free"!==b.anchor||i.getComponentMethod("rangeslider","isVisible")(b))){var T=1,A=0;for(o=0;o<b._counterAxes.length;o++){var M=h.getFromId(f,b._counterAxes[o]);T=Math.min(T,M.domain[0]),A=Math.max(A,M.domain[1])}T<A&&(b._counterDomainMin=T,b._counterDomainMax=A)}},m.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],o.crawl(t._module.attributes,function(t,n,a,i){r[i]=n,r.length=i+1,"color"===t.valType&&void 0===t.dflt&&e.push(r.join("."))})),n=0;n<e.length;n++){l.nestedProperty(t,"_input."+e[n]).get()||l.nestedProperty(t,e[n]).set(null)}},m.supplyDataDefaults=function(t,e,r,n){var a,o,c,u=n._modules,h=n._visibleModules,f=n._basePlotModules,p=0,d=0;function v(t){e.push(t);var r=t._module;r&&(l.pushUnique(u,r),!0===t.visible&&l.pushUnique(h,r),l.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&d++)}n._transformModules=[];var y={},x=[],b=(r.template||{}).data||{},_=s.traceTemplater(b);for(a=0;a<t.length;a++){if(c=t[a],(o=_.newTrace(c)).uid=n._traceUids[a],m.supplyTraceDefaults(c,o,d,n,a),o.index=a,o._input=c,o._expandedIndex=p,o.transforms&&o.transforms.length)for(var w=!1!==c.visible&&!1===o.visible,k=A(o,e,r,n),T=0;T<k.length;T++){var M=k[T],S={_template:o._template,type:o.type,uid:o.uid+T};w&&!1===M.visible&&delete M.visible,m.supplyTraceDefaults(M,S,p,n,a),g(S,M),S.index=a,S._input=c,S._fullInput=o,S._expandedIndex=p,S._expandedInput=M,v(S)}else o._fullInput=o,o._expandedInput=o,v(o);i.traceIs(o,"carpetAxis")&&(y[o.carpet]=o),i.traceIs(o,"carpetDependent")&&x.push(a)}for(a=0;a<x.length;a++)if((o=e[x[a]]).visible){var E=y[o.carpet];o._carpet=E,E&&E.visible?(o.xaxis=E.xaxis,o.yaxis=E.yaxis):o.visible=!1}},m.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return l.coerce(t||{},r,f,e,n)}if(n("mode"),n("direction"),n("fromcurrent"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=m.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=m.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=m.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=m.supplyAnimationTransitionDefaults(t.transition||{});return r},m.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.frame,r,n)}return r("duration"),r("redraw"),e},m.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.transition,r,n)}return r("duration"),r("easing"),e},m.supplyFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t,e,p,r,n)}return r("group"),r("name"),r("traces"),r("baseframe"),r("data"),r("layout"),e},m.supplyTraceDefaults=function(t,e,r,n,a){var o,s=n.colorway||c.defaults,u=s[r%s.length];function h(r,n){return l.coerce(t,e,m.attributes,r,n)}var f=h("visible");h("type"),h("name",n._traceWord+" "+a),h("uirevision",n.uirevision);var p=m.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,v=d.attributes;if(g&&v){var y=n._subplots,x="";if("gl2d"!==d.name||f){if(Array.isArray(g))for(o=0;o<g.length;o++){var b=g[o],_=l.coerce(t,e,v,b);y[b]&&l.pushUnique(y[b],_),x+=_}else x=l.coerce(t,e,v,g);y[d.name]&&l.pushUnique(y[d.name],x)}}}return f&&(h("customdata"),h("ids"),h("meta"),i.traceIs(e,"showLegend")?(e._dfltShowLegend=!0,h("showlegend"),h("legendgroup")):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,u,n),i.traceIs(e,"noOpacity")||h("opacity"),i.traceIs(e,"notLegendIsolatable")&&(e.visible=!!e.visible),i.traceIs(e,"noHover")||(e.hovertemplate||l.coerceHoverinfo(t,e,n),"parcats"!==e.type&&i.getComponentMethod("fx","supplyDefaults")(t,e,u,n)),p&&p.selectPoints&&h("selectedpoints"),m.supplyTransformDefaults(t,e,n)),e},m.hasMakesDataTransform=T,m.supplyTransformDefaults=function(t,e,r){if(e._length||T(t)){var n=r._globalTransforms||[],a=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var i=t.transforms||[],o=n.concat(i),s=e.transforms=[],c=0;c<o.length;c++){var u,h=o[c],f=h.type,p=y[f],d=!(h._module&&h._module===p),g=p&&"function"==typeof p.transform;p||l.warn("Unrecognized transform type "+f+"."),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(h,e,r,t)).type=f,u._module=p,l.pushUnique(a,p)):u=l.extendFlat({},h),s.push(u)}}},m.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return l.coerce(t,e,m.layoutAttributes,r,n)}var a=t.template;l.isPlainObject(a)&&(e.template=a,e._template=a.layout,e._dataTemplate=a.data);var o=l.coerceFont(n,"font");n("title.text",e._dfltTitle.plot),l.coerceFont(n,"title.font",{family:o.family,size:Math.round(1.4*o.size),color:o.color}),n("title.xref"),n("title.yref"),n("title.x"),n("title.y"),n("title.xanchor"),n("title.yanchor"),n("title.pad.t"),n("title.pad.r"),n("title.pad.b"),n("title.pad.l"),n("autosize",!(t.width&&t.height)),n("width"),n("height"),n("margin.l"),n("margin.r"),n("margin.t"),n("margin.b"),n("margin.pad"),n("margin.autoexpand"),t.width&&t.height&&m.sanitizeMargins(e),i.getComponentMethod("grid","sizeDefaults")(t,e),n("paper_bgcolor"),n("separators",r.decimal+r.thousands),n("hidesources"),n("colorway"),n("datarevision");var s=n("uirevision");n("editrevision",s),n("selectionrevision",s),n("modebar.orientation"),n("modebar.bgcolor",c.addOpacity(e.paper_bgcolor,.5));var u=c.contrast(c.rgb(e.modebar.bgcolor));n("modebar.color",c.addOpacity(u,.3)),n("modebar.activecolor",c.addOpacity(u,.7)),n("modebar.uirevision",s),n("meta"),l.isPlainObject(t.transition)&&(n("transition.duration"),n("transition.easing"),n("transition.ordering")),i.getComponentMethod("calendars","handleDefaults")(t,e,"calendar"),i.getComponentMethod("fx","supplyLayoutGlobalDefaults")(t,e,n)},m.plotAutoSize=function(t,e,r){var n,i,o=t._context||{},s=o.frameMargins,c=l.isPlotDiv(t);if(c&&t.emit("plotly_autosize"),o.fillFrame)n=window.innerWidth,i=window.innerHeight,document.body.style.overflow="hidden";else{var u=c?window.getComputedStyle(t):{};if(n=parseFloat(u.width)||parseFloat(u.maxWidth)||r.width,i=parseFloat(u.height)||parseFloat(u.maxHeight)||r.height,a(s)&&s>0){var h=1-2*s;n=Math.round(h*n),i=Math.round(h*i)}}var f=m.layoutAttributes.width.min,p=m.layoutAttributes.height.min;n<f&&(n=f),i<p&&(i=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-i)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=i)),t._initialAutoSize||(t._initialAutoSize={width:n,height:i}),m.sanitizeMargins(r)},m.supplyLayoutModuleDefaults=function(t,e,r,n){var a,o,s,c=i.componentsRegistry,u=e._basePlotModules,h=i.subplotsRegistry.cartesian;for(a in c)(s=c[a]).includeBasePlot&&s.includeBasePlot(t,e);for(var f in u.length||u.push(h),e._has("cartesian")&&(i.getComponentMethod("grid","contentDefaults")(t,e),h.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(l.subplotSort);for(o=0;o<u.length;o++)(s=u[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(o=0;o<p.length;o++)(s=p[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(o=0;o<d.length;o++)(s=d[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(a in c)(s=c[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},m.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(".gl-canvas").remove(),e._glcontainer.remove(),e._glcanvas=null),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),l.clearThrottle(),l.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},m.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var a=r[e];a.style&&l.pushUnique(n,a.style)}for(e=0;e<n.length;e++)n[e](t)},m.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,a=t.margin,i=r-(a.l+a.r),o=n-(a.t+a.b);i<0&&(e=(r-1)/(a.l+a.r),a.l=Math.floor(e*a.l),a.r=Math.floor(e*a.r)),o<0&&(e=(n-1)/(a.t+a.b),a.t=Math.floor(e*a.t),a.b=Math.floor(e*a.b))}},m.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},m.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},m.autoMargin=function(t,e,r){var n=t._fullLayout,a=n._pushmargin,i=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(l.log("Margin push",e,"is too big in x, dropping"),r.l=r.r=0),r.b+r.t>.5*n.height&&(l.log("Margin push",e,"is too big in y, dropping"),r.b=r.t=0);var c=void 0!==r.xl?r.xl:r.x,u=void 0!==r.xr?r.xr:r.x,h=void 0!==r.yt?r.yt:r.y,f=void 0!==r.yb?r.yb:r.y;a[e]={l:{val:c,size:r.l+o},r:{val:u,size:r.r+o},b:{val:f,size:r.b+o},t:{val:h,size:r.t+o}},i[e]=1}else delete a[e],delete i[e];if(!n._replotting)return m.doAutoMargin(t)}},m.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),M(e);var r=e._size,n=e.margin,o=l.extendFlat({},r),s=n.l,c=n.r,u=n.t,h=n.b,f=e.width,p=e.height,d=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var v in d)g[v]||delete d[v];for(var y in d.base={l:{val:0,size:s},r:{val:1,size:c},t:{val:1,size:u},b:{val:0,size:h}},d){var x=d[y].l||{},b=d[y].b||{},_=x.val,w=x.size,k=b.val,T=b.size;for(var A in d){if(a(w)&&d[A].r){var S=d[A].r.val,E=d[A].r.size;if(S>_){var L=(w*S+(E-f)*_)/(S-_),C=(E*(1-_)+(w-f)*(1-S))/(S-_);L>=0&&C>=0&&f-(L+C)>0&&L+C>s+c&&(s=L,c=C)}}if(a(T)&&d[A].t){var P=d[A].t.val,O=d[A].t.size;if(P>k){var z=(T*P+(O-p)*k)/(P-k),I=(O*(1-k)+(T-p)*(1-P))/(P-k);z>=0&&I>=0&&p-(I+z)>0&&z+I>h+u&&(h=z,u=I)}}}}}if(r.l=Math.round(s),r.r=Math.round(c),r.t=Math.round(u),r.b=Math.round(h),r.p=Math.round(n.pad),r.w=Math.round(f)-r.l-r.r,r.h=Math.round(p)-r.t-r.b,!e._replotting&&m.didMarginChange(o,r)){"_redrawFromAutoMarginCount"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1;var D=3*(1+Object.keys(g).length);if(e._redrawFromAutoMarginCount<D)return i.call("plot",t);l.warn("Too many auto-margin redraws.")}};var S=["l","r","t","b","p","w","h"];function E(t,e,r){var n=!1;var a=[m.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,m.rehover,function(){return t.emit("plotly_transitioning",[]),new Promise(function(a){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push(function(){n=!0}),r.redraw&&t._transitionData._interruptCallbacks.push(function(){return i.call("redraw",t)}),t._transitionData._interruptCallbacks.push(function(){t.emit("plotly_transitioninterrupted",[])});var o=0,s=0;function l(){return o++,function(){var e;s++,n||s!==o||(e=a,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then(function(){if(r.redraw)return i.call("redraw",t)}).then(function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit("plotly_transitioned",[])}).then(e)))}}r.runFn(l),setTimeout(l())})}],o=l.syncOrAsync(a,t);return o&&o.then||(o=Promise.resolve()),o.then(function(){return t})}m.didMarginChange=function(t,e){for(var r=0;r<S.length;r++){var n=S[r],i=t[n],o=e[n];if(!a(i)||Math.abs(o-i)>1)return!0}return!1},m.graphJson=function(t,e,r,n,a){(a&&e&&!t._fullData||a&&!e&&!t._fullLayout)&&m.supplyDefaults(t);var i=a?t._fullData:t.data,o=a?t._fullLayout:t.layout,s=(t._transitionData||{})._frames;function c(t){if("function"==typeof t)return null;if(l.isPlainObject(t)){var e,n,a={};for(e in t)if("function"!=typeof t[e]&&-1===["_","["].indexOf(e.charAt(0))){if("keepdata"===r){if("src"===e.substr(e.length-3))continue}else if("keepstream"===r){if("string"==typeof(n=t[e+"src"])&&n.indexOf(":")>0&&!l.isPlainObject(t.stream))continue}else if("keepall"!==r&&"string"==typeof(n=t[e+"src"])&&n.indexOf(":")>0)continue;a[e]=c(t[e])}return a}return Array.isArray(t)?t.map(c):l.isTypedArray(t)?l.simpleMap(t,l.identity):l.isJSDate(t)?l.ms2DateTimeLocal(+t):t}var u={data:(i||[]).map(function(t){var r=c(t);return e&&delete r.fit,r})};return e||(u.layout=c(o)),t.framework&&t.framework.isPolar&&(u=t.framework.getConfig()),s&&(u.frames=c(s)),"object"===n?u:JSON.stringify(u)},m.modifyFrames=function(t,e){var r,n,a,i=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case"replace":a=n.value;var s=(i[n.index]||{}).name,l=a.name;i[n.index]=o[l]=a,l!==s&&(delete o[s],o[l]=a);break;case"insert":o[(a=n.value).name]=a,i.splice(n.index,0,a);break;case"delete":delete o[(a=i[n.index]).name],i.splice(n.index,1)}return Promise.resolve()},m.computeFrame=function(t,e){var r,n,a,i,o=t._transitionData._frameHash;if(!e)throw new Error("computeFrame must be given a string frame name");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=m.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(a=n[r])&&(-1===(i=u.traces.indexOf(a))&&(i=u.data.length,u.traces[i]=a),u.data[i]=m.extendTrace(u.data[i],s.data[r]))}return u},m.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var a=r[n];a&&a.name&&(e[a.name]=a)}},m.extendObjectWithContainers=function(t,e,r){var n,a,i,o,s,c,u,h=l.extendDeepNoArrays({},e||{}),f=l.expandObjectPaths(h),p={};if(r&&r.length)for(i=0;i<r.length;i++)void 0===(a=(n=l.nestedProperty(f,r[i])).get())?l.nestedProperty(p,r[i]).set(null):(n.set(null),l.nestedProperty(p,r[i]).set(a));if(t=l.extendDeepNoArrays(t||{},f),r&&r.length)for(i=0;i<r.length;i++)if(c=l.nestedProperty(p,r[i]).get()){for(u=(s=l.nestedProperty(t,r[i])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<c.length;o++){var d=c[o];u[o]=null===d?null:m.extendObjectWithContainers(u[o],d)}s.set(u)}return t},m.dataArrayContainers=["transforms","dimensions"],m.layoutArrayContainers=i.layoutArrayContainers,m.extendTrace=function(t,e){return m.extendObjectWithContainers(t,e,m.dataArrayContainers)},m.extendLayout=function(t,e){return m.extendObjectWithContainers(t,e,m.layoutArrayContainers)},m.transition=function(t,e,r,n,a,i){var o={redraw:a.redraw},s={},c=[];return o.prepareFn=function(){for(var a=Array.isArray(e)?e.length:0,i=n.slice(0,a),o=0;o<i.length;o++){var u=i[o],h=t._fullData[u]._module;if(h){if(h.animatable){var f=h.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(u)}t.data[i[o]]=m.extendTrace(t.data[i[o]],e[o])}}var p=l.expandObjectPaths(l.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;m.extendLayout(t.layout,p),delete t.calcdata,m.supplyDefaults(t),m.doCalcdata(t);var v=l.expandObjectPaths(r);if(v){var y=t._fullLayout._plots;for(var x in y){var b=y[x],_=b.xaxis,w=b.yaxis,k=_.range.slice(),T=w.range.slice(),A=null,M=null,S=null,E=null;Array.isArray(v[_._name+".range"])?A=v[_._name+".range"].slice():Array.isArray((v[_._name]||{}).range)&&(A=v[_._name].range.slice()),Array.isArray(v[w._name+".range"])?M=v[w._name+".range"].slice():Array.isArray((v[w._name]||{}).range)&&(M=v[w._name].range.slice()),k&&A&&(_.r2l(k[0])!==_.r2l(A[0])||_.r2l(k[1])!==_.r2l(A[1]))&&(S={xr0:k,xr1:A}),T&&M&&(w.r2l(T[0])!==w.r2l(M[0])||w.r2l(T[1])!==w.r2l(M[1]))&&(E={yr0:T,yr1:M}),(S||E)&&c.push(l.extendFlat({plotinfo:b},S,E))}}return Promise.resolve()},o.runFn=function(e){var n,a,o=t._fullLayout._basePlotModules,u=c.length;if(r)for(a=0;a<o.length;a++)o[a].transitionAxes&&o[a].transitionAxes(t,c,i,e);for(var h in u?((n=l.extendFlat({},i)).duration=0,delete s.cartesian):n=i,s){var f=s[h];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},E(t,i,o)},m.transitionFromReact=function(t,e,r,n){var a=t._fullLayout,i=a.transition,o={},s=[];return o.prepareFn=function(){var t=a._plots;for(var i in o.redraw=!1,"some"===e.anim&&(o.redraw=!0),"some"===r.anim&&(o.redraw=!0),t){var c=t[i],u=c.xaxis,h=c.yaxis,f=n[u._name].range.slice(),p=n[h._name].range.slice(),d=u.range.slice(),g=h.range.slice();u.setScale(),h.setScale();var v=null,m=null;u.r2l(f[0])===u.r2l(d[0])&&u.r2l(f[1])===u.r2l(d[1])||(v={xr0:f,xr1:d}),h.r2l(p[0])===h.r2l(g[0])&&h.r2l(p[1])===h.r2l(g[1])||(m={yr0:p,yr1:g}),(v||m)&&s.push(l.extendFlat({plotinfo:c},v,m))}return Promise.resolve()},o.runFn=function(r){for(var n,a,o,c=t._fullData,u=t._fullLayout._basePlotModules,h=[],f=0;f<c.length;f++)h.push(f);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,a,r)}s.length&&e.anim?"traces first"===i.ordering?(n=l.extendFlat({},i,{duration:0}),o=h,a=i,setTimeout(p,i.duration),d()):(n=i,o=null,a=l.extendFlat({},i,{duration:0}),setTimeout(d,n.duration),p()):s.length?(n=i,p()):e.anim&&(o=h,a=i,d())},E(t,i,o)},m.doCalcdata=function(t,e){var r,n,a,s,c=h.list(t),f=t._fullData,p=t._fullLayout,d=new Array(f.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._treemapcolormap={},p._funnelareacolormap={},a=0;a<f.length;a++)Array.isArray(e)&&-1===e.indexOf(a)&&(d[a]=g[a]);for(a=0;a<f.length;a++)(r=f[a])._arrayAttrs=o.findArrayAttributes(r),r._extremes={};var v=p._subplots.polar||[];for(a=0;a<v.length;a++)c.push(p[v[a]].radialaxis,p[v[a]].angularaxis);for(var m in p._colorAxes){var x=p[m];!1!==x.cauto&&(delete x.cmin,delete x.cmax)}var b=!1;function _(e){if(r=f[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var a=n.calc(t,r);a[0]&&a[0].t&&a[0].t._scene&&delete a[0].t._scene.dirty}for(s=0;s<r.transforms.length;s++){var i=r.transforms[s];(n=y[i.type])&&n.calcTransform&&(r._hasCalcTransform=!0,b=!0,n.calcTransform(t,r,i))}}}function w(e,a){if(r=f[e],!!(n=r._module).isContainer===a){var i=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var o=r.transforms||[];for(s=o.length-1;s>=0;s--)if(o[s].enabled){r._indexToPoints=o[s]._indexToPoints;break}n&&n.calc&&(i=n.calc(t,r))}Array.isArray(i)&&i[0]||(i=[{x:u,y:u}]),i[0].t||(i[0].t={}),i[0].trace=r,d[e]=i}}for(C(c,f),a=0;a<f.length;a++)w(a,!0);for(a=0;a<f.length;a++)_(a);for(b&&C(c,f),a=0;a<f.length;a++)w(a,!0);for(a=0;a<f.length;a++)w(a,!1);P(t);var k=function(t,e){var r,n,a,o,s,c=[];function u(t,r,n){var a=r._id.charAt(0);if("histogram2dcontour"===t){var i=r._counterAxes[0],o=h.getFromId(e,i),s="x"===a||"x"===i&&"category"===o.type,l="y"===a||"y"===i&&"category"===o.type;return function(t,e){return 0===t||0===e?-1:s&&t===n[e].length-1?-1:l&&e===n.length-1?-1:("y"===a?e:t)-1}}return function(t,e){return"y"===a?e:t}}var f={min:function(t){return l.aggNums(Math.min,null,t)},max:function(t){return l.aggNums(Math.max,null,t)},sum:function(t){return l.aggNums(function(t,e){return t+e},null,t)},total:function(t){return l.aggNums(function(t,e){return t+e},null,t)},mean:function(t){return l.mean(t)},median:function(t){return l.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if("category"===p.type){var d=p.categoryorder.match(L);if(d){var g=d[1],v=d[2],m=[];for(n=0;n<p._categories.length;n++)m.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var y=p._traceIndices[n],x=e._fullData[y],b=p._id.charAt(0);if(!0===x.visible){var _=x.type;i.traceIs(x,"histogram")&&(delete x._xautoBinFinished,delete x._yautoBinFinished);var w=e.calcdata[y];for(a=0;a<w.length;a++){var k,T,A,M=w[a];if("splom"===_){var S=x._axesDim[p._id];if("y"===b){var E=x._diag[S][0];E&&(p=e._fullLayout[h.id2name(E)])}var C=M.trace.dimensions[S].values;for(o=0;o<C.length;o++)for(k=C[o],T=p._categoriesMap[k],s=0;s<M.trace.dimensions.length;s++)if(s!==S){var P=M.trace.dimensions[s];m[T][1].push(P.values[o])}}else if("scattergl"===_){for(o=0;o<M.t.x.length;o++)"x"===b&&(k=M.t.x[o],T=k,A=M.t.y[o]),"y"===b&&(k=M.t.y[o],T=k,A=M.t.x[o]),m[T][1].push(A);M.t&&M.t._scene&&delete M.t._scene.dirty}else if(M.hasOwnProperty("z")){A=M.z;var O=u(x.type,p,A);for(o=0;o<A.length;o++)for(s=0;s<A[o].length;s++)(T=O(s,o))+1&&m[T][1].push(A[o][s])}else for("x"===b?(k=M.p+1?M.p:M.x,A=M.s||M.v||M.y):"y"===b&&(k=M.p+1?M.p:M.y,A=M.s||M.v||M.x),Array.isArray(A)||(A=[A]),o=0;o<A.length;o++)m[k][1].push(A[o])}}}p._categoriesValue=m;var z=[];for(n=0;n<m.length;n++)z.push([m[n][0],f[g](m[n][1])]);z.sort(function(t,e){return t[1]-e[1]}),p._categoriesAggregatedValue=z,p._initialCategories=z.map(function(t){return t[0]}),"descending"===v&&p._initialCategories.reverse(),c=c.concat(p.sortByInitialCategories())}}}return c}(c,t);if(k.length){for(p._numBoxes=0,p._numViolins=0,a=0;a<k.length;a++)w(k[a],!0);for(a=0;a<k.length;a++)w(k[a],!1);P(t)}i.getComponentMethod("fx","calc")(t),i.getComponentMethod("errorbars","calc")(t)};var L=/(total|sum|min|max|mean|median) (ascending|descending)/;function C(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.clearCalc(),"multicategory"===n.type&&n.setupMultiCategory(e)}}function P(t){var e,r,n,a=t._fullLayout,i=a._visibleModules,o={};for(r=0;r<i.length;r++){var s=i[r],c=s.crossTraceCalc;if(c){var u=s.basePlotModule.name;o[u]?l.pushUnique(o[u],c):o[u]=[c]}}for(n in o){var h=o[n],f=a._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d="cartesian"===n?a._plots[p]:a[p];for(r=0;r<h.length;r++)h[r](t,d,p)}else for(r=0;r<h.length;r++)h[r](t)}}m.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},m.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},m.generalUpdatePerTraceModule=function(t,e,r,n){var a,i=e.traceHash,o={};for(a=0;a<r.length;a++){var s=r[a],c=s[0].trace;c.visible&&(o[c.type]=o[c.type]||[],o[c.type].push(s))}for(var u in i)if(!o[u]){var h=i[u][0];h[0].trace.visible=!1,o[u]=[h]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,l.filterVisible(p),n)}e.traceHash=o},m.plotBasePlot=function(t,e,r,n,a){var o=i.getModule(t),s=d(e.calcdata,o)[0];o.plot(e,s,n,a)},m.cleanBasePlot=function(t,e,r,n,a){var i=a._has&&a._has(t),o=r._has&&r._has(t);i&&!o&&a["_"+t+"layer"].selectAll("g.trace").remove()}},{"../components/color":591,"../constants/numerical":692,"../lib":716,"../plot_api/plot_schema":753,"../plot_api/plot_template":754,"../plots/get_data":799,"../registry":845,"./animation_attributes":759,"./attributes":761,"./cartesian/axis_ids":767,"./command":788,"./font_attributes":790,"./frame_attributes":791,"./layout_attributes":816,d3:164,"fast-isnumeric":227}],826:[function(t,e,r){"use strict";e.exports={attr:"subplot",name:"polar",axisNames:["angularaxis","radialaxis"],axisName2dataArray:{angularaxis:"theta",radialaxis:"r"},layerNames:["draglayer","plotbg","backplot","angular-grid","radial-grid","frontplot","angular-line","radial-line","angular-axis","radial-axis"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],827:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../lib/polygon").tester,i=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var a,i,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?i=u*(a=d/(u-p)):c?(a=s*f,i=s):(a=o,i=o*u):l&&c?(a=0,i=d):c?(a=0,i=s):a=i=NaN,[a,i]}function u(t,e,r,a){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,a=new Array(n+1);for(r=0;r<n;r++){var i=e[r];a[r]=[t*Math.cos(i),t*Math.sin(i)]}return a[r]=a[0].slice(),a}(t,a):function(t,e,r,a){var s,u,h=a.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,h)}function v(t){return o(t,[e,r])}var m=i(a,function(t){return v(t)?l(t,e):1/0}),y=d(a[m],a[g(m-1)],e);for(f.push(y),s=m,u=0;u<h;s++,u++){var x=a[g(s)];if(!v(x))break;f.push(p(x))}var b=i(a,function(t){return v(t)?l(t,r):1/0}),_=d(a[b],a[g(b+1)],r);return f.push(_),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,a)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,a=new Array(n),i=0;i<n;i++){var o=t[i];a[i]=[e+o[0],r-o[1]]}return a}e.exports={isPtInsidePolygon:function(t,e,r,n,i){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=a(u(s,n[0],n[1],i)),h=a(u(l,n[0],n[1],i)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var a=1/0,i=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];a=Math.min(a,l[0]),i=Math.min(i,-l[1])}return[a,i]},findEnclosingVertexAngles:function(t,e){var r=i(e,function(e){var r=s(e,t);return r>0?r:1/0}),a=n.mod(r+1,e.length);return[e[r],e[a]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var a=-e*r,i=e*e+1,o=2*(e*a-r),s=a*a+r*r-t*t,l=Math.sqrt(o*o-4*i*s),c=(-o+l)/(2*i),u=(-o-l)/(2*i);return[[c,e*c+a+n],[u,e*u+a+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,a,i){return"M"+f(u(t,e,r,n),a,i).join("L")},pathPolygonAnnulus:function(t,e,r,n,a,i,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,a),i,o);return"M"+f(u(l,r,n,a),i,o).reverse().join("L")+"M"+c.join("L")}}},{"../../lib":716,"../../lib/polygon":728}],828:[function(t,e,r){"use strict";var n=t("../get_data").getSubplotCalcData,a=t("../../lib").counterRegex,i=t("./polar"),o=t("./constants"),s=o.attr,l=o.name,c=a(l),u={};u[s]={valType:"subplotid",dflt:l,editType:"calc"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t("./layout_attributes"),supplyLayoutDefaults:t("./layout_defaults"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots[l],o=0;o<a.length;o++){var s=a[o],c=n(r,l,s),u=e[s]._subplot;u||(u=i(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var a=n._subplots[l]||[],i=n._has&&n._has("gl"),o=e._has&&e._has("gl"),s=i&&!o,c=0;c<a.length;c++){var u=a[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers["radial-axis-title"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:t("../cartesian").toSVG}},{"../../lib":716,"../cartesian":775,"../get_data":799,"./constants":826,"./layout_attributes":829,"./layout_defaults":830,"./polar":837}],829:[function(t,e,r){"use strict";var n=t("../../components/color/attributes"),a=t("../cartesian/layout_attributes"),i=t("../domain").attributes,o=t("../../lib").extendFlat,s=t("../../plot_api/edit_types").overrideAll,l=s({color:a.color,showline:o({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:o({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth},"plot","from-root"),c=s({tickmode:a.tickmode,nticks:a.nticks,tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,layer:a.layer},"plot","from-root"),u={visible:o({},a.visible,{dflt:!0}),type:o({},a.type,{values:["-","linear","log","date","category"]}),autorange:o({},a.autorange,{editType:"plot"}),rangemode:{valType:"enumerated",values:["tozero","nonnegative","normal"],dflt:"tozero",editType:"calc"},range:o({},a.range,{items:[{valType:"any",editType:"plot",impliedEdits:{"^autorange":!1}},{valType:"any",editType:"plot",impliedEdits:{"^autorange":!1}}],editType:"plot"}),categoryorder:a.categoryorder,categoryarray:a.categoryarray,angle:{valType:"angle",editType:"plot"},side:{valType:"enumerated",values:["clockwise","counterclockwise"],dflt:"clockwise",editType:"plot"},title:{text:o({},a.title.text,{editType:"plot",dflt:""}),font:o({},a.title.font,{editType:"plot"}),editType:"plot"},hoverformat:a.hoverformat,uirevision:{valType:"any",editType:"none"},editType:"calc",_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}};o(u,l,c);var h={visible:o({},a.visible,{dflt:!0}),type:{valType:"enumerated",values:["-","linear","category"],dflt:"-",editType:"calc",_noTemplating:!0},categoryorder:a.categoryorder,categoryarray:a.categoryarray,thetaunit:{valType:"enumerated",values:["radians","degrees"],dflt:"degrees",editType:"calc"},period:{valType:"number",editType:"calc",min:0},direction:{valType:"enumerated",values:["counterclockwise","clockwise"],dflt:"counterclockwise",editType:"calc"},rotation:{valType:"angle",editType:"calc"},hoverformat:a.hoverformat,uirevision:{valType:"any",editType:"none"},editType:"calc"};o(h,l,c),e.exports={domain:i({name:"polar",editType:"plot"}),sector:{valType:"info_array",items:[{valType:"number",editType:"plot"},{valType:"number",editType:"plot"}],dflt:[0,360],editType:"plot"},hole:{valType:"number",min:0,max:1,dflt:0,editType:"plot"},bgcolor:{valType:"color",editType:"plot",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:"enumerated",values:["circular","linear"],dflt:"circular",editType:"plot"},uirevision:{valType:"any",editType:"none"},editType:"calc"}},{"../../components/color/attributes":590,"../../lib":716,"../../plot_api/edit_types":747,"../cartesian/layout_attributes":776,"../domain":789}],830:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../../plot_api/plot_template"),o=t("../subplot_defaults"),s=t("../get_data").getSubplotData,l=t("../cartesian/tick_value_defaults"),c=t("../cartesian/tick_mark_defaults"),u=t("../cartesian/tick_label_defaults"),h=t("../cartesian/category_order_defaults"),f=t("../cartesian/line_grid_defaults"),p=t("../cartesian/axis_autotype"),d=t("./layout_attributes"),g=t("./set_convert"),v=t("./constants"),m=v.axisNames;function y(t,e,r,o){var p=r("bgcolor");o.bgColor=a.combine(p,o.paper_bgcolor);var y=r("sector");r("hole");var b,_=s(o.fullData,v.name,o.id),w=o.layoutOut;function k(t,e){return r(b+"."+t,e)}for(var T=0;T<m.length;T++){b=m[T],n.isPlainObject(t[b])||(t[b]={});var A=t[b],M=i.newContainer(e,b);M._id=M._name=b,M._attr=o.id+"."+b,M._traceIndices=_.map(function(t){return t._expandedIndex});var S=v.axisName2dataArray[b],E=x(A,M,k,_,S);h(A,M,k,{axData:_,dataAttr:S});var L,C,P=k("visible");switch(g(M,e,w),k("uirevision",e.uirevision),P&&(C=(L=k("color"))===A.color?L:o.font.color),M._m=1,b){case"radialaxis":var O=k("autorange",!M.isValidRange(A.range));A.autorange=O,!O||"linear"!==E&&"-"!==E||k("rangemode"),"reversed"===O&&(M._m=-1),k("range"),M.cleanRange("range",{dfltRange:[0,1]}),P&&(k("side"),k("angle",y[0]),k("title.text"),n.coerceFont(k,"title.font",{family:o.font.family,size:Math.round(1.2*o.font.size),color:C}));break;case"angularaxis":if("date"===E){n.log("Polar plots do not support date angular axes yet.");for(var z=0;z<_.length;z++)_[z].visible=!1;E=A.type=M.type="linear"}k("linear"===E?"thetaunit":"period");var I=k("direction");k("rotation",{counterclockwise:0,clockwise:90}[I])}if(P)l(A,M,k,M.type),u(A,M,k,M.type,{tickSuffixDflt:"degrees"===M.thetaunit?"\xb0":void 0}),c(A,M,k,{outerTicks:!0}),k("showticklabels")&&(n.coerceFont(k,"tickfont",{family:o.font.family,size:o.font.size,color:C}),k("tickangle"),k("tickformat")),f(A,M,k,{dfltColor:L,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),k("layer");"category"!==E&&k("hoverformat"),M._input=A}"category"===e.angularaxis.type&&r("gridshape")}function x(t,e,r,n,a){if("-"===r("type")){for(var i,o=0;o<n.length;o++)if(n[o].visible){i=n[o];break}i&&i[a]&&(e.type=p(i[a],"gregorian")),"-"===e.type?e.type="linear":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{"../../components/color":591,"../../lib":716,"../../plot_api/plot_template":754,"../cartesian/axis_autotype":765,"../cartesian/category_order_defaults":768,"../cartesian/line_grid_defaults":778,"../cartesian/tick_label_defaults":783,"../cartesian/tick_mark_defaults":784,"../cartesian/tick_value_defaults":785,"../get_data":799,"../subplot_defaults":839,"./constants":826,"./layout_attributes":829,"./set_convert":838}],831:[function(t,e,r){"use strict";var n=t("../../../traces/scatter/attributes"),a=n.marker,i=t("../../../lib/extend").extendFlat;["Area traces are deprecated!","Please switch to the *barpolar* trace type."].join(" ");e.exports={r:i({},n.r,{}),t:i({},n.t,{}),marker:{color:i({},a.color,{}),size:i({},a.size,{}),symbol:i({},a.symbol,{}),opacity:i({},a.opacity,{}),editType:"calc"}}},{"../../../lib/extend":707,"../../../traces/scatter/attributes":1118}],832:[function(t,e,r){"use strict";var n=t("../../cartesian/layout_attributes"),a=t("../../../lib/extend").extendFlat,i=t("../../../plot_api/edit_types").overrideAll,o=["Legacy polar charts are deprecated!","Please switch to *polar* subplots."].join(" "),s=a({},n.domain,{});function l(t,e){return a({},e,{showline:{valType:"boolean"},showticklabels:{valType:"boolean"},tickorientation:{valType:"enumerated",values:["horizontal","vertical"]},ticklen:{valType:"number",min:0},tickcolor:{valType:"color"},ticksuffix:{valType:"string"},endpadding:{valType:"number",description:o},visible:{valType:"boolean"}})}e.exports=i({radialaxis:l(0,{range:{valType:"info_array",items:[{valType:"number"},{valType:"number"}]},domain:s,orientation:{valType:"number"}}),angularaxis:l(0,{range:{valType:"info_array",items:[{valType:"number",dflt:0},{valType:"number",dflt:360}]},domain:s}),layout:{direction:{valType:"enumerated",values:["clockwise","counterclockwise"]},orientation:{valType:"angle"}}},"plot","nested")},{"../../../lib/extend":707,"../../../plot_api/edit_types":747,"../../cartesian/layout_attributes":776}],833:[function(t,e,r){"use strict";(e.exports=t("./micropolar")).manager=t("./micropolar_manager")},{"./micropolar":834,"./micropolar_manager":835}],834:[function(t,e,r){var n=t("d3"),a=t("../../../lib").extendDeepAll,i=t("../../../constants/alignment").MID_SHIFT,o=e.exports={version:"0.2.2"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},h=n.dispatch("hover"),f={};return f.render=function(c){return function(c){e=c||e;var h=l.data,f=l.layout;("string"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(h).each(function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(f)};var h=0;c.forEach(function(t,e){t.color||(t.color=f.defaultColorRange[h],h=(h+1)%f.defaultColorRange.length),t.strokeColor||(t.strokeColor="LinePlot"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize});var p=c.filter(function(t,e){var r=t.visible;return"undefined"==typeof r||!0===r}),d=!1,g=p.map(function(t,e){return d=d||"undefined"!=typeof t.groupId,t});if(d){var v=n.nest().key(function(t,e){return"undefined"!=typeof t.groupId?t.groupId:"unstacked"}).entries(g),m=[],y=v.map(function(t,e){if("unstacked"===t.key)return t.values;var r=t.values[0].r.map(function(t,e){return 0});return t.values.forEach(function(t,e,n){t.yStack=[r],m.push(r),r=o.util.sumArrays(t.r,r)}),t.values});p=n.merge(y)}p.forEach(function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]});var x=Math.min(f.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2;x=Math.max(10,x);var b,_=[f.margin.left+x,f.margin.top+x];b=d?[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(m)))]:n.extent(o.util.flattenArray(p.map(function(t,e){return t.r}))),f.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(f.radialAxis.domain!=o.DATAEXTENT&&f.radialAxis.domain?f.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,k=o.util.flattenArray(p.map(function(t,e){return t.t})),T="string"==typeof k[0];T&&(k=o.util.deduplicate(k),w=k.slice(),k=n.range(k.length),p=p.map(function(t,e){var r=t;return t.t=[k],d&&(r.yStack=t.yStack),r}));var A=p.filter(function(t,e){return"LinePlot"===t.geometry||"DotPlot"===t.geometry}).length===p.length,M=null===f.needsEndSpacing?T||!A:f.needsEndSpacing,S=f.angularAxis.domain&&f.angularAxis.domain!=o.DATAEXTENT&&!T&&f.angularAxis.domain[0]>=0?f.angularAxis.domain:n.extent(k),E=Math.abs(k[1]-k[0]);A&&!T&&(E=0);var L=S.slice();M&&T&&(L[1]+=E);var C=f.angularAxis.ticksCount||4;C>8&&(C=C/(C/8)+C%8),f.angularAxis.ticksStep&&(C=(L[1]-L[0])/C);var P=f.angularAxis.ticksStep||(L[1]-L[0])/(C*(f.minorTicks+1));w&&(P=Math.max(Math.round(P),1)),L[2]||(L[2]=P);var O=n.range.apply(this,L);if(O=O.map(function(t,e){return parseFloat(t.toPrecision(12))}),s=n.scale.linear().domain(L.slice(0,2)).range("clockwise"===f.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=M?E:0,"undefined"==typeof(t=n.select(this).select("svg.chart-root"))||t.empty()){var z=(new DOMParser).parseFromString("<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>","application/xml"),I=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(I)}t.select(".guides-group").style({"pointer-events":"none"}),t.select(".angular.axis-group").style({"pointer-events":"none"}),t.select(".radial.axis-group").style({"pointer-events":"none"});var D,R=t.select(".chart-group"),F={fill:"none",stroke:f.tickColor},B={"font-size":f.font.size,"font-family":f.font.family,fill:f.font.color,"text-shadow":["-1px 0px","1px -1px","-1px 1px","1px 1px"].map(function(t,e){return" "+t+" 0 "+f.font.outlineColor}).join(",")};if(f.showLegend){D=t.select(".legend-group").attr({transform:"translate("+[x,f.margin.top]+")"}).style({display:"block"});var N=p.map(function(t,e){var r=o.util.cloneJson(t);return r.symbol="DotPlot"===t.geometry?t.dotType||"circle":"LinePlot"!=t.geometry?"square":"line",r.visibleInLegend="undefined"==typeof t.visibleInLegend||t.visibleInLegend,r.color="LinePlot"===t.geometry?t.strokeColor:t.color,r});o.Legend().config({data:p.map(function(t,e){return t.name||"Element"+e}),legendConfig:a({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:f.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(f.width-j.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2,x=Math.max(10,x),_=[f.margin.left+x,f.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr("transform","translate("+[_[0]+x,_[1]-x]+")")}else D=t.select(".legend-group").style({display:"none"});t.attr({width:f.width,height:f.height}).style({opacity:f.opacity}),R.attr("transform","translate("+_+")").style({cursor:"crosshair"});var V=[(f.width-(f.margin.left+f.margin.right+2*x+(j?j.width:0)))/2,(f.height-(f.margin.top+f.margin.bottom+2*x))/2];if(V[0]=Math.max(0,V[0]),V[1]=Math.max(0,V[1]),t.select(".outer-group").attr("transform","translate("+V+")"),f.title&&f.title.text){var U=t.select("g.title-group text").style(B).text(f.title.text),q=U.node().getBBox();U.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(".radial.axis-group");if(f.radialAxis.gridLinesVisible){var G=H.selectAll("circle.grid-circle").data(r.ticks(5));G.enter().append("circle").attr({class:"grid-circle"}).style(F),G.attr("r",r),G.exit().remove()}H.select("circle.outside-circle").attr({r:x}).style(F);var Y=t.select("circle.background-circle").attr({r:x}).style({fill:f.backgroundColor,stroke:f.stroke});function W(t,e){return s(t)%360+f.orientation}if(f.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:"rotate("+f.radialAxis.orientation+")"}),H.selectAll(".domain").style(F),H.selectAll("g>text").text(function(t,e){return this.textContent+f.radialAxis.ticksSuffix}).style(B).style({"text-anchor":"start"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return"horizontal"===f.radialAxis.tickOrientation?"rotate("+-f.radialAxis.orientation+") translate("+[0,B["font-size"]]+")":"translate("+[0,B["font-size"]]+")"}}),H.selectAll("g>line").style({stroke:"black"})}var Z=t.select(".angular.axis-group").selectAll("g.angular-tick").data(O),J=Z.enter().append("g").classed("angular-tick",!0);Z.attr({transform:function(t,e){return"rotate("+W(t)+")"}}).style({display:f.angularAxis.visible?"block":"none"}),Z.exit().remove(),J.append("line").classed("grid-line",!0).classed("major",function(t,e){return e%(f.minorTicks+1)==0}).classed("minor",function(t,e){return!(e%(f.minorTicks+1)==0)}).style(F),J.selectAll(".minor").style({stroke:f.minorTickColor}),Z.select("line.grid-line").attr({x1:f.tickLength?x-f.tickLength:0,x2:x}).style({display:f.angularAxis.gridLinesVisible?"block":"none"}),J.append("text").classed("axis-text",!0).style(B);var K=Z.select("text.axis-text").attr({x:x+f.labelOffset,dy:i+"em",transform:function(t,e){var r=W(t),n=x+f.labelOffset,a=f.angularAxis.tickOrientation;return"horizontal"==a?"rotate("+-r+" "+n+" 0)":"radial"==a?r<270&&r>90?"rotate(180 "+n+" 0)":null:"rotate("+(r<=180&&r>0?-90:90)+" "+n+" 0)"}}).style({"text-anchor":"middle",display:f.angularAxis.labelsVisible?"block":"none"}).text(function(t,e){return e%(f.minorTicks+1)!=0?"":w?w[t]+f.angularAxis.ticksSuffix:t+f.angularAxis.ticksSuffix}).style(B);f.angularAxis.rewriteTicks&&K.text(function(t,e){return e%(f.minorTicks+1)!=0?"":f.angularAxis.rewriteTicks(this.textContent,e)});var Q=n.max(R.selectAll(".angular-tick text")[0].map(function(t,e){return t.getCTM().e+t.getBBox().width}));D.attr({transform:"translate("+[x+Q,f.margin.top]+")"});var $=t.select("g.geometry-group").selectAll("g").size()>0,tt=t.select("g.geometry-group").selectAll("g.geometry").data(p);if(tt.enter().append("g").attr({class:function(t,e){return"geometry geometry"+e}}),tt.exit().remove(),p[0]||$){var et=[];p.forEach(function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter(function(t,r){return r==e}),n.geometry=t.geometry,n.orientation=f.orientation,n.direction=f.direction,n.index=e,et.push({data:t,geometryConfig:n})});var rt=n.nest().key(function(t,e){return"undefined"!=typeof t.data.groupId||"unstacked"}).entries(et),nt=[];rt.forEach(function(t,e){"unstacked"===t.key?nt=nt.concat(t.values.map(function(t,e){return[t]})):nt.push(t.values)}),nt.forEach(function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map(function(t,e){return a(o[r].defaultConfig(),t)});o[r]().config(n)()})}var at,it,ot=t.select(".guides-group"),st=t.select(".tooltips-group"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!T){var ht=ot.select("line").attr({x1:0,y1:0,y2:0}).style({stroke:"grey","pointer-events":"none"});R.on("mousemove.angular-guide",function(t,e){var r=o.util.getMousePos(Y).angle;ht.attr({x2:-x,transform:"rotate("+r+")"}).style({opacity:.5});var n=(r+180+360-f.orientation)%360;at=s.invert(n);var a=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(at)).move([a[0]+_[0],a[1]+_[1]])}).on("mouseout.angular-guide",function(t,e){ot.select("line").style({opacity:0})})}var ft=ot.select("circle").style({stroke:"grey",fill:"none"});R.on("mousemove.radial-guide",function(t,e){var n=o.util.getMousePos(Y).radius;ft.attr({r:n}).style({opacity:.5}),it=r.invert(o.util.getMousePos(Y).radius);var a=o.util.convertToCartesian(n,f.radialAxis.orientation);ct.text(o.util.round(it)).move([a[0]+_[0],a[1]+_[1]])}).on("mouseout.radial-guide",function(t,e){ft.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()}),t.selectAll(".geometry-group .mark").on("mouseover.tooltip",function(e,r){var a=n.select(this),i=this.style.fill,s="black",l=this.style.opacity||1;if(a.attr({"data-opacity":l}),i&&"none"!==i){a.attr({"data-fill":i}),s=n.hsl(i).darker().toString(),a.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};T&&(c.t=w[e[0]]);var u="t: "+c.t+", r: "+c.r,h=this.getBoundingClientRect(),f=t.node().getBoundingClientRect(),p=[h.left+h.width/2-V[0]-f.left,h.top+h.height/2-V[1]-f.top];ut.config({color:s}).text(u),ut.move(p)}else i=this.style.stroke||"black",a.attr({"data-stroke":i}),s=n.hsl(i).darker().toString(),a.style({stroke:s,opacity:1})}).on("mousemove.tooltip",function(t,e){if(0!=n.event.which)return!1;n.select(this).attr("data-fill")&&ut.show()}).on("mouseout.tooltip",function(t,e){ut.hide();var r=n.select(this),a=r.attr("data-fill");a?r.style({fill:a,opacity:r.attr("data-opacity")}):r.style({stroke:r.attr("data-stroke"),opacity:r.attr("data-opacity")})})})}(c),this},f.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach(function(t,e){l.data[e]||(l.data[e]={}),a(l.data[e],o.Axis.defaultConfig().data[0]),a(l.data[e],t)}),a(l.layout,o.Axis.defaultConfig().layout),a(l.layout,e.layout),this},f.getLiveConfig=function(){return u},f.getinputConfig=function(){return c},f.radialScale=function(t){return r},f.angularScale=function(t){return s},f.svg=function(){return t},n.rebind(f,h,"on"),f},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:"Line1",geometry:"LinePlot",color:null,strokeDash:"solid",strokeColor:null,strokeSize:"1",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:"gray",outlineColor:"white",family:"Tahoma, sans-serif"},direction:"clockwise",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:"",visible:!0,gridLinesVisible:!0,tickOrientation:"horizontal",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:"",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:"horizontal",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:"silver",minorTickColor:"#eee",backgroundColor:"none",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT="dataExtent",o.AREA="AreaChart",o.LINE="LinePlot",o.DOT="DotPlot",o.BAR="BarChart",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map(function(e,r){var n=e*Math.PI/180;return[e,t(n)]})},o.util.dataFromEquation=function(t,e,r){var a=e||6,i=[],o=[];n.range(0,360+a,a).forEach(function(e,r){var n=e*Math.PI/180,a=t(n);i.push(e),o.push(a)});var s={t:i,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if("undefined"==typeof t)return null;var r=[].concat(t);return n.range(e).map(function(t,e){return r[e]||r[0]})},o.util.fillArrays=function(t,e,r){return e.forEach(function(e,n){t[e]=o.util.ensureArray(t[e],r)}),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){"string"==typeof e&&(e=e.split("."));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map(function(t,e){return n.sum(t)})},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter(function(t,e,r){return r.indexOf(t)==e})},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],a=e[1],i={};return i.x=r,i.y=a,i.pos=e,i.angle=180*(Math.atan2(a,r)+Math.PI)/Math.PI,i.radius=Math.sqrt(r*r+a*a),i},o.util.duplicatesCount=function(t){for(var e,r={},n={},a=0,i=t.length;a<i;a++)(e=t[a])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var a=r.slice();r=e,e=a}var i=e.reduce(function(t,e){if("undefined"!=typeof t)return t[e]},t);"undefined"!=typeof i&&(e.reduce(function(t,r,n){if("undefined"!=typeof t)return n===e.length-1&&delete t[r],t[r]},t),r.reduce(function(t,e,n){return"undefined"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=i),t[e]},t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch("hover"),r={solid:"none",dash:[5,2],dot:[2,5]};function i(){var e=t[0].geometryConfig,a=e.container;"string"==typeof a&&(a=n.select(a)),a.datum(t).each(function(t,a){var i=!!t[0].data.yStack,o=t.map(function(t,e){return i?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])}),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,a,i){var o=t[i].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:"mark bar",d:"M"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join("L")+"Z",transform:function(t,r){return"rotate("+(e.orientation+s(t[0]))+")"}})}};c.dot=function(r,a,i){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[i].data.dotSize).type(t[i].data.dotType)(r,a);n.select(this).attr({class:"mark dot",d:s,transform:function(t,r){var n,a,i,s=(n=function(t,r){var n=e.radialScale(t[1]),a=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:a}}(o),a=n.r*Math.cos(n.t),i=n.r*Math.sin(n.t),{x:a,y:i});return"translate("+[s.x,s.y]+")"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius(function(t){return e.radialScale(t[1])}).angle(function(t){return e.angularScale(t[0])*Math.PI/180});c.line=function(r,a,i){var s=r[2]?o[i].map(function(t,e){return[t[0],t[1]+t[2]]}):o[i];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[i].data.dotVisible},fill:d.stroke(r,a,i)}).attr({class:"mark dot"}),!(a>0)){var l=n.select(this.parentNode).selectAll("path.line").data([0]);l.enter().insert("path"),l.attr({class:"line",d:u(s),transform:function(t,r){return"rotate("+(e.orientation+90)+")"},"pointer-events":"none"}).style({fill:function(t,e){return d.fill(r,a,i)},"fill-opacity":0,stroke:function(t,e){return d.stroke(r,a,i)},"stroke-width":function(t,e){return d["stroke-width"](r,a,i)},"stroke-dasharray":function(t,e){return d["stroke-dasharray"](r,a,i)},opacity:function(t,e){return d.opacity(r,a,i)},display:function(t,e){return d.display(r,a,i)}})}};var h=e.angularScale.range(),f=Math.abs(h[1]-h[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle(function(t){return-f/2}).endAngle(function(t){return f/2}).innerRadius(function(t){return e.radialScale(l+(t[2]||0))}).outerRadius(function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])});c.arc=function(t,r,a){n.select(this).attr({class:"mark arc",d:p,transform:function(t,r){return"rotate("+(e.orientation+s(t[0])+90)+")"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},"stroke-width":function(e,r,n){return t[n].data.strokeSize+"px"},"stroke-dasharray":function(e,n,a){return r[t[a].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return"undefined"==typeof t[n].data.visible||t[n].data.visible?"block":"none"}},g=n.select(this).selectAll("g.layer").data(o);g.enter().append("g").attr({class:"layer"});var v=g.selectAll("path.mark").data(function(t,e){return t});v.enter().append("path").attr({class:"mark"}),v.style(d).each(c[e.geometryType]),v.exit().remove(),g.exit().remove()})}return i.config=function(e){return arguments.length?(e.forEach(function(e,r){t[r]||(t[r]={}),a(t[r],o.PolyChart.defaultConfig()),a(t[r],e)}),this):t},i.getColorScale=function(){},n.rebind(i,e,"on"),i},o.PolyChart.defaultConfig=function(){return{data:{name:"geom1",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:"circle",dotSize:64,dotVisible:!1,barWidth:20,color:"#ffa500",strokeSize:1,strokeColor:"silver",strokeDash:"solid",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:"LinePlot",geometryType:"arc",direction:"clockwise",orientation:0,container:"body",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:"bar"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:"arc"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:"dot",dotType:"circle"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:"line"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch("hover");function r(){var e=t.legendConfig,i=t.data.map(function(t,r){return[].concat(t).map(function(t,n){var i=a({},e.elements[r]);return i.name=t,i.color=[].concat(e.elements[r].color)[n],i})}),o=n.merge(i);o=o.filter(function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||"undefined"==typeof e.elements[r].visibleInLegend)}),e.reverseOrder&&(o=o.reverse());var s=e.container;("string"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map(function(t,e){return t.color}),c=e.fontSize,u=null==e.isContinuous?"number"==typeof o[0]:e.isContinuous,h=u?e.height:c*o.length,f=s.classed("legend-group",!0).selectAll("svg").data([0]),p=f.enter().append("svg").attr({width:300,height:h+c,xmlns:"http://www.w3.org/2000/svg","xmlns:xlink":"http://www.w3.org/1999/xlink",version:"1.1"});p.append("g").classed("legend-axis",!0),p.append("g").classed("legend-marks",!0);var d=n.range(o.length),g=n.scale[u?"linear":"ordinal"]().domain(d).range(l),v=n.scale[u?"linear":"ordinal"]().domain(d)[u?"range":"rangePoints"]([0,h]);if(u){var m=f.select(".legend-marks").append("defs").append("linearGradient").attr({id:"grad1",x1:"0%",y1:"0%",x2:"0%",y2:"100%"}).selectAll("stop").data(l);m.enter().append("stop"),m.attr({offset:function(t,e){return e/(l.length-1)*100+"%"}}).style({"stop-color":function(t,e){return t}}),f.append("rect").classed("legend-mark",!0).attr({height:e.height,width:e.colorBandWidth,fill:"url(#grad1)"})}else{var y=f.select(".legend-marks").selectAll("path.legend-mark").data(o);y.enter().append("path").classed("legend-mark",!0),y.attr({transform:function(t,e){return"translate("+[c/2,v(e)+c/2]+")"},d:function(t,e){var r,a,i,o=t.symbol;return i=3*(a=c),"line"===(r=o)?"M"+[[-a/2,-a/12],[a/2,-a/12],[a/2,a/12],[-a/2,a/12]]+"Z":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(i)():n.svg.symbol().type("square").size(i)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(v).orient("right"),b=f.select("g.legend-axis").attr({transform:"translate("+[u?e.colorBandWidth:c,c/2]+")"}).call(x);return b.selectAll(".domain").style({fill:"none",stroke:"none"}),b.selectAll("line").style({fill:"none",stroke:u?e.textColor:"none"}),b.selectAll("text").style({fill:e.textColor,"font-size":e.fontSize}).text(function(t,e){return o[e].name}),r}return r.config=function(e){return arguments.length?(a(t,e),this):t},n.rebind(r,e,"on"),r},o.Legend.defaultConfig=function(t,e){return{data:["a","b","c"],legendConfig:{elements:[{symbol:"line",color:"red"},{symbol:"square",color:"yellow"},{symbol:"diamond",color:"limegreen"}],height:150,colorBandWidth:30,fontSize:12,container:"body",isContinuous:null,textColor:"grey",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,i={container:null,hasTick:!1,fontSize:12,color:"white",padding:5},s="tooltip-"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=i.container.selectAll("g."+s).data([0])).enter().append("g").classed(s,!0).style({"pointer-events":"none",display:"none"});return r=n.append("path").style({fill:"white","fill-opacity":.9}).attr({d:"M0 0"}),e=n.append("text").attr({dx:i.padding+l,dy:.3*+i.fontSize}),c};return c.text=function(a){var o=n.hsl(i.color).l,s=o>=.5?"#aaa":"white",u=o>=.5?"black":"white",h=a||"";e.style({fill:u,"font-size":i.fontSize+"px"}).text(h);var f=i.padding,p=e.node().getBBox(),d={fill:i.color,stroke:s,"stroke-width":"2px"},g=p.width+2*f+l,v=p.height+2*f;return r.attr({d:"M"+[[l,-v/2],[l,-v/4],[i.hasTick?0:l,0],[l,v/4],[l,v/2],[g,v/2],[g,-v/2]].join("L")+"Z"}).style(d),t.attr({transform:"translate("+[l,-v/2+2*f]+")"}),t.style({display:"block"}),c},c.move=function(e){if(t)return t.attr({transform:"translate("+[e[0],e[1]]+")"}).style({display:"block"}),c},c.hide=function(){if(t)return t.style({display:"none"}),c},c.show=function(){if(t)return t.style({display:"block"}),c},c.config=function(t){return a(i,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map(function(t,r){var n=a({},t);return[[n,["marker","color"],["color"]],[n,["marker","opacity"],["opacity"]],[n,["marker","line","color"],["strokeColor"]],[n,["marker","line","dash"],["strokeDash"]],[n,["marker","line","width"],["strokeSize"]],[n,["marker","symbol"],["dotType"]],[n,["marker","size"],["dotSize"]],[n,["marker","barWidth"],["barWidth"]],[n,["line","interpolation"],["lineInterpolation"]],[n,["showlegend"],["visibleInLegend"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e||delete n.marker,e&&delete n.groupId,e?("LinePlot"===n.geometry?(n.type="scatter",!0===n.dotVisible?(delete n.dotVisible,n.mode="lines+markers"):n.mode="lines"):"DotPlot"===n.geometry?(n.type="scatter",n.mode="markers"):"AreaChart"===n.geometry?n.type="area":"BarChart"===n.geometry&&(n.type="bar"),delete n.geometry):("scatter"===n.type?"lines"===n.mode?n.geometry="LinePlot":"markers"===n.mode?n.geometry="DotPlot":"lines+markers"===n.mode&&(n.geometry="LinePlot",n.dotVisible=!0):"area"===n.type?n.geometry="AreaChart":"bar"===n.type&&(n.geometry="BarChart"),delete n.mode,delete n.type),n}),!e&&t.layout&&"stack"===t.layout.barmode)){var i=o.util.duplicates(r.data.map(function(t,e){return t.geometry}));r.data.forEach(function(t,e){var n=i.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)})}if(t.layout){var s=a({},t.layout);if([[s,["plot_bgcolor"],["backgroundColor"]],[s,["showlegend"],["showLegend"]],[s,["radialaxis"],["radialAxis"]],[s,["angularaxis"],["angularAxis"]],[s.angularaxis,["showline"],["gridLinesVisible"]],[s.angularaxis,["showticklabels"],["labelsVisible"]],[s.angularaxis,["nticks"],["ticksCount"]],[s.angularaxis,["tickorientation"],["tickOrientation"]],[s.angularaxis,["ticksuffix"],["ticksSuffix"]],[s.angularaxis,["range"],["domain"]],[s.angularaxis,["endpadding"],["endPadding"]],[s.radialaxis,["showline"],["gridLinesVisible"]],[s.radialaxis,["tickorientation"],["tickOrientation"]],[s.radialaxis,["ticksuffix"],["ticksSuffix"]],[s.radialaxis,["range"],["domain"]],[s.angularAxis,["showline"],["gridLinesVisible"]],[s.angularAxis,["showticklabels"],["labelsVisible"]],[s.angularAxis,["nticks"],["ticksCount"]],[s.angularAxis,["tickorientation"],["tickOrientation"]],[s.angularAxis,["ticksuffix"],["ticksSuffix"]],[s.angularAxis,["range"],["domain"]],[s.angularAxis,["endpadding"],["endPadding"]],[s.radialAxis,["showline"],["gridLinesVisible"]],[s.radialAxis,["tickorientation"],["tickOrientation"]],[s.radialAxis,["ticksuffix"],["ticksSuffix"]],[s.radialAxis,["range"],["domain"]],[s.font,["outlinecolor"],["outlineColor"]],[s.legend,["traceorder"],["reverseOrder"]],[s,["labeloffset"],["labelOffset"]],[s,["defaultcolorrange"],["defaultColorRange"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e?("undefined"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&"undefined"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&"undefined"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&"boolean"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder="normal"!=s.legend.reverseOrder),s.legend&&"boolean"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?"reversed":"normal",delete s.legend.reverseOrder),s.margin&&"undefined"!=typeof s.margin.t){var l=["t","r","b","l","pad"],c=["top","right","bottom","left","pad"],u={};n.entries(s.margin).forEach(function(t,e){u[c[l.indexOf(t.key)]]=t.value}),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{"../../../constants/alignment":685,"../../../lib":716,d3:164}],835:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../../lib"),i=t("../../../components/color"),o=t("./micropolar"),s=t("./undo_manager"),l=a.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,a,i,u,h=new s;function f(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(".svg-container>*:not(.chart-root)").remove(),e=e?l(e,r):r,a||(a=o.Axis()),i=o.adapter.plotly().convert(e),a.config(i).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return f.isPolar=!0,f.svg=function(){return a.svg()},f.getConfig=function(){return e},f.getLiveConfig=function(){return o.adapter.plotly().convert(a.getLiveConfig(),!0)},f.getLiveScales=function(){return{t:a.angularScale(),r:a.radialScale()}},f.setUndoPoint=function(){var t,n,a=this,i=o.util.cloneJson(e);t=i,n=r,h.add({undo:function(){n&&a(n)},redo:function(){a(t)}}),r=o.util.cloneJson(i)},f.undo=function(){h.undo()},f.redo=function(){h.redo()},f},c.fillLayout=function(t){var e=n.select(t).selectAll(".plot-container"),r=e.selectAll(".svg-container"),a=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:i.background,_container:e,_paperdiv:r,_paper:a};t._fullLayout=l(o,t.layout)}},{"../../../components/color":591,"../../../lib":716,"./micropolar":834,"./undo_manager":836,d3:164}],836:[function(t,e,r){"use strict";e.exports=function(){var t,e=[],r=-1,n=!1;function a(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n?this:(e.splice(r+1,e.length-r),e.push(t),r=e.length-1,this)},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(a(n,"undo"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(a(n,"redo"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],837:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("../../registry"),o=t("../../lib"),s=t("../../components/color"),l=t("../../components/drawing"),c=t("../plots"),u=t("../../plots/cartesian/axes"),h=t("../cartesian/set_convert"),f=t("./set_convert"),p=t("../cartesian/autorange").doAutoRange,d=t("../cartesian/dragbox"),g=t("../../components/dragelement"),v=t("../../components/fx"),m=t("../../components/titles"),y=t("../cartesian/select").prepSelect,x=t("../cartesian/select").selectOnClick,b=t("../cartesian/select").clearSelect,_=t("../../lib/setcursor"),w=t("../../lib/clear_gl_canvases"),k=t("../../plot_api/subroutines").redrawReglTraces,T=t("../../constants/alignment").MID_SHIFT,A=t("./constants"),M=t("./helpers"),S=o._,E=o.mod,L=o.deg2rad,C=o.rad2deg;function P(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n="clip"+r._uid+e;this.clipIds.forTraces=n+"-for-traces",this.clipPaths.forTraces=r._clips.append("clipPath").attr("id",this.clipIds.forTraces),this.clipPaths.forTraces.append("path"),this.framework=r._polarlayer.append("g").attr("class",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=P.prototype;function z(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return"side"in t&&(e+=t.side),e}function I(t,e){return e[o.findIndexOfMin(e,function(e){return o.angleDist(t,e)})]}function D(t,e,r){return e?(t.attr("display",null),t.attr(r)):t&&t.attr("display","none"),t}function R(t,e){return"translate("+t+","+e+")"}function F(t){return"rotate("+t+")"}e.exports=function(t,e){return new P(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,a=e.radialaxis,i=e.angularaxis,o=A.layerNames,s=o.indexOf("frontplot"),l=o.slice(0,s),c="below traces"===i.layer,u="below traces"===a.layer;c&&l.push("angular-line"),u&&l.push("radial-line"),c&&l.push("angular-axis"),u&&l.push("radial-axis"),l.push("frontplot"),c||l.push("angular-line"),u||l.push("radial-line"),c||l.push("angular-axis"),u||l.push("radial-axis");var h=this.framework.selectAll(".polarsublayer").data(l,String);h.enter().append("g").attr("class",function(t){return"polarsublayer "+t}).each(function(t){var e=r[t]=n.select(this);switch(t){case"frontplot":e.append("g").classed("barlayer",!0),e.append("g").classed("scatterlayer",!0);break;case"backplot":e.append("g").classed("maplayer",!0);break;case"plotbg":r.bg=e.append("path");break;case"radial-grid":case"angular-grid":e.style("fill","none");break;case"radial-line":e.append("line").style("fill","none");break;case"angular-line":e.append("path").style("fill","none")}}),h.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,a=e.radialaxis,i=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(c[1]-c[0]),f=e.sector;this.sectorInRad=f.map(L);var p,d,g,v,m,y=this.sectorBBox=function(t){var e,r,n,a,i=t[0],o=t[1]-i,s=E(i,360),l=s+o,c=Math.cos(L(s)),u=Math.sin(L(s)),h=Math.cos(L(l)),f=Math.sin(L(l));a=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&f<=0?0:Math.max(u,f);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&h>=0?0:Math.min(c,h);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&f>=0?0:Math.min(u,f);n=l>=360?1:c<=0&&h<=0?0:Math.max(c,h);return[e,r,n,a]}(f),x=y[2]-y[0],b=y[3]-y[1],_=h/u,w=Math.abs(b/x);_>w?(p=u,m=(h-(d=u*w))/n.h/2,g=[o[0],o[1]],v=[c[0]+m,c[1]-m]):(d=h,m=(u-(p=h/w))/n.w/2,g=[o[0]+m,o[1]-m],v=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],T=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=p/x,M=this.innerRadius=e.hole*A,S=this.cx=k-A*y[0],C=this.cy=T+A*y[3],P=this.cxx=S-k,O=this.cyy=C-T;this.radialAxis=this.mockAxis(t,e,a,{_id:"x",side:{counterclockwise:"top",clockwise:"bottom"}[a.side],domain:[M/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,i,{side:"right",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:"x",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:"y",domain:v});var z=this.pathSubplot();this.clipPaths.forTraces.select("path").attr("d",z).attr("transform",R(P,O)),r.frontplot.attr("transform",R(k,T)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr("d",z).attr("transform",R(S,C)).call(s.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var a=o.extendFlat({},r,n);return f(a,e,t),a},O.mockCartesianAxis=function(t,e,r){var n=this,a=r._id,i=o.extendFlat({type:"linear"},r);h(i,t);var s={x:[0,2],y:[1,3]};return i.setRange=function(){var t=n.sectorBBox,r=s[a],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);i.range=[t[r[0]]*l,t[r[1]]*l]},i.isPtWithinRange="x"===a?function(t){return n.isPtInside(t)}:function(){return!0},i.setRange(),i.setScale(),i},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,a=e.radialaxis;n.setScale(),p(r,n);var i=n.range;a.range=i.slice(),a._input.range=i.slice(),n._rl=[n.r2l(i[0],null,"gregorian"),n.r2l(i[1],null,"gregorian")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,a=r.layers,i=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.radialaxis,p=E(e.sector[0],360),d=r.radialAxis,g=l<i;r.fillViewInitialKey("radialaxis.angle",f.angle),r.fillViewInitialKey("radialaxis.range",d.range.slice()),d.setGeometry(),"auto"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var v=function(t){return"translate("+(d.l2p(t.x)+l)+",0)"},m=z(f);if(r.radialTickLayout!==m&&(a["radial-axis"].selectAll(".xtick").remove(),r.radialTickLayout=m),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:a["radial-axis"],path:u.makeTickPath(d,0,b),transFn:v,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:a["radial-grid"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:a["radial-axis"],transFn:v,labelFns:u.makeLabelFns(d,0)})}var _=r.radialAxisAngle=r.vangles?C(I(L(f.angle),r.vangles)):f.angle,w=R(c,h),k=w+F(-_);D(a["radial-axis"],g&&(f.showticklabels||f.ticks),{transform:k}),D(a["radial-grid"],g&&f.showgrid,{transform:w}),D(a["radial-line"].select("line"),g&&f.showline,{x1:l,y1:0,x2:i,y2:0,transform:k}).attr("stroke-width",f.linewidth).call(s.stroke,f.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,a=this.radius,i=this.cx,o=this.cy,s=e.radialaxis,c=this.id+"title",u=void 0!==r?r:this.radialAxisAngle,h=L(u),f=Math.cos(h),p=Math.sin(h),d=0;if(s.title){var g=l.bBox(this.layers["radial-axis"].node()).height,v=s.title.font.size;d="counterclockwise"===s.side?-g-.4*v:g+.8*v}this.layers["radial-axis-title"]=m.draw(n,c,{propContainer:s,propName:this.id+".radialaxis.title",placeholder:S(n,"Click to enter radial axis title"),attributes:{x:i+a/2*f+d*p,y:o-a/2*p+d*f,"text-anchor":"middle"},transform:{rotate:-u}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,a=r.layers,i=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey("angularaxis.rotation",f.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};"linear"===p.type&&"radians"===p.thetaunit&&(p.tick0=C(p.tick0),p.dtick=C(p.dtick));var g=function(t){return R(c+i*Math.cos(t),h-i*Math.sin(t))},v=u.makeLabelFns(p,0).labelStandoff,m={xFn:function(t){var e=d(t);return Math.cos(e)*v},yFn:function(t){var e=d(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(v+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*T)},anchorFn:function(t){var e=d(t),r=Math.cos(e);return Math.abs(r)<.1?"middle":r>0?"start":"end"},heightFn:function(t,e,r){var n=d(t);return-.5*(1+Math.sin(n))*r}},y=z(f);r.angularTickLayout!==y&&(a["angular-axis"].selectAll("."+p._id+"tick").remove(),r.angularTickLayout=y);var x,b=u.calcTicks(p);if("linear"===e.gridshape?(x=b.map(d),o.angleDelta(x[0],x[1])<0&&(x=x.slice().reverse())):x=null,r.vangles=x,"category"===p.type&&(b=b.filter(function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)})),p.visible){var _="inside"===p.ticks?-1:1,w=(p.linewidth||1)/2;u.drawTicks(n,p,{vals:b,layer:a["angular-axis"],path:"M"+_*w+",0h"+_*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-C(e))},crisp:!1}),u.drawGrid(n,p,{vals:b,layer:a["angular-grid"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return"M"+[c+l*r,h-l*n]+"L"+[c+i*r,h-i*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:b,layer:a["angular-axis"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelFns:m})}D(a["angular-line"].select("path"),f.showline,{d:r.pathSubplot(),transform:R(c,h)}).attr("stroke-width",f.linewidth).call(s.stroke,f.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=A.MINZOOM,c=A.OFFEDGE,u=e.radius,h=e.innerRadius,f=e.cx,p=e.cy,m=e.cxx,_=e.cyy,w=e.sectorInRad,k=e.vangles,T=e.radialAxis,S=M.clampTiny,E=M.findXYatLength,L=M.findEnclosingVertexAngles,C=A.cornerHalfWidth,P=A.cornerLen/2,O=d.makeDragger(o,"path","maindrag","crosshair");n.select(O).attr("d",e.pathSubplot()).attr("transform",R(f,p));var z,I,D,F,B,N,j,V,U,q={element:O,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-m,e-_)}function Y(t,e){return Math.atan2(_-e,t-m)}function W(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function X(t,r){if(0===t)return e.pathSector(2*C);var n=P/t,a=r-n,i=r+n,o=Math.max(0,Math.min(t,u)),s=o-C,l=o+C;return"M"+W(s,a)+"A"+[s,s]+" 0,0,0 "+W(s,i)+"L"+W(l,i)+"A"+[l,l]+" 0,0,1 "+W(l,a)+"Z"}function Z(t,r,n){if(0===t)return e.pathSector(2*C);var a,i,o=W(t,r),s=W(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,h=-1/u,f=E(C,u,l,c);a=E(P,h,f[0][0],f[0][1]),i=E(P,h,f[1][0],f[1][1])}else{var p,d;c?(p=P,d=C):(p=C,d=P),a=[[l-p,c-d],[l+p,c-d]],i=[[l-p,c+d],[l+p,c+d]]}return"M"+a.join("L")+"L"+i.reverse().join("L")+"Z"}function J(t,e){return e=Math.max(Math.min(e,u),h),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(D=t,F=e):(D=e,F=t),!0):(D=null,F=null,!1)}function K(t,e){t=t||B,e=e||"M0,0Z",V.attr("d",t),U.attr("d",e),d.transitionZoombox(V,U,N,j),N=!0;var n={};rt(n),r.emit("plotly_relayouting",n)}function Q(t,r){var n,a,i=z+t,o=I+r,s=G(z,I),l=Math.min(G(i,o),u),c=Y(z,I);J(s,l)&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),a=X(D,c)+X(F,c)),K(n,a)}function $(t,e,r,n){var a=M.findIntersectionXY(r,n,r,[t-m,_-e]);return H(a[0],a[1])}function tt(t,r){var n,a,i=z+t,o=I+r,s=Y(z,I),l=Y(i,o),c=L(s,k),h=L(l,k);J($(z,I,c[0],c[1]),Math.min($(i,o,h[0],h[1]),u))&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),a=[Z(D,c[0],c[1]),Z(F,c[0],c[1])].join(" ")),K(n,a)}function et(){if(d.removeZoombox(r),null!==D&&null!==F){var t={};rt(t),d.showDoubleClickNotifier(r),i.call("_guiRelayout",r,t)}}function rt(t){var r=T._rl,n=(r[1]-r[0])/(1-h/u)/u,a=[r[0]+(D-h)*n,r[0]+(F-h)*n];t[e.id+".radialaxis.range"]=a}function nt(t,n){var a=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+"."+s]=e.viewInitial[s];r.emit("plotly_doubleclick",null),i.call("_guiRelayout",r,o)}a.indexOf("select")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),a.indexOf("event")>-1&&v.click(r,n,e.id)}q.prepFn=function(t,n,i){var o=r._fullLayout.dragmode,l=O.getBoundingClientRect();if(z=n-l.left,I=i-l.top,k){var c=M.findPolygonOffset(u,w[0],w[1],k);z+=m+c[0],I+=_+c[1]}switch(o){case"zoom":q.moveFn=k?tt:Q,q.clickFn=nt,q.doneFn=et,function(){D=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=a(t.bgcolor).getLuminance(),(V=d.makeZoombox(s,j,f,p,B)).attr("fill-rule","evenodd"),U=d.makeCorners(s,f,p),b(r)}();break;case"select":case"lasso":y(t,n,i,q,o)}},O.onmousemove=function(t){v.hover(r,t,e.id),r._fullLayout._lasthover=O,r._fullLayout._hoversubplot=e.id},O.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},O.updateRadialDrag=function(t,e,r){var a=this,s=a.gd,l=a.layers,c=a.radius,u=a.innerRadius,h=a.cx,f=a.cy,p=a.radialAxis,v=A.radialDragBoxSize,m=v/2;if(p.visible){var y,x,_,T=L(a.radialAxisAngle),M=p._rl,S=M[0],E=M[1],P=M[r],O=.75*(M[1]-M[0])/(1-e.hole)/c;r?(y=h+(c+m)*Math.cos(T),x=f-(c+m)*Math.sin(T),_="radialdrag"):(y=h+(u-m)*Math.cos(T),x=f-(u-m)*Math.sin(T),_="radialdrag-inner");var z,B,N,j=d.makeRectDragger(l,_,"crosshair",-m,-m,v,v),V={element:j,gd:s};D(n.select(j),p.visible&&u<c,{transform:R(y,x)}),V.prepFn=function(){z=null,B=null,N=null,V.moveFn=U,V.doneFn=q,b(s)},V.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<A.MINDRAG&&(t=0,e=0),[t,e]},g.init(V)}function U(t,e){if(z)z(t,e);else{var n=[t,-e],i=[Math.cos(T),Math.sin(T)],l=Math.abs(o.dot(n,i)/Math.sqrt(o.dot(n,n)));isNaN(l)||(z=l<.5?H:G)}var c={};!function(t){null!==B?t[a.id+".radialaxis.angle"]=B:null!==N&&(t[a.id+".radialaxis.range["+r+"]"]=N)}(c),s.emit("plotly_relayouting",c)}function q(){null!==B?i.call("_guiRelayout",s,a.id+".radialaxis.angle",B):null!==N&&i.call("_guiRelayout",s,a.id+".radialaxis.range["+r+"]",N)}function H(t,e){if(0!==r){var n=y+t,i=x+e;B=Math.atan2(f-i,n-h),a.vangles&&(B=I(B,a.vangles)),B=C(B);var o=R(h,f)+F(-B);l["radial-axis"].attr("transform",o),l["radial-line"].select("line").attr("transform",o);var s=a.gd._fullLayout,c=s[a.id];a.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(T),Math.sin(T)]);if(N=P-O*n,O>0==(r?N>S:N<E)){var l=s._fullLayout,c=l[a.id];p.range[r]=N,p._rl[r]=N,a.updateRadialAxis(l,c),a.xaxis.setRange(),a.xaxis.setScale(),a.yaxis.setRange(),a.yaxis.setScale();var u=!1;for(var h in a.traceHash){var f=a.traceHash[h],d=o.filterVisible(f);f[0][0].trace._module.plot(s,a,d,c),i.traceIs(h,"gl")&&d.length&&(u=!0)}u&&(w(s),k(s))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,a=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,h=e.cy,f=e.cxx,p=e.cyy,v=A.angularDragBoxSize,m=d.makeDragger(a,"path","angulardrag","move"),y={element:m,gd:r};function x(t,e){return Math.atan2(p+v-e,t-f-v)}n.select(m).attr("d",e.pathAnnulus(s,s+v)).attr("transform",R(u,h)).call(_,"move");var T,M,S,E,L,P,O=a.frontplot.select(".scatterlayer").selectAll(".trace"),z=O.selectAll(".point"),I=O.selectAll(".textpoint");function D(t,s){var d=e.gd._fullLayout,g=d[e.id],v=x(T+t,M+s),m=C(v-P);if(E=S+m,a.frontplot.attr("transform",R(e.xOffset2,e.yOffset2)+F([-m,f,p])),e.vangles){L=e.radialAxisAngle+m;var y=R(u,h)+F(-m),b=R(u,h)+F(-L);a.bg.attr("transform",y),a["radial-grid"].attr("transform",y),a["radial-axis"].attr("transform",b),a["radial-line"].select("line").attr("transform",b),e.updateRadialAxisTitle(d,g,L)}else e.clipPaths.forTraces.select("path").attr("transform",R(f,p)+F(m));z.each(function(){var t=n.select(this),e=l.getTranslate(t);t.attr("transform",R(e.x,e.y)+F([m]))}),I.each(function(){var t=n.select(this),e=t.select("text"),r=l.getTranslate(t);t.attr("transform",F([m,e.attr("x"),e.attr("y")])+R(r.x,r.y))}),c.rotation=o.modHalf(E,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(l.hideOutsideRangePoints,e);var _=!1;for(var A in e.traceHash)if(i.traceIs(A,"gl")){var D=e.traceHash[A],N=o.filterVisible(D);D[0][0].trace._module.plot(r,e,N,g),N.length&&(_=!0)}_&&(w(r),k(r));var j={};B(j),r.emit("plotly_relayouting",j)}function B(t){t[e.id+".angularaxis.rotation"]=E,e.vangles&&(t[e.id+".radialaxis.angle"]=L)}function N(){I.select("text").attr("transform",null);var t={};B(t),i.call("_guiRelayout",r,t)}y.prepFn=function(n,a,i){var o=t[e.id];S=o.angularaxis.rotation;var s=m.getBoundingClientRect();T=a-s.left,M=i-s.top,P=x(T,M),y.moveFn=D,y.doneFn=N,b(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(m),null)),g.init(y)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),a=this.radialAxis,i=a.c2l(t.r),s=a._rl;return(r?M.isPtInsidePolygon:o.isPtInsideSector)(i,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?M.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{"../../components/color":591,"../../components/dragelement":609,"../../components/drawing":612,"../../components/fx":629,"../../components/titles":678,"../../constants/alignment":685,"../../lib":716,"../../lib/clear_gl_canvases":701,"../../lib/setcursor":736,"../../plot_api/subroutines":755,"../../plots/cartesian/axes":764,"../../registry":845,"../cartesian/autorange":763,"../cartesian/dragbox":772,"../cartesian/select":781,"../cartesian/set_convert":782,"../plots":825,"./constants":826,"./helpers":827,"./set_convert":838,d3:164,tinycolor2:535}],838:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../cartesian/set_convert"),i=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(a(t,r),t._id){case"x":case"radialaxis":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],a=r.innerRadius,i=(r.radius-a)/(n-e),o=a/i,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*i},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case"angularaxis":!function(t,e){var r=t.type;if("linear"===r){var a=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return"degrees"===e?i(t):t}(a(t),e)},t.c2d=function(t,e){return s(function(t,e){return"degrees"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,a){var i,o,s=e[a],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&"linear"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(i=new Array(l),o=0;o<l;o++)i[o]=c(s[o])}else{var u=a+"0",h="d"+a,f=u in e?c(e[u]):0,p=e[h]?c(e[h]):(t.period||2*Math.PI)/l;for(i=new Array(l),o=0;o<l;o++)i[o]=f+o*p}return i},t.setGeometry=function(){var a,s,l,c,u=e.sector,h=u.map(i),f={clockwise:-1,counterclockwise:1}[t.direction],p=i(t.rotation),d=function(t){return f*t+p},g=function(t){return(t-p)/f};switch(r){case"linear":s=a=n.identity,c=i,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(g).map(o);break;case"category":var v=t._categories.length,m=t.period?Math.max(t.period,v):v;0===m&&(m=1),s=c=function(t){return 2*t*Math.PI/m},a=l=function(t){return t*m/Math.PI/2},t.range=[0,m]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return a(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{"../../lib":716,"../cartesian/set_convert":782}],839:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plot_api/plot_template"),i=t("./domain").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||"x",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\d+$/,"");function v(t,e){return n.coerce(s,l,u,t,e)}for(var m=0;m<d;m++){var y=p[m];s=t[y]?t[y]:t[y]={},l=a.newContainer(e,y,g),v("uirevision",e.uirevision);var x={};x[f]=[m/d,(m+1)/d],i(l,e,v,x),o.id=y,h(s,l,v,o)}}},{"../lib":716,"../plot_api/plot_template":754,"./domain":789}],840:[function(t,e,r){"use strict";['Variables are inserted using %{variable}, for example "y: %{y}".','Numbers are formatted using d3-format\'s syntax %{variable:d3-format}, for example "Price: %{y:$.2f}".',t("../constants/docs").FORMAT_LINK,"for details on the formatting syntax.",'Dates are formatted using d3-time-format\'s syntax %{variable|d3-time-format}, for example "Day: %{2019-01-01|%A}".',t("../constants/docs").DATE_FORMAT_LINK,"for details on the date formatting syntax."].join(" ");function n(t){var e=t.description?" "+t.description:"",r=t.keys||[];if(r.length>0){for(var n=[],a=0;a<r.length;a++)n[a]="`"+r[a]+"`";e+="Finally, the template string has access to ",e=1===r.length?"variable "+n[0]:"variables "+n.slice(0,-1).join(", ")+" and "+n.slice(-1)+"."}return e}r.hovertemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:"string",dflt:"",editType:t.editType||"none"};return!1!==t.arrayOk&&(r.arrayOk=!0),r},r.texttemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:"string",dflt:"",editType:t.editType||"calc"};return!1!==t.arrayOk&&(r.arrayOk=!0),r}},{"../constants/docs":687}],841:[function(t,e,r){"use strict";var n=t("./ternary"),a=t("../../plots/get_data").getSubplotCalcData,i=t("../../lib").counterRegex;r.name="ternary";var o=r.attr="subplot";r.idRoot="ternary",r.idRegex=r.attrRegex=i("ternary"),(r.attributes={})[o]={valType:"subplotid",dflt:"ternary",editType:"calc"},r.layoutAttributes=t("./layout_attributes"),r.supplyLayoutDefaults=t("./layout_defaults"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots.ternary,o=0;o<i.length;o++){var s=i[o],l=a(r,"ternary",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var a=n._subplots.ternary||[],i=0;i<a.length;i++){var o=a[i],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers["a-title"].remove(),s.layers["b-title"].remove(),s.layers["c-title"].remove())}}},{"../../lib":716,"../../plots/get_data":799,"./layout_attributes":842,"./layout_defaults":843,"./ternary":844}],842:[function(t,e,r){"use strict";var n=t("../../components/color/attributes"),a=t("../domain").attributes,i=t("../cartesian/layout_attributes"),o=t("../../plot_api/edit_types").overrideAll,s=t("../../lib/extend").extendFlat,l={title:{text:i.title.text,font:i.title.font},color:i.color,tickmode:i.tickmode,nticks:s({},i.nticks,{dflt:6,min:1}),tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:s({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:s({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth,layer:i.layer,min:{valType:"number",dflt:0,min:0},_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},c=e.exports=o({domain:a({name:"ternary"}),bgcolor:{valType:"color",dflt:n.background},sum:{valType:"number",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},"plot","from-root");c.uirevision={valType:"any",editType:"none"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:"any",editType:"none"}},{"../../components/color/attributes":590,"../../lib/extend":707,"../../plot_api/edit_types":747,"../cartesian/layout_attributes":776,"../domain":789}],843:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../../plot_api/plot_template"),i=t("../../lib"),o=t("../subplot_defaults"),s=t("../cartesian/tick_label_defaults"),l=t("../cartesian/tick_mark_defaults"),c=t("../cartesian/tick_value_defaults"),u=t("../cartesian/line_grid_defaults"),h=t("./layout_attributes"),f=["aaxis","baxis","caxis"];function p(t,e,r,i){var o,s,l,c=r("bgcolor"),u=r("sum");i.bgColor=n.combine(c,i.paper_bgcolor);for(var h=0;h<f.length;h++)s=t[o=f[h]]||{},(l=a.newContainer(e,o))._name=o,d(s,l,i,e);var p=e.aaxis,g=e.baxis,v=e.caxis;p.min+g.min+v.min>=u&&(p.min=0,g.min=0,v.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var a=h[e._name];function o(r,n){return i.coerce(t,e,a,r,n)}o("uirevision",n.uirevision),e.type="linear";var f=o("color"),p=f!==a.color.dflt?f:r.font.color,d=e._name.charAt(0).toUpperCase(),g="Component "+d,v=o("title.text",g);e._hovertitle=v===g?v:d,i.coerceFont(o,"title.font",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o("min"),c(t,e,o,"linear"),s(t,e,o,"linear",{}),l(t,e,o,{outerTicks:!0}),o("showticklabels")&&(i.coerceFont(o,"tickfont",{family:r.font.family,size:r.font.size,color:p}),o("tickangle"),o("tickformat")),u(t,e,o,{dfltColor:f,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:a}),o("hoverformat"),o("layer")}e.exports=function(t,e,r){o(t,e,r,{type:"ternary",attributes:h,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{"../../components/color":591,"../../lib":716,"../../plot_api/plot_template":754,"../cartesian/line_grid_defaults":778,"../cartesian/tick_label_defaults":783,"../cartesian/tick_mark_defaults":784,"../cartesian/tick_value_defaults":785,"../subplot_defaults":839,"./layout_attributes":842}],844:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("../../registry"),o=t("../../lib"),s=o._,l=t("../../components/color"),c=t("../../components/drawing"),u=t("../cartesian/set_convert"),h=t("../../lib/extend").extendFlat,f=t("../plots"),p=t("../cartesian/axes"),d=t("../../components/dragelement"),g=t("../../components/fx"),v=t("../../components/titles"),m=t("../cartesian/select").prepSelect,y=t("../cartesian/select").selectOnClick,x=t("../cartesian/select").clearSelect,b=t("../cartesian/constants");function _(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=_;var w=_.prototype;w.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},w.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var a=0;a<t.length;a++){if(!1===t[a][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),f.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select("path").call(l.fill,r.bgcolor)},w.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId="clip"+this.layoutId+this.id,a=this.clipIdRelative="clip-relative"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,"clipPath",n,function(t){t.append("path").attr("d","M0,0Z")}),this.clipDefRelative=o.ensureSingleById(t._clips,"clipPath",a,function(t){t.append("path").attr("d","M0,0Z")}),this.plotContainer=o.ensureSingle(this.container,"g",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},w.updateLayers=function(t){var e=this.layers,r=["draglayer","plotbg","backplot","grids"];"below traces"===t.aaxis.layer&&r.push("aaxis","aline"),"below traces"===t.baxis.layer&&r.push("baxis","bline"),"below traces"===t.caxis.layer&&r.push("caxis","cline"),r.push("frontplot"),"above traces"===t.aaxis.layer&&r.push("aaxis","aline"),"above traces"===t.baxis.layer&&r.push("baxis","bline"),"above traces"===t.caxis.layer&&r.push("caxis","cline");var a=this.plotContainer.selectAll("g.toplevel").data(r,String),i=["agrid","bgrid","cgrid"];a.enter().append("g").attr("class",function(t){return"toplevel "+t}).each(function(t){var r=n.select(this);e[t]=r,"frontplot"===t?r.append("g").classed("scatterlayer",!0):"backplot"===t?r.append("g").classed("maplayer",!0):"plotbg"===t?r.append("path").attr("d","M0,0Z"):"aline"===t||"bline"===t||"cline"===t?r.append("path"):"grids"===t&&i.forEach(function(t){e[t]=r.append("g").classed("grid "+t,!0)})}),a.order()};var k=Math.sqrt(4/3);w.adjustLayout=function(t,e){var r,n,a,i,o,s,f=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,v=p.x[1]-p.x[0],m=p.y[1]-p.y[0],y=v*e.w,x=m*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,T=t.caxis.min;y>k*x?a=(i=x)*k:i=(a=y)/k,o=v*a/y,s=m*i/x,r=e.l+e.w*d-a/2,n=e.t+e.h*(1-g)-i/2,f.x0=r,f.y0=n,f.w=a,f.h=i,f.sum=b,f.xaxis={type:"linear",range:[_+2*T-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:"x"},u(f.xaxis,f.graphDiv._fullLayout),f.xaxis.setScale(),f.xaxis.isPtWithinRange=function(t){return t.a>=f.aaxis.range[0]&&t.a<=f.aaxis.range[1]&&t.b>=f.baxis.range[1]&&t.b<=f.baxis.range[0]&&t.c>=f.caxis.range[1]&&t.c<=f.caxis.range[0]},f.yaxis={type:"linear",range:[_,b-w-T],domain:[g-s/2,g+s/2],_id:"y"},u(f.yaxis,f.graphDiv._fullLayout),f.yaxis.setScale(),f.yaxis.isPtWithinRange=function(){return!0};var A=f.yaxis.domain[0],M=f.aaxis=h({},t.aaxis,{range:[_,b-w-T],side:"left",tickangle:(+t.aaxis.tickangle||0)-30,domain:[A,A+s*k],anchor:"free",position:0,_id:"y",_length:a});u(M,f.graphDiv._fullLayout),M.setScale();var S=f.baxis=h({},t.baxis,{range:[b-_-T,w],side:"bottom",domain:f.xaxis.domain,anchor:"free",position:0,_id:"x",_length:a});u(S,f.graphDiv._fullLayout),S.setScale();var E=f.caxis=h({},t.caxis,{range:[b-_-w,T],side:"right",tickangle:(+t.caxis.tickangle||0)+30,domain:[A,A+s*k],anchor:"free",position:0,_id:"y",_length:a});u(E,f.graphDiv._fullLayout),E.setScale();var L="M"+r+","+(n+i)+"h"+a+"l-"+a/2+",-"+i+"Z";f.clipDef.select("path").attr("d",L),f.layers.plotbg.select("path").attr("d",L);var C="M0,"+i+"h"+a+"l-"+a/2+",-"+i+"Z";f.clipDefRelative.select("path").attr("d",C);var P="translate("+r+","+n+")";f.plotContainer.selectAll(".scatterlayer,.maplayer").attr("transform",P),f.clipDefRelative.select("path").attr("transform",null);var O="translate("+(r-S._offset)+","+(n+i)+")";f.layers.baxis.attr("transform",O),f.layers.bgrid.attr("transform",O);var z="translate("+(r+a/2)+","+n+")rotate(30)translate(0,"+-M._offset+")";f.layers.aaxis.attr("transform",z),f.layers.agrid.attr("transform",z);var I="translate("+(r+a/2)+","+n+")rotate(-30)translate(0,"+-E._offset+")";f.layers.caxis.attr("transform",I),f.layers.cgrid.attr("transform",I),f.drawAxes(!0),f.layers.aline.select("path").attr("d",M.showline?"M"+r+","+(n+i)+"l"+a/2+",-"+i:"M0,0").call(l.stroke,M.linecolor||"#000").style("stroke-width",(M.linewidth||0)+"px"),f.layers.bline.select("path").attr("d",S.showline?"M"+r+","+(n+i)+"h"+a:"M0,0").call(l.stroke,S.linecolor||"#000").style("stroke-width",(S.linewidth||0)+"px"),f.layers.cline.select("path").attr("d",E.showline?"M"+(r+a/2)+","+n+"l"+a/2+","+i:"M0,0").call(l.stroke,E.linecolor||"#000").style("stroke-width",(E.linewidth||0)+"px"),f.graphDiv._context.staticPlot||f.initInteractions(),c.setClipUrl(f.layers.frontplot,f._hasClipOnAxisFalse?null:f.clipId,f.graphDiv)},w.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+"title",n=this.layers,a=this.aaxis,i=this.baxis,o=this.caxis;if(this.drawAx(a),this.drawAx(i),this.drawAx(o),t){var l=Math.max(a.showticklabels?a.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+("outside"===o.ticks?.87*o.ticklen:0)),c=(i.showticklabels?i.tickfont.size:0)+("outside"===i.ticks?i.ticklen:0)+3;n["a-title"]=v.draw(e,"a"+r,{propContainer:a,propName:this.id+".aaxis.title",placeholder:s(e,"Click to enter Component A title"),attributes:{x:this.x0+this.w/2,y:this.y0-a.title.font.size/3-l,"text-anchor":"middle"}}),n["b-title"]=v.draw(e,"b"+r,{propContainer:i,propName:this.id+".baxis.title",placeholder:s(e,"Click to enter Component B title"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*i.title.font.size+c,"text-anchor":"middle"}}),n["c-title"]=v.draw(e,"c"+r,{propContainer:o,propName:this.id+".caxis.title",placeholder:s(e,"Click to enter Component C title"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,"text-anchor":"middle"}})}},w.drawAx=function(t){var e,r=this.graphDiv,n=t._name,a=n.charAt(0),i=t._id,s=this.layers[n],l=a+"tickLayout",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll("."+i+"tick").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),h=p.clipEnds(t,u),f=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),v=d*(t.linewidth||1)/2,m=d*t.ticklen,y=this.w,x=this.h,b="b"===a?"M0,"+v+"l"+Math.sin(g)*m+","+Math.cos(g)*m:"M"+v+",0l"+Math.cos(g)*m+","+-Math.sin(g)*m,_={a:"M0,0l"+x+",-"+y/2,b:"M0,0l-"+y/2+",-"+x,c:"M0,0l-"+x+","+y/2}[a];p.drawTicks(r,t,{vals:"inside"===t.ticks?h:u,layer:s,path:b,transFn:f,crisp:!1}),p.drawGrid(r,t,{vals:h,layer:this.layers[a+"grid"],path:_,transFn:f,crisp:!1}),p.drawLabels(r,t,{vals:u,layer:s,transFn:f,labelFns:p.makeLabelFns(t,0,30)})};var T=b.MINZOOM/2+.87,A="m-0.87,.5h"+T+"v3h-"+(T+5.2)+"l"+(T/2+2.6)+",-"+(.87*T+4.5)+"l2.6,1.5l-"+T/2+","+.87*T+"Z",M="m0.87,.5h-"+T+"v3h"+(T+5.2)+"l-"+(T/2+2.6)+",-"+(.87*T+4.5)+"l-2.6,1.5l"+T/2+","+.87*T+"Z",S="m0,1l"+T/2+","+.87*T+"l2.6,-1.5l-"+(T/2+2.6)+",-"+(.87*T+4.5)+"l-"+(T/2+2.6)+","+(.87*T+4.5)+"l2.6,1.5l"+T/2+",-"+.87*T+"Z",E="m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2Z",L=!0;function C(t){n.select(t).selectAll(".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners").remove()}w.initInteractions=function(){var t,e,r,n,u,h,f,p,v,_,w=this,T=w.layers.plotbg.select("path").node(),P=w.graphDiv,O=P._fullLayout._zoomlayer,z={element:T,gd:P,plotinfo:{id:w.id,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(i,o,s){z.xaxes=[w.xaxis],z.yaxes=[w.yaxis];var c=P._fullLayout.dragmode;z.minDrag="lasso"===c?1:void 0,"zoom"===c?(z.moveFn=N,z.clickFn=D,z.doneFn=j,function(i,o,s){var c=T.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,h=a(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),f="M0,"+w.h+"L"+w.w/2+", 0L"+w.w+","+w.h+"Z",p=!1,v=O.append("path").attr("class","zoombox").attr("transform","translate("+w.x0+", "+w.y0+")").style({fill:h>.2?"rgba(0,0,0,0)":"rgba(255,255,255,0)","stroke-width":0}).attr("d",f),_=O.append("path").attr("class","zoombox-corners").attr("transform","translate("+w.x0+", "+w.y0+")").style({fill:l.background,stroke:l.defaultLine,"stroke-width":1,opacity:0}).attr("d","M0,0Z"),x(P)}(0,o,s)):"pan"===c?(z.moveFn=V,z.clickFn=D,z.doneFn=U,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,x(P)):"select"!==c&&"lasso"!==c||m(i,o,s,z,c)}};function I(t){var e={};return e[w.id+".aaxis.min"]=t.a,e[w.id+".baxis.min"]=t.b,e[w.id+".caxis.min"]=t.c,e}function D(t,e){var r=P._fullLayout.clickmode;C(P),2===t&&(P.emit("plotly_doubleclick",null),i.call("_guiRelayout",P,I({a:0,b:0,c:0}))),r.indexOf("select")>-1&&1===t&&y(e,P,[w.xaxis],[w.yaxis],w.id,z),r.indexOf("event")>-1&&g.click(P,e,w.id)}function R(t,e){return 1-e/w.h}function F(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function B(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function N(a,i){var o=t+a,s=e+i,l=Math.max(0,Math.min(1,R(0,e),R(0,s))),c=Math.max(0,Math.min(1,F(t,e),F(o,s))),d=Math.max(0,Math.min(1,B(t,e),B(o,s))),g=(l/2+d)*w.w,m=(1-l/2-c)*w.w,y=(g+m)/2,x=m-g,T=(1-l)*w.h,L=T-x/k;x<b.MINZOOM?(u=r,v.attr("d",f),_.attr("d","M0,0Z")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},v.attr("d",f+"M"+g+","+T+"H"+m+"L"+y+","+L+"L"+g+","+T+"Z"),_.attr("d","M"+t+","+e+E+"M"+g+","+T+A+"M"+m+","+T+M+"M"+y+","+L+S)),p||(v.transition().style("fill",h>.2?"rgba(0,0,0,0.4)":"rgba(255,255,255,0.3)").duration(200),_.transition().style("opacity",1).duration(200),p=!0),P.emit("plotly_relayouting",I(u))}function j(){C(P),u!==r&&(i.call("_guiRelayout",P,I(u)),L&&P.data&&P._context.showTips&&(o.notifier(s(P,"Double-click to zoom back out"),"long"),L=!1))}function V(t,e){var n=t/w.xaxis._m,a=e/w.yaxis._m,i=[(u={a:r.a-a,b:r.b+(n+a)/2,c:r.c-(n-a)/2}).a,u.b,u.c].sort(),o=i.indexOf(u.a),s=i.indexOf(u.b),l=i.indexOf(u.c);i[0]<0&&(i[1]+i[0]/2<0?(i[2]+=i[0]+i[1],i[0]=i[1]=0):(i[2]+=i[0]/2,i[1]+=i[0]/2,i[0]=0),u={a:i[o],b:i[s],c:i[l]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var h="translate("+(w.x0+t)+","+(w.y0+e)+")";w.plotContainer.selectAll(".scatterlayer,.maplayer").attr("transform",h);var f="translate("+-t+","+-e+")";w.clipDefRelative.select("path").attr("transform",f),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(".scatterlayer").selectAll(".trace").call(c.hideOutsideRangePoints,w),P.emit("plotly_relayouting",I(u))}function U(){i.call("_guiRelayout",P,I(u))}T.onmousemove=function(t){g.hover(P,t,w.id),P._fullLayout._lasthover=T,P._fullLayout._hoversubplot=w.id},T.onmouseout=function(t){P._dragging||d.unhover(P,t)},d.init(z)}},{"../../components/color":591,"../../components/dragelement":609,"../../components/drawing":612,"../../components/fx":629,"../../components/titles":678,"../../lib":716,"../../lib/extend":707,"../../registry":845,"../cartesian/axes":764,"../cartesian/constants":770,"../cartesian/select":781,"../cartesian/set_convert":782,"../plots":825,d3:164,tinycolor2:535}],845:[function(t,e,r){"use strict";var n=t("./lib/loggers"),a=t("./lib/noop"),i=t("./lib/push_unique"),o=t("./lib/is_plain_object"),s=t("./lib/dom").addStyleRule,l=t("./lib/extend"),c=t("./plots/attributes"),u=t("./plots/layout_attributes"),h=l.extendFlat,f=l.extendDeepAll;function p(t){var e=t.name,a=t.categories,i=t.meta;if(r.modules[e])n.log("Type "+e+" already registered");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log("Plot type "+e+" already registered.");for(var a in m(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(a,t.name)}(t.basePlotModule);for(var o={},l=0;l<a.length;l++)o[a[l]]=!0,r.allCategories[a[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},i&&Object.keys(i).length&&(r.modules[e].meta=i),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&h(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,f=u.name;if("mapbox"===f){var p=u.constants.styleRules;for(var d in p)s(".js-plotly-plot .plotly .mapboxgl-"+d,p[d])}"geo"!==f&&"mapbox"!==f||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if("string"!=typeof t.name)throw new Error("Component module *name* must be a string.");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&i(r.layoutArrayContainers,e),m(t)),r.modules)y(e,n);for(var a in r.subplotsRegistry)b(e,a);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function g(t){if("string"!=typeof t.name)throw new Error("Transform module *name* must be a string.");var e="Transform module "+t.name,a="function"==typeof t.transform,i="function"==typeof t.calcTransform;if(!a&&!i)throw new Error(e+" is missing a *transform* or *calcTransform* method.");for(var s in a&&i&&n.log([e+" has both a *transform* and *calcTransform* methods.","Please note that all *transform* methods are executed","before all *calcTransform* methods."].join(" ")),o(t.attributes)||n.log(e+" registered without an *attributes* object."),"function"!=typeof t.supplyDefaults&&n.log(e+" registered without a *supplyDefaults* method."),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function v(t){var e=t.name,n=e.split("-")[0],a=t.dictionary,i=t.format,o=a&&Object.keys(a).length,s=i&&Object.keys(i).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=a),s&&u.format===c.format&&(u.format=i)}o&&(c.dictionary=a),s&&(c.format=i)}function m(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)i(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var a=n.traces[e];a&&f(r.modules[e]._module.attributes,a)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var a=n.transforms[e];a&&f(r.transformsRegistry[e].attributes,a)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var a=r.subplotsRegistry[e],i=a.layoutAttributes,o="subplot"===a.attr?a.name:a.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];i&&s&&f(i,s)}}function _(t){return"object"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error("No argument passed to Plotly.register.");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error("Invalid module was attempted to be registered!");switch(n.moduleType){case"trace":p(n);break;case"transform":g(n);break;case"component":d(n);break;case"locale":v(n);break;case"apiMethod":var a=n.name;r.apiMethodRegistry[a]=n.fn;break;default:throw new Error("Invalid module was attempted to be registered!")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if("various"===(t=_(t)))return!1;var a=r.modules[t];return a||(t&&"area"!==t&&n.log("Unrecognized trace type "+t+"."),a=r.modules[c.type.dflt]),!!a.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],a=0;a<n.length;a++)n[a].type===e&&r.push(a);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||a},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{"./lib/dom":705,"./lib/extend":707,"./lib/is_plain_object":717,"./lib/loggers":720,"./lib/noop":725,"./lib/push_unique":730,"./plots/attributes":761,"./plots/layout_attributes":816}],846:[function(t,e,r){"use strict";var n=t("../registry"),a=t("../lib"),i=a.extendFlat,o=a.extendDeep;function s(t){var e;switch(t){case"themes__thumb":e={autosize:!0,width:150,height:150,title:{text:""},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case"thumbnail":e={title:{text:""},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:"",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var a,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),"thumbnail"===e.tileClass||"themes__thumb"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)a=p[r],["xaxis","yaxis","zaxis"].indexOf(a.slice(0,5))>-1&&(h[p[r]].title={text:""});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,"pie-like")&&(d.textposition="none")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var g=Object.keys(h).filter(function(t){return t.match(/^scene\d*$/)});if(g.length){var v={};for("thumbnail"===e.tileClass&&(v={title:{text:""},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var m=h[g[r]];m.xaxis||(m.xaxis={}),m.yaxis||(m.yaxis={}),m.zaxis||(m.zaxis={}),i(m.xaxis,v),i(m.yaxis,v),i(m.zaxis,v),m._scene=null}}var y=document.createElement("div");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return"transparent"!==e.setBackground&&(x.config.setBackground=e.setBackground||"opaque"),x.gd.defaultLayout=s(e.tileClass),x}},{"../lib":716,"../registry":845}],847:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plot_api/to_image"),i=t("./filesaver"),o=t("./helpers");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||"png",e.imageDataOnly=!0,new Promise(function(s,l){r&&r._snapshotInProgress&&l(new Error("Snapshotting already in progress.")),n.isIE()&&"svg"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=a(t,e),u=e.filename||t.fn||"newplot";u+="."+e.format,c.then(function(t){return r&&(r._snapshotInProgress=!1),i(t,u,e.format)}).then(function(t){s(t)}).catch(function(t){r&&(r._snapshotInProgress=!1),l(t)})})}},{"../lib":716,"../plot_api/to_image":757,"./filesaver":848,"./helpers":849}],848:[function(t,e,r){"use strict";var n=t("../lib"),a=t("./helpers");e.exports=function(t,e,r){var i=document.createElement("a"),o="download"in i;return new Promise(function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error("IE < 10 unsupported")),n.isSafari()){var h="svg"===r?",":";base64,";return a.octetStream(h+encodeURIComponent(t)),s(e)}return n.isIE()?(c=a.createBlob(t,"svg"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=a.createBlob(t,r),u=a.createObjectURL(c),i.href=u,i.download=e,document.body.appendChild(i),i.click(),document.body.removeChild(i),a.revokeObjectURL(u),c=null,s(e)):void l(new Error("download error"))})}},{"../lib":716,"./helpers":849}],849:[function(t,e,r){"use strict";var n=t("../registry");r.getDelay=function(t){return t._has&&(t._has("gl3d")||t._has("gl2d")||t._has("mapbox"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has("polar"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod("colorbar","draw")(t)}},r.encodeSVG=function(t){return"data:image/svg+xml,"+encodeURIComponent(t)};var a=window.URL||window.webkitURL;r.createObjectURL=function(t){return a.createObjectURL(t)},r.revokeObjectURL=function(t){return a.revokeObjectURL(t)},r.createBlob=function(t,e){if("svg"===e)return new window.Blob([t],{type:"image/svg+xml;charset=utf-8"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),a=0;a<e;a++)n[a]=t.charCodeAt(a);return r}(window.atob(t));return new window.Blob([r],{type:"image/"+e})},r.octetStream=function(t){document.location.href="data:application/octet-stream"+t},r.IMAGE_URL_PREFIX=/^data:image\/\w+;base64,/,r.MSG_IE_BAD_FORMAT="Sorry IE does not support downloading from canvas. Try {format:'svg'} instead."},{"../registry":845}],850:[function(t,e,r){"use strict";var n=t("./helpers"),a={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t("./cloneplot"),toSVG:t("./tosvg"),svgToImg:t("./svgtoimg"),toImage:t("./toimage"),downloadImage:t("./download")};e.exports=a},{"./cloneplot":846,"./download":847,"./helpers":849,"./svgtoimg":851,"./toimage":852,"./tosvg":853}],851:[function(t,e,r){"use strict";var n=t("../lib"),a=t("events").EventEmitter,i=t("./helpers");e.exports=function(t){var e=t.emitter||new a,r=new Promise(function(a,o){var s=window.Image,l=t.svg,c=t.format||"png";if(n.isIE()&&"svg"!==c){var u=new Error(i.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit("error",u)}var h,f,p=t.canvas,d=t.scale||1,g=t.width||300,v=t.height||150,m=d*g,y=d*v,x=p.getContext("2d"),b=new s;"svg"===c||n.isIE9orBelow()||n.isSafari()?f=i.encodeSVG(l):(h=i.createBlob(l,"svg"),f=i.createObjectURL(h)),p.width=m,p.height=y,b.onload=function(){var r;switch(h=null,i.revokeObjectURL(f),"svg"!==c&&x.drawImage(b,0,0,m,y),c){case"jpeg":r=p.toDataURL("image/jpeg");break;case"png":r=p.toDataURL("image/png");break;case"webp":r=p.toDataURL("image/webp");break;case"svg":r=f;break;default:var n="Image format is not jpeg, png, svg or webp.";if(o(new Error(n)),!t.promise)return e.emit("error",n)}a(r),t.promise||e.emit("success",r)},b.onerror=function(r){if(h=null,i.revokeObjectURL(f),o(r),!t.promise)return e.emit("error",r)},b.src=f});return t.promise?r:e}},{"../lib":716,"./helpers":849,events:105}],852:[function(t,e,r){"use strict";var n=t("events").EventEmitter,a=t("../registry"),i=t("../lib"),o=t("./helpers"),s=t("./cloneplot"),l=t("./tosvg"),c=t("./svgtoimg");e.exports=function(t,e){var r=new n,u=s(t,{format:"png"}),h=u.gd;h.style.position="absolute",h.style.left="-5000px",document.body.appendChild(h);var f=o.getRedrawFunc(h);return a.call("plot",h,u.data,u.layout,u.config).then(f).then(function(){var t=o.getDelay(h._fullLayout);setTimeout(function(){var t=l(h),n=document.createElement("canvas");n.id=i.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}},t)}).catch(function(t){r.emit("error",t)}),r}},{"../lib":716,"../registry":845,"./cloneplot":846,"./helpers":849,"./svgtoimg":851,"./tosvg":853,events:105}],853:[function(t,e,r){"use strict";var n=t("d3"),a=t("../lib"),i=t("../components/drawing"),o=t("../components/color"),s=t("../constants/xmlns_namespaces"),l=/"/g,c=new RegExp('("TOBESTRIPPED)|(TOBESTRIPPED")',"g");e.exports=function(t,e,r){var u,h=t._fullLayout,f=h._paper,p=h._toppaper,d=h.width,g=h.height;f.insert("rect",":first-child").call(i.setRect,0,0,d,g).call(o.fill,h.paper_bgcolor);var v=h._basePlotModules||[];for(u=0;u<v.length;u++){var m=v[u];m.toSVG&&m.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&f.node().appendChild(b)}}h._draggers&&h._draggers.remove(),f.node().style.background="",f.selectAll("text").attr({"data-unformatted":null,"data-math":null}).each(function(){var t=n.select(this);if("hidden"!==this.style.visibility&&"none"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('"')&&t.style("font-family",e.replace(l,"TOBESTRIPPED"))}else t.remove()}),f.selectAll(".point, .scatterpts, .legendfill>path, .legendlines>path, .cbfill").each(function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf("url(")&&t.style("fill",e.replace(l,"TOBESTRIPPED"));var r=this.style.stroke;r&&-1!==r.indexOf("url(")&&t.style("stroke",r.replace(l,"TOBESTRIPPED"))}),"pdf"!==e&&"eps"!==e||f.selectAll("#MathJax_SVG_glyphs path").attr("stroke-width",0),f.node().setAttributeNS(s.xmlns,"xmlns",s.svg),f.node().setAttributeNS(s.xmlns,"xmlns:xlink",s.xlink),"svg"===e&&r&&(f.attr("width",r*d),f.attr("height",r*g),f.attr("viewBox","0 0 "+d+" "+g));var _=(new window.XMLSerializer).serializeToString(f.node());return _=function(t){var e=n.select("body").append("div").style({display:"none"}).html(""),r=t.replace(/(&[^;]*;)/gi,function(t){return"&lt;"===t?"&#60;":"&rt;"===t?"&#62;":-1!==t.indexOf("<")||-1!==t.indexOf(">")?"":e.html(t).text()});return e.remove(),r}(_),_=(_=_.replace(/&(?!\w+;|\#[0-9]+;| \#x[0-9A-F]+;)/g,"&amp;")).replace(c,"'"),a.isIE()&&(_=(_=(_=_.replace(/"/gi,"'")).replace(/(\('#)([^']*)('\))/gi,'("#$2")')).replace(/(\\')/gi,'"')),_}},{"../components/color":591,"../components/drawing":612,"../constants/xmlns_namespaces":693,"../lib":716,d3:164}],854:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,"tx"),n.mergeArray(e.hovertext,t,"htx");var a=e.marker;if(a){n.mergeArray(a.opacity,t,"mo",!0),n.mergeArray(a.color,t,"mc");var i=a.line;i&&(n.mergeArray(i.color,t,"mlc"),n.mergeArrayCastPositive(i.width,t,"mlw"))}}},{"../../lib":716}],855:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../../plots/template_attributes").texttemplateAttrs,o=t("../../components/colorscale/attributes"),s=t("../../plots/font_attributes"),l=t("./constants"),c=t("../../lib/extend").extendFlat,u=s({editType:"calc",arrayOk:!0,colorEditType:"style"}),h=c({},n.marker.line.width,{dflt:0}),f=c({width:h,editType:"calc"},o("marker.line")),p=c({line:f,editType:"calc"},o("marker"),{opacity:{valType:"number",arrayOk:!0,dflt:1,min:0,max:1,editType:"style"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,texttemplate:i({editType:"plot"},{keys:l.eventDataKeys}),hovertext:n.hovertext,hovertemplate:a({},{keys:l.eventDataKeys}),textposition:{valType:"enumerated",values:["inside","outside","auto","none"],dflt:"none",arrayOk:!0,editType:"calc"},insidetextanchor:{valType:"enumerated",values:["end","middle","start"],dflt:"end",editType:"plot"},textangle:{valType:"angle",dflt:"auto",editType:"plot"},textfont:c({},u,{}),insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),constraintext:{valType:"enumerated",values:["inside","outside","both","none"],dflt:"both",editType:"calc"},cliponaxis:c({},n.cliponaxis,{}),orientation:{valType:"enumerated",values:["v","h"],editType:"calc+clearAxisTypes"},base:{valType:"any",dflt:null,arrayOk:!0,editType:"calc"},offset:{valType:"number",dflt:null,arrayOk:!0,editType:"calc"},width:{valType:"number",dflt:null,min:0,arrayOk:!0,editType:"calc"},marker:p,offsetgroup:{valType:"string",dflt:"",editType:"calc"},alignmentgroup:{valType:"string",dflt:"",editType:"calc"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:"style"},textfont:n.selected.textfont,editType:"style"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:"style"},textfont:n.unselected.textfont,editType:"style"},r:n.r,t:n.t,_deprecated:{bardir:{valType:"enumerated",editType:"calc",values:["v","h"]}}}},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/font_attributes":790,"../../plots/template_attributes":840,"../scatter/attributes":1118,"./constants":857}],856:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/calc"),o=t("./arrays_to_calcdata"),s=t("../scatter/calc_selection");e.exports=function(t,e){var r,l,c=n.getFromId(t,e.xaxis||"x"),u=n.getFromId(t,e.yaxis||"y");"h"===e.orientation?(r=c.makeCalcdata(e,"x"),l=u.makeCalcdata(e,"y")):(r=u.makeCalcdata(e,"y"),l=c.makeCalcdata(e,"x"));for(var h=Math.min(l.length,r.length),f=new Array(h),p=0;p<h;p++)f[p]={p:l[p],s:r[p]},e.ids&&(f[p].id=String(e.ids[p]));return a(e,"marker")&&i(t,e,{vals:e.marker.color,containerStr:"marker",cLetter:"c"}),a(e,"marker.line")&&i(t,e,{vals:e.marker.line.color,containerStr:"marker.line",cLetter:"c"}),o(f,e),s(f,e),f}},{"../../components/colorscale/calc":599,"../../components/colorscale/helpers":602,"../../plots/cartesian/axes":764,"../scatter/calc_selection":1120,"./arrays_to_calcdata":854}],857:[function(t,e,r){"use strict";e.exports={TEXTPAD:3,eventDataKeys:["value","label"]}},{}],858:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib").isArrayOrTypedArray,i=t("../../constants/numerical").BADNUM,o=t("../../registry"),s=t("../../plots/cartesian/axes"),l=t("../../plots/cartesian/axis_ids").getAxisGroup,c=t("./sieve.js");function u(t,e,r,o,u){if(o.length){var b,_,w,k;switch(function(t,e){var r,i;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c="funnel"===l.type?l._base:l.base,u="h"===l.orientation?l.xcalendar:l.ycalendar,h="category"===t.type||"multicategory"===t.type?function(){return null}:t.d2c;if(a(c)){for(i=0;i<Math.min(c.length,s.length);i++)o=h(c[i],0,u),n(o)?(s[i].b=+o,s[i].hasB=1):s[i].b=0;for(;i<s.length;i++)s[i].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,i=0;i<s.length;i++)s[i].b=o,f&&(s[i].hasB=1)}}}(r,o),u.mode){case"overlay":h(e,r,o,u);break;case"group":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.offset?_.push(k):b.push(k);_.length&&function(t,e,r,n,a){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!a.norm});(function(t,e,r,n){for(var a=t._fullLayout,i=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=i.length!==o.length,f=s*(1-n.gap),v=l(a,e._id)+c[0][0].trace.orientation,m=a._alignmentOpts[v]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,k=m[w.alignmentgroup]||{},T=Object.keys(k.offsetGroups||{}).length,A=(x=T?f/T:h?f/u:f)*(1-(n.groupgap||0));b=T?((2*w._offsetIndex+1-T)*x-A)/2:h?((2*y+1-u)*x-A)/2:-A/2;var M=_[0].t;M.barwidth=A,M.poffset=b,M.bargroupwidth=f,M.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,h)})(t,e,o,a),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r],a=n[0].trace;if(void 0===a.base)for(var o=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),s=0;s<n.length;s++){var l=n[s];if(l.p!==i){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o),a.norm?(m(o),y(r,o,a)):v(r,o)}(t,e,r,_,u),b.length&&h(e,r,b,u);break;case"stack":case"relative":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.base?_.push(k):b.push(k);_.length&&function(t,e,r,n,a){var o=new c(n,{sepNegVal:"relative"===a.mode,overlapNoMerge:!(a.norm||"stack"===a.mode||"relative"===a.mode)});f(e,o,a),function(t,e,r){var n,a,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(n=f[l],"funnel"===(a=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==i&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){n=f[l],a=n[0].trace,o="funnel"===a.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==i){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),v=g+d;u.b=g,u[h]=v,r.norm||(p.push(v),u.hasB&&p.push(g))}r.norm||(a._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,a);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];if(p.s!==i){var d=p.b+p.s===o.get(p.p,p.s);d&&(p._outmost=!0)}}a.norm&&y(r,o,a)}(0,e,r,_,u),b.length&&h(e,r,b,u)}!function(t,e){var r,a,i,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(i=t[r],a=0;a<i.length;a++){var u=i[a].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var h=1e4/(c-l),f=s.round=function(t){return String(Math.round(h*(t-l)))};for(r=0;r<t.length;r++){(i=t[r])[0].t.extents=s;var p=i[0].t.poffset,d=Array.isArray(p);for(a=0;a<i.length;a++){var g=i[a],v=g[o]-g.w/2;if(n(v)){var m=g[o]+g.w/2,y=f(g.p);s[y]?s[y]=[Math.min(v,s[y][0]),Math.max(m,s[y][1])]:s[y]=[v,m]}g.p0=g.p+(d?p[a]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function h(t,e,r,n){for(var a=0;a<r.length;a++){var i=r[a],o=new c([i],{sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(m(o),y(e,o,n)):v(e,o)}}function f(t,e,r){for(var n=e.minDiff,a=e.traces,i=n*(1-r.gap),o=i*(1-(r.groupgap||0)),s=-o/2,l=0;l<a.length;l++){var c=a[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=i,c.bardelta=n}e.binWidth=a[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,i=t.traces;for(e=0;e<i.length;e++){var o,s=i[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(a(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(a(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),a=0;a<r.length;a++)for(var i=r[a],o=i[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),h=0;h<i.length;h++){var f=i[h],p=f.w=u?c[h]:c;f[n]=f.p+(l?s[h]:s)+p/2}}function g(t,e,r){var n=e.traces,a=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var i=0;i<n.length;i++){var o,l,c,u,h=n[i],f=h[0],p=f.trace,d=[];for(u=0;u<h.length;u++)l=(o=h[u]).p-a,c=o.p+a,d.push(l,c);if(p.width||p.offset){var g=f.t,v=g.poffset,m=g.barwidth,y=Array.isArray(v),x=Array.isArray(m);for(u=0;u<h.length;u++){o=h[u];var b=y?v[u]:v,_=x?m[u]:m;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function v(t,e){for(var r=e.traces,n=x(t),a=0;a<r.length;a++){for(var i=r[a],o=i[0].trace,l=[],c=!0,u=0;u<i.length;u++){var h=i[u],f=h.b,p=f+h.s;h[n]=p,l.push(p),h.hasB&&l.push(f),h.hasB&&h.b>0&&h.s>0||(c=!1)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:!c,padded:!0})}}function m(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],a=0;a<n.length;a++){var o=n[a];o.s!==i&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var a=e.traces,o=x(t),l="fraction"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h="stack"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<a.length;p++){for(var d=a[p],g=d[0].trace,v=[],m=!0,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==i){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var k=_.b,T=k+_.s;_[o]=T,v.push(T),y=y||f(T),_.hasB&&(v.push(k),y=y||f(k)),_.hasB&&_.b>0&&_.s>0||(m=!1)}}g._extremes[t._id]=s.findExtremes(t,v,{tozero:!m,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,a=t._fullLayout,i=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<i.length;h++){var f=i[h];!0===f.visible&&o.traceIs(f,"bar")&&f.xaxis===r._id&&f.yaxis===n._id&&("h"===f.orientation?l.push(s[h]):c.push(s[h]))}var p={mode:a.barmode,norm:a.barnorm,gap:a.bargap,groupgap:a.bargroupgap};u(t,r,n,c,p),u(t,n,r,l,p)},setGroupPositions:u}},{"../../constants/numerical":692,"../../lib":716,"../../plots/cartesian/axes":764,"../../plots/cartesian/axis_ids":767,"../../registry":845,"./sieve.js":868,"fast-isnumeric":227}],859:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../../registry"),o=t("../scatter/xy_defaults"),s=t("./style_defaults"),l=t("../../plots/cartesian/axis_ids").getAxisGroup,c=t("./attributes"),u=n.coerceFont;function h(t,e,r,n){var a=e.orientation,i=e[{v:"x",h:"y"}[a]+"axis"],o=l(r,i)+a,s=r._alignmentOpts||{},c=n("alignmentgroup"),u=s[o];u||(u=s[o]={});var h=u[c];h?h.traces.push(e):h=u[c]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=n("offsetgroup"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function f(t,e,r,a,i,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),h=!(!1===o.moduleHasCliponaxis),f=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=Array.isArray(i)||"auto"===i,g=d||"inside"===i,v=d||"outside"===i;if(g||v){var m=u(a,"textfont",r.font),y=n.extendFlat({},m);!(t.textfont&&t.textfont.color)&&delete y.color,u(a,"insidetextfont",y),v&&u(a,"outsidetextfont",m),s&&a("selected.textfont.color"),l&&a("unselected.textfont.color"),c&&a("constraintext"),h&&a("cliponaxis"),f&&a("textangle"),a("texttemplate")}g&&p&&a("insidetextanchor")}e.exports={supplyDefaults:function(t,e,r,l){function u(r,a){return n.coerce(t,e,c,r,a)}if(o(t,e,l,u)){u("orientation",e.x&&!e.y?"h":"v"),u("base"),u("offset"),u("width"),u("text"),u("hovertext"),u("hovertemplate");var h=u("textposition");f(t,0,l,u,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),s(t,e,u,r,l);var p=(e.marker.line||{}).color,d=i.getComponentMethod("errorbars","supplyDefaults");d(t,e,p||a.defaultLine,{axis:"y"}),d(t,e,p||a.defaultLine,{axis:"x",inherit:"y"}),n.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function a(t){return n.coerce(r._input,r,c,t)}if("group"===e.barmode)for(var i=0;i<t.length;i++)"bar"===(r=t[i]).type&&(r._input,h(0,r,e,a))},handleGroupingDefaults:h,handleText:f}},{"../../components/color":591,"../../lib":716,"../../plots/cartesian/axis_ids":767,"../../registry":845,"../scatter/xy_defaults":1144,"./attributes":855,"./style_defaults":870}],860:[function(t,e,r){"use strict";e.exports=function(t,e,r){return t.x="xVal"in e?e.xVal:e.x,t.y="yVal"in e?e.yVal:e.y,e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),"h"===r.orientation?(t.label=t.y,t.value=t.x):(t.label=t.x,t.value=t.y),t}},{}],861:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("tinycolor2"),i=t("../../lib").isArrayOrTypedArray;r.coerceString=function(t,e,r){if("string"==typeof e){if(e||!t.noBlank)return e}else if(("number"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var a=t.min,i=t.max;if(!(void 0!==a&&e<a||void 0!==i&&e>i))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return a(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:i(t.marker.line.width)?0:t.marker.line.width}},{"../../lib":716,"fast-isnumeric":227,tinycolor2:535}],862:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../registry"),i=t("../../components/color"),o=t("../../lib").fillText,s=t("./helpers").getLineWidth,l=t("../../plots/cartesian/axes").hoverLabelText;function c(t,e,r,a){var i,s,c,u,h,f,p,d=t.cd,g=d[0].trace,v=d[0].t,m="closest"===a,y="waterfall"===g.type,x=t.maxHoverDistance,b=t.maxSpikeDistance;function _(t){return t[c]-t.w/2}function w(t){return t[c]+t.w/2}var k=m?_:function(t){return Math.min(_(t),t.p-v.bardelta/2)},T=m?w:function(t){return Math.max(w(t),t.p+v.bardelta/2)};function A(t,e){return n.inbox(t-i,e-i,x+Math.min(1,Math.abs(e-t)/p)-1)}function M(t){return A(k(t),T(t))}function S(t){var e=s,r=t.b,a=t[u];return y&&(a+=Math.abs(t.rawS||0)),n.inbox(r-e,a-e,x+(a-e)/(a-r)-1)}"h"===g.orientation?(i=r,s=e,c="y",u="x",h=S,f=M):(i=e,s=r,c="x",u="y",f=S,h=M);var E=t[c+"a"],L=t[u+"a"];p=Math.abs(E.r2c(E.range[1])-E.r2c(E.range[0]));var C=n.getDistanceFunction(a,h,f,function(t){return(h(t)+f(t))/2});if(n.getClosest(d,C,t),!1!==t.index){m||(k=function(t){return Math.min(_(t),t.p-v.bargroupwidth/2)},T=function(t){return Math.max(w(t),t.p+v.bargroupwidth/2)});var P=d[t.index],O=g.base?P.b+P.s:P.s;t[u+"0"]=t[u+"1"]=L.c2p(P[u],!0),t[u+"LabelVal"]=O;var z=v.extents[v.extents.round(P.p)];return t[c+"0"]=E.c2p(m?k(P):z[0],!0),t[c+"1"]=E.c2p(m?T(P):z[1],!0),t[c+"LabelVal"]=P.p,t.labelLabel=l(E,t[c+"LabelVal"]),t.valueLabel=l(L,t[u+"LabelVal"]),t.spikeDistance=(S(P)+function(t){return A(_(t),w(t))}(P))/2+b-x,t[c+"Spike"]=E.c2p(P.p,!0),o(P,g,t),t.hovertemplate=g.hovertemplate,t}}function u(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,a=s(t,e);return i.opacity(r)?r:i.opacity(n)&&a?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var i=c(t,e,r,n);if(i){var o=i.cd,s=o[0].trace,l=o[i.index];return i.color=u(s,l),a.getComponentMethod("errorbars","hoverInfo")(l,s,i),[i]}},hoverOnBars:c,getTraceColor:u}},{"../../components/color":591,"../../components/fx":629,"../../lib":716,"../../plots/cartesian/axes":764,"../../registry":845,"./helpers":861}],863:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults").supplyDefaults,crossTraceDefaults:t("./defaults").crossTraceDefaults,supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc"),crossTraceCalc:t("./cross_trace_calc").crossTraceCalc,colorbar:t("../scatter/marker_colorbar"),arraysToCalcdata:t("./arrays_to_calcdata"),plot:t("./plot").plot,style:t("./style").style,styleOnSelect:t("./style").styleOnSelect,hoverPoints:t("./hover").hoverPoints,eventData:t("./event_data"),selectPoints:t("./select"),moduleType:"trace",name:"bar",basePlotModule:t("../../plots/cartesian"),categories:["bar-like","cartesian","svg","bar","oriented","errorBarsOK","showLegend","zoomScale"],animatable:!0,meta:{}}},{"../../plots/cartesian":775,"../scatter/marker_colorbar":1136,"./arrays_to_calcdata":854,"./attributes":855,"./calc":856,"./cross_trace_calc":858,"./defaults":859,"./event_data":860,"./hover":862,"./layout_attributes":864,"./layout_defaults":865,"./plot":866,"./select":867,"./style":869}],864:[function(t,e,r){"use strict";e.exports={barmode:{valType:"enumerated",values:["stack","group","overlay","relative"],dflt:"group",editType:"calc"},barnorm:{valType:"enumerated",values:["","fraction","percent"],dflt:"",editType:"calc"},bargap:{valType:"number",min:0,max:1,editType:"calc"},bargroupgap:{valType:"number",min:0,max:1,dflt:0,editType:"calc"}}},{}],865:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../plots/cartesian/axes"),i=t("../../lib"),o=t("./layout_attributes");e.exports=function(t,e,r){function s(r,n){return i.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,h={},f=s("barmode"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,"bar")&&d.visible){if(l=!0,"group"===f){var g=d.xaxis+d.yaxis;h[g]&&(u=!0),h[g]=!0}if(d.visible&&"histogram"===d.type)"category"!==a.getFromId({_fullLayout:e},d["v"===d.orientation?"xaxis":"yaxis"]).type&&(c=!0)}}l?("overlay"!==f&&s("barnorm"),s("bargap",c&&!u?0:.2),s("bargroupgap")):delete e.barmode}},{"../../lib":716,"../../plots/cartesian/axes":764,"../../registry":845,"./layout_attributes":864}],866:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../lib"),o=t("../../lib/svg_text_utils"),s=t("../../components/color"),l=t("../../components/drawing"),c=t("../../registry"),u=t("../../plots/cartesian/axes").tickText,h=t("./style"),f=t("./helpers"),p=t("./constants"),d=t("./attributes"),g=d.text,v=d.textposition,m=t("../../components/fx/helpers").appendArrayPointValue,y=p.TEXTPAD;function x(t){return t.id}function b(t){if(t.ids)return x}function _(t,e){return t<e?1:-1}function w(t,e,r){var n;return k(e)?(r&&(n=r()),t.transition().duration(e.duration).ease(e.easing).each("end",function(){n&&n()}).each("interrupt",function(){n&&n()})):t}function k(t){return t&&t.duration>0}function T(t){return"auto"===t?0:t}function A(t,e,r,n,a,i){var o=!!i.isHorizontal,s=!!i.constrained,l=i.angle||0,c=i.anchor||0,u=a.width,h=a.height,f=Math.abs(e-t),p=Math.abs(n-r),d=f>2*y&&p>2*y?y:0;f-=2*d,p-=2*d;var g=!1;if(!("auto"===l)||u<=f&&h<=p||!(u>f||h>p)||(u>p||h>f)&&u<h==f<p||(g=!0),g){var v=p;p=f,f=v}var m=T(l),x=Math.abs(Math.sin(Math.PI/180*m)),b=Math.abs(Math.cos(Math.PI/180*m)),w=Math.max(f*b,p*x),k=Math.max(f*x,p*b),A=s?Math.min(w/u,k/h):Math.max(b,x);A=Math.min(1,A);var M=(t+e)/2,S=(r+n)/2;"middle"!==c&&(d+=.5*(A*(o!==g?h:u)*x+A*(o!==g?u:h)*b),o?(d*=_(t,e),M="start"===c?t+d:e-d):(d*=_(r,n),S="start"===c?r+d:n-d));return g&&(m+=90),{textX:(a.left+a.right)/2,textY:(a.top+a.bottom)/2,targetX:M,targetY:S,scale:A,rotate:m}}function M(t,e,r,n,a,i){var o,s=!!i.isHorizontal,l=!!i.constrained,c=i.angle||0,u=a.width,h=a.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*y?y:0:f>2*y?y:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var g=T(c);o+=.5*(d*(s?h:u)*Math.abs(Math.sin(Math.PI/180*g))+d*(s?u:h)*Math.abs(Math.cos(Math.PI/180*g)));var v=(t+e)/2,m=(r+n)/2;return s?v=e-o*_(e,t):m=n+o*_(r,n),{textX:(a.left+a.right)/2,textY:(a.top+a.bottom)/2,targetX:v,targetY:m,scale:d,rotate:g}}e.exports={plot:function(t,e,r,p,d,x){var T=e.xaxis,S=e.yaxis,E=t._fullLayout;d||(d={mode:E.barmode,norm:E.barmode,gap:E.bargap,groupgap:E.bargroupgap});var L=i.makeTraceGroups(p,r,"trace bars").each(function(r){var c=n.select(this),p=r[0].trace,E="waterfall"===p.type,L="funnel"===p.type,C="bar"===p.type||L,P=0;E&&p.connector.visible&&"between"===p.connector.mode&&(P=p.connector.line.width/2);var O="h"===p.orientation,z=i.ensureSingle(c,"g","points"),I=b(p),D=z.selectAll("g.point").data(i.identity,I);D.enter().append("g").classed("point",!0),D.exit().remove(),D.each(function(c,b){var E,L,z=n.select(this),I=function(t,e,r,n){var a=[],i=[],o=n?e:r,s=n?r:e;return a[0]=o.c2p(t.s0,!0),i[0]=s.c2p(t.p0,!0),a[1]=o.c2p(t.s1,!0),i[1]=s.c2p(t.p1,!0),n?[a,i]:[i,a]}(c,T,S,O),D=I[0][0],R=I[0][1],F=I[1][0],B=I[1][1],N=!(D!==R&&F!==B&&a(D)&&a(R)&&a(F)&&a(B));if(N&&C&&f.getLineWidth(p,c)&&(O?R-D==0:B-F==0)&&(N=!1),c.isBlank=N,N&&O&&(R=D),N&&!O&&(B=F),P&&!N&&(O?(D-=_(D,R)*P,R+=_(D,R)*P):(F-=_(F,B)*P,B+=_(F,B)*P)),"waterfall"===p.type){if(!N){var j=p[c.dir].marker;E=j.line.width,L=j.color}}else E=f.getLineWidth(p,c),L=c.mc||p.marker.color;var V=n.round(E/2%1,2);function U(t){return 0===d.gap&&0===d.groupgap?n.round(Math.round(t)-V,2):t}if(!t._context.staticPlot){var q=s.opacity(L)<1||E>.01?U:function(t,e){return Math.abs(t-e)>=2?U(t):t>e?Math.ceil(t):Math.floor(t)};D=q(D,R),R=q(R,D),F=q(F,B),B=q(B,F)}var H=w(i.ensureSingle(z,"path"),d,x);if(H.style("vector-effect","non-scaling-stroke").attr("d","M"+D+","+F+"V"+B+"H"+R+"V"+F+"Z").call(l.setClipUrl,e.layerClipId,t),k(d)){var G=l.makePointStyleFns(p);l.singlePointStyle(c,H,p,G,t)}!function(t,e,r,n,a,s,c,p,d,x,b){var _,k=e.xaxis,T=e.yaxis,S=t._fullLayout;function E(e,r,n){var a=i.ensureSingle(e,"text").text(r).attr({class:"bartext bartext-"+_,"text-anchor":"middle","data-notex":1}).call(l.font,n).call(o.convertToTspans,t);return a}var L=n[0].trace,C="h"===L.orientation,P=function(t,e,r,n,a){var o,s=e[0].trace;return o=s.texttemplate?function(t,e,r,n,a){var o=e[0].trace,s=i.castOption(o,r,"texttemplate");if(!s)return"";var l,c,h,f,p="waterfall"===o.type,d="funnel"===o.type;function g(t){return u(f,+t,!0).text}"h"===o.orientation?(l="y",c=a,h="x",f=n):(l="x",c=n,h="y",f=a);var v,y=e[r],x={};x.label=y.p,x.labelLabel=x[l+"Label"]=(v=y.p,u(c,v,!0).text);var b=i.castOption(o,y.i,"text");(0===b||b)&&(x.text=b),x.value=y.s,x.valueLabel=x[h+"Label"]=g(y.s);var _={};m(_,o,y.i),p&&(x.delta=+y.rawS||y.s,x.deltaLabel=g(x.delta),x.final=y.v,x.finalLabel=g(x.final),x.initial=x.final-x.delta,x.initialLabel=g(x.initial)),d&&(x.value=y.s,x.valueLabel=g(x.value),x.percentInitial=y.begR,x.percentInitialLabel=i.formatPercent(y.begR),x.percentPrevious=y.difR,x.percentPreviousLabel=i.formatPercent(y.difR),x.percentTotal=y.sumR,x.percenTotalLabel=i.formatPercent(y.sumR));var w=i.castOption(o,y.i,"customdata");return w&&(x.customdata=w),i.texttemplateString(s,x,t._d3locale,_,x,o._meta||{})}(t,e,r,n,a):s.textinfo?function(t,e,r,n){var a=t[0].trace,o="h"===a.orientation,s="waterfall"===a.type,l="funnel"===a.type;function c(t){var e=o?r:n;return u(e,+t,!0).text}var h,f,p=a.textinfo,d=t[e],g=p.split("+"),v=[],m=function(t){return-1!==g.indexOf(t)};if(m("label")&&v.push((f=t[e].p,u(o?n:r,f,!0).text)),m("text")&&(0===(h=i.castOption(a,d.i,"text"))||h)&&v.push(h),s){var y=+d.rawS||d.s,x=d.v,b=x-y;m("initial")&&v.push(c(b)),m("delta")&&v.push(c(y)),m("final")&&v.push(c(x))}if(l){m("value")&&v.push(c(d.s));var _=0;m("percent initial")&&_++,m("percent previous")&&_++,m("percent total")&&_++;var w=_>1;m("percent initial")&&(h=i.formatPercent(d.begR),w&&(h+=" of initial"),v.push(h)),m("percent previous")&&(h=i.formatPercent(d.difR),w&&(h+=" of previous"),v.push(h)),m("percent total")&&(h=i.formatPercent(d.sumR),w&&(h+=" of total"),v.push(h))}return v.join("<br>")}(e,r,n,a):f.getValue(s.text,r),f.coerceString(g,o)}(S,n,a,k,T);_=function(t,e){var r=f.getValue(t.textposition,e);return f.coerceEnumerated(v,r)}(L,a);var O="stack"===x.mode||"relative"===x.mode,z=n[a],I=!O||z._outmost;if(P&&"none"!==_&&(!z.isBlank&&s!==c&&p!==d||"auto"!==_&&"inside"!==_)){var D=S.font,R=h.getBarColor(n[a],L),F=h.getInsideTextFont(L,a,D,R),B=h.getOutsideTextFont(L,a,D),N=r.datum();C?"log"===k.type&&N.s0<=0&&(s=k.range[0]<k.range[1]?0:k._length):"log"===T.type&&N.s0<=0&&(p=T.range[0]<T.range[1]?T._length:0);var j,V,U,q,H,G,Y=Math.abs(c-s)-2*y,W=Math.abs(d-p)-2*y;if("outside"===_&&(I||z.hasB||(_="inside")),"auto"===_)if(I){_="inside",j=E(r,P,F),V=l.bBox(j.node()),U=V.width,q=V.height;var X=U>0&&q>0,Z=U<=Y&&q<=W,J=U<=W&&q<=Y,K=C?Y>=U*(W/q):W>=q*(Y/U);X&&(Z||J||K)?_="inside":(_="outside",j.remove(),j=null)}else _="inside";if(!j){var Q=(j=E(r,P,"outside"===_?B:F)).attr("transform");if(j.attr("transform",""),V=l.bBox(j.node()),U=V.width,q=V.height,j.attr("transform",Q),U<=0||q<=0)return void j.remove()}"outside"===_?(G="both"===L.constraintext||"outside"===L.constraintext,H=i.getTextTransform(M(s,c,p,d,V,{isHorizontal:C,constrained:G,angle:L.textangle}))):(G="both"===L.constraintext||"inside"===L.constraintext,H=i.getTextTransform(A(s,c,p,d,V,{isHorizontal:C,constrained:G,angle:L.textangle,anchor:L.insidetextanchor}))),w(j,x,b).attr("transform",H)}else r.select("text").remove()}(t,e,z,r,b,D,R,F,B,d,x),e.layerClipId&&l.hideOutsideRangePoint(c,z.select("text"),T,S,p.xcalendar,p.ycalendar)});var R=!1===p.cliponaxis;l.setClipUrl(c,R?null:e.layerClipId,t)});c.getComponentMethod("errorbars","plot")(t,L,e,d)},toMoveInsideBar:A,toMoveOutsideBar:M}},{"../../components/color":591,"../../components/drawing":612,"../../components/fx/helpers":626,"../../lib":716,"../../lib/svg_text_utils":740,"../../plots/cartesian/axes":764,"../../registry":845,"./attributes":855,"./constants":857,"./helpers":861,"./style":869,d3:164,"fast-isnumeric":227}],867:[function(t,e,r){"use strict";function n(t,e,r,n,a){var i=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return a?[(i+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(i+o)/2,l]}e.exports=function(t,e){var r,a=t.cd,i=t.xaxis,o=t.yaxis,s=a[0].trace,l="funnel"===s.type,c="h"===s.orientation,u=[];if(!1===e)for(r=0;r<a.length;r++)a[r].selected=0;else for(r=0;r<a.length;r++){var h=a[r],f="ct"in h?h.ct:n(h,i,o,c,l);e.contains(f,!1,r,t)?(u.push({pointNumber:r,x:i.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},{}],868:[function(t,e,r){"use strict";e.exports=i;var n=t("../../lib").distinctVals,a=t("../../constants/numerical").BADNUM;function i(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,i=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==a&&i.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=i;var u=n(i);this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}i.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},i.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},i.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?"v":"^")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{"../../constants/numerical":692,"../../lib":716}],869:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../../components/drawing"),o=t("../../lib"),s=t("../../registry"),l=t("./attributes"),c=l.textfont,u=l.insidetextfont,h=l.outsidetextfont,f=t("./helpers");function p(t,e,r){i.pointStyle(t.selectAll("path"),e,r),d(t,e,r)}function d(t,e,r){t.selectAll("text").each(function(t){var a=n.select(this),o=g(a,t,e,r);i.font(a,o)})}function g(t,e,r,n){var a=n._fullLayout.font,i=r.textfont;if(t.classed("bartext-inside")){var o=b(e,r);i=m(r,e.i,a,o)}else t.classed("bartext-outside")&&(i=y(r,e.i,a));return i}function v(t,e,r){return x(c,t.textfont,e,r)}function m(t,e,r,n){var i=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(i={color:a.contrast(n),family:i.family,size:i.size}),x(u,t.insidetextfont,e,i)}function y(t,e,r){var n=v(t,e,r);return x(h,t.outsidetextfont,e,n)}function x(t,e,r,n){e=e||{};var a=f.getValue(e.family,r),i=f.getValue(e.size,r),o=f.getValue(e.color,r);return{family:f.coerceString(t.family,a,n.family),size:f.coerceNumber(t.size,i,n.size),color:f.coerceColor(t.color,o,n.color)}}function b(t,e){return"waterfall"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll("g.barlayer").selectAll("g.trace"),r=e.size(),a=t._fullLayout;e.style("opacity",function(t){return t[0].trace.opacity}).each(function(t){("stack"===a.barmode&&r>1||0===a.bargap&&0===a.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr("shape-rendering","crispEdges")}),e.selectAll("g.points").each(function(e){p(n.select(this),e[0].trace,t)}),s.getComponentMethod("errorbars","style")(e)},styleTextPoints:d,styleOnSelect:function(t,e,r){var a=e[0].trace;a.selectedpoints?function(t,e,r){i.selectedPointStyle(t.selectAll("path"),e),function(t,e,r){t.each(function(t){var a,s=n.select(this);if(t.selected){a=o.extendFlat({},g(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(a.color=l),i.font(s,a)}else i.selectedTextStyle(s,e)})}(t.selectAll("text"),e,r)}(r,a,t):(p(r,a,t),s.getComponentMethod("errorbars","style")(r))},getInsideTextFont:m,getOutsideTextFont:y,getBarColor:b}},{"../../components/color":591,"../../components/drawing":612,"../../lib":716,"../../registry":845,"./attributes":855,"./helpers":861,d3:164}],870:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/defaults");e.exports=function(t,e,r,o,s){r("marker.color",o),a(t,"marker")&&i(t,e,s,r,{prefix:"marker.",cLetter:"c"}),r("marker.line.color",n.defaultLine),a(t,"marker.line")&&i(t,e,s,r,{prefix:"marker.line.",cLetter:"c"}),r("marker.line.width"),r("marker.opacity"),r("selected.marker.color"),r("unselected.marker.color")}},{"../../components/color":591,"../../components/colorscale/defaults":601,"../../components/colorscale/helpers":602}],871:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../lib/extend").extendFlat,i=t("../scatterpolar/attributes"),o=t("../bar/attributes");e.exports={r:i.r,theta:i.theta,r0:i.r0,dr:i.dr,theta0:i.theta0,dtheta:i.dtheta,thetaunit:i.thetaunit,base:a({},o.base,{}),offset:a({},o.offset,{}),width:a({},o.width,{}),text:a({},o.text,{}),hovertext:a({},o.hovertext,{}),marker:o.marker,hoverinfo:i.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{"../../lib/extend":707,"../../plots/template_attributes":840,"../bar/attributes":855,"../scatterpolar/attributes":1190}],872:[function(t,e,r){"use strict";var n=t("../../components/colorscale/helpers").hasColorscale,a=t("../../components/colorscale/calc"),i=t("../bar/arrays_to_calcdata"),o=t("../bar/cross_trace_calc").setGroupPositions,s=t("../scatter/calc_selection"),l=t("../../registry").traceIs,c=t("../../lib").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,"r"),h=c.makeCalcdata(e,"theta"),f=e._length,p=new Array(f),d=u,g=h,v=0;v<f;v++)p[v]={p:g[v],s:d[v]};function m(t){var r=e[t];void 0!==r&&(e["_"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return"linear"===c.type&&(m("width"),m("offset")),n(e,"marker")&&a(t,e,{vals:e.marker.color,containerStr:"marker",cLetter:"c"}),n(e,"marker.line")&&a(t,e,{vals:e.marker.line.color,containerStr:"marker.line",cLetter:"c"}),i(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,a=[],i=0;i<n.length;i++){var s=n[i],u=s[0].trace;!0===u.visible&&l(u,"bar")&&u.subplot===r&&a.push(s)}var h=c({},e.radialaxis,{_id:"x"}),f=e.angularaxis;o(t,f,h,a,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{"../../components/colorscale/calc":599,"../../components/colorscale/helpers":602,"../../lib":716,"../../registry":845,"../bar/arrays_to_calcdata":854,"../bar/cross_trace_calc":858,"../scatter/calc_selection":1120}],873:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatterpolar/defaults").handleRThetaDefaults,i=t("../bar/style_defaults"),o=t("./attributes");e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,o,r,a)}a(t,e,s,l)?(l("thetaunit"),l("base"),l("offset"),l("width"),l("text"),l("hovertext"),l("hovertemplate"),i(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{"../../lib":716,"../bar/style_defaults":870,"../scatterpolar/defaults":1192,"./attributes":871}],874:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../lib"),i=t("../bar/hover").getTraceColor,o=a.fillText,s=t("../scatterpolar/hover").makeHoverPointText,l=t("../../plots/polar/helpers").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,g=d?l:a.isPtInsideSector,v=t.maxHoverDistance,m=p._period||2*Math.PI,y=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);f.range[0]>f.range[1]&&(x+=Math.PI);if(n.getClosest(c,function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?v+Math.min(1,Math.abs(t.thetag1-t.thetag0)/m)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0},t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=a.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,h,t),t.hovertemplate=u.hovertemplate,t.color=i(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign="left"),[t]}}},{"../../components/fx":629,"../../lib":716,"../../plots/polar/helpers":827,"../bar/hover":862,"../scatterpolar/hover":1194}],875:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"barpolar",basePlotModule:t("../../plots/polar"),categories:["polar","bar","showLegend"],attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults"),supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc").calc,crossTraceCalc:t("./calc").crossTraceCalc,plot:t("./plot"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("../scatterpolar/format_labels"),style:t("../bar/style").style,styleOnSelect:t("../bar/style").styleOnSelect,hoverPoints:t("./hover"),selectPoints:t("../bar/select"),meta:{}}},{"../../plots/polar":828,"../bar/select":867,"../bar/style":869,"../scatter/marker_colorbar":1136,"../scatterpolar/format_labels":1193,"./attributes":871,"./calc":872,"./defaults":873,"./hover":874,"./layout_attributes":876,"./layout_defaults":877,"./plot":878}],876:[function(t,e,r){"use strict";e.exports={barmode:{valType:"enumerated",values:["stack","overlay"],dflt:"stack",editType:"calc"},bargap:{valType:"number",dflt:.1,min:0,max:1,editType:"calc"}}},{}],877:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e,r){var i,o={};function s(r,o){return n.coerce(t[i]||{},e[i],a,r,o)}for(var l=0;l<r.length;l++){var c=r[l];"barpolar"===c.type&&!0===c.visible&&(o[i=c.subplot]||(s("barmode"),s("bargap"),o[i]=1))}}},{"../../lib":716,"./layout_attributes":876}],878:[function(t,e,r){"use strict";var n=t("d3"),a=t("fast-isnumeric"),i=t("../../lib"),o=t("../../components/drawing"),s=t("../../plots/polar/helpers");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,h=e.angularAxis,f=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,a,o,l){var c,u;i.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=s.findEnclosingVertexAngles(c,t.vangles)[0],f=s.findEnclosingVertexAngles(u,t.vangles)[1],p=[h,(c+u)/2,f];return s.pathPolygonAnnulus(n,a,c,u,p,e,r)};return function(t,n,a,o){return i.pathAnnulus(t,n,a,o,e,r)}}(e),p=e.layers.frontplot.select("g.barlayer");i.makeTraceGroups(p,r,"trace bars").each(function(){var r=n.select(this),s=i.ensureSingle(r,"g","points").selectAll("g.point").data(i.identity);s.enter().append("g").style("vector-effect","non-scaling-stroke").style("stroke-miterlimit",2).classed("point",!0),s.exit().remove(),s.each(function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=h.c2g(t.p0),d=t.thetag1=h.c2g(t.p1);if(a(o)&&a(s)&&a(p)&&a(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),v=(p+d)/2;t.ct=[l.c2p(g*Math.cos(v)),c.c2p(g*Math.sin(v))],e=f(o,s,p,d)}else e="M0,0Z";i.ensureSingle(r,"path").attr("d",e)}),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)})}},{"../../components/drawing":612,"../../lib":716,"../../plots/polar/helpers":827,d3:164,"fast-isnumeric":227}],879:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../bar/attributes"),i=t("../../components/color/attributes"),o=t("../../plots/template_attributes").hovertemplateAttrs,s=t("../../lib/extend").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:"data_array",editType:"calc+clearAxisTypes"},x:{valType:"data_array",editType:"calc+clearAxisTypes"},x0:{valType:"any",editType:"calc+clearAxisTypes"},y0:{valType:"any",editType:"calc+clearAxisTypes"},name:{valType:"string",editType:"calc+clearAxisTypes"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),whiskerwidth:{valType:"number",min:0,max:1,dflt:.5,editType:"calc"},notched:{valType:"boolean",editType:"calc"},notchwidth:{valType:"number",min:0,max:.5,dflt:.25,editType:"calc"},boxpoints:{valType:"enumerated",values:["all","outliers","suspectedoutliers",!1],dflt:"outliers",editType:"calc"},boxmean:{valType:"enumerated",values:[!0,"sd",!1],dflt:!1,editType:"calc"},jitter:{valType:"number",min:0,max:1,editType:"calc"},pointpos:{valType:"number",min:-2,max:2,editType:"calc"},orientation:{valType:"enumerated",values:["v","h"],editType:"calc+clearAxisTypes"},width:{valType:"number",min:0,dflt:0,editType:"calc"},marker:{outliercolor:{valType:"color",dflt:"rgba(0, 0, 0, 0)",editType:"style"},symbol:s({},l.symbol,{arrayOk:!1,editType:"plot"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:"style"}),size:s({},l.size,{arrayOk:!1,editType:"calc"}),color:s({},l.color,{arrayOk:!1,editType:"style"}),line:{color:s({},c.color,{arrayOk:!1,dflt:i.defaultLine,editType:"style"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:"style"}),outliercolor:{valType:"color",editType:"style"},outlierwidth:{valType:"number",min:0,dflt:1,editType:"style"},editType:"style"},editType:"plot"},line:{color:{valType:"color",editType:"style"},width:{valType:"number",min:0,dflt:2,editType:"style"},editType:"plot"},fillcolor:n.fillcolor,offsetgroup:a.offsetgroup,alignmentgroup:a.alignmentgroup,selected:{marker:n.selected.marker,editType:"style"},unselected:{marker:n.unselected.marker,editType:"style"},hoveron:{valType:"flaglist",flags:["boxes","points"],dflt:"boxes+points",editType:"style"}}},{"../../components/color/attributes":590,"../../lib/extend":707,"../../plots/template_attributes":840,"../bar/attributes":855,"../scatter/attributes":1118}],880:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=a._,o=t("../../plots/cartesian/axes");function s(t,e,r){var n={text:"tx",hovertext:"htx"};for(var a in n)Array.isArray(e[a])&&(t[n[a]]=e[a][r])}function l(t,e){return t.v-e.v}function c(t){return t.v}e.exports=function(t,e){var r,u,h,f,p,d=t._fullLayout,g=o.getFromId(t,e.xaxis||"x"),v=o.getFromId(t,e.yaxis||"y"),m=[],y="violin"===e.type?"_numViolins":"_numBoxes";"h"===e.orientation?(u=g,h="x",f=v,p="y"):(u=v,h="y",f=g,p="x");var x,b=u.makeCalcdata(e,h),_=function(t,e,r,i,o){if(e in t)return r.makeCalcdata(t,e);var s;s=e+"0"in t?t[e+"0"]:"name"in t&&("category"===r.type||n(t.name)&&-1!==["linear","log"].indexOf(r.type)||a.isDateTime(t.name)&&"date"===r.type)?t.name:o;var l="multicategory"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+"calendar"]);return i.map(function(){return l})}(e,p,f,b,d[y]),w=a.distinctVals(_),k=w.vals,T=w.minDiff/2,A=function(t,e){for(var r=t.length,n=new Array(r+1),a=0;a<r;a++)n[a]=t[a]-e;return n[r]=t[r-1]+e,n}(k,T),M=k.length,S=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(M);for(r=0;r<e._length;r++){var E=b[r];if(n(E)){var L=a.findBin(_[r],A);if(L>=0&&L<M){var C={v:E,i:r};s(C,e,r),S[L].push(C)}}}var P="all"===(e.boxpoints||e.points)?a.identity:function(t){return t.v<x.lf||t.v>x.uf};for(r=0;r<M;r++)if(S[r].length>0){var O=S[r].sort(l),z=O.map(c),I=z.length;(x={}).pos=k[r],x.pts=O,x[p]=x.pos,x[h]=x.pts.map(function(t){return t.v}),x.min=z[0],x.max=z[I-1],x.mean=a.mean(z,I),x.sd=a.stdev(z,I,x.mean),x.q1=a.interp(z,.25),x.med=a.interp(z,.5),x.q3=a.interp(z,.75),x.lf=Math.min(x.q1,z[Math.min(a.findBin(2.5*x.q1-1.5*x.q3,z,!0)+1,I-1)]),x.uf=Math.max(x.q3,z[Math.max(a.findBin(2.5*x.q3-1.5*x.q1,z),0)]),x.lo=4*x.q1-3*x.q3,x.uo=4*x.q3-3*x.q1;var D=1.57*(x.q3-x.q1)/Math.sqrt(I);x.ln=x.med-D,x.un=x.med+D,x.pts2=O.filter(P),m.push(x)}!function(t,e){if(a.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],i={},o=0;o<n.length;o++)i[n[o].i]=o;a.tagSelected(n,e,i)}}(m,e);var R=o.findExtremes(u,b,{padded:!0});return e._extremes[u._id]=R,m.length>0?(m[0].t={num:d[y],dPos:T,posLetter:p,valLetter:h,labels:{med:i(t,"median:"),min:i(t,"min:"),q1:i(t,"q1:"),q3:i(t,"q3:"),max:i(t,"max:"),mean:"sd"===e.boxmean?i(t,"mean \xb1 \u03c3:"):i(t,"mean:"),lf:i(t,"lower fence:"),uf:i(t,"upper fence:")}},d[y]++,m):[{t:{empty:!0}}]}},{"../../lib":716,"../../plots/cartesian/axes":764,"fast-isnumeric":227}],881:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib"),i=t("../../plots/cartesian/axis_ids").getAxisGroup,o=["v","h"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(o.c2l(c[l].pos,!0)),g+=(c[l].pts2||[]).length;if(d.length){var v=a.distinctVals(d),m=v.minDiff/2;n.minDtick(o,v.minDiff,v.vals[0],!0);var y=h["violin"===t?"_numViolins":"_numBoxes"],x="group"===h[t+"mode"]&&y>1,b=1-h[t+"gap"],_=1-h[t+"groupgap"];for(s=0;s<r.length;s++){var w,k,T,A,M,S,E=(c=u[r[s]])[0].trace,L=c[0].t,C=E.width,P=E.side;if(C)w=k=A=C/2,T=0;else if(w=m,x){var O=i(h,o._id)+E.orientation,z=(h._alignmentOpts[O]||{})[E.alignmentgroup]||{},I=Object.keys(z.offsetGroups||{}).length,D=I||y;k=w*b*_/D,T=2*w*(((I?E._offsetIndex:L.num)+.5)/D-.5)*b,A=w*b/D}else k=w*b*_,T=0,A=w;L.dPos=w,L.bPos=T,L.bdPos=k,L.wHover=A;var R,F,B,N,j,V,U=T+k,q=Boolean(C);if("positive"===P?(M=w*(C?1:.5),R=U,S=R=T):"negative"===P?(M=R=T,S=w*(C?1:.5),F=U):(M=S=w,R=F=U),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=U*(H+G))>M?(q=!0,j=Y,B=W):W>R&&(j=Y,B=M)),W<=M&&(B=M);var X=0;H-G<=0&&((X=-U*(H-G))>S?(q=!0,V=Y,N=X):X>F&&(V=Y,N=S)),X<=S&&(N=S)}else B=M,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,vpadLinearized:!0,ppadminus:{x:V,y:j}[p],ppadplus:{x:j,y:V}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,a=e.yaxis,i=0;i<o.length;i++){for(var l=o[i],c="h"===l?a:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||"box"!==d.type&&"candlestick"!==d.type||p.empty||(d.orientation||"v")!==l||d.xaxis!==n._id||d.yaxis!==a._id||u.push(h)}s("box",t,u,c)}},setPositionOffset:s}},{"../../lib":716,"../../plots/cartesian/axes":764,"../../plots/cartesian/axis_ids":767}],882:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=t("../../components/color"),o=t("../bar/defaults").handleGroupingDefaults,s=t("./attributes");function l(t,e,r,i){var o,s,l=r("y"),c=r("x"),u=c&&c.length;if(l&&l.length)o="v",u?s=Math.min(n.minRowLength(c),n.minRowLength(l)):(r("x0"),s=n.minRowLength(l));else{if(!u)return void(e.visible=!1);o="h",r("y0"),s=n.minRowLength(c)}e._length=s,a.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y"],i),r("orientation",o)}function c(t,e,r,a){var i=a.prefix,o=n.coerce2(t,e,s,"marker.outliercolor"),l=r("marker.line.outliercolor"),c=r(i+"points",o||l?"suspectedoutliers":void 0);c?(r("jitter","all"===c?.3:0),r("pointpos","all"===c?-1.5:0),r("marker.symbol"),r("marker.opacity"),r("marker.size"),r("marker.color",e.line.color),r("marker.line.color"),r("marker.line.width"),"suspectedoutliers"===c&&(r("marker.line.outliercolor",e.marker.color),r("marker.line.outlierwidth")),r("selected.marker.color"),r("unselected.marker.color"),r("selected.marker.size"),r("unselected.marker.size"),r("text"),r("hovertext")):delete e.marker;var u=r("hoveron");"all"!==u&&-1===u.indexOf("points")||r("hovertemplate"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,a){function o(r,a){return n.coerce(t,e,s,r,a)}l(t,e,o,a),!1!==e.visible&&(o("line.color",(t.marker||{}).color||r),o("line.width"),o("fillcolor",i.addOpacity(e.line.color,.5)),o("whiskerwidth"),o("boxmean"),o("width"),o("notched",void 0!==t.notchwidth)&&o("notchwidth"),c(t,e,o,{prefix:"box"}))},crossTraceDefaults:function(t,e){var r,a;function i(t){return n.coerce(a._input,a,s,t)}for(var l=0;l<t.length;l++){var c=(a=t[l]).type;"box"!==c&&"violin"!==c||(r=a._input,"group"===e[c+"mode"]&&o(r,a,e,i))}},handleSampleDefaults:l,handlePointsDefaults:c}},{"../../components/color":591,"../../lib":716,"../../registry":845,"../bar/defaults":859,"./attributes":879}],883:[function(t,e,r){"use strict";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),"xVal"in e&&(t.x=e.xVal),"yVal"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],884:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib"),i=t("../../components/fx"),o=t("../../components/color"),s=a.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w=t.cd,k=t.xa,T=t.ya,A=w[0].trace,M=w[0].t,S="violin"===A.type,E=[],L=M.bdPos,C=M.wHover,P=function(t){return u.c2l(t.pos)+M.bPos-u.c2l(p)};S&&"both"!==A.side?("positive"===A.side&&(v=function(t){var e=P(t);return i.inbox(e,e+C,m)},x=L,b=0),"negative"===A.side&&(v=function(t){var e=P(t);return i.inbox(e-C,e,m)},x=0,b=L)):(v=function(t){var e=P(t);return i.inbox(e-C,e+C,m)},x=b=L),_=S?function(t){return i.inbox(t.span[0]-f,t.span[1]-f,m)}:function(t){return i.inbox(t.min-f,t.max-f,m)},"h"===A.orientation?(f=e,p=r,d=_,g=v,l="y",u=T,c="x",h=k):(f=r,p=e,d=v,g=_,l="x",u=k,c="y",h=T);var O=Math.min(1,L/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}m=t.maxHoverDistance-O,y=t.maxSpikeDistance-O;var I=i.getDistanceFunction(s,d,g,z);if(i.getClosest(w,I,t),!1===t.index)return[];var D=w[t.index],R=A.line.color,F=(A.marker||{}).color;o.opacity(R)&&A.line.width?t.color=R:o.opacity(F)&&A.boxpoints?t.color=F:t.color=A.fillcolor,t[l+"0"]=u.c2p(D.pos+M.bPos-b,!0),t[l+"1"]=u.c2p(D.pos+M.bPos+x,!0),t[l+"LabelVal"]=D.pos;var B=l+"Spike";t.spikeDistance=z(D)*y/m,t[B]=u.c2p(D.pos,!0);var N={},j=["med","q1","q3","min","max"];(A.boxmean||(A.meanline||{}).visible)&&j.push("mean"),(A.boxpoints||A.points)&&j.push("lf","uf");for(var V=0;V<j.length;V++){var U=j[V];if(U in D&&!(D[U]in N)){N[D[U]]=!0;var q=D[U],H=h.c2p(q,!0),G=a.extendFlat({},t);G.attr=U,G[c+"0"]=G[c+"1"]=H,G[c+"LabelVal"]=q,G[c+"Label"]=(M.labels?M.labels[U]+" ":"")+n.hoverLabelText(h,q),G.hoverOnBox=!0,"mean"===U&&"sd"in D&&"sd"===A.boxmean&&(G[c+"err"]=D.sd),t.name="",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),g=i.quadrature(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)},function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)}),v=!1,m=0;m<c.length;m++){o=c[m];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,v=[m,y])}}if(!v)return!1;l=(o=c[v[0]]).pts[v[1]];var b,_=u.c2p(l.x,!0),w=h.c2p(l.y,!0),k=l.mrc||1;return n=a.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:_-k,x1:_+k,y0:w-k,y1:w+k,spikeDistance:t.distance,hovertemplate:f.hovertemplate}),"h"===f.orientation?(b=h,n.xLabelVal=l.x,n.yLabelVal=o.pos):(b=u,n.xLabelVal=o.pos,n.yLabelVal=l.y),n[b._id.charAt(0)+"Spike"]=b.c2p(o.pos,!0),s(l,f,n),n}e.exports={hoverPoints:function(t,e,r,n){var a,i=t.cd[0].trace.hoveron,o=[];return-1!==i.indexOf("boxes")&&(o=o.concat(l(t,e,r,n))),-1!==i.indexOf("points")&&(a=c(t,e,r)),"closest"===n?a?[a]:o:a?(o.push(a),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{"../../components/color":591,"../../components/fx":629,"../../lib":716,"../../plots/cartesian/axes":764}],885:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults").supplyDefaults,crossTraceDefaults:t("./defaults").crossTraceDefaults,supplyLayoutDefaults:t("./layout_defaults").supplyLayoutDefaults,calc:t("./calc"),crossTraceCalc:t("./cross_trace_calc").crossTraceCalc,plot:t("./plot").plot,style:t("./style").style,styleOnSelect:t("./style").styleOnSelect,hoverPoints:t("./hover").hoverPoints,eventData:t("./event_data"),selectPoints:t("./select"),moduleType:"trace",name:"box",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","symbols","oriented","box-violin","showLegend","boxLayout","zoomScale"],meta:{}}},{"../../plots/cartesian":775,"./attributes":879,"./calc":880,"./cross_trace_calc":881,"./defaults":882,"./event_data":883,"./hover":884,"./layout_attributes":886,"./layout_defaults":887,"./plot":888,"./select":889,"./style":890}],886:[function(t,e,r){"use strict";e.exports={boxmode:{valType:"enumerated",values:["group","overlay"],dflt:"overlay",editType:"calc"},boxgap:{valType:"number",min:0,max:1,dflt:.3,editType:"calc"},boxgroupgap:{valType:"number",min:0,max:1,dflt:.3,editType:"calc"}}},{}],887:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("./layout_attributes");function o(t,e,r,a,i){for(var o=i+"Layout",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(a(i+"mode"),a(i+"gap"),a(i+"groupgap"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,function(r,n){return a.coerce(t,e,i,r,n)},"box")},_supply:o}},{"../../lib":716,"../../registry":845,"./layout_attributes":886}],888:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=5,s=.01;function l(t,e,r,i){var o,s,l=e.pos,c=e.val,u=i.bPos,h=i.wdPos||0,f=i.bPosPxOffset||0,p=r.whiskerwidth||0,d=r.notched||!1,g=d?1-2*r.notchwidth:1;Array.isArray(i.bdPos)?(o=i.bdPos[0],s=i.bdPos[1]):(o=i.bdPos,s=i.bdPos);var v=t.selectAll("path.box").data("violin"!==r.type||r.box.visible?a.identity:[]);v.enter().append("path").style("vector-effect","non-scaling-stroke").attr("class","box"),v.exit().remove(),v.each(function(t){if(t.empty)return"M0,0Z";var e=l.c2l(t.pos+u,!0),i=l.l2p(e)+f,v=l.l2p(e-o)+f,m=l.l2p(e+s)+f,y=l.l2p(e-h)+f,x=l.l2p(e+h)+f,b=l.l2p(e-o*g)+f,_=l.l2p(e+s*g)+f,w=c.c2p(t.q1,!0),k=c.c2p(t.q3,!0),T=a.constrain(c.c2p(t.med,!0),Math.min(w,k)+1,Math.max(w,k)-1),A=void 0===t.lf||!1===r.boxpoints,M=c.c2p(A?t.min:t.lf,!0),S=c.c2p(A?t.max:t.uf,!0),E=c.c2p(t.ln,!0),L=c.c2p(t.un,!0);"h"===r.orientation?n.select(this).attr("d","M"+T+","+b+"V"+_+"M"+w+","+v+"V"+m+(d?"H"+E+"L"+T+","+_+"L"+L+","+m:"")+"H"+k+"V"+v+(d?"H"+L+"L"+T+","+b+"L"+E+","+v:"")+"ZM"+w+","+i+"H"+M+"M"+k+","+i+"H"+S+(0===p?"":"M"+M+","+y+"V"+x+"M"+S+","+y+"V"+x)):n.select(this).attr("d","M"+b+","+T+"H"+_+"M"+v+","+w+"H"+m+(d?"V"+E+"L"+_+","+T+"L"+m+","+L:"")+"V"+k+"H"+v+(d?"V"+L+"L"+b+","+T+"L"+v+","+E:"")+"ZM"+i+","+w+"V"+M+"M"+i+","+k+"V"+S+(0===p?"":"M"+y+","+M+"H"+x+"M"+y+","+S+"H"+x))})}function c(t,e,r,n){var l=e.x,c=e.y,u=n.bdPos,h=n.bPos,f=r.boxpoints||r.points;a.seedPseudoRandom();var p=t.selectAll("g.points").data(f?function(t){return t.forEach(function(t){t.t=n,t.trace=r}),t}:[]);p.enter().append("g").attr("class","points"),p.exit().remove();var d=p.selectAll("path").data(function(t){var e,n,i=t.pts2,l=Math.max((t.max-t.min)/10,t.q3-t.q1),c=1e-9*l,p=l*s,d=[],g=0;if(r.jitter){if(0===l)for(g=1,d=new Array(i.length),e=0;e<i.length;e++)d[e]=1;else for(e=0;e<i.length;e++){var v=Math.max(0,e-o),m=i[v].v,y=Math.min(i.length-1,e+o),x=i[y].v;"all"!==f&&(i[e].v<t.lf?x=Math.min(x,t.lf):m=Math.max(m,t.uf));var b=Math.sqrt(p*(y-v)/(x-m+c))||0;b=a.constrain(Math.abs(b),0,1),d.push(b),g=Math.max(b,g)}n=2*r.jitter/(g||1)}for(e=0;e<i.length;e++){var _=i[e],w=_.v,k=r.jitter?n*d[e]*(a.pseudoRandom()-.5):0,T=t.pos+h+u*(r.pointpos+k);"h"===r.orientation?(_.y=T,_.x=w):(_.x=T,_.y=w),"suspectedoutliers"===f&&w<t.uo&&w>t.lo&&(_.so=!0)}return i});d.enter().append("path").classed("point",!0),d.exit().remove(),d.call(i.translatePoints,l,c)}function u(t,e,r,i){var o,s,l=e.pos,c=e.val,u=i.bPos,h=i.bPosPxOffset||0,f=r.boxmean||(r.meanline||{}).visible;Array.isArray(i.bdPos)?(o=i.bdPos[0],s=i.bdPos[1]):(o=i.bdPos,s=i.bdPos);var p=t.selectAll("path.mean").data("box"===r.type&&r.boxmean||"violin"===r.type&&r.box.visible&&r.meanline.visible?a.identity:[]);p.enter().append("path").attr("class","mean").style({fill:"none","vector-effect":"non-scaling-stroke"}),p.exit().remove(),p.each(function(t){var e=l.c2l(t.pos+u,!0),a=l.l2p(e)+h,i=l.l2p(e-o)+h,p=l.l2p(e+s)+h,d=c.c2p(t.mean,!0),g=c.c2p(t.mean-t.sd,!0),v=c.c2p(t.mean+t.sd,!0);"h"===r.orientation?n.select(this).attr("d","M"+d+","+i+"V"+p+("sd"===f?"m0,0L"+g+","+a+"L"+d+","+i+"L"+v+","+a+"Z":"")):n.select(this).attr("d","M"+i+","+d+"H"+p+("sd"===f?"m0,0L"+a+","+g+"L"+i+","+d+"L"+a+","+v+"Z":""))})}e.exports={plot:function(t,e,r,i){var o=e.xaxis,s=e.yaxis;a.makeTraceGroups(i,r,"trace boxes").each(function(t){var e,r,a=n.select(this),i=t[0],h=i.t,f=i.trace;h.wdPos=h.bdPos*f.whiskerwidth,!0!==f.visible||h.empty?a.remove():("h"===f.orientation?(e=s,r=o):(e=o,r=s),l(a,{pos:e,val:r},f,h),c(a,{x:o,y:s},f,h),u(a,{pos:e,val:r},f,h))})},plotBoxAndWhiskers:l,plotPoints:c,plotBoxMean:u}},{"../../components/drawing":612,"../../lib":716,d3:164}],889:[function(t,e,r){"use strict";e.exports=function(t,e){var r,n,a=t.cd,i=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<a.length;r++)for(n=0;n<(a[r].pts||[]).length;n++)a[r].pts[n].selected=0;else for(r=0;r<a.length;r++)for(n=0;n<(a[r].pts||[]).length;n++){var l=a[r].pts[n],c=i.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:i.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],890:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../../components/drawing");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll("g.trace.boxes");o.style("opacity",function(t){return t[0].trace.opacity}),o.each(function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style("stroke-width",e+"px").call(a.stroke,r).call(a.fill,n)}var c=r.selectAll("path.box");if("candlestick"===o.type)c.each(function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style("opacity",o.selectedpoints&&!t.selected?.3:1)}});else{l(c,s,o.line.color,o.fillcolor),r.selectAll("path.mean").style({"stroke-width":s,"stroke-dasharray":2*s+"px,"+s+"px"}).call(a.stroke,o.line.color);var u=r.selectAll("path.point");i.pointStyle(u,o,t)}})},styleOnSelect:function(t,e,r){var n=e[0].trace,a=r.selectAll("path.point");n.selectedpoints?i.selectedPointStyle(a,n):i.pointStyle(a,n,t)}}},{"../../components/color":591,"../../components/drawing":612,d3:164}],891:[function(t,e,r){"use strict";var n=t("../../lib").extendFlat,a=t("../ohlc/attributes"),i=t("../box/attributes");function o(t){return{line:{color:n({},i.line.color,{dflt:t}),width:i.line.width,editType:"style"},fillcolor:i.fillcolor,editType:"style"}}e.exports={x:a.x,open:a.open,high:a.high,low:a.low,close:a.close,line:{width:n({},i.line.width,{}),editType:"style"},increasing:o(a.increasing.line.color.dflt),decreasing:o(a.decreasing.line.color.dflt),text:a.text,hovertext:a.hovertext,whiskerwidth:n({},i.whiskerwidth,{dflt:0}),hoverlabel:a.hoverlabel}},{"../../lib":716,"../box/attributes":879,"../ohlc/attributes":1064}],892:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../ohlc/calc").calcCommon;function o(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,s=a.getFromId(t,e.xaxis),l=a.getFromId(t,e.yaxis),c=s.makeCalcdata(e,"x"),u=i(t,e,c,l,o);return u.length?(n.extendFlat(u[0].t,{num:r._numBoxes,dPos:n.distinctVals(c).minDiff/2,posLetter:"x",valLetter:"y"}),r._numBoxes++,u):[{t:{empty:!0}}]}},{"../../lib":716,"../../plots/cartesian/axes":764,"../ohlc/calc":1065}],893:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../ohlc/ohlc_defaults"),o=t("./attributes");function s(t,e,r,n){var i=r(n+".line.color");r(n+".line.width",e.line.width),r(n+".fillcolor",a.addOpacity(i,.5))}e.exports=function(t,e,r,a){function l(r,a){return n.coerce(t,e,o,r,a)}i(t,e,l,a)?(l("line.width"),s(t,e,l,"increasing"),s(t,e,l,"decreasing"),l("text"),l("hovertext"),l("whiskerwidth"),a._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{"../../components/color":591,"../../lib":716,"../ohlc/ohlc_defaults":1069,"./attributes":891}],894:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"candlestick",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","showLegend","candlestick","boxLayout"],meta:{},attributes:t("./attributes"),layoutAttributes:t("../box/layout_attributes"),supplyLayoutDefaults:t("../box/layout_defaults").supplyLayoutDefaults,crossTraceCalc:t("../box/cross_trace_calc").crossTraceCalc,supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("../box/plot").plot,layerName:"boxlayer",style:t("../box/style").style,hoverPoints:t("../ohlc/hover").hoverPoints,selectPoints:t("../ohlc/select")}},{"../../plots/cartesian":775,"../box/cross_trace_calc":881,"../box/layout_attributes":886,"../box/layout_defaults":887,"../box/plot":888,"../box/style":890,"../ohlc/hover":1067,"../ohlc/select":1071,"./attributes":891,"./calc":892,"./defaults":893}],895:[function(t,e,r){"use strict";var n=t("./axis_defaults"),a=t("../../plot_api/plot_template");e.exports=function(t,e,r,i,o){i("a")||(i("da"),i("a0")),i("b")||(i("db"),i("b0")),function(t,e,r,i){["aaxis","baxis"].forEach(function(o){var s=o.charAt(0),l=t[o]||{},c=a.newContainer(e,o),u={tickfont:"x",id:s+"axis",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:i,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||"-"===l.type||(t[o]={type:l.type})})}(t,e,r,o)}},{"../../plot_api/plot_template":754,"./axis_defaults":900}],896:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;var a=1/0;var i=-1/0;var o=e.length;for(var s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(a=Math.min(c[0],a),i=Math.max(c[1],i))}else a=Math.min(l,a),i=Math.max(l,i)}return[a,i]}(t,0)}},{"../../lib":716}],897:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("./axis_attributes"),i=t("../../components/color/attributes"),o=n({editType:"calc"});o.family.dflt='"Open Sans", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=i.defaultLine,e.exports={carpet:{valType:"string",editType:"calc"},x:{valType:"data_array",editType:"calc+clearAxisTypes"},y:{valType:"data_array",editType:"calc+clearAxisTypes"},a:{valType:"data_array",editType:"calc"},a0:{valType:"number",dflt:0,editType:"calc"},da:{valType:"number",dflt:1,editType:"calc"},b:{valType:"data_array",editType:"calc"},b0:{valType:"number",dflt:0,editType:"calc"},db:{valType:"number",dflt:1,editType:"calc"},cheaterslope:{valType:"number",dflt:1,editType:"calc"},aaxis:a,baxis:a,font:o,color:{valType:"color",dflt:i.defaultLine,editType:"plot"},transforms:void 0}},{"../../components/color/attributes":590,"../../plots/font_attributes":790,"./axis_attributes":899}],898:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray;e.exports=function(t,e,r,a){var i,o,s,l,c,u,h,f,p,d,g,v,m,y=n(r)?"a":"b",x=("a"===y?t.aaxis:t.baxis).smoothing,b="a"===y?t.a2i:t.b2j,_="a"===y?r:a,w="a"===y?a:r,k="a"===y?e.a.length:e.b.length,T="a"===y?e.b.length:e.a.length,A=Math.floor("a"===y?t.b2j(w):t.a2i(w)),M="a"===y?function(e){return t.evalxy([],e,A)}:function(e){return t.evalxy([],A,e)};x&&(s=Math.max(0,Math.min(T-2,A)),l=A-s,o="a"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),L=S<E?1:-1,C=1e-8*(E-S),P=L>0?Math.floor:Math.ceil,O=L>0?Math.ceil:Math.floor,z=L>0?Math.min:Math.max,I=L>0?Math.max:Math.min,D=P(S+C),R=O(E-C),F=[[h=M(S)]];for(i=D;i*L<R*L;i+=L)c=[],g=I(S,i),m=(v=z(E,i+L))-g,u=Math.max(0,Math.min(k-2,Math.floor(.5*(g+v)))),f=M(v),x&&(p=o(u,g-u),d=o(u,v-u),c.push([h[0]+p[0]/3*m,h[1]+p[1]/3*m]),c.push([f[0]-d[0]/3*m,f[1]-d[1]/3*m])),c.push(f),F.push(c),h=f;return F}},{"../../lib":716}],899:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../../components/color/attributes"),i=t("../../plots/cartesian/layout_attributes"),o=t("../../plot_api/edit_types").overrideAll;t("../../constants/docs").FORMAT_LINK,t("../../constants/docs").TIME_FORMAT_LINK;e.exports={color:{valType:"color",editType:"calc"},smoothing:{valType:"number",dflt:1,min:0,max:1.3,editType:"calc"},title:{text:{valType:"string",dflt:"",editType:"calc"},font:n({editType:"calc"}),offset:{valType:"number",dflt:10,editType:"calc"},editType:"calc"},type:{valType:"enumerated",values:["-","linear","date","category"],dflt:"-",editType:"calc"},autorange:{valType:"enumerated",values:[!0,!1,"reversed"],dflt:!0,editType:"calc"},rangemode:{valType:"enumerated",values:["normal","tozero","nonnegative"],dflt:"normal",editType:"calc"},range:{valType:"info_array",editType:"calc",items:[{valType:"any",editType:"calc"},{valType:"any",editType:"calc"}]},fixedrange:{valType:"boolean",dflt:!1,editType:"calc"},cheatertype:{valType:"enumerated",values:["index","value"],dflt:"value",editType:"calc"},tickmode:{valType:"enumerated",values:["linear","array"],dflt:"array",editType:"calc"},nticks:{valType:"integer",min:0,dflt:0,editType:"calc"},tickvals:{valType:"data_array",editType:"calc"},ticktext:{valType:"data_array",editType:"calc"},showticklabels:{valType:"enumerated",values:["start","end","both","none"],dflt:"start",editType:"calc"},tickfont:n({editType:"calc"}),tickangle:{valType:"angle",dflt:"auto",editType:"calc"},tickprefix:{valType:"string",dflt:"",editType:"calc"},showtickprefix:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"calc"},ticksuffix:{valType:"string",dflt:"",editType:"calc"},showticksuffix:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"calc"},showexponent:{valType:"enumerated",values:["all","first","last","none"],dflt:"all",editType:"calc"},exponentformat:{valType:"enumerated",values:["none","e","E","power","SI","B"],dflt:"B",editType:"calc"},separatethousands:{valType:"boolean",dflt:!1,editType:"calc"},tickformat:{valType:"string",dflt:"",editType:"calc"},tickformatstops:o(i.tickformatstops,"calc","from-root"),categoryorder:{valType:"enumerated",values:["trace","category ascending","category descending","array"],dflt:"trace",editType:"calc"},categoryarray:{valType:"data_array",editType:"calc"},labelpadding:{valType:"integer",dflt:10,editType:"calc"},labelprefix:{valType:"string",editType:"calc"},labelsuffix:{valType:"string",dflt:"",editType:"calc"},showline:{valType:"boolean",dflt:!1,editType:"calc"},linecolor:{valType:"color",dflt:a.defaultLine,editType:"calc"},linewidth:{valType:"number",min:0,dflt:1,editType:"calc"},gridcolor:{valType:"color",editType:"calc"},gridwidth:{valType:"number",min:0,dflt:1,editType:"calc"},showgrid:{valType:"boolean",dflt:!0,editType:"calc"},minorgridcount:{valType:"integer",min:0,dflt:0,editType:"calc"},minorgridwidth:{valType:"number",min:0,dflt:1,editType:"calc"},minorgridcolor:{valType:"color",dflt:a.lightLine,editType:"calc"},startline:{valType:"boolean",editType:"calc"},startlinecolor:{valType:"color",editType:"calc"},startlinewidth:{valType:"number",dflt:1,editType:"calc"},endline:{valType:"boolean",editType:"calc"},endlinewidth:{valType:"number",dflt:1,editType:"calc"},endlinecolor:{valType:"color",editType:"calc"},tick0:{valType:"number",min:0,dflt:0,editType:"calc"},dtick:{valType:"number",min:0,dflt:1,editType:"calc"},arraytick0:{valType:"integer",min:0,dflt:0,editType:"calc"},arraydtick:{valType:"integer",min:1,dflt:1,editType:"calc"},_deprecated:{title:{valType:"string",editType:"calc"},titlefont:n({editType:"calc"}),titleoffset:{valType:"number",dflt:10,editType:"calc"}},editType:"calc"}},{"../../components/color/attributes":590,"../../constants/docs":687,"../../plot_api/edit_types":747,"../../plots/cartesian/layout_attributes":776,"../../plots/font_attributes":790}],900:[function(t,e,r){"use strict";var n=t("./attributes"),a=t("../../components/color").addOpacity,i=t("../../registry"),o=t("../../lib"),s=t("../../plots/cartesian/tick_value_defaults"),l=t("../../plots/cartesian/tick_label_defaults"),c=t("../../plots/cartesian/category_order_defaults"),u=t("../../plots/cartesian/set_convert"),h=t("../../plots/cartesian/axis_autotype");e.exports=function(t,e,r){var f=r.letter,p=r.font||{},d=n[f+"axis"];function g(r,n){return o.coerce(t,e,d,r,n)}function v(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var m=g("type");("-"===m&&(r.data&&function(t,e){if("-"!==t.type)return;var r=t._id.charAt(0),n=t[r+"calendar"];t.type=h(e,n)}(e,r.data),"-"===e.type?e.type="linear":m=t.type=e.type),g("smoothing"),g("cheatertype"),g("showticklabels"),g("labelprefix",f+" = "),g("labelsuffix"),g("showtickprefix"),g("showticksuffix"),g("separatethousands"),g("tickformat"),g("exponentformat"),g("showexponent"),g("categoryorder"),g("tickmode"),g("tickvals"),g("ticktext"),g("tick0"),g("dtick"),"array"===e.tickmode&&(g("arraytick0"),g("arraydtick")),g("labelpadding"),e._hovertitle=f,"date"===m)&&i.getComponentMethod("calendars","handleDefaults")(t,e,"calendar",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g("color",r.dfltColor),x=y===t.color?y:p.color;g("title.text")&&(o.coerceFont(g,"title.font",{family:p.family,size:Math.round(1.2*p.size),color:x}),g("title.offset")),g("tickangle"),g("autorange",!e.isValidRange(t.range))&&g("rangemode"),g("range"),e.cleanRange(),g("fixedrange"),s(t,e,g,m),l(t,e,g,m,r),c(t,e,g,{data:r.data,dataAttr:f});var b=v("gridcolor",a(y,.3)),_=v("gridwidth"),w=g("showgrid");w||(delete e.gridcolor,delete e.gridwidth);var k=v("startlinecolor",y),T=v("startlinewidth",_);g("startline",e.showgrid||!!k||!!T)||(delete e.startlinecolor,delete e.startlinewidth);var A=v("endlinecolor",y),M=v("endlinewidth",_);return g("endline",e.showgrid||!!A||!!M)||(delete e.endlinecolor,delete e.endlinewidth),w?(g("minorgridcount"),g("minorgridwidth",_),g("minorgridcolor",a(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),"none"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g("tickmode"),e}},{"../../components/color":591,"../../lib":716,"../../plots/cartesian/axis_autotype":765,"../../plots/cartesian/category_order_defaults":768,"../../plots/cartesian/set_convert":782,"../../plots/cartesian/tick_label_defaults":783,"../../plots/cartesian/tick_value_defaults":785,"../../registry":845,"./attributes":897}],901:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib").isArray1D,i=t("./cheater_basis"),o=t("./array_minmax"),s=t("./calc_gridlines"),l=t("./calc_labels"),c=t("./calc_clippath"),u=t("../heatmap/clean_2d_array"),h=t("./smooth_fill_2d_array"),f=t("../heatmap/convert_column_xyz"),p=t("./set_convert");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,v=e.baxis,m=e.x,y=e.y,x=[];m&&a(m)&&x.push("x"),y&&a(y)&&x.push("y"),x.length&&f(e,g,v,"a","b",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;m=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var k="index"===g.cheatertype?b.length:b,T="index"===v.cheatertype?_.length:_;m=i(k,T,e.cheaterslope)}e._x=m=u(m),e._y=y=u(y),h(m,b,_),h(y,b,_),p(e),e.setScale();var A=o(m),M=o(y),S=.5*(A[1]-A[0]),E=.5*(A[1]+A[0]),L=.5*(M[1]-M[0]),C=.5*(M[1]+M[0]);return A=[E-1.3*S,E+1.3*S],M=[C-1.3*L,C+1.3*L],e._extremes[r._id]=n.findExtremes(r,A,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,M,{padded:!0}),s(e,"a","b"),s(e,"b","a"),l(e,g),l(e,v),w.clipsegments=c(e._xctrl,e._yctrl,g,v),w.x=m,w.y=y,w.a=b,w.b=_,[w]}},{"../../lib":716,"../../plots/cartesian/axes":764,"../heatmap/clean_2d_array":1e3,"../heatmap/convert_column_xyz":1002,"./array_minmax":896,"./calc_clippath":902,"./calc_gridlines":903,"./calc_labels":904,"./cheater_basis":906,"./set_convert":919,"./smooth_fill_2d_array":920}],902:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){var a,i,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(a=0,i=[],o=[];a<=u;a++)i[a]=t[0][a],o[a]=e[0][a];for(s.push({x:i,y:o,bicubic:l}),a=0,i=[],o=[];a<=h;a++)i[a]=t[a][u],o[a]=e[a][u];for(s.push({x:i,y:o,bicubic:c}),a=u,i=[],o=[];a>=0;a--)i[u-a]=t[h][a],o[u-a]=e[h][a];for(s.push({x:i,y:o,bicubic:l}),a=h,i=[],o=[];a>=0;a--)i[h-a]=t[a][0],o[h-a]=e[a][0];return s.push({x:i,y:o,bicubic:c}),s}},{}],903:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib/extend").extendFlat;e.exports=function(t,e,r){var i,o,s,l,c,u,h,f,p,d,g,v,m,y,x=t["_"+e],b=t[e+"axis"],_=b._gridlines=[],w=b._minorgridlines=[],k=b._boundarylines=[],T=t["_"+r],A=t[r+"axis"];"array"===b.tickmode&&(b.tickvals=x.slice());var M=t._xctrl,S=t._yctrl,E=M[0].length,L=M.length,C=t._a.length,P=t._b.length;n.prepTicks(b),"array"===b.tickmode&&delete b.tickvals;var O=b.smoothing?3:1;function z(n){var a,i,o,s,l,c,u,h,p,d,g,v,m=[],y=[],x={};if("b"===e)for(i=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,i))),s=i-o,x.length=P,x.crossLength=C,x.xy=function(e){return t.evalxy([],e,i)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},a=0;a<C;a++)c=Math.min(C-2,a),u=a-c,h=t.evalxy([],a,i),A.smoothing&&a>0&&(p=t.dxydi([],a-1,o,0,s),m.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],a-1,o,1,s),m.push(h[0]-d[0]/3),y.push(h[1]-d[1]/3)),m.push(h[0]),y.push(h[1]),l=h;else for(a=t.a2i(n),c=Math.floor(Math.max(0,Math.min(C-2,a))),u=a-c,x.length=C,x.crossLength=P,x.xy=function(e){return t.evalxy([],a,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},i=0;i<P;i++)o=Math.min(P-2,i),s=i-o,h=t.evalxy([],a,i),A.smoothing&&i>0&&(g=t.dxydj([],c,i-1,u,0),m.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),v=t.dxydj([],c,i-1,u,1),m.push(h[0]-v[0]/3),y.push(h[1]-v[1]/3)),m.push(h[0]),y.push(h[1]),l=h;return x.axisLetter=e,x.axis=b,x.crossAxis=A,x.value=n,x.constvar=r,x.index=f,x.x=m,x.y=y,x.smoothing=A.smoothing,x}function I(n){var a,i,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=T.length,"b"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},a=0;a<E;a++)c[a]=M[n*O][a],u[a]=S[n*O][a];else for(i=Math.max(0,Math.min(C-2,n)),s=Math.min(1,Math.max(0,n-i)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],i,e,s,r)},a=0;a<L;a++)c[a]=M[a][n*O],u[a]=S[a][n*O];return h.axisLetter=e,h.axis=b,h.crossAxis=A,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=A.smoothing,h}if("array"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort(function(t,e){return t-e}))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=b.arraytick0+b.arraydtick*f)<0||o>x.length-1||_.push(a(I(o),{color:b.gridcolor,width:b.gridwidth}));for(f=u;f<h;f++)if(s=b.arraytick0+b.arraydtick*f,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(v=x[s],m=x[g],i=0;i<b.minorgridcount;i++)(y=g-s)<=0||(d=v+(m-v)*(i+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(a(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(a(I(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(a(I(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort(function(t,e){return t-e}))[0],h=c[1],f=u;f<=h;f++)p=b.tick0+b.dtick*f,_.push(a(z(p),{color:b.gridcolor,width:b.gridwidth}));for(f=u-1;f<h+1;f++)for(p=b.tick0+b.dtick*f,i=0;i<b.minorgridcount;i++)(d=p+b.dtick*(i+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(a(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(a(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(a(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{"../../lib/extend":707,"../../plots/cartesian/axes":764}],904:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib/extend").extendFlat;e.exports=function(t,e){var r,i,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==["start","both"].indexOf(e.showticklabels)&&(i=n.tickText(e,o.value),a(i,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(i)),-1!==["end","both"].indexOf(e.showticklabels)&&(i=n.tickText(e,o.value),a(i,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(i))}},{"../../lib/extend":707,"../../plots/cartesian/axes":764}],905:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){var a=t[0]-e[0],i=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(a*a+i*i,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*a-l*l*o)*n,h=(c*c*i-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},{}],906:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray;e.exports=function(t,e,r){var a,i,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var g=1/0,v=-1/0;for(i=0;i<f;i++)for(u[i]=[],l=d?(d[i]-d[0])*s:i/(f-1),a=0;a<h;a++)c=(p?(p[a]-p[0])*o:a/(h-1))-l*r,g=Math.min(c,g),v=Math.max(c,v),u[i][a]=c;var m=1/(v-g),y=-g*m;for(i=0;i<f;i++)for(a=0;a<h;a++)u[i][a]=m*u[i][a]+y;return u}},{"../../lib":716}],907:[function(t,e,r){"use strict";var n=t("./catmull_rom"),a=t("../../lib").ensureArray;function i(t,e,r){var n=-.5*r[0]+1.5*e[0],a=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*a+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,g,v,m,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=a(t,w),e=a(e,w),h=0;h<w;h++)t[h]=a(t[h],_),e[h]=a(e[h],_);for(u=0,f=0;u<b;u++,f+=l?3:1)for(p=t[f],d=e[f],g=r[u],v=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=g[c],d[h]=v[c];if(s)for(u=0,f=0;u<b;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)m=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=m[0][0],e[f][h-1]=m[0][1],t[f][h+1]=m[1][0],e[f][h+1]=m[1][1];y=i([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=y[0],e[f][1]=y[1],y=i([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=y[0],e[f][_-2]=y[1]}if(l)for(h=0;h<_;h++){for(f=3;f<w-3;f+=3)m=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=m[0][0],e[f-1][h]=m[0][1],t[f+1][h]=m[1][0],e[f+1][h]=m[1][1];y=i([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=y[0],e[1][h]=y[1],y=i([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=y[0],e[w-2][h]=y[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<_-3;h+=3)m=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+m[0][0]),e[f][h-1]=.5*(e[f][h-1]+m[0][1]),t[f][h+1]=.5*(t[f][h+1]+m[1][0]),e[f][h+1]=.5*(e[f][h+1]+m[1][1]);y=i([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+y[0]),e[f][1]=.5*(e[f][1]+y[1]),y=i([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=.5*(t[f][_-2]+y[0]),e[f][_-2]=.5*(e[f][_-2]+y[1])}return[t,e]}},{"../../lib":716,"./catmull_rom":905}],908:[function(t,e,r){"use strict";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],909:[function(t,e,r){"use strict";e.exports=function(t,e,r){return e&&r?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=a*a,p=1-a,d=p*p,g=p*a*2,v=-3*d,m=3*(d-g),y=3*(g-f),x=3*f,b=i*i,_=b*i,w=1-i,k=w*w,T=k*w;for(h=0;h<t.length;h++)o=v*(u=t[h])[n][r]+m*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=v*u[n+1][r]+m*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=v*u[n+2][r]+m*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=v*u[n+3][r]+m*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[h]=T*o+3*(k*i*s+w*b*l)+_*c;return e}:e?function(e,r,n,a,i){var o,s,l,c;e||(e=[]),r*=3;var u=a*a,h=1-a,f=h*h,p=h*a*2,d=-3*f,g=3*(f-p),v=3*(p-u),m=3*u,y=1-i;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+v*c[n][r+2]+m*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+v*c[n+1][r+2]+m*c[n+1][r+3],e[l]=y*o+i*s;return e}:r?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:function(e,r,n,a,i){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+i*s;return e}}},{}],910:[function(t,e,r){"use strict";e.exports=function(t,e,r){return e&&r?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d,m=i*i,y=1-i,x=y*y,b=y*i*2,_=-3*x,w=3*(x-b),k=3*(b-m),T=3*m;for(h=0;h<t.length;h++)o=_*(u=t[h])[n][r]+w*u[n+1][r]+k*u[n+2][r]+T*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+k*u[n+2][r+1]+T*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+k*u[n+2][r+2]+T*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+k*u[n+2][r+3]+T*u[n+3][r+3],e[h]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:e?function(e,r,n,a,i){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:r?function(e,r,n,a,i){var o,s,l,c;e||(e=[]),n*=3;var u=1-a,h=i*i,f=1-i,p=f*f,d=f*i*2,g=-3*p,v=3*(p-d),m=3*(d-h),y=3*h;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+v*c[n+1][r]+m*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+v*c[n+1][r+1]+m*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+a*s;return e}:function(e,r,n,a,i){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+a*s;return e}}},{}],911:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){var i=e-2,o=r-2;return n&&a?function(e,r,n){var a,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),i)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,k=1-g,T=k*k,A=T*k;for(h=0;h<t.length;h++)a=b*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+y*v*u[p][f+2])+m*u[p][f+3],s=b*u[p+1][f]+3*(x*d*u[p+1][f+1]+y*v*u[p+1][f+2])+m*u[p+1][f+3],l=b*u[p+2][f]+3*(x*d*u[p+2][f+1]+y*v*u[p+2][f+2])+m*u[p+2][f+3],c=b*u[p+3][f]+3*(x*d*u[p+3][f+1]+y*v*u[p+3][f+2])+m*u[p+3][f+3],e[h]=A*a+3*(T*g*s+k*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var a,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),i)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)a=_*(h=t[u])[p][f]+g*h[p+1][f],s=_*h[p][f+1]+g*h[p+1][f+1],l=_*h[p][f+2]+g*h[p+1][f+1],c=_*h[p][f+3]+g*h[p+1][f+1],e[u]=b*a+3*(x*d*s+y*v*l)+m*c;return e}:a?function(e,r,n){e||(e=[]);var a,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),i)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));p*=3;var v=g*g,m=v*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)a=_*(h=t[u])[p][f]+d*h[p][f+1],s=_*h[p+1][f]+d*h[p+1][f+1],l=_*h[p+2][f]+d*h[p+2][f+1],c=_*h[p+3][f]+d*h[p+3][f+1],e[u]=b*a+3*(x*g*s+y*v*l)+m*c;return e}:function(e,r,n){e||(e=[]);var a,s,l,c,u=Math.max(0,Math.min(Math.floor(r),i)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,g=1-f;for(l=0;l<t.length;l++)a=g*(c=t[l])[h][u]+f*c[h][u+1],s=g*c[h+1][u]+f*c[h+1][u+1],e[l]=d*a+p*s;return e}}},{}],912:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./xy_defaults"),i=t("./ab_defaults"),o=t("./attributes"),s=t("../../components/color/attributes");e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,o,r,a)}e._clipPathId="clip"+e.uid+"carpet";var u=c("color",s.defaultLine);(n.coerceFont(c,"font"),c("carpet"),i(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),a(t,e,c)||(e.visible=!1),e._cheater&&c("cheaterslope")):e.visible=!1}},{"../../components/color/attributes":590,"../../lib":716,"./ab_defaults":895,"./attributes":897,"./xy_defaults":921}],913:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),plot:t("./plot"),calc:t("./calc"),animatable:!0,isContainer:!0,moduleType:"trace",name:"carpet",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","carpet","carpetAxis","notLegendIsolatable","noMultiCategory","noHover","noSortingByValue"],meta:{}}},{"../../plots/cartesian":775,"./attributes":897,"./calc":901,"./defaults":912,"./plot":918}],914:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r,n=t._fullData.length,a=0;a<n;a++){var i=t._fullData[a];if(i.index!==e.index&&("carpet"===i.type&&(r||(r=i),i.carpet===e.carpet)))return i}return r}},{}],915:[function(t,e,r){"use strict";e.exports=function(t,e,r){if(0===t.length)return"";var n,a=[],i=r?3:1;for(n=0;n<t.length;n+=i)a.push(t[n]+","+e[n]),r&&n<t.length-i&&(a.push("C"),a.push([t[n+1]+","+e[n+1],t[n+2]+","+e[n+2]+" "].join(" ")));return a.join(r?"":"L")}},{}],916:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray;e.exports=function(t,e,r){var a;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],a=0;a<e.length;a++)t[a]=r(e[a]);return t}},{"../../lib":716}],917:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a,i){var o=a[0]*t.dpdx(e),s=a[1]*t.dpdy(r),l=1,c=1;if(i){var u=Math.sqrt(a[0]*a[0]+a[1]*a[1]),h=Math.sqrt(i[0]*i[0]+i[1]*i[1]),f=(a[0]*i[0]+a[1]*i[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],918:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("./map_1d_array"),o=t("./makepath"),s=t("./orient_text"),l=t("../../lib/svg_text_utils"),c=t("../../lib"),u=t("../../constants/alignment");function h(t,e,r,a,s,l){var c="const-"+s+"-lines",u=r.selectAll("."+c).data(l);u.enter().append("path").classed(c,!0).style("vector-effect","non-scaling-stroke"),u.each(function(r){var a=r,s=a.x,l=a.y,c=i([],s,t.c2p),u=i([],l,e.c2p),h="M"+o(c,u,a.smoothing);n.select(this).attr("d",h).style("stroke-width",a.width).style("stroke",a.color).style("fill","none")}),u.exit().remove()}function f(t,e,r,i,o,c,u,h){var f=c.selectAll("text."+h).data(u);f.enter().append("text").classed(h,!0);var p=0,d={};return f.each(function(o,c){var u;if("auto"===o.axis.tickangle)u=s(i,e,r,o.xy,o.dxy);else{var h=(o.axis.tickangle+180)*Math.PI/180;u=s(i,e,r,o.xy,[Math.cos(h),Math.sin(h)])}c||(d={angle:u.angle,flip:u.flip});var f=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({"text-anchor":f>0?"start":"end","data-notex":1}).call(a.font,o.font).text(o.text).call(l.convertToTspans,t),v=a.bBox(this);g.attr("transform","translate("+u.p[0]+","+u.p[1]+") rotate("+u.angle+")translate("+o.axis.labelpadding*f+","+.3*v.height+")"),p=Math.max(p,v.width+o.axis.labelpadding)}),f.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,a){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(a,r,"trace").each(function(e){var r=n.select(this),a=e[0],d=a.trace,v=d.aaxis,m=d.baxis,y=c.ensureSingle(r,"g","minorlayer"),x=c.ensureSingle(r,"g","majorlayer"),b=c.ensureSingle(r,"g","boundarylayer"),_=c.ensureSingle(r,"g","labellayer");r.style("opacity",d.opacity),h(l,u,x,v,"a",v._gridlines),h(l,u,x,m,"b",m._gridlines),h(l,u,y,v,"a",v._minorgridlines),h(l,u,y,m,"b",m._minorgridlines),h(l,u,b,v,"a-boundary",v._boundarylines),h(l,u,b,m,"b-boundary",m._boundarylines);var w=f(t,l,u,d,a,_,v._labels,"a-label"),k=f(t,l,u,d,a,_,m._labels,"b-label");!function(t,e,r,n,a,i,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),v=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+v),h=m,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,a,i,f,r.dxydb_rough(u,h)));g(t,e,r,n,f,p,r.aaxis,a,i,o,"a-title"),u=d,h=.5*(m+y),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,a,i,f,r.dxyda_rough(u,h)));g(t,e,r,n,f,p,r.baxis,a,i,l,"b-title")}(t,_,d,a,l,u,w,k),function(t,e,r,n,a){var s,l,u,h,f=r.select("#"+t._clipPathId);f.size()||(f=r.append("clipPath").classed("carpetclip",!0));var p=c.ensureSingle(f,"path","carpetboundary"),d=e.clipsegments,g=[];for(h=0;h<d.length;h++)s=d[h],l=i([],s.x,n.c2p),u=i([],s.y,a.c2p),g.push(o(l,u,s.bicubic));var v="M"+g.join("L")+"Z";f.attr("id",t._clipPathId),p.attr("d",v)}(d,a,p,l,u)})};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,i,o,c,u,h,f,g,v){var m=[];u.title.text&&m.push(u.title.text);var y=e.selectAll("text."+v).data(m),x=g.maxExtent;y.enter().append("text").classed(v,!0),y.each(function(){var e=s(r,h,f,o,c);-1===["start","both"].indexOf(u.showticklabels)&&(x=0);var i=u.title.font.size;x+=i+u.title.offset;var v=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,m=v>90&&v<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),m&&(x=(-l.lineCount(y)+d)*p*i-x),y.attr("transform","translate("+e.p[0]+","+e.p[1]+") rotate("+e.angle+") translate(0,"+x+")").classed("user-select-none",!0).attr("text-anchor","middle").call(a.font,u.title.font)}),y.exit().remove()}},{"../../components/drawing":612,"../../constants/alignment":685,"../../lib":716,"../../lib/svg_text_utils":740,"./makepath":915,"./map_1d_array":916,"./orient_text":917,d3:164}],919:[function(t,e,r){"use strict";var n=t("./constants"),a=t("../../lib/search").findBin,i=t("./compute_control_points"),o=t("./create_spline_evaluator"),s=t("./create_i_derivative_evaluator"),l=t("./create_j_derivative_evaluator");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],g=r[0],v=r[u-1],m=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=m*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,v+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<v},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>v},t.setScale=function(){var e=t._x,r=t._y,n=i(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(a(t,e),c-2)),n=e[r],i=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(i-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(a(t,r),u-2)),n=r[e],i=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(i-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,a,i){if(!i&&(n<e[0]||n>e[c-1]|a<r[0]||a>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(a),l=t.evalxy([],o,s);if(i){var h,f,p,d,g=0,v=0,m=[];n<e[0]?(h=0,f=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),a<r[0]?(p=0,d=0,v=(a-r[0])/(r[1]-r[0])):a>r[u-1]?(p=u-2,d=1,v=(a-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(m,h,p,f,d),l[0]+=m[0]*g,l[1]+=m[1]*g),v&&(t.dxydj(m,h,p,f,d),l[0]+=m[0]*v,l[1]+=m[1]*v)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,a){var i=t.dxydi(null,e,r,n,a),o=t.dadi(e,n);return[i[0]/o,i[1]/o]},t.dxydb=function(e,r,n,a){var i=t.dxydj(null,e,r,n,a),o=t.dbdj(r,a);return[i[0]/o,i[1]/o]},t.dxyda_rough=function(e,r,n){var a=m*(n||.1),i=t.ab2xy(e+a,r,!0),o=t.ab2xy(e-a,r,!0);return[.5*(i[0]-o[0])/a,.5*(i[1]-o[1])/a]},t.dxydb_rough=function(e,r,n){var a=y*(n||.1),i=t.ab2xy(e,r+a,!0),o=t.ab2xy(e,r-a,!0);return[.5*(i[0]-o[0])/a,.5*(i[1]-o[1])/a]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{"../../lib/search":735,"./compute_control_points":907,"./constants":908,"./create_i_derivative_evaluator":909,"./create_j_derivative_evaluator":910,"./create_spline_evaluator":911}],920:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e,r){var a,i,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,a=0,i=0;return e>0&&void 0!==(n=t[r][e-1])&&(i++,a+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(i++,a+=n),r>0&&void 0!==(n=t[r-1][e])&&(i++,a+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(i++,a+=n),a/Math.max(1,i)}var f,p,d,g,v,m,y,x,b,_,w,k=0;for(a=0;a<c;a++)for(i=0;i<u;i++)void 0===t[i][a]&&(s.push(a),l.push(i),t[i][a]=h(a,i)),k=Math.max(k,Math.abs(t[i][a]));if(!s.length)return t;var T=0,A=0,M=s.length;do{for(T=0,o=0;o<M;o++){a=s[o],i=l[o];var S,E,L,C,P,O,z=0,I=0;0===a?(L=e[P=Math.min(c-1,2)],C=e[1],S=t[i][P],I+=(E=t[i][1])+(E-S)*(e[0]-C)/(C-L),z++):a===c-1&&(L=e[P=Math.max(0,c-3)],C=e[c-2],S=t[i][P],I+=(E=t[i][c-2])+(E-S)*(e[c-1]-C)/(C-L),z++),(0===a||a===c-1)&&i>0&&i<u-1&&(f=r[i+1]-r[i],I+=((p=r[i]-r[i-1])*t[i+1][a]+f*t[i-1][a])/(p+f),z++),0===i?(L=r[O=Math.min(u-1,2)],C=r[1],S=t[O][a],I+=(E=t[1][a])+(E-S)*(r[0]-C)/(C-L),z++):i===u-1&&(L=r[O=Math.max(0,u-3)],C=r[u-2],S=t[O][a],I+=(E=t[u-2][a])+(E-S)*(r[u-1]-C)/(C-L),z++),(0===i||i===u-1)&&a>0&&a<c-1&&(f=e[a+1]-e[a],I+=((p=e[a]-e[a-1])*t[i][a+1]+f*t[i][a-1])/(p+f),z++),z?I/=z:(d=e[a+1]-e[a],g=e[a]-e[a-1],x=(v=r[i+1]-r[i])*(m=r[i]-r[i-1])*(v+m),I=((y=d*g*(d+g))*(m*t[i+1][a]+v*t[i-1][a])+x*(g*t[i][a+1]+d*t[i][a-1]))/(x*(g+d)+y*(m+v))),T+=(_=(b=I-t[i][a])/k)*_,w=z?0:.85,t[i][a]+=b*(1+w)}T=Math.sqrt(T)}while(A++<100&&T>1e-5);return n.log("Smoother converged to",T,"after",A,"iterations"),t}},{"../../lib":716}],921:[function(t,e,r){"use strict";var n=t("../../lib").isArray1D;e.exports=function(t,e,r){var a=r("x"),i=a&&a.length,o=r("y"),s=o&&o.length;if(!i&&!s)return!1;if(e._cheater=!a,i&&!n(a)||s&&!n(o))e._length=null;else{var l=i?a.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{"../../lib":716}],922:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../scattergeo/attributes"),i=t("../../components/colorscale/attributes"),o=t("../../plots/attributes"),s=t("../../components/color/attributes").defaultLine,l=t("../../lib/extend").extendFlat,c=a.marker.line;e.exports=l({locations:{valType:"data_array",editType:"calc"},locationmode:a.locationmode,z:{valType:"data_array",editType:"calc"},text:l({},a.text,{}),hovertext:l({},a.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:"calc"},opacity:{valType:"number",arrayOk:!0,min:0,max:1,dflt:1,editType:"style"},editType:"calc"},selected:{marker:{opacity:a.selected.marker.opacity,editType:"plot"},editType:"plot"},unselected:{marker:{opacity:a.unselected.marker.opacity,editType:"plot"},editType:"plot"},hoverinfo:l({},o.hoverinfo,{editType:"calc",flags:["location","z","text","name"]}),hovertemplate:n()},i("",{cLetter:"z",editTypeOverride:"calc"}))},{"../../components/color/attributes":590,"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/template_attributes":840,"../scattergeo/attributes":1159}],923:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../constants/numerical").BADNUM,i=t("../../components/colorscale/calc"),o=t("../scatter/arrays_to_calcdata"),s=t("../scatter/calc_selection");function l(t){return t&&"string"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=a),f.index=h}return o(u,e),i(t,e,{vals:e.z,containerStr:"",cLetter:"z"}),s(u,e),u}},{"../../components/colorscale/calc":599,"../../constants/numerical":692,"../scatter/arrays_to_calcdata":1117,"../scatter/calc_selection":1120,"fast-isnumeric":227}],924:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/defaults"),i=t("./attributes");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s("locations"),c=s("z");l&&l.length&&n.isArrayOrTypedArray(c)&&c.length?(e._length=Math.min(l.length,c.length),s("locationmode"),s("text"),s("hovertext"),s("hovertemplate"),s("marker.line.width")&&s("marker.line.color"),s("marker.opacity"),a(t,e,o,s,{prefix:"",cLetter:"z"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":716,"./attributes":922}],925:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){t.location=e.location,t.z=e.z;var i=n[a];return i.fIn&&(t.properties=i.fIn.properties),t}},{}],926:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("./attributes"),i=t("../../lib").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),"hover").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=String(r.loc),s="all"===n?a.hoverinfo.flags:n.split("+"),l=-1!==s.indexOf("name"),c=-1!==s.indexOf("location"),u=-1!==s.indexOf("z"),h=-1!==s.indexOf("text"),f=[];!l&&c?t.nameOverride=o:(l&&(t.nameOverride=e.name),c&&f.push(o));u&&f.push(t.zLabel);h&&i(r,e,f);t.extraText=f.join("<br>")}(t,h,o,f.mockAxis),[t]}},{"../../lib":716,"../../plots/cartesian/axes":764,"./attributes":922}],927:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../heatmap/colorbar"),calc:t("./calc"),plot:t("./plot").plot,style:t("./style").style,styleOnSelect:t("./style").styleOnSelect,hoverPoints:t("./hover"),eventData:t("./event_data"),selectPoints:t("./select"),moduleType:"trace",name:"choropleth",basePlotModule:t("../../plots/geo"),categories:["geo","noOpacity"],meta:{}}},{"../../plots/geo":794,"../heatmap/colorbar":1001,"./attributes":922,"./calc":923,"./defaults":924,"./event_data":925,"./hover":926,"./plot":928,"./select":929,"./style":930}],928:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../lib/polygon"),o=t("../../lib/topojson_utils").getTopojsonFeatures,s=t("../../lib/geo_location_utils").locationToFeature,l=t("./style").style;function c(t,e){for(var r=t[0].trace,n=t.length,a=o(r,e),i=0;i<n;i++){var l=t[i],c=s(r.locationmode,l.loc,a);c?(l.geojson=c,l.ct=c.properties.ct,l._polygons=u(c)):l.geojson=null}}function u(t){var e,r,n,a,o=t.geometry,s=o.coordinates,l=t.id,c=[];function u(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e="RUS"===l||"FJI"===l?function(t){var e;if(null===u(t))e=t;else for(e=new Array(t.length),a=0;a<t.length;a++)e[a]=[t[a][0]<0?t[a][0]+360:t[a][0],t[a][1]];c.push(i.tester(e))}:"ATA"===l?function(t){var e=u(t);if(null===e)return c.push(i.tester(t));var r=new Array(t.length+1),n=0;for(a=0;a<t.length;a++)a>e?r[n++]=[t[a][0]+360,t[a][1]]:a===e?(r[n++]=t[a],r[n++]=[t[a][0],-90]):r[n++]=t[a];var o=i.tester(r);o.pts.pop(),c.push(o)}:function(t){c.push(i.tester(t))},o.type){case"MultiPolygon":for(r=0;r<s.length;r++)for(n=0;n<s[r].length;n++)e(s[r][n]);break;case"Polygon":for(r=0;r<s.length;r++)e(s[r])}return c}e.exports={plot:function(t,e,r){for(var i=0;i<r.length;i++)c(r[i],e.topojson);var o=e.layers.backplot.select(".choroplethlayer");a.makeTraceGroups(o,r,"trace choropleth").each(function(e){var r=n.select(this).selectAll("path.choroplethlocation").data(a.identity);r.enter().append("path").classed("choroplethlocation",!0),r.exit().remove(),l(t,e)})},feature2polygons:u}},{"../../lib":716,"../../lib/geo_location_utils":710,"../../lib/polygon":728,"../../lib/topojson_utils":743,"./style":930,d3:164}],929:[function(t,e,r){"use strict";e.exports=function(t,e){var r,n,a,i,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(a=(n=s[r]).ct)&&(i=l.c2p(a),o=c.c2p(a),e.contains([i,o],null,r,t)?(u.push({pointNumber:r,lon:a[0],lat:a[1]}),n.selected=1):n.selected=0);return u}},{}],930:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../../components/drawing"),o=t("../../components/colorscale");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(".choroplethlocation"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each(function(t){n.select(this).attr("fill",u(t.z)).call(a.stroke,t.mlc||c.color).call(i.dashLine,"",t.mlw||c.width||0).style("opacity",l.opacity)}),i.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?i.selectedPointStyle(r.selectAll(".choroplethlocation"),n,t):s(t,e)}}},{"../../components/color":591,"../../components/colorscale":603,"../../components/drawing":612,d3:164}],931:[function(t,e,r){"use strict";var n=t("../choropleth/attributes"),a=t("../../components/colorscale/attributes"),i=t("../../plots/template_attributes").hovertemplateAttrs,o=t("../../lib/extend").extendFlat;e.exports=o({locations:{valType:"data_array",editType:"calc"},z:{valType:"data_array",editType:"calc"},geojson:{valType:"any",editType:"calc"},below:{valType:"string",editType:"plot"},text:n.text,hovertext:n.hovertext,marker:{line:{color:o({},n.marker.line.color,{editType:"plot"}),width:o({},n.marker.line.width,{editType:"plot"}),editType:"calc"},opacity:o({},n.marker.opacity,{editType:"plot"}),editType:"calc"},selected:{marker:{opacity:o({},n.selected.marker.opacity,{editType:"plot"}),editType:"plot"},editType:"plot"},unselected:{marker:{opacity:o({},n.unselected.marker.opacity,{editType:"plot"}),editType:"plot"},editType:"plot"},hoverinfo:n.hoverinfo,hovertemplate:i({},{keys:["properties"]})},a("",{cLetter:"z",editTypeOverride:"calc"}))},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/template_attributes":840,"../choropleth/attributes":922}],932:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("@turf/area"),i=t("@turf/centroid"),o=t("../../lib"),s=t("../../components/colorscale"),l=t("../../components/drawing"),c=t("../../lib/geojson_utils").makeBlank,u=t("../choropleth/plot").feature2polygons;function h(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var a=l.makeSelectedPointStyleFns(r),i=0;i<t.length;i++){var s=t[i];s.fOut&&(s.fOut.properties.mo2=a.selectedOpacityFn(s))}e={type:"identity",property:"mo2"}}else e=o.isArrayOrTypedArray(r.marker.opacity)?{type:"identity",property:"mo"}:r.marker.opacity;return o.extendFlat(n.fill.paint,{"fill-opacity":e}),o.extendFlat(n.line.paint,{"line-opacity":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,l={layout:{visibility:"none"},paint:{}},f={layout:{visibility:"none"},paint:{}},p=e._opts={fill:l,line:f,geojson:c()};if(!r)return p;var d="string"==typeof e.geojson?(window.PlotlyGeoAssets||{})[e.geojson]:e.geojson;if(!o.isPlainObject(d))return o.error("Oops ... something when wrong when fetching "+e.geojson),p;var g,v={},m=[];for(g=0;g<t.length;g++){var y=t[g];y.loc&&(v[y.loc]=y)}var x,b,_,w=s.makeColorScaleFuncFromTrace(e),k=e.marker,T=k.line||{};function A(t){var e=v[t.id];if(e){var r=t.geometry;if("Polygon"===r.type||"MultiPolygon"===r.type){var n={fc:w(e.z)};x&&(n.mo=x(e)),b&&(n.mlc=b(e)),_&&(n.mlw=_(e));var s={type:"Feature",geometry:r,properties:n};e._polygons=u(s),e.ct=function(t){var e,r=t.geometry;if("MultiPolygon"===r.type)for(var n=r.coordinates,o=0,s=0;s<n.length;s++){var l={type:"Polygon",coordinates:n[s]},c=a.default(l);c>o&&(o=c,e=l)}else e=r;return i.default(e).geometry.coordinates}(s),e.fIn=t,e.fOut=s,m.push(s)}else o.log(["Location with id",e.loc,"does not have a valid GeoJSON geometry,","choroplethmapbox traces only support *Polygon* and *MultiPolygon* geometries."].join(" "))}delete v[t.id]}switch(o.isArrayOrTypedArray(k.opacity)&&(x=function(t){var e=t.mo;return n(e)?+o.constrain(e,0,1):0}),o.isArrayOrTypedArray(T.color)&&(b=function(t){return t.mlc}),o.isArrayOrTypedArray(T.width)&&(_=function(t){return t.mlw}),d.type){case"FeatureCollection":var M=d.features;for(g=0;g<M.length;g++)A(M[g]);break;case"Feature":A(d);break;default:return o.warn(["Invalid GeoJSON type",(d.type||"none")+",","choroplethmapbox traces only support *FeatureCollection* and *Feature* types."].join(" ")),p}for(var S in v)o.log("Location with id "+S+" does not have a matching feature");var E=x?{type:"identity",property:"mo"}:k.opacity;return o.extendFlat(l.paint,{"fill-color":{type:"identity",property:"fc"},"fill-opacity":E}),o.extendFlat(f.paint,{"line-color":b?{type:"identity",property:"mlc"}:T.color,"line-width":_?{type:"identity",property:"mlw"}:T.width,"line-opacity":E}),l.layout.visibility="visible",f.layout.visibility="visible",p.geojson={type:"FeatureCollection",features:m},h(t),p},convertOnSelect:h}},{"../../components/colorscale":603,"../../components/drawing":612,"../../lib":716,"../../lib/geojson_utils":711,"../choropleth/plot":928,"@turf/area":57,"@turf/centroid":58,"fast-isnumeric":227}],933:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/defaults"),i=t("./attributes");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s("locations"),c=s("z"),u=s("geojson");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&("string"==typeof u&&""!==u||n.isPlainObject(u))?(e._length=Math.min(l.length,c.length),s("below"),s("text"),s("hovertext"),s("hovertemplate"),s("marker.line.width")&&s("marker.line.color"),s("marker.opacity"),a(t,e,o,s,{prefix:"",cLetter:"z"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":716,"./attributes":931}],934:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../heatmap/colorbar"),calc:t("../choropleth/calc"),plot:t("./plot"),hoverPoints:t("../choropleth/hover"),eventData:t("../choropleth/event_data"),selectPoints:t("../choropleth/select"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var a=r[n].id;if("string"==typeof a&&0===a.indexOf("water"))for(var i=n+1;i<r.length;i++)if("string"==typeof(a=r[i].id)&&-1===a.indexOf("plotly-"))return a}},moduleType:"trace",name:"choroplethmapbox",basePlotModule:t("../../plots/mapbox"),categories:["mapbox","gl","noOpacity"],meta:{hr_name:"choropleth_mapbox"}}},{"../../plots/mapbox":819,"../choropleth/calc":923,"../choropleth/event_data":925,"../choropleth/hover":926,"../choropleth/select":929,"../heatmap/colorbar":1001,"./attributes":931,"./defaults":933,"./plot":935}],935:[function(t,e,r){"use strict";var n=t("./convert").convert,a=t("./convert").convertOnSelect,i=t("../../plots/mapbox/constants").traceLayerPrefix;function o(t,e){this.type="choroplethmapbox",this.subplot=t,this.uid=e,this.sourceId="source-"+e,this.layerList=[["fill",i+e+"-fill"],["line",i+e+"-line"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(a(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup["trace-"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var a=0;a<r.length;a++){var i=r[a],o=i[0],s=i[1],l=t[o];e.setOptions(s,"setLayoutProperty",l.layout),"visible"===l.layout.visibility&&e.setOptions(s,"setPaintProperty",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,a=this.sourceId,i=0;i<n.length;i++){var o=n[i],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:a,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,a=new o(t,r.uid),i=a.sourceId,s=n(e),l=a.below=t.belowLookup["trace-"+r.uid];return t.map.addSource(i,{type:"geojson",data:s.geojson}),a._addLayers(s,l),e[0].trace._glTrace=a,a}},{"../../plots/mapbox/constants":817,"./convert":932}],936:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../mesh3d/attributes"),o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat,l={x:{valType:"data_array",editType:"calc+clearAxisTypes"},y:{valType:"data_array",editType:"calc+clearAxisTypes"},z:{valType:"data_array",editType:"calc+clearAxisTypes"},u:{valType:"data_array",editType:"calc"},v:{valType:"data_array",editType:"calc"},w:{valType:"data_array",editType:"calc"},sizemode:{valType:"enumerated",values:["scaled","absolute"],editType:"calc",dflt:"scaled"},sizeref:{valType:"number",editType:"calc",min:0},anchor:{valType:"enumerated",editType:"calc",values:["tip","tail","cm","center"],dflt:"cm"},text:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},hovertext:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},hovertemplate:a({editType:"calc"},{keys:["norm"]})};s(l,n("",{colorAttr:"u/v/w norm",showScaleDflt:!0,editTypeOverride:"calc"}));["opacity","lightposition","lighting"].forEach(function(t){l[t]=i[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:"calc",flags:["x","y","z","u","v","w","norm","text","name"],dflt:"x+y+z+norm+text+name"}),l.transforms=void 0,e.exports=l},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/template_attributes":840,"../mesh3d/attributes":1059}],937:[function(t,e,r){"use strict";var n=t("../../components/colorscale/calc");e.exports=function(t,e){for(var r=e.u,a=e.v,i=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,a.length,i.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=a[c],f=i[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:"",cLetter:"c"})}},{"../../components/colorscale/calc":599}],938:[function(t,e,r){"use strict";var n=t("gl-cone3d"),a=t("gl-cone3d").createConeMesh,i=t("../../lib").simpleMap,o=t("../../lib/gl_format_color").parseColorScale,s=t("../../components/colorscale").extractOpts,l=t("../../plots/gl3d/zip3");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],a=this.data.z[e],i=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,a,i,o,s,Math.sqrt(i*i+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var h={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,a=t.dataScale,c={};function u(t,e){var n=r[e],o=a[h[e]];return i(t,function(t){return n.d2l(t)*o})}c.vectors=l(u(e.u,"xaxis"),u(e.v,"yaxis"),u(e.w,"zaxis"),e._len),c.positions=l(u(e.x,"xaxis"),u(e.y,"yaxis"),u(e.z,"zaxis"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=f[e.anchor],"scaled"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),v=e.lightposition;return g.lightPosition=[v.x,v.y,v.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),i=a(r,n),o=new c(t,e.uid);return o.mesh=i,o.data=e,i._trace=o,t.glplot.add(i),o}},{"../../components/colorscale":603,"../../lib":716,"../../lib/gl_format_color":713,"../../plots/gl3d/zip3":815,"gl-cone3d":244}],939:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/defaults"),i=t("./attributes");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s("u"),c=s("v"),u=s("w"),h=s("x"),f=s("y"),p=s("z");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s("sizeref"),s("sizemode"),s("anchor"),s("lighting.ambient"),s("lighting.diffuse"),s("lighting.specular"),s("lighting.roughness"),s("lighting.fresnel"),s("lightposition.x"),s("lightposition.y"),s("lightposition.z"),a(t,e,o,s,{prefix:"",cLetter:"c"}),s("text"),s("hovertext"),s("hovertemplate"),e._length=null):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":716,"./attributes":936}],940:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"cone",basePlotModule:t("../../plots/gl3d"),categories:["gl3d"],attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:{min:"cmin",max:"cmax"},calc:t("./calc"),plot:t("./convert"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{"../../plots/gl3d":804,"./attributes":936,"./calc":937,"./convert":938,"./defaults":939}],941:[function(t,e,r){"use strict";var n=t("../heatmap/attributes"),a=t("../scatter/attributes"),i=t("../../components/colorscale/attributes"),o=t("../../components/drawing/attributes").dash,s=t("../../plots/font_attributes"),l=t("../../lib/extend").extendFlat,c=t("../../constants/filter_ops"),u=c.COMPARISON_OPS2,h=c.INTERVAL_OPS,f=(t("../../constants/docs").FORMAT_LINK,a.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,hoverongaps:n.hoverongaps,connectgaps:l({},n.connectgaps,{}),fillcolor:{valType:"color",editType:"calc"},autocontour:{valType:"boolean",dflt:!0,editType:"calc",impliedEdits:{"contours.start":void 0,"contours.end":void 0,"contours.size":void 0}},ncontours:{valType:"integer",dflt:15,min:1,editType:"calc"},contours:{type:{valType:"enumerated",values:["levels","constraint"],dflt:"levels",editType:"calc"},start:{valType:"number",dflt:null,editType:"plot",impliedEdits:{"^autocontour":!1}},end:{valType:"number",dflt:null,editType:"plot",impliedEdits:{"^autocontour":!1}},size:{valType:"number",dflt:null,min:0,editType:"plot",impliedEdits:{"^autocontour":!1}},coloring:{valType:"enumerated",values:["fill","heatmap","lines","none"],dflt:"fill",editType:"calc"},showlines:{valType:"boolean",dflt:!0,editType:"plot"},showlabels:{valType:"boolean",dflt:!1,editType:"plot"},labelfont:s({editType:"plot",colorEditType:"style"}),labelformat:{valType:"string",dflt:"",editType:"plot"},operation:{valType:"enumerated",values:[].concat(u).concat(h),dflt:"=",editType:"calc"},value:{valType:"any",dflt:0,editType:"calc"},editType:"calc",impliedEdits:{autocontour:!1}},line:{color:l({},f.color,{editType:"style+colorbars"}),width:{valType:"number",min:0,editType:"style+colorbars"},dash:o,smoothing:l({},f.smoothing,{}),editType:"plot"}},i("",{cLetter:"z",autoColorDflt:!1,editTypeOverride:"calc"}))},{"../../components/colorscale/attributes":598,"../../components/drawing/attributes":611,"../../constants/docs":687,"../../constants/filter_ops":688,"../../lib/extend":707,"../../plots/font_attributes":790,"../heatmap/attributes":998,"../scatter/attributes":1118}],942:[function(t,e,r){"use strict";var n=t("../../components/colorscale"),a=t("../heatmap/calc"),i=t("./set_contours"),o=t("./end_plus");e.exports=function(t,e){var r=a(t,e),s=r[0].z;i(e,s);var l,c=e.contours,u=n.extractOpts(e);if("heatmap"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var g=h-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:"z"}),r}},{"../../components/colorscale":603,"../heatmap/calc":999,"./end_plus":952,"./set_contours":960}],943:[function(t,e,r){"use strict";e.exports=function(t,e){var r,n=t[0],a=n.z;switch(e.type){case"levels":var i=Math.min(a[0][0],a[0][1]);for(r=0;r<t.length;r++){var o=t[r];o.prefixBoundary=!o.edgepaths.length&&(i>o.level||o.starts.length&&i===o.level)}break;case"constraint":if(n.prefixBoundary=!1,n.edgepaths.length)return;var s=n.x.length,l=n.y.length,c=-1/0,u=1/0;for(r=0;r<l;r++)u=Math.min(u,a[r][0]),u=Math.min(u,a[r][s-1]),c=Math.max(c,a[r][0]),c=Math.max(c,a[r][s-1]);for(r=1;r<s-1;r++)u=Math.min(u,a[0][r]),u=Math.min(u,a[l-1][r]),c=Math.max(c,a[0][r]),c=Math.max(c,a[l-1][r]);var h,f,p=e.value;switch(e._operation){case">":p>c&&(n.prefixBoundary=!0);break;case"<":(p<u||n.starts.length&&p===u)&&(n.prefixBoundary=!0);break;case"[]":h=Math.min(p[0],p[1]),((f=Math.max(p[0],p[1]))<u||h>c||n.starts.length&&f===u)&&(n.prefixBoundary=!0);break;case"][":h=Math.min(p[0],p[1]),f=Math.max(p[0],p[1]),h<u&&f>c&&(n.prefixBoundary=!0)}}}},{}],944:[function(t,e,r){"use strict";var n=t("../../components/colorscale").extractOpts,a=t("./make_color_map"),i=t("./end_plus");e.exports={min:"zmin",max:"zmax",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=a(e,{isColorbar:!0});if("heatmap"===c){var h=n(e);r._fillgradient=e.colorscale,r._zrange=[h.min,h.max]}else"fill"===c&&(r._fillcolor=u);r._line={color:"lines"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:i(o),size:l}}}},{"../../components/colorscale":603,"./end_plus":952,"./make_color_map":957}],945:[function(t,e,r){"use strict";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],946:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("./label_defaults"),i=t("../../components/color"),o=i.addOpacity,s=i.opacity,l=t("../../constants/filter_ops"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,i,l,h){var f,p,d,g=e.contours,v=r("contours.operation");(g._operation=c[v],function(t,e){var r;-1===u.indexOf(e.operation)?(t("contours.value",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t("contours.value",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),"="===v?f=g.showlines=!0:(f=r("contours.showlines"),d=r("fillcolor",o((t.line||{}).color||l,.5))),f)&&(p=r("line.color",d&&s(d)?o(e.fillcolor,1):l),r("line.width",2),r("line.dash"));r("line.smoothing"),a(r,i,p,h)}},{"../../components/color":591,"../../constants/filter_ops":688,"./label_defaults":956,"fast-isnumeric":227}],947:[function(t,e,r){"use strict";var n=t("../../constants/filter_ops"),a=t("fast-isnumeric");function i(t,e){var r,i=Array.isArray(e);function o(t){return a(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(i?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=i?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=i?e.map(o):[o(e)]),r}function o(t){return function(e){e=i(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=i(t,e),end:1/0,size:1/0}}}e.exports={"[]":o("[]"),"][":o("]["),">":s(">"),"<":s("<"),"=":s("=")}},{"../../constants/filter_ops":688,"fast-isnumeric":227}],948:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){var a=n("contours.start"),i=n("contours.end"),o=!1===a||!1===i,s=r("contours.size");!(o?e.autocontour=!0:r("autocontour",!1))&&s||r("ncontours")}},{}],949:[function(t,e,r){"use strict";var n=t("../../lib");function a(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths),starts:n.extendDeep([],t.starts)})}e.exports=function(t,e){var r,i,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case"=":case"<":return t;case">":for(1!==t.length&&n.warn("Contour data invalid for the specified inequality operation."),i=t[0],r=0;r<i.edgepaths.length;r++)i.edgepaths[r]=s(i.edgepaths[r]);for(r=0;r<i.paths.length;r++)i.paths[r]=s(i.paths[r]);for(r=0;r<i.starts.length;r++)i.starts[r]=s(i.starts[r]);return t;case"][":var c=s;s=l,l=c;case"[]":for(2!==t.length&&n.warn("Contour data invalid for the specified inequality range operation."),i=a(t[0]),o=a(t[1]),r=0;r<i.edgepaths.length;r++)i.edgepaths[r]=s(i.edgepaths[r]);for(r=0;r<i.paths.length;r++)i.paths[r]=s(i.paths[r]);for(r=0;r<i.starts.length;r++)i.starts[r]=s(i.starts[r]);for(;o.edgepaths.length;)i.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)i.paths.push(l(o.paths.shift()));for(;o.starts.length;)i.starts.push(l(o.starts.shift()));return[i]}}},{"../../lib":716}],950:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../heatmap/xyz_defaults"),i=t("./constraint_defaults"),o=t("./contours_defaults"),s=t("./style_defaults"),l=t("./attributes");e.exports=function(t,e,r,c){function u(r,a){return n.coerce(t,e,l,r,a)}if(a(t,e,u,c)){u("text"),u("hovertext"),u("hovertemplate"),u("hoverongaps");var h="constraint"===u("contours.type");u("connectgaps",n.isArray1D(e.z)),h?i(t,e,u,c,r):(o(t,e,u,function(r){return n.coerce2(t,e,l,r)}),s(t,e,u,c))}else e.visible=!1}},{"../../lib":716,"../heatmap/xyz_defaults":1012,"./attributes":941,"./constraint_defaults":946,"./contours_defaults":948,"./style_defaults":962}],951:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./constraint_mapping"),i=t("./end_plus");e.exports=function(t,e,r){for(var o="constraint"===t.type?a[t._operation](t.value):t,s=o.size,l=[],c=i(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn("Too many contours, clipping at 1000",t);break}return l}},{"../../lib":716,"./constraint_mapping":947,"./end_plus":952}],952:[function(t,e,r){"use strict";e.exports=function(t){return t.end+t.size/1e6}},{}],953:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./constants");function i(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(","),h=t.crossings[u],f=function(t,e,r){var n=0,i=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:i=0===r[1]?1:-1:-1!==a.BOTTOMSTART.indexOf(t)?i=1:-1!==a.LEFTSTART.indexOf(t)?n=1:-1!==a.TOPSTART.indexOf(t)?i=-1:n=-1;return[n,i]}(h,r,e),p=[s(t,e,[-f[0],-f[1]])],d=t.z.length,g=t.z[0].length,v=e.slice(),m=f.slice();for(c=0;c<1e4;c++){if(h>20?(h=a.CHOOSESADDLE[h][(f[0]||f[1])<0?0:1],t.crossings[u]=a.SADDLEREMAINDER[h]):delete t.crossings[u],!(f=a.NEWDELTA[h])){n.log("Found bad marching index:",h,e,t.level);break}p.push(s(t,e,f)),e[0]+=f[0],e[1]+=f[1],u=e.join(","),i(p[p.length-1],p[p.length-2],o,l)&&p.pop();var y=f[0]&&(e[0]<0||e[0]>g-2)||f[1]&&(e[1]<0||e[1]>d-2);if(e[0]===v[0]&&e[1]===v[1]&&f[0]===m[0]&&f[1]===m[1]||r&&y)break;h=t.crossings[u]}1e4===c&&n.log("Infinite loop in contour?");var x,b,_,w,k,T,A,M,S,E,L,C,P,O,z,I=i(p[0],p[p.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<p.length;c++)C=p[c],P=p[c-1],void 0,void 0,O=C[2]-P[2],z=C[3]-P[3],D+=A=Math.sqrt(O*O+z*z),F.push(A);var N=D/F.length*R;function j(t){return p[t%p.length]}for(c=p.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(I&&c===p.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];k=c-b+_+1,T=Math.floor((c+b+_+2)/2),w=I||c!==p.length-2?I||-1!==b?k%2?j(T):[(j(T)[0]+j(T+1)[0])/2,(j(T)[1]+j(T+1)[1])/2]:p[0]:p[p.length-1],p.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),I&&(c===p.length-2?p[_]=p[p.length-1]:0===c&&(p[p.length-1]=p[0]))}for(p.splice(0,B),c=0;c<p.length;c++)p[c].length=2;if(!(p.length<2))if(I)p.pop(),t.paths.push(p);else{r||n.log("Unclosed interior contour?",t.level,v.join(","),p.join("L"));var V=!1;for(M=0;M<t.edgepaths.length;M++)if(E=t.edgepaths[M],!V&&i(E[0],p[p.length-1],o,l)){p.pop(),V=!0;var U=!1;for(S=0;S<t.edgepaths.length;S++)if(i((L=t.edgepaths[S])[L.length-1],p[0],o,l)){U=!0,p.shift(),t.edgepaths.splice(M,1),S===M?t.paths.push(p.concat(L)):(S>M&&S--,t.edgepaths[S]=L.concat(p,E));break}U||(t.edgepaths[M]=p.concat(E))}for(M=0;M<t.edgepaths.length&&!V;M++)i((E=t.edgepaths[M])[E.length-1],p[0],o,l)&&(p.shift(),t.edgepaths[M]=E.concat(p),V=!0);V||t.edgepaths.push(p)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),a=e[1]+Math.max(r[1],0),i=t.z[a][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-i)/(t.z[a][n+1]-i);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[a],!0),n+l,a]}var c=(t.level-i)/(t.z[a+1][n]-i);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[a]+c*t.y[a+1],!0),n,a+c]}e.exports=function(t,e,r){var a,i,s,l;for(e=e||.01,r=r||.01,i=0;i<t.length;i++){for(s=t[i],l=0;l<s.starts.length;l++)o(s,s.starts[l],"edge",e,r);for(a=0;Object.keys(s.crossings).length&&a<1e4;)a++,o(s,Object.keys(s.crossings)[0].split(",").map(Number),void 0,e,r);1e4===a&&n.log("Infinite loop in contour?")}}},{"../../lib":716,"./constants":945}],954:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../heatmap/hover");e.exports=function(t,e,r,i,o){var s=a(t,e,r,i,o,!0);return s&&s.forEach(function(t){var e=t.trace;"constraint"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))}),s}},{"../../components/color":591,"../heatmap/hover":1005}],955:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot").plot,style:t("./style"),colorbar:t("./colorbar"),hoverPoints:t("./hover"),moduleType:"trace",name:"contour",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","2dMap","contour","showLegend"],meta:{}}},{"../../plots/cartesian":775,"./attributes":941,"./calc":942,"./colorbar":944,"./defaults":950,"./hover":954,"./plot":959,"./style":961}],956:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e,r,a){if(a||(a={}),t("contours.showlabels")){var i=e.font;n.coerceFont(t,"contours.labelfont",{family:i.family,size:i.size,color:r}),t("contours.labelformat")}!1!==a.hasHover&&t("zhoverformat")}},{"../../lib":716}],957:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/colorscale"),i=t("./end_plus");e.exports=function(t){var e=t.contours,r=e.start,o=i(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c="lines"===e.coloring?0:1,u=a.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?a.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),v=new Array(d);if("heatmap"===e.coloring){var m=u.min,y=u.max;for(f=0;f<d;f++)h=p[f],g[f]=h[0]*(y-m)+m,v[f]=h[1];var x=n.extent([m,y,e.start,e.start+s*(l-1)]),b=x[m<y?0:1],_=x[m<y?1:0];b!==m&&(g.splice(0,0,b),v.splice(0,0,v[0])),_!==y&&(g.push(_),v.push(v[v.length-1]))}else for(f=0;f<d;f++)h=p[f],g[f]=(h[0]*(l+c-1)-c/2)*s+r,v[f]=h[1];return a.makeColorScaleFunc({domain:g,range:v},{noNumericCheck:!0})}},{"../../components/colorscale":603,"./end_plus":952,d3:164}],958:[function(t,e,r){"use strict";var n=t("./constants");function a(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,i,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(i=o.slice(),0===e&&(i=i.concat(n.LEFTSTART)),e===d-2&&(i=i.concat(n.RIGHTSTART)),s=e+","+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=a((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==i.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==i.indexOf(c,i.indexOf(c)+1)&&u.starts.push([e,r])))}},{"./constants":945}],959:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../../components/colorscale"),s=t("../../lib/svg_text_utils"),l=t("../../plots/cartesian/axes"),c=t("../../plots/cartesian/set_convert"),u=t("../heatmap/plot"),h=t("./make_crossings"),f=t("./find_all_paths"),p=t("./empty_pathinfo"),d=t("./convert_to_constraints"),g=t("./close_boundaries"),v=t("./constants"),m=v.LABELOPTIMIZER;function y(t,e){var r,n,o,s,l,c,u,h="",f=0,p=t.edgepaths.map(function(t,e){return e}),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function v(t){return Math.abs(t[0]-e[0][0])<.01}function m(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=i.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,"L"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){a.log("Missing end?",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!m(r)?n=e[1]:v(r)?n=e[0]:g(r)?n=e[3]:m(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):a.log("endpt to newendpt is not vert. or horz.",r,n,y)}if(r=n,s>=0)break;h+="L"+n}if(s===t.edgepaths.length){a.log("unclosed perimeter path");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+="Z")}for(f=0;f<t.paths.length;f++)h+=i.smoothclosed(t.paths[f],t.smoothing);return h}function x(t,e,r,n){var i=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*i,h=Math.sin(c)*i,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=m.EDGECOST*(1/(f-1)+1/(p-1));d+=m.ANGLECOST*c*c;for(var g=s-u,v=l-h,y=s+u,x=l+h,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,k=Math.sin(_.theta)*_.width/2,T=2*a.segmentDistance(g,v,y,x,_.x-w,_.y-k,_.x+w,_.y+k)/(e.height+_.height),A=_.level===e.level,M=A?m.SAMELEVELDISTANCE:1;if(T<=M)return 1/0;d+=m.NEIGHBORCOST*(A?m.SAMELEVELFACTOR:1)/(T-M)}return d}r.plot=function(t,e,o,s){var l=e.xaxis,c=e.yaxis;a.makeTraceGroups(s,o,"contour").each(function(o){var s=n.select(this),m=o[0],x=m.trace,b=m.x,_=m.y,w=x.contours,k=p(w,e,m),T=a.ensureSingle(s,"g","heatmapcoloring"),A=[];"heatmap"===w.coloring&&(A=[o]),u(t,e,A,T),h(k),f(k);var M=l.c2p(b[0],!0),S=l.c2p(b[b.length-1],!0),E=c.c2p(_[0],!0),L=c.c2p(_[_.length-1],!0),C=[[M,L],[S,L],[S,E],[M,E]],P=k;"constraint"===w.type&&(P=d(k,w._operation)),function(t,e,r){var n=a.ensureSingle(t,"g","contourbg").selectAll("path").data("fill"===r.coloring?[0]:[]);n.enter().append("path"),n.exit().remove(),n.attr("d","M"+e.join("L")+"Z").style("stroke","none")}(s,C,w),function(t,e,r,i){var o="fill"===i.coloring||"constraint"===i.type&&"="!==i._operation,s="M"+r.join("L")+"Z";o&&g(e,i);var l=a.ensureSingle(t,"g","contourfill").selectAll("path").data(o?e:[]);l.enter().append("path"),l.exit().remove(),l.each(function(t){var e=(t.prefixBoundary?s:"")+y(t,r);e?n.select(this).attr("d",e).style("stroke","none"):n.select(this).remove()})}(s,P,C,w),function(t,e,o,s,l){var c=a.ensureSingle(t,"g","contourlines"),u=!1!==l.showlines,h=l.showlabels,f=u&&h,p=r.createLines(c,u||h,e),d=r.createLineClip(c,f,o,s.trace.uid),g=t.selectAll("g.contourlabels").data(h?[0]:[]);if(g.exit().remove(),g.enter().append("g").classed("contourlabels",!0),h){var m=[],y=[];a.clearLocationCache();var x=r.labelFormatter(o,s),b=i.tester.append("text").attr("data-notex",1).call(i.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,k=_._length,T=w._length,A=_.range,M=w.range,S=a.aggNums(Math.min,null,s.x),E=a.aggNums(Math.max,null,s.x),L=a.aggNums(Math.min,null,s.y),C=a.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),O=Math.min(_.c2p(E,!0),k),z=Math.max(w.c2p(C,!0),0),I=Math.min(w.c2p(L,!0),T),D={};A[0]<A[1]?(D.left=P,D.right=O):(D.left=O,D.right=P),M[0]<M[1]?(D.top=z,D.bottom=I):(D.top=I,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,m.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(k*k+T*T),F=v.LABELDISTANCE*R/Math.max(1,e.length/v.LABELINCREASE);p.each(function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll("path").each(function(){var t=a.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*v.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),v.LABELMAX),i=0;i<n;i++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,m)}})}),b.remove(),r.drawLabels(g,y,o,d,f?m:null)}h&&!u&&p.remove()}(s,k,t,m,w),function(t,e,r,n,o){var s=n.trace,l=r._fullLayout._clips,c="clip"+s.uid,u=l.selectAll("#"+c).data(s.connectgaps?[]:[0]);if(u.enter().append("clipPath").classed("contourclip",!0).attr("id",c),u.exit().remove(),!1===s.connectgaps){var p={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:function(t){var e,r,n=t.trace._emptypoints,a=[],i=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<i;e++)a.push(s.slice());for(e=0;e<n.length;e++)r=n[e],a[r[0]][r[1]]=0;return t.zmask=a,a}(n),smoothing:0};h([p]),f([p]),g([p],{type:"levels"});var d=a.ensureSingle(u,"path","");d.attr("d",(p.prefixBoundary?"M"+o.join("L")+"Z":"")+y(p,o))}else c=null;i.setClipUrl(t,c,r)}(s,e,t,m,C)})},r.createLines=function(t,e,r){var n=r[0].smoothing,a=t.selectAll("g.contourlevel").data(e?r:[]);if(a.exit().remove(),a.enter().append("g").classed("contourlevel",!0),e){var o=a.selectAll("path.openline").data(function(t){return t.pedgepaths||t.edgepaths});o.exit().remove(),o.enter().append("path").classed("openline",!0),o.attr("d",function(t){return i.smoothopen(t,n)}).style("stroke-miterlimit",1).style("vector-effect","non-scaling-stroke");var s=a.selectAll("path.closedline").data(function(t){return t.ppaths||t.paths});s.exit().remove(),s.enter().append("path").classed("closedline",!0),s.attr("d",function(t){return i.smoothclosed(t,n)}).style("stroke-miterlimit",1).style("vector-effect","non-scaling-stroke")}return a},r.createLineClip=function(t,e,r,n){var a=e?"clipline"+n:null,o=r._fullLayout._clips.selectAll("#"+a).data(e?[0]:[]);return o.exit().remove(),o.enter().append("clipPath").classed("contourlineclip",!0).attr("id",a),i.setClipUrl(t,a,r),o},r.labelFormatter=function(t,e){var r=t._fullLayout,n=e.trace,a=n.contours;if(a.labelformat)return r._d3locale.numberFormat(a.labelformat);var i,s=o.extractOpts(n);if(s&&s.colorbar&&s.colorbar._axis)i=s.colorbar._axis;else{if(i={type:"linear",_id:"ycontour",showexponent:"all",exponentformat:"B"},"constraint"===a.type){var u=a.value;Array.isArray(u)?i.range=[u[0],u[u.length-1]]:i.range=[u,u]}else i.range=[a.start,a.end],i.nticks=(a.end-a.start)/a.size;i.range[0]===i.range[1]&&(i.range[1]+=i.range[0]||1),i.nticks||(i.nticks=1e3),c(i,r),l.prepTicks(i),i._tmin=null,i._tmax=null}return function(t){return l.tickText(i,t).text}},r.calcTextOpts=function(t,e,r,n){var a=e(t);r.text(a).call(s.convertToTspans,n);var o=i.bBox(r.node(),!0);return{text:a,width:o.width,height:o.height,level:t,dy:(o.top+o.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,i){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/m.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(m.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<m.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=a.getTextLocation(t,e.total,d,h),v=x(g,r,n,i);v<f&&(f=v,u=g,c=d)}if(f>2*m.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=m.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var a=e.width/2,i=e.height/2,o=t.x,s=t.y,l=t.theta,c=Math.sin(l),u=Math.cos(l),h=a*u,f=i*c,p=a*c,d=-i*u,g=[[o-h-f,s-p-d],[o+h-f,s+p-d],[o+h+f,s+p+d],[o-h+f,s-p+d]];r.push({text:e.text,x:o,y:s,dy:e.dy,theta:l,level:e.level,width:e.width,height:e.height}),n.push(g)},r.drawLabels=function(t,e,r,i,o){var l=t.selectAll("text").data(e,function(t){return t.text+","+t.x+","+t.y+","+t.theta});if(l.exit().remove(),l.enter().append("text").attr({"data-notex":1,"text-anchor":"middle"}).each(function(t){var e=t.x+Math.sin(t.theta)*t.dy,a=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:a,transform:"rotate("+180*t.theta/Math.PI+" "+e+" "+a+")"}).call(s.convertToTspans,r)}),o){for(var c="",u=0;u<o.length;u++)c+="M"+o[u].join("L")+"Z";a.ensureSingle(i,"path","").attr("d",c)}}},{"../../components/colorscale":603,"../../components/drawing":612,"../../lib":716,"../../lib/svg_text_utils":740,"../../plots/cartesian/axes":764,"../../plots/cartesian/set_convert":782,"../heatmap/plot":1009,"./close_boundaries":943,"./constants":945,"./convert_to_constraints":949,"./empty_pathinfo":951,"./find_all_paths":953,"./make_crossings":958,d3:164}],960:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib");function i(t,e,r){var a={type:"linear",range:[t,e]};return n.autoTicks(a,(e-t)/(r||15)),a}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=a.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=a.aggNums(Math.max,null,e));var l=i(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),a.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if("constraint"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;if(u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),!(r.size>0))c=u===h?1:i(u,h,t.ncontours).dtick,f.size=r.size=c}}},{"../../lib":716,"../../plots/cartesian/axes":764}],961:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../heatmap/style"),o=t("./make_color_map");e.exports=function(t){var e=n.select(t).selectAll("g.contour");e.style("opacity",function(t){return t[0].trace.opacity}),e.each(function(t){var e=n.select(this),r=t[0].trace,i=r.contours,s=r.line,l=i.size||1,c=i.start,u="constraint"===i.type,h=!u&&"lines"===i.coloring,f=!u&&"fill"===i.coloring,p=h||f?o(r):null;e.selectAll("g.contourlevel").each(function(t){n.select(this).selectAll("path").call(a.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)});var d=i.labelfont;if(e.selectAll("g.contourlabels text").each(function(t){a.font(n.select(this),{family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})}),u)e.selectAll("g.contourfill path").style("fill",r.fillcolor);else if(f){var g;e.selectAll("g.contourfill path").style("fill",function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)}),void 0===g&&(g=c),e.selectAll("g.contourbg path").style("fill",p(g-.5*l))}}),i(t)}},{"../../components/drawing":612,"../heatmap/style":1010,"./make_color_map":957,d3:164}],962:[function(t,e,r){"use strict";var n=t("../../components/colorscale/defaults"),a=t("./label_defaults");e.exports=function(t,e,r,i,o){var s,l=r("contours.coloring"),c="";"fill"===l&&(s=r("contours.showlines")),!1!==s&&("lines"!==l&&(c=r("line.color","#000")),r("line.width",.5),r("line.dash")),"none"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,i,r,{prefix:"",cLetter:"z"})),r("line.smoothing"),a(r,i,c,o)}},{"../../components/colorscale/defaults":601,"./label_defaults":956}],963:[function(t,e,r){"use strict";var n=t("../heatmap/attributes"),a=t("../contour/attributes"),i=t("../../components/colorscale/attributes"),o=t("../../lib/extend").extendFlat,s=a.contours;e.exports=o({carpet:{valType:"string",editType:"calc"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:a.fillcolor,autocontour:a.autocontour,ncontours:a.ncontours,contours:{type:s.type,start:s.start,end:s.end,size:s.size,coloring:{valType:"enumerated",values:["fill","lines","none"],dflt:"fill",editType:"calc"},showlines:s.showlines,showlabels:s.showlabels,labelfont:s.labelfont,labelformat:s.labelformat,operation:s.operation,value:s.value,editType:"calc",impliedEdits:{autocontour:!1}},line:{color:a.line.color,width:a.line.width,dash:a.line.dash,smoothing:a.line.smoothing,editType:"plot"},transforms:void 0},i("",{cLetter:"z",autoColorDflt:!1}))},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../contour/attributes":941,"../heatmap/attributes":998}],964:[function(t,e,r){"use strict";var n=t("../../components/colorscale/calc"),a=t("../../lib"),i=t("../heatmap/convert_column_xyz"),o=t("../heatmap/clean_2d_array"),s=t("../heatmap/interp2d"),l=t("../heatmap/find_empties"),c=t("../heatmap/make_bound_array"),u=t("./defaults"),h=t("../carpet/lookup_carpetid"),f=t("../contour/set_contours");e.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&"legendonly"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,h,f,p,d,g,v=e._carpetTrace,m=v.aaxis,y=v.baxis;m._minDtick=0,y._minDtick=0,a.isArray1D(e.z)&&i(e,m,y,"a","b",["z"]);r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?m.makeCalcdata(e,"_a"):[],f=f?y.makeCalcdata(e,"_b"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=a.maxRowLength(g),b="scaled"===e.xtype?"":r,_=c(e,b,u,h,x,m),w="scaled"===e.ytype?"":f,k=c(e,w,p,d,g.length,y),T={a:_,b:k,z:g};"levels"===e.contours.type&&"none"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:"",cLetter:"z"});return[T]}(t,e);return f(e,e._z),g}}},{"../../components/colorscale/calc":599,"../../lib":716,"../carpet/lookup_carpetid":914,"../contour/set_contours":960,"../heatmap/clean_2d_array":1e3,"../heatmap/convert_column_xyz":1002,"../heatmap/find_empties":1004,"../heatmap/interp2d":1007,"../heatmap/make_bound_array":1008,"./defaults":965}],965:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../heatmap/xyz_defaults"),i=t("./attributes"),o=t("../contour/constraint_defaults"),s=t("../contour/contours_defaults"),l=t("../contour/style_defaults");e.exports=function(t,e,r,c){function u(r,a){return n.coerce(t,e,i,r,a)}if(u("carpet"),t.a&&t.b){if(!a(t,e,u,c,"a","b"))return void(e.visible=!1);u("text"),"constraint"===u("contours.type")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,function(r){return n.coerce2(t,e,i,r)}),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{"../../lib":716,"../contour/constraint_defaults":946,"../contour/contours_defaults":948,"../contour/style_defaults":962,"../heatmap/xyz_defaults":1012,"./attributes":963}],966:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../contour/colorbar"),calc:t("./calc"),plot:t("./plot"),style:t("../contour/style"),moduleType:"trace",name:"contourcarpet",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","carpet","contour","symbols","showLegend","hasLines","carpetDependent","noHover","noSortingByValue"],meta:{}}},{"../../plots/cartesian":775,"../contour/colorbar":944,"../contour/style":961,"./attributes":963,"./calc":964,"./defaults":965,"./plot":967}],967:[function(t,e,r){"use strict";var n=t("d3"),a=t("../carpet/map_1d_array"),i=t("../carpet/makepath"),o=t("../../components/drawing"),s=t("../../lib"),l=t("../contour/make_crossings"),c=t("../contour/find_all_paths"),u=t("../contour/plot"),h=t("../contour/constants"),f=t("../contour/convert_to_constraints"),p=t("../contour/empty_pathinfo"),d=t("../contour/close_boundaries"),g=t("../carpet/lookup_carpetid"),v=t("../carpet/axis_aligned_line");function m(t,e,r){var n=t.getPointAtLength(e),a=t.getPointAtLength(r),i=a.x-n.x,o=a.y-n.y,s=Math.sqrt(i*i+o*o);return[i/s,o/s]}function y(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function x(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,b){var _=e.xaxis,w=e.yaxis;s.makeTraceGroups(b,r,"contour").each(function(r){var b=n.select(this),k=r[0],T=k.trace,A=T._carpetTrace=g(t,T),M=t.calcdata[A.index][0];if(A.visible&&"legendonly"!==A.visible){var S=k.a,E=k.b,L=T.contours,C=p(L,e,k),P="constraint"===L.type,O=L._operation,z=P?"="===O?"lines":"fill":L.coloring,I=[[S[0],E[E.length-1]],[S[S.length-1],E[E.length-1]],[S[S.length-1],E[0]],[S[0],E[0]]];l(C);var D=1e-8*(S[S.length-1]-S[0]),R=1e-8*(E[E.length-1]-E[0]);c(C,D,R);var F,B,N,j,V=C;"constraint"===L.type&&(V=f(C,O)),function(t,e){var r,n,a,i,o,s,l,c,u;for(r=0;r<t.length;r++){for(i=t[r],o=i.pedgepaths=[],s=i.ppaths=[],n=0;n<i.edgepaths.length;n++){for(u=i.edgepaths[n],l=[],a=0;a<u.length;a++)l[a]=e(u[a]);o.push(l)}for(n=0;n<i.paths.length;n++){for(u=i.paths[n],c=[],a=0;a<u.length;a++)c[a]=e(u[a]);s.push(c)}}}(C,H);var U=[];for(j=M.clipsegments.length-1;j>=0;j--)F=M.clipsegments[j],B=a([],F.x,_.c2p),N=a([],F.y,w.c2p),B.reverse(),N.reverse(),U.push(i(B,N,F.bicubic));var q="M"+U.join("L")+"Z";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,"g","contourbg").selectAll("path").data("fill"!==l||o?[]:[0]);p.enter().append("path"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=a([],c.x,r.c2p),h=a([],c.y,n.c2p),d.push(i(u,h,c.bicubic));p.attr("d","M"+d.join("L")+"Z").style("stroke","none")}(b,M.clipsegments,_,w,P,z),function(t,e,r,a,i,l,c,u,h,f,p){var g="fill"===f;g&&d(i,t.contours);var m=s.ensureSingle(e,"g","contourfill").selectAll("path").data(g?i:[]);m.enter().append("path"),m.exit().remove(),m.each(function(t){var e=(t.prefixBoundary?p:"")+function(t,e,r,n,a,i,l,c){var u,h,f,p,d,g,m,y="",x=e.edgepaths.map(function(t,e){return e}),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function k(t){return Math.abs(t[1]-r[0][1])<w}function T(t){return Math.abs(t[1]-r[2][1])<w}function A(t){return Math.abs(t[0]-r[0][0])<_}function M(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,o,s,u="";for(k(t)&&!M(t)||T(t)&&!A(t)?(s=a.aaxis,o=v(a,i,[t[0],e[0]],.5*(t[1]+e[1]))):(s=a.baxis,o=v(a,i,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<o.length;r++)for(u+=s.smoothing?"C":"L",n=0;n<o[r].length;n++){var h=o[r][n];u+=[l.c2p(h[0]),c.c2p(h[1])]+" "}return u}u=0,h=null;for(;x.length;){var E=e.edgepaths[u][0];for(h&&(y+=S(h,E)),m=o.smoothopen(e.edgepaths[u].map(n),e.smoothing),y+=b?m:m.replace(/^M/,"L"),x.splice(x.indexOf(u),1),h=e.edgepaths[u][e.edgepaths[u].length-1],d=-1,p=0;p<4;p++){if(!h){s.log("Missing end?",u,e);break}for(k(h)&&!M(h)?f=r[1]:A(h)?f=r[0]:T(h)?f=r[3]:M(h)&&(f=r[2]),g=0;g<e.edgepaths.length;g++){var L=e.edgepaths[g][0];Math.abs(h[0]-f[0])<_?Math.abs(h[0]-L[0])<_&&(L[1]-h[1])*(f[1]-L[1])>=0&&(f=L,d=g):Math.abs(h[1]-f[1])<w?Math.abs(h[1]-L[1])<w&&(L[0]-h[0])*(f[0]-L[0])>=0&&(f=L,d=g):s.log("endpt to newendpt is not vert. or horz.",h,f,L)}if(d>=0)break;y+=S(h,f),h=f}if(d===e.edgepaths.length){s.log("unclosed perimeter path");break}u=d,(b=-1===x.indexOf(u))&&(u=x[0],y+=S(h,f)+"Z",h=null)}for(u=0;u<e.paths.length;u++)y+=o.smoothclosed(e.paths[u].map(n),e.smoothing);return y}(0,t,l,c,u,h,r,a);e?n.select(this).attr("d",e).style("stroke","none"):n.select(this).remove()})}(T,b,_,w,V,I,H,A,M,z,q),function(t,e,r,a,i,l,c){var f=s.ensureSingle(t,"g","contourlines"),p=!1!==i.showlines,d=i.showlabels,g=p&&d,v=u.createLines(f,p||d,e),b=u.createLineClip(f,g,r,a.trace.uid),_=t.selectAll("g.contourlabels").data(d?[0]:[]);if(_.exit().remove(),_.enter().append("g").classed("contourlabels",!0),d){var w=l.xaxis,k=l.yaxis,T=w._length,A=k._length,M=[[[0,0],[T,0],[T,A],[0,A]]],S=[];s.clearLocationCache();var E=u.labelFormatter(r,a),L=o.tester.append("text").attr("data-notex",1).call(o.font,i.labelfont),C={left:0,right:T,center:T/2,top:0,bottom:A,middle:A/2},P=Math.sqrt(T*T+A*A),O=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);v.each(function(t){var e=u.calcTextOpts(t.level,E,L,r);n.select(this).selectAll("path").each(function(r){var n=s.getVisibleSegment(this,C,e.height/2);if(n&&(function(t,e,r,n,a,i){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=a.a[0],c=a.a[a.a.length-1],u=a.b[0],h=a.b[a.b.length-1];function f(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=y(a.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,i*x(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-h)<.1)&&(r=y(a.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,i*x(e,r)/2)),n}var p=m(t,0,1),d=m(t,n.total,n.total-1),g=f(o[0],p),v=n.total-f(o[o.length-1],d);n.min<g&&(n.min=g);n.max>v&&(n.max=v);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*h.LABELMIN)))for(var a=Math.min(Math.ceil(n.len/O),h.LABELMAX),i=0;i<a;i++){var o=u.findBestTextLocation(this,n,e,S,C);if(!o)break;u.addLabelData(o,e,S,M)}})}),L.remove(),u.drawLabels(_,S,r,b,g?M:null)}d&&!p&&v.remove()}(b,C,t,k,L,e,A),o.setClipUrl(b,A._clipPathId,t)}function H(t){var e=A.ab2xy(t[0],t[1],!0);return[_.c2p(e[0]),w.c2p(e[1])]}})}},{"../../components/drawing":612,"../../lib":716,"../carpet/axis_aligned_line":898,"../carpet/lookup_carpetid":914,"../carpet/makepath":915,"../carpet/map_1d_array":916,"../contour/close_boundaries":943,"../contour/constants":945,"../contour/convert_to_constraints":949,"../contour/empty_pathinfo":951,"../contour/find_all_paths":953,"../contour/make_crossings":958,"../contour/plot":959,d3:164}],968:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../../plots/attributes"),o=t("../scattermapbox/attributes"),s=t("../../lib/extend").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:"data_array",editType:"calc"},radius:{valType:"number",editType:"plot",arrayOk:!0,min:1,dflt:30},below:{valType:"string",editType:"plot"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},i.hoverinfo,{flags:["lon","lat","z","text","name"]}),hovertemplate:a()},n("",{cLetter:"z",editTypeOverride:"calc"}))},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/template_attributes":840,"../scattermapbox/attributes":1181}],969:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib").isArrayOrTypedArray,i=t("../../constants/numerical").BADNUM,o=t("../../components/colorscale/calc"),s=t("../../lib")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=a(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[i,i],u){var g=c[h];f.z=n(g)?g:i}}return o(t,e,{vals:u?c:[0,1],containerStr:"",cLetter:"z"}),r&&(l[0].t={labels:{lat:s(t,"lat:")+" ",lon:s(t,"lon:")+" "}}),l}},{"../../components/colorscale/calc":599,"../../constants/numerical":692,"../../lib":716,"fast-isnumeric":227}],970:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../components/color"),o=t("../../components/colorscale"),s=t("../../constants/numerical").BADNUM,l=t("../../lib/geojson_utils").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:"none"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=a.isArrayOrTypedArray(f)&&f.length,g=a.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var v=t[u],m=v.lonlat;if(m[0]!==s){var y={};if(d){var x=v.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:"Feature",geometry:{type:"Point",coordinates:m},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],k=["interpolate",["linear"],["heatmap-density"],0,i.opacity(w)<1?w:i.addOpacity(w,0)];for(u=1;u<_.length;u++)k.push(_[u][0],_[u][1]);var T=["interpolate",["linear"],["get","z"],b.min,0,b.max,1];return a.extendFlat(c.heatmap.paint,{"heatmap-weight":d?T:1/(b.max-b.min),"heatmap-color":k,"heatmap-radius":g?{type:"identity",property:"r"}:e.radius,"heatmap-opacity":e.opacity}),c.geojson={type:"FeatureCollection",features:h},c.heatmap.layout.visibility="visible",c}},{"../../components/color":591,"../../components/colorscale":603,"../../constants/numerical":692,"../../lib":716,"../../lib/geojson_utils":711,"fast-isnumeric":227}],971:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/defaults"),i=t("./attributes");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s("lon")||[],c=s("lat")||[],u=Math.min(l.length,c.length);u?(e._length=u,s("z"),s("radius"),s("below"),s("text"),s("hovertext"),s("hovertemplate"),a(t,e,o,s,{prefix:"",cLetter:"z"})):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":716,"./attributes":968}],972:[function(t,e,r){"use strict";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],973:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../scattermapbox/hover");e.exports=function(t,e,r){var o=i(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,"z"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=a.tickText(h,h.c2l(u.z),"hover").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var a=(e.hi||t.hoverinfo).split("+"),i=-1!==a.indexOf("all"),o=-1!==a.indexOf("lon"),s=-1!==a.indexOf("lat"),l=e.lonlat,c=[];function u(t){return t+"\xb0"}i||o&&s?c.push("("+u(l[0])+", "+u(l[1])+")"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==a.indexOf("text"))&&n.fillText(e,t,c);return c.join("<br>")}(c,u,l[0].t.labels),[s]}}},{"../../lib":716,"../../plots/cartesian/axes":764,"../scattermapbox/hover":1186}],974:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../heatmap/colorbar"),formatLabels:t("../scattermapbox/format_labels"),calc:t("./calc"),plot:t("./plot"),hoverPoints:t("./hover"),eventData:t("./event_data"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var a=r[n],i=a.id;if("symbol"===a.type&&"string"==typeof i&&-1===i.indexOf("plotly-"))return i}},moduleType:"trace",name:"densitymapbox",basePlotModule:t("../../plots/mapbox"),categories:["mapbox","gl"],meta:{hr_name:"density_mapbox"}}},{"../../plots/mapbox":819,"../heatmap/colorbar":1001,"../scattermapbox/format_labels":1185,"./attributes":968,"./calc":969,"./defaults":971,"./event_data":972,"./hover":973,"./plot":975}],975:[function(t,e,r){"use strict";var n=t("./convert"),a=t("../../plots/mapbox/constants").traceLayerPrefix;function i(t,e){this.type="densitymapbox",this.subplot=t,this.uid=e,this.sourceId="source-"+e,this.layerList=[["heatmap",a+e+"-heatmap"]],this.below=null}var o=i.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,a=n(t),i=e.belowLookup["trace-"+this.uid];e.map.getSource(this.sourceId).setData(a.geojson),i!==this.below&&(this._removeLayers(),this._addLayers(a,i),this.below=i);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=a[l];e.setOptions(c,"setLayoutProperty",u.layout),"visible"===u.layout.visibility&&e.setOptions(c,"setPaintProperty",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,a=this.sourceId,i=0;i<n.length;i++){var o=n[i],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:a,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,a=new i(t,r.uid),o=a.sourceId,s=n(e),l=a.below=t.belowLookup["trace-"+r.uid];return t.map.addSource(o,{type:"geojson",data:s.geojson}),a._addLayers(s,l),a}},{"../../plots/mapbox/constants":817,"./convert":970}],976:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,"tx"),n.mergeArray(e.hovertext,t,"htx");var a=e.marker;if(a){n.mergeArray(a.opacity,t,"mo"),n.mergeArray(a.color,t,"mc");var i=a.line;i&&(n.mergeArray(i.color,t,"mlc"),n.mergeArrayCastPositive(i.width,t,"mlw"))}}},{"../../lib":716}],977:[function(t,e,r){"use strict";var n=t("../bar/attributes"),a=t("../scatter/attributes").line,i=t("../../plots/attributes"),o=t("../../plots/template_attributes").hovertemplateAttrs,s=t("../../plots/template_attributes").texttemplateAttrs,l=t("./constants"),c=t("../../lib/extend").extendFlat,u=t("../../components/color");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},i.hoverinfo,{flags:["name","x","y","text","percent initial","percent previous","percent total"]}),textinfo:{valType:"flaglist",flags:["label","text","percent initial","percent previous","percent total","value"],extras:["none"],editType:"plot",arrayOk:!1},texttemplate:s({editType:"plot"},{keys:l.eventDataKeys.concat(["label","value"])}),text:n.text,textposition:c({},n.textposition,{dflt:"auto"}),insidetextanchor:c({},n.insidetextanchor,{dflt:"middle"}),textangle:c({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:c({},n.orientation,{}),offset:c({},n.offset,{arrayOk:!1}),width:c({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:"color",editType:"style"},line:{color:c({},a.color,{dflt:u.defaultLine}),width:c({},a.width,{dflt:0,editType:"plot"}),dash:a.dash,editType:"style"},visible:{valType:"boolean",dflt:!0,editType:"plot"},editType:"plot"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{"../../components/color":591,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/template_attributes":840,"../bar/attributes":855,"../scatter/attributes":1118,"./constants":979}],978:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("./arrays_to_calcdata"),i=t("../scatter/calc_selection"),o=t("../../constants/numerical").BADNUM;function s(t){return t===o?0:t}e.exports=function(t,e){var r,l,c,u,h=n.getFromId(t,e.xaxis||"x"),f=n.getFromId(t,e.yaxis||"y");"h"===e.orientation?(r=h.makeCalcdata(e,"x"),l=f.makeCalcdata(e,"y")):(r=f.makeCalcdata(e,"y"),l=h.makeCalcdata(e,"x"));var p,d=Math.min(l.length,r.length),g=new Array(d);for(e._base=[],c=0;c<d;c++){r[c]<0&&(r[c]=o);var v=!1;r[c]!==o&&c+1<d&&r[c+1]!==o&&(v=!0),u=g[c]={p:l[c],s:r[c],cNext:v},e._base[c]=-.5*u.s,e.ids&&(u.id=String(e.ids[c])),0===c&&(g[0].vTotal=0),g[0].vTotal+=s(u.s),u.begR=s(u.s)/s(g[0].s)}for(c=0;c<d;c++)(u=g[c]).s!==o&&(u.sumR=u.s/g[0].vTotal,u.difR=void 0!==p?u.s/p:1,p=u.s);return a(g,e),i(g,e),g}},{"../../constants/numerical":692,"../../plots/cartesian/axes":764,"../scatter/calc_selection":1120,"./arrays_to_calcdata":976}],979:[function(t,e,r){"use strict";e.exports={eventDataKeys:["percentInitial","percentPrevious","percentTotal"]}},{}],980:[function(t,e,r){"use strict";var n=t("../bar/cross_trace_calc").setGroupPositions;e.exports=function(t,e){var r,a,i=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(a=0;a<o.length;a++){var p=o[a],d="h"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&"funnel"===p.type&&(r=s[a],d?f.push(r):h.push(r),u.push(r))}var g={mode:i.funnelmode,norm:i.funnelnorm,gap:i.funnelgap,groupgap:i.funnelgroupgap};for(n(t,l,c,h,g),n(t,c,l,f,g),a=0;a<u.length;a++){r=u[a];for(var v=0;v<r.length;v++)v+1<r.length&&(r[v].nextP0=r[v+1].p0,r[v].nextS0=r[v+1].s0,r[v].nextP1=r[v+1].p1,r[v].nextS1=r[v+1].s1)}}},{"../bar/cross_trace_calc":858}],981:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../bar/defaults").handleGroupingDefaults,i=t("../bar/defaults").handleText,o=t("../scatter/xy_defaults"),s=t("./attributes"),l=t("../../components/color");e.exports={supplyDefaults:function(t,e,r,a){function c(r,a){return n.coerce(t,e,s,r,a)}if(o(t,e,a,c)){c("orientation",e.y&&!e.x?"v":"h"),c("offset"),c("width");var u=c("text");c("hovertext"),c("hovertemplate");var h=c("textposition");i(t,e,a,c,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),"none"===e.textposition||e.texttemplate||c("textinfo",Array.isArray(u)?"text+value":"value");var f=c("marker.color",r);c("marker.line.color",l.defaultLine),c("marker.line.width"),c("connector.visible")&&(c("connector.fillcolor",function(t){var e=n.isArrayOrTypedArray(t)?"#000":t;return l.addOpacity(e,.5*l.opacity(e))}(f)),c("connector.line.width")&&(c("connector.line.color"),c("connector.line.dash")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,i;function o(t){return n.coerce(i._input,i,s,t)}if("group"===e.funnelmode)for(var l=0;l<t.length;l++)r=(i=t[l])._input,a(r,i,e,o)}}},{"../../components/color":591,"../../lib":716,"../bar/defaults":859,"../scatter/xy_defaults":1144,"./attributes":977}],982:[function(t,e,r){"use strict";e.exports=function(t,e){return t.x="xVal"in e?e.xVal:e.x,t.y="yVal"in e?e.yVal:e.y,"percentInitial"in e&&(t.percentInitial=e.percentInitial),"percentPrevious"in e&&(t.percentPrevious=e.percentPrevious),"percentTotal"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],983:[function(t,e,r){"use strict";var n=t("../../components/color").opacity,a=t("../bar/hover").hoverOnBars,i=t("../../lib").formatPercent;e.exports=function(t,e,r,o){var s=a(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u="h"===c.orientation,h=l[s.index];s[(u?"x":"y")+"LabelVal"]=h.s,s.percentInitial=h.begR,s.percentInitialLabel=i(h.begR,1),s.percentPrevious=h.difR,s.percentPreviousLabel=i(h.difR,1),s.percentTotal=h.sumR,s.percentTotalLabel=i(h.sumR,1);var f=h.hi||c.hoverinfo,p=[];if(f&&"none"!==f&&"skip"!==f){var d="all"===f,g=f.split("+"),v=function(t){return d||-1!==g.indexOf(t)};v("percent initial")&&p.push(s.percentInitialLabel+" of initial"),v("percent previous")&&p.push(s.percentPreviousLabel+" of previous"),v("percent total")&&p.push(s.percentTotalLabel+" of total")}return s.extraText=p.join("<br>"),s.color=function(t,e){var r=t.marker,a=e.mc||r.color,i=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(a))return a;if(n(i)&&o)return i}(c,h),[s]}}},{"../../components/color":591,"../../lib":716,"../bar/hover":862}],984:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults").supplyDefaults,crossTraceDefaults:t("./defaults").crossTraceDefaults,supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc"),crossTraceCalc:t("./cross_trace_calc"),plot:t("./plot"),style:t("./style").style,hoverPoints:t("./hover"),eventData:t("./event_data"),selectPoints:t("../bar/select"),moduleType:"trace",name:"funnel",basePlotModule:t("../../plots/cartesian"),categories:["bar-like","cartesian","svg","oriented","showLegend","zoomScale"],meta:{}}},{"../../plots/cartesian":775,"../bar/select":867,"./attributes":977,"./calc":978,"./cross_trace_calc":980,"./defaults":981,"./event_data":982,"./hover":983,"./layout_attributes":985,"./layout_defaults":986,"./plot":987,"./style":988}],985:[function(t,e,r){"use strict";e.exports={funnelmode:{valType:"enumerated",values:["stack","group","overlay"],dflt:"stack",editType:"calc"},funnelgap:{valType:"number",min:0,max:1,editType:"calc"},funnelgroupgap:{valType:"number",min:0,max:1,dflt:0,editType:"calc"}}},{}],986:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e,r){var i=!1;function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&"funnel"===l.type){i=!0;break}}i&&(o("funnelmode"),o("funnelgap",.2),o("funnelgroupgap"))}},{"../../lib":716,"./layout_attributes":985}],987:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../bar/plot").plot;function s(t,e,r,n){var a=[],i=[],o=n?e:r,s=n?r:e;return a[0]=o.c2p(t.s0,!0),i[0]=s.c2p(t.p0,!0),a[1]=o.c2p(t.s1,!0),i[1]=s.c2p(t.p1,!0),a[2]=o.c2p(t.nextS0,!0),i[2]=s.c2p(t.nextP0,!0),a[3]=o.c2p(t.nextS1,!0),i[3]=s.c2p(t.nextP1,!0),n?[a,i]:[i,a]}e.exports=function(t,e,r,l){var c=t._fullLayout;!function(t,e,r,o){var l=e.xaxis,c=e.yaxis;a.makeTraceGroups(o,r,"trace bars").each(function(r){var o=n.select(this),u=r[0].trace,h=a.ensureSingle(o,"g","regions");if(u.connector&&u.connector.visible){var f="h"===u.orientation,p=h.selectAll("g.region").data(a.identity);p.enter().append("g").classed("region",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g="";void 0!==h[3]&&void 0!==p[3]&&(g+=f?"M"+h[0]+","+p[1]+"L"+h[2]+","+p[2]+"H"+h[3]+"L"+h[1]+","+p[1]+"Z":"M"+h[1]+","+p[1]+"L"+h[2]+","+p[3]+"V"+p[2]+"L"+h[1]+","+p[0]+"Z"),a.ensureSingle(n.select(this),"path").attr("d",g).call(i.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),function(t,e,r,o){var l=e.xaxis,c=e.yaxis;a.makeTraceGroups(o,r,"trace bars").each(function(r){var o=n.select(this),u=r[0].trace,h=a.ensureSingle(o,"g","lines");if(u.connector&&u.connector.visible&&u.connector.line.width){var f="h"===u.orientation,p=h.selectAll("g.line").data(a.identity);p.enter().append("g").classed("line",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g="";void 0!==h[3]&&void 0!==p[3]&&(f?(g+="M"+h[0]+","+p[1]+"L"+h[2]+","+p[2],g+="M"+h[1]+","+p[1]+"L"+h[3]+","+p[2]):(g+="M"+h[1]+","+p[1]+"L"+h[2]+","+p[3],g+="M"+h[1]+","+p[0]+"L"+h[2]+","+p[2])),""===g&&(g="M0,0Z"),a.ensureSingle(n.select(this),"path").attr("d",g).call(i.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),o(t,e,r,l,{mode:c.funnelmode,norm:c.funnelmode,gap:c.funnelgap,groupgap:c.funnelgroupgap})}},{"../../components/drawing":612,"../../lib":716,"../bar/plot":866,d3:164}],988:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../components/color"),o=t("../../constants/interactions").DESELECTDIM,s=t("../bar/style").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll("g.funnellayer").selectAll("g.trace");l.style("opacity",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(".point > path").each(function(t){if(!t.isBlank){var e=l.marker;n.select(this).call(i.fill,t.mc||e.color).call(i.stroke,t.mlc||e.line.color).call(a.dashLine,e.line.dash,t.mlw||e.line.width).style("opacity",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(".regions").each(function(){n.select(this).selectAll("path").style("stroke-width",0).call(i.fill,l.connector.fillcolor)}),r.selectAll(".lines").each(function(){var t=l.connector.line;a.lineGroupStyle(n.select(this).selectAll("path"),t.width,t.color,t.dash)})})}}},{"../../components/color":591,"../../components/drawing":612,"../../constants/interactions":691,"../bar/style":869,d3:164}],989:[function(t,e,r){"use strict";var n=t("../pie/attributes"),a=t("../../plots/attributes"),i=t("../../plots/domain").attributes,o=t("../../plots/template_attributes").hovertemplateAttrs,s=t("../../plots/template_attributes").texttemplateAttrs,l=t("../../lib/extend").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:l({},n.marker.line.color,{dflt:null}),width:l({},n.marker.line.width,{dflt:1}),editType:"calc"},editType:"calc"},text:n.text,hovertext:n.hovertext,scalegroup:l({},n.scalegroup,{}),textinfo:l({},n.textinfo,{flags:["label","text","value","percent"]}),texttemplate:s({editType:"plot"},{keys:["label","color","value","text","percent"]}),hoverinfo:l({},a.hoverinfo,{flags:["label","text","value","percent","name"]}),hovertemplate:o({},{keys:["label","color","value","text","percent"]}),textposition:l({},n.textposition,{values:["inside","none"],dflt:"inside"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:l({},n.title.position,{values:["top left","top center","top right"],dflt:"top center"}),editType:"plot"},domain:i({name:"funnelarea",trace:!0,editType:"calc"}),aspectratio:{valType:"number",min:0,dflt:1,editType:"plot"},baseratio:{valType:"number",min:0,max:1,dflt:.333,editType:"plot"}}},{"../../lib/extend":707,"../../plots/attributes":761,"../../plots/domain":789,"../../plots/template_attributes":840,"../pie/attributes":1092}],990:[function(t,e,r){"use strict";var n=t("../../plots/plots");r.name="funnelarea",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{"../../plots/plots":825}],991:[function(t,e,r){"use strict";var n=t("../pie/calc");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:"funnelarea"})}}},{"../pie/calc":1094}],992:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../plots/domain").defaults,o=t("../bar/defaults").handleText;e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}var c,u=l("values"),h=n.isArrayOrTypedArray(u),f=l("labels");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l("label0"),l("dlabel")),c){e._length=c,l("marker.line.width")&&l("marker.line.color",s.paper_bgcolor),l("marker.colors"),l("scalegroup");var p,d=l("text"),g=l("texttemplate");if(g||(p=l("textinfo",Array.isArray(d)?"text+percent":"percent")),l("hovertext"),l("hovertemplate"),g||p&&"none"!==p){var v=l("textposition");o(t,e,s,l,v,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}i(e,s,l),l("title.text")&&(l("title.position"),n.coerceFont(l,"title.font",s.font)),l("aspectratio"),l("baseratio")}else e.visible=!1}},{"../../lib":716,"../../plots/domain":789,"../bar/defaults":859,"./attributes":989}],993:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"funnelarea",basePlotModule:t("./base_plot"),categories:["pie-like","funnelarea","showLegend"],attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults"),supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc").calc,crossTraceCalc:t("./calc").crossTraceCalc,plot:t("./plot"),style:t("./style"),styleOne:t("../pie/style_one"),meta:{}}},{"../pie/style_one":1103,"./attributes":989,"./base_plot":990,"./calc":991,"./defaults":992,"./layout_attributes":994,"./layout_defaults":995,"./plot":996,"./style":997}],994:[function(t,e,r){"use strict";var n=t("../pie/layout_attributes").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:"colorlist",editType:"calc"},extendfunnelareacolors:{valType:"boolean",dflt:!0,editType:"calc"}}},{"../pie/layout_attributes":1099}],995:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r("hiddenlabels"),r("funnelareacolorway",e.colorway),r("extendfunnelareacolors")}},{"../../lib":716,"./layout_attributes":994}],996:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../lib"),o=t("../../lib/svg_text_utils"),s=t("../bar/plot").toMoveInsideBar,l=t("../pie/helpers"),c=t("../pie/plot"),u=c.attachFxHandlers,h=c.determineInsideTextFont,f=c.layoutAreas,p=c.prerenderTitles,d=c.positionTitleOutside;function g(t,e){return"l"+(e[0]-t[0])+","+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;p(e,t),f(e,r._size),i.makeTraceGroups(r._funnelarealayer,e,"trace").each(function(e){var f=n.select(this),p=e[0],v=p.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,a=r.baseratio;a>.999&&(a=.999);var i,o=Math.pow(a,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var h,f,p=[];for(p.push(u()),h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var d=f.v/l;c+=d,p.push(u())}var g=1/0,v=-1/0;for(h=0;h<p.length;h++)i=p[h],g=Math.min(g,i[1]),v=Math.max(v,i[1]);for(h=0;h<p.length;h++)p[h][1]-=(v+g)/2;var m=p[p.length-1][0],y=e.r,x=(v-g)/2,b=y/m,_=y/x*n;for(e.r=_*x,h=0;h<p.length;h++)p[h][0]*=b,p[h][1]*=_;var w=[-(i=p[0])[0],i[1]],k=[i[0],i[1]],T=0;for(h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var A=p[T+=1][0],M=p[T][1];f.TL=[-A,M],f.TR=[A,M],f.BL=w,f.BR=k,f.pxmid=(S=f.TR,E=f.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=f.TL,k=f.TR}var S,E}(e),f.each(function(){var f=n.select(this).selectAll("g.slice").data(e);f.enter().append("g").classed("slice",!0),f.exit().remove(),f.each(function(r){if(r.hidden)n.select(this).selectAll("path,g").remove();else{r.pointNumber=r.i,r.curveNumber=v.index;var f=p.cx,d=p.cy,m=n.select(this),y=m.selectAll("path.surface").data([r]);y.enter().append("path").classed("surface",!0).style({"pointer-events":"all"}),m.call(u,t,e);var x="M"+(f+r.TR[0])+","+(d+r.TR[1])+g(r.TR,r.BR)+g(r.BR,r.BL)+g(r.BL,r.TL)+"Z";y.attr("d",x),c.formatSliceLabel(t,r,p);var b=l.castOption(v.textposition,r.pts),_=m.selectAll("g.slicetext").data(r.text&&"none"!==b?[0]:[]);_.enter().append("g").classed("slicetext",!0),_.exit().remove(),_.each(function(){var e=i.ensureSingle(n.select(this),"text","",function(t){t.attr("data-notex",1)});e.text(r.text).attr({class:"slicetext",transform:"","text-anchor":"middle"}).call(a.font,h(v,r,t._fullLayout.font)).call(o.convertToTspans,t);var l,c,u,p=a.bBox(e.node()),g=Math.min(r.BL[1],r.BR[1]),m=Math.max(r.TL[1],r.TR[1]);c=Math.max(r.TL[0],r.BL[0]),u=Math.min(r.TR[0],r.BR[0]),l=i.getTextTransform(s(c,u,g,m,p,{isHorizontal:!0,constrained:!0,angle:0,anchor:"middle"})),e.attr("transform","translate("+f+","+d+")"+l)})}});var m=n.select(this).selectAll("g.titletext").data(v.title.text?[0]:[]);m.enter().append("g").classed("titletext",!0),m.exit().remove(),m.each(function(){var e=i.ensureSingle(n.select(this),"text","",function(t){t.attr("data-notex",1)}),s=v.title.text;v._meta&&(s=i.templateString(s,v._meta)),e.text(s).attr({class:"titletext",transform:"","text-anchor":"middle"}).call(a.font,v.title.font).call(o.convertToTspans,t);var l=d(p,r._size);e.attr("transform","translate("+l.x+","+l.y+")"+(l.scale<1?"scale("+l.scale+")":"")+"translate("+l.tx+","+l.ty+")")})})})}},{"../../components/drawing":612,"../../lib":716,"../../lib/svg_text_utils":740,"../bar/plot":866,"../pie/helpers":1097,"../pie/plot":1101,d3:164}],997:[function(t,e,r){"use strict";var n=t("d3"),a=t("../pie/style_one");e.exports=function(t){t._fullLayout._funnelarealayer.selectAll(".trace").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll("path.surface").each(function(t){n.select(this).call(a,t,e)})})}},{"../pie/style_one":1103,d3:164}],998:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../../components/colorscale/attributes"),o=(t("../../constants/docs").FORMAT_LINK,t("../../lib/extend").extendFlat);e.exports=o({z:{valType:"data_array",editType:"calc"},x:o({},n.x,{impliedEdits:{xtype:"array"}}),x0:o({},n.x0,{impliedEdits:{xtype:"scaled"}}),dx:o({},n.dx,{impliedEdits:{xtype:"scaled"}}),y:o({},n.y,{impliedEdits:{ytype:"array"}}),y0:o({},n.y0,{impliedEdits:{ytype:"scaled"}}),dy:o({},n.dy,{impliedEdits:{ytype:"scaled"}}),text:{valType:"data_array",editType:"calc"},hovertext:{valType:"data_array",editType:"calc"},transpose:{valType:"boolean",dflt:!1,editType:"calc"},xtype:{valType:"enumerated",values:["array","scaled"],editType:"calc+clearAxisTypes"},ytype:{valType:"enumerated",values:["array","scaled"],editType:"calc+clearAxisTypes"},zsmooth:{valType:"enumerated",values:["fast","best",!1],dflt:!1,editType:"calc"},hoverongaps:{valType:"boolean",dflt:!0,editType:"none"},connectgaps:{valType:"boolean",editType:"calc"},xgap:{valType:"number",dflt:0,min:0,editType:"plot"},ygap:{valType:"number",dflt:0,min:0,editType:"plot"},zhoverformat:{valType:"string",dflt:"",editType:"none"},hovertemplate:a()},{transforms:void 0},i("",{cLetter:"z",autoColorDflt:!1}))},{"../../components/colorscale/attributes":598,"../../constants/docs":687,"../../lib/extend":707,"../../plots/template_attributes":840,"../scatter/attributes":1118}],999:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../plots/cartesian/axes"),o=t("../histogram2d/calc"),s=t("../../components/colorscale/calc"),l=t("./convert_column_xyz"),c=t("./clean_2d_array"),u=t("./interp2d"),h=t("./find_empties"),f=t("./make_bound_array");e.exports=function(t,e){var r,p,d,g,v,m,y,x,b,_=i.getFromId(t,e.xaxis||"x"),w=i.getFromId(t,e.yaxis||"y"),k=n.traceIs(e,"contour"),T=n.traceIs(e,"histogram"),A=n.traceIs(e,"gl2d"),M=k?"best":e.zsmooth;if(_._minDtick=0,w._minDtick=0,T)r=(b=o(t,e)).x,p=b.x0,d=b.dx,g=b.y,v=b.y0,m=b.dy,y=b.z;else{var S=e.z;a.isArray1D(S)?(l(e,_,w,"x","y",["z"]),r=e._x,g=e._y,S=e._z):(r=e._x=e.x?_.makeCalcdata(e,"x"):[],g=e._y=e.y?w.makeCalcdata(e,"y"):[]),p=e.x0,d=e.dx,v=e.y0,m=e.dy,y=c(S,e,_,w),(k||e.connectgaps)&&(e._emptypoints=h(y),u(y,e._emptypoints))}function E(t){M=e._input.zsmooth=e.zsmooth=!1,a.warn('cannot use zsmooth: "fast": '+t)}if("fast"===M)if("log"===_.type||"log"===w.type)E("log axis found");else if(!T){if(r.length){var L=(r[r.length-1]-r[0])/(r.length-1),C=Math.abs(L/100);for(x=0;x<r.length-1;x++)if(Math.abs(r[x+1]-r[x]-L)>C){E("x scale is not linear");break}}if(g.length&&"fast"===M){var P=(g[g.length-1]-g[0])/(g.length-1),O=Math.abs(P/100);for(x=0;x<g.length-1;x++)if(Math.abs(g[x+1]-g[x]-P)>O){E("y scale is not linear");break}}}var z=a.maxRowLength(y),I="scaled"===e.xtype?"":r,D=f(e,I,p,d,z,_),R="scaled"===e.ytype?"":g,F=f(e,R,v,m,y.length,w);A||(e._extremes[_._id]=i.findExtremes(_,D),e._extremes[w._id]=i.findExtremes(w,F));var B={x:D,y:F,z:y,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(I&&I.length===D.length-1&&(B.xCenter=I),R&&R.length===F.length-1&&(B.yCenter=R),T&&(B.xRanges=b.xRanges,B.yRanges=b.yRanges,B.pts=b.pts),k||s(t,e,{vals:y,cLetter:"z"}),k&&e.contours&&"heatmap"===e.contours.coloring){var N={type:"contour"===e.type?"heatmap":"histogram2d",xcalendar:e.xcalendar,ycalendar:e.ycalendar};B.xfill=f(N,I,p,d,z,_),B.yfill=f(N,R,v,m,y.length,w)}return[B]}},{"../../components/colorscale/calc":599,"../../lib":716,"../../plots/cartesian/axes":764,"../../registry":845,"../histogram2d/calc":1030,"./clean_2d_array":1e3,"./convert_column_xyz":1002,"./find_empties":1004,"./interp2d":1007,"./make_bound_array":1008}],1000:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../constants/numerical").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===i||r===i?i:u(t,e,r)};function g(t){if(e&&"carpet"!==e.type&&"contourcarpet"!==e.type&&t&&"category"===t.type&&e["_"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e["_"+r+"CategoryMap"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:i}}return a.identity}var v=g(r),m=g(o);o&&"category"===o.type&&(s=o._categories.length);var y=new Array(s);for(h=0;h<s;h++)for(l=r&&"category"===r.type?r._categories.length:c(t,h),y[h]=new Array(l),f=0;f<l;f++)y[h][f]=p(d(t,m(h),v(f)));return y}},{"../../constants/numerical":692,"../../lib":716,"fast-isnumeric":227}],1001:[function(t,e,r){"use strict";e.exports={min:"zmin",max:"zmax"}},{}],1002:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../constants/numerical").BADNUM;e.exports=function(t,e,r,i,o,s){var l,c,u,h,f=t._length,p=e.makeCalcdata(t,i),d=r.makeCalcdata(t,o),g=t.text,v=void 0!==g&&n.isArray1D(g),m=t.hovertext,y=void 0!==m&&n.isArray1D(m),x=n.distinctVals(p),b=x.vals,_=n.distinctVals(d),w=_.vals,k=[];for(l=0;l<s.length;l++)k[l]=n.init2dArray(w.length,b.length);for(v&&(u=n.init2dArray(w.length,b.length)),y&&(h=n.init2dArray(w.length,b.length)),l=0;l<f;l++)if(p[l]!==a&&d[l]!==a){var T=n.findBin(p[l]+x.minDiff/2,b),A=n.findBin(d[l]+_.minDiff/2,w);for(c=0;c<s.length;c++){var M=t[s[c]];k[c][A][T]=M[l]}v&&(u[A][T]=g[l]),y&&(h[A][T]=m[l])}for(t["_"+i]=b,t["_"+o]=w,c=0;c<s.length;c++)t["_"+s[c]]=k[c];v&&(t._text=u),y&&(t._hovertext=h),e&&"category"===e.type&&(t["_"+i+"CategoryMap"]=b.map(function(t){return e._categories[t]})),r&&"category"===r.type&&(t["_"+o+"CategoryMap"]=w.map(function(t){return r._categories[t]}))}},{"../../constants/numerical":692,"../../lib":716}],1003:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./xyz_defaults"),i=t("./style_defaults"),o=t("../../components/colorscale/defaults"),s=t("./attributes");e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,s,r,a)}a(t,e,c,l)?(c("text"),c("hovertext"),c("hovertemplate"),i(t,e,c,l),c("hoverongaps"),c("connectgaps",n.isArray1D(e.z)&&!1!==e.zsmooth),o(t,e,l,c,{prefix:"",cLetter:"z"})):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":716,"./attributes":998,"./style_defaults":1011,"./xyz_defaults":1012}],1004:[function(t,e,r){"use strict";var n=t("../../lib").maxRowLength;e.exports=function(t){var e,r,a,i,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],g=[0,0,0],v=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],a=0;a<v;a++)void 0===d[a]&&((s=(void 0!==d[a-1]?1:0)+(void 0!==d[a+1]?1:0)+(void 0!==e[a]?1:0)+(void 0!==p[a]?1:0))?(0===r&&s++,0===a&&s++,r===t.length-1&&s++,a===d.length-1&&s++,s<4&&(h[[r,a]]=[r,a,s]),u.push([r,a,s])):f.push([r,a]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(i=f[o])[0])-1,a=i[1]]]||g)[2]+(h[[r+1,a]]||g)[2]+(h[[r,a-1]]||g)[2]+(h[[r,a+1]]||g)[2])/20)&&(l[i]=[r,a,s],f.splice(o,1),c=!0);if(!c)throw"findEmpties iterated with no new neighbors";for(i in l)h[i]=l[i],u.push(l[i])}return u.sort(function(t,e){return e[2]-t[2]})}},{"../../lib":716}],1005:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../lib"),i=t("../../plots/cartesian/axes"),o=t("../../components/colorscale").extractOpts;e.exports=function(t,e,r,s,l,c){var u,h,f,p,d=t.cd[0],g=d.trace,v=t.xa,m=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,k=d.zmask,T=g.zhoverformat,A=y,M=x;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void a.error("Error hovering on heatmap, pointNumber must be [row,col], found:",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(A=[2*y[0]-y[1]],S=1;S<y.length;S++)A.push((y[S]+y[S-1])/2);for(A.push([2*y[y.length-1]-y[y.length-2]]),M=[2*x[0]-x[1]],S=1;S<x.length;S++)M.push((x[S]+x[S-1])/2);M.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(A.length-2,a.findBin(e,A))),p=Math.max(0,Math.min(M.length-2,a.findBin(r,M)))}var E=v.c2p(y[f]),L=v.c2p(y[f+1]),C=m.c2p(x[p]),P=m.c2p(x[p+1]);c?(L=E,u=y[f],P=C,h=x[p]):(u=_?_[f]:(y[f]+y[f+1])/2,h=w?w[p]:(x[p]+x[p+1])/2,v&&"category"===v.type&&(u=y[f]),m&&"category"===m.type&&(h=x[p]),g.zsmooth&&(E=L=v.c2p(u),C=P=m.c2p(h)));var O=b[p][f];if(k&&!k[p][f]&&(O=void 0),void 0!==O||g.hoverongaps){var z;Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?z=d.hovertext[p][f]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(z=d.text[p][f]);var I=o(g),D={type:"linear",range:[I.min,I.max],hoverformat:T,_separators:v._separators,_numFormat:v._numFormat},R=i.tickText(D,O,"hover").text;return[a.extendFlat(t,{index:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:E,x1:L,y0:C,y1:P,xLabelVal:u,yLabelVal:h,zLabelVal:O,zLabel:R,text:z})]}}},{"../../components/colorscale":603,"../../components/fx":629,"../../lib":716,"../../plots/cartesian/axes":764}],1006:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),colorbar:t("./colorbar"),style:t("./style"),hoverPoints:t("./hover"),moduleType:"trace",name:"heatmap",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","2dMap"],meta:{}}},{"../../plots/cartesian":775,"./attributes":998,"./calc":999,"./colorbar":1001,"./defaults":1003,"./hover":1005,"./plot":1009,"./style":1010}],1007:[function(t,e,r){"use strict";var n=t("../../lib"),a=[[-1,0],[1,0],[0,-1],[0,1]];function i(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,i,o,s,l,c,u,h,f,p,d,g,v,m=0;for(s=0;s<e.length;s++){for(i=(n=e[s])[0],o=n[1],d=t[i][o],p=0,f=0,l=0;l<4;l++)(u=t[i+(c=a[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?g=v=h:(g=Math.min(g,h),v=Math.max(v,h)),f++,p+=h);if(0===f)throw"iterateInterp2d order is wrong: no defined neighbors";t[i][o]=p/f,void 0===d?f<4&&(m=1):(t[i][o]=(1+r)*t[i][o]-r*d,v>g&&(m=Math.max(m,Math.abs(t[i][o]-d)/(v-g))))}return m}e.exports=function(t,e){var r,a=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&a>.01;r++)a=o(t,e,i(a));return a>.01&&n.log("interp2d didn't converge quickly",a),t}},{"../../lib":716}],1008:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib").isArrayOrTypedArray;e.exports=function(t,e,r,i,o,s){var l,c,u,h=[],f=n.traceIs(t,"contour"),p=n.traceIs(t,"histogram"),d=n.traceIs(t,"gl2d");if(a(e)&&e.length>1&&!p&&"category"!==s.type){var g=e.length;if(!(g<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=e.slice(0,o);else if(1===o)h=[e[0]-.5,e[0]+.5];else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var v=h[h.length-1],m=v-h[h.length-2];for(u=g;u<o;u++)v+=m,h.push(v)}}else{var y=t[s._id.charAt(0)+"calendar"];if(p)l=s.r2c(r,0,y);else if(a(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=("log"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=i||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},{"../../lib":716,"../../registry":845}],1009:[function(t,e,r){"use strict";var n=t("d3"),a=t("tinycolor2"),i=t("../../registry"),o=t("../../lib"),s=t("../../components/colorscale").makeColorScaleFuncFromTrace,l=t("../../constants/xmlns_namespaces");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),a=e[n],i=e[n+1],s=o.constrain(n+(t-a)/(i-a)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),a=e[n],i=(t-a)/(e[n+1]-a)||0;return i<=0?{bin0:n,bin1:n,frac:0}:i<.5?{bin0:n,bin1:n+1,frac:i}:{bin0:n+1,bin1:n,frac:1-i}}function h(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,f){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(f,r,"hm").each(function(e){var r,f,g,v,m,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,k=b.x,T=b.y,A=b.xCenter,M=b.yCenter,S=i.traceIs(_,"contour"),E=S?"best":_.zsmooth,L=w.length,C=o.maxRowLength(w),P=!1,O=!1;for(y=0;void 0===r&&y<k.length-1;)r=p.c2p(k[y]),y++;for(y=k.length-1;void 0===f&&y>0;)f=p.c2p(k[y]),y--;for(f<r&&(g=f,f=r,r=g,P=!0),y=0;void 0===v&&y<T.length-1;)v=d.c2p(T[y]),y++;for(y=T.length-1;void 0===m&&y>0;)m=d.c2p(T[y]),y--;if(m<v&&(g=v,v=m,m=g,O=!0),S&&(A=k,M=T,k=b.xfill,T=b.yfill),"fast"!==E){var z="best"===E?0:.5;r=Math.max(-z*p._length,r),f=Math.min((1+z)*p._length,f),v=Math.max(-z*d._length,v),m=Math.min((1+z)*d._length,m)}var I=Math.round(f-r),D=Math.round(m-v);if(I<=0||D<=0){x.selectAll("image").data([]).exit().remove()}else{var R,F;"fast"===E?(R=C,F=L):(R=I,F=D);var B=document.createElement("canvas");B.width=R,B.height=F;var N,j,V=B.getContext("2d"),U=s(_,{noNumericCheck:!0,returnArray:!0});"fast"===E?(N=P?function(t){return C-1-t}:o.identity,j=O?function(t){return L-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(k[t])-r),0,I)},j=function(t){return o.constrain(Math.round(d.c2p(T[t])-v),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=P?0:1,K=O?0:1,Q=0,$=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(I*D*4)}catch(t){rt=new Array(I*D*4)}if("best"===E){var at,it,ot,st=A||k,lt=M||T,ct=new Array(st.length),ut=new Array(lt.length),ht=new Array(I),ft=A?u:c,pt=M?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-v);for(y=0;y<I;y++)ht[y]=ft(y,ct);for(H=0;H<D;H++)for(it=w[(at=pt(H,ut)).bin0],ot=w[at.bin1],y=0;y<I;y++,nt+=4)h(rt,nt,W=Tt(it,ot,ht[y],at))}else for(H=0;H<L;H++)for(Y=w[H],Z=j(H),y=0;y<I;y++)W=kt(Y[y],1),h(rt,nt=4*(Z*I+N(y)),W);var dt=V.createImageData(I,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,vt=gt.length;for(H=0;H<vt;H++)gt[H]=rt[H]}V.putImageData(dt,0,0)}else{var mt=_.xgap,yt=_.ygap,xt=Math.floor(mt/2),bt=Math.floor(yt/2);for(H=0;H<L;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<C;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=kt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),V.fillStyle="rgba("+W.join(",")+")",V.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-mt,Z[1]-Z[0]-yt))}$=Math.round($/Q),tt=Math.round(tt/Q),et=Math.round(et/Q);var _t=a("rgb("+$+","+tt+","+et+")");t._hmpixcount=(t._hmpixcount||0)+Q,t._hmlumcount=(t._hmlumcount||0)+Q*_t.getLuminance();var wt=x.selectAll("image").data(e);wt.enter().append("svg:image").attr({xmlns:l.svg,preserveAspectRatio:"none"}),wt.attr({height:D,width:I,x:r,y:v,"xlink:href":B.toDataURL("image/png")})}function kt(t,e){if(void 0!==t){var r=U(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),Q+=e,$+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function Tt(t,e,r,n){var a=t[r.bin0];if(void 0===a)return kt(void 0,1);var i,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-a||0,u=s-a||0;return i=void 0===o?void 0===l?0:void 0===s?2*(l-a):2*(2*l-s-a)/3:void 0===l?void 0===s?0:2*(2*a-o-s)/3:void 0===s?2*(2*l-o-a)/3:l+a-o-s,kt(a+r.frac*c+n.frac*(u+r.frac*i))}})}},{"../../components/colorscale":603,"../../constants/xmlns_namespaces":693,"../../lib":716,"../../registry":845,d3:164,tinycolor2:535}],1010:[function(t,e,r){"use strict";var n=t("d3");e.exports=function(t){n.select(t).selectAll(".hm image").style("opacity",function(t){return t.trace.opacity})}},{d3:164}],1011:[function(t,e,r){"use strict";e.exports=function(t,e,r){!1===r("zsmooth")&&(r("xgap"),r("ygap")),r("zhoverformat")}},{}],1012:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../registry");function o(t,e){var r=e(t);return"scaled"===(r?e(t+"type","array"):"scaled")&&(e(t+"0"),e("d"+t)),r}e.exports=function(t,e,r,s,l,c){var u,h,f=r("z");if(l=l||"x",c=c||"y",void 0===f||!f.length)return 0;if(a.isArray1D(t.z)){u=r(l),h=r(c);var p=a.minRowLength(u),d=a.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,i=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!a.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(i=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&i&&o}(f))return 0;r("transpose"),e._length=null}return i.getComponentMethod("calendars","handleTraceDefaults")(t,e,[l,c],s),!0}},{"../../lib":716,"../../registry":845,"fast-isnumeric":227}],1013:[function(t,e,r){"use strict";for(var n=t("../heatmap/attributes"),a=t("../../components/colorscale/attributes"),i=t("../../lib/extend").extendFlat,o=t("../../plot_api/edit_types").overrideAll,s=["z","x","x0","dx","y","y0","dy","text","transpose","xtype","ytype"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}i(l,a("",{cLetter:"z",autoColorDflt:!1})),e.exports=o(l,"calc","nested")},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plot_api/edit_types":747,"../heatmap/attributes":998}],1014:[function(t,e,r){"use strict";var n=t("gl-heatmap2d"),a=t("../../plots/cartesian/axes"),i=t("../../lib/str2rgbarray");function o(t,e){this.scene=t,this.uid=e,this.type="heatmapgl",this.name="",this.hoverinfo="all",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,a=n%r[0],i=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[a],e.y[i],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[i,a],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,a=e.length,o=new Array(a),s=new Array(4*a),l=0;l<a;l++){var c=e[l],u=i(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c=this.scene.xaxis,u=this.scene.yaxis;t._extremes[c._id]=a.findExtremes(c,r.x),t._extremes[u._id]=a.findExtremes(u,r.y)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{"../../lib/str2rgbarray":739,"../../plots/cartesian/axes":764,"gl-heatmap2d":253}],1015:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("../heatmap/defaults"),colorbar:t("../heatmap/colorbar"),calc:t("../heatmap/calc"),plot:t("./convert"),moduleType:"trace",name:"heatmapgl",basePlotModule:t("../../plots/gl2d"),categories:["gl","gl2d","2dMap"],meta:{}}},{"../../plots/gl2d":802,"../heatmap/calc":999,"../heatmap/colorbar":1001,"../heatmap/defaults":1003,"./attributes":1013,"./convert":1014}],1016:[function(t,e,r){"use strict";var n=t("../bar/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("./bin_attributes"),o=t("./constants"),s=t("../../lib/extend").extendFlat;e.exports={x:{valType:"data_array",editType:"calc+clearAxisTypes"},y:{valType:"data_array",editType:"calc+clearAxisTypes"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:"enumerated",values:["count","sum","avg","min","max"],dflt:"count",editType:"calc"},histnorm:{valType:"enumerated",values:["","percent","probability","density","probability density"],dflt:"",editType:"calc"},cumulative:{enabled:{valType:"boolean",dflt:!1,editType:"calc"},direction:{valType:"enumerated",values:["increasing","decreasing"],dflt:"increasing",editType:"calc"},currentbin:{valType:"enumerated",values:["include","exclude","half"],dflt:"include",editType:"calc"},editType:"calc"},nbinsx:{valType:"integer",min:0,dflt:0,editType:"calc"},xbins:i("x",!0),nbinsy:{valType:"integer",min:0,dflt:0,editType:"calc"},ybins:i("y",!0),autobinx:{valType:"boolean",dflt:null,editType:"calc"},autobiny:{valType:"boolean",dflt:null,editType:"calc"},bingroup:{valType:"string",dflt:"",editType:"calc"},hovertemplate:a({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{"../../lib/extend":707,"../../plots/template_attributes":840,"../bar/attributes":855,"./bin_attributes":1018,"./constants":1022}],1017:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r=t.length,n=0,a=0;a<r;a++)e[a]?(t[a]/=e[a],n+=t[a]):t[a]=null;return n}},{}],1018:[function(t,e,r){"use strict";e.exports=function(t,e){return{start:{valType:"any",editType:"calc"},end:{valType:"any",editType:"calc"},size:{valType:"any",editType:"calc"},editType:"calc"}}},{}],1019:[function(t,e,r){"use strict";var n=t("fast-isnumeric");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,a){var i=a[e];return n(i)?(i=Number(i),r[t]+=i,i):0},avg:function(t,e,r,a,i){var o=a[e];return n(o)&&(o=Number(o),r[t]+=o,i[t]++),0},min:function(t,e,r,a){var i=a[e];if(n(i)){if(i=Number(i),!n(r[t]))return r[t]=i,i;if(r[t]>i){var o=i-r[t];return r[t]=i,o}}return 0},max:function(t,e,r,a){var i=a[e];if(n(i)){if(i=Number(i),!n(r[t]))return r[t]=i,i;if(r[t]<i){var o=i-r[t];return r[t]=i,o}}return 0}}},{"fast-isnumeric":227}],1020:[function(t,e,r){"use strict";var n=t("../../constants/numerical"),a=n.ONEAVGYEAR,i=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t("../../plots/cartesian/axes").tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var a=Math.abs(e-t),i="date"===r.type,o=f(a,i),s=0;s<10;s++){var l=f(80*o,i);if(o===l)break;if(!p(l,t,e,i,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*a?a:t>1.1*i?i:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,i,s){if(n&&t>o){var l=d(e,i,s),c=d(r,i,s),u=t===a?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,a,r).split("-");return""===n[0]&&(n.unshift(),n[0]="-"+n[0]),n}e.exports=function(t,e,r,n,i){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],g=r[1],v=Math.min(h(d+f,d+p,n,i),h(g+f,g+p,n,i)),m=Math.min(h(d+c,d+f,n,i),h(g+c,g+f,n,i));if(v>m&&m<Math.abs(g-d)/4e3?(s=v,l=!1):(s=Math.min(v,m),l=!0),"date"===n.type&&s>o){var y=s===a?1:6,x=s===a?"M12":"M1";return function(e,r){var o=n.c2d(e,a,i),s=o.indexOf("-",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,i);if(c<e){var h=u(c,x,!1,i);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,i):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{"../../constants/numerical":692,"../../plots/cartesian/axes":764}],1021:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../registry"),o=t("../../plots/cartesian/axes"),s=t("../bar/arrays_to_calcdata"),l=t("./bin_functions"),c=t("./norm_functions"),u=t("./average"),h=t("./bin_label_vals");function f(t,e,r,s,l){var c,u,h,p,d,g,v,m=s+"bins",y=t._fullLayout,x=e["_"+s+"bingroup"],b=y._histogramBinOpts[x],_="overlay"===y.barmode,w=function(t){return r.r2c(t,0,p)},k=function(t){return r.c2r(t,0,p)},T="date"===r.type?function(t){return t||0===t?a.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function A(t,e,r){e[t+"Found"]?(e[t]=T(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],a.nestedProperty(u[0],m+"."+t).set(r[t]))}if(e["_"+s+"autoBinFinished"])delete e["_"+s+"autoBinFinished"];else{u=b.traces;var M=[],S=!0,E=!1,L=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var C=b.dirs[c];d=h["_"+C+"pos0"]=r.makeCalcdata(h,C),M=a.concat(M,d),delete h["_"+s+"autoBinFinished"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h["_"+s+"autoBinFinished"]=1),i.traceIs(h,"2dMap")&&(E=!0),"histogram2dcontour"===h.type&&(L=!0))}p=u[0][s+"calendar"];var P=o.autoBin(M,r,b.nbins,E,p,b.sizeFound&&b.size),O=u[0]._autoBin={};if(g=O[b.dirs[0]]={},L&&(b.size||(P.start=k(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=k(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!i.traceIs(e,"2dMap")&&0===P._dataSpan&&"category"!==r.type&&"multicategory"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,i){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,a=e.orientation,i=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];"histogram"===l.type&&!0===l.visible&&l.orientation===a&&l.xaxis===r&&l.yaxis===n&&i.push(l)}return i}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var g=f(t,s,r,n,!0),v=g[0],m=g[2];s["_"+n+"autoBinFinished"]=1,s["_"+n+"pos0"]=g[1],m?d.push(s):p=Math.min(p,v.size)}else l=c._histogramBinOpts[s["_"+n+"bingroup"]],p=Math.min(p,l.size||s[i].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o]["_"+n+"pos0"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=a.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+"calendar"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[i]=s[i]=w,(l=c._histogramBinOpts[s["_"+n+"bingroup"]])&&a.extendFlat(l,w)}return e[i]}(t,e,r,s,m)}(v=h.cumulative||{}).enabled&&"include"!==v.currentbin&&("decreasing"===v.direction?P.start=k(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=k(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(g.size=P.size,a.nestedProperty(u[0],m+".size").set(P.size)),A("start",b,P),A("end",b,P)}d=e["_"+s+"pos0"],delete e["_"+s+"pos0"];var z=e._input[m]||{},I=a.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:a.aggNums(Math.min,null,d),N={type:"category"===r.type||"multicategory"===r.type?"linear":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),I.start=r.l2r(j),F||a.nestedProperty(e,m+".start").set(I.start)}var V=b.end,U=r.r2l(z.end),q=void 0!==U;if((b.endFound||q)&&U!==r.r2l(V)){var H=q?U:a.aggNums(Math.max,null,d);I.end=r.l2r(H),q||a.nestedProperty(e,m+".start").set(I.end)}var G="autobin"+s;return!1===e._input[G]&&(e._input[m]=a.extendFlat({},e[m]||{}),delete e._input[G],delete e[G]),[I,d]}e.exports={calc:function(t,e){var r,i,p,d,g=[],v=[],m=o.getFromId(t,"h"===e.orientation?e.yaxis:e.xaxis),y="h"===e.orientation?"y":"x",x={x:"y",y:"x"}[y],b=e[y+"calendar"],_=e.cumulative,w=f(t,e,m,y),k=w[0],T=w[1],A="string"==typeof k.size,M=[],S=A?M:k,E=[],L=[],C=[],P=0,O=e.histnorm,z=e.histfunc,I=-1!==O.indexOf("density");_.enabled&&I&&(O=O.replace(/ ?density$/,""),I=!1);var D,R="max"===z||"min"===z?null:0,F=l.count,B=c[O],N=!1,j=function(t){return m.r2c(t,0,b)};for(a.isArrayOrTypedArray(e[x])&&"count"!==z&&(D=e[x],N="avg"===z,F=l[z]),r=j(k.start),p=j(k.end)+(r-o.tickIncrement(r,k.size,!1,b))/1e6;r<p&&g.length<1e6&&(i=o.tickIncrement(r,k.size,!1,b),g.push((r+i)/2),v.push(R),C.push([]),M.push(r),I&&E.push(1/(i-r)),N&&L.push(0),!(i<=r));)r=i;M.push(r),A||"date"!==m.type||(S={start:j(S.start),end:j(S.end),size:S.size});var V,U=v.length,q=!0,H=1/0,G=1/0,Y={};for(r=0;r<T.length;r++){var W=T[r];(d=a.findBin(W,S))>=0&&d<U&&(P+=F(d,r,v,D,L),q&&C[d].length&&W!==T[C[d][0]]&&(q=!1),C[d].push(r),Y[r]=d,H=Math.min(H,W-M[d]),G=Math.min(G,M[d+1]-W))}q||(V=h(H,G,M,m,b)),N&&(P=u(v,L)),B&&B(v,P,E),_.enabled&&function(t,e,r){var n,a,i;function o(e){i=t[e],t[e]/=2}function s(e){a=t[e],t[e]=i+a/2,i+=a}if("half"===r)if("increasing"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if("increasing"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];"exclude"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];"exclude"===r&&(t.push(0),t.shift())}}(v,_.direction,_.currentbin);var X=Math.min(g.length,v.length),Z=[],J=0,K=X-1;for(r=0;r<X;r++)if(v[r]){J=r;break}for(r=X-1;r>=J;r--)if(v[r]){K=r;break}for(r=J;r<=K;r++)if(n(g[r])&&n(v[r])){var Q={p:g[r],s:v[r],b:0};_.enabled||(Q.pts=C[r],q?Q.ph0=Q.ph1=C[r].length?T[C[r][0]]:g[r]:(Q.ph0=V(M[r]),Q.ph1=V(M[r+1],!0))),Z.push(Q)}return 1===Z.length&&(Z[0].width1=o.tickIncrement(Z[0].p,k.size,!1,b)-Z[0].p),s(Z,e),a.isArrayOrTypedArray(e.selectedpoints)&&a.tagSelected(Z,e,Y),Z},calcAllAutoBins:f}},{"../../lib":716,"../../plots/cartesian/axes":764,"../../registry":845,"../bar/arrays_to_calcdata":854,"./average":1017,"./bin_functions":1019,"./bin_label_vals":1020,"./norm_functions":1028,"fast-isnumeric":227}],1022:[function(t,e,r){"use strict";e.exports={eventDataKeys:["binNumber"]}},{}],1023:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axis_ids"),i=t("../../registry").traceIs,o=t("../bar/defaults").handleGroupingDefaults,s=n.nestedProperty,l=a.getAxisGroup,c=[{aStr:{x:"xbins.start",y:"ybins.start"},name:"start"},{aStr:{x:"xbins.end",y:"ybins.end"},name:"end"},{aStr:{x:"xbins.size",y:"ybins.size"},name:"size"},{aStr:{x:"nbinsx",y:"nbinsy"},name:"nbins"}],u=["x","y"];e.exports=function(t,e){var r,h,f,p,d,g,v,m=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return"v"===t.orientation?"x":"y"}function k(t,r,i){var o=t.uid+"__"+i;r||(r=o);var s=function(t,r){return a.getFromTrace({_fullLayout:e},t,r).type}(t,i),l=t[i+"calendar"],c=m[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(i)):(r=o,s!==c.axType&&n.warn(["Attempted to group the bins of trace",t.index,"set on a","type:"+s,"axis","with bins on","type:"+c.axType,"axis."].join(" ")),l!==c.calendar&&n.warn(["Attempted to group the bins of trace",t.index,"set with a",l,"calendar","with bins",c.calendar?"on a "+c.calendar+" calendar":"w/o a set calendar"].join(" ")))),u&&(m[r]={traces:[t],dirs:[i],axType:s,calendar:t[i+"calendar"]||""}),t["_"+i+"bingroup"]=r}for(d=0;d<t.length;d++)r=t[d],i(r,"histogram")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,i(r,"2dMap")||o(r._input,r,e,_));var T=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],f="",!i(r,"2dMap")){if(p=w(r),"group"===e.barmode&&r.alignmentgroup){var A=r[p+"axis"],M=l(e,A)+r.orientation;(T[M]||{})[r.alignmentgroup]&&(f=M)}f||"overlay"===e.barmode||(f=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}f?(x[f]||(x[f]=[]),x[f].push(r)):b.push(r)}for(f in x)if(1!==(h=x[f]).length){var S=!1;for(d=0;d<h.length;d++){r=h[d],S=_("bingroup");break}for(f=S||f,d=0;d<h.length;d++){var E=(r=h[d])._input.bingroup;E&&E!==f&&n.warn(["Trace",r.index,"must match","within bingroup",f+".","Ignoring its bingroup:",E,"setting."].join(" ")),r.bingroup=f,k(r,f,w(r))}}else b.push(h[0]);for(d=0;d<b.length;d++){r=b[d];var L=_("bingroup");if(i(r,"2dMap"))for(v=0;v<2;v++){var C=_((p=u[v])+"bingroup",L?L+"__"+p:null);k(r,C,p)}else k(r,L,w(r))}for(f in m){var P=m[f];for(h=P.traces,g=0;g<c.length;g++){var O,z,I=c[g],D=I.name;if("nbins"!==D||!P.sizeFound){for(d=0;d<h.length;d++){if(r=h[d],p=P.dirs[d],O=I.aStr[p],void 0!==s(r._input,O).get()){P[D]=_(O),P[D+"Found"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,O).set(z[D])}if("start"===D||"end"===D)for(;d<h.length;d++)(r=h[d])["_"+p+"bingroup"]&&_(O,(z=(r._autoBin||{})[p]||{})[D]);"nbins"!==D||P.sizeFound||P.nbinsFound||(r=h[0],P[D]=_(O))}}}}},{"../../lib":716,"../../plots/cartesian/axis_ids":767,"../../registry":845,"../bar/defaults":859}],1024:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../components/color"),o=t("../bar/style_defaults"),s=t("./attributes");e.exports=function(t,e,r,l){function c(r,n){return a.coerce(t,e,s,r,n)}var u=c("x"),h=c("y");c("cumulative.enabled")&&(c("cumulative.direction"),c("cumulative.currentbin")),c("text"),c("hovertext"),c("hovertemplate");var f=c("orientation",h&&!u?"h":"v"),p="v"===f?"x":"y",d="v"===f?"y":"x",g=u&&h?Math.min(a.minRowLength(u)&&a.minRowLength(h)):a.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y"],l),e[d]&&c("histfunc"),c("histnorm"),c("autobin"+p),o(t,e,c,r,l),a.coerceSelectionMarkerOpacity(e,c);var v=(e.marker.line||{}).color,m=n.getComponentMethod("errorbars","supplyDefaults");m(t,e,v||i.defaultLine,{axis:"y"}),m(t,e,v||i.defaultLine,{axis:"x",inherit:"y"})}else e.visible=!1}},{"../../components/color":591,"../../lib":716,"../../registry":845,"../bar/style_defaults":870,"./attributes":1016}],1025:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){if(t.x="xVal"in e?e.xVal:e.x,t.y="yVal"in e?e.yVal:e.y,"zLabelVal"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var i,o=Array.isArray(a)?n[0].pts[a[0]][a[1]]:n[a].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){i=[];for(var s=0;s<o.length;s++)i=i.concat(r._indexToPoints[o[s]])}else i=o;t.pointIndices=i}return t}},{}],1026:[function(t,e,r){"use strict";var n=t("../bar/hover").hoverPoints,a=t("../../plots/cartesian/axes").hoverLabelText;e.exports=function(t,e,r,i){var o=n(t,e,r,i);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c="h"===l.orientation?"y":"x";t[c+"Label"]=a(t[c+"a"],s.ph0,s.ph1)}return l.hovermplate&&(t.hovertemplate=l.hovertemplate),o}}},{"../../plots/cartesian/axes":764,"../bar/hover":862}],1027:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("../bar/layout_attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("./cross_trace_defaults"),supplyLayoutDefaults:t("../bar/layout_defaults"),calc:t("./calc").calc,crossTraceCalc:t("../bar/cross_trace_calc").crossTraceCalc,plot:t("../bar/plot").plot,layerName:"barlayer",style:t("../bar/style").style,styleOnSelect:t("../bar/style").styleOnSelect,colorbar:t("../scatter/marker_colorbar"),hoverPoints:t("./hover"),selectPoints:t("../bar/select"),eventData:t("./event_data"),moduleType:"trace",name:"histogram",basePlotModule:t("../../plots/cartesian"),categories:["bar-like","cartesian","svg","bar","histogram","oriented","errorBarsOK","showLegend"],meta:{}}},{"../../plots/cartesian":775,"../bar/cross_trace_calc":858,"../bar/layout_attributes":864,"../bar/layout_defaults":865,"../bar/plot":866,"../bar/select":867,"../bar/style":869,"../scatter/marker_colorbar":1136,"./attributes":1016,"./calc":1021,"./cross_trace_defaults":1023,"./defaults":1024,"./event_data":1025,"./hover":1026}],1028:[function(t,e,r){"use strict";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,a=0;a<r;a++)t[a]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var a=t.length;n=n||1;for(var i=0;i<a;i++)t[i]*=r[i]*n},"probability density":function(t,e,r,n){var a=t.length;n&&(e/=n);for(var i=0;i<a;i++)t[i]*=r[i]/e}}},{}],1029:[function(t,e,r){"use strict";var n=t("../histogram/attributes"),a=t("../histogram/bin_attributes"),i=t("../heatmap/attributes"),o=t("../../plots/template_attributes").hovertemplateAttrs,s=t("../../components/colorscale/attributes"),l=t("../../lib/extend").extendFlat;e.exports=l({x:n.x,y:n.y,z:{valType:"data_array",editType:"calc"},marker:{color:{valType:"data_array",editType:"calc"},editType:"calc"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:a("x"),nbinsy:n.nbinsy,ybins:a("y"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:l({},n.bingroup,{}),xbingroup:l({},n.bingroup,{}),ybingroup:l({},n.bingroup,{}),xgap:i.xgap,ygap:i.ygap,zsmooth:i.zsmooth,zhoverformat:i.zhoverformat,hovertemplate:o({},{keys:"z"})},s("",{cLetter:"z",autoColorDflt:!1}))},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/template_attributes":840,"../heatmap/attributes":998,"../histogram/attributes":1016,"../histogram/bin_attributes":1018}],1030:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../histogram/bin_functions"),o=t("../histogram/norm_functions"),s=t("../histogram/average"),l=t("../histogram/bin_label_vals"),c=t("../histogram/calc").calcAllAutoBins;function u(t,e,r,n){var a,i=new Array(t);if(n)for(a=0;a<t;a++)i[a]=1/(e[a+1]-e[a]);else{var o=1/r;for(a=0;a<t;a++)i[a]=o}return i}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,a,i){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,a,i);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}e.exports=function(t,e){var r,l,p,d,g=a.getFromId(t,e.xaxis),v=a.getFromId(t,e.yaxis),m=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,m)},b=function(t){return v.r2c(t,0,y)},_=c(t,e,g,"x"),w=_[0],k=_[1],T=c(t,e,v,"y"),A=T[0],M=T[1],S=e._length;k.length>S&&k.splice(S,k.length-S),M.length>S&&M.splice(S,M.length-S);var E=[],L=[],C=[],P="string"==typeof w.size,O="string"==typeof A.size,z=[],I=[],D=P?z:w,R=O?I:A,F=0,B=[],N=[],j=e.histnorm,V=e.histfunc,U=-1!==j.indexOf("density"),q="max"===V||"min"===V?null:0,H=i.count,G=o[j],Y=!1,W=[],X=[],Z="z"in e?e.z:"marker"in e&&Array.isArray(e.marker.color)?e.marker.color:"";Z&&"count"!==V&&(Y="avg"===V,H=i[V]);var J=w.size,K=x(w.start),Q=x(w.end)+(K-a.tickIncrement(K,J,!1,m))/1e6;for(r=K;r<Q;r=a.tickIncrement(r,J,!1,m))L.push(q),z.push(r),Y&&C.push(0);z.push(r);var $,tt=L.length,et=(r-K)/tt,rt=($=K+et/2,g.c2r($,0,m)),nt=A.size,at=b(A.start),it=b(A.end)+(at-a.tickIncrement(at,nt,!1,y))/1e6;for(r=at;r<it;r=a.tickIncrement(r,nt,!1,y)){E.push(L.slice()),I.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(C.slice())}I.push(r);var st=E.length,lt=(r-at)/st,ct=function(t){return v.c2r(t,0,y)}(at+lt/2);U&&(W=u(L.length,D,et,P),X=u(E.length,R,lt,O)),P||"date"!==g.type||(D=h(x,D)),O||"date"!==v.type||(R=h(b,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,vt=1/0,mt=1/0;for(r=0;r<S;r++){var yt=k[r],xt=M[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=yt:ft[p]!==yt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),vt=Math.min(vt,xt-I[d]),mt=Math.min(mt,I[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:k,xRanges:f(z,ut&&ft,dt,gt,g,m),x0:rt,dx:et,y:M,yRanges:f(I,ht&&pt,vt,mt,v,y),y0:ct,dy:lt,z:E,pts:N}}},{"../../lib":716,"../../plots/cartesian/axes":764,"../histogram/average":1017,"../histogram/bin_functions":1019,"../histogram/bin_label_vals":1020,"../histogram/calc":1021,"../histogram/norm_functions":1028}],1031:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./sample_defaults"),i=t("../heatmap/style_defaults"),o=t("../../components/colorscale/defaults"),s=t("./attributes");e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,s,r,a)}a(t,e,c,l),!1!==e.visible&&(i(t,e,c,l),o(t,e,l,c,{prefix:"",cLetter:"z"}),c("hovertemplate"))}},{"../../components/colorscale/defaults":601,"../../lib":716,"../heatmap/style_defaults":1011,"./attributes":1029,"./sample_defaults":1034}],1032:[function(t,e,r){"use strict";var n=t("../heatmap/hover"),a=t("../../plots/cartesian/axes").hoverLabelText;e.exports=function(t,e,r,i,o,s){var l=n(t,e,r,i,o,s);if(l){var c=(t=l[0]).index,u=c[0],h=c[1],f=t.cd[0],p=f.xRanges[h],d=f.yRanges[u];return t.xLabel=a(t.xa,p[0],p[1]),t.yLabel=a(t.ya,d[0],d[1]),l}}},{"../../plots/cartesian/axes":764,"../heatmap/hover":1005}],1033:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("../histogram/cross_trace_defaults"),calc:t("../heatmap/calc"),plot:t("../heatmap/plot"),layerName:"heatmaplayer",colorbar:t("../heatmap/colorbar"),style:t("../heatmap/style"),hoverPoints:t("./hover"),eventData:t("../histogram/event_data"),moduleType:"trace",name:"histogram2d",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","2dMap","histogram"],meta:{}}},{"../../plots/cartesian":775,"../heatmap/calc":999,"../heatmap/colorbar":1001,"../heatmap/plot":1009,"../heatmap/style":1010,"../histogram/cross_trace_defaults":1023,"../histogram/event_data":1025,"./attributes":1029,"./defaults":1031,"./hover":1032}],1034:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib");e.exports=function(t,e,r,i){var o=r("x"),s=r("y"),l=a.minRowLength(o),c=a.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y"],i),(r("z")||r("marker.color"))&&r("histfunc"),r("histnorm"),r("autobinx"),r("autobiny")):e.visible=!1}},{"../../lib":716,"../../registry":845}],1035:[function(t,e,r){"use strict";var n=t("../histogram2d/attributes"),a=t("../contour/attributes"),i=t("../../components/colorscale/attributes"),o=t("../../lib/extend").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:a.autocontour,ncontours:a.ncontours,contours:a.contours,line:{color:a.line.color,width:o({},a.line.width,{dflt:.5}),dash:a.line.dash,smoothing:a.line.smoothing,editType:"plot"},zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},i("",{cLetter:"z",editTypeOverride:"calc"}))},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../contour/attributes":941,"../histogram2d/attributes":1029}],1036:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../histogram2d/sample_defaults"),i=t("../contour/contours_defaults"),o=t("../contour/style_defaults"),s=t("./attributes");e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,s,r,a)}a(t,e,c,l),!1!==e.visible&&(i(t,e,c,function(r){return n.coerce2(t,e,s,r)}),o(t,e,c,l),c("hovertemplate"))}},{"../../lib":716,"../contour/contours_defaults":948,"../contour/style_defaults":962,"../histogram2d/sample_defaults":1034,"./attributes":1035}],1037:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("../histogram/cross_trace_defaults"),calc:t("../contour/calc"),plot:t("../contour/plot").plot,layerName:"contourlayer",style:t("../contour/style"),colorbar:t("../contour/colorbar"),hoverPoints:t("../contour/hover"),moduleType:"trace",name:"histogram2dcontour",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","2dMap","contour","histogram","showLegend"],meta:{}}},{"../../plots/cartesian":775,"../contour/calc":942,"../contour/colorbar":944,"../contour/hover":954,"../contour/plot":959,"../contour/style":961,"../histogram/cross_trace_defaults":1023,"./attributes":1035,"./defaults":1036}],1038:[function(t,e,r){"use strict";for(var n=t("../../plots/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../../lib/extend").extendFlat,o=t("./constants").colormodel,s=["rgb","rgba","hsl","hsla"],l=[],c=[],u=0;u<s.length;u++)l.push("For the `"+s[u]+"` colormodel, it is ["+o[s[u]].min.join(", ")+"]."),c.push("For the `"+s[u]+"` colormodel, it is ["+o[s[u]].max.join(", ")+"].");e.exports=i({z:{valType:"data_array",editType:"calc"},colormodel:{valType:"enumerated",values:s,dflt:"rgb",editType:"calc"},zmin:{valType:"info_array",items:[{valType:"number",editType:"calc"},{valType:"number",editType:"calc"},{valType:"number",editType:"calc"},{valType:"number",editType:"calc"}],editType:"calc"},zmax:{valType:"info_array",items:[{valType:"number",editType:"calc"},{valType:"number",editType:"calc"},{valType:"number",editType:"calc"},{valType:"number",editType:"calc"}],editType:"calc"},x0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes"},y0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes"},dx:{valType:"number",dflt:1,editType:"calc"},dy:{valType:"number",dflt:1,editType:"calc"},text:{valType:"data_array",editType:"plot"},hovertext:{valType:"data_array",editType:"plot"},hoverinfo:i({},n.hoverinfo,{flags:["x","y","z","color","name","text"],dflt:"x+y+z+text+name"}),hovertemplate:a({},{keys:["z","color","colormodel"]}),transforms:void 0})},{"../../lib/extend":707,"../../plots/attributes":761,"../../plots/template_attributes":840,"./constants":1040}],1039:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./constants"),i=t("fast-isnumeric"),o=t("../../plots/cartesian/axes"),s=t("../../lib").maxRowLength;function l(t,e,r,a){return function(i){return n.constrain((i-t)*e,r,a)}}function c(t,e){return function(r){return n.constrain(r,t,e)}}e.exports=function(t,e){var r,n=o.getFromId(t,e.xaxis||"x"),u=o.getFromId(t,e.yaxis||"y"),h=n.d2c(e.x0)-e.dx/2,f=u.d2c(e.y0)-e.dy/2,p=e.z.length,d=s(e.z),g=[h,h+d*e.dx],v=[f,f+p*e.dy];if(n&&"log"===n.type)for(r=0;r<d;r++)g.push(h+r*e.dx);if(u&&"log"===u.type)for(r=0;r<p;r++)v.push(f+r*e.dy);return e._extremes[n._id]=o.findExtremes(n,g),e._extremes[u._id]=o.findExtremes(u,v),e._scaler=function(t){var e=t.colormodel,r=e.length,n=a.colormodel[e];t._sArray=[];for(var o=0;o<r;o++)n.min[o]!==t.zmin[o]||n.max[o]!==t.zmax[o]?t._sArray.push(l(t.zmin[o],(n.max[o]-n.min[o])/(t.zmax[o]-t.zmin[o]),n.min[o],n.max[o])):t._sArray.push(c(n.min[o],n.max[o]));return function(e){for(var n=e.slice(0,r),a=0;a<r;a++){var o=n[a];if(!i(o))return!1;n[a]=t._sArray[a](o)}return n}}(e),[{x0:h,y0:f,z:e.z,w:d,h:p}]}},{"../../lib":716,"../../plots/cartesian/axes":764,"./constants":1040,"fast-isnumeric":227}],1040:[function(t,e,r){"use strict";e.exports={colormodel:{rgb:{min:[0,0,0],max:[255,255,255],fmt:function(t){return t.slice(0,3)},suffix:["","",""]},rgba:{min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:["","","",""]},hsl:{min:[0,0,0],max:[360,100,100],fmt:function(t){var e=t.slice(0,3);return e[1]=e[1]+"%",e[2]=e[2]+"%",e},suffix:["\xb0","%","%"]},hsla:{min:[0,0,0,0],max:[360,100,100,1],fmt:function(t){var e=t.slice(0,4);return e[1]=e[1]+"%",e[2]=e[2]+"%",e},suffix:["\xb0","%","%",""]}}}},{}],1041:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("./constants");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}var o=r("z");if(void 0!==o&&o.length&&o[0]&&o[0].length){r("x0"),r("y0"),r("dx"),r("dy");var s=r("colormodel");r("zmin",i.colormodel[s].min),r("zmax",i.colormodel[s].max),r("text"),r("hovertext"),r("hovertemplate"),e._length=null}else e.visible=!1}},{"../../lib":716,"./attributes":1038,"./constants":1040}],1042:[function(t,e,r){"use strict";e.exports=function(t,e){return"xVal"in e&&(t.x=e.xVal),"yVal"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t.color=e.color,t.colormodel=e.trace.colormodel,t}},{}],1043:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../lib"),i=t("./constants");e.exports=function(t,e,r){var o=t.cd[0],s=o.trace,l=t.xa,c=t.ya;if(!(n.inbox(e-o.x0,e-(o.x0+o.w*s.dx),0)>0||n.inbox(r-o.y0,r-(o.y0+o.h*s.dy),0)>0)){var u=Math.floor((e-o.x0)/s.dx),h=Math.floor(Math.abs(r-o.y0)/s.dy);if(o.z[h][u]){var f,p=o.hi||s.hoverinfo;if(p){var d=p.split("+");-1!==d.indexOf("all")&&(d=["color"]),-1!==d.indexOf("color")&&(f=!0)}var g,v=s.colormodel,m=v.length,y=s._scaler(o.z[h][u]),x=i.colormodel[v].suffix,b=[];(s.hovertemplate||f)&&(b.push("["+[y[0]+x[0],y[1]+x[1],y[2]+x[2]].join(", ")),4===m&&b.push(", "+y[3]+x[3]),b.push("]"),b=b.join(""),t.extraText=v.toUpperCase()+": "+b),Array.isArray(s.hovertext)&&Array.isArray(s.hovertext[h])?g=s.hovertext[h][u]:Array.isArray(s.text)&&Array.isArray(s.text[h])&&(g=s.text[h][u]);var _=c.c2p(o.y0+(h+.5)*s.dy),w=o.x0+(u+.5)*s.dx,k=o.y0+(h+.5)*s.dy,T="["+o.z[h][u].slice(0,s.colormodel.length).join(", ")+"]";return[a.extendFlat(t,{index:[h,u],x0:l.c2p(o.x0+u*s.dx),x1:l.c2p(o.x0+(u+1)*s.dx),y0:_,y1:_,color:y,xVal:w,xLabelVal:w,yVal:k,yLabelVal:k,zLabelVal:T,text:g,hovertemplateLabels:{zLabel:T,colorLabel:b,"color[0]Label":y[0]+x[0],"color[1]Label":y[1]+x[1],"color[2]Label":y[2]+x[2],"color[3]Label":y[3]+x[3]}})]}}}},{"../../components/fx":629,"../../lib":716,"./constants":1040}],1044:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),style:t("./style"),hoverPoints:t("./hover"),eventData:t("./event_data"),moduleType:"trace",name:"image",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","2dMap","noSortingByValue"],animatable:!1,meta:{}}},{"../../plots/cartesian":775,"./attributes":1038,"./calc":1039,"./defaults":1041,"./event_data":1042,"./hover":1043,"./plot":1045,"./style":1046}],1045:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../constants/xmlns_namespaces"),o=t("./constants");e.exports=function(t,e,r,s){var l=e.xaxis,c=e.yaxis;a.makeTraceGroups(s,r,"im").each(function(t){var e,r,s,u,h,f,p=n.select(this),d=t[0],g=d.trace,v=d.z,m=d.x0,y=d.y0,x=d.w,b=d.h,_=g.dx,w=g.dy;for(f=0;void 0===e&&f<x;)e=l.c2p(m+f*_),f++;for(f=x;void 0===r&&f>0;)r=l.c2p(m+f*_),f--;for(f=0;void 0===u&&f<b;)u=c.c2p(y+f*w),f++;for(f=b;void 0===h&&f>0;)h=c.c2p(y+f*w),f--;r<e&&(s=r,r=e,e=s),h<u&&(s=u,u=h,h=s);e=Math.max(-.5*l._length,e),r=Math.min(1.5*l._length,r),u=Math.max(-.5*c._length,u),h=Math.min(1.5*c._length,h);var k=Math.round(r-e),T=Math.round(h-u);if(k<=0||T<=0){p.selectAll("image").data([]).exit().remove()}else{var A=document.createElement("canvas");A.width=k,A.height=T;var M,S=A.getContext("2d"),E=function(t){return a.constrain(Math.round(l.c2p(m+t*_)-e),0,k)},L=function(t){return a.constrain(Math.round(c.c2p(y+t*w)-u),0,T)},C=o.colormodel[g.colormodel].fmt;for(f=0;f<d.w;f++){var P=E(f),O=E(f+1);if(O!==P&&!isNaN(O)&&!isNaN(P))for(var z=0;z<d.h;z++){var I=L(z),D=L(z+1);D===I||isNaN(D)||isNaN(I)||!v[z][f]||(M=g._scaler(v[z][f]),S.fillStyle=M?g.colormodel+"("+C(M).join(",")+")":"rgba(0,0,0,0)",S.fillRect(P,I,O-P,D-I))}}var R=p.selectAll("image").data(t);R.enter().append("svg:image").attr({xmlns:i.svg,preserveAspectRatio:"none"}),R.attr({height:T,width:k,x:e,y:u,"xlink:href":A.toDataURL("image/png")})}})}},{"../../constants/xmlns_namespaces":693,"../../lib":716,"./constants":1040,d3:164}],1046:[function(t,e,r){"use strict";var n=t("d3");e.exports=function(t){n.select(t).selectAll(".im image").style("opacity",function(t){return t.trace.opacity})}},{d3:164}],1047:[function(t,e,r){"use strict";var n=t("../../lib/extend").extendFlat,a=t("../../lib/extend").extendDeep,i=t("../../plot_api/edit_types").overrideAll,o=t("../../plots/font_attributes"),s=t("../../components/color/attributes"),l=t("../../plots/domain").attributes,c=t("../../plots/cartesian/layout_attributes"),u=t("../../plot_api/plot_template").templatedArray,h=t("../../constants/delta.js"),f=(t("../../constants/docs").FORMAT_LINK,o({editType:"plot",colorEditType:"plot"})),p={color:{valType:"color",editType:"plot"},line:{color:{valType:"color",dflt:s.defaultLine,editType:"plot"},width:{valType:"number",min:0,dflt:0,editType:"plot"},editType:"calc"},thickness:{valType:"number",min:0,max:1,dflt:1,editType:"plot"},editType:"calc"},d={valType:"info_array",items:[{valType:"number",editType:"plot"},{valType:"number",editType:"plot"}],editType:"plot"},g=u("step",a({},p,{range:d}));e.exports={mode:{valType:"flaglist",editType:"calc",flags:["number","delta","gauge"],dflt:"number"},value:{valType:"number",editType:"calc",anim:!0},align:{valType:"enumerated",values:["left","center","right"],editType:"plot"},domain:l({name:"indicator",trace:!0,editType:"calc"}),title:{text:{valType:"string",editType:"plot"},align:{valType:"enumerated",values:["left","center","right"],editType:"plot"},font:n({},f,{}),editType:"plot"},number:{valueformat:{valType:"string",dflt:"",editType:"plot"},font:n({},f,{}),prefix:{valType:"string",dflt:"",editType:"plot"},suffix:{valType:"string",dflt:"",editType:"plot"},editType:"plot"},delta:{reference:{valType:"number",editType:"calc"},position:{valType:"enumerated",values:["top","bottom","left","right"],dflt:"bottom",editType:"plot"},relative:{valType:"boolean",editType:"plot",dflt:!1},valueformat:{valType:"string",editType:"plot"},increasing:{symbol:{valType:"string",dflt:h.INCREASING.SYMBOL,editType:"plot"},color:{valType:"color",dflt:h.INCREASING.COLOR,editType:"plot"},editType:"plot"},decreasing:{symbol:{valType:"string",dflt:h.DECREASING.SYMBOL,editType:"plot"},color:{valType:"color",dflt:h.DECREASING.COLOR,editType:"plot"},editType:"plot"},font:n({},f,{}),editType:"calc"},gauge:{shape:{valType:"enumerated",editType:"plot",dflt:"angular",values:["angular","bullet"]},bar:a({},p,{color:{dflt:"green"}}),bgcolor:{valType:"color",editType:"plot"},bordercolor:{valType:"color",dflt:s.defaultLine,editType:"plot"},borderwidth:{valType:"number",min:0,dflt:1,editType:"plot"},axis:i({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:"outside"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,showexponent:c.showexponent,editType:"plot"},"plot"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:"plot"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:"number",editType:"calc",dflt:!1},editType:"plot"},editType:"plot"}}},{"../../components/color/attributes":590,"../../constants/delta.js":686,"../../constants/docs":687,"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plot_api/plot_template":754,"../../plots/cartesian/layout_attributes":776,"../../plots/domain":789,"../../plots/font_attributes":790}],1048:[function(t,e,r){"use strict";var n=t("../../plots/plots");r.name="indicator",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{"../../plots/plots":825}],1049:[function(t,e,r){"use strict";e.exports={calc:function(t,e){var r=[],n=e.value;"number"!=typeof e._lastValue&&(e._lastValue=e.value);var a=e._lastValue,i=a;return e._hasDelta&&"number"==typeof e.delta.reference&&(i=e.delta.reference),r[0]={y:n,lastY:a,delta:n-i,relativeDelta:(n-i)/i},r}}},{}],1050:[function(t,e,r){"use strict";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1051:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../plots/domain").defaults,o=t("../../plot_api/plot_template"),s=t("../../plots/array_container_defaults"),l=t("./constants.js"),c=t("../../plots/cartesian/tick_value_defaults"),u=t("../../plots/cartesian/tick_mark_defaults"),h=t("../../plots/cartesian/tick_label_defaults");function f(t,e){function r(r,i){return n.coerce(t,e,a.gauge.steps,r,i)}r("color"),r("line.color"),r("line.width"),r("range"),r("thickness")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}i(e,p,d),d("mode"),e._hasNumber=-1!==e.mode.indexOf("number"),e._hasDelta=-1!==e.mode.indexOf("delta"),e._hasGauge=-1!==e.mode.indexOf("gauge");var g=d("value");e._range=[0,"number"==typeof g?1.5*g:1];var v,m,y,x,b,_,w=new Array(2);function k(t,e){return n.coerce(y,x,a.gauge,t,e)}function T(t,e){return n.coerce(b,_,a.gauge.axis,t,e)}if(e._hasNumber&&(d("number.valueformat"),d("number.font.color",p.font.color),d("number.font.family",p.font.family),d("number.font.size"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d("number.prefix"),d("number.suffix"),v=e.number.font.size),e._hasDelta&&(d("delta.font.color",p.font.color),d("delta.font.family",p.font.family),d("delta.font.size"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(v||l.defaultNumberFontSize),w[1]=!0),d("delta.reference",e.value),d("delta.relative"),d("delta.valueformat",e.delta.relative?"2%":""),d("delta.increasing.symbol"),d("delta.increasing.color"),d("delta.decreasing.symbol"),d("delta.decreasing.color"),d("delta.position"),m=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d("title.font.color",p.font.color),d("title.font.family",p.font.family),d("title.font.size",.25*(v||m||l.defaultNumberFontSize)),d("title.text"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,"gauge"),k("shape"),(e._isBullet="bullet"===e.gauge.shape)||d("title.align","center"),(e._isAngular="angular"===e.gauge.shape)||d("align","center"),k("bgcolor",p.paper_bgcolor),k("borderwidth"),k("bordercolor"),k("bar.color"),k("bar.line.color"),k("bar.line.width"),k("bar.thickness",l.valueThickness*("bullet"===e.gauge.shape?.5:1)),s(y,x,{name:"steps",handleItemDefaults:f}),k("threshold.value"),k("threshold.thickness"),k("threshold.line.width"),k("threshold.line.color"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,"axis"),T("visible"),e._range=T("range",e._range);var A={outerTicks:!0};c(b,_,T,"linear"),h(b,_,T,"linear",A),u(b,_,T,A)}else d("title.align","center"),d("align","center"),e._isAngular=e._isBullet=!1;e._length=null}}},{"../../lib":716,"../../plot_api/plot_template":754,"../../plots/array_container_defaults":760,"../../plots/cartesian/tick_label_defaults":783,"../../plots/cartesian/tick_mark_defaults":784,"../../plots/cartesian/tick_value_defaults":785,"../../plots/domain":789,"./attributes":1047,"./constants.js":1050}],1052:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"indicator",basePlotModule:t("./base_plot"),categories:["svg","noOpacity","noHover"],animatable:!0,attributes:t("./attributes"),supplyDefaults:t("./defaults").supplyDefaults,calc:t("./calc").calc,plot:t("./plot"),meta:{}}},{"./attributes":1047,"./base_plot":1048,"./calc":1049,"./defaults":1051,"./plot":1053}],1053:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=a.rad2deg,o=t("../../constants/alignment").MID_SHIFT,s=t("../../components/drawing"),l=t("./constants"),c=t("../../lib/svg_text_utils"),u=t("../../plots/cartesian/axes"),h=t("../../plots/cartesian/axis_defaults"),f=t("../../plots/cartesian/position_defaults"),p=t("../../plots/cartesian/layout_attributes"),d=t("../../components/color"),g={left:"start",center:"middle",right:"end"},v={left:0,center:.5,right:1},m=/[yzafpn\xb5mkMGTPEZY]/;function y(t){return t&&t.duration>0}function x(t){t.each(function(t){d.stroke(n.select(this),t.line.color)}).each(function(t){d.fill(n.select(this),t.color)}).style("stroke-width",function(t){return t.line.width})}function b(t,e,r){var n=t._fullLayout,i=a.extendFlat({type:"linear",ticks:"outside",range:r,showline:!0},e),o={type:"linear",_id:"x"+e._id},s={letter:"x",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return a.coerce(i,o,p,t,e)}return h(i,o,l,s,n),f(i,o,l,s),o}function _(t,e){return"translate("+t+","+e+")"}function w(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+"x"+r]}function k(t,e,r,a){var i=document.createElementNS("http://www.w3.org/2000/svg","text"),o=n.select(i);return o.text(t).attr("x",0).attr("y",0).attr("text-anchor",r).attr("data-unformatted",t).call(c.convertToTspans,a).call(s.font,e),s.bBox(o.node())}function T(t,e,r,n,i,o){var s="_cache"+e;t[s]&&t[s].key===i||(t[s]={key:i,value:r});var l=a.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,h){var f,p=t._fullLayout;y(r)&&h&&(f=h()),a.makeTraceGroups(p._indicatorlayer,e,"trace").each(function(e){var h,A,M,S,E,L=e[0].trace,C=n.select(this),P=L._hasGauge,O=L._isAngular,z=L._isBullet,I=L.domain,D={w:p._size.w*(I.x[1]-I.x[0]),h:p._size.h*(I.y[1]-I.y[0]),l:p._size.l+p._size.w*I.x[0],r:p._size.r+p._size.w*(1-I.x[1]),t:p._size.t+p._size.h*(1-I.y[1]),b:p._size.b+p._size.h*I.y[0]},R=D.l+D.w/2,F=D.t+D.h/2,B=Math.min(D.w/2,D.h),N=l.innerRadius*B,j=L.align||"center";if(A=F,P){if(O&&(h=R,A=F+B/2,M=function(t){return e=t,r=.9*N,n=Math.sqrt(e.width/2*(e.width/2)+e.height*e.height),[r/n,e,r];var e,r,n}),z){var V=l.bulletPadding,U=1-l.bulletNumberDomainSize+V;h=D.l+(U+(1-U)*v[j])*D.w,M=function(t){return w(t,(l.bulletNumberDomainSize-V)*D.w,D.h)}}}else h=D.l+v[j]*D.w,M=function(t){return w(t,D.w,D.h)};!function(t,e,r,i){var o,l,h,f=r[0].trace,p=i.numbersX,x=i.numbersY,w=f.align||"center",A=g[w],M=i.transitionOpts,S=i.onComplete,E=a.ensureSingle(e,"g","numbers"),L=[];f._hasNumber&&L.push("number");f._hasDelta&&(L.push("delta"),"left"===f.delta.position&&L.reverse());var C=E.selectAll("text").data(L);function P(e,r,n,a){if(!e.match("s")||n>=0==a>=0||r(n).slice(-1).match(m)||r(a).slice(-1).match(m))return r;var i=e.slice().replace("s","f").replace(/\d+/,function(t){return parseInt(t)-1}),o=b(t,{tickformat:i});return function(t){return Math.abs(t)<1?u.tickText(o,t).text:r(t)}}C.enter().append("text"),C.attr("text-anchor",function(){return A}).attr("class",function(t){return t}).attr("x",null).attr("y",null).attr("dx",null).attr("dy",null),C.exit().remove();var O,z=f.mode+f.align;f._hasDelta&&(O=function(){var e=b(t,{tickformat:f.delta.valueformat},f._range);e.setScale(),u.prepTicks(e);var a=function(t){return u.tickText(e,t).text},i=function(t){var e=f.delta.relative?t.relativeDelta:t.delta;return e},o=function(t,e){return 0===t||"number"!=typeof t||isNaN(t)?"-":(t>0?f.delta.increasing.symbol:f.delta.decreasing.symbol)+e(t)},h=function(t){return t.delta>=0?f.delta.increasing.color:f.delta.decreasing.color};void 0===f._deltaLastValue&&(f._deltaLastValue=i(r[0]));var p=E.select("text.delta");function g(){p.text(o(i(r[0]),a)).call(d.fill,h(r[0])).call(c.convertToTspans,t)}p.call(s.font,f.delta.font).call(d.fill,h({delta:f._deltaLastValue})),y(M)?p.transition().duration(M.duration).ease(M.easing).tween("text",function(){var t=n.select(this),e=i(r[0]),s=f._deltaLastValue,l=P(f.delta.valueformat,a,s,e),c=n.interpolateNumber(s,e);return f._deltaLastValue=e,function(e){t.text(o(c(e),l)),t.call(d.fill,h({delta:c(e)}))}}).each("end",function(){g(),S&&S()}).each("interrupt",function(){g(),S&&S()}):g();return l=k(o(i(r[0]),a),f.delta.font,A,t),p}(),z+=f.delta.position+f.delta.font.size+f.delta.font.family+f.delta.valueformat,z+=f.delta.increasing.symbol+f.delta.decreasing.symbol,h=l);f._hasNumber&&(!function(){var e=b(t,{tickformat:f.number.valueformat},f._range);e.setScale(),u.prepTicks(e);var a=function(t){return u.tickText(e,t).text},i=f.number.suffix,l=f.number.prefix,h=E.select("text.number");function p(){var e="number"==typeof r[0].y?l+a(r[0].y)+i:"-";h.text(e).call(s.font,f.number.font).call(c.convertToTspans,t)}y(M)?h.transition().duration(M.duration).ease(M.easing).each("end",function(){p(),S&&S()}).each("interrupt",function(){p(),S&&S()}).attrTween("text",function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);f._lastValue=r[0].y;var o=P(f.number.valueformat,a,r[0].lastY,r[0].y);return function(r){t.text(l+o(e(r))+i)}}):p();o=k(l+a(r[0].y)+i,f.number.font,A,t)}(),z+=f.number.font.size+f.number.font.family+f.number.valueformat+f.number.suffix+f.number.prefix,h=o);if(f._hasDelta&&f._hasNumber){var I,D,R=[(o.left+o.right)/2,(o.top+o.bottom)/2],F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=.75*f.delta.font.size;"left"===f.delta.position&&(I=T(f,"deltaPos",0,-1*(o.width*v[f.align]+l.width*(1-v[f.align])+B),z,Math.min),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:l.left+I,right:o.right,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),"right"===f.delta.position&&(I=T(f,"deltaPos",0,o.width*(1-v[f.align])+l.width*v[f.align]+B,z,Math.max),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:o.left,right:l.right+I,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),"bottom"===f.delta.position&&(I=null,D=l.height,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height,bottom:o.bottom+l.height}),"top"===f.delta.position&&(I=null,D=o.top,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height-l.height,bottom:o.bottom}),O.attr({dx:I,dy:D})}(f._hasNumber||f._hasDelta)&&E.attr("transform",function(){var t=i.numbersScaler(h);z+=t[2];var e,r=T(f,"numbersScale",1,t[0],z,Math.min);f._scaleNumbers||(r=1),e=f._isAngular?x-r*h.bottom:x-r*(h.top+h.bottom)/2,f._numbersTop=r*h.top+e;var n=h[w];"center"===w&&(n=(h.left+h.right)/2);var a=p-r*n;return _(a=T(f,"numbersTranslate",0,a,z,Math.max),e)+" scale("+r+")"})}(t,C,e,{numbersX:h,numbersY:A,numbersScaler:M,transitionOpts:r,onComplete:f}),P&&(S={range:L.gauge.axis.range,color:L.gauge.bgcolor,line:{color:L.gauge.bordercolor,width:0},thickness:1},E={range:L.gauge.axis.range,color:"rgba(0, 0, 0, 0)",line:{color:L.gauge.bordercolor,width:L.gauge.borderwidth},thickness:1});var q=C.selectAll("g.angular").data(O?e:[]);q.exit().remove();var H=C.selectAll("g.angularaxis").data(O?e:[]);H.exit().remove(),O&&function(t,e,r,a){var s,l,c,h,f=r[0].trace,p=a.size,d=a.radius,g=a.innerRadius,v=a.gaugeBg,m=a.gaugeOutline,w=[p.l+p.w/2,p.t+p.h/2+d/2],k=a.gauge,T=a.layer,A=a.transitionOpts,M=a.onComplete,S=Math.PI/2;function E(t){var e=f.gauge.axis.range[0],r=f.gauge.axis.range[1],n=(t-e)/(r-e)*Math.PI-S;return n<-S?-S:n>S?S:n}function L(t){return n.svg.arc().innerRadius((g+d)/2-t/2*(d-g)).outerRadius((g+d)/2+t/2*(d-g)).startAngle(-S)}function C(t){t.attr("d",function(t){return L(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()})}k.enter().append("g").classed("angular",!0),k.attr("transform",_(w[0],w[1])),T.enter().append("g").classed("angularaxis",!0).classed("crisp",!0),T.selectAll("g.xangularaxistick,path,text").remove(),(s=b(t,f.gauge.axis)).type="linear",s.range=f.gauge.axis.range,s._id="xangularaxis",s.setScale();var P=function(t){return(s.range[0]-t.x)/(s.range[1]-s.range[0])*Math.PI+Math.PI},O={},z=u.makeLabelFns(s,0).labelStandoff;O.xFn=function(t){var e=P(t);return Math.cos(e)*z},O.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*o)},O.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?"middle":r>0?"start":"end"},O.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var I=function(t){return _(w[0]+d*Math.cos(t),w[1]-d*Math.sin(t))};c=function(t){return I(P(t))};if(l=u.calcTicks(s),h=u.getTickSigns(s)[2],s.visible){h="inside"===s.ticks?-1:1;var D=(s.linewidth||1)/2;u.drawTicks(t,s,{vals:l,layer:T,path:"M"+h*D+",0h"+h*s.ticklen,transFn:function(t){var e=P(t);return I(e)+"rotate("+-i(e)+")"}}),u.drawLabels(t,s,{vals:l,layer:T,transFn:c,labelFns:O})}var R=[v].concat(f.gauge.steps),F=k.selectAll("g.bg-arc").data(R);F.enter().append("g").classed("bg-arc",!0).append("path"),F.select("path").call(C).call(x),F.exit().remove();var B=L(f.gauge.bar.thickness),N=k.selectAll("g.value-arc").data([f.gauge.bar]);N.enter().append("g").classed("value-arc",!0).append("path");var j=N.select("path");y(A)?(j.transition().duration(A.duration).ease(A.easing).each("end",function(){M&&M()}).each("interrupt",function(){M&&M()}).attrTween("d",(V=B,U=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(U,q);return function(e){return V.endAngle(t(e))()}})),f._lastValue=r[0].y):j.attr("d","number"==typeof r[0].y?B.endAngle(E(r[0].y)):"M0,0Z");var V,U,q;j.call(x),N.exit().remove(),R=[];var H=f.gauge.threshold.value;H&&R.push({range:[H,H],color:f.gauge.threshold.color,line:{color:f.gauge.threshold.line.color,width:f.gauge.threshold.line.width},thickness:f.gauge.threshold.thickness});var G=k.selectAll("g.threshold-arc").data(R);G.enter().append("g").classed("threshold-arc",!0).append("path"),G.select("path").call(C).call(x),G.exit().remove();var Y=k.selectAll("g.gauge-outline").data([m]);Y.enter().append("g").classed("gauge-outline",!0).append("path"),Y.select("path").call(C).call(x),Y.exit().remove()}(t,0,e,{radius:B,innerRadius:N,gauge:q,layer:H,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var G=C.selectAll("g.bullet").data(z?e:[]);G.exit().remove();var Y=C.selectAll("g.bulletaxis").data(z?e:[]);Y.exit().remove(),z&&function(t,e,r,n){var a,i,o,s,c,h=r[0].trace,f=n.gauge,p=n.layer,g=n.gaugeBg,v=n.gaugeOutline,m=n.size,_=h.domain,w=n.transitionOpts,k=n.onComplete;f.enter().append("g").classed("bullet",!0),f.attr("transform","translate("+m.l+", "+m.t+")"),p.enter().append("g").classed("bulletaxis",!0).classed("crisp",!0),p.selectAll("g.xbulletaxistick,path,text").remove();var T=m.h,A=h.gauge.bar.thickness*T,M=_.x[0],S=_.x[0]+(_.x[1]-_.x[0])*(h._hasNumber||h._hasDelta?1-l.bulletNumberDomainSize:1);(a=b(t,h.gauge.axis))._id="xbulletaxis",a.domain=[M,S],a.setScale(),i=u.calcTicks(a),o=u.makeTransFn(a),s=u.getTickSigns(a)[2],c=m.t+m.h,a.visible&&(u.drawTicks(t,a,{vals:"inside"===a.ticks?u.clipEnds(a,i):i,layer:p,path:u.makeTickPath(a,c,s),transFn:o}),u.drawLabels(t,a,{vals:i,layer:p,transFn:o,labelFns:u.makeLabelFns(a,c)}));function E(t){t.attr("width",function(t){return Math.max(0,a.c2p(t.range[1])-a.c2p(t.range[0]))}).attr("x",function(t){return a.c2p(t.range[0])}).attr("y",function(t){return.5*(1-t.thickness)*T}).attr("height",function(t){return t.thickness*T})}var L=[g].concat(h.gauge.steps),C=f.selectAll("g.bg-bullet").data(L);C.enter().append("g").classed("bg-bullet",!0).append("rect"),C.select("rect").call(E).call(x),C.exit().remove();var P=f.selectAll("g.value-bullet").data([h.gauge.bar]);P.enter().append("g").classed("value-bullet",!0).append("rect"),P.select("rect").attr("height",A).attr("y",(T-A)/2).call(x),y(w)?P.select("rect").transition().duration(w.duration).ease(w.easing).each("end",function(){k&&k()}).each("interrupt",function(){k&&k()}).attr("width",Math.max(0,a.c2p(Math.min(h.gauge.axis.range[1],r[0].y)))):P.select("rect").attr("width","number"==typeof r[0].y?Math.max(0,a.c2p(Math.min(h.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var O=r.filter(function(){return h.gauge.threshold.value}),z=f.selectAll("g.threshold-bullet").data(O);z.enter().append("g").classed("threshold-bullet",!0).append("line"),z.select("line").attr("x1",a.c2p(h.gauge.threshold.value)).attr("x2",a.c2p(h.gauge.threshold.value)).attr("y1",(1-h.gauge.threshold.thickness)/2*T).attr("y2",(1-(1-h.gauge.threshold.thickness)/2)*T).call(d.stroke,h.gauge.threshold.line.color).style("stroke-width",h.gauge.threshold.line.width),z.exit().remove();var I=f.selectAll("g.gauge-outline").data([v]);I.enter().append("g").classed("gauge-outline",!0).append("rect"),I.select("rect").call(E).call(x),I.exit().remove()}(t,0,e,{gauge:G,layer:Y,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var W=C.selectAll("text.title").data(e);W.exit().remove(),W.enter().append("text").classed("title",!0),W.attr("text-anchor",function(){return z?g.right:g[L.title.align]}).text(L.title.text).call(s.font,L.title.font).call(c.convertToTspans,t),W.attr("transform",function(){var t,e=D.l+D.w*v[L.title.align],r=l.titlePadding,n=s.bBox(W.node());if(P){if(O)if(L.gauge.axis.visible)t=s.bBox(H.node()).top-r-n.bottom;else t=D.t+D.h/2-B/2-n.bottom-r;z&&(t=A-(n.top+n.bottom)/2,e=D.l-l.bulletPadding*D.w)}else t=L._numbersTop-r-n.bottom;return _(e,t)})})}},{"../../components/color":591,"../../components/drawing":612,"../../constants/alignment":685,"../../lib":716,"../../lib/svg_text_utils":740,"../../plots/cartesian/axes":764,"../../plots/cartesian/axis_defaults":766,"../../plots/cartesian/layout_attributes":776,"../../plots/cartesian/position_defaults":779,"./constants":1050,d3:164}],1054:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../mesh3d/attributes"),o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat,l=t("../../plot_api/edit_types").overrideAll;var c=e.exports=l(s({x:{valType:"data_array"},y:{valType:"data_array"},z:{valType:"data_array"},value:{valType:"data_array"},isomin:{valType:"number"},isomax:{valType:"number"},surface:{show:{valType:"boolean",dflt:!0},count:{valType:"integer",dflt:2,min:1},fill:{valType:"number",min:0,max:1,dflt:1},pattern:{valType:"flaglist",flags:["A","B","C","D","E"],extras:["all","odd","even"],dflt:"all"}},spaceframe:{show:{valType:"boolean",dflt:!1},fill:{valType:"number",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:"boolean",dflt:!1},locations:{valType:"data_array",dflt:[]},fill:{valType:"number",min:0,max:1,dflt:1}},y:{show:{valType:"boolean",dflt:!1},locations:{valType:"data_array",dflt:[]},fill:{valType:"number",min:0,max:1,dflt:1}},z:{show:{valType:"boolean",dflt:!1},locations:{valType:"data_array",dflt:[]},fill:{valType:"number",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:"boolean",dflt:!0},fill:{valType:"number",min:0,max:1,dflt:1}},y:{show:{valType:"boolean",dflt:!0},fill:{valType:"number",min:0,max:1,dflt:1}},z:{show:{valType:"boolean",dflt:!0},fill:{valType:"number",min:0,max:1,dflt:1}}},text:{valType:"string",dflt:"",arrayOk:!0},hovertext:{valType:"string",dflt:"",arrayOk:!0},hovertemplate:a()},n("",{colorAttr:"`value`",showScaleDflt:!0,editTypeOverride:"calc"}),{opacity:i.opacity,lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:s({},o.hoverinfo)}),"calc","nested");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType="calc+clearAxisTypes",c.transforms=void 0},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plots/attributes":761,"../../plots/template_attributes":840,"../mesh3d/attributes":1059}],1055:[function(t,e,r){"use strict";var n=t("../../components/colorscale/calc");e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length);for(var r=1/0,a=-1/0,i=e.value.length,o=0;o<i;o++){var s=e.value[o];r=Math.min(r,s),a=Math.max(a,s)}e._minValues=r,e._maxValues=a,e._vMin=void 0===e.isomin||null===e.isomin?r:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?a:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:"",cLetter:"c"})}},{"../../components/colorscale/calc":599}],1056:[function(t,e,r){"use strict";var n=t("gl-mesh3d"),a=t("../../lib"),i=t("../../lib/gl_format_color").parseColorScale,o=t("../../lib/str2rgbarray"),s=t("../../components/colorscale").extractOpts,l=t("../../plots/gl3d/zip3");function c(t){return a.distinctVals(t).vals}var u=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),a=Math.max(e[r],e[r-1]);if(a>n&&n<t&&t<=a)return{id:r,distRatio:(a-t)/(a-n)}}return{id:0,distRatio:0}};function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name="",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){t._i=[],t._j=[],t._k=[];var e,r,n=t.surface.show,a=t.spaceframe.show,i=t.surface.fill,o=t.spaceframe.fill,s=!1,l=!1,h=0,f=c(t.x.slice(0,t._len)),p=c(t.y.slice(0,t._len)),d=c(t.z.slice(0,t._len)),g=f.length,v=p.length,m=d.length;function y(t,e,r){return r+m*e+m*v*t}var x,b,_,w,k,T=t._minValues,A=t._maxValues,M=t._vMin,S=t._vMax;function E(t,e,n){for(var a=w.length,i=r;i<a;i++)if(t===x[i]&&e===b[i]&&n===_[i])return i;return-1}function L(){r=e}function C(){x=[],b=[],_=[],w=[],e=0,L()}function P(t,r,n,a){return x.push(t),b.push(r),_.push(n),w.push(a),++e-1}function O(t,e,r){for(var n=[],a=0;a<t.length;a++)n[a]=t[a]*(1-r)+r*e[a];return n}function z(t){k=t}function I(t,e){return"all"===t||null===t||t.indexOf(e)>-1}function D(t,e){return null===t?e:t}function R(e,r,n){L();var a,i,o,s=[r],l=[n];if(k>=1)s=[r],l=[n];else if(k>0){var c=function(t,e){var r=t[0],n=t[1],a=t[2],i=function(t,e,r){for(var n=[],a=0;a<t.length;a++)n[a]=(t[a]+e[a]+r[a])/3;return n}(r,n,a),o=Math.sqrt(1-k),s=O(i,r,o),l=O(i,n,o),c=O(i,a,o),u=e[0],h=e[1],f=e[2];return{xyzv:[[r,n,l],[l,s,r],[n,a,c],[c,l,n],[a,r,s],[s,c,a]],abc:[[u,h,-1],[-1,-1,u],[h,f,-1],[-1,-1,h],[f,u,-1],[-1,-1,f]]}}(r,n);s=c.xyzv,l=c.abc}for(var u=0;u<s.length;u++){r=s[u],n=l[u];for(var f=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],m=r[p][3],y=n[p]>-1?n[p]:E(d,g,v);f[p]=y>-1?y:P(d,g,v,D(e,m))}a=f[0],i=f[1],o=f[2],t._i.push(a),t._j.push(i),t._k.push(o),++h}}function F(t,e,r,n){var a=t[3];a<r&&(a=r),a>n&&(a=n);for(var i=(t[3]-a)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-i)*t[s]+i*e[s];return o}function B(t,e,r){return t>=e&&t<=r}function N(t){var e=.001*(S-M);return t>=M-e&&t<=S+e}function j(e){for(var r=[],n=0;n<4;n++){var a=e[n];r.push([t.x[a],t.y[a],t.z[a],t.value[a]])}return r}var V=3;function U(t,e,r,n,a,i){i||(i=1),r=[-1,-1,-1];var o=!1,s=[B(e[0][3],n,a),B(e[1][3],n,a),B(e[2][3],n,a)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return N(e[0][3])&&N(e[1][3])&&N(e[2][3])?(R(t,e,r),!0):i<V&&U(t,e,r,M,S,++i)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach(function(i){if(s[i[0]]&&s[i[1]]&&!s[i[2]]){var u=e[i[0]],h=e[i[1]],f=e[i[2]],p=F(f,u,n,a),d=F(f,h,n,a);o=l(t,[d,p,u],[-1,-1,r[i[0]]])||o,o=l(t,[u,h,d],[r[i[0]],r[i[1]],-1])||o,c=!0}}),c?o:([[0,1,2],[1,2,0],[2,0,1]].forEach(function(i){if(s[i[0]]&&!s[i[1]]&&!s[i[2]]){var u=e[i[0]],h=e[i[1]],f=e[i[2]],p=F(h,u,n,a),d=F(f,u,n,a);o=l(t,[d,p,u],[-1,-1,r[i[0]]])||o,c=!0}}),o)}function q(t,e,r,n){var a=!1,i=j(e),o=[B(i[0][3],r,n),B(i[1][3],r,n),B(i[2][3],r,n),B(i[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return a;if(o[0]&&o[1]&&o[2]&&o[3])return l&&(a=function(t,e,r){var n=function(n,a,i){R(t,[e[n],e[a],e[i]],[r[n],r[a],r[i]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,i,e)||a),a;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&o[c[2]]&&!o[c[3]]){var u=i[c[0]],h=i[c[1]],f=i[c[2]],p=i[c[3]];if(l)a=R(t,[u,h,f],[e[c[0]],e[c[1]],e[c[2]]])||a;else{var d=F(p,u,r,n),g=F(p,h,r,n),v=F(p,f,r,n);a=R(null,[d,g,v],[-1,-1,-1])||a}s=!0}}),s?a:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=i[c[0]],h=i[c[1]],f=i[c[2]],p=i[c[3]],d=F(f,u,r,n),g=F(f,h,r,n),v=F(p,h,r,n),m=F(p,u,r,n);l?(a=R(t,[u,m,d],[e[c[0]],-1,-1])||a,a=R(t,[h,g,v],[e[c[1]],-1,-1])||a):a=function(t,e,r){var n=function(n,a,i){R(t,[e[n],e[a],e[i]],[r[n],r[a],r[i]])};n(0,1,2),n(2,3,0)}(null,[d,g,v,m],[-1,-1,-1,-1])||a,s=!0}}),s?a:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach(function(c){if(o[c[0]]&&!o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=i[c[0]],h=i[c[1]],f=i[c[2]],p=i[c[3]],d=F(h,u,r,n),g=F(f,u,r,n),v=F(p,u,r,n);l?(a=R(t,[u,d,g],[e[c[0]],-1,-1])||a,a=R(t,[u,g,v],[e[c[0]],-1,-1])||a,a=R(t,[u,v,d],[e[c[0]],-1,-1])||a):a=R(null,[d,g,v],[-1,-1,-1])||a,s=!0}}),a))}function H(t,e,r,n,a,i,o,c,u,h,f){var p=!1;return s&&(I(t,"A")&&(p=q(null,[e,r,n,i],h,f)||p),I(t,"B")&&(p=q(null,[r,n,a,u],h,f)||p),I(t,"C")&&(p=q(null,[r,i,o,u],h,f)||p),I(t,"D")&&(p=q(null,[n,i,c,u],h,f)||p),I(t,"E")&&(p=q(null,[r,n,i,u],h,f)||p)),l&&(p=q(t,[r,n,i,u],h,f)||p),p}function G(t,e,r,n,a,i,o,s){return[!0===s[0]||U(t,j([e,r,n]),[e,r,n],i,o),!0===s[1]||U(t,j([n,a,e]),[n,a,e],i,o)]}function Y(t,e,r,n,a,i,o,s,l){return s?G(t,e,r,a,n,i,o,l):G(t,r,a,n,e,i,o,l)}function W(t,e,r,n,a,i,o){var s,l,c,u,h=!1,f=function(){h=U(t,[s,l,c],[-1,-1,-1],a,i)||h,h=U(t,[c,u,s],[-1,-1,-1],a,i)||h},p=o[0],d=o[1],g=o[2];return p&&(s=O(j([y(e,r-0,n-0)])[0],j([y(e-1,r-0,n-0)])[0],p),l=O(j([y(e,r-0,n-1)])[0],j([y(e-1,r-0,n-1)])[0],p),c=O(j([y(e,r-1,n-1)])[0],j([y(e-1,r-1,n-1)])[0],p),u=O(j([y(e,r-1,n-0)])[0],j([y(e-1,r-1,n-0)])[0],p),f()),d&&(s=O(j([y(e-0,r,n-0)])[0],j([y(e-0,r-1,n-0)])[0],d),l=O(j([y(e-0,r,n-1)])[0],j([y(e-0,r-1,n-1)])[0],d),c=O(j([y(e-1,r,n-1)])[0],j([y(e-1,r-1,n-1)])[0],d),u=O(j([y(e-1,r,n-0)])[0],j([y(e-1,r-1,n-0)])[0],d),f()),g&&(s=O(j([y(e-0,r-0,n)])[0],j([y(e-0,r-0,n-1)])[0],g),l=O(j([y(e-0,r-1,n)])[0],j([y(e-0,r-1,n-1)])[0],g),c=O(j([y(e-1,r-1,n)])[0],j([y(e-1,r-1,n-1)])[0],g),u=O(j([y(e-1,r-0,n)])[0],j([y(e-1,r-0,n-1)])[0],g),f()),h}function X(t,e,r,n,a,i,o,l,c,u,h,f){var p=t;return f?(s&&"even"===t&&(p=null),H(p,e,r,n,a,i,o,l,c,u,h)):(s&&"odd"===t&&(p=null),H(p,c,l,o,i,a,n,r,e,u,h))}function Z(t,e,r,n,a){for(var i=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<m;c++)for(var u=1;u<v;u++)i.push(Y(t,y(l,u-1,c-1),y(l,u-1,c),y(l,u,c-1),y(l,u,c),r,n,(l+u+c)%2,a&&a[o]?a[o]:[])),o++;return i}function J(t,e,r,n,a){for(var i=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<g;c++)for(var u=1;u<m;u++)i.push(Y(t,y(c-1,l,u-1),y(c,l,u-1),y(c-1,l,u),y(c,l,u),r,n,(c+l+u)%2,a&&a[o]?a[o]:[])),o++;return i}function K(t,e,r,n,a){for(var i=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<v;c++)for(var u=1;u<g;u++)i.push(Y(t,y(u-1,c-1,l),y(u-1,c,l),y(u,c-1,l),y(u,c,l),r,n,(u+c+l)%2,a&&a[o]?a[o]:[])),o++;return i}function Q(t,e,r){for(var n=1;n<m;n++)for(var a=1;a<v;a++)for(var i=1;i<g;i++)X(t,y(i-1,a-1,n-1),y(i-1,a-1,n),y(i-1,a,n-1),y(i-1,a,n),y(i,a-1,n-1),y(i,a-1,n),y(i,a,n-1),y(i,a,n),e,r,(i+a+n)%2)}function $(t,e,r){s=!0,Q(t,e,r),s=!1}function tt(t,e,r,n,a,i){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<m;u++)for(var h=1;h<v;h++)o.push(W(t,c,h,u,r,n,a[l],i&&i[s]&&i[s])),s++;return o}function et(t,e,r,n,a,i){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<g;u++)for(var h=1;h<m;h++)o.push(W(t,u,c,h,r,n,a[l],i&&i[s]&&i[s])),s++;return o}function rt(t,e,r,n,a,i){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<v;u++)for(var h=1;h<g;h++)o.push(W(t,h,u,c,r,n,a[l],i&&i[s]&&i[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(C(),function(){for(var e=0;e<g;e++)for(var r=0;r<v;r++)for(var n=0;n<m;n++){var a=y(e,r,n);P(t.x[a],t.y[a],t.z[a],t.value[a])}}(),a&&o&&(z(o),l=!0,Q(null,M,S),l=!1),n&&i){z(i);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var c=1===r?.5:s/(r-1),k=(1-c)*M+c*S,E=Math.abs(k-T)>Math.abs(k-A)?[T,k]:[k,A];$(e,E[0],E[1])}}var L=[[Math.min(M,A),Math.max(M,A)],[Math.min(T,S),Math.max(T,S)]];["x","y","z"].forEach(function(e){for(var r=[],n=0;n<L.length;n++){var a=0,i=L[n][0],o=L[n][1],s=t.slices[e];if(s.show&&s.fill){z(s.fill);var l=[],c=[],h=[];if(s.locations.length)for(var y=0;y<s.locations.length;y++){var x=u(s.locations[y],"x"===e?f:"y"===e?p:d);0===x.distRatio?l.push(x.id):x.id>0&&(c.push(x.id),"x"===e?h.push([x.distRatio,0,0]):"y"===e?h.push([0,x.distRatio,0]):h.push([0,0,x.distRatio]))}else l=nt(1,"x"===e?g-1:"y"===e?v-1:m-1);c.length>0&&(r[a]="x"===e?tt(null,c,i,o,h,r[a]):"y"===e?et(null,c,i,o,h,r[a]):rt(null,c,i,o,h,r[a]),a++),l.length>0&&(r[a]="x"===e?Z(null,l,i,o,r[a]):"y"===e?J(null,l,i,o,r[a]):K(null,l,i,o,r[a]),a++)}var b=t.caps[e];b.show&&b.fill&&(z(b.fill),r[a]="x"===e?Z(null,[0,g-1],i,o,r[a]):"y"===e?J(null,[0,v-1],i,o,r[a]):K(null,[0,m-1],i,o,r[a]),a++)}}),0===h&&C(),t._x=x,t._y=b,t._z=_,t._intensity=w,t._Xs=f,t._Ys=p,t._Zs=d}(),t}f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],a=this.data._z[e],i=this.data._Ys.length,o=this.data._Zs.length,s=u(r,this.data._Xs).id,l=u(n,this.data._Ys).id,c=u(a,this.data._Zs).id,h=t.index=c+o*l+o*i*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=p(t);var a={positions:l(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:l(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:o(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=s(t);a.vertexIntensity=t._intensity,a.vertexIntensityBounds=[c.min,c.max],a.colormap=i(t),this.mesh.update(a)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports={findNearestOnAxis:u,generateIsoMeshes:p,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new h(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}}},{"../../components/colorscale":603,"../../lib":716,"../../lib/gl_format_color":713,"../../lib/str2rgbarray":739,"../../plots/gl3d/zip3":815,"gl-mesh3d":282}],1057:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=t("./attributes"),o=t("../../components/colorscale/defaults");function s(t,e,r,n,i){var s=i("isomin"),l=i("isomax");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=i("x"),u=i("y"),h=i("z"),f=i("value");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(a.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y","z"],n),["x","y","z"].forEach(function(t){var e="caps."+t;i(e+".show")&&i(e+".fill");var r="slices."+t;i(r+".show")&&(i(r+".fill"),i(r+".locations"))}),i("spaceframe.show")&&i("spaceframe.fill"),i("surface.show")&&(i("surface.count"),i("surface.fill"),i("surface.pattern")),i("contour.show")&&(i("contour.color"),i("contour.width")),["text","hovertext","hovertemplate","lighting.ambient","lighting.diffuse","lighting.specular","lighting.roughness","lighting.fresnel","lighting.vertexnormalsepsilon","lighting.facenormalsepsilon","lightposition.x","lightposition.y","lightposition.z","flatshading","opacity"].forEach(function(t){i(t)}),o(t,e,n,i,{prefix:"",cLetter:"c"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,a){s(t,e,0,a,function(r,a){return n.coerce(t,e,i,r,a)})},supplyIsoDefaults:s}},{"../../components/colorscale/defaults":601,"../../lib":716,"../../registry":845,"./attributes":1054}],1058:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults").supplyDefaults,calc:t("./calc"),colorbar:{min:"cmin",max:"cmax"},plot:t("./convert").createIsosurfaceTrace,moduleType:"trace",name:"isosurface",basePlotModule:t("../../plots/gl3d"),categories:["gl3d"],meta:{}}},{"../../plots/gl3d":804,"./attributes":1054,"./calc":1055,"./convert":1056,"./defaults":1057}],1059:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../surface/attributes"),o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat;e.exports=s({x:{valType:"data_array",editType:"calc+clearAxisTypes"},y:{valType:"data_array",editType:"calc+clearAxisTypes"},z:{valType:"data_array",editType:"calc+clearAxisTypes"},i:{valType:"data_array",editType:"calc"},j:{valType:"data_array",editType:"calc"},k:{valType:"data_array",editType:"calc"},text:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},hovertext:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},hovertemplate:a({editType:"calc"}),delaunayaxis:{valType:"enumerated",values:["x","y","z"],dflt:"z",editType:"calc"},alphahull:{valType:"number",dflt:-1,editType:"calc"},intensity:{valType:"data_array",editType:"calc"},color:{valType:"color",editType:"calc"},vertexcolor:{valType:"data_array",editType:"calc"},facecolor:{valType:"data_array",editType:"calc"},transforms:void 0},n("",{colorAttr:"`intensity`",showScaleDflt:!0,editTypeOverride:"calc"}),{opacity:i.opacity,flatshading:{valType:"boolean",dflt:!1,editType:"calc"},contour:{show:s({},i.contours.x.show,{}),color:i.contours.x.color,width:i.contours.x.width,editType:"calc"},lightposition:{x:s({},i.lightposition.x,{dflt:1e5}),y:s({},i.lightposition.y,{dflt:1e5}),z:s({},i.lightposition.z,{dflt:0}),editType:"calc"},lighting:s({vertexnormalsepsilon:{valType:"number",min:0,max:1,dflt:1e-12,editType:"calc"},facenormalsepsilon:{valType:"number",min:0,max:1,dflt:1e-6,editType:"calc"},editType:"calc"},i.lighting),hoverinfo:s({},o.hoverinfo,{editType:"calc"})})},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/template_attributes":840,"../surface/attributes":1240}],1060:[function(t,e,r){"use strict";var n=t("../../components/colorscale/calc");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:"",cLetter:"c"})}},{"../../components/colorscale/calc":599}],1061:[function(t,e,r){"use strict";var n=t("gl-mesh3d"),a=t("delaunay-triangulate"),i=t("alpha-shape"),o=t("convex-hull"),s=t("../../lib/gl_format_color").parseColorScale,l=t("../../lib/str2rgbarray"),c=t("../../components/colorscale").extractOpts,u=t("../../plots/gl3d/zip3");function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name="",this.color="#fff",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var a=[],i=e.length,o=0;o<i;o++)a[o]=t.d2l(e[o],0,n)*r;return a}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function v(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,h=t.x.length,f=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!v(t.i,h)||!v(t.j,h)||!v(t.k,h))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?i(t.alphahull,f):function(t,e){for(var r=["x","y","z"].indexOf(t),n=[],i=e.length,o=0;o<i;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return a(n)}(t.delaunayaxis,f);var m={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color="#fff",m.vertexIntensity=t.intensity,m.vertexIntensityBounds=[y.min,y.max],m.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],m.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],m.cellColors=p(t.facecolor)):(this.color=t.color,m.meshColor=l(t.color));this.mesh.update(m)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new h(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}},{"../../components/colorscale":603,"../../lib/gl_format_color":713,"../../lib/str2rgbarray":739,"../../plots/gl3d/zip3":815,"alpha-shape":66,"convex-hull":131,"delaunay-triangulate":166,"gl-mesh3d":282}],1062:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../components/colorscale/defaults"),o=t("./attributes");e.exports=function(t,e,r,s){function l(r,n){return a.coerce(t,e,o,r,n)}function c(t){var e=t.map(function(t){var e=l(t);return e&&a.isArrayOrTypedArray(e)?e:null});return e.every(function(t){return t&&t.length===e[0].length})&&e}c(["x","y","z"])?(c(["i","j","k"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y","z"],s),["lighting.ambient","lighting.diffuse","lighting.specular","lighting.roughness","lighting.fresnel","lighting.vertexnormalsepsilon","lighting.facenormalsepsilon","lightposition.x","lightposition.y","lightposition.z","flatshading","alphahull","delaunayaxis","opacity"].forEach(function(t){l(t)}),l("contour.show")&&(l("contour.color"),l("contour.width")),"intensity"in t?(l("intensity"),i(t,e,s,l,{prefix:"",cLetter:"c"})):(e.showscale=!1,"facecolor"in t?l("facecolor"):"vertexcolor"in t?l("vertexcolor"):l("color",r)),l("text"),l("hovertext"),l("hovertemplate"),e._length=null):e.visible=!1):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":716,"../../registry":845,"./attributes":1059}],1063:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),colorbar:{min:"cmin",max:"cmax"},plot:t("./convert"),moduleType:"trace",name:"mesh3d",basePlotModule:t("../../plots/gl3d"),categories:["gl3d"],meta:{}}},{"../../plots/gl3d":804,"./attributes":1059,"./calc":1060,"./convert":1061,"./defaults":1062}],1064:[function(t,e,r){"use strict";var n=t("../../lib").extendFlat,a=t("../scatter/attributes"),i=t("../../components/drawing/attributes").dash,o=t("../../components/fx/attributes"),s=t("../../constants/delta.js"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=a.line;function h(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:i,editType:"style"},editType:"style"}}e.exports={x:{valType:"data_array",editType:"calc+clearAxisTypes"},open:{valType:"data_array",editType:"calc"},high:{valType:"data_array",editType:"calc"},low:{valType:"data_array",editType:"calc"},close:{valType:"data_array",editType:"calc"},line:{width:n({},u.width,{}),dash:n({},i,{}),editType:"style"},increasing:h(l),decreasing:h(c),text:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},hovertext:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},tickwidth:{valType:"number",min:0,max:.5,dflt:.3,editType:"calc"},hoverlabel:n({},o.hoverlabel,{split:{valType:"boolean",dflt:!1,editType:"style"}})}},{"../../components/drawing/attributes":611,"../../components/fx/attributes":621,"../../constants/delta.js":686,"../../lib":716,"../scatter/attributes":1118}],1065:[function(t,e,r){"use strict";var n=t("../../lib"),a=n._,i=t("../../plots/cartesian/axes"),o=t("../../constants/numerical").BADNUM;function s(t,e,r,n){return{o:t,h:e,l:r,c:n}}function l(t,e,r,s,l){for(var c=s.makeCalcdata(e,"open"),u=s.makeCalcdata(e,"high"),h=s.makeCalcdata(e,"low"),f=s.makeCalcdata(e,"close"),p=Array.isArray(e.text),d=Array.isArray(e.hovertext),g=!0,v=null,m=[],y=0;y<r.length;y++){var x=r[y],b=c[y],_=u[y],w=h[y],k=f[y];if(x!==o&&b!==o&&_!==o&&w!==o&&k!==o){k===b?null!==v&&k!==v&&(g=k>v):g=k>b,v=k;var T=l(b,_,w,k);T.pos=x,T.yc=(b+k)/2,T.i=y,T.dir=g?"increasing":"decreasing",T.x=T.pos,T.y=[w,_],p&&(T.tx=e.text[y]),d&&(T.htx=e.hovertext[y]),m.push(T)}else m.push({pos:x,empty:!0})}return e._extremes[s._id]=i.findExtremes(s,n.concat(h,u),{padded:!0}),m.length&&(m[0].t={labels:{open:a(t,"open:")+" ",high:a(t,"high:")+" ",low:a(t,"low:")+" ",close:a(t,"close:")+" "}}),m}e.exports={calc:function(t,e){var r=i.getFromId(t,e.xaxis),a=i.getFromId(t,e.yaxis),o=function(t,e,r){var a=r._minDiff;if(!a){var i,o=t._fullData,s=[];for(a=1/0,i=0;i<o.length;i++){var l=o[i];if("ohlc"===l.type&&!0===l.visible&&l.xaxis===e._id){s.push(l);var c=e.makeCalcdata(l,"x");l._xcalc=c;var u=n.distinctVals(c).minDiff;u&&isFinite(u)&&(a=Math.min(a,u))}}for(a===1/0&&(a=1),i=0;i<s.length;i++)s[i]._minDiff=a}return a*r.tickwidth}(t,r,e),c=e._minDiff;e._minDiff=null;var u=e._xcalc;e._xcalc=null;var h=l(t,e,u,a,s);return e._extremes[r._id]=i.findExtremes(r,u,{vpad:c/2}),h.length?(n.extendFlat(h[0].t,{wHover:c/2,tickLen:o}),h):[{t:{empty:!0}}]},calcCommon:l}},{"../../constants/numerical":692,"../../lib":716,"../../plots/cartesian/axes":764}],1066:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./ohlc_defaults"),i=t("./attributes");function o(t,e,r,n){r(n+".line.color"),r(n+".line.width",e.line.width),r(n+".line.dash",e.line.dash)}e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}a(t,e,l,s)?(l("line.width"),l("line.dash"),o(t,e,l,"increasing"),o(t,e,l,"decreasing"),l("text"),l("hovertext"),l("tickwidth"),s._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{"../../lib":716,"./attributes":1064,"./ohlc_defaults":1069}],1067:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib"),i=t("../../components/fx"),o=t("../../components/color"),s=t("../../lib").fillText,l=t("../../constants/delta.js"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var a,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p="ohlc"===f?"l":"min",d="ohlc"===f?"h":"max",g=h.bPos||0,v=function(t){return t.pos+g-e},m=h.bdPos||h.tickLen,y=h.wHover,x=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function b(t){var e=v(t);return i.inbox(e-y,e+y,a)}function _(t){var e=t[p],n=t[d];return e===n||i.inbox(e-r,n-r,a)}function w(t){return(b(t)+_(t))/2}a=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var k=i.getDistanceFunction(n,b,_,w);if(i.getClosest(l,k,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var A=u[T.dir],M=A.line.color;return o.opacity(M)&&A.line.width?t.color=M:t.color=A.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=T.pos,t.spikeDistance=w(T)*s/a,t.xSpike=c.c2p(T.pos,!0),t}function h(t,e,r,i){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,i);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split("+");if(!("all"===p||-1!==d.indexOf("y")))return[];for(var g=["high","open","close","low"],v={},m=0;m<g.length;m++){var y,x=g[m],b=l[x][f.index],_=s.c2p(b,!0);b in v?(y=v[b]).yLabel+="<br>"+c.labels[x]+n.hoverLabelText(s,b):((y=a.extendFlat({},f)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name="",h.push(y),v[b]=y)}return h}function f(t,e,r,a){var i=t.cd,o=t.ya,l=i[0].trace,h=i[0].t,f=u(t,e,r,a);if(!f)return[];var p=i[f.index],d=f.index=p.i,g=p.dir;function v(t){return h.labels[t]+n.hoverLabelText(o,l[t][d])}var m=p.hi||l.hoverinfo,y=m.split("+"),x="all"===m,b=x||-1!==y.indexOf("y"),_=x||-1!==y.indexOf("text"),w=b?[v("open"),v("high"),v("low"),v("close")+"  "+c[g]]:[];return _&&s(p,l,w),f.extraText=w.join("<br>"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},{"../../components/color":591,"../../components/fx":629,"../../constants/delta.js":686,"../../lib":716,"../../plots/cartesian/axes":764}],1068:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"ohlc",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","showLegend"],meta:{},attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc").calc,plot:t("./plot"),style:t("./style"),hoverPoints:t("./hover").hoverPoints,selectPoints:t("./select")}},{"../../plots/cartesian":775,"./attributes":1064,"./calc":1065,"./defaults":1066,"./hover":1067,"./plot":1070,"./select":1071,"./style":1072}],1069:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib");e.exports=function(t,e,r,i){var o=r("x"),s=r("open"),l=r("high"),c=r("low"),u=r("close");if(r("hoverlabel.split"),n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x"],i),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,a.minRowLength(o))),e._length=h,h}}},{"../../lib":716,"../../registry":845}],1070:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib");e.exports=function(t,e,r,i){var o=e.xaxis,s=e.yaxis;a.makeTraceGroups(i,r,"trace ohlc").each(function(t){var e=n.select(this),r=t[0],i=r.t;if(!0!==r.trace.visible||i.empty)e.remove();else{var l=i.tickLen,c=e.selectAll("path").data(a.identity);c.enter().append("path"),c.exit().remove(),c.attr("d",function(t){if(t.empty)return"M0,0Z";var e=o.c2p(t.pos,!0),r=o.c2p(t.pos-l,!0),n=o.c2p(t.pos+l,!0);return"M"+r+","+s.c2p(t.o,!0)+"H"+e+"M"+e+","+s.c2p(t.h,!0)+"V"+s.c2p(t.l,!0)+"M"+n+","+s.c2p(t.c,!0)+"H"+e})}})}},{"../../lib":716,d3:164}],1071:[function(t,e,r){"use strict";e.exports=function(t,e){var r,n=t.cd,a=t.xaxis,i=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([a.c2p(l.pos+s),i.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:a.c2d(l.pos),y:i.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1072:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../components/color");e.exports=function(t,e,r){var o=r||n.select(t).selectAll("g.ohlclayer").selectAll("g.trace");o.style("opacity",function(t){return t[0].trace.opacity}),o.each(function(t){var e=t[0].trace;n.select(this).selectAll("path").each(function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style("fill","none").call(i.stroke,r.color).call(a.dashLine,r.dash,r.width).style("opacity",e.selectedpoints&&!t.selected?.3:1)}})})}},{"../../components/color":591,"../../components/drawing":612,d3:164}],1073:[function(t,e,r){"use strict";var n=t("../../lib/extend").extendFlat,a=t("../../plots/attributes"),i=t("../../plots/font_attributes"),o=t("../../components/colorscale/attributes"),s=t("../../plots/template_attributes").hovertemplateAttrs,l=t("../../plots/domain").attributes,c=n({editType:"calc"},o("line",{editTypeOverride:"calc"}),{shape:{valType:"enumerated",values:["linear","hspline"],dflt:"linear",editType:"plot"},hovertemplate:s({editType:"plot",arrayOk:!1},{keys:["count","probability"]})});e.exports={domain:l({name:"parcats",trace:!0,editType:"calc"}),hoverinfo:n({},a.hoverinfo,{flags:["count","probability"],editType:"plot",arrayOk:!1}),hoveron:{valType:"enumerated",values:["category","color","dimension"],dflt:"category",editType:"plot"},hovertemplate:s({editType:"plot",arrayOk:!1},{keys:["count","probability","category","categorycount","colorcount","bandcolorcount"]}),arrangement:{valType:"enumerated",values:["perpendicular","freeform","fixed"],dflt:"perpendicular",editType:"plot"},bundlecolors:{valType:"boolean",dflt:!0,editType:"plot"},sortpaths:{valType:"enumerated",values:["forward","backward"],dflt:"forward",editType:"plot"},labelfont:i({editType:"calc"}),tickfont:i({editType:"calc"}),dimensions:{_isLinkedToArray:"dimension",label:{valType:"string",editType:"calc"},categoryorder:{valType:"enumerated",values:["trace","category ascending","category descending","array"],dflt:"trace",editType:"calc"},categoryarray:{valType:"data_array",editType:"calc"},ticktext:{valType:"data_array",editType:"calc"},values:{valType:"data_array",dflt:[],editType:"calc"},displayindex:{valType:"integer",editType:"calc"},editType:"calc",visible:{valType:"boolean",dflt:!0,editType:"calc"}},line:c,counts:{valType:"number",min:0,dflt:1,arrayOk:!0,editType:"calc"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/domain":789,"../../plots/font_attributes":790,"../../plots/template_attributes":840}],1074:[function(t,e,r){"use strict";var n=t("../../plots/get_data").getModuleCalcData,a=t("./plot");r.name="parcats",r.plot=function(t,e,r,i){var o=n(t.calcdata,"parcats");if(o.length){var s=o[0];a(t,s,r,i)}},r.clean=function(t,e,r,n){var a=n._has&&n._has("parcats"),i=e._has&&e._has("parcats");a&&!i&&n._paperdiv.selectAll(".parcats").remove()}},{"../../plots/get_data":799,"./plot":1079}],1075:[function(t,e,r){"use strict";var n=t("../../lib/gup").wrap,a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/calc"),o=t("../../lib/filter_unique.js"),s=t("../../components/drawing"),l=t("../../lib");function c(t,e,r){t.valueInds.push(e),t.count+=r}function u(t,e,r){return{categoryInds:t,color:e,rawColor:r,valueInds:[],count:0}}function h(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var f,p,d,g=r.map(function(t){var e;return"trace"===t.categoryorder?e=null:"array"===t.categoryorder?e=t.categoryarray:(e=o(t.values).sort(),"category descending"===t.categoryorder&&(e=e.reverse())),function(t,e){e=null==e?[]:e.map(function(t){return t});var r={},n={},a=[];e.forEach(function(t,e){r[t]=0,n[t]=e});for(var i=0;i<t.length;i++){var o,s=t[i];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),a.push(o)}var l=e.map(function(t){return r[t]});return{uniqueValues:e,uniqueCounts:l,inds:a}}(t.values,e)});f=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map(function(t){return t.displayindex})))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach(function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,g[e])});var v,m=e.line;m?(a(e,"line")&&i(t,e,{vals:e.line.color,containerStr:"line",cLetter:"c"}),v=s.tryColorscale(m)):v=l.identity;var y,x,b,_,w,k=r[0].values.length,T={},A=g.map(function(t){return t.inds});for(d=0,y=0;y<k;y++){var M=[];for(x=0;x<A.length;x++)M.push(A[x][y]);p=f[y%f.length],d+=p;var S=(b=y,_=void 0,w=void 0,l.isArrayOrTypedArray(m.color)?w=_=m.color[b%m.color.length]:_=m.color,{color:v(_),rawColor:w}),E=M+"-"+S.rawColor;void 0===T[E]&&(T[E]=u(M,S.color,S.rawColor)),h(T[E],y,p)}var L,C=r.map(function(t,e){return r=e,n=t._index,a=t._displayindex,i=t.label,{dimensionInd:r,containerInd:n,displayInd:a,dimensionLabel:i,count:d,categories:[],dragX:null};var r,n,a,i});for(y=0;y<k;y++)for(p=f[y%f.length],x=0;x<C.length;x++){var P=C[x].containerInd,O=g[x].inds[y],z=C[x].categories;if(void 0===z[O]){var I=e.dimensions[P]._categoryarray[O],D=e.dimensions[P]._ticktext[O];z[O]={dimensionInd:x,categoryInd:L=O,categoryValue:I,displayInd:L,categoryLabel:D,valueInds:[],count:0,dragY:null}}c(z[O],y,p)}return n(function(t,e,r){var n=t.map(function(t){return t.categories.length}).reduce(function(t,e){return Math.max(t,e)});return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(C,T,d))}},{"../../components/colorscale/calc":599,"../../components/colorscale/helpers":602,"../../components/drawing":612,"../../lib":716,"../../lib/filter_unique.js":708,"../../lib/gup":714}],1076:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/defaults"),o=t("../../plots/domain").defaults,s=t("../../plots/array_container_defaults"),l=t("./attributes"),c=t("../parcoords/merge_length");function u(t,e){function r(r,a){return n.coerce(t,e,l.dimensions,r,a)}var a=r("values"),i=r("visible");if(a&&a.length||(i=e.visible=!1),i){r("label"),r("displayindex",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o="array");var u=r("categoryorder",o);"array"===u?(r("categoryarray"),r("ticktext")):(delete t.categoryarray,delete t.ticktext),c||"array"!==u||(e.categoryorder="trace")}}e.exports=function(t,e,r,h){function f(r,a){return n.coerce(t,e,l,r,a)}var p=s(t,e,{name:"dimensions",handleItemDefaults:u}),d=function(t,e,r,o,s){s("line.shape"),s("line.hovertemplate");var l=s("line.color",o.colorway[0]);if(a(t,"line")&&n.isArrayOrTypedArray(l)){if(l.length)return s("line.colorscale"),i(t,e,o,s,{prefix:"line.",cLetter:"c"}),l.length;e.line.color=r}return 1/0}(t,e,r,h,f);o(e,h,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,"values",d),f("hoveron"),f("hovertemplate"),f("arrangement"),f("bundlecolors"),f("sortpaths"),f("counts");var g={family:h.font.family,size:Math.round(h.font.size),color:h.font.color};n.coerceFont(f,"labelfont",g);var v={family:h.font.family,size:Math.round(h.font.size/1.2),color:h.font.color};n.coerceFont(f,"tickfont",v)}},{"../../components/colorscale/defaults":601,"../../components/colorscale/helpers":602,"../../lib":716,"../../plots/array_container_defaults":760,"../../plots/domain":789,"../parcoords/merge_length":1089,"./attributes":1073}],1077:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),colorbar:{container:"line",min:"cmin",max:"cmax"},moduleType:"trace",name:"parcats",basePlotModule:t("./base_plot"),categories:["noOpacity"],meta:{}}},{"./attributes":1073,"./base_plot":1074,"./calc":1075,"./defaults":1076,"./plot":1079}],1078:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../plot_api/plot_api"),i=t("../../components/fx"),o=t("../../lib"),s=t("../../components/drawing"),l=t("tinycolor2"),c=t("../../lib/svg_text_utils");function u(t,e,r,a){var i=t.map(function(t,e,r){var n,a=r[0],i=e.margin||{l:80,r:80,t:100,b:80},o=a.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+i.l,p=e.height-s.y[1]*e.height+i.t,d=o.line.shape;n="all"===o.hoverinfo?["count","probability"]:(o.hoverinfo||"").split("+");var g={trace:o,key:o.uid,model:a,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:i,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};a.dimensions&&(F(g),R(g));return g}.bind(0,e,r)),l=a.selectAll("g.parcatslayer").data([null]);l.enter().append("g").attr("class","parcatslayer").style("pointer-events","all");var u=l.selectAll("g.trace.parcats").data(i,h),v=u.enter().append("g").attr("class","trace parcats");u.attr("transform",function(t){return"translate("+t.x+", "+t.y+")"}),v.append("g").attr("class","paths");var m=u.select("g.paths").selectAll("path.path").data(function(t){return t.paths},h);m.attr("fill",function(t){return t.model.color});var b=m.enter().append("path").attr("class","path").attr("stroke-opacity",0).attr("fill",function(t){return t.model.color}).attr("fill-opacity",0);x(b),m.attr("d",function(t){return t.svgD}),b.empty()||m.sort(p),m.exit().remove(),m.on("mouseover",d).on("mouseout",g).on("click",y),v.append("g").attr("class","dimensions");var k=u.select("g.dimensions").selectAll("g.dimension").data(function(t){return t.dimensions},h);k.enter().append("g").attr("class","dimension"),k.attr("transform",function(t){return"translate("+t.x+", 0)"}),k.exit().remove();var T=k.selectAll("g.category").data(function(t){return t.categories},h),A=T.enter().append("g").attr("class","category");T.attr("transform",function(t){return"translate(0, "+t.y+")"}),A.append("rect").attr("class","catrect").attr("pointer-events","none"),T.select("rect.catrect").attr("fill","none").attr("width",function(t){return t.width}).attr("height",function(t){return t.height}),_(A);var M=T.selectAll("rect.bandrect").data(function(t){return t.bands},h);M.each(function(){o.raiseToTop(this)}),M.attr("fill",function(t){return t.color});var O=M.enter().append("rect").attr("class","bandrect").attr("stroke-opacity",0).attr("fill",function(t){return t.color}).attr("fill-opacity",0);M.attr("fill",function(t){return t.color}).attr("width",function(t){return t.width}).attr("height",function(t){return t.height}).attr("y",function(t){return t.y}).attr("cursor",function(t){return"fixed"===t.parcatsViewModel.arrangement?"default":"perpendicular"===t.parcatsViewModel.arrangement?"ns-resize":"move"}),w(O),M.exit().remove(),A.append("text").attr("class","catlabel").attr("pointer-events","none");var z=e._fullLayout.paper_bgcolor;T.select("text.catlabel").attr("text-anchor",function(t){return f(t)?"start":"end"}).attr("alignment-baseline","middle").style("text-shadow",z+" -1px  1px 2px, "+z+" 1px  1px 2px, "+z+"  1px -1px 2px, "+z+" -1px -1px 2px").style("fill","rgb(0, 0, 0)").attr("x",function(t){return f(t)?t.width+5:-5}).attr("y",function(t){return t.height/2}).text(function(t){return t.model.categoryLabel}).each(function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)}),A.append("text").attr("class","dimlabel"),T.select("text.dimlabel").attr("text-anchor","middle").attr("alignment-baseline","baseline").attr("cursor",function(t){return"fixed"===t.parcatsViewModel.arrangement?"default":"ew-resize"}).attr("x",function(t){return t.width/2}).attr("y",-5).text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}).each(function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)}),T.selectAll("rect.bandrect").on("mouseover",S).on("mouseout",E),T.exit().remove(),k.call(n.behavior.drag().origin(function(t){return{x:t.x,y:0}}).on("dragstart",L).on("drag",C).on("dragend",P)),u.each(function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll("g.paths").selectAll("path.path"),t.dimensionSelection=n.select(this).selectAll("g.dimensions").selectAll("g.dimension")}),u.exit().remove()}function h(t){return t.key}function f(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf("skip")){o.raiseToTop(this),b(n.select(this));var e=v(t),r=m(t);if(t.parcatsViewModel.graphDiv.emit("plotly_hover",{points:e,event:n.event,constraints:r}),-1===t.parcatsViewModel.hoverinfoItems.indexOf("none")){var a,s,c,u=n.mouse(this)[0],h=t.parcatsViewModel.graphDiv,f=t.parcatsViewModel.trace,p=h._fullLayout,d=p._paperdiv.node().getBoundingClientRect(),g=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(c=0;c<t.leftXs.length-1;c++)if(t.leftXs[c]+t.dimWidths[c]-2<=u&&u<=t.leftXs[c+1]+2){var y=t.parcatsViewModel.dimensions[c],x=t.parcatsViewModel.dimensions[c+1];a=(y.x+y.width+x.x)/2,s=(t.topYs[c]+t.topYs[c+1]+t.height)/2;break}var _=t.parcatsViewModel.x+a,w=t.parcatsViewModel.y+s,k=l.mostReadable(t.model.color,["black","white"]),T=t.model.count,A=T/t.parcatsViewModel.model.count,M={countLabel:T,probabilityLabel:A.toFixed(3)},S=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf("count")&&S.push(["Count:",M.countLabel].join(" ")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf("probability")&&S.push(["P:",M.probabilityLabel].join(" "));var E=S.join("<br>"),L=n.mouse(h)[0];i.loneHover({trace:f,x:_-d.left+g.left,y:w-d.top+g.top,text:E,color:t.model.color,borderColor:"black",fontFamily:'Monaco, "Courier New", monospace',fontSize:10,fontColor:k,idealAlign:L<_?"right":"left",hovertemplate:(f.line||{}).hovertemplate,hovertemplateLabels:M,eventData:[{data:f._input,fullData:f,count:T,probability:A}]},{container:p._hoverlayer.node(),outerContainer:p._paper.node(),gd:h})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(x(n.select(this)),i.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf("skip"))){var e=v(t),r=m(t);t.parcatsViewModel.graphDiv.emit("plotly_unhover",{points:e,event:n.event,constraints:r})}}function v(t){for(var e=[],r=O(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var a=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:a})}return e}function m(t){for(var e={},r=t.parcatsViewModel.model.dimensions,n=0;n<r.length;n++){var a=r[n],i=a.categories[t.model.categoryInds[n]];e[a.containerInd]=i.categoryValue}return void 0!==t.model.rawColor&&(e.color=t.model.rawColor),e}function y(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf("skip")){var e=v(t),r=m(t);t.parcatsViewModel.graphDiv.emit("plotly_click",{points:e,event:n.event,constraints:r})}}function x(t){t.attr("fill",function(t){return t.model.color}).attr("fill-opacity",.6).attr("stroke","lightgray").attr("stroke-width",.2).attr("stroke-opacity",1)}function b(t){t.attr("fill-opacity",.8).attr("stroke",function(t){return l.mostReadable(t.model.color,["black","white"])}).attr("stroke-width",.3)}function _(t){t.select("rect.catrect").attr("stroke","black").attr("stroke-width",1).attr("stroke-opacity",1)}function w(t){t.attr("stroke","black").attr("stroke-width",.2).attr("stroke-opacity",1).attr("fill-opacity",1)}function k(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter(function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color})}function T(t,e,r){var a=n.select(t).datum(),i=a.categoryViewModel.model,o=a.parcatsViewModel.graphDiv,s=n.select(t.parentNode).selectAll("rect.bandrect"),l=[];s.each(function(t){k(t).each(function(t){Array.prototype.push.apply(l,v(t))})});var c={};c[i.dimensionInd]=i.categoryValue,o.emit(e,{points:l,event:r,constraints:c})}function A(t,e,r){var a=n.select(t).datum(),i=a.categoryViewModel.model,o=a.parcatsViewModel.graphDiv,s=k(a),l=[];s.each(function(t){Array.prototype.push.apply(l,v(t))});var c={};c[i.dimensionInd]=i.categoryValue,void 0!==a.rawColor&&(c.color=a.rawColor),o.emit(e,{points:l,event:r,constraints:c})}function M(t,e){var r,a,i=n.select(e.parentNode).select("rect.catrect"),o=i.node().getBoundingClientRect(),s=i.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=l.trace,h=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,a="left"):(r=o.left+o.width,a="right");var f=s.model.count,p=s.model.categoryLabel,d=f/s.parcatsViewModel.model.count,g={countLabel:f,categoryLabel:p,probabilityLabel:d.toFixed(3)},v=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf("count")&&v.push(["Count:",g.countLabel].join(" ")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf("probability")&&v.push(["P("+g.categoryLabel+"):",g.probabilityLabel].join(" "));var m=v.join("<br>");return{trace:u,x:r-t.left,y:h-t.top,text:m,color:"lightgray",borderColor:"black",fontFamily:'Monaco, "Courier New", monospace',fontSize:12,fontColor:"black",idealAlign:a,hovertemplate:u.hovertemplate,hovertemplateLabels:g,eventData:[{data:u._input,fullData:u,count:f,category:p,probability:d}]}}function S(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf("skip")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,a=r._fullLayout,s=a._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if("color"===c?(!function(t){var e=n.select(t).datum(),r=k(e);b(r),r.each(function(){o.raiseToTop(this)}),n.select(t.parentNode).selectAll("rect.bandrect").filter(function(t){return t.color===e.color}).each(function(){o.raiseToTop(this),n.select(this).attr("stroke","black").attr("stroke-width",1.5)})}(this),A(this,"plotly_hover",n.event)):(!function(t){n.select(t.parentNode).selectAll("rect.bandrect").each(function(t){var e=k(t);b(e),e.each(function(){o.raiseToTop(this)})}),n.select(t.parentNode).select("rect.catrect").attr("stroke","black").attr("stroke-width",2.5)}(this),T(this,"plotly_hover",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf("none"))"category"===c?e=M(s,this):"color"===c?e=function(t,e){var r,a,i=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],h=c.trace,f=i.y+i.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=i.left,a="left"):(r=i.left+i.width,a="right");var p=s.model.categoryLabel,d=o.parcatsViewModel.model.count,g=0;o.categoryViewModel.bands.forEach(function(t){t.color===o.color&&(g+=t.count)});var v=s.model.count,m=0;c.pathSelection.each(function(t){t.model.color===o.color&&(m+=t.model.count)});var y=g/d,x=g/m,b=g/v,_={countLabel:d,categoryLabel:p,probabilityLabel:y.toFixed(3)},w=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf("count")&&w.push(["Count:",_.countLabel].join(" ")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf("probability")&&(w.push("P(color \u2229 "+p+"): "+_.probabilityLabel),w.push("P("+p+" | color): "+x.toFixed(3)),w.push("P(color | "+p+"): "+b.toFixed(3)));var k=w.join("<br>"),T=l.mostReadable(o.color,["black","white"]);return{trace:h,x:r-t.left,y:f-t.top,text:k,color:o.color,borderColor:"black",fontFamily:'Monaco, "Courier New", monospace',fontColor:T,fontSize:10,idealAlign:a,hovertemplate:h.hovertemplate,hovertemplateLabels:_,eventData:[{data:h._input,fullData:h,category:p,count:d,probability:y,categorycount:v,colorcount:m,bandcolorcount:g}]}}(s,this):"dimension"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll("g.category").select("rect.catrect").each(function(){r.push(M(t,this))}),r}(s,this)),e&&i.loneHover(e,{container:a._hoverlayer.node(),outerContainer:a._paper.node(),gd:r})}}function E(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(x(e.pathSelection),_(e.dimensionSelection.selectAll("g.category")),w(e.dimensionSelection.selectAll("g.category").selectAll("rect.bandrect")),i.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf("skip"))){"color"===t.parcatsViewModel.hoveron?A(this,"plotly_unhover",n.event):T(this,"plotly_unhover",n.event)}}function L(t){"fixed"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll("g.category").select("rect.catrect").each(function(e){var r=n.mouse(this)[0],a=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=a&&a<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map(function(t){return t.displayInd}),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll("rect.bandrect").each(function(e){e.y<a&&a<=e.y+e.height&&(t.potentialClickBand=this)}))}),t.parcatsViewModel.dragDimension=t,i.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function C(t){if("fixed"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,a=e+1,i=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=i.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=i.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||"freeform"===t.parcatsViewModel.arrangement){i.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[a];void 0!==f&&i.model.dragX<f.x+f.width&&(i.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&i.model.dragX+i.width>p.x&&(i.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=i.model.displayInd}F(t.parcatsViewModel),R(t.parcatsViewModel),I(t.parcatsViewModel),z(t.parcatsViewModel)}}function P(t){if("fixed"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll("text").attr("font-weight","normal");var e={},r=O(t.parcatsViewModel),i=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),o=t.initialDragDimensionDisplayInds.some(function(t,e){return t!==i[e]});o&&i.forEach(function(r,n){var a=t.parcatsViewModel.model.dimensions[n].containerInd;e["dimensions["+a+"].displayindex"]=r});var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map(function(t){return t.displayInd});if(s=t.initialDragCategoryDisplayInds.some(function(t,e){return t!==l[e]})){var c=t.model.categories.slice().sort(function(t,e){return t.displayInd-e.displayInd}),u=c.map(function(t){return t.categoryValue}),h=c.map(function(t){return t.categoryLabel});e["dimensions["+t.model.containerInd+"].categoryarray"]=[u],e["dimensions["+t.model.containerInd+"].ticktext"]=[h],e["dimensions["+t.model.containerInd+"].categoryorder"]="array"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf("skip")&&!t.dragHasMoved&&t.potentialClickBand&&("color"===t.parcatsViewModel.hoveron?A(t.potentialClickBand,"plotly_click",n.event.sourceEvent):T(t.potentialClickBand,"plotly_click",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,F(t.parcatsViewModel),R(t.parcatsViewModel),n.transition().duration(300).ease("cubic-in-out").each(function(){I(t.parcatsViewModel,!0),z(t.parcatsViewModel,!0)}).each("end",function(){(o||s)&&a.restyle(t.parcatsViewModel.graphDiv,e,[r])})}}function O(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function z(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data(function(t){return t.paths},h),(r=t.pathSelection,e?r.transition():r).attr("d",function(t){return t.svgD})}function I(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data(function(t){return t.dimensions},h);var a=t.dimensionSelection.selectAll("g.category").data(function(t){return t.categories},h);r(t.dimensionSelection).attr("transform",function(t){return"translate("+t.x+", 0)"}),r(a).attr("transform",function(t){return"translate(0, "+t.y+")"}),a.select(".dimlabel").text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}),a.select(".catlabel").attr("text-anchor",function(t){return f(t)?"start":"end"}).attr("x",function(t){return f(t)?t.width+5:-5}).each(function(t){var e,r;f(t)?(e=t.width+5,r="start"):(e=-5,r="end"),n.select(this).selectAll("tspan").attr("x",e).attr("text-anchor",r)});var i=a.selectAll("rect.bandrect").data(function(t){return t.bands},h),s=i.enter().append("rect").attr("class","bandrect").attr("cursor","move").attr("stroke-opacity",0).attr("fill",function(t){return t.color}).attr("fill-opacity",0);i.attr("fill",function(t){return t.color}).attr("width",function(t){return t.width}).attr("height",function(t){return t.height}).attr("y",function(t){return t.y}),w(s),i.each(function(){o.raiseToTop(this)}),i.exit().remove()}function D(t,e,r,a,i){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(i)),c.push(o(1-i));var u="M "+t[0]+","+e[0];for(u+="l"+r[0]+",0 ",s=1;s<r.length;s++)u+="C"+l[s-1]+","+e[s-1]+" "+c[s-1]+","+e[s]+" "+t[s]+","+e[s],u+="l"+r[s]+",0 ";for(u+="l0,"+a+" ",u+="l -"+r[r.length-1]+",0 ",s=r.length-2;s>=0;s--)u+="C"+c[s]+","+(e[s+1]+a)+" "+l[s]+","+(e[s]+a)+" "+(t[s]+r[s])+","+(e[s]+a),u+="l-"+r[s]+",0 ";return u+="Z"}function R(t){var e=t.dimensions,r=t.model,n=e.map(function(t){return t.categories.map(function(t){return t.y})}),a=t.model.dimensions.map(function(t){return t.categories.map(function(t){return t.displayInd})}),i=t.model.dimensions.map(function(t){return t.displayInd}),o=t.dimensions.map(function(t){return t.model.dimensionInd}),s=e.map(function(t){return t.x}),l=e.map(function(t){return t.width}),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map(function(t,e){return a[e][t]});return o.map(function(t){return e[t]})}c.sort(function(e,r){var n=h(e),a=h(r);return"backward"===t.sortpaths&&(n.reverse(),a.reverse()),n.push(e.valueInds[0]),a.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),a.unshift(r.rawColor)),n<a?-1:n>a?1:0});for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map(function(t){return t.height}).reduce(function(t,e){return t+e}),g=0;g<c.length;g++){var v,m=c[g];v=p>0?d*(m.count/p):0;for(var y,x=new Array(n.length),b=0;b<m.categoryInds.length;b++){var _=m.categoryInds[b],w=a[b][_],k=i[b];x[k]=n[k][w],n[k][w]+=v;var T=t.dimensions[k].categories[w],A=T.bands.length,M=T.bands[A-1];if(void 0===M||m.rawColor!==M.rawColor){var S=void 0===M?0:M.y+M.height;T.bands.push({key:S,color:m.color,rawColor:m.rawColor,height:v,width:T.width,count:m.count,y:S,categoryViewModel:T,parcatsViewModel:t})}else{var E=T.bands[A-1];E.height+=v,E.count+=m.count}}y="hspline"===t.pathShape?D(s,x,l,v,.5):D(s,x,l,v,0),f[g]={key:m.valueInds[0],model:m,height:v,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=f}function F(t){var e=t.model.dimensions.map(function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}});e.sort(function(t,e){return t.displayInd-e.displayInd});var r=[];for(var n in e){var a=e[n].dimensionInd,i=t.model.dimensions[a];r.push(B(t,i))}t.dimensions=r}function B(t,e){var r,n=t.model.dimensions.length,a=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*a;var i,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),g=8*(h-f)/2,v=e.categories.map(function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}});for(v.sort(function(t,e){return t.displayInd-e.displayInd}),c=0;c<f;c++)l=v[c].categoryInd,o=e.categories[l],i=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:i,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+i+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{"../../components/drawing":612,"../../components/fx":629,"../../lib":716,"../../lib/svg_text_utils":740,"../../plot_api/plot_api":751,d3:164,tinycolor2:535}],1079:[function(t,e,r){"use strict";var n=t("./parcats");e.exports=function(t,e,r,a){var i=t._fullLayout,o=i._paper,s=i._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,a)}},{"./parcats":1078}],1080:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/cartesian/layout_attributes"),i=t("../../plots/font_attributes"),o=t("../../plots/domain").attributes,s=t("../../lib/extend").extendFlat,l=t("../../plot_api/plot_template").templatedArray;e.exports={domain:o({name:"parcoords",trace:!0,editType:"plot"}),labelangle:{valType:"angle",dflt:0,editType:"plot"},labelside:{valType:"enumerated",values:["top","bottom"],dflt:"top",editType:"plot"},labelfont:i({editType:"plot"}),tickfont:i({editType:"plot"}),rangefont:i({editType:"plot"}),dimensions:l("dimension",{label:{valType:"string",editType:"plot"},tickvals:s({},a.tickvals,{editType:"plot"}),ticktext:s({},a.ticktext,{editType:"plot"}),tickformat:s({},a.tickformat,{editType:"plot"}),visible:{valType:"boolean",dflt:!0,editType:"plot"},range:{valType:"info_array",items:[{valType:"number",editType:"plot"},{valType:"number",editType:"plot"}],editType:"plot"},constraintrange:{valType:"info_array",freeLength:!0,dimensions:"1-2",items:[{valType:"number",editType:"plot"},{valType:"number",editType:"plot"}],editType:"plot"},multiselect:{valType:"boolean",dflt:!0,editType:"plot"},values:{valType:"data_array",editType:"calc"},editType:"calc"}),line:s({editType:"calc"},n("line",{colorscaleDflt:"Viridis",autoColorDflt:!1,editTypeOverride:"calc"}))}},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plot_api/plot_template":754,"../../plots/cartesian/layout_attributes":776,"../../plots/domain":789,"../../plots/font_attributes":790}],1081:[function(t,e,r){"use strict";var n=t("./constants"),a=t("d3"),i=t("../../lib/gup").keyFun,o=t("../../lib/gup").repeat,s=t("../../lib").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function h(t,e){return t*(1-u)+e*u}function f(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var a=t?-1:1,i=0,o=e.length-1;if(a<0){var s=i;i=o,o=s}for(var l=e[i],u=l,f=i;a*f<a*o;f+=a){var p=f+a,d=e[p];if(a*r<a*h(l,d))return c(l,u);if(a*r<a*d||p===o)return c(d,l);u=l,l=d}}function p(t){t.attr("x",-n.bar.captureWidth/2).attr("width",n.bar.captureWidth)}function d(t){t.attr("visibility","visible").style("visibility","visible").attr("fill","yellow").attr("opacity",0)}function g(t){if(!t.brush.filterSpecified)return"0,"+t.height;for(var e,r,n,a=v(t.brush.filter.getConsolidated(),t.height),i=[0],o=a.length?a[0][0]:null,s=0;s<a.length;s++)r=(e=a[s])[1]-e[0],i.push(o),i.push(r),(n=s+1)<a.length&&(o=a[n][0]-e[1]);return i.push(t.height),i}function v(t,e){return t.map(function(t){return t.map(function(t){return Math.max(0,t*e)}).sort(s)})}function m(){a.select(document.body).style("cursor",null)}function y(t){t.attr("stroke-dasharray",g)}function x(t,e){var r=a.select(t).selectAll(".highlight, .highlight-shadow");y(e?r.transition().duration(n.bar.snapDuration).each("end",e):r)}function b(t,e){var r,a=t.brush,i=NaN,o={};if(a.filterSpecified){var s=t.height,l=a.filter.getConsolidated(),c=v(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(i=u,isNaN(i)&&(i=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(i)){var d=c[i],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?"n":e<=.9*t[0]+.1*t[1]?"s":"ns"}(d,e);g&&(o.interval=l[i],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function _(t,e){a.event.sourceEvent.stopPropagation();var r=e.height-a.mouse(t)[1]-2*n.verticalPadding,i=e.brush.svgBrush;i.wasDragged=!0,i._dragging=!0,i.grabbingBar?i.newExtent=[r-i.grabPoint,r+i.barLength-i.grabPoint].map(e.unitToPaddedPx.invert):i.newExtent=[i.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,i.extent=i.stayingIntervals.concat([i.newExtent]),i.brushCallback(e),x(t.parentNode)}function w(t,e){var r=b(e,e.height-a.mouse(t)[1]-2*n.verticalPadding),i="crosshair";r.clickableOrdinalRange?i="pointer":r.region&&(i=r.region+"-resize"),a.select(document.body).style("cursor",i)}function k(t){t.on("mousemove",function(t){a.event.preventDefault(),t.parent.inBrushDrag||w(this,t)}).on("mouseleave",function(t){t.parent.inBrushDrag||m()}).call(a.behavior.drag().on("dragstart",function(t){!function(t,e){a.event.sourceEvent.stopPropagation();var r=e.height-a.mouse(t)[1]-2*n.verticalPadding,i=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar="ns"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter(function(t){return t[0]!==l[0]&&t[1]!==l[1]})),c.startExtent=s.region?l["s"===s.region?1:0]:i,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)}).on("drag",function(t){_(this,t)}).on("dragend",function(t){!function(t,e){var r=e.brush,n=r.filter,i=r.svgBrush;i._dragging||(w(t,e),_(t,e),e.brush.svgBrush.wasDragged=!1),i._dragging=!1,a.event.sourceEvent.stopPropagation();var o=i.grabbingBar;if(i.grabbingBar=!1,i.grabLocation=void 0,e.parent.inBrushDrag=!1,m(),!i.wasDragged)return i.wasDragged=void 0,i.clickableOrdinalRange?r.filterSpecified&&e.multiselect?i.extent.push(i.clickableOrdinalRange):(i.extent=[i.clickableOrdinalRange],r.filterSpecified=!0):o?(i.extent=i.stayingIntervals,0===i.extent.length&&A(r)):A(r),i.brushCallback(e),x(t.parentNode),void i.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),i.newExtent=[f(0,l,i.newExtent[0],i.stayingIntervals),f(1,l,i.newExtent[1],i.stayingIntervals)];var c=i.newExtent[1]>i.newExtent[0];i.extent=i.stayingIntervals.concat(c?[i.newExtent]:[]),i.extent.length||A(r),i.brushCallback(e),c?x(t.parentNode,s):(s(),x(t.parentNode))}else s();i.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)}))}function T(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function M(t){for(var e,r=t.slice(),n=[],a=r.shift();a;){for(e=a.slice();(a=r.shift())&&a[0]<=e[1];)e[1]=Math.max(e[1],a[1]);n.push(e)}return n}e.exports={makeBrush:function(t,e,r,n,a,i){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map(function(t){return t.slice().sort(s)}).sort(T)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=M(r),e=r.reduce(function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]},[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=a,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map(function(t){return t.slice()})}(e).slice();e.filter.set(r),o()}),brushEndCallback:i}}},ensureAxisBrush:function(t){var e=t.selectAll("."+n.cn.axisBrush).data(o,i);e.enter().append("g").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(".background").data(o);e.enter().append("rect").classed("background",!0).call(p).call(d).style("pointer-events","auto").attr("transform","translate(0 "+n.verticalPadding+")"),e.call(k).attr("height",function(t){return t.height-n.verticalPadding});var r=t.selectAll(".highlight-shadow").data(o);r.enter().append("line").classed("highlight-shadow",!0).attr("x",-n.bar.width/2).attr("stroke-width",n.bar.width+n.bar.strokeWidth).attr("stroke",n.bar.strokeColor).attr("opacity",n.bar.strokeOpacity).attr("stroke-linecap","butt"),r.attr("y1",function(t){return t.height}).call(y);var a=t.selectAll(".highlight").data(o);a.enter().append("line").classed("highlight",!0).attr("x",-n.bar.width/2).attr("stroke-width",n.bar.width-n.bar.strokeWidth).attr("stroke",n.bar.fillColor).attr("opacity",n.bar.fillOpacity).attr("stroke-linecap","butt"),a.attr("y1",function(t){return t.height}).call(y)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map(function(t){return t.sort(s)}),t=e.multiselect?M(t.sort(T)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map(function(t){var e=[f(0,r,t[0],[]),f(1,r,t[1],[])];if(e[1]>e[0])return e}).filter(function(t){return t})).length)return}return t.length>1?t:t[0]}}},{"../../lib":716,"../../lib/gup":714,"./constants":1084,d3:164}],1082:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../plots/get_data").getModuleCalcData,i=t("./plot"),o=t("../../constants/xmlns_namespaces");r.name="parcoords",r.plot=function(t){var e=a(t.calcdata,"parcoords")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var a=n._has&&n._has("parcoords"),i=e._has&&e._has("parcoords");a&&!i&&(n._paperdiv.selectAll(".parcoords").remove(),n._glimages.selectAll("*").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(".svg-container");r.filter(function(t,e){return e===r.size()-1}).selectAll(".gl-canvas-context, .gl-canvas-focus").each(function(){var t=this.toDataURL("image/png");e.append("svg:image").attr({xmlns:o.svg,"xlink:href":t,preserveAspectRatio:"none",x:0,y:0,width:this.width,height:this.height})}),window.setTimeout(function(){n.selectAll("#filterBarPattern").attr("id","filterBarPattern")},60)}},{"../../constants/xmlns_namespaces":693,"../../plots/get_data":799,"./plot":1091,d3:164}],1083:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray,a=t("../../components/colorscale"),i=t("../../lib/gup").wrap;e.exports=function(t,e){var r,o;return a.hasColorscale(e,"line")&&n(e.line.color)?(r=e.line.color,o=a.extractOpts(e.line).colorscale,a.calc(t,e,{vals:r,containerStr:"line",cLetter:"c"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),i({lineColor:r,cscale:o})}},{"../../components/colorscale":603,"../../lib":716,"../../lib/gup":714}],1084:[function(t,e,r){"use strict";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:["contextLineLayer","focusLineLayer","pickLineLayer"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:"#777",bar:{width:4,captureWidth:10,fillColor:"magenta",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:"white",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:"axis-extent-text",parcoordsLineLayers:"parcoords-line-layers",parcoordsLineLayer:"parcoords-lines",parcoords:"parcoords",parcoordsControlView:"parcoords-control-view",yAxis:"y-axis",axisOverlays:"axis-overlays",axis:"axis",axisHeading:"axis-heading",axisTitle:"axis-title",axisExtent:"axis-extent",axisExtentTop:"axis-extent-top",axisExtentTopText:"axis-extent-top-text",axisExtentBottom:"axis-extent-bottom",axisExtentBottomText:"axis-extent-bottom-text",axisBrush:"axis-brush"},id:{filterBarPattern:"filter-bar-pattern"}}},{}],1085:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/defaults"),o=t("../../plots/domain").defaults,s=t("../../plots/array_container_defaults"),l=t("../../plots/cartesian/axes"),c=t("./attributes"),u=t("./axisbrush"),h=t("./constants").maxDimensionCount,f=t("./merge_length");function p(t,e,r,a){function i(r,a){return n.coerce(t,e,c.dimensions,r,a)}var o=i("values"),s=i("visible");if(o&&o.length||(s=e.visible=!1),s){i("label"),i("tickvals"),i("ticktext"),i("tickformat");var h=i("range");e._ax={_id:"y",type:"linear",showexponent:"all",exponentformat:"B",range:h},l.setConvert(e._ax,a.layout),i("multiselect");var f=i("constraintrange");f&&(e.constraintrange=u.cleanRanges(f,e))}}e.exports=function(t,e,r,l){function u(r,a){return n.coerce(t,e,c,r,a)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log("parcoords traces support up to "+h+" dimensions at the moment"),d.splice(h));var g=s(t,e,{name:"dimensions",layout:l,handleItemDefaults:p}),v=function(t,e,r,o,s){var l=s("line.color",r);if(a(t,"line")&&n.isArrayOrTypedArray(l)){if(l.length)return s("line.colorscale"),i(t,e,o,s,{prefix:"line.",cLetter:"c"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,"values",v);var m={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,"labelfont",m),n.coerceFont(u,"tickfont",m),n.coerceFont(u,"rangefont",m),u("labelangle"),u("labelside")}},{"../../components/colorscale/defaults":601,"../../components/colorscale/helpers":602,"../../lib":716,"../../plots/array_container_defaults":760,"../../plots/cartesian/axes":764,"../../plots/domain":789,"./attributes":1080,"./axisbrush":1081,"./constants":1084,"./merge_length":1089}],1086:[function(t,e,r){"use strict";var n=t("../../lib").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!("visible"in t)}},{"../../lib":716}],1087:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),colorbar:{container:"line",min:"cmin",max:"cmax"},moduleType:"trace",name:"parcoords",basePlotModule:t("./base_plot"),categories:["gl","regl","noOpacity","noHover"],meta:{}}},{"./attributes":1080,"./base_plot":1082,"./calc":1083,"./defaults":1085,"./plot":1091}],1088:[function(t,e,r){"use strict";var n=t("glslify"),a=n(["precision highp float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor;\n\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\n               p17_20, p21_24, p25_28, p29_32,\n               p33_36, p37_40, p41_44, p45_48,\n               p49_52, p53_56, p57_60, colors;\n\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\n\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\nuniform sampler2D mask, palette;\nuniform float maskHeight;\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\nuniform vec4 contextColor;\n\nbool isPick    = (drwLayer > 1.5);\nbool isContext = (drwLayer < 0.5);\n\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\n\nfloat val(mat4 p, mat4 v) {\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\n}\n\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\n    return y1 * (1.0 - ratio) + y2 * ratio;\n}\n\nint iMod(int a, int b) {\n    return a - b * (a / b);\n}\n\nbool fOutside(float p, float lo, float hi) {\n    return (lo < hi) && (lo > p || p > hi);\n}\n\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\n    return (\n        fOutside(p[0], lo[0], hi[0]) ||\n        fOutside(p[1], lo[1], hi[1]) ||\n        fOutside(p[2], lo[2], hi[2]) ||\n        fOutside(p[3], lo[3], hi[3])\n    );\n}\n\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\n    return (\n        vOutside(p[0], lo[0], hi[0]) ||\n        vOutside(p[1], lo[1], hi[1]) ||\n        vOutside(p[2], lo[2], hi[2]) ||\n        vOutside(p[3], lo[3], hi[3])\n    );\n}\n\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\n    return mOutside(A, loA, hiA) ||\n           mOutside(B, loB, hiB) ||\n           mOutside(C, loC, hiC) ||\n           mOutside(D, loD, hiD);\n}\n\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\n    mat4 pnts[4];\n    pnts[0] = A;\n    pnts[1] = B;\n    pnts[2] = C;\n    pnts[3] = D;\n\n    for(int i = 0; i < 4; ++i) {\n        for(int j = 0; j < 4; ++j) {\n            for(int k = 0; k < 4; ++k) {\n                if(0 == iMod(\n                    int(255.0 * texture2D(mask,\n                        vec2(\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\n                        ))[3]\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\n                    2\n                )) return true;\n            }\n        }\n    }\n    return false;\n}\n\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\n    float x = 0.5 * sign(v) + 0.5;\n    float y = axisY(x, A, B, C, D);\n    float z = 1.0 - abs(v);\n\n    z += isContext ? 0.0 : 2.0 * float(\n        outsideBoundingBox(A, B, C, D) ||\n        outsideRasterMask(A, B, C, D)\n    );\n\n    return vec4(\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\n        z,\n        1.0\n    );\n}\n\nvoid main() {\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\n\n    float v = colors[3];\n\n    gl_Position = position(isContext, v, A, B, C, D);\n\n    fragColor =\n        isContext ? vec4(contextColor) :\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\n}\n"]),i=n(["precision highp float;\n#define GLSLIFY 1\n\nvarying vec4 fragColor;\n\nvoid main() {\n    gl_FragColor = fragColor;\n}\n"]),o=t("./constants").maxDimensionCount,s=t("../../lib"),l=1e-6,c=2048,u=new Uint8Array(4),h=new Uint8Array(4),f={shape:[256,1],format:"rgba",type:"uint8",mag:"nearest",min:"nearest"};function p(t,e,r,n,a){var i=t._gl;i.enable(i.SCISSOR_TEST),i.scissor(e,r,n,a),t.clear({color:[0,0,0,0],depth:1})}function d(t,e,r,n,a,i){var o=i.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:u})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,a-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],p(t,i.scissorX,i.scissorY,i.scissorWidth,i.viewBoxSize[1])),r.clearOnly||(i.count=2*c,i.offset=2*l*n,e(i),l*n+c<a&&(r.currentRafs[o]=window.requestAnimationFrame(function(){s(l+1)})),r.drawCompleted=!1)}(0)}function g(t,e){return(t>>>8*e)%256/255}function v(t,e,r){for(var n=new Array(8*e),a=0,i=0;i<e;i++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*i+l];63===l&&0===o&&(c*=-1),n[a++]=c}return n}function m(t){var e="0"+t;return e.substr(e.length-2)}function y(t){return t<o?"p"+m(t+1)+"_"+m(t+4):"colors"}function x(t,e,r,n,a,i,o,l,c,u,h,f,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===a?1:0,d[1][g]=g===i?1:0;var v=t.lines.canvasOverdrag,m=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:h,resolution:[y,x],viewBoxPos:[o+v,l],viewBoxSize:[c,u],i0:a,i1:i,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:f,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+v)+(t.pad.l-v)+t.layoutWidth*m.x[0],scissorWidth:(n===r?y-o+v:c+.5)+(n===e?o+v:0),scissorY:l+t.pad.b+t.layoutHeight*m.y[0],scissorHeight:u,viewportX:t.pad.l-v+t.layoutWidth*m.x[0],viewportY:t.pad.b+t.layoutHeight*m.y[0],viewportWidth:y,viewportHeight:x},p)}function b(t){var e=c-1,r=Math.max(0,Math.floor(t[0]*e),0),n=Math.min(e,Math.ceil(t[1]*e),e);return[Math.min(r,n),Math.max(r,n)]}e.exports=function(t,e){var r,n,u,m,_,w=e.context,k=e.pick,T=e.regl,A={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[y(r)]=t.buffer({usage:"dynamic",type:"float",data:new Uint8Array(0)});return e}(T),S=T.texture(f),E=[];C(e);var L=T({profile:!1,blend:{enable:w,func:{srcRGB:"src alpha",dstRGB:"one minus src alpha",srcAlpha:1,dstAlpha:1},equation:{rgb:"add",alpha:"add"},color:[0,0,0,0]},depth:{enable:!w,mask:!0,func:"less",range:[0,1]},cull:{enable:!0,face:"back"},scissor:{enable:!0,box:{x:T.prop("scissorX"),y:T.prop("scissorY"),width:T.prop("scissorWidth"),height:T.prop("scissorHeight")}},viewport:{x:T.prop("viewportX"),y:T.prop("viewportY"),width:T.prop("viewportWidth"),height:T.prop("viewportHeight")},dither:!1,vert:a,frag:i,primitive:"lines",lineWidth:1,attributes:M,uniforms:{resolution:T.prop("resolution"),viewBoxPos:T.prop("viewBoxPos"),viewBoxSize:T.prop("viewBoxSize"),dim0A:T.prop("dim0A"),dim1A:T.prop("dim1A"),dim0B:T.prop("dim0B"),dim1B:T.prop("dim1B"),dim0C:T.prop("dim0C"),dim1C:T.prop("dim1C"),dim0D:T.prop("dim0D"),dim1D:T.prop("dim1D"),loA:T.prop("loA"),hiA:T.prop("hiA"),loB:T.prop("loB"),hiB:T.prop("hiB"),loC:T.prop("loC"),hiC:T.prop("hiC"),loD:T.prop("loD"),hiD:T.prop("hiD"),palette:S,contextColor:T.prop("contextColor"),mask:T.prop("maskTexture"),drwLayer:T.prop("drwLayer"),maskHeight:T.prop("maskHeight")},offset:T.prop("offset"),count:T.prop("count")});function C(t){r=t.model,n=t.viewModel,u=n.dimensions.slice(),m=u[0]?u[0].values.length:0;var e=r.lines,a=k?e.color.map(function(t,r){return r/e.color.length}):e.color,i=function(t,e,r){for(var n,a=new Array(t*(o+4)),i=0,s=0;s<t;s++){for(var c=0;c<o;c++)a[i++]=c<e.length?e[c].paddedUnitValues[s]:.5;a[i++]=g(s,2),a[i++]=g(s,1),a[i++]=g(s,0),a[i++]=(n=r[s],Math.max(l,Math.min(1-l,n)))}return a}(m,u,a);!function(t,e,r){for(var n=0;n<=o;n+=4)t[y(n)](v(n/4,e,r))}(M,m,i),w||k||(S=T.texture(s.extendFlat({data:function(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}(r.unitToColor,255)},f)))}return{render:function(t,e,n){var a,i,o,s=t.length,l=1/0,h=-1/0;for(a=0;a<s;a++)t[a].dim0.canvasX<l&&(l=t[a].dim0.canvasX,i=a),t[a].dim1.canvasX>h&&(h=t[a].dim1.canvasX,o=a);0===s&&p(T,0,0,r.canvasWidth,r.canvasHeight);var f=function(t){var e,r,n,a=[[],[]];for(n=0;n<64;n++){var i=!t&&n<u.length?u[n].brush.filter.getBounds():[-1/0,1/0];a[0][n]=i[0],a[1][n]=i[1]}var o=8*c,s=new Array(o);for(e=0;e<o;e++)s[e]=255;if(!t)for(e=0;e<u.length;e++){var l=e%8,h=(e-l)/8,f=Math.pow(2,l),p=u[e].brush.filter.get();if(!(p.length<2)){var d=b(p[0])[1];for(r=1;r<p.length;r++){var g=b(p[r]);for(n=d+1;n<g[0];n++)s[8*n+h]&=~f;d=Math.max(d,g[1])}}}var v={shape:[8,c],format:"alpha",type:"uint8",mag:"nearest",min:"nearest",data:s};return _?_(v):_=T.texture(v),{maskTexture:_,maskHeight:c,loA:a[0].slice(0,16),loB:a[0].slice(16,32),loC:a[0].slice(32,48),loD:a[0].slice(48,64),hiA:a[1].slice(0,16),hiB:a[1].slice(16,32),hiC:a[1].slice(32,48),hiD:a[1].slice(48,64)}}(w);for(a=0;a<s;a++){var g=t[a],v=g.dim0.crossfilterDimensionIndex,y=g.dim1.crossfilterDimensionIndex,M=g.canvasX,S=g.canvasY,C=M+g.panelSizeX;if(e||!E[v]||E[v][0]!==M||E[v][1]!==C){E[v]=[M,C];var P=x(r,i,o,a,v,y,M,S,g.panelSizeX,g.panelSizeY,g.dim0.crossfilterDimensionIndex,w?0:k?2:1,f);A.clearOnly=n;var O=e?r.lines.blockLineCount:m;d(T,L,A,O,m,P)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:h}),h},readPixels:function(t,e,r,n){var a=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:a}),a},destroy:function(){for(var e in t.style["pointer-events"]="none",S.destroy(),_&&_.destroy(),M)M[e].destroy()},update:C}}},{"../../lib":716,"./constants":1084,glslify:410}],1089:[function(t,e,r){"use strict";e.exports=function(t,e,r,n){var a,i;for(n||(n=1/0),a=0;a<e.length;a++)(i=e[a]).visible&&(n=Math.min(n,i[r].length));for(n===1/0&&(n=0),t._length=n,a=0;a<e.length;a++)(i=e[a]).visible&&(i._length=n);return n}},{}],1090:[function(t,e,r){"use strict";var n=t("d3"),a=t("color-rgba"),i=t("../../plots/cartesian/axes"),o=t("../../lib"),s=t("../../lib/svg_text_utils"),l=t("../../components/drawing"),c=t("../../components/colorscale"),u=t("../../lib/gup"),h=u.keyFun,f=u.repeat,p=u.unwrap,d=t("./helpers"),g=t("./constants"),v=t("./axisbrush"),m=t("./lines");function y(t,e,r){return o.aggNums(t,null,e,r)}function x(t,e){return _(y(Math.min,t,e),y(Math.max,t,e))}function b(t){var e=t.range;return e?_(e[0],e[1]):x(t.values,t._length)}function _(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function w(t){return t.dimensions.some(function(t){return t.brush.filterSpecified})}function k(t,e,r){var i=p(e),s=i.trace,l=d.convertTypedArray(i.lineColor),u=s.line,h={color:a(g.deselectedLineColor)},f=c.extractOpts(u),v=f.reversescale?c.flipScale(i.cscale):i.cscale,m=s.domain,y=s.dimensions,x=t.width,_=s.labelangle,w=s.labelside,k=s.labelfont,T=s.tickfont,A=s.rangefont,M=o.extendDeepNoArrays({},u,{color:l.map(n.scale.linear().domain(b({values:l,range:[f.min,f.max],_length:s._length}))),blockLineCount:g.blockLineCount,canvasOverdrag:g.overdrag*g.canvasPixelRatio}),S=Math.floor(x*(m.x[1]-m.x[0])),E=Math.floor(t.height*(m.y[1]-m.y[0])),L=t.margin||{l:80,r:80,t:100,b:80},C=S,P=E;return{key:r,colCount:y.filter(d.isVisible).length,dimensions:y,tickDistance:g.tickDistance,unitToColor:function(t){var e=t.map(function(t){return t[0]}),r=t.map(function(t){var e=a(t[1]);return n.rgb("rgb("+e[0]+","+e[1]+","+e[2]+")")}),i="rgb".split("").map(function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((a=t,function(t){return t[a]})));var a});return function(t){return i.map(function(e){return e(t)})}}(v),lines:M,deselectedLines:h,labelAngle:_,labelSide:w,labelFont:k,tickFont:T,rangeFont:A,layoutWidth:x,layoutHeight:t.height,domain:m,translateX:m.x[0]*x,translateY:t.height-m.y[1]*t.height,pad:L,canvasWidth:C*g.canvasPixelRatio+2*M.canvasOverdrag,canvasHeight:P*g.canvasPixelRatio,width:C,height:P,canvasPixelRatio:g.canvasPixelRatio}}function T(t,e,r){var a=r.width,i=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return a*t/Math.max(1,r.colCount-1)},u=g.verticalPadding/i,h=function(t,e){return n.scale.linear().range([e,t-e])}(i,g.verticalPadding),f={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return f.dimensions=s.filter(d.isVisible).map(function(a,s){var m=function(t,e){return n.scale.linear().domain(b(t)).range([e,1-e])}(a,u),y=p[a.label];p[a.label]=(y||0)+1;var x=a.label+(y?"__"+y:""),_=a.constraintrange,k=_&&_.length;k&&!Array.isArray(_[0])&&(_=[_]);var T=k?_.map(function(t){return t.map(m)}):[[-1/0,1/0]],A=a.values;A.length>a._length&&(A=A.slice(0,a._length));var M,S=a.tickvals;function E(t,e){return{val:t,text:M[e]}}function L(t,e){return t.val-e.val}if(Array.isArray(S)&&S.length){M=a.ticktext,Array.isArray(M)&&M.length?M.length>S.length?M=M.slice(0,S.length):S.length>M.length&&(S=S.slice(0,M.length)):M=S.map(n.format(a.tickformat));for(var C=1;C<S.length;C++)if(S[C]<S[C-1]){for(var P=S.map(E).sort(L),O=0;O<S.length;O++)S[O]=P[O].val,M[O]=P[O].text;break}}else S=void 0;return A=d.convertTypedArray(A),{key:x,label:a.label,tickFormat:a.tickformat,tickvals:S,ticktext:M,ordinal:d.isOrdinal(a),multiselect:a.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:a._index,height:i,values:A,paddedUnitValues:A.map(m),unitTickvals:S&&S.map(m),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:h,domainScale:function(t,e,r,a,i){var o,s,l=b(r);return a?n.scale.ordinal().domain(a.map((o=n.format(r.tickformat),s=i,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(a.map(function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)})):n.scale.linear().domain(l).range([t-e,e])}(i,g.verticalPadding,a,S,M),ordinalScale:function(t){if(t.tickvals){var e=b(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map(function(t){return(t-e[0])/(e[1]-e[0])}))}}(a),parent:f,model:r,brush:v.makeBrush(t,k,T,function(){t.linePickActive(!1)},function(){var e=f;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=w(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))},function(r){if(f.focusLayer.render(f.panels,!0),f.pickLayer&&f.pickLayer.render(f.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=m.invert,i=r.map(function(t){return t.map(n).sort(o.sorterAsc)}).sort(function(t,e){return t[0]-e[0]});e.filterChanged(f.key,a._index,i)}})}}),f}function A(t){t.classed(g.cn.axisExtentText,!0).attr("text-anchor","middle").style("cursor","default").style("user-select","none")}function M(t,e){var r="top"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function S(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),a=0;a<n.length-1;a++){var i=r[a]||(r[a]={}),o=n[a],s=n[a+1];i.dim0=o,i.dim1=s,i.canvasX=o.canvasX,i.panelSizeX=s.canvasX-o.canvasX,i.panelSizeY=e.model.canvasHeight,i.y=0,i.canvasY=0}}function E(t,e){return i.tickText(t._ax,e,!1).text}function L(t,e){if(t.ordinal)return"";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return E(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,a){var c=t._fullLayout,u=c._toppaper,y=c._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,a=n.dimensions,o=0;o<a.length;o++){var s=a[o].values,l=a[o]._ax;l&&(l.range?l.range=_(l.range[0],l.range[1]):l.range=x(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=a[o].tickformat,i.calcTicks(l),l.cleanRange())}}(e);var b,C,P=(b=!0,C=!1,{linePickActive:function(t){return arguments.length?b=!!t:b},contextShown:function(t){return arguments.length?C=!!t:C}}),O=e.filter(function(t){return p(t).trace.visible}).map(k.bind(0,r)).map(T.bind(0,P,a));y.each(function(t,e){return o.extendFlat(t,O[e])});var z=y.selectAll(".gl-canvas").each(function(t){t.viewModel=O[0],t.model=t.viewModel?t.viewModel.model:null}),I=null;z.filter(function(t){return t.pick}).style("pointer-events","auto").on("mousemove",function(t){if(P.linePickActive()&&t.lineLayer&&a&&a.hover){var e=n.event,r=this.width,i=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=i)return;var c=t.lineLayer.readPixel(s,i-1-l),u=0!==c[3],h=u?c[2]+256*(c[1]+256*c[0]):null,f={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==I&&(u?a.hover(f):a.unhover&&a.unhover(f),I=h)}}),z.style("opacity",function(t){return t.pick?0:1}),u.style("background","rgba(255, 255, 255, 0)");var D=u.selectAll("."+g.cn.parcoords).data(O,h);D.exit().remove(),D.enter().append("g").classed(g.cn.parcoords,!0).style("shape-rendering","crispEdges").style("pointer-events","none"),D.attr("transform",function(t){return"translate("+t.model.translateX+","+t.model.translateY+")"});var R=D.selectAll("."+g.cn.parcoordsControlView).data(f,h);R.enter().append("g").classed(g.cn.parcoordsControlView,!0),R.attr("transform",function(t){return"translate("+t.model.pad.l+","+t.model.pad.t+")"});var F=R.selectAll("."+g.cn.yAxis).data(function(t){return t.dimensions},h);F.enter().append("g").classed(g.cn.yAxis,!0),R.each(function(t){S(F,t)}),z.each(function(t){if(t.viewModel){!t.lineLayer||a?t.lineLayer=m(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||a;t.lineLayer.render(t.viewModel.panels,e)}}),F.attr("transform",function(t){return"translate("+t.xScale(t.xIndex)+", 0)"}),F.call(n.behavior.drag().origin(function(t){return t}).on("drag",function(t){var e=t.parent;P.linePickActive(!1),t.x=Math.max(-g.overdrag,Math.min(t.model.width+g.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,F.sort(function(t,e){return t.x-e.x}).each(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio}),S(F,e),F.filter(function(e){return 0!==Math.abs(t.xIndex-e.xIndex)}).attr("transform",function(t){return"translate("+t.xScale(t.xIndex)+", 0)"}),n.select(this).attr("transform","translate("+t.x+", 0)"),F.each(function(r,n,a){a===t.parent.key&&(e.dimensions[n]=r)}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)}).on("dragend",function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,S(F,e),n.select(this).attr("transform",function(t){return"translate("+t.x+", 0)"}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),P.linePickActive(!0),a&&a.axesMoved&&a.axesMoved(e.key,e.dimensions.map(function(t){return t.crossfilterDimensionIndex}))})),F.exit().remove();var B=F.selectAll("."+g.cn.axisOverlays).data(f,h);B.enter().append("g").classed(g.cn.axisOverlays,!0),B.selectAll("."+g.cn.axis).remove();var N=B.selectAll("."+g.cn.axis).data(f,h);N.enter().append("g").classed(g.cn.axis,!0),N.each(function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,a=r.domain();n.select(this).call(n.svg.axis().orient("left").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?a:null).tickFormat(function(e){return d.isOrdinal(t)?e:E(t.model.dimensions[t.visibleIndex],e)}).scale(r)),l.font(N.selectAll("text"),t.model.tickFont)}),N.selectAll(".domain, .tick>line").attr("fill","none").attr("stroke","black").attr("stroke-opacity",.25).attr("stroke-width","1px"),N.selectAll("text").style("text-shadow","1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff").style("cursor","default").style("user-select","none");var j=B.selectAll("."+g.cn.axisHeading).data(f,h);j.enter().append("g").classed(g.cn.axisHeading,!0);var V=j.selectAll("."+g.cn.axisTitle).data(f,h);V.enter().append("text").classed(g.cn.axisTitle,!0).attr("text-anchor","middle").style("cursor","ew-resize").style("user-select","none").style("pointer-events","auto"),V.text(function(t){return t.label}).each(function(e){var r=n.select(this);l.font(r,e.model.labelFont),s.convertToTspans(r,t)}).attr("transform",function(t){var e=M(t.model.labelAngle,t.model.labelSide),r=g.axisTitleOffset;return(e.dir>0?"":"translate(0,"+(2*r+t.model.height)+")")+"rotate("+e.degrees+")translate("+-r*e.dx+","+-r*e.dy+")"}).attr("text-anchor",function(t){var e=M(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?"start":"end":"middle"});var U=B.selectAll("."+g.cn.axisExtent).data(f,h);U.enter().append("g").classed(g.cn.axisExtent,!0);var q=U.selectAll("."+g.cn.axisExtentTop).data(f,h);q.enter().append("g").classed(g.cn.axisExtentTop,!0),q.attr("transform","translate(0,"+-g.axisExtentOffset+")");var H=q.selectAll("."+g.cn.axisExtentTopText).data(f,h);H.enter().append("text").classed(g.cn.axisExtentTopText,!0).call(A),H.text(function(t){return L(t,!0)}).each(function(t){l.font(n.select(this),t.model.rangeFont)});var G=U.selectAll("."+g.cn.axisExtentBottom).data(f,h);G.enter().append("g").classed(g.cn.axisExtentBottom,!0),G.attr("transform",function(t){return"translate(0,"+(t.model.height+g.axisExtentOffset)+")"});var Y=G.selectAll("."+g.cn.axisExtentBottomText).data(f,h);Y.enter().append("text").classed(g.cn.axisExtentBottomText,!0).attr("dy","0.75em").call(A),Y.text(function(t){return L(t,!1)}).each(function(t){l.font(n.select(this),t.model.rangeFont)}),v.ensureAxisBrush(B)}},{"../../components/colorscale":603,"../../components/drawing":612,"../../lib":716,"../../lib/gup":714,"../../lib/svg_text_utils":740,"../../plots/cartesian/axes":764,"./axisbrush":1081,"./constants":1084,"./helpers":1086,"./lines":1088,"color-rgba":123,d3:164}],1091:[function(t,e,r){"use strict";var n=t("./parcoords"),a=t("../../lib/prepare_regl"),i=t("./helpers").isVisible;function o(t,e,r){var n=e.indexOf(r),a=t.indexOf(n);return-1===a&&(a+=e.length),a}e.exports=function(t,e){var r=t._fullLayout;if(a(t)){var s={},l={},c={},u={},h=r._size;e.forEach(function(e,r){var n=e[0].trace;c[r]=n.index;var a=u[r]=n._fullInput.index;s[r]=t.data[a].dimensions,l[r]=t.data[a].dimensions.slice()});n(t,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,a){var i=l[e][n],o=a.map(function(t){return t.slice()}),s="dimensions["+n+"].constraintrange",h=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===h[s]){var f=i.constraintrange;h[s]=f||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),i.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete i.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit("plotly_restyle",[d,[u[e]]])},hover:function(e){t.emit("plotly_hover",e)},unhover:function(e){t.emit("plotly_unhover",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(i));s[e].sort(n),l[e].filter(function(t){return!i(t)}).sort(function(t){return l[e].indexOf(t)}).forEach(function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)}),t.emit("plotly_restyle",[{dimensions:[s[e]]},[u[e]]])}})}}},{"../../lib/prepare_regl":729,"./helpers":1086,"./parcoords":1090}],1092:[function(t,e,r){"use strict";var n=t("../../plots/attributes"),a=t("../../plots/domain").attributes,i=t("../../plots/font_attributes"),o=t("../../components/color/attributes"),s=t("../../plots/template_attributes").hovertemplateAttrs,l=t("../../plots/template_attributes").texttemplateAttrs,c=t("../../lib/extend").extendFlat,u=i({editType:"plot",arrayOk:!0,colorEditType:"plot"});e.exports={labels:{valType:"data_array",editType:"calc"},label0:{valType:"number",dflt:0,editType:"calc"},dlabel:{valType:"number",dflt:1,editType:"calc"},values:{valType:"data_array",editType:"calc"},marker:{colors:{valType:"data_array",editType:"calc"},line:{color:{valType:"color",dflt:o.defaultLine,arrayOk:!0,editType:"style"},width:{valType:"number",min:0,dflt:0,arrayOk:!0,editType:"style"},editType:"calc"},editType:"calc"},text:{valType:"data_array",editType:"plot"},hovertext:{valType:"string",dflt:"",arrayOk:!0,editType:"style"},scalegroup:{valType:"string",dflt:"",editType:"calc"},textinfo:{valType:"flaglist",flags:["label","text","value","percent"],extras:["none"],editType:"calc"},hoverinfo:c({},n.hoverinfo,{flags:["label","text","value","percent","name"]}),hovertemplate:s({},{keys:["label","color","value","percent","text"]}),texttemplate:l({editType:"plot"},{keys:["label","color","value","percent","text"]}),textposition:{valType:"enumerated",values:["inside","outside","auto","none"],dflt:"auto",arrayOk:!0,editType:"plot"},textfont:c({},u,{}),insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),automargin:{valType:"boolean",dflt:!1,editType:"plot"},title:{text:{valType:"string",dflt:"",editType:"plot"},font:c({},u,{}),position:{valType:"enumerated",values:["top left","top center","top right","middle center","bottom left","bottom center","bottom right"],editType:"plot"},editType:"plot"},domain:a({name:"pie",trace:!0,editType:"calc"}),hole:{valType:"number",min:0,max:1,dflt:0,editType:"calc"},sort:{valType:"boolean",dflt:!0,editType:"calc"},direction:{valType:"enumerated",values:["clockwise","counterclockwise"],dflt:"counterclockwise",editType:"calc"},rotation:{valType:"number",min:-360,max:360,dflt:0,editType:"calc"},pull:{valType:"number",min:0,max:1,dflt:0,arrayOk:!0,editType:"calc"},_deprecated:{title:{valType:"string",dflt:"",editType:"calc"},titlefont:c({},u,{}),titleposition:{valType:"enumerated",values:["top left","top center","top right","middle center","bottom left","bottom center","bottom right"],editType:"calc"}}}},{"../../components/color/attributes":590,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/domain":789,"../../plots/font_attributes":790,"../../plots/template_attributes":840}],1093:[function(t,e,r){"use strict";var n=t("../../plots/plots");r.name="pie",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{"../../plots/plots":825}],1094:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib").isArrayOrTypedArray,i=t("tinycolor2"),o=t("../../components/color"),s={};function l(t){return function(e,r){return!!e&&(!!(e=i(e)).isValid()&&(e=o.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function c(t,e){var r,n=JSON.stringify(t),a=e[n];if(!a){for(a=t.slice(),r=0;r<t.length;r++)a.push(i(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)a.push(i(t[r]).darken(20).toHexString());e[n]=a}return a}e.exports={calc:function(t,e){var r,i,o=[],s=t._fullLayout,c=s.hiddenlabels||[],u=e.labels,h=e.marker.colors||[],f=e.values,p=a(f)&&f.length;if(e.dlabel)for(u=new Array(f.length),r=0;r<f.length;r++)u[r]=String(e.label0+r*e.dlabel);var d={},g=l(s["_"+e.type+"colormap"]),v=(p?f:u).length,m=0,y=!1;for(r=0;r<v;r++){var x,b,_;if(p){if(x=f[r],!n(x))continue;if((x=+x)<0)continue}else x=1;void 0!==(b=u[r])&&""!==b||(b=r);var w=d[b=String(b)];void 0===w?(d[b]=o.length,(_=-1!==c.indexOf(b))||(m+=x),o.push({v:x,label:b,color:g(h[r],b),i:r,pts:[r],hidden:_})):(y=!0,(i=o[w]).v+=x,i.pts.push(r),i.hidden||(m+=x),!1===i.color&&h[r]&&(i.color=g(h[r],b)))}return("funnelarea"===e.type?y:e.sort)&&o.sort(function(t,e){return e.v-t.v}),o[0]&&(o[0].vTotal=m),o},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r="pie");var n=t._fullLayout,a=t.calcdata,i=n[r+"colorway"],o=n["_"+r+"colormap"];n["extend"+r+"colors"]&&(i=c(i,s));for(var l=0,u=0;u<a.length;u++){var h=a[u];if(h[0].trace.type===r)for(var f=0;f<h.length;f++){var p=h[f];!1===p.color&&(o[p.label]?p.color=o[p.label]:(o[p.label]=p.color=i[l%i.length],l++))}}},makePullColorFn:l,generateExtendedColors:c}},{"../../components/color":591,"../../lib":716,"fast-isnumeric":227,tinycolor2:535}],1095:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../plots/domain").defaults,o=t("../bar/defaults").handleText;e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}var c,u=l("values"),h=n.isArrayOrTypedArray(u),f=l("labels");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l("label0"),l("dlabel")),c){e._length=c,l("marker.line.width")&&l("marker.line.color"),l("marker.colors"),l("scalegroup");var p,d=l("text"),g=l("texttemplate");if(g||(p=l("textinfo",Array.isArray(d)?"text+percent":"percent")),l("hovertext"),l("hovertemplate"),g||p&&"none"!==p){var v=l("textposition");o(t,e,s,l,v,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),(Array.isArray(v)||"auto"===v||"outside"===v)&&l("automargin")}i(e,s,l);var m=l("hole");if(l("title.text")){var y=l("title.position",m?"middle center":"top center");m||"middle center"!==y||(e.title.position="top center"),n.coerceFont(l,"title.font",s.font)}l("sort"),l("direction"),l("rotation"),l("pull")}else e.visible=!1}},{"../../lib":716,"../../plots/domain":789,"../bar/defaults":859,"./attributes":1092}],1096:[function(t,e,r){"use strict";var n=t("../../components/fx/helpers").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),"funnelarea"===e.type&&(delete r.v,delete r.i),r}},{"../../components/fx/helpers":626}],1097:[function(t,e,r){"use strict";var n=t("../../lib");r.formatPiePercent=function(t,e){var r=(100*t).toPrecision(3);return-1!==r.lastIndexOf(".")&&(r=r.replace(/[.]?0+$/,"")),n.numSeparate(r,e)+"%"},r.formatPieValue=function(t,e){var r=t.toPrecision(10);return-1!==r.lastIndexOf(".")&&(r=r.replace(/[.]?0+$/,"")),n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n||""===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{"../../lib":716}],1098:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),supplyLayoutDefaults:t("./layout_defaults"),layoutAttributes:t("./layout_attributes"),calc:t("./calc").calc,crossTraceCalc:t("./calc").crossTraceCalc,plot:t("./plot").plot,style:t("./style"),styleOne:t("./style_one"),moduleType:"trace",name:"pie",basePlotModule:t("./base_plot"),categories:["pie-like","pie","showLegend"],meta:{}}},{"./attributes":1092,"./base_plot":1093,"./calc":1094,"./defaults":1095,"./layout_attributes":1099,"./layout_defaults":1100,"./plot":1101,"./style":1102,"./style_one":1103}],1099:[function(t,e,r){"use strict";e.exports={hiddenlabels:{valType:"data_array",editType:"calc"},piecolorway:{valType:"colorlist",editType:"calc"},extendpiecolors:{valType:"boolean",dflt:!0,editType:"calc"}}},{}],1100:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r("hiddenlabels"),r("piecolorway",e.colorway),r("extendpiecolors")}},{"../../lib":716,"./layout_attributes":1099}],1101:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../plots/plots"),i=t("../../components/fx"),o=t("../../components/color"),s=t("../../components/drawing"),l=t("../../lib"),c=t("../../lib/svg_text_utils"),u=t("./helpers"),h=t("./event_data"),f=t("../../lib").isValidTextValue;function p(t,e,r){var a=r[0],o=a.trace,s=a.cx,c=a.cy;"_hasHoverLabel"in o||(o._hasHoverLabel=!1),"_hasHoverEvent"in o||(o._hasHoverEvent=!1),t.on("mouseover",function(t){var r=e._fullLayout,f=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var p=f.hoverinfo;if(Array.isArray(p)&&(p=i.castHoverinfo({hoverinfo:[u.castOption(p,t.pts)],_module:o._module},r,0)),"all"===p&&(p="label+text+value+percent+name"),f.hovertemplate||"none"!==p&&"skip"!==p&&p){var d=t.rInscribed||0,g=s+t.pxmid[0]*(1-d),v=c+t.pxmid[1]*(1-d),m=r.separators,y=[];if(p&&-1!==p.indexOf("label")&&y.push(t.label),t.text=u.castOption(f.hovertext||f.text,t.pts),p&&-1!==p.indexOf("text")){var x=t.text;l.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=u.formatPieValue(t.v,m),p&&-1!==p.indexOf("value")&&y.push(t.valueLabel),t.percent=t.v/a.vTotal,t.percentLabel=u.formatPiePercent(t.percent,m),p&&-1!==p.indexOf("percent")&&y.push(t.percentLabel);var b=f.hoverlabel,_=b.font;i.loneHover({trace:o,x0:g-d*a.r,x1:g+d*a.r,y:v,text:y.join("<br>"),name:f.hovertemplate||-1!==p.indexOf("name")?f.name:void 0,idealAlign:t.pxmid[0]<0?"left":"right",color:u.castOption(b.bgcolor,t.pts)||t.color,borderColor:u.castOption(b.bordercolor,t.pts),fontFamily:u.castOption(_.family,t.pts),fontSize:u.castOption(_.size,t.pts),fontColor:u.castOption(_.color,t.pts),nameLength:u.castOption(b.namelength,t.pts),textAlign:u.castOption(b.align,t.pts),hovertemplate:u.castOption(f.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[h(t,f)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit("plotly_hover",{points:[h(t,f)],event:n.event})}}),t.on("mouseout",function(t){var r=e._fullLayout,a=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit("plotly_unhover",{points:[h(s,a)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(i.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)}),t.on("click",function(t){var r=e._fullLayout,a=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[h(t,a)],i.click(e,n.event))})}function d(t,e,r){var n=u.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=u.castOption(t._input.textfont.color,e.pts));var a=u.castOption(t.insidetextfont.family,e.pts)||u.castOption(t.textfont.family,e.pts)||r.family,i=u.castOption(t.insidetextfont.size,e.pts)||u.castOption(t.textfont.size,e.pts)||r.size;return{color:n||o.contrast(e.color),family:a,size:i}}function g(t,e){for(var r,n,a=0;a<t.length;a++)if((n=(r=t[a][0]).trace).title.text){var i=n.title.text;n._meta&&(i=l.templateString(i,n._meta));var o=s.tester.append("text").attr("data-notex",1).text(i).call(s.font,n.title.font).call(c.convertToTspans,e),u=s.bBox(o.node(),!0);r.titleBox={width:u.width,height:u.height},o.remove()}}function v(t,e,r){var n=Math.sqrt(t.width*t.width+t.height*t.height),a=t.width/t.height,i=e.halfangle,o=e.ring,s=e.rInscribed,l=r.r||e.rpx1,c={scale:s*l*2/n,rCenter:1-s,rotate:0};if(c.scale>=1)return c;var u=a+1/(2*Math.tan(i)),h=l*Math.min(1/(Math.sqrt(u*u+.5)+u),o/(Math.sqrt(a*a+o/2)+a)),f={scale:2*h/t.height,rCenter:Math.cos(h/l)-h*a/l,rotate:(180/Math.PI*e.midangle+720)%180-90},p=1/a,d=p+1/(2*Math.tan(i)),g=l*Math.min(1/(Math.sqrt(d*d+.5)+d),o/(Math.sqrt(p*p+o/2)+p)),v={scale:2*g/t.width,rCenter:Math.cos(g/l)-g/a/l,rotate:(180/Math.PI*e.midangle+810)%180-90},m=v.scale>f.scale?v:f;return c.scale<1&&m.scale>c.scale?m:c}function m(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function y(t,e){var r=e.pxmid[0],n=e.pxmid[1],a=t.width/2,i=t.height/2;return r<0&&(a*=-1),n<0&&(i*=-1),{scale:1,rCenter:1,rotate:0,x:a+Math.abs(i)*(a>0?1:-1)/2,y:i/(1+r*r/(n*n)),outside:!0}}function x(t,e){var r,n,a,i=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=i.title.font.size,a=_(i),-1!==i.title.position.indexOf("top")?(o.y-=(1+a)*t.r,s.ty-=t.titleBox.height):-1!==i.title.position.indexOf("bottom")&&(o.y+=(1+a)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),h=e.w*(i.domain.x[1]-i.domain.x[0])/2;return-1!==i.title.position.indexOf("left")?(h+=u,o.x-=(1+a)*u,s.tx+=t.titleBox.width/2):-1!==i.title.position.indexOf("center")?h*=2:-1!==i.title.position.indexOf("right")&&(h+=u,o.x+=(1+a)*u,s.tx-=t.titleBox.width/2),r=h/t.titleBox.width,n=b(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function b(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function _(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function w(t,e){for(var r=[],n=0;n<t.length;n++){var a=t[n][0],i=a.trace,o=i.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);i.title.text&&"middle center"!==i.title.position&&(l-=b(a,e));var c=s/2,u=l/2;"funnelarea"!==i.type||i.scalegroup||(u/=i.aspectratio),a.r=Math.min(c,u)/(1+_(i)),a.cx=e.l+e.w*(i.domain.x[1]+i.domain.x[0])/2,a.cy=e.t+e.h*(1-i.domain.y[0])-l/2,i.title.text&&-1!==i.title.position.indexOf("bottom")&&(a.cy-=b(a,e)),i.scalegroup&&-1===r.indexOf(i.scalegroup)&&r.push(i.scalegroup)}!function(t,e){for(var r,n,a,i=0;i<e.length;i++){var o=1/0,s=e[i];for(n=0;n<t.length;n++)if(r=t[n][0],(a=r.trace).scalegroup===s){var l;if("pie"===a.type)l=r.r*r.r;else if("funnelarea"===a.type){var c,u;a.aspectratio>1?(c=r.r,u=c/a.aspectratio):(u=r.r,c=u*a.aspectratio),c*=(1+a.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(a=r.trace).scalegroup===s){var h=o*r.vTotal;"funnelarea"===a.type&&(h/=(1+a.baseratio)/2,h/=a.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}function k(t,e,r){var n=t._fullLayout,a=r.trace,i=a.texttemplate,o=a.textinfo;if(!i&&o&&"none"!==o){var s,c=o.split("+"),h=function(t){return-1!==c.indexOf(t)},p=h("label"),d=h("text"),g=h("value"),v=h("percent"),m=n.separators;if(s=p?[e.label]:[],d){var y=u.getFirstFilled(a.text,e.pts);f(y)&&s.push(y)}g&&s.push(u.formatPieValue(e.v,m)),v&&s.push(u.formatPiePercent(e.v/r.vTotal,m)),e.text=s.join("<br>")}if(i){var x=l.castOption(a,e.i,"texttemplate");if(x){var b=function(t){return{label:t.label,value:t.v,valueLabel:u.formatPieValue(t.v,n.separators),percent:t.v/r.vTotal,percentLabel:u.formatPiePercent(t.v/r.vTotal,n.separators),color:t.color,text:t.text,customdata:l.castOption(a,t.i,"customdata")}}(e),_=u.getFirstFilled(a.text,e.pts);(f(_)||""===_)&&(b.text=_),e.text=l.texttemplateString(x,b,t._fullLayout._d3locale,b,a._meta||{})}else e.text=""}}e.exports={plot:function(t,e){var r=t._fullLayout,i=r._size;g(e,t),w(e,i);var h=l.makeTraceGroups(r._pielayer,e,"trace").each(function(e){var r=n.select(this),h=e[0],f=h.trace;!function(t){var e,r,n,a=t[0],i=a.trace,o=i.rotation*Math.PI/180,s=2*Math.PI/a.vTotal,l="px0",c="px1";if("counterclockwise"===i.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;o+=s*t[e].v,s*=-1,l="px1",c="px0"}function u(t){return[a.r*Math.sin(t),-a.r*Math.cos(t)]}for(n=u(o),e=0;e<t.length;e++)(r=t[e]).hidden||(r[l]=n,o+=s*r.v/2,r.pxmid=u(o),r.midangle=o,o+=s*r.v/2,n=u(o),r[c]=n,r.largeArc=r.v>a.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/a.vTotal,.5),r.ring=1-i.hole,r.rInscribed=m(r,a))}(e),r.attr("stroke-linejoin","round"),r.each(function(){var g=n.select(this).selectAll("g.slice").data(e);g.enter().append("g").classed("slice",!0),g.exit().remove();var m=[[[],[]],[[],[]]],b=!1;g.each(function(r){if(r.hidden)n.select(this).selectAll("path,g").remove();else{r.pointNumber=r.i,r.curveNumber=f.index,m[r.pxmid[1]<0?0:1][r.pxmid[0]<0?0:1].push(r);var a=h.cx,i=h.cy,o=n.select(this),g=o.selectAll("path.surface").data([r]);if(g.enter().append("path").classed("surface",!0).style({"pointer-events":"all"}),o.call(p,t,e),f.pull){var x=+u.castOption(f.pull,r.pts)||0;x>0&&(a+=x*r.pxmid[0],i+=x*r.pxmid[1])}r.cxFinal=a,r.cyFinal=i;var _=f.hole;if(r.v===h.vTotal){var w="M"+(a+r.px0[0])+","+(i+r.px0[1])+E(r.px0,r.pxmid,!0,1)+E(r.pxmid,r.px0,!0,1)+"Z";_?g.attr("d","M"+(a+_*r.px0[0])+","+(i+_*r.px0[1])+E(r.px0,r.pxmid,!1,_)+E(r.pxmid,r.px0,!1,_)+"Z"+w):g.attr("d",w)}else{var T=E(r.px0,r.px1,!0,1);if(_){var A=1-_;g.attr("d","M"+(a+_*r.px1[0])+","+(i+_*r.px1[1])+E(r.px1,r.px0,!1,_)+"l"+A*r.px0[0]+","+A*r.px0[1]+T+"Z")}else g.attr("d","M"+a+","+i+"l"+r.px0[0]+","+r.px0[1]+T+"Z")}k(t,r,h);var M=u.castOption(f.textposition,r.pts),S=o.selectAll("g.slicetext").data(r.text&&"none"!==M?[0]:[]);S.enter().append("g").classed("slicetext",!0),S.exit().remove(),S.each(function(){var e=l.ensureSingle(n.select(this),"text","",function(t){t.attr("data-notex",1)});e.text(r.text).attr({class:"slicetext",transform:"","text-anchor":"middle"}).call(s.font,"outside"===M?function(t,e,r){var n=u.castOption(t.outsidetextfont.color,e.pts)||u.castOption(t.textfont.color,e.pts)||r.color,a=u.castOption(t.outsidetextfont.family,e.pts)||u.castOption(t.textfont.family,e.pts)||r.family,i=u.castOption(t.outsidetextfont.size,e.pts)||u.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:a,size:i}}(f,r,t._fullLayout.font):d(f,r,t._fullLayout.font)).call(c.convertToTspans,t);var o,p=s.bBox(e.node());"outside"===M?o=y(p,r):(o=v(p,r,h),"auto"===M&&o.scale<1&&(e.call(s.font,f.outsidetextfont),f.outsidetextfont.family===f.insidetextfont.family&&f.outsidetextfont.size===f.insidetextfont.size||(p=s.bBox(e.node())),o=y(p,r)));var g=a+r.pxmid[0]*o.rCenter+(o.x||0),m=i+r.pxmid[1]*o.rCenter+(o.y||0);o.outside&&(r.yLabelMin=m-p.height/2,r.yLabelMid=m,r.yLabelMax=m+p.height/2,r.labelExtraX=0,r.labelExtraY=0,b=!0),e.attr("transform","translate("+g+","+m+")"+(o.scale<1?"scale("+o.scale+")":"")+(o.rotate?"rotate("+o.rotate+")":"")+"translate("+-(p.left+p.right)/2+","+-(p.top+p.bottom)/2+")")})}function E(t,e,n,a){var i=a*(e[0]-t[0]),o=a*(e[1]-t[1]);return"a"+a*h.r+","+a*h.r+" 0 "+r.largeArc+(n?" 1 ":" 0 ")+i+","+o}});var _=n.select(this).selectAll("g.titletext").data(f.title.text?[0]:[]);if(_.enter().append("g").classed("titletext",!0),_.exit().remove(),_.each(function(){var e,r=l.ensureSingle(n.select(this),"text","",function(t){t.attr("data-notex",1)}),a=f.title.text;f._meta&&(a=l.templateString(a,f._meta)),r.text(a).attr({class:"titletext",transform:"","text-anchor":"middle"}).call(s.font,f.title.font).call(c.convertToTspans,t),e="middle center"===f.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(h):x(h,i),r.attr("transform","translate("+e.x+","+e.y+")"+(e.scale<1?"scale("+e.scale+")":"")+"translate("+e.tx+","+e.ty+")")}),b&&function(t,e){var r,n,a,i,o,s,l,c,h,f,p,d,g;function v(t,e){return t.pxmid[1]-e.pxmid[1]}function m(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var a,c,h,p,d,g,v=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,x=t.cyFinal+o(t.px0[1],t.px1[1]),b=v-m;if(b*l>0&&(t.labelExtraY=b),Array.isArray(e.pull))for(c=0;c<f.length;c++)(h=f[c])===t||(u.castOption(e.pull,t.pts)||0)>=(u.castOption(e.pull,h.pts)||0)||((t.pxmid[1]-h.pxmid[1])*l>0?(p=h.cyFinal+o(h.px0[1],h.px1[1]),(b=p-m-t.labelExtraY)*l>0&&(t.labelExtraY+=b)):(y+t.labelExtraY-x)*l>0&&(a=3*s*Math.abs(c-f.indexOf(t)),d=h.cxFinal+i(h.px0[0],h.px1[0]),(g=d+a-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=g)))}for(n=0;n<2;n++)for(a=n?v:m,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(i=r?Math.max:Math.min,s=r?1:-1,(c=t[n][r]).sort(a),h=t[1-n][r],f=h.concat(c),d=[],p=0;p<c.length;p++)void 0!==c[p].yLabelMid&&d.push(c[p]);for(g=!1,p=0;n&&p<h.length;p++)if(void 0!==h[p].yLabelMid){g=h[p];break}for(p=0;p<d.length;p++){var x=p&&d[p-1];g&&!p&&(x=g),y(d[p],x)}}}(m,f),function(t,e){t.each(function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var a=r.select("g.slicetext text");a.attr("transform","translate("+t.labelExtraX+","+t.labelExtraY+")"+a.attr("transform"));var i=t.cxFinal+t.pxmid[0],s=t.cyFinal+t.pxmid[1],c="M"+i+","+s,u=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var h=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(h)>Math.abs(f)?c+="l"+f*t.pxmid[0]/t.pxmid[1]+","+f+"H"+(i+t.labelExtraX+u):c+="l"+t.labelExtraX+","+h+"v"+(f-h)+"h"+u}else c+="V"+(t.yLabelMid+t.labelExtraY)+"h"+u;l.ensureSingle(r,"path","textline").call(o.stroke,e.outsidetextfont.color).attr({"stroke-width":Math.min(2,e.outsidetextfont.size/8),d:c,fill:"none"})}else r.select("path.textline").remove()})}(g,f),b&&f.automargin){var w=s.bBox(r.node()),T=f.domain,A=i.w*(T.x[1]-T.x[0]),M=i.h*(T.y[1]-T.y[0]),S=(.5*A-h.r)/i.w,E=(.5*M-h.r)/i.h;a.autoMargin(t,"pie."+f.uid+".automargin",{xl:T.x[0]-S,xr:T.x[1]+S,yb:T.y[0]-E,yt:T.y[1]+E,l:Math.max(h.cx-h.r-w.left,0),r:Math.max(w.right-(h.cx+h.r),0),b:Math.max(w.bottom-(h.cy+h.r),0),t:Math.max(h.cy-h.r-w.top,0),pad:5})}})});setTimeout(function(){h.selectAll("tspan").each(function(){var t=n.select(this);t.attr("dy")&&t.attr("dy",t.attr("dy"))})},0)},formatSliceLabel:k,transformInsideText:v,determineInsideTextFont:d,positionTitleOutside:x,prerenderTitles:g,layoutAreas:w,attachFxHandlers:p}},{"../../components/color":591,"../../components/drawing":612,"../../components/fx":629,"../../lib":716,"../../lib/svg_text_utils":740,"../../plots/plots":825,"./event_data":1096,"./helpers":1097,d3:164}],1102:[function(t,e,r){"use strict";var n=t("d3"),a=t("./style_one");e.exports=function(t){t._fullLayout._pielayer.selectAll(".trace").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll("path.surface").each(function(t){n.select(this).call(a,t,e)})})}},{"./style_one":1103,d3:164}],1103:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("./helpers").castOption;e.exports=function(t,e,r){var i=r.marker.line,o=a(i.color,e.pts)||n.defaultLine,s=a(i.width,e.pts)||0;t.style("stroke-width",s).call(n.fill,e.color).call(n.stroke,o)}},{"../../components/color":591,"./helpers":1097}],1104:[function(t,e,r){"use strict";var n=t("../scatter/attributes");e.exports={x:n.x,y:n.y,xy:{valType:"data_array",editType:"calc"},indices:{valType:"data_array",editType:"calc"},xbounds:{valType:"data_array",editType:"calc"},ybounds:{valType:"data_array",editType:"calc"},text:n.text,marker:{color:{valType:"color",arrayOk:!1,editType:"calc"},opacity:{valType:"number",min:0,max:1,dflt:1,arrayOk:!1,editType:"calc"},blend:{valType:"boolean",dflt:null,editType:"calc"},sizemin:{valType:"number",min:.1,max:2,dflt:.5,editType:"calc"},sizemax:{valType:"number",min:.1,dflt:20,editType:"calc"},border:{color:{valType:"color",arrayOk:!1,editType:"calc"},arearatio:{valType:"number",min:0,max:1,dflt:0,editType:"calc"},editType:"calc"},editType:"calc"},transforms:void 0}},{"../scatter/attributes":1118}],1105:[function(t,e,r){"use strict";var n=t("gl-pointcloud2d"),a=t("../../lib/str2rgbarray"),i=t("../../plots/cartesian/autorange").findExtremes,o=t("../scatter/get_trace_color");function s(t,e){this.scene=t,this.uid=e,this.type="pointcloud",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color="rgb(0, 0, 0)",this.name="",this.hoverinfo="all",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=a(t.marker.color),v=a(t.marker.border.color),m=t.opacity*t.marker.opacity;g[3]*=m,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,v[3]*=m,this.pointcloudOptions.borderColor=v;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,k=b/2||.5;t._extremes[_._id]=i(_,[d[0],d[2]],{ppad:k}),t._extremes[w._id]=i(w,[d[1],d[3]],{ppad:k})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{"../../lib/str2rgbarray":739,"../../plots/cartesian/autorange":763,"../scatter/get_trace_color":1128,"gl-pointcloud2d":294}],1106:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes");e.exports=function(t,e,r){function i(r,i){return n.coerce(t,e,a,r,i)}i("x"),i("y"),i("xbounds"),i("ybounds"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),i("text"),i("marker.color",r),i("marker.opacity"),i("marker.blend"),i("marker.sizemin"),i("marker.sizemax"),i("marker.border.color",r),i("marker.border.arearatio"),e._length=null}},{"../../lib":716,"./attributes":1104}],1107:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("../scatter3d/calc"),plot:t("./convert"),moduleType:"trace",name:"pointcloud",basePlotModule:t("../../plots/gl2d"),categories:["gl","gl2d","showLegend"],meta:{}}},{"../../plots/gl2d":802,"../scatter3d/calc":1146,"./attributes":1104,"./convert":1105,"./defaults":1106}],1108:[function(t,e,r){"use strict";var n=t("../../plots/font_attributes"),a=t("../../plots/attributes"),i=t("../../components/color/attributes"),o=t("../../components/fx/attributes"),s=t("../../plots/domain").attributes,l=t("../../plots/template_attributes").hovertemplateAttrs,c=t("../../components/colorscale/attributes"),u=t("../../plot_api/plot_template").templatedArray,h=t("../../lib/extend").extendFlat,f=t("../../plot_api/edit_types").overrideAll;t("../../constants/docs").FORMAT_LINK;(e.exports=f({hoverinfo:h({},a.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:"sankey",trace:!0}),orientation:{valType:"enumerated",values:["v","h"],dflt:"h"},valueformat:{valType:"string",dflt:".3s"},valuesuffix:{valType:"string",dflt:""},arrangement:{valType:"enumerated",values:["snap","perpendicular","freeform","fixed"],dflt:"snap"},textfont:n({}),node:{label:{valType:"data_array",dflt:[]},groups:{valType:"info_array",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:"number",editType:"calc"}},x:{valType:"data_array",dflt:[]},y:{valType:"data_array",dflt:[]},color:{valType:"color",arrayOk:!0},line:{color:{valType:"color",dflt:i.defaultLine,arrayOk:!0},width:{valType:"number",min:0,dflt:.5,arrayOk:!0}},pad:{valType:"number",arrayOk:!1,min:0,dflt:20},thickness:{valType:"number",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:"enumerated",values:["all","none","skip"],dflt:"all"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:["value","label"]})},link:{label:{valType:"data_array",dflt:[]},color:{valType:"color",arrayOk:!0},line:{color:{valType:"color",dflt:i.defaultLine,arrayOk:!0},width:{valType:"number",min:0,dflt:0,arrayOk:!0}},source:{valType:"data_array",dflt:[]},target:{valType:"data_array",dflt:[]},value:{valType:"data_array",dflt:[]},hoverinfo:{valType:"enumerated",values:["all","none","skip"],dflt:"all"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:["value","label"]}),colorscales:u("concentrationscales",{editType:"calc",label:{valType:"string",editType:"calc",dflt:""},cmax:{valType:"number",editType:"calc",dflt:1},cmin:{valType:"number",editType:"calc",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,"white"],[1,"black"]]})})}},"calc","nested")).transforms=void 0},{"../../components/color/attributes":590,"../../components/colorscale/attributes":598,"../../components/fx/attributes":621,"../../constants/docs":687,"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plot_api/plot_template":754,"../../plots/attributes":761,"../../plots/domain":789,"../../plots/font_attributes":790,"../../plots/template_attributes":840}],1109:[function(t,e,r){"use strict";var n=t("../../plot_api/edit_types").overrideAll,a=t("../../plots/get_data").getModuleCalcData,i=t("./plot"),o=t("../../components/fx/layout_attributes"),s=t("../../lib/setcursor"),l=t("../../components/dragelement"),c=t("../../plots/cartesian/select").prepSelect,u=t("../../lib"),h=t("../../registry");function f(t,e){var r=t._fullData[e],n=t._fullLayout,a=n.dragmode,i="pan"===n.dragmode?"move":"crosshair",o=r._bgRect;if("pan"!==a&&"zoom"!==a){s(o,i);var f={_id:"x",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:"y",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,a=t._fullData[e],i=a.node.groups.slice(),o=[];function s(t){for(var e=a._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);i[c.pointNumber-a.node._count]=!1}else o.push(c.pointNumber)}n=i.filter(Boolean).concat([o]),h.call("_guiRestyle",t,{"node.groups":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,a)}};l.init(d)}}r.name="sankey",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},"plot","nested"),r.plot=function(t){var e=a(t.calcdata,"sankey")[0];i(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var a=n._has&&n._has("sankey"),i=e._has&&e._has("sankey");a&&!i&&(n._paperdiv.selectAll(".sankey").remove(),n._paperdiv.selectAll(".bgsankey").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)f(t,e)}},{"../../components/dragelement":609,"../../components/fx/layout_attributes":630,"../../lib":716,"../../lib/setcursor":736,"../../plot_api/edit_types":747,"../../plots/cartesian/select":781,"../../plots/get_data":799,"../../registry":845,"./plot":1114}],1110:[function(t,e,r){"use strict";var n=t("strongly-connected-components"),a=t("../../lib"),i=t("../../lib/gup").wrap,o=a.isArrayOrTypedArray,s=a.isIndex,l=t("../../components/colorscale");function c(t){var e,r=t.node,i=t.link,c=[],u=o(i.color),h={},f={},p=i.colorscales.length;for(e=0;e<p;e++){var d=i.colorscales[e],g=l.extractScale(d,{cLetter:"c"}),v=l.makeColorScaleFunc(g);f[d.label]=v}var m=0;for(e=0;e<i.value.length;e++)i.source[e]>m&&(m=i.source[e]),i.target[e]>m&&(m=i.target[e]);var y,x=m+1;t.node._count=x;var b=t.node.groups,_={};for(e=0;e<b.length;e++){var w=b[e];for(y=0;y<w.length;y++){var k=w[y],T=x+e;_.hasOwnProperty(k)?a.warn("Node "+k+" is already part of a group."):_[k]=T}}var A={source:[],target:[]};for(e=0;e<i.value.length;e++){var M=i.value[e],S=i.source[e],E=i.target[e];if(M>0&&s(S,x)&&s(E,x)&&(!_.hasOwnProperty(S)||!_.hasOwnProperty(E)||_[S]!==_[E])){_.hasOwnProperty(E)&&(E=_[E]),_.hasOwnProperty(S)&&(S=_[S]),E=+E,h[S=+S]=h[E]=!0;var L="";i.label&&i.label[e]&&(L=i.label[e]);var C=null;L&&f.hasOwnProperty(L)&&(C=f[L]),c.push({pointNumber:e,label:L,color:u?i.color[e]:i.color,concentrationscale:C,source:S,target:E,value:+M}),A.source.push(S),A.target.push(E)}}var P=x+b.length,O=o(r.color),z=[];for(e=0;e<P;e++)if(h[e]){var I=r.label[e];z.push({group:e>x-1,childrenNodes:[],pointNumber:e,label:I,color:O?r.color[e]:r.color})}var D=!1;return function(t,e,r){for(var i=a.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(a.isIndex(e[o],t)&&a.isIndex(r[o],t)){if(e[o]===r[o])return!0;i[e[o]].push(r[o])}return n(i).components.some(function(t){return t.length>1})}(P,A.source,A.target)&&(D=!0),{circular:D,links:c,nodes:z,groups:b,groupLookup:_}}e.exports=function(t,e){var r=c(e);return i({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{"../../components/colorscale":603,"../../lib":716,"../../lib/gup":714,"strongly-connected-components":528}],1111:[function(t,e,r){"use strict";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:"linear",cn:{sankey:"sankey",sankeyLinks:"sankey-links",sankeyLink:"sankey-link",sankeyNodeSet:"sankey-node-set",sankeyNode:"sankey-node",nodeRect:"node-rect",nodeCapture:"node-capture",nodeCentered:"node-entered",nodeLabelGuide:"node-label-guide",nodeLabel:"node-label",nodeLabelTextPath:"node-label-text-path"}}},{}],1112:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../components/color"),o=t("tinycolor2"),s=t("../../plots/domain").defaults,l=t("../../components/fx/hoverlabel_defaults"),c=t("../../plot_api/plot_template"),u=t("../../plots/array_container_defaults");function h(t,e){function r(r,i){return n.coerce(t,e,a.link.colorscales,r,i)}r("label"),r("cmin"),r("cmax"),r("colorscale")}e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,a,r,i)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),g=t.node,v=c.newContainer(e,"node");function m(t,e){return n.coerce(g,v,a.node,t,e)}m("label"),m("groups"),m("x"),m("y"),m("pad"),m("thickness"),m("line.color"),m("line.width"),m("hoverinfo",t.hoverinfo),l(g,v,m,d),m("hovertemplate");var y=f.colorway;m("color",v.label.map(function(t,e){return i.addOpacity(function(t){return y[t%y.length]}(e),.8)}));var x=t.link||{},b=c.newContainer(e,"link");function _(t,e){return n.coerce(x,b,a.link,t,e)}_("label"),_("source"),_("target"),_("value"),_("line.color"),_("line.width"),_("hoverinfo",t.hoverinfo),l(x,b,_,d),_("hovertemplate");var w,k=o(f.paper_bgcolor).getLuminance()<.333?"rgba(255, 255, 255, 0.6)":"rgba(0, 0, 0, 0.2)";_("color",n.repeat(k,b.value.length)),u(x,b,{name:"colorscales",handleItemDefaults:h}),s(e,f,p),p("orientation"),p("valueformat"),p("valuesuffix"),v.x.length&&v.y.length&&(w="freeform"),p("arrangement",w),n.coerceFont(p,"textfont",n.extendFlat({},f.font)),e._length=null}},{"../../components/color":591,"../../components/fx/hoverlabel_defaults":628,"../../lib":716,"../../plot_api/plot_template":754,"../../plots/array_container_defaults":760,"../../plots/domain":789,"./attributes":1108,tinycolor2:535}],1113:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),moduleType:"trace",name:"sankey",basePlotModule:t("./base_plot"),selectPoints:t("./select.js"),categories:["noOpacity"],meta:{}}},{"./attributes":1108,"./base_plot":1109,"./calc":1110,"./defaults":1112,"./plot":1114,"./select.js":1116}],1114:[function(t,e,r){"use strict";var n=t("d3"),a=t("./render"),i=t("../../components/fx"),o=t("../../components/color"),s=t("../../lib"),l=t("./constants").cn,c=s._;function u(t){return""!==t}function h(t,e){return t.filter(function(t){return t.key===e.traceId})}function f(t,e){n.select(t).select("path").style("fill-opacity",e),n.select(t).select("rect").style("fill-opacity",e)}function p(t){n.select(t).select("text.name").style("fill","black")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function v(t,e,r){e&&r&&h(r,e).selectAll("."+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function m(t,e,r){e&&r&&h(r,e).selectAll("."+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var a=n.datum().link.label;n.style("fill-opacity",function(t){if(!t.link.concentrationscale)return.4}),a&&h(e,t).selectAll("."+l.sankeyLink).filter(function(t){return t.link.label===a}).style("fill-opacity",function(t){if(!t.link.concentrationscale)return.4}),r&&h(e,t).selectAll("."+l.sankeyNode).filter(g(t)).call(v)}function x(t,e,r,n){var a=n.datum().link.label;n.style("fill-opacity",function(t){return t.tinyColorAlpha}),a&&h(e,t).selectAll("."+l.sankeyLink).filter(function(t){return t.link.label===a}).style("fill-opacity",function(t){return t.tinyColorAlpha}),r&&h(e,t).selectAll(l.sankeyNode).filter(g(t)).call(m)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,h=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].visible&&t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,"source:")+" ",w=c(t,"target:")+" ",k=c(t,"concentration:")+" ",T=c(t,"incoming flow count:")+" ",A=c(t,"outgoing flow count:")+" ";a(t,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{linkEvents:{hover:function(e,r,a){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,a,!0)),"skip"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit("plotly_hover",{event:n.event,points:[r.link]})))},follow:function(e,a){if(!1!==t._fullLayout.hovermode){var s=a.link.trace.link;if("none"!==s.hoverinfo&&"skip"!==s.hoverinfo){for(var l=[],c=0,h=0;h<a.flow.links.length;h++){var d=a.flow.links[h];if("closest"!==t._fullLayout.hovermode||a.link.pointNumber===d.pointNumber){a.link.pointNumber===d.pointNumber&&(c=h),d.fullData=d.trace,s=a.link.trace.link;var g=m(d),v={valueLabel:n.format(a.valueFormat)(d.value)+a.valueSuffix};l.push({x:g[0],y:g[1],name:v.valueLabel,text:[d.label||"",_+d.source.label,w+d.target.label,d.concentrationscale?k+n.format("%0.2f")(d.flow.labelConcentration):""].filter(u).join("<br>"),color:b(s,"bgcolor")||o.addOpacity(d.color,1),borderColor:b(s,"bordercolor"),fontFamily:b(s,"font.family"),fontSize:b(s,"font.size"),fontColor:b(s,"font.color"),nameLength:b(s,"namelength"),textAlign:b(s,"align"),idealAlign:n.event.x<g[0]?"right":"left",hovertemplate:s.hovertemplate,hovertemplateLabels:v,eventData:[d]})}}i.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each(function(){a.link.concentrationscale||f(this,.65),p(this)})}}function m(t){var e,r;return t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2+a.parent.translateX,r=t.circularPathData.verticalFullExtent+a.parent.translateY):(e=(t.source.x1+t.target.x0)/2+a.parent.translateX,r=(t.y0+t.y1)/2+a.parent.translateY),[e,r]}},unhover:function(e,a,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,a,o,!0)),"skip"!==a.link.trace.link.hoverinfo&&(a.link.fullData=a.link.trace,t.emit("plotly_unhover",{event:n.event,points:[a.link]})),i.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var a=r.link;a.originalEvent=n.event,t._hoverdata=[a],i.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,a){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,r,a),"skip"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit("plotly_hover",{event:n.event,points:[r.node]})))},follow:function(e,a){if(!1!==t._fullLayout.hovermode){var o=a.node.trace.node;if("none"!==o.hoverinfo&&"skip"!==o.hoverinfo){var s=n.select(e).select("."+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),h=s.node().getBoundingClientRect(),d=h.left-2-c.left,g=h.right+2-c.left,v=h.top+h.height/4-c.top,m={valueLabel:n.format(a.valueFormat)(a.node.value)+a.valueSuffix};a.node.fullData=a.node.trace;var y=i.loneHover({x0:d,x1:g,y:v,name:n.format(a.valueFormat)(a.node.value)+a.valueSuffix,text:[a.node.label,T+a.node.targetLinks.length,A+a.node.sourceLinks.length].filter(u).join("<br>"),color:b(o,"bgcolor")||a.tinyColorHue,borderColor:b(o,"bordercolor"),fontFamily:b(o,"font.family"),fontSize:b(o,"font.size"),fontColor:b(o,"font.color"),nameLength:b(o,"namelength"),textAlign:b(o,"align"),idealAlign:"left",hovertemplate:o.hovertemplate,hovertemplateLabels:m,eventData:[a.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});f(y,.85),p(y)}}},unhover:function(e,a,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,a,o),"skip"!==a.node.trace.node.hoverinfo&&(a.node.fullData=a.node.trace,t.emit("plotly_unhover",{event:n.event,points:[a.node]})),i.loneUnhover(r._hoverlayer.node()))},select:function(e,r,a){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(m,r,a),i.click(t,{target:!0})}}})}},{"../../components/color":591,"../../components/fx":629,"../../lib":716,"./constants":1111,"./render":1115,d3:164}],1115:[function(t,e,r){"use strict";var n=t("./constants"),a=t("d3"),i=t("tinycolor2"),o=t("../../components/color"),s=t("../../components/drawing"),l=t("@plotly/d3-sankey"),c=t("@plotly/d3-sankey-circular"),u=t("d3-force"),h=t("../../lib"),f=t("../../lib/gup"),p=f.keyFun,d=f.repeat,g=f.unwrap,v=t("d3-interpolate").interpolateNumber,m=t("../../registry");function y(){var t=.5;return function(e){if(e.link.circular)return r=e.link,n=r.width/2,a=r.circularPathData,"top"===r.circularLinkType?"M "+a.targetX+" "+(a.targetY+n)+" L"+a.rightInnerExtent+" "+(a.targetY+n)+"A"+(a.rightLargeArcRadius+n)+" "+(a.rightSmallArcRadius+n)+" 0 0 1 "+(a.rightFullExtent-n)+" "+(a.targetY-a.rightSmallArcRadius)+"L"+(a.rightFullExtent-n)+" "+a.verticalRightInnerExtent+"A"+(a.rightLargeArcRadius+n)+" "+(a.rightLargeArcRadius+n)+" 0 0 1 "+a.rightInnerExtent+" "+(a.verticalFullExtent-n)+"L"+a.leftInnerExtent+" "+(a.verticalFullExtent-n)+"A"+(a.leftLargeArcRadius+n)+" "+(a.leftLargeArcRadius+n)+" 0 0 1 "+(a.leftFullExtent+n)+" "+a.verticalLeftInnerExtent+"L"+(a.leftFullExtent+n)+" "+(a.sourceY-a.leftSmallArcRadius)+"A"+(a.leftLargeArcRadius+n)+" "+(a.leftSmallArcRadius+n)+" 0 0 1 "+a.leftInnerExtent+" "+(a.sourceY+n)+"L"+a.sourceX+" "+(a.sourceY+n)+"L"+a.sourceX+" "+(a.sourceY-n)+"L"+a.leftInnerExtent+" "+(a.sourceY-n)+"A"+(a.leftLargeArcRadius-n)+" "+(a.leftSmallArcRadius-n)+" 0 0 0 "+(a.leftFullExtent-n)+" "+(a.sourceY-a.leftSmallArcRadius)+"L"+(a.leftFullExtent-n)+" "+a.verticalLeftInnerExtent+"A"+(a.leftLargeArcRadius-n)+" "+(a.leftLargeArcRadius-n)+" 0 0 0 "+a.leftInnerExtent+" "+(a.verticalFullExtent+n)+"L"+a.rightInnerExtent+" "+(a.verticalFullExtent+n)+"A"+(a.rightLargeArcRadius-n)+" "+(a.rightLargeArcRadius-n)+" 0 0 0 "+(a.rightFullExtent+n)+" "+a.verticalRightInnerExtent+"L"+(a.rightFullExtent+n)+" "+(a.targetY-a.rightSmallArcRadius)+"A"+(a.rightLargeArcRadius-n)+" "+(a.rightSmallArcRadius-n)+" 0 0 0 "+a.rightInnerExtent+" "+(a.targetY-n)+"L"+a.targetX+" "+(a.targetY-n)+"Z":"M "+a.targetX+" "+(a.targetY-n)+" L"+a.rightInnerExtent+" "+(a.targetY-n)+"A"+(a.rightLargeArcRadius+n)+" "+(a.rightSmallArcRadius+n)+" 0 0 0 "+(a.rightFullExtent-n)+" "+(a.targetY+a.rightSmallArcRadius)+"L"+(a.rightFullExtent-n)+" "+a.verticalRightInnerExtent+"A"+(a.rightLargeArcRadius+n)+" "+(a.rightLargeArcRadius+n)+" 0 0 0 "+a.rightInnerExtent+" "+(a.verticalFullExtent+n)+"L"+a.leftInnerExtent+" "+(a.verticalFullExtent+n)+"A"+(a.leftLargeArcRadius+n)+" "+(a.leftLargeArcRadius+n)+" 0 0 0 "+(a.leftFullExtent+n)+" "+a.verticalLeftInnerExtent+"L"+(a.leftFullExtent+n)+" "+(a.sourceY+a.leftSmallArcRadius)+"A"+(a.leftLargeArcRadius+n)+" "+(a.leftSmallArcRadius+n)+" 0 0 0 "+a.leftInnerExtent+" "+(a.sourceY-n)+"L"+a.sourceX+" "+(a.sourceY-n)+"L"+a.sourceX+" "+(a.sourceY+n)+"L"+a.leftInnerExtent+" "+(a.sourceY+n)+"A"+(a.leftLargeArcRadius-n)+" "+(a.leftSmallArcRadius-n)+" 0 0 1 "+(a.leftFullExtent-n)+" "+(a.sourceY+a.leftSmallArcRadius)+"L"+(a.leftFullExtent-n)+" "+a.verticalLeftInnerExtent+"A"+(a.leftLargeArcRadius-n)+" "+(a.leftLargeArcRadius-n)+" 0 0 1 "+a.leftInnerExtent+" "+(a.verticalFullExtent-n)+"L"+a.rightInnerExtent+" "+(a.verticalFullExtent-n)+"A"+(a.rightLargeArcRadius-n)+" "+(a.rightLargeArcRadius-n)+" 0 0 1 "+(a.rightFullExtent+n)+" "+a.verticalRightInnerExtent+"L"+(a.rightFullExtent+n)+" "+(a.targetY+a.rightSmallArcRadius)+"A"+(a.rightLargeArcRadius-n)+" "+(a.rightSmallArcRadius-n)+" 0 0 1 "+a.rightInnerExtent+" "+(a.targetY+n)+"L"+a.targetX+" "+(a.targetY+n)+"Z";var r,n,a,i=e.link.source.x1,o=e.link.target.x0,s=v(i,o),l=s(t),c=s(1-t),u=e.link.y0-e.link.width/2,h=e.link.y0+e.link.width/2,f=e.link.y1-e.link.width/2,p=e.link.y1+e.link.width/2;return"M"+i+","+u+"C"+l+","+u+" "+c+","+f+" "+o+","+f+"L"+o+","+p+"C"+c+","+p+" "+l+","+h+" "+i+","+h+"Z"}}function x(t){t.attr("transform",function(t){return"translate("+t.node.x0.toFixed(3)+", "+t.node.y0.toFixed(3)+")"})}function b(t){t.call(x)}function _(t,e){t.call(b),e.attr("d",y())}function w(t){t.attr("width",function(t){return t.node.x1-t.node.x0}).attr("height",function(t){return t.visibleHeight})}function k(t){return t.link.width>1||t.linkLineWidth>0}function T(t){return"translate("+t.translateX+","+t.translateY+")"+(t.horizontal?"matrix(1 0 0 1 0 0)":"matrix(0 1 1 0 0 0)")}function A(t){return"translate("+(t.horizontal?0:t.labelY)+" "+(t.horizontal?t.labelY:0)+")"}function M(t){return a.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function S(t){return t.horizontal?"matrix(1 0 0 1 0 0)":"matrix(0 1 1 0 0 0)"}function E(t){return t.horizontal?"scale(1 1)":"scale(-1 1)"}function L(t){return t.darkBackground&&!t.horizontal?"rgb(255,255,255)":"rgb(0,0,0)"}function C(t){return t.horizontal&&t.left?"100%":"0%"}function P(t,e,r){t.on(".basic",null).on("mouseover.basic",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])}).on("mousemove.basic",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])}).on("mouseout.basic",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)}).on("click.basic",function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)})}function O(t,e,r,i){var o=a.behavior.drag().origin(function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}}).on("dragstart",function(a){if("fixed"!==a.arrangement&&(h.ensureSingle(i._fullLayout._infolayer,"g","dragcover",function(t){i._fullLayout._dragCover=t}),h.raiseToTop(this),a.interactionState.dragInProgress=a.node,I(a.node),a.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,a.interactionState.hovered),a.interactionState.hovered=!1),"snap"===a.arrangement)){var o=a.traceId+"|"+a.key;a.forceLayouts[o]?a.forceLayouts[o].alpha(1):function(t,e,r,a){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var i=r.graph.nodes.filter(function(t){return t.originalX===r.node.originalX}).filter(function(t){return!t.partOfGroup});r.forceLayouts[e]=u.forceSimulation(i).alphaDecay(0).force("collide",u.forceCollide().radius(function(t){return t.dy/2+r.nodePad/2}).strength(1).iterations(n.forceIterations)).force("constrain",function(t,e,r,a){return function(){for(var t=0,i=0;i<r.length;i++){var o=r[i];o===a.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(a.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!a.interactionState.dragInProgress&&t<.1&&a.forceLayouts[e].alpha()>0&&a.forceLayouts[e].alpha(0)}}(0,e,i,r)).stop()}(0,o,a),function(t,e,r,a,i){window.requestAnimationFrame(function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[a].tick();var l=r.graph.nodes;if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(l),r.sankey.update(r.graph),_(t.filter(D(r)),e),r.forceLayouts[a].alpha()>0)window.requestAnimationFrame(o);else{var c=r.node.originalX;r.node.x0=c-r.visibleWidth/2,r.node.x1=c+r.visibleWidth/2,z(r,i)}})}(t,e,a,o,i)}}).on("drag",function(r){if("fixed"!==r.arrangement){var n=a.event.x,i=a.event.y;"snap"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=i-r.visibleHeight/2,r.node.y1=i+r.visibleHeight/2):("freeform"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),i=Math.max(0,Math.min(r.size-r.visibleHeight/2,i)),r.node.y0=i-r.visibleHeight/2,r.node.y1=i+r.visibleHeight/2),I(r.node),"snap"!==r.arrangement&&(r.sankey.update(r.graph),_(t.filter(D(r)),e))}}).on("dragend",function(t){if("fixed"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;"snap"!==t.arrangement&&z(t,i)}});t.on(".drag",null).call(o)}function z(t,e){for(var r=[],n=[],a=0;a<t.graph.nodes.length;a++){var i=(t.graph.nodes[a].x0+t.graph.nodes[a].x1)/2,o=(t.graph.nodes[a].y0+t.graph.nodes[a].y1)/2;r.push(i/t.figure.width),n.push(o/t.figure.height)}m.call("_guiRestyle",e,{"node.x":[r],"node.y":[n]},t.trace.index).then(function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()})}function I(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function D(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,u,f){var v=!1;h.ensureSingle(t._fullLayout._infolayer,"g","first-render",function(){v=!0});var m=t._fullLayout._dragCover,b=r.filter(function(t){return g(t).trace.visible}).map(function(t,e,r){var a,o=g(e),s=o.trace,u=s.domain,f="h"===s.orientation,p=s.node.pad,d=s.node.thickness,v=t.width*(u.x[1]-u.x[0]),m=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(a=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(f?[v,m]:[m,v]).nodeWidth(d).nodePadding(p).nodeId(function(t){return t.pointNumber}).nodes(y).links(x);var _,w,k,T=a();for(var A in a.nodePadding()<p&&h.warn("node.pad was reduced to ",a.nodePadding()," to fit within the figure."),o._groupLookup){var M,S=parseInt(o._groupLookup[A]);for(_=0;_<T.nodes.length;_++)if(T.nodes[_].pointNumber===S){M=T.nodes[_];break}if(M){var E={pointNumber:parseInt(A),x0:M.x0,x1:M.x1,y0:M.y0,y1:M.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};T.nodes.unshift(E),M.childrenNodes.unshift(E)}}if(function(){for(_=0;_<T.nodes.length;_++){var t,e,r=T.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+":"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var a=Object.keys(n);for(w=0;w<a.length;w++){var o=n[t=a[w]],s=0,l={};for(k=0;k<o.length;k++)l[(e=o[k]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(k=0;k<o.length;k++)(e=o[k]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=i(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,T.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var L=[s.node.x[_]*v,s.node.y[_]*m];T.nodes[_].x0=L[0]-d/2,T.nodes[_].x1=L[0]+d/2;var C=T.nodes[_].y1-T.nodes[_].y0;T.nodes[_].y0=L[1]-C/2,T.nodes[_].y1=L[1]+C/2}"snap"===s.arrangement&&function(t){t.forEach(function(t){var e,r,n,a=0,i=t.length;for(t.sort(function(t,e){return t.y0-e.y0}),n=0;n<i;++n)(e=t[n]).y0>=a||(r=a-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),a=e.y1+p})}(function(t){var e,r,n=t.map(function(t,e){return{x0:t.x0,index:e}}).sort(function(t,e){return t.x0-e.x0}),a=[],i=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(i+=1,e=s.x0),o=s.x0,a[i]||(a[i]=[]),a[i].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return a}(y=T.nodes)),a.update(T)}return{circular:b,key:r,trace:s,guid:h.randstr(),horizontal:f,width:v,height:m,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?m:v,dragPerpendicular:f?v:m,arrangement:s.arrangement,sankey:a,graph:T,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}.bind(null,u)),_=e.selectAll("."+n.cn.sankey).data(b,p);_.exit().remove(),_.enter().append("g").classed(n.cn.sankey,!0).style("box-sizing","content-box").style("position","absolute").style("left",0).style("shape-rendering","geometricPrecision").style("pointer-events","auto").attr("transform",T),_.each(function(e,r){t._fullData[r]._sankey=e;var n="bgsankey-"+e.trace.uid+"-"+r;h.ensureSingle(t._fullLayout._draggers,"rect",n),t._fullData[r]._bgRect=a.select("."+n),t._fullData[r]._bgRect.style("pointer-events","all").attr("width",e.width).attr("height",e.height).attr("x",e.translateX).attr("y",e.translateY).classed("bgsankey",!0).style({fill:"transparent","stroke-width":0})}),_.transition().ease(n.ease).duration(n.duration).attr("transform",T);var z=_.selectAll("."+n.cn.sankeyLinks).data(d,p);z.enter().append("g").classed(n.cn.sankeyLinks,!0).style("fill","none");var I=z.selectAll("."+n.cn.sankeyLink).data(function(t){return t.graph.links.filter(function(t){return t.value}).map(function(t,e,r){var n=i(e.color),a=e.source.label+"|"+e.target.label+"__"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:a,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:y,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}.bind(null,t))},p);I.enter().append("path").classed(n.cn.sankeyLink,!0).call(P,_,f.linkEvents),I.style("stroke",function(t){return k(t)?o.tinyRGB(i(t.linkLineColor)):t.tinyColorHue}).style("stroke-opacity",function(t){return k(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha}).style("fill",function(t){return t.tinyColorHue}).style("fill-opacity",function(t){return t.tinyColorAlpha}).style("stroke-width",function(t){return k(t)?t.linkLineWidth:1}).attr("d",y()),I.style("opacity",function(){return t._context.staticPlot||v||m?1:0}).transition().ease(n.ease).duration(n.duration).style("opacity",1),I.exit().transition().ease(n.ease).duration(n.duration).style("opacity",0).remove();var D=_.selectAll("."+n.cn.sankeyNodeSet).data(d,p);D.enter().append("g").classed(n.cn.sankeyNodeSet,!0),D.style("cursor",function(t){switch(t.arrangement){case"fixed":return"default";case"perpendicular":return"ns-resize";default:return"move"}});var R=D.selectAll("."+n.cn.sankeyNode).data(function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort(function(t,e){return t-e}),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(function(t,e){var r=i(e.color),a=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u="node_"+e.pointNumber;return e.group&&(u=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-a,zoneY:-s,zoneWidth:l+2*a,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join("_"),interactionState:t.interactionState,figure:t}}.bind(null,t))},p);R.enter().append("g").classed(n.cn.sankeyNode,!0).call(x).style("opacity",function(e){return!t._context.staticPlot&&!v||e.partOfGroup?0:1}),R.call(P,_,f.nodeEvents).call(O,I,f,t),R.transition().ease(n.ease).duration(n.duration).call(x).style("opacity",function(t){return t.partOfGroup?0:1}),R.exit().transition().ease(n.ease).duration(n.duration).style("opacity",0).remove();var F=R.selectAll("."+n.cn.nodeRect).data(d);F.enter().append("rect").classed(n.cn.nodeRect,!0).call(w),F.style("stroke-width",function(t){return t.nodeLineWidth}).style("stroke",function(t){return o.tinyRGB(i(t.nodeLineColor))}).style("stroke-opacity",function(t){return o.opacity(t.nodeLineColor)}).style("fill",function(t){return t.tinyColorHue}).style("fill-opacity",function(t){return t.tinyColorAlpha}),F.transition().ease(n.ease).duration(n.duration).call(w);var B=R.selectAll("."+n.cn.nodeCapture).data(d);B.enter().append("rect").classed(n.cn.nodeCapture,!0).style("fill-opacity",0),B.attr("x",function(t){return t.zoneX}).attr("y",function(t){return t.zoneY}).attr("width",function(t){return t.zoneWidth}).attr("height",function(t){return t.zoneHeight});var N=R.selectAll("."+n.cn.nodeCentered).data(d);N.enter().append("g").classed(n.cn.nodeCentered,!0).attr("transform",A),N.transition().ease(n.ease).duration(n.duration).attr("transform",A);var j=N.selectAll("."+n.cn.nodeLabelGuide).data(d);j.enter().append("path").classed(n.cn.nodeLabelGuide,!0).attr("id",function(t){return t.uniqueNodeLabelPathId}).attr("d",M).attr("transform",S),j.transition().ease(n.ease).duration(n.duration).attr("d",M).attr("transform",S);var V=N.selectAll("."+n.cn.nodeLabel).data(d);V.enter().append("text").classed(n.cn.nodeLabel,!0).attr("transform",E).style("user-select","none").style("cursor","default").style("fill","black"),V.style("text-shadow",function(t){return t.horizontal?"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff":"none"}).each(function(t){s.font(V,t.textFont)}),V.transition().ease(n.ease).duration(n.duration).attr("transform",E);var U=V.selectAll("."+n.cn.nodeLabelTextPath).data(d);U.enter().append("textPath").classed(n.cn.nodeLabelTextPath,!0).attr("alignment-baseline","middle").attr("xlink:href",function(t){return"#"+t.uniqueNodeLabelPathId}).attr("startOffset",C).style("fill",L),U.text(function(t){return t.horizontal||t.node.dy>5?t.node.label:""}).attr("text-anchor",function(t){return t.horizontal&&t.left?"end":"start"}),U.transition().ease(n.ease).duration(n.duration).attr("startOffset",C).style("fill",L)}},{"../../components/color":591,"../../components/drawing":612,"../../lib":716,"../../lib/gup":714,"../../registry":845,"./constants":1111,"@plotly/d3-sankey":56,"@plotly/d3-sankey-circular":55,d3:164,"d3-force":157,"d3-interpolate":159,tinycolor2:535}],1116:[function(t,e,r){"use strict";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,a=n._sankey.graph.nodes,i=0;i<a.length;i++){var o=a[i];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];"v"===n.orientation&&s.reverse(),e&&e.contains(s,!1,i,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1117:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,"tx"),n.mergeArray(e.texttemplate,t,"txt"),n.mergeArray(e.hovertext,t,"htx"),n.mergeArray(e.customdata,t,"data"),n.mergeArray(e.textposition,t,"tp"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,"ts"),n.mergeArray(e.textfont.color,t,"tc"),n.mergeArray(e.textfont.family,t,"tf"));var a=e.marker;if(a){n.mergeArrayCastPositive(a.size,t,"ms"),n.mergeArrayCastPositive(a.opacity,t,"mo"),n.mergeArray(a.symbol,t,"mx"),n.mergeArray(a.color,t,"mc");var i=a.line;a.line&&(n.mergeArray(i.color,t,"mlc"),n.mergeArrayCastPositive(i.width,t,"mlw"));var o=a.gradient;o&&"none"!==o.type&&(n.mergeArray(o.type,t,"mgt"),n.mergeArray(o.color,t,"mgc"))}}},{"../../lib":716}],1118:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").texttemplateAttrs,a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../../components/colorscale/attributes"),o=t("../../plots/font_attributes"),s=t("../../components/drawing/attributes").dash,l=t("../../components/drawing"),c=t("./constants"),u=t("../../lib/extend").extendFlat;e.exports={x:{valType:"data_array",editType:"calc+clearAxisTypes",anim:!0},x0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes",anim:!0},dx:{valType:"number",dflt:1,editType:"calc",anim:!0},y:{valType:"data_array",editType:"calc+clearAxisTypes",anim:!0},y0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes",anim:!0},dy:{valType:"number",dflt:1,editType:"calc",anim:!0},stackgroup:{valType:"string",dflt:"",editType:"calc"},orientation:{valType:"enumerated",values:["v","h"],editType:"calc"},groupnorm:{valType:"enumerated",values:["","fraction","percent"],dflt:"",editType:"calc"},stackgaps:{valType:"enumerated",values:["infer zero","interpolate"],dflt:"infer zero",editType:"calc"},text:{valType:"string",dflt:"",arrayOk:!0,editType:"calc"},texttemplate:n({},{}),hovertext:{valType:"string",dflt:"",arrayOk:!0,editType:"style"},mode:{valType:"flaglist",flags:["lines","markers","text"],extras:["none"],editType:"calc"},hoveron:{valType:"flaglist",flags:["points","fills"],editType:"style"},hovertemplate:a({},{keys:c.eventDataKeys}),line:{color:{valType:"color",editType:"style",anim:!0},width:{valType:"number",min:0,dflt:2,editType:"style",anim:!0},shape:{valType:"enumerated",values:["linear","spline","hv","vh","hvh","vhv"],dflt:"linear",editType:"plot"},smoothing:{valType:"number",min:0,max:1.3,dflt:1,editType:"plot"},dash:u({},s,{editType:"style"}),simplify:{valType:"boolean",dflt:!0,editType:"plot"},editType:"plot"},connectgaps:{valType:"boolean",dflt:!1,editType:"calc"},cliponaxis:{valType:"boolean",dflt:!0,editType:"plot"},fill:{valType:"enumerated",values:["none","tozeroy","tozerox","tonexty","tonextx","toself","tonext"],editType:"calc"},fillcolor:{valType:"color",editType:"style",anim:!0},marker:u({symbol:{valType:"enumerated",values:l.symbolList,dflt:"circle",arrayOk:!0,editType:"style"},opacity:{valType:"number",min:0,max:1,arrayOk:!0,editType:"style",anim:!0},size:{valType:"number",min:0,dflt:6,arrayOk:!0,editType:"calc",anim:!0},maxdisplayed:{valType:"number",min:0,dflt:0,editType:"plot"},sizeref:{valType:"number",dflt:1,editType:"calc"},sizemin:{valType:"number",min:0,dflt:0,editType:"calc"},sizemode:{valType:"enumerated",values:["diameter","area"],dflt:"diameter",editType:"calc"},line:u({width:{valType:"number",min:0,arrayOk:!0,editType:"style",anim:!0},editType:"calc"},i("marker.line",{anim:!0})),gradient:{type:{valType:"enumerated",values:["radial","horizontal","vertical","none"],arrayOk:!0,dflt:"none",editType:"calc"},color:{valType:"color",arrayOk:!0,editType:"calc"},editType:"calc"},editType:"calc"},i("marker",{anim:!0})),selected:{marker:{opacity:{valType:"number",min:0,max:1,editType:"style"},color:{valType:"color",editType:"style"},size:{valType:"number",min:0,editType:"style"},editType:"style"},textfont:{color:{valType:"color",editType:"style"},editType:"style"},editType:"style"},unselected:{marker:{opacity:{valType:"number",min:0,max:1,editType:"style"},color:{valType:"color",editType:"style"},size:{valType:"number",min:0,editType:"style"},editType:"style"},textfont:{color:{valType:"color",editType:"style"},editType:"style"},editType:"style"},textposition:{valType:"enumerated",values:["top left","top center","top right","middle left","middle center","middle right","bottom left","bottom center","bottom right"],dflt:"middle center",arrayOk:!0,editType:"calc"},textfont:o({editType:"calc",colorEditType:"style",arrayOk:!0}),r:{valType:"data_array",editType:"calc"},t:{valType:"data_array",editType:"calc"}}},{"../../components/colorscale/attributes":598,"../../components/drawing":612,"../../components/drawing/attributes":611,"../../lib/extend":707,"../../plots/font_attributes":790,"../../plots/template_attributes":840,"./constants":1122}],1119:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../plots/cartesian/axes"),o=t("../../constants/numerical").BADNUM,s=t("./subtypes"),l=t("./colorscale_calc"),c=t("./arrays_to_calcdata"),u=t("./calc_selection");function h(t,e,r,n,a,o,l){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[d(e)]===e.uid,v=(g(e,u,r,n)||{}).orientation,m=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};l&&(y.ppad=x.ppad=l);var b=c<2||a[0]!==a[c-1]||o[0]!==o[c-1];b&&("tozerox"===m||"tonextx"===m&&(p||"h"===v))?y.tozero=!0:(e.error_y||{}).visible||"tonexty"!==m&&"tozeroy"!==m&&(s.hasMarkers(e)||s.hasText(e))||(y.padded=!1,y.ppad=0),b&&("tozeroy"===m||"tonexty"===m&&(p||"v"===v))?x.tozero=!0:"tonextx"!==m&&"tozerox"!==m||(x.padded=!1),h&&(e._extremes[h]=i.findExtremes(r,a,y)),f&&(e._extremes[f]=i.findExtremes(n,o,x))}function f(t,e){if(s.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r="area"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},a.isArrayOrTypedArray(n.size)){var l={type:"linear"};i.setConvert(l);for(var c=l.makeCalcdata(t.marker,"size"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function p(t,e){var r=d(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function d(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?"-"+e:"")}function g(t,e,r,n){var a=t.stackgroup;if(a){var i=e._scatterStackOpts[r._id+n._id][a],o="v"===i.orientation?n:r;return"linear"===o.type||"log"===o.type?i:void 0}}e.exports={calc:function(t,e){var r,s,d,v,m,y,x=t._fullLayout,b=i.getFromId(t,e.xaxis||"x"),_=i.getFromId(t,e.yaxis||"y"),w=b.makeCalcdata(e,"x"),k=_.makeCalcdata(e,"y"),T=e._length,A=new Array(T),M=e.ids,S=g(e,x,b,_),E=!1;p(x,e);var L,C="x",P="y";for(S?(a.pushUnique(S.traceIndices,e._expandedIndex),(r="v"===S.orientation)?(P="s",L="x"):(C="s",L="y"),m="interpolate"===S.stackgaps):h(t,e,b,_,w,k,f(e,T)),s=0;s<T;s++){var O=A[s]={},z=n(w[s]),I=n(k[s]);z&&I?(O[C]=w[s],O[P]=k[s]):S&&(r?z:I)?(O[L]=r?w[s]:k[s],O.gap=!0,m?(O.s=o,E=!0):O.s=0):O[C]=O[P]=o,M&&(O.id=String(M[s]))}if(c(A,e),l(t,e),u(A,e),S){for(s=0;s<A.length;)A[s][L]===o?A.splice(s,1):s++;if(a.sort(A,function(t,e){return t[L]-e[L]||t.i-e.i}),E){for(s=0;s<A.length-1&&A[s].gap;)s++;for((y=A[s].s)||(y=A[s].s=0),d=0;d<s;d++)A[d].s=y;for(v=A.length-1;v>s&&A[v].gap;)v--;for(y=A[v].s,d=A.length-1;d>v;d--)A[d].s=y;for(;s<v;)if(A[++s].gap){for(d=s+1;A[d].gap;)d++;for(var D=A[s-1][L],R=A[s-1].s,F=(A[d].s-R)/(A[d][L]-D);s<d;)A[s].s=R+(A[s][L]-D)*F,s++}}}return A},calcMarkerSize:f,calcAxisExpansion:h,setFirstScatter:p,getStackOpts:g}},{"../../constants/numerical":692,"../../lib":716,"../../plots/cartesian/axes":764,"./arrays_to_calcdata":1117,"./calc_selection":1120,"./colorscale_calc":1121,"./subtypes":1142,"fast-isnumeric":227}],1120:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{"../../lib":716}],1121:[function(t,e,r){"use strict";var n=t("../../components/colorscale/helpers").hasColorscale,a=t("../../components/colorscale/calc"),i=t("./subtypes");e.exports=function(t,e){i.hasLines(e)&&n(e,"line")&&a(t,e,{vals:e.line.color,containerStr:"line",cLetter:"c"}),i.hasMarkers(e)&&(n(e,"marker")&&a(t,e,{vals:e.marker.color,containerStr:"marker",cLetter:"c"}),n(e,"marker.line")&&a(t,e,{vals:e.marker.line.color,containerStr:"marker.line",cLetter:"c"}))}},{"../../components/colorscale/calc":599,"../../components/colorscale/helpers":602,"./subtypes":1142}],1122:[function(t,e,r){"use strict";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1123:[function(t,e,r){"use strict";var n=t("./calc");function a(t,e,r,n,a,i,o){a[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else i&&(s.s=function(t,e,r,n){var a=t[e-1],i=t[e+1];return i?a?a.s+(i.s-a.s)*(r-a[n])/(i[n]-a[n]):i.s:a.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,i=e.yaxis,o=r._id+i._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k=t.calcdata;for(var T in s){var A=(m=s[T]).traceIndices;if(A.length){for(y="interpolate"===m.stackgaps,x=m.groupnorm,"v"===m.orientation?(b="x",_="y"):(b="y",_="x"),w=new Array(A.length),l=0;l<w.length;l++)w[l]=!1;p=k[A[0]];var M=new Array(p.length);for(l=0;l<p.length;l++)M[l]=p[l][b];for(l=1;l<A.length;l++){for(f=k[A[l]],c=u=0;c<f.length;c++){for(d=f[c][b];d>M[u]&&u<M.length;u++)a(f,c,M[u],l,w,y,b),c++;if(d!==M[u]){for(h=0;h<l;h++)a(k[A[h]],u,d,h,w,y,b);M.splice(u,0,d)}u++}for(;u<M.length;u++)a(f,c,M[u],l,w,y,b),c++}var S=M.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<A.length;l++)(f=k[A[l]])[0].trace._rawLength=f[0].trace._length,f[0].trace._length=S,g+=f[c].s,f[c][_]=g;if(x)for(v=("fraction"===x?g:g/100)||1,l=0;l<A.length;l++){var E=k[A[l]][c];E[_]/=v,E.sNorm=E.s/v}}for(l=0;l<A.length;l++){var L=(f=k[A[l]])[0].trace,C=n.calcMarkerSize(L,L._rawLength),P=Array.isArray(C);if(C&&w[l]||P){var O=C;for(C=new Array(S),c=0;c<S;c++)C[c]=f[c].gap?0:P?O[f[c].i]:O}var z=new Array(S),I=new Array(S);for(c=0;c<S;c++)z[c]=f[c].x,I[c]=f[c].y;n.calcAxisExpansion(t,L,r,i,z,I,C),f[0].t.orientation=m.orientation}}}}}},{"./calc":1119}],1124:[function(t,e,r){"use strict";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if("scatter"===r.type){var n=r.fill;if("none"!==n&&"toself"!==n&&(r.opacity=void 0,"tonexty"===n||"tonextx"===n))for(var a=e-1;a>=0;a--){var i=t[a];if("scatter"===i.type&&i.xaxis===r.xaxis&&i.yaxis===r.yaxis){i.opacity=void 0;break}}}}}},{}],1125:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=t("./attributes"),o=t("./constants"),s=t("./subtypes"),l=t("./xy_defaults"),c=t("./stack_defaults"),u=t("./marker_defaults"),h=t("./line_defaults"),f=t("./line_shape_defaults"),p=t("./text_defaults"),d=t("./fillcolor_defaults");e.exports=function(t,e,r,g){function v(r,a){return n.coerce(t,e,i,r,a)}var m=l(t,e,g,v);if(m||(e.visible=!1),e.visible){var y=c(t,e,g,v),x=!y&&m<o.PTS_LINESONLY?"lines+markers":"lines";v("text"),v("hovertext"),v("mode",x),s.hasLines(e)&&(h(t,e,r,g,v),f(t,e,v),v("connectgaps"),v("line.simplify")),s.hasMarkers(e)&&u(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&(v("texttemplate"),p(t,e,g,v));var b=[];(s.hasMarkers(e)||s.hasText(e))&&(v("cliponaxis"),v("marker.maxdisplayed"),b.push("points")),v("fill",y?y.fillDflt:"none"),"none"!==e.fill&&(d(t,e,r,v),s.hasLines(e)||f(t,e,v));var _=(e.line||{}).color,w=(e.marker||{}).color;"tonext"!==e.fill&&"toself"!==e.fill||b.push("fills"),v("hoveron",b.join("+")||"points"),"fills"!==e.hoveron&&v("hovertemplate");var k=a.getComponentMethod("errorbars","supplyDefaults");k(t,e,_||w||r,{axis:"y"}),k(t,e,_||w||r,{axis:"x",inherit:"y"}),n.coerceSelectionMarkerOpacity(e,v)}}},{"../../lib":716,"../../registry":845,"./attributes":1118,"./constants":1122,"./fillcolor_defaults":1126,"./line_defaults":1131,"./line_shape_defaults":1133,"./marker_defaults":1137,"./stack_defaults":1140,"./subtypes":1142,"./text_defaults":1143,"./xy_defaults":1144}],1126:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../../lib").isArrayOrTypedArray;e.exports=function(t,e,r,i){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!a(s)?o=s:l&&!a(l)&&(o=l)}i("fillcolor",n.addOpacity((e.line||{}).color||o||r,.5))}},{"../../components/color":591,"../../lib":716}],1127:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes");e.exports=function(t,e,r){var a={},i={_fullLayout:r},o=n.getFromTrace(i,e,"x"),s=n.getFromTrace(i,e,"y");return a.xLabel=n.tickText(o,t.x,!0).text,a.yLabel=n.tickText(s,t.y,!0).text,a}},{"../../plots/cartesian/axes":764}],1128:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("./subtypes");e.exports=function(t,e){var r,i;if("lines"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if("none"===t.mode)return t.fill?t.fillcolor:"";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(i=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:"")?n.opacity(i)<.3?n.addOpacity(i,.3):i:(r=(t.line||{}).color)&&n.opacity(r)&&a.hasLines(t)&&t.line.width?r:t.fillcolor}},{"../../components/color":591,"./subtypes":1142}],1129:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/fx"),i=t("../../registry"),o=t("./get_trace_color"),s=t("../../components/color"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),g=p.c2p(r),v=[d,g],m=h.hoveron||"",y=-1!==h.mode.indexOf("markers")?3:.5;if(-1!==m.indexOf("points")){var x=function(t){var e=Math.max(y,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=a.getDistanceFunction(c,function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(f.c2p(t.x)-d);return n<e?r*n/e:n-e+r},function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r},x);if(a.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=f.c2p(_.x,!0),k=p.c2p(_.y,!0),T=_.mrc||1;t.index=_.i;var A=u[0].t.orientation,M=A&&(_.sNorm||_.s),S="h"===A?M:_.x,E="v"===A?M:_.y;return n.extendFlat(t,{color:o(h,_),x0:w-T,x1:w+T,xLabelVal:S,y0:k-T,y1:k+T,yLabelVal:E,spikeDistance:x(_),hovertemplate:h.hovertemplate}),l(_,h,t),i.getComponentMethod("errorbars","hoverInfo")(_,h,t),[t]}}if(-1!==m.indexOf("fills")&&h._polygons){var L,C,P,O,z,I,D,R,F,B=h._polygons,N=[],j=!1,V=1/0,U=-1/0,q=1/0,H=-1/0;for(L=0;L<B.length;L++)(P=B[L]).contains(v)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(L=0;L<N.length;L++)for(O=N[L].pts,C=1;C<O.length;C++)(R=O[C-1][1])>G!=(F=O[C][1])>=G&&(I=O[C-1][0],D=O[C][0],F-R&&(z=I+(D-I)*(G-R)/(F-R),V=Math.min(V,z),U=Math.max(U,z)));V=Math.max(V,0),U=Math.min(U,f._length);var Y=s.defaultLine;return s.opacity(h.fillcolor)?Y=h.fillcolor:s.opacity((h.line||{}).color)&&(Y=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:V,x1:U,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,h.text&&!Array.isArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}}},{"../../components/color":591,"../../components/fx":629,"../../lib":716,"../../registry":845,"./get_trace_color":1128}],1130:[function(t,e,r){"use strict";var n=t("./subtypes");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t("./attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("./cross_trace_defaults"),calc:t("./calc").calc,crossTraceCalc:t("./cross_trace_calc"),arraysToCalcdata:t("./arrays_to_calcdata"),plot:t("./plot"),colorbar:t("./marker_colorbar"),formatLabels:t("./format_labels"),style:t("./style").style,styleOnSelect:t("./style").styleOnSelect,hoverPoints:t("./hover"),selectPoints:t("./select"),animatable:!0,moduleType:"trace",name:"scatter",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","symbols","errorBarsOK","showLegend","scatter-like","zoomScale"],meta:{}}},{"../../plots/cartesian":775,"./arrays_to_calcdata":1117,"./attributes":1118,"./calc":1119,"./cross_trace_calc":1123,"./cross_trace_defaults":1124,"./defaults":1125,"./format_labels":1127,"./hover":1129,"./marker_colorbar":1136,"./plot":1138,"./select":1139,"./style":1141,"./subtypes":1142}],1131:[function(t,e,r){"use strict";var n=t("../../lib").isArrayOrTypedArray,a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/defaults");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s("line.color",r),a(t,"line"))?i(t,e,o,s,{prefix:"line.",cLetter:"c"}):s("line.color",!n(c)&&c||r);s("line.width"),(l||{}).noDash||s("line.dash")}},{"../../components/colorscale/defaults":601,"../../components/colorscale/helpers":602,"../../lib":716}],1132:[function(t,e,r){"use strict";var n=t("../../constants/numerical"),a=n.BADNUM,i=n.LOG_CLIP,o=i+.5,s=i-.5,l=t("../../lib"),c=l.segmentsIntersect,u=l.constrain,h=t("./constants");e.exports=function(t,e){var r,n,i,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S=e.xaxis,E=e.yaxis,L="log"===S.type,C="log"===E.type,P=S._length,O=E._length,z=e.connectGaps,I=e.baseTolerance,D=e.shape,R="linear"===D,F=e.fill&&"none"!==e.fill,B=[],N=h.minTolerance,j=t.length,V=new Array(j),U=0;function q(r){var n=t[r];if(!n)return!1;var i=e.linearized?S.l2p(n.x):S.c2p(n.x),l=e.linearized?E.l2p(n.y):E.c2p(n.y);if(i===a){if(L&&(i=S.c2p(n.x,!0)),i===a)return!1;C&&l===a&&(i*=Math.abs(S._m*O*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),i*=1e3}if(l===a){if(C&&(l=E.c2p(n.y,!0)),l===a)return!1;l*=1e3}return[i,l]}function H(t,e,r,n){var a=r-t,i=n-e,o=.5-t,s=.5-e,l=a*a+i*i,c=a*o+i*s;if(c>0&&c<l){var u=o*i-s*a;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/O,a=Math.max(0,-r,r-1,-n,n-1);return a&&void 0!==A&&H(r,n,A,M)&&(a=0),a&&e&&H(r,n,e[0]/P,e[1]/O)&&(a=0),(1+h.toleranceGrowth*a)*I}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,Q,$,tt=h.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-O*tt,at=O*(1+tt),it=[[et,nt,rt,nt],[rt,nt,rt,at],[rt,at,et,at],[et,at,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>at)return[u(t[0],et,rt),u(t[1],nt,at)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===at)||void 0)}function lt(t,e,r){return function(n,a){var i=ot(n),o=ot(a),s=[];if(i&&o&&st(i,o))return s;i&&s.push(i),o&&s.push(o);var c=2*l.constrain((n[t]+a[t])/2,e,r)-((i||n)[t]+(o||a)[t]);c&&((i&&o?c>0==i[t]>o[t]?i:o:i||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===V[U-1][0],a=r===V[U-1][1];if(!n||!a)if(U>1){var i=e===V[U-2][0],o=r===V[U-2][1];n&&(e===et||e===rt)&&i?o?U--:V[U-1]=t:a&&(r===nt||r===at)&&o?i?U--:V[U-1]=t:V[U++]=t}else V[U++]=t}function ut(t){V[U-1][0]!==t[0]&&V[U-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ht(t){if(A=t[0]/P,M=t[1]/O,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>at?at:0,W||X){if(U)if(K){var e=$(K,t);e.length>1&&(ut(e[0]),V[U++]=e[1])}else Q=$(V[U-1],t)[0],V[U++]=Q;else V[U++]=[W||t[0],X||t[1]];var r=V[U-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,i=(a=t)[0]-n[0],o=(a[1]-n[1])/i,(n[1]*a[0]-a[1]*n[0])/i>0?[o>0?et:rt,at]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut($(K,t)[0]),V[U++]=t;var n,a,i,o}for("linear"===D||"spline"===D?$=function(t,e){for(var r=[],n=0,a=0;a<4;a++){var i=it[a],o=c(t[0],t[1],e[0],e[1],i[0],i[1],i[2],i[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:"hv"===D||"vh"===D?$=function(t,e){var r=[],n=ot(t),a=ot(e);return n&&a&&st(n,a)?r:(n&&r.push(n),a&&r.push(a),r)}:"hvh"===D?$=lt(0,et,rt):"vhv"===D&&($=lt(1,nt,at)),r=0;r<j;r++)if(n=q(r)){for(U=0,K=null,ht(n),r++;r<j;r++){if(!(f=q(r))){if(z)continue;break}if(R&&e.simplify){var ft=q(r+1);if(y=Y(f,n),F&&(0===U||U===j-1)||!(y<G(f,ft)*N)){for(v=[(f[0]-n[0])/y,(f[1]-n[1])/y],p=n,x=y,b=w=k=0,g=!1,i=f,r++;r<t.length;r++){if(d=ft,ft=q(r+1),!d){if(z)continue;break}if(T=(m=[d[0]-n[0],d[1]-n[1]])[0]*v[1]-m[1]*v[0],w=Math.min(w,T),(k=Math.max(k,T))-w>G(d,ft))break;i=d,(_=m[0]*v[0]+m[1]*v[1])>x?(x=_,f=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ht(f),i!==p&&ht(p)):(p!==n&&ht(p),i!==f&&ht(f)),ht(i),r>=t.length||!d)break;ht(d),n=d}}else ht(f)}K&&ct([Z||K[0],J||K[1]]),B.push(V.slice(0,U))}return B}},{"../../constants/numerical":692,"../../lib":716,"./constants":1122}],1133:[function(t,e,r){"use strict";e.exports=function(t,e,r){"spline"===r("line.shape")&&r("line.smoothing")}},{}],1134:[function(t,e,r){"use strict";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var a,i,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(i=0;i<r.length;i++)(o=(a=r[i][0].trace).stackgroup||"")?o in c?l=c[o]:(l=c[o]=f,f++):a.fill in n&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),a._groupIndex=h=l;var d=r.slice();u&&d.sort(function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index});var g={};for(i=0;i<d.length;i++)o=(a=d[i][0].trace).stackgroup||"",!0===a.visible?(a._nexttrace=null,a.fill in n&&(s=g[o],a._prevtrace=s||null,s&&(s._nexttrace=a)),a._ownfill=a.fill&&("tozero"===a.fill.substr(0,6)||"toself"===a.fill||"to"===a.fill.substr(0,2)&&!a._prevtrace),g[o]=a):a._prevtrace=a._nexttrace=a._ownfill=null;return d}},{}],1135:[function(t,e,r){"use strict";var n=t("fast-isnumeric");e.exports=function(t){var e=t.marker,r=e.sizeref||1,a=e.sizemin||0,i="area"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=i(t/2);return n(e)&&e>0?Math.max(e,a):0}}},{"fast-isnumeric":227}],1136:[function(t,e,r){"use strict";e.exports={container:"marker",min:"cmin",max:"cmax"}},{}],1137:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../../components/colorscale/helpers").hasColorscale,i=t("../../components/colorscale/defaults"),o=t("./subtypes");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;(c=c||{},h&&(r=h),l("marker.symbol"),l("marker.opacity",u?.7:1),l("marker.size"),l("marker.color",r),a(t,"marker")&&i(t,e,s,l,{prefix:"marker.",cLetter:"c"}),c.noSelect||(l("selected.marker.color"),l("unselected.marker.color"),l("selected.marker.size"),l("unselected.marker.size")),c.noLine||(l("marker.line.color",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),a(t,"marker.line")&&i(t,e,s,l,{prefix:"marker.line.",cLetter:"c"}),l("marker.line.width",u?1:0)),u&&(l("marker.sizeref"),l("marker.sizemin"),l("marker.sizemode")),c.gradient)&&("none"!==l("marker.gradient.type")&&l("marker.gradient.color"))}},{"../../components/color":591,"../../components/colorscale/defaults":601,"../../components/colorscale/helpers":602,"./subtypes":1142}],1138:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../lib"),o=i.ensureSingle,s=i.identity,l=t("../../components/drawing"),c=t("./subtypes"),u=t("./line_points"),h=t("./link_traces"),f=t("../../lib/polygon").tester;function p(t,e,r,h,p,d,g){var v;!function(t,e,r,a,o){var s=r.xaxis,l=r.yaxis,u=n.extent(i.simpleMap(s.range,s.r2c)),h=n.extent(i.simpleMap(l.range,l.r2c)),f=a[0].trace;if(!c.hasMarkers(f))return;var p=f.marker.maxdisplayed;if(0===p)return;var d=a.filter(function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]}),g=Math.ceil(d.length/p),v=0;o.forEach(function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&v++});var m=Math.round(v*g/3+Math.floor(v/3)*g/7.1);a.forEach(function(t){delete t.vis}),d.forEach(function(t,e){0===Math.round((e+m)%g)&&(t.vis=!0)})}(0,e,r,h,p);var m=!!g&&g.duration>0;function y(t){return m?t.transition():t}var x=r.xaxis,b=r.yaxis,_=h[0].trace,w=_.line,k=n.select(d),T=o(k,"g","errorbars"),A=o(k,"g","lines"),M=o(k,"g","points"),S=o(k,"g","text");if(a.getComponentMethod("errorbars","plot")(t,T,r,g),!0===_.visible){var E,L;y(k).style("opacity",_.opacity);var C=_.fill.charAt(_.fill.length-1);"x"!==C&&"y"!==C&&(C=""),h[0][r.isRangePlot?"nodeRangePlot3":"node3"]=k;var P,O,z="",I=[],D=_._prevtrace;D&&(z=D._prevRevpath||"",L=D._nextFill,I=D._polygons);var R,F,B,N,j,V,U,q="",H="",G=[],Y=i.noop;if(E=_._ownFill,c.hasLines(_)||"none"!==_.fill){for(L&&L.datum(h),-1!==["hv","vh","hvh","vhv"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split("").reverse().join(""))):R=F="spline"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return"M"+t.join("L")},B=function(t){return F(t.reverse())},G=u(h,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),U=_._polygons=new Array(G.length),v=0;v<G.length;v++)_._polygons[v]=f(G[v]);G.length&&(N=G[0][0],V=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),O=B(e),q?C?(q+="L"+P.substr(1),H=O+"L"+H.substr(1)):(q+="Z"+P,H=O+"Z"+H):(q=P,H=O),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(h),t)y(r.style("opacity",0).attr("d",P).call(l.lineGroupStyle)).style("opacity",1);else{var a=y(r);a.attr("d",P),l.singleLineStyle(h,a)}}}}}var W=A.selectAll(".js-line").data(G);y(W.exit()).style("opacity",0).remove(),W.each(Y(!1)),W.enter().append("path").classed("js-line",!0).style("vector-effect","non-scaling-stroke").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(h),N&&V&&(C?("y"===C?N[1]=V[1]=b.c2p(0,!0):"x"===C&&(N[0]=V[0]=x.c2p(0,!0)),y(E).attr("d","M"+V+"L"+N+"L"+q.substr(1)).call(l.singleFillStyle)):y(E).attr("d",q+"Z").call(l.singleFillStyle))):L&&("tonext"===_.fill.substr(0,6)&&q&&z?("tonext"===_.fill?y(L).attr("d",q+"Z"+z+"Z").call(l.singleFillStyle):y(L).attr("d",q+"L"+z.substr(1)+"Z").call(l.singleFillStyle),_._polygons=_._polygons.concat(I)):(Z(L),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=U):(E?Z(E):L&&Z(L),_._polygons=_._prevRevpath=_._prevPolygons=null),M.datum(h),S.datum(h),function(e,a,i){var o,u=i[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=tt(u),d=et,g=et;if(h||f){var v=s,_=u.stackgroup,w=_&&"infer zero"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?v=w?K:J:_&&!w&&(v=Q),h&&(d=v),f&&(g=v)}var k,T=(o=e.selectAll("path.point").data(d,p)).enter().append("path").classed("point",!0);m&&T.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style("opacity",0).transition().style("opacity",1),o.order(),h&&(k=l.makePointStyleFns(u)),o.each(function(e){var a=n.select(this),i=y(a);l.translatePoint(e,i,x,b)?(l.singlePointStyle(e,i,u,k,t),r.layerClipId&&l.hideOutsideRangePoint(e,i,x,b,u.xcalendar,u.ycalendar),u.customdata&&a.classed("plotly-customdata",null!==e.data&&void 0!==e.data)):i.remove()}),m?o.exit().transition().style("opacity",0).remove():o.exit().remove(),(o=a.selectAll("g").data(g,p)).enter().append("g").classed("textpoint",!0).append("text"),o.order(),o.each(function(t){var e=n.select(this),a=y(e.select("text"));l.translatePoint(t,a,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()}),o.selectAll("text").call(l.textPointStyle,u,t).each(function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll("tspan.line").each(function(){y(n.select(this)).attr({x:e,y:r})})}),o.exit().remove()}(M,S,h);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(M,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr("d","M0,0Z")}function J(t){return t.filter(function(t){return!t.gap&&t.vis})}function K(t){return t.filter(function(t){return t.vis})}function Q(t){return t.filter(function(t){return!t.gap})}function $(t){return t.id}function tt(t){if(t.ids)return $}function et(){return!1}}e.exports=function(t,e,r,a,i,c){var u,f,d=!i,g=!!i&&i.duration>0,v=h(t,e,r);((u=a.selectAll("g.trace").data(v,function(t){return t[0].trace.uid})).enter().append("g").attr("class",function(t){return"trace scatter trace"+t[0].trace.uid}).style("stroke-miterlimit",2),u.order(),function(t,e,r){e.each(function(e){var a=o(n.select(this),"g","fills");l.setClipUrl(a,r.layerClipId,t);var i=e[0].trace,c=[];i._ownfill&&c.push("_ownFill"),i._nexttrace&&c.push("_nextFill");var u=a.selectAll("g").data(c,s);u.enter().append("g"),u.exit().each(function(t){i[t]=null}).remove(),u.order().each(function(t){i[t]=o(n.select(this),"path","js-fill")})})}(t,u,e),g)?(c&&(f=c()),n.transition().duration(i.duration).ease(i.easing).each("end",function(){f&&f()}).each("interrupt",function(){f&&f()}).each(function(){a.selectAll("g.trace").each(function(r,n){p(t,n,e,r,v,this,i)})})):u.each(function(r,n){p(t,n,e,r,v,this,i)});d&&u.exit().remove(),a.selectAll("path:not([d])").remove()}},{"../../components/drawing":612,"../../lib":716,"../../lib/polygon":728,"../../registry":845,"./line_points":1132,"./link_traces":1134,"./subtypes":1142,d3:164}],1139:[function(t,e,r){"use strict";var n=t("./subtypes");e.exports=function(t,e){var r,a,i,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)a=s[r],i=l.c2p(a.x),o=c.c2p(a.y),null!==a.i&&e.contains([i,o],!1,r,t)?(u.push({pointNumber:a.i,x:l.c2d(a.x),y:c.c2d(a.y)}),a.selected=1):a.selected=0;return u}},{"./subtypes":1142}],1140:[function(t,e,r){"use strict";var n=["orientation","groupnorm","stackgaps"];e.exports=function(t,e,r,a){var i=r._scatterStackOpts,o=a("stackgroup");if(o){var s=e.xaxis+e.yaxis,l=i[s];l||(l=i[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var h={orientation:e.x&&!e.y?"h":"v"},f=0;f<n.length;f++){var p=n[f],d=p+"Found";if(!c[d]){var g=void 0!==t[p],v="orientation"===p;if((g||u)&&(c[p]=a(p,h[p]),v&&(c.fillDflt="h"===c[p]?"tonextx":"tonexty"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],v))))for(var m=0;m<c.traces.length-1;m++){var y=c.traces[m];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1141:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../registry");function o(t,e,r){a.pointStyle(t.selectAll("path.point"),e,r)}function s(t,e,r){a.textPointStyle(t.selectAll("text"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll("g.trace.scatter");e.style("opacity",function(t){return t[0].trace.opacity}),e.selectAll("g.points").each(function(e){o(n.select(this),e.trace||e[0].trace,t)}),e.selectAll("g.text").each(function(e){s(n.select(this),e.trace||e[0].trace,t)}),e.selectAll("g.trace path.js-line").call(a.lineGroupStyle),e.selectAll("g.trace path.js-fill").call(a.fillGroupStyle),i.getComponentMethod("errorbars","style")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(a.selectedPointStyle(r.selectAll("path.point"),n),a.selectedTextStyle(r.selectAll("text"),n)):(o(r,n,t),s(r,n,t))}}},{"../../components/drawing":612,"../../registry":845,d3:164}],1142:[function(t,e,r){"use strict";var n=t("../../lib");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf("lines")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf("markers")||"splom"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf("text")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{"../../lib":716}],1143:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e,r,a,i){i=i||{},a("textposition"),n.coerceFont(a,"textfont",r.font),i.noSelect||(a("selected.textfont.color"),a("unselected.textfont.color"))}},{"../../lib":716}],1144:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry");e.exports=function(t,e,r,i){var o,s=i("x"),l=i("y");if(a.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,i("y0"),i("dy"))}else{if(!l)return 0;o=n.minRowLength(l),i("x0"),i("dx")}return e._length=o,o}},{"../../lib":716,"../../registry":845}],1145:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../../components/colorscale/attributes"),i=t("../../plots/template_attributes").hovertemplateAttrs,o=t("../../plots/template_attributes").texttemplateAttrs,s=t("../../plots/attributes"),l=t("../../constants/gl3d_dashes"),c=t("../../constants/gl3d_markers"),u=t("../../lib/extend").extendFlat,h=t("../../plot_api/edit_types").overrideAll,f=n.line,p=n.marker,d=p.line,g=u({width:f.width,dash:{valType:"enumerated",values:Object.keys(l),dflt:"solid"}},a("line"));var v=e.exports=h({x:n.x,y:n.y,z:{valType:"data_array"},text:u({},n.text,{}),texttemplate:o({},{}),hovertext:u({},n.hovertext,{}),hovertemplate:i(),mode:u({},n.mode,{dflt:"lines+markers"}),surfaceaxis:{valType:"enumerated",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:"color"},projection:{x:{show:{valType:"boolean",dflt:!1},opacity:{valType:"number",min:0,max:1,dflt:1},scale:{valType:"number",min:0,max:10,dflt:2/3}},y:{show:{valType:"boolean",dflt:!1},opacity:{valType:"number",min:0,max:1,dflt:1},scale:{valType:"number",min:0,max:10,dflt:2/3}},z:{show:{valType:"boolean",dflt:!1},opacity:{valType:"number",min:0,max:1,dflt:1},scale:{valType:"number",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:g,marker:u({symbol:{valType:"enumerated",values:Object.keys(c),dflt:"circle",arrayOk:!0},size:u({},p.size,{dflt:8}),sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode,opacity:u({},p.opacity,{arrayOk:!1}),colorbar:p.colorbar,line:u({width:u({},d.width,{arrayOk:!1})},a("marker.line"))},a("marker")),textposition:u({},n.textposition,{dflt:"top center"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:u({},n.textfont.family,{arrayOk:!1})},hoverinfo:u({},s.hoverinfo)},"calc","nested");v.x.editType=v.y.editType=v.z.editType="calc+clearAxisTypes"},{"../../components/colorscale/attributes":598,"../../constants/gl3d_dashes":689,"../../constants/gl3d_markers":690,"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plots/attributes":761,"../../plots/template_attributes":840,"../scatter/attributes":1118}],1146:[function(t,e,r){"use strict";var n=t("../scatter/arrays_to_calcdata"),a=t("../scatter/colorscale_calc");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),a(t,e),r}},{"../scatter/arrays_to_calcdata":1117,"../scatter/colorscale_calc":1121}],1147:[function(t,e,r){"use strict";var n=t("../../registry");function a(t,e,r,a){if(!e||!e.visible)return null;for(var i=n.getComponentMethod("errorbars","makeComputeError")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=i(+t[s],s);if("log"===a.type){var c=a.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(a.c2l(u,!0)-c)*r,(a.c2l(h,!0)-c)*r],u>0){var f=a.c2l(u);a._lowerLogErrorBound||(a._lowerLogErrorBound=f),a._lowerErrorBound=Math.min(a._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[a(t.x,t.error_x,e[0],r.xaxis),a(t.y,t.error_y,e[1],r.yaxis),a(t.z,t.error_z,e[2],r.zaxis)],i=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===i)return null;for(var o=new Array(i),s=0;s<i;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{"../../registry":845}],1148:[function(t,e,r){"use strict";var n=t("gl-line3d"),a=t("gl-scatter3d"),i=t("gl-error3d"),o=t("gl-mesh3d"),s=t("delaunay-triangulate"),l=t("../../lib"),c=t("../../lib/str2rgbarray"),u=t("../../lib/gl_format_color").formatColor,h=t("../scatter/make_bubble_size_func"),f=t("../../constants/gl3d_dashes"),p=t("../../constants/gl3d_markers"),d=t("../../plots/cartesian/axes"),g=t("../../components/fx/helpers").appendArrayPointValue,v=t("./calc_errors");function m(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode="",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var y=m.prototype;function x(t){return null==t?0:t.indexOf("left")>-1?-1:t.indexOf("right")>-1?1:0}function b(t){return null==t?0:t.indexOf("top")>-1?-1:t.indexOf("bottom")>-1?1:0}function _(t,e){return e(4*t)}function w(t){return p[t]}function k(t,e,r,n,a){var i=null;if(l.isArrayOrTypedArray(t)){i=[];for(var o=0;o<e;o++)void 0===t[o]?i[o]=n:i[o]=r(t[o],a)}else i=r(t,l.identity);return i}function T(t,e){var r,n,a,i,o,s,f=[],p=t.fullSceneLayout,m=t.dataScale,y=p.xaxis,T=p.yaxis,A=p.zaxis,M=e.marker,S=e.line,E=e.x||[],L=e.y||[],C=e.z||[],P=E.length,O=e.xcalendar,z=e.ycalendar,I=e.zcalendar;for(o=0;o<P;o++)r=y.d2l(E[o],0,O)*m[0],n=T.d2l(L[o],0,z)*m[1],a=A.d2l(C[o],0,I)*m[2],f[o]=[r,n,a];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(P),o=0;o<P;o++)s[o]=e.text;function D(t,e){var r=p[t];return d.tickText(r,r.d2l(e),!0).text}var R=e.texttemplate;if(R){var F=t.fullLayout._d3locale,B=Array.isArray(R),N=B?Math.min(R.length,P):P,j=B?function(t){return R[t]}:function(){return R};for(s=new Array(N),o=0;o<N;o++){var V={x:E[o],y:L[o],z:C[o]},U={xLabel:D("xaxis",E[o]),yLabel:D("yaxis",L[o]),zLabel:D("zaxis",C[o])},q={};g(q,e,o);var H=e._meta||{};s[o]=l.texttemplateString(j(o),U,F,q,V,H)}}if(i={position:f,mode:e.mode,text:s},"line"in e&&(i.lineColor=u(S,1,P),i.lineWidth=S.width,i.lineDashes=S.dash),"marker"in e){var G=h(e);i.scatterColor=u(M,1,P),i.scatterSize=k(M.size,P,_,20,G),i.scatterMarker=k(M.symbol,P,w,"\u25cf"),i.scatterLineWidth=M.line.width,i.scatterLineColor=u(M.line,1,P),i.scatterAngle=0}"textposition"in e&&(i.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=x(t[r]),e[r][1]=b(t[r]));else e[0]=x(t),e[1]=b(t);return e}(e.textposition),i.textColor=u(e.textfont,1,P),i.textSize=k(e.textfont.size,P,l.identity,12),i.textFont=e.textfont.family,i.textAngle=0);var Y=["x","y","z"];for(i.project=[!1,!1,!1],i.projectScale=[1,1,1],i.projectOpacity=[1,1,1],o=0;o<3;++o){var W=e.projection[Y[o]];(i.project[o]=W.show)&&(i.projectOpacity[o]=W.opacity,i.projectScale[o]=W.scale)}i.errorBounds=v(e,m,p);var X=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],a=0;a<3;a++){var i=t[a];i&&!1!==i.copy_zstyle&&!1!==t[2].visible&&(i=t[2]),i&&i.visible&&(e[a]=i.width/2,r[a]=c(i.color),n[a]=i.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return i.errorColor=X.color,i.errorLineWidth=X.lineWidth,i.errorCapSize=X.capSize,i.delaunayAxis=e.surfaceaxis,i.delaunayColor=c(e.surfacecolor),i}function A(t){if(Array.isArray(t)){var e=t[0];return Array.isArray(e)&&(t=e),"rgb("+t.slice(0,3).map(function(t){return Math.round(255*t)})+")"}return null}y.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel="",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},y.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,h=f.solid;this.data=t;var p=T(this.scene,t);"mode"in p&&(this.mode=p.mode),"lineDashes"in p&&p.lineDashes in f&&(h=f[p.lineDashes]),this.color=A(p.scatterColor)||A(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:h[0],dashScale:h[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf("lines")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf("markers")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=a(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf("text")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=a(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=i(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,a=(r+1)%3,i=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[a])&&isFinite(c[a])&&!isNaN(c[i])&&isFinite(c[i])&&(o.push([c[a],c[i]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},y.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new m(t,e.uid);return r.update(e),r}},{"../../components/fx/helpers":626,"../../constants/gl3d_dashes":689,"../../constants/gl3d_markers":690,"../../lib":716,"../../lib/gl_format_color":713,"../../lib/str2rgbarray":739,"../../plots/cartesian/axes":764,"../scatter/make_bubble_size_func":1135,"./calc_errors":1147,"delaunay-triangulate":166,"gl-error3d":249,"gl-line3d":257,"gl-mesh3d":282,"gl-scatter3d":299}],1149:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../scatter/subtypes"),o=t("../scatter/marker_defaults"),s=t("../scatter/line_defaults"),l=t("../scatter/text_defaults"),c=t("./attributes");e.exports=function(t,e,r,u){function h(r,n){return a.coerce(t,e,c,r,n)}if(function(t,e,r,a){var i=0,o=r("x"),s=r("y"),l=r("z");n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y","z"],a),o&&s&&l&&(i=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=i);return i}(t,e,h,u)){h("text"),h("hovertext"),h("hovertemplate"),h("mode"),i.hasLines(e)&&(h("connectgaps"),s(t,e,r,u,h)),i.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0}),i.hasText(e)&&(h("texttemplate"),l(t,e,u,h,{noSelect:!0}));var f=(e.line||{}).color,p=(e.marker||{}).color;h("surfaceaxis")>=0&&h("surfacecolor",f||p);for(var d=["x","y","z"],g=0;g<3;++g){var v="projection."+d[g];h(v+".show")&&(h(v+".opacity"),h(v+".scale"))}var m=n.getComponentMethod("errorbars","supplyDefaults");m(t,e,f||p||r,{axis:"z"}),m(t,e,f||p||r,{axis:"y",inherit:"z"}),m(t,e,f||p||r,{axis:"x",inherit:"z"})}else e.visible=!1}},{"../../lib":716,"../../registry":845,"../scatter/line_defaults":1131,"../scatter/marker_defaults":1137,"../scatter/subtypes":1142,"../scatter/text_defaults":1143,"./attributes":1145}],1150:[function(t,e,r){"use strict";e.exports={plot:t("./convert"),attributes:t("./attributes"),markerSymbols:t("../../constants/gl3d_markers"),supplyDefaults:t("./defaults"),colorbar:[{container:"marker",min:"cmin",max:"cmax"},{container:"line",min:"cmin",max:"cmax"}],calc:t("./calc"),moduleType:"trace",name:"scatter3d",basePlotModule:t("../../plots/gl3d"),categories:["gl3d","symbols","showLegend","scatter-like"],meta:{}}},{"../../constants/gl3d_markers":690,"../../plots/gl3d":804,"./attributes":1145,"./calc":1146,"./convert":1148,"./defaults":1149}],1151:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../../plots/attributes"),i=t("../../plots/template_attributes").hovertemplateAttrs,o=t("../../plots/template_attributes").texttemplateAttrs,s=t("../../components/colorscale/attributes"),l=t("../../lib/extend").extendFlat,c=n.marker,u=n.line,h=c.line;e.exports={carpet:{valType:"string",editType:"calc"},a:{valType:"data_array",editType:"calc"},b:{valType:"data_array",editType:"calc"},mode:l({},n.mode,{dflt:"markers"}),text:l({},n.text,{}),texttemplate:o({editType:"plot"},{keys:["a","b","text"]}),hovertext:l({},n.hovertext,{}),line:{color:u.color,width:u.width,dash:u.dash,shape:l({},u.shape,{values:["linear","spline"]}),smoothing:u.smoothing,editType:"calc"},connectgaps:n.connectgaps,fill:l({},n.fill,{values:["none","toself","tonext"],dflt:"none"}),fillcolor:n.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:h.width,editType:"calc"},s("marker.line")),gradient:c.gradient,editType:"calc"},s("marker")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:l({},a.hoverinfo,{flags:["a","b","text","name"]}),hoveron:n.hoveron,hovertemplate:i()}},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/template_attributes":840,"../scatter/attributes":1118}],1152:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../scatter/colorscale_calc"),i=t("../scatter/arrays_to_calcdata"),o=t("../scatter/calc_selection"),s=t("../scatter/calc").calcMarkerSize,l=t("../carpet/lookup_carpetid");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&"legendonly"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var g=r.ab2xy(+u,+h,!0),v=r.isVisible(+u,+h);v||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:h,vis:v}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),a(t,e),i(p,e),o(p,e),p}}},{"../carpet/lookup_carpetid":914,"../scatter/arrays_to_calcdata":1117,"../scatter/calc":1119,"../scatter/calc_selection":1120,"../scatter/colorscale_calc":1121,"fast-isnumeric":227}],1153:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/constants"),i=t("../scatter/subtypes"),o=t("../scatter/marker_defaults"),s=t("../scatter/line_defaults"),l=t("../scatter/line_shape_defaults"),c=t("../scatter/text_defaults"),u=t("../scatter/fillcolor_defaults"),h=t("./attributes");e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,h,r,a)}p("carpet"),e.xaxis="x",e.yaxis="y";var d=p("a"),g=p("b"),v=Math.min(d.length,g.length);if(v){e._length=v,p("text"),p("texttemplate"),p("hovertext"),p("mode",v<a.PTS_LINESONLY?"lines+markers":"lines"),i.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p("connectgaps")),i.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),i.hasText(e)&&c(t,e,f,p);var m=[];(i.hasMarkers(e)||i.hasText(e))&&(p("marker.maxdisplayed"),m.push("points")),p("fill"),"none"!==e.fill&&(u(t,e,r,p),i.hasLines(e)||l(t,e,p)),"tonext"!==e.fill&&"toself"!==e.fill||m.push("fills"),"fills"!==p("hoveron",m.join("+")||"points")&&p("hovertemplate"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{"../../lib":716,"../scatter/constants":1122,"../scatter/fillcolor_defaults":1126,"../scatter/line_defaults":1131,"../scatter/line_shape_defaults":1133,"../scatter/marker_defaults":1137,"../scatter/subtypes":1142,"../scatter/text_defaults":1143,"./attributes":1151}],1154:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){var i=n[a];return t.a=i.a,t.b=i.b,t.y=i.y,t}},{}],1155:[function(t,e,r){"use strict";e.exports=function(t,e){var r={},n=e._carpet,a=n.ab2ij([t.a,t.b]),i=Math.floor(a[0]),o=a[0]-i,s=Math.floor(a[1]),l=a[1]-s,c=n.evalxy([],i,s,o,l);return r.yLabel=c[1].toFixed(3),r}},{}],1156:[function(t,e,r){"use strict";var n=t("../scatter/hover"),a=t("../../lib").fillText;e.exports=function(t,e,r,i){var o=n(t,e,r,i);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=p._module.formatLabels(f,p);s.yLabel=g.yLabel,delete s.text;var v=[];if(!p.hovertemplate){var m=(f.hi||p.hoverinfo).split("+");-1!==m.indexOf("all")&&(m=["a","b","text"]),-1!==m.indexOf("a")&&y(d.aaxis,f.a),-1!==m.indexOf("b")&&y(d.baxis,f.b),v.push("y: "+s.yLabel),-1!==m.indexOf("text")&&a(f,p,v),s.extraText=v.join("<br>")}return o}function y(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,""):t._hovertitle,v.push(r+": "+e.toFixed(3)+t.labelsuffix)}}},{"../../lib":716,"../scatter/hover":1129}],1157:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),plot:t("./plot"),style:t("../scatter/style").style,styleOnSelect:t("../scatter/style").styleOnSelect,hoverPoints:t("./hover"),selectPoints:t("../scatter/select"),eventData:t("./event_data"),moduleType:"trace",name:"scattercarpet",basePlotModule:t("../../plots/cartesian"),categories:["svg","carpet","symbols","showLegend","carpetDependent","zoomScale"],meta:{}}},{"../../plots/cartesian":775,"../scatter/marker_colorbar":1136,"../scatter/select":1139,"../scatter/style":1141,"./attributes":1151,"./calc":1152,"./defaults":1153,"./event_data":1154,"./format_labels":1155,"./hover":1156,"./plot":1158}],1158:[function(t,e,r){"use strict";var n=t("../scatter/plot"),a=t("../../plots/cartesian/axes"),i=t("../../components/drawing");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h={xaxis:a.getFromId(t,u.xaxis||"x"),yaxis:a.getFromId(t,u.yaxis||"y"),plot:e.plot};for(n(t,h,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll("g.trace"+l.uid+" .js-line"),i.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{"../../components/drawing":612,"../../plots/cartesian/axes":764,"../scatter/plot":1138}],1159:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../plots/template_attributes").texttemplateAttrs,i=t("../scatter/attributes"),o=t("../../plots/attributes"),s=t("../../components/colorscale/attributes"),l=t("../../components/drawing/attributes").dash,c=t("../../lib/extend").extendFlat,u=t("../../plot_api/edit_types").overrideAll,h=i.marker,f=i.line,p=h.line;e.exports=u({lon:{valType:"data_array"},lat:{valType:"data_array"},locations:{valType:"data_array"},locationmode:{valType:"enumerated",values:["ISO-3","USA-states","country names"],dflt:"ISO-3"},mode:c({},i.mode,{dflt:"markers"}),text:c({},i.text,{}),texttemplate:a({editType:"plot"},{keys:["lat","lon","location","text"]}),hovertext:c({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:f.color,width:f.width,dash:l},connectgaps:i.connectgaps,marker:c({symbol:h.symbol,opacity:h.opacity,size:h.size,sizeref:h.sizeref,sizemin:h.sizemin,sizemode:h.sizemode,colorbar:h.colorbar,line:c({width:p.width},s("marker.line")),gradient:h.gradient},s("marker")),fill:{valType:"enumerated",values:["none","toself"],dflt:"none"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:c({},o.hoverinfo,{flags:["lon","lat","location","text","name"]}),hovertemplate:n()},"calc","nested")},{"../../components/colorscale/attributes":598,"../../components/drawing/attributes":611,"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plots/attributes":761,"../../plots/template_attributes":840,"../scatter/attributes":1118}],1160:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../constants/numerical").BADNUM,i=t("../scatter/colorscale_calc"),o=t("../scatter/arrays_to_calcdata"),s=t("../scatter/calc_selection"),l=t("../../lib")._;e.exports=function(t,e){for(var r=Array.isArray(e.locations),c=r?e.locations.length:e._length,u=new Array(c),h=0;h<c;h++){var f=u[h]={};if(r){var p=e.locations[h];f.loc="string"==typeof p?p:null}else{var d=e.lon[h],g=e.lat[h];n(d)&&n(g)?f.lonlat=[+d,+g]:f.lonlat=[a,a]}}return o(u,e),i(t,e),s(u,e),c&&(u[0].t={labels:{lat:l(t,"lat:")+" ",lon:l(t,"lon:")+" "}}),u}},{"../../constants/numerical":692,"../../lib":716,"../scatter/arrays_to_calcdata":1117,"../scatter/calc_selection":1120,"../scatter/colorscale_calc":1121,"fast-isnumeric":227}],1161:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("../scatter/marker_defaults"),o=t("../scatter/line_defaults"),s=t("../scatter/text_defaults"),l=t("../scatter/fillcolor_defaults"),c=t("./attributes");e.exports=function(t,e,r,u){function h(r,a){return n.coerce(t,e,c,r,a)}!function(t,e,r){var n,a,i=0,o=r("locations");if(o)return r("locationmode"),i=o.length;return n=r("lon")||[],a=r("lat")||[],i=Math.min(n.length,a.length),e._length=i,i}(0,e,h)?e.visible=!1:(h("text"),h("hovertext"),h("hovertemplate"),h("mode"),a.hasLines(e)&&(o(t,e,r,u,h),h("connectgaps")),a.hasMarkers(e)&&i(t,e,r,u,h,{gradient:!0}),a.hasText(e)&&(h("texttemplate"),s(t,e,u,h)),h("fill"),"none"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h))}},{"../../lib":716,"../scatter/fillcolor_defaults":1126,"../scatter/line_defaults":1131,"../scatter/marker_defaults":1137,"../scatter/subtypes":1142,"../scatter/text_defaults":1143,"./attributes":1159}],1162:[function(t,e,r){"use strict";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null,t}},{}],1163:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes");e.exports=function(t,e,r){var a={},i=r[e.geo]._subplot.mockAxis,o=t.lonlat;return a.lonLabel=n.tickText(i,i.c2l(o[0]),!0).text,a.latLabel=n.tickText(i,i.c2l(o[1]),!0).text,a}},{"../../plots/cartesian/axes":764}],1164:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../constants/numerical").BADNUM,i=t("../scatter/get_trace_color"),o=t("../../lib").fillText,s=t("./attributes");e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=f.projection.isLonLatOverEdges,d=f.project;if(n.getClosest(l,function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(p(n))return 1/0;var i=d(n),o=d([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[u.c2p(v),h.c2p(v)],y=g.mrc||1;t.x0=m[0]-y,t.x1=m[0]+y,t.y0=m[1]-y,t.y1=m[1]+y,t.loc=g.loc,t.lon=v[0],t.lat=v[1];var x={};x[c.geo]={_subplot:f};var b=c._module.formatLabels(g,c,x);return t.lonLabel=b.lonLabel,t.latLabel=b.latLabel,t.color=i(c,g),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var a=e.hi||t.hoverinfo,i="all"===a?s.hoverinfo.flags:a.split("+"),l=-1!==i.indexOf("location")&&Array.isArray(t.locations),c=-1!==i.indexOf("lon"),u=-1!==i.indexOf("lat"),h=-1!==i.indexOf("text"),f=[];function p(t){return t+"\xb0"}l?f.push(e.loc):c&&u?f.push("("+p(r.lonLabel)+", "+p(r.latLabel)+")"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel));h&&o(e,t,f);return f.join("<br>")}(c,g,t,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{"../../components/fx":629,"../../constants/numerical":692,"../../lib":716,"../scatter/get_trace_color":1128,"./attributes":1159}],1165:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),plot:t("./plot"),style:t("./style"),styleOnSelect:t("../scatter/style").styleOnSelect,hoverPoints:t("./hover"),eventData:t("./event_data"),selectPoints:t("./select"),moduleType:"trace",name:"scattergeo",basePlotModule:t("../../plots/geo"),categories:["geo","symbols","showLegend","scatter-like"],meta:{}}},{"../../plots/geo":794,"../scatter/marker_colorbar":1136,"../scatter/style":1141,"./attributes":1159,"./calc":1160,"./defaults":1161,"./event_data":1162,"./format_labels":1163,"./hover":1164,"./plot":1166,"./select":1167,"./style":1168}],1166:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../constants/numerical").BADNUM,o=t("../../lib/topojson_utils").getTopojsonFeatures,s=t("../../lib/geo_location_utils").locationToFeature,l=t("../../lib/geojson_utils"),c=t("../scatter/subtypes"),u=t("./style");function h(t,e){var r=t[0].trace;if(Array.isArray(r.locations))for(var n=o(r,e),a=r.locationmode,l=0;l<t.length;l++){var c=t[l],u=s(a,c.loc,n);c.lonlat=u?u.properties.ct:[i,i]}}e.exports=function(t,e,r){for(var o=0;o<r.length;o++)h(r[o],e.topojson);function s(t,e){t.lonlat[0]===i&&n.select(e).remove()}var f=e.layers.frontplot.select(".scatterlayer"),p=a.makeTraceGroups(f,r,"trace scattergeo");p.selectAll("*").remove(),p.each(function(e){var r=n.select(this),i=e[0].trace;if(c.hasLines(i)||"none"!==i.fill){var o=l.calcTraceToLineCoords(e),h="none"!==i.fill?l.makePolygon(o):l.makeLine(o);r.selectAll("path.js-line").data([{geojson:h,trace:i}]).enter().append("path").classed("js-line",!0).style("stroke-miterlimit",2)}c.hasMarkers(i)&&r.selectAll("path.point").data(a.identity).enter().append("path").classed("point",!0).each(function(t){s(t,this)}),c.hasText(i)&&r.selectAll("g").data(a.identity).enter().append("g").append("text").each(function(t){s(t,this)}),u(t,e)})}},{"../../constants/numerical":692,"../../lib":716,"../../lib/geo_location_utils":710,"../../lib/geojson_utils":711,"../../lib/topojson_utils":743,"../scatter/subtypes":1142,"./style":1168,d3:164}],1167:[function(t,e,r){"use strict";var n=t("../scatter/subtypes"),a=t("../../constants/numerical").BADNUM;e.exports=function(t,e){var r,i,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(i=(r=c[l]).lonlat)[0]!==a&&(o=u.c2p(i),s=h.c2p(i),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:i[0],lat:i[1]}),r.selected=1):r.selected=0);return f}},{"../../constants/numerical":692,"../scatter/subtypes":1142}],1168:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../components/color"),o=t("../scatter/style"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style("opacity",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll("path.js-line").style("fill","none").each(function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(i.stroke,o.color).call(a.dashLine,o.dash||"",o.width||0),"none"!==r.fill&&e.call(i.fill,r.fillcolor)})}(t,e)}},{"../../components/color":591,"../../components/drawing":612,"../scatter/style":1141,d3:164}],1169:[function(t,e,r){"use strict";var n=t("../../plots/attributes"),a=t("../scatter/attributes"),i=t("../../components/colorscale/attributes"),o=t("../../lib/extend").extendFlat,s=t("../../plot_api/edit_types").overrideAll,l=t("./constants").DASHES,c=a.line,u=a.marker,h=u.line,f=e.exports=s({x:a.x,x0:a.x0,dx:a.dx,y:a.y,y0:a.y0,dy:a.dy,text:a.text,hovertext:a.hovertext,textposition:a.textposition,textfont:a.textfont,mode:{valType:"flaglist",flags:["lines","markers","text"],extras:["none"]},line:{color:c.color,width:c.width,shape:{valType:"enumerated",values:["linear","hv","vh","hvh","vhv"],dflt:"linear",editType:"plot"},dash:{valType:"enumerated",values:Object.keys(l),dflt:"solid"}},marker:o({},i("marker"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},i("marker.line"),{width:h.width})}),connectgaps:a.connectgaps,fill:o({},a.fill,{dflt:"none"}),fillcolor:a.fillcolor,selected:{marker:a.selected.marker,textfont:a.selected.textfont},unselected:{marker:a.unselected.marker,textfont:a.unselected.textfont},opacity:n.opacity},"calc","nested");f.x.editType=f.y.editType=f.x0.editType=f.y0.editType="calc+clearAxisTypes",f.hovertemplate=a.hovertemplate,f.texttemplate=a.texttemplate},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plots/attributes":761,"../scatter/attributes":1118,"./constants":1171}],1170:[function(t,e,r){"use strict";var n=t("point-cluster"),a=t("../../lib"),i=t("../../plots/cartesian/axis_ids"),o=t("../../plots/cartesian/autorange").findExtremes,s=t("../scatter/calc"),l=s.calcMarkerSize,c=s.calcAxisExpansion,u=s.setFirstScatter,h=t("../scatter/colorscale_calc"),f=t("./convert"),p=t("./scene_update"),d=t("../../constants/numerical").BADNUM,g=t("./constants").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],a=o(e,r._bnds,{padded:!0});n.min=n.min.concat(a.min),n.max=n.max.concat(a.max)}e.exports=function(t,e){var r,o,s,m=t._fullLayout,y=i.getFromId(t,e.xaxis),x=i.getFromId(t,e.yaxis),b=m._plots[e.xaxis+e.yaxis],_=e._length,w=_>=g,k=2*_,T={},A=e._x=y.makeCalcdata(e,"x"),M=e._y=x.makeCalcdata(e,"y"),S=new Array(k);for(r=0;r<_;r++)o=A[r],s=M[r],S[2*r]=o===d?NaN:o,S[2*r+1]=s===d?NaN:s;if("log"===y.type)for(r=0;r<k;r+=2)S[r]=y.c2l(S[r]);if("log"===x.type)for(r=1;r<k;r+=2)S[r]=x.c2l(S[r]);if(w&&"log"!==y.type&&"log"!==x.type)T.tree=n(S);else{var E=T.ids=new Array(_);for(r=0;r<_;r++)E[r]=r}h(t,e);var L,C=function(t,e,r,n,i,o){var s=f.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&a.extendFlat(s.line,f.linePositions(t,r,n));if(s.errorX||s.errorY){var l=f.errorBarPositions(t,r,n,i,o);s.errorX&&a.extendFlat(s.errorX,l.x),s.errorY&&a.extendFlat(s.errorY,l.y)}s.text&&(a.extendFlat(s.text,{positions:n},f.textPosition(t,r,s.text,s.marker)),a.extendFlat(s.textSel,{positions:n},f.textPosition(t,r,s.text,s.markerSel)),a.extendFlat(s.textUnsel,{positions:n},f.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,S,A,M),P=p(t,b);return u(m,e),w?C.marker&&(L=2*(C.marker.sizeAvg||Math.max(C.marker.size,3))):L=l(e,_),c(t,e,y,x,A,M,L),C.errorX&&v(e,y,C.errorX),C.errorY&&v(e,x,C.errorY),C.fill&&!P.fill2d&&(P.fill2d=!0),C.marker&&!P.scatter2d&&(P.scatter2d=!0),C.line&&!P.line2d&&(P.line2d=!0),!C.errorX&&!C.errorY||P.error2d||(P.error2d=!0),C.text&&!P.glText&&(P.glText=!0),C.marker&&(C.marker.snap=_),P.lineOptions.push(C.line),P.errorXOptions.push(C.errorX),P.errorYOptions.push(C.errorY),P.fillOptions.push(C.fill),P.markerOptions.push(C.marker),P.markerSelectedOptions.push(C.markerSel),P.markerUnselectedOptions.push(C.markerUnsel),P.textOptions.push(C.text),P.textSelectedOptions.push(C.textSel),P.textUnselectedOptions.push(C.textUnsel),P.selectBatch.push([]),P.unselectBatch.push([]),T._scene=P,T.index=P.count,T.x=A,T.y=M,T.positions=S,P.count++,[{x:!1,y:!1,t:T,trace:e}]}},{"../../constants/numerical":692,"../../lib":716,"../../plots/cartesian/autorange":763,"../../plots/cartesian/axis_ids":767,"../scatter/calc":1119,"../scatter/colorscale_calc":1121,"./constants":1171,"./convert":1172,"./scene_update":1179,"point-cluster":470}],1171:[function(t,e,r){"use strict";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1172:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("svg-path-sdf"),i=t("color-normalize"),o=t("../../registry"),s=t("../../lib"),l=t("../../components/drawing"),c=t("../../plots/cartesian/axis_ids"),u=t("../../lib/gl_format_color").formatColor,h=t("../scatter/subtypes"),f=t("../scatter/make_bubble_size_func"),p=t("./constants"),d=t("../../constants/interactions").DESELECTDIM,g={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1},v=t("../../components/fx/helpers").appendArrayPointValue;function m(t,e){var r,a=t._fullLayout,i=e._length,o=e.textfont,l=e.textposition,c=Array.isArray(l)?l:[l],u=o.color,h=o.size,f=o.family,p={},d=e.texttemplate;if(d){p.text=[];var g=a._d3locale,m=Array.isArray(d),y=m?Math.min(d.length,i):i,x=m?function(t){return d[t]}:function(){return d};for(r=0;r<y;r++){var b={i:r},_=e._module.formatLabels(b,e,a),w={};v(w,e,r);var k=e._meta||{};p.text.push(s.texttemplateString(x(r),_,g,w,b,k))}}else Array.isArray(e.text)&&e.text.length<i?p.text=e.text.slice():p.text=e.text;if(Array.isArray(p.text))for(r=p.text.length;r<i;r++)p.text[r]="";for(p.opacity=e.opacity,p.font={},p.align=[],p.baseline=[],r=0;r<c.length;r++){var T=c[r].split(/\s+/);switch(T[1]){case"left":p.align.push("right");break;case"right":p.align.push("left");break;default:p.align.push(T[1])}switch(T[0]){case"top":p.baseline.push("bottom");break;case"bottom":p.baseline.push("top");break;default:p.baseline.push(T[0])}}if(Array.isArray(u))for(p.color=new Array(i),r=0;r<i;r++)p.color[r]=u[r];else p.color=u;if(Array.isArray(h)||Array.isArray(f))for(p.font=new Array(i),r=0;r<i;r++){var A=p.font[r]={};A.size=Array.isArray(h)?n(h[r])?h[r]:0:h,A.family=Array.isArray(f)?f[r]:f}else p.font={size:h,family:f};return p}function y(t){var e,r,n=t._length,a=t.marker,o={},l=Array.isArray(a.symbol),c=s.isArrayOrTypedArray(a.color),h=s.isArrayOrTypedArray(a.line.color),d=s.isArrayOrTypedArray(a.opacity),g=s.isArrayOrTypedArray(a.size),v=s.isArrayOrTypedArray(a.line.width);if(l||(r=p.OPEN_RE.test(a.symbol)),l||c||h||d){o.colors=new Array(n),o.borderColors=new Array(n);var m=u(a,a.opacity,n),y=u(a.line,a.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(m[0])){var b=m;for(m=Array(n),e=0;e<n;e++)m[e]=b}for(o.colors=m,o.borderColors=y,e=0;e<n;e++){if(l){var _=a.symbol[e];r=p.OPEN_RE.test(_)}r&&(y[e]=m[e].slice(),m[e]=m[e].slice(),m[e][3]=0)}o.opacity=t.opacity}else r?(o.color=i(a.color,"uint8"),o.color[3]=0,o.borderColor=i(a.color,"uint8")):(o.color=i(a.color,"uint8"),o.borderColor=i(a.line.color,"uint8")),o.opacity=t.opacity*a.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=S(a.symbol[e]);else o.marker=S(a.symbol);var w,k=f(t);if(g||v){var T,A=o.sizes=new Array(n),M=o.borderSizes=new Array(n),E=0;if(g){for(e=0;e<n;e++)A[e]=k(a.size[e]),E+=A[e];T=E/n}else for(w=k(a.size),e=0;e<n;e++)A[e]=w;if(v)for(e=0;e<n;e++)M[e]=a.line.width[e]/2;else for(w=a.line.width/2,e=0;e<n;e++)M[e]=w;o.sizeAvg=T}else o.size=k(a&&a.size||10),o.borderSizes=k(a.line.width);return o}function x(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=y(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function b(t,e,r){var n={};if(!r)return n;if(r.textfont){var a={opacity:1,text:e.text,texttemplate:e.texttemplate,textposition:e.textposition,textfont:s.extendFlat({},e.textfont)};r.textfont&&s.extendFlat(a.textfont,r.textfont),n=m(t,a)}return n}function _(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var w=p.SYMBOL_SDF_SIZE,k=p.SYMBOL_SIZE,T=p.SYMBOL_STROKE,A={},M=l.symbolFuncs[0](.05*k);function S(t){if("circle"===t)return null;var e,r,n=l.symbolNumber(t),i=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.DOT_RE.test(t);return A[t]?A[t]:(e=c&&!o?i(1.1*k)+M:i(k),r=a(e,{w:w,h:w,viewBox:[-k,-k,k,k],stroke:s?T:-T}),A[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(h.hasText(e)&&(n.text=m(t,e),n.textSel=b(t,e,e.selected),n.textUnsel=b(t,e,e.unselected)),h.hasMarkers(e)&&(n.marker=y(e),n.markerSel=x(e,e.selected),n.markerUnsel=x(e,e.unselected),!e.unselected&&Array.isArray(e.marker.opacity))){var a=e.marker.opacity;for(n.markerUnsel.opacity=new Array(a.length),r=0;r<a.length;r++)n.markerUnsel.opacity[r]=d*a[r]}if(h.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var i=(p.DASHES[e.line.dash]||[1]).slice();for(r=0;r<i.length;++r)i[r]*=e.line.width;n.line.dashes=i}return e.error_x&&e.error_x.visible&&(n.errorX=_(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=_(e,e.error_y)),e.fill&&"none"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:y,markerSelection:x,linePositions:function(t,e,r){var n,a,i=r.length,o=i/2;if(h.hasLines(e)&&o)if("hv"===e.line.shape){for(n=[],a=0;a<o-1;a++)isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*a],r[2*a+1]),isNaN(r[2*a+2])||isNaN(r[2*a+3])?n.push(NaN,NaN):n.push(r[2*a+2],r[2*a+1]));n.push(r[i-2],r[i-1])}else if("hvh"===e.line.shape){for(n=[],a=0;a<o-1;a++)if(isNaN(r[2*a])||isNaN(r[2*a+1])||isNaN(r[2*a+2])||isNaN(r[2*a+3]))isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN):n.push(r[2*a],r[2*a+1]),n.push(NaN,NaN);else{var s=(r[2*a]+r[2*a+2])/2;n.push(r[2*a],r[2*a+1],s,r[2*a+1],s,r[2*a+3])}n.push(r[i-2],r[i-1])}else if("vhv"===e.line.shape){for(n=[],a=0;a<o-1;a++)if(isNaN(r[2*a])||isNaN(r[2*a+1])||isNaN(r[2*a+2])||isNaN(r[2*a+3]))isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN):n.push(r[2*a],r[2*a+1]),n.push(NaN,NaN);else{var l=(r[2*a+1]+r[2*a+3])/2;n.push(r[2*a],r[2*a+1],r[2*a],l,r[2*a+2],l)}n.push(r[i-2],r[i-1])}else if("vh"===e.line.shape){for(n=[],a=0;a<o-1;a++)isNaN(r[2*a])||isNaN(r[2*a+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*a],r[2*a+1]),isNaN(r[2*a+2])||isNaN(r[2*a+3])?n.push(NaN,NaN):n.push(r[2*a],r[2*a+3]));n.push(r[i-2],r[i-1])}else n=r;var c=!1;for(a=0;a<n.length;a++)if(isNaN(n[a])){c=!0;break}var u=c||n.length>p.TOO_MANY_POINTS?"rect":h.hasMarkers(e)?"rect":"round";if(c&&e.connectgaps){var f=n[0],d=n[1];for(a=0;a<n.length;a+=2)isNaN(n[a])||isNaN(n[a+1])?(n[a]=f,n[a+1]=d):(f=n[a],d=n[a+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,a,i){var s=o.getComponentMethod("errorbars","makeComputeError"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),h=r.length/2,f={};function p(t,a){var i=a._id.charAt(0),o=e["error_"+i];if(o&&o.visible&&("linear"===a.type||"log"===a.type)){for(var l=s(o),c={x:0,y:1}[i],u={x:[0,1,2,3],y:[2,3,0,1]}[i],p=new Float64Array(4*h),d=1/0,g=-1/0,v=0,m=0;v<h;v++,m+=4){var y=t[v];if(n(y)){var x=r[2*v+c],b=l(y,v),_=b[0],w=b[1];if(n(_)&&n(w)){var k=y-_,T=y+w;p[m+u[0]]=x-a.c2l(k),p[m+u[1]]=a.c2l(T)-x,p[m+u[2]]=0,p[m+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}f[i]={positions:r,errors:p,_bnds:[d,g]}}}return p(a,l),p(i,u),f},textPosition:function(t,e,r,n){var a,i=e._length,o={};if(h.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(i),a=0;a<i;a++){var u=n.sizes?n.sizes[a]:n.size,f=Array.isArray(s)?s[a].size:s.size,p=Array.isArray(l)?l.length>1?l[a]:l[0]:l,d=Array.isArray(c)?c.length>1?c[a]:c[0]:c,v=g[p],m=g[d],y=u?u/.8+1:0,x=-m*y-.5*m;o.offset[a]=[v*y/f,x/f]}}return o}}},{"../../components/drawing":612,"../../components/fx/helpers":626,"../../constants/interactions":691,"../../lib":716,"../../lib/gl_format_color":713,"../../plots/cartesian/axis_ids":767,"../../registry":845,"../scatter/make_bubble_size_func":1135,"../scatter/subtypes":1142,"./constants":1171,"color-normalize":121,"fast-isnumeric":227,"svg-path-sdf":533}],1173:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../registry"),i=t("./attributes"),o=t("../scatter/constants"),s=t("../scatter/subtypes"),l=t("../scatter/xy_defaults"),c=t("../scatter/marker_defaults"),u=t("../scatter/line_defaults"),h=t("../scatter/fillcolor_defaults"),f=t("../scatter/text_defaults");e.exports=function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}var g=!!t.marker&&/-open/.test(t.marker.symbol),v=s.isBubble(t),m=l(t,e,p,d);if(m){var y=m<o.PTS_LINESONLY?"lines+markers":"lines";d("text"),d("hovertext"),d("hovertemplate"),d("mode",y),s.hasLines(e)&&(d("connectgaps"),u(t,e,r,p,d),d("line.shape")),s.hasMarkers(e)&&(c(t,e,r,p,d),d("marker.line.width",g||v?1:0)),s.hasText(e)&&(d("texttemplate"),f(t,e,p,d));var x=(e.line||{}).color,b=(e.marker||{}).color;d("fill"),"none"!==e.fill&&h(t,e,r,d);var _=a.getComponentMethod("errorbars","supplyDefaults");_(t,e,x||b||r,{axis:"y"}),_(t,e,x||b||r,{axis:"x",inherit:"y"}),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}},{"../../lib":716,"../../registry":845,"../scatter/constants":1122,"../scatter/fillcolor_defaults":1126,"../scatter/line_defaults":1131,"../scatter/marker_defaults":1137,"../scatter/subtypes":1142,"../scatter/text_defaults":1143,"../scatter/xy_defaults":1144,"./attributes":1169}],1174:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../../constants/interactions").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},v=n.extendFlat({},p);if(h.length||f.length){var m=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(v.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],v.color[r]=m||(b?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var _=b?x[r]:x;v.color[r]=y||(m?_:a.addOpacity(_,i))}}c.glText[u].update(v)}}},{"../../components/color":591,"../../constants/interactions":691,"../../lib":716}],1175:[function(t,e,r){"use strict";var n=t("../scatter/format_labels");e.exports=function(t,e,r){var a=t.i;return"x"in t||(t.x=e._x[a]),"y"in t||(t.y=e._y[a]),n(t,e,r)}},{"../scatter/format_labels":1127}],1176:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../scatter/get_trace_color");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=Array.isArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=Array.isArray(p.size)?p.size[h]:p.size,f.tc=Array.isArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family);var d=o.marker;d&&(f.ms=a.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=a.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=Array.isArray(d.symbol)?d.symbol[h]:d.symbol,f.mc=a.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var g=d&&d.line;g&&(f.mlc=Array.isArray(g.color)?g.color[h]:g.color,f.mlw=a.isArrayOrTypedArray(g.width)?g.width[h]:g.width);var v=d&&d.gradient;v&&"none"!==v.type&&(f.mgt=Array.isArray(v.type)?v.type[h]:v.type,f.mgc=Array.isArray(v.color)?v.color[h]:v.color);var m=s.c2p(f.x,!0),y=l.c2p(f.y,!0),x=f.mrc||1,b=o.hoverlabel;b&&(f.hbg=Array.isArray(b.bgcolor)?b.bgcolor[h]:b.bgcolor,f.hbc=Array.isArray(b.bordercolor)?b.bordercolor[h]:b.bordercolor,f.hts=Array.isArray(b.font.size)?b.font.size[h]:b.font.size,f.htc=Array.isArray(b.font.color)?b.font.color[h]:b.font.color,f.htf=Array.isArray(b.font.family)?b.font.family[h]:b.font.family,f.hnl=Array.isArray(b.namelength)?b.namelength[h]:b.namelength);var _=o.hoverinfo;_&&(f.hi=Array.isArray(_)?_[h]:_);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var k={};k[t.index]=f;var T=a.extendFlat({},t,{color:i(o,f),x0:m-x,x1:m+x,xLabelVal:f.x,y0:y-x,y1:y+x,yLabelVal:f.y,cd:k,distance:c,spikeDistance:u,hovertemplate:f.ht});return f.htx?T.text=f.htx:f.tx?T.text=f.tx:o.text&&(T.text=o.text),a.fillText(f,o,T),n.getComponentMethod("errorbars","hoverInfo")(f,o,T),T}e.exports={hoverPoints:function(t,e,r,n){var a,i,s,l,c,u,h,f,p,d=t.cd,g=d[0].t,v=d[0].trace,m=t.xa,y=t.ya,x=g.x,b=g.y,_=m.c2p(e),w=y.c2p(r),k=t.distance;if(g.tree){var T=m.p2c(_-k),A=m.p2c(_+k),M=y.p2c(w-k),S=y.p2c(w+k);a="x"===n?g.tree.range(Math.min(T,A),Math.min(y._rl[0],y._rl[1]),Math.max(T,A),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(T,A),Math.min(M,S),Math.max(T,A),Math.max(M,S))}else a=g.ids;var E=k;if("x"===n)for(c=0;c<a.length;c++)s=x[a[c]],(u=Math.abs(m.c2p(s)-_))<E&&(E=u,h=y.c2p(b[a[c]])-w,p=Math.sqrt(u*u+h*h),i=a[c]);else for(c=a.length-1;c>-1;c--)s=x[a[c]],l=b[a[c]],u=m.c2p(s)-_,h=y.c2p(l)-w,(f=Math.sqrt(u*u+h*h))<E&&(E=p=f,i=a[c]);return t.index=i,t.distance=E,t.dxy=p,void 0===i?[t]:[o(t,x,b,v)]},calcHover:o}},{"../../lib":716,"../../registry":845,"../scatter/get_trace_color":1128}],1177:[function(t,e,r){"use strict";var n=t("./hover");e.exports={moduleType:"trace",name:"scattergl",basePlotModule:t("../../plots/cartesian"),categories:["gl","regl","cartesian","symbols","errorBarsOK","showLegend","scatter-like"],attributes:t("./attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("../scatter/cross_trace_defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),plot:t("./plot"),hoverPoints:n.hoverPoints,selectPoints:t("./select"),meta:{}}},{"../../plots/cartesian":775,"../scatter/cross_trace_defaults":1124,"../scatter/marker_colorbar":1136,"./attributes":1169,"./calc":1170,"./defaults":1173,"./format_labels":1175,"./hover":1176,"./plot":1178,"./select":1180}],1178:[function(t,e,r){"use strict";var n=t("regl-scatter2d"),a=t("regl-line2d"),i=t("regl-error2d"),o=t("gl-text"),s=t("../../lib"),l=t("../../lib/prepare_regl"),c=t("../scatter/subtypes"),u=t("../scatter/link_traces"),h=t("./edit_style").styleTextSelection;e.exports=function(t,e,r){if(r.length){var f,p,d=t._fullLayout,g=e._scene,v=e.xaxis,m=e.yaxis;if(g)if(l(t,["ANGLE_instanced_arrays","OES_element_index_uint"])){var y=g.count,x=d._glcanvas.data()[0].regl;if(u(t,e,r),g.dirty){if(!0===g.error2d&&(g.error2d=i(x)),!0===g.line2d&&(g.line2d=a(x)),!0===g.scatter2d&&(g.scatter2d=n(x)),!0===g.fill2d&&(g.fill2d=a(x)),!0===g.glText)for(g.glText=new Array(y),f=0;f<y;f++)g.glText[f]=new o(x);if(g.glText){if(y>g.glText.length){var b=y-g.glText.length;for(f=0;f<b;f++)g.glText.push(new o(x))}else if(y<g.glText.length){var _=g.glText.length-y;g.glText.splice(y,_).forEach(function(t){t.destroy()})}for(f=0;f<y;f++)g.glText[f].update(g.textOptions[f])}if(g.line2d&&(g.line2d.update(g.lineOptions),g.lineOptions=g.lineOptions.map(function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t}),g.line2d.update(g.lineOptions)),g.error2d){var w=(g.errorXOptions||[]).concat(g.errorYOptions||[]);g.error2d.update(w)}g.scatter2d&&g.scatter2d.update(g.markerOptions),g.fillOrder=s.repeat(null,y),g.fill2d&&(g.fillOptions=g.fillOptions.map(function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var a,i,o=n[0],s=o.trace,l=o.t,c=g.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(g.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if("tozeroy"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if("tozerox"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if("toself"===s.fill||"tonext"===s.fill){for(p=[],a=0,i=0;i<d.length;i+=2)(isNaN(d[i])||isNaN(d[i+1]))&&((p=p.concat(d.slice(a,i))).push(d[a],d[a+1]),a=i+2);p=p.concat(d.slice(a)),a&&p.push(d[a],d[a+1])}else{var v=s._nexttrace;if(v){var m=g.lineOptions[e+1];if(m){var y=m.positions;if("tonexty"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=v.fillcolor}}}}if(s._prevtrace&&"tonext"===s._prevtrace.fill){var _=g.lineOptions[e-1].positions,w=p.length/2,k=[a=w];for(i=0;i<_.length;i+=2)(isNaN(_[i])||isNaN(_[i+1]))&&(k.push(i/2+w+1),a=i+2);p=p.concat(_),t.hole=k}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}}),g.fill2d.update(g.fillOptions))}var k=d.dragmode,T="lasso"===k||"select"===k,A=d.clickmode.indexOf("select")>-1;for(f=0;f<y;f++){var M=r[f][0],S=M.trace,E=M.t,L=E.index,C=S._length,P=E.x,O=E.y;if(S.selectedpoints||T||A){if(T||(T=!0),S.selectedpoints){var z=g.selectBatch[L]=s.selIndices2selPoints(S),I={};for(p=0;p<z.length;p++)I[z[p]]=1;var D=[];for(p=0;p<C;p++)I[p]||D.push(p);g.unselectBatch[L]=D}var R=E.xpx=new Array(C),F=E.ypx=new Array(C);for(p=0;p<C;p++)R[p]=v.c2p(P[p]),F[p]=m.c2p(O[p])}else E.xpx=E.ypx=null}if(T){if(g.select2d||(g.select2d=n(d._glcanvas.data()[1].regl)),g.scatter2d){var B=new Array(y);for(f=0;f<y;f++)B[f]=g.selectBatch[f].length||g.unselectBatch[f].length?g.markerUnselectedOptions[f]:{};g.scatter2d.update(B)}g.select2d&&(g.select2d.update(g.markerOptions),g.select2d.update(g.markerSelectedOptions)),g.glText&&r.forEach(function(t){var e=((t||[])[0]||{}).trace||{};c.hasText(e)&&h(t)})}else g.scatter2d&&g.scatter2d.update(g.markerOptions);var N={viewport:function(t,e,r){var n=t._size,a=t.width,i=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,a-n.r-(1-e.domain[1])*n.w,i-n.t-(1-r.domain[1])*n.h]}(d,v,m),range:[(v._rl||v.range)[0],(m._rl||m.range)[0],(v._rl||v.range)[1],(m._rl||m.range)[1]]},j=s.repeat(N,g.count);g.fill2d&&g.fill2d.update(j),g.line2d&&g.line2d.update(j),g.error2d&&g.error2d.update(j.concat(j)),g.scatter2d&&g.scatter2d.update(j),g.select2d&&g.select2d.update(j),g.glText&&g.glText.forEach(function(t){t.update(N)})}else g.init()}}},{"../../lib":716,"../../lib/prepare_regl":729,"../scatter/link_traces":1134,"../scatter/subtypes":1142,"./edit_style":1174,"gl-text":318,"regl-error2d":491,"regl-line2d":492,"regl-scatter2d":498}],1179:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){var r=e._scene,a={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},i={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,i,a)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var a=0;a<r.count;a++)r.glText[a].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,a=r.error2d,i=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),i&&r.lineOptions[h]&&i.draw(h),a&&(r.errorXOptions[h]&&a.draw(h),r.errorYOptions[h]&&a.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach(function(t){t.destroy&&t.destroy()}),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,a),r}},{"../../lib":716}],1180:[function(t,e,r){"use strict";var n=t("../scatter/subtypes"),a=t("./edit_style").styleTextSelection;e.exports=function(t,e){var r=t.cd,i=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,h=s._scene,f=s.index;if(!h)return i;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return i;var v=[],m=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(v.push(y),i.push({pointNumber:y,x:c[y],y:u[y]})):m.push(y);if(d){var x=h.scatter2d;if(v.length||m.length){if(!h.selectBatch[f].length&&!h.unselectBatch[f].length){var b=new Array(h.count);b[f]=h.markerUnselectedOptions[f],x.update.apply(x,b)}}else{var _=new Array(h.count);_[f]=h.markerOptions[f],x.update.apply(x,_)}}return h.selectBatch[f]=v,h.unselectBatch[f]=m,p&&a(r),i}},{"../scatter/subtypes":1142,"./edit_style":1174}],1181:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../plots/template_attributes").texttemplateAttrs,i=t("../scattergeo/attributes"),o=t("../scatter/attributes"),s=t("../../plots/mapbox/layout_attributes"),l=t("../../plots/attributes"),c=t("../../components/colorscale/attributes"),u=t("../../lib/extend").extendFlat,h=t("../../plot_api/edit_types").overrideAll,f=i.line,p=i.marker;e.exports=h({lon:i.lon,lat:i.lat,mode:u({},o.mode,{dflt:"markers"}),text:u({},o.text,{}),texttemplate:a({editType:"plot"},{keys:["lat","lon","text"]}),hovertext:u({},o.hovertext,{}),line:{color:f.color,width:f.width},connectgaps:o.connectgaps,marker:u({symbol:{valType:"string",dflt:"circle",arrayOk:!0},opacity:p.opacity,size:p.size,sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode},c("marker")),fill:i.fill,fillcolor:o.fillcolor,textfont:s.layers.symbol.textfont,textposition:s.layers.symbol.textposition,below:{valType:"string"},selected:{marker:o.selected.marker},unselected:{marker:o.unselected.marker},hoverinfo:u({},l.hoverinfo,{flags:["lon","lat","text","name"]}),hovertemplate:n()},"calc","nested")},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plots/attributes":761,"../../plots/mapbox/layout_attributes":821,"../../plots/template_attributes":840,"../scatter/attributes":1118,"../scattergeo/attributes":1159}],1182:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../lib"),i=t("../../constants/numerical").BADNUM,o=t("../../lib/geojson_utils"),s=t("../../components/colorscale"),l=t("../../components/drawing"),c=t("../scatter/make_bubble_size_func"),u=t("../scatter/subtypes"),h=t("../../plots/mapbox/convert_text_opts"),f=t("../../components/fx/helpers").appendArrayPointValue,p=t("../../lib/svg_text_utils").NEWLINES,d=t("../../lib/svg_text_utils").BR_TAG_ALL;function g(){return{geojson:o.makeBlank(),layout:{visibility:"none"},paint:{}}}function v(t){return a.isArrayOrTypedArray(t)?function(t){return t}:t?function(){return t}:m}function m(){return""}function y(t){return t[0]===i}e.exports=function(t,e){var r,i=e[0].trace,x=!0===i.visible&&0!==i._length,b="none"!==i.fill,_=u.hasLines(i),w=u.hasMarkers(i),k=u.hasText(i),T=w&&"circle"===i.marker.symbol,A=w&&"circle"!==i.marker.symbol,M=g(),S=g(),E=g(),L=g(),C={fill:M,line:S,circle:E,symbol:L};if(!x)return C;if((b||_)&&(r=o.calcTraceToLineCoords(e)),b&&(M.geojson=o.makePolygon(r),M.layout.visibility="visible",a.extendFlat(M.paint,{"fill-color":i.fillcolor})),_&&(S.geojson=o.makeLine(r),S.layout.visibility="visible",a.extendFlat(S.paint,{"line-width":i.line.width,"line-color":i.line.color,"line-opacity":i.opacity})),T){var P=function(t){var e,r,i,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=a.isArrayOrTypedArray(h.color),d=a.isArrayOrTypedArray(h.size),g=a.isArrayOrTypedArray(h.opacity);function v(t){return u.opacity*t}p&&(r=s.hasColorscale(u,"marker")?s.makeColorScaleFuncFromTrace(h):a.identity);d&&(i=c(u));g&&(o=function(t){var e=n(t)?+a.constrain(t,0,1):0;return v(e)});var m,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!y(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),i&&(w.mrc=b.mrc=i(b.ms)),o&&(w.mo=o(b.mo)),f&&(w.selected=b.selected||0),x.push({type:"Feature",geometry:{type:"Point",coordinates:_},properties:w})}}if(f)for(m=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var k=x[e].properties;m.selectedOpacityFn&&(k.mo=v(m.selectedOpacityFn(k))),m.selectedColorFn&&(k.mcc=m.selectedColorFn(k)),m.selectedSizeFn&&(k.mrc=m.selectedSizeFn(k))}return{geojson:{type:"FeatureCollection",features:x},mcc:p||m&&m.selectedColorFn?{type:"identity",property:"mcc"}:h.color,mrc:d||m&&m.selectedSizeFn?{type:"identity",property:"mrc"}:(T=h.size,T/2),mo:g||m&&m.selectedOpacityFn?{type:"identity",property:"mo"}:v(h.opacity)};var T}(e);E.geojson=P.geojson,E.layout.visibility="visible",a.extendFlat(E.paint,{"circle-color":P.mcc,"circle-radius":P.mrc,"circle-opacity":P.mo})}if((A||k)&&(L.geojson=function(t,e){for(var r=e._fullLayout,n=t[0].trace,i=(n.marker||{}).symbol,o="circle"!==i?v(i):m,s=u.hasText(n)?v(n.text):m,l=[],c=0;c<t.length;c++){var h=t[c];if(!y(h.lonlat)){var g,x=n.texttemplate;if(x){var b=Array.isArray(x)?x[c]||"":x,_=n._module.formatLabels(h,n,r),w={};f(w,n,h.i);var k=n._meta||{};g=a.texttemplateString(b,_,r._d3locale,w,h,k)}else g=s(h.tx);g&&(g=g.replace(p,"").replace(d,"\n")),l.push({type:"Feature",geometry:{type:"Point",coordinates:h.lonlat},properties:{symbol:o(h.mx),text:g}})}}return{type:"FeatureCollection",features:l}}(e,t),a.extendFlat(L.layout,{visibility:"visible","icon-image":"{symbol}-15","text-field":"{text}"}),A&&(a.extendFlat(L.layout,{"icon-size":i.marker.size/10}),a.extendFlat(L.paint,{"icon-opacity":i.opacity*i.marker.opacity,"icon-color":i.marker.color})),k)){var O=(i.marker||{}).size,z=h(i.textposition,O);a.extendFlat(L.layout,{"text-size":i.textfont.size,"text-anchor":z.anchor,"text-offset":z.offset}),a.extendFlat(L.paint,{"text-color":i.textfont.color,"text-opacity":i.opacity})}return C}},{"../../components/colorscale":603,"../../components/drawing":612,"../../components/fx/helpers":626,"../../constants/numerical":692,"../../lib":716,"../../lib/geojson_utils":711,"../../lib/svg_text_utils":740,"../../plots/mapbox/convert_text_opts":818,"../scatter/make_bubble_size_func":1135,"../scatter/subtypes":1142,"fast-isnumeric":227}],1183:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("../scatter/marker_defaults"),o=t("../scatter/line_defaults"),s=t("../scatter/text_defaults"),l=t("../scatter/fillcolor_defaults"),c=t("./attributes");e.exports=function(t,e,r,u){function h(r,a){return n.coerce(t,e,c,r,a)}if(function(t,e,r){var n=r("lon")||[],a=r("lat")||[],i=Math.min(n.length,a.length);return e._length=i,i}(0,e,h)){if(h("text"),h("texttemplate"),h("hovertext"),h("hovertemplate"),h("mode"),h("below"),a.hasLines(e)&&(o(t,e,r,u,h,{noDash:!0}),h("connectgaps")),a.hasMarkers(e)){i(t,e,r,u,h,{noLine:!0});var f=e.marker;"circle"!==f.symbol&&(n.isArrayOrTypedArray(f.size)&&(f.size=f.size[0]),n.isArrayOrTypedArray(f.color)&&(f.color=f.color[0]))}a.hasText(e)&&s(t,e,u,h,{noSelect:!0}),h("fill"),"none"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{"../../lib":716,"../scatter/fillcolor_defaults":1126,"../scatter/line_defaults":1131,"../scatter/marker_defaults":1137,"../scatter/subtypes":1142,"../scatter/text_defaults":1143,"./attributes":1181}],1184:[function(t,e,r){"use strict";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1185:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes");e.exports=function(t,e,r){var a={},i=r[e.subplot]._subplot.mockAxis,o=t.lonlat;return a.lonLabel=n.tickText(i,i.c2l(o[0]),!0).text,a.latLabel=n.tickText(i,i.c2l(o[1]),!0).text,a}},{"../../plots/cartesian/axes":764}],1186:[function(t,e,r){"use strict";var n=t("../../components/fx"),a=t("../../lib"),i=t("../scatter/get_trace_color"),o=a.fillText,s=t("../../constants/numerical").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=a.modHalf(e[0],360),i=e[1],o=f.project([n,i]),l=o.x-u.c2p([d,i]),c=o.y-h.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[a.modHalf(v[0],360)+p,v[1]],y=u.c2p(m),x=h.c2p(m),b=g.mrc||1;t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b;var _={};_[c.subplot]={_subplot:f};var w=c._module.formatLabels(g,c,_);return t.lonLabel=w.lonLabel,t.latLabel=w.latLabel,t.color=i(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split("+"),a=-1!==n.indexOf("all"),i=-1!==n.indexOf("lon"),s=-1!==n.indexOf("lat"),l=e.lonlat,c=[];function u(t){return t+"\xb0"}a||i&&s?c.push("("+u(l[0])+", "+u(l[1])+")"):i?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==n.indexOf("text"))&&o(e,t,c);return c.join("<br>")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{"../../components/fx":629,"../../constants/numerical":692,"../../lib":716,"../scatter/get_trace_color":1128}],1187:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("../scattergeo/calc"),plot:t("./plot"),hoverPoints:t("./hover"),eventData:t("./event_data"),selectPoints:t("./select"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:"trace",name:"scattermapbox",basePlotModule:t("../../plots/mapbox"),categories:["mapbox","gl","symbols","showLegend","scatter-like"],meta:{}}},{"../../plots/mapbox":819,"../scatter/marker_colorbar":1136,"../scattergeo/calc":1160,"./attributes":1181,"./defaults":1183,"./event_data":1184,"./format_labels":1185,"./hover":1186,"./plot":1188,"./select":1189}],1188:[function(t,e,r){"use strict";var n=t("./convert"),a=t("../../plots/mapbox/constants").traceLayerPrefix,i=["fill","line","circle","symbol"];function o(t,e){this.type="scattermapbox",this.subplot=t,this.uid=e,this.sourceIds={fill:"source-"+e+"-fill",line:"source-"+e+"-line",circle:"source-"+e+"-circle",symbol:"source-"+e+"-symbol"},this.layerIds={fill:a+e+"-fill",line:a+e+"-line",circle:a+e+"-circle",symbol:a+e+"-symbol"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:"geojson",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,a,o=this.subplot,s=o.map,l=n(o.gd,t),c=o.belowLookup["trace-"+this.uid];if(c!==this.below){for(e=i.length-1;e>=0;e--)r=i[e],s.removeLayer(this.layerIds[r]);for(e=0;e<i.length;e++)a=l[r=i[e]],this.addLayer(r,a,c);this.below=c}for(e=0;e<i.length;e++)a=l[r=i[e]],o.setOptions(this.layerIds[r],"setLayoutProperty",a.layout),"visible"===a.layout.visibility&&(this.setSourceData(r,a),o.setOptions(this.layerIds[r],"setPaintProperty",a.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=i.length-1;e>=0;e--){var r=i[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,a=new o(t,r.uid),s=n(t.gd,e),l=a.below=t.belowLookup["trace-"+r.uid],c=0;c<i.length;c++){var u=i[c],h=s[u];a.addSource(u,h),a.addLayer(u,h,l)}return e[0].trace._glTrace=a,a}},{"../../plots/mapbox/constants":817,"./convert":1182}],1189:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("../../constants/numerical").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!a.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==i){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},{"../../constants/numerical":692,"../../lib":716,"../scatter/subtypes":1142}],1190:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../plots/template_attributes").texttemplateAttrs,i=t("../../lib/extend").extendFlat,o=t("../scatter/attributes"),s=t("../../plots/attributes"),l=o.line;e.exports={mode:o.mode,r:{valType:"data_array",editType:"calc+clearAxisTypes"},theta:{valType:"data_array",editType:"calc+clearAxisTypes"},r0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes"},dr:{valType:"number",dflt:1,editType:"calc"},theta0:{valType:"any",dflt:0,editType:"calc+clearAxisTypes"},dtheta:{valType:"number",editType:"calc"},thetaunit:{valType:"enumerated",values:["radians","degrees","gradians"],dflt:"degrees",editType:"calc+clearAxisTypes"},text:o.text,texttemplate:a({editType:"plot"},{keys:["r","theta","text"]}),hovertext:o.hovertext,line:{color:l.color,width:l.width,dash:l.dash,shape:i({},l.shape,{values:["linear","spline"]}),smoothing:l.smoothing,editType:"calc"},connectgaps:o.connectgaps,marker:o.marker,cliponaxis:i({},o.cliponaxis,{dflt:!1}),textposition:o.textposition,textfont:o.textfont,fill:i({},o.fill,{values:["none","toself","tonext"],dflt:"none"}),fillcolor:o.fillcolor,hoverinfo:i({},s.hoverinfo,{flags:["r","theta","text","name"]}),hoveron:o.hoveron,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{"../../lib/extend":707,"../../plots/attributes":761,"../../plots/template_attributes":840,"../scatter/attributes":1118}],1191:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../../constants/numerical").BADNUM,i=t("../../plots/cartesian/axes"),o=t("../scatter/colorscale_calc"),s=t("../scatter/arrays_to_calcdata"),l=t("../scatter/calc_selection"),c=t("../scatter/calc").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,"r"),d=f.makeCalcdata(e,"theta"),g=e._length,v=new Array(g),m=0;m<g;m++){var y=p[m],x=d[m],b=v[m]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=a}var _=c(e,g);return e._extremes.x=i.findExtremes(h,p,{ppad:_}),o(t,e),s(v,e),l(v,e),v}},{"../../constants/numerical":692,"../../plots/cartesian/axes":764,"../scatter/arrays_to_calcdata":1117,"../scatter/calc":1119,"../scatter/calc_selection":1120,"../scatter/colorscale_calc":1121,"fast-isnumeric":227}],1192:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("../scatter/marker_defaults"),o=t("../scatter/line_defaults"),s=t("../scatter/line_shape_defaults"),l=t("../scatter/text_defaults"),c=t("../scatter/fillcolor_defaults"),u=t("../scatter/constants").PTS_LINESONLY,h=t("./attributes");function f(t,e,r,n){var a,i=n("r"),o=n("theta");if(i)o?a=Math.min(i.length,o.length):(a=i.length,n("theta0"),n("dtheta"));else{if(!o)return 0;a=e.theta.length,n("r0"),n("dr")}return e._length=a,a}e.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,h,r,a)}var g=f(0,e,0,d);if(g){d("thetaunit"),d("mode",g<u?"lines+markers":"lines"),d("text"),d("hovertext"),"fills"!==e.hoveron&&d("hovertemplate"),a.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d("connectgaps")),a.hasMarkers(e)&&i(t,e,r,p,d,{gradient:!0}),a.hasText(e)&&(d("texttemplate"),l(t,e,p,d));var v=[];(a.hasMarkers(e)||a.hasText(e))&&(d("cliponaxis"),d("marker.maxdisplayed"),v.push("points")),d("fill"),"none"!==e.fill&&(c(t,e,r,d),a.hasLines(e)||s(t,e,d)),"tonext"!==e.fill&&"toself"!==e.fill||v.push("fills"),d("hoveron",v.join("+")||"points"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{"../../lib":716,"../scatter/constants":1122,"../scatter/fillcolor_defaults":1126,"../scatter/line_defaults":1131,"../scatter/line_shape_defaults":1133,"../scatter/marker_defaults":1137,"../scatter/subtypes":1142,"../scatter/text_defaults":1143,"./attributes":1190}],1193:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes");e.exports=function(t,e,r){var i,o,s={},l=r[e.subplot]._subplot;l?(i=l.radialAxis,o=l.angularAxis):(i=(l=r[e.subplot]).radialaxis,o=l.angularaxis);var c=i.c2l(t.r);s.rLabel=a.tickText(i,c,!0).text;var u="degrees"===o.thetaunit?n.rad2deg(t.theta):t.theta;return s.thetaLabel=a.tickText(o,u,!0).text,s}},{"../../lib":716,"../../plots/cartesian/axes":764}],1194:[function(t,e,r){"use strict";var n=t("../scatter/hover");function a(t,e,r,n){var a=r.radialAxis,i=r.angularAxis;a._hovertitle="r",i._hovertitle="\u03b8";var o={};o[e.subplot]={_subplot:r};var s=e._module.formatLabels(t,e,o);n.rLabel=s.rLabel,n.thetaLabel=s.thetaLabel;var l=t.hi||e.hoverinfo,c=[];function u(t,e){c.push(t._hovertitle+": "+e)}if(!e.hovertemplate){var h=l.split("+");-1!==h.indexOf("all")&&(h=["r","theta","text"]),-1!==h.indexOf("r")&&u(a,n.rLabel),-1!==h.indexOf("theta")&&u(i,n.thetaLabel),-1!==h.indexOf("text")&&n.text&&(c.push(n.text),delete n.text),n.extraText=c.join("<br>")}}e.exports={hoverPoints:function(t,e,r,i){var o=n(t,e,r,i);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index)return o;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,a(c,u,l,s),s.hovertemplate=u.hovertemplate,o}},makeHoverPointText:a}},{"../scatter/hover":1129}],1195:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"scatterpolar",basePlotModule:t("../../plots/polar"),categories:["polar","symbols","showLegend","scatter-like"],attributes:t("./attributes"),supplyDefaults:t("./defaults").supplyDefaults,colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),plot:t("./plot"),style:t("../scatter/style").style,styleOnSelect:t("../scatter/style").styleOnSelect,hoverPoints:t("./hover").hoverPoints,selectPoints:t("../scatter/select"),meta:{}}},{"../../plots/polar":828,"../scatter/marker_colorbar":1136,"../scatter/select":1139,"../scatter/style":1141,"./attributes":1190,"./calc":1191,"./defaults":1192,"./format_labels":1193,"./hover":1194,"./plot":1196}],1196:[function(t,e,r){"use strict";var n=t("../scatter/plot"),a=t("../../constants/numerical").BADNUM;e.exports=function(t,e,r){for(var i=e.layers.frontplot.select("g.scatterlayer"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],h=0;h<u.length;h++){var f=u[h],p=f.r;if(p===a)f.x=f.y=a;else{var d=s.c2g(p),g=l.c2g(f.theta);f.x=d*Math.cos(g),f.y=d*Math.sin(g)}}n(t,o,r,i)}},{"../../constants/numerical":692,"../scatter/plot":1138}],1197:[function(t,e,r){"use strict";var n=t("../scatterpolar/attributes"),a=t("../scattergl/attributes"),i=t("../../plots/template_attributes").texttemplateAttrs;e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,texttemplate:i({editType:"plot"},{keys:["r","theta","text"]}),hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:a.line,connectgaps:a.connectgaps,marker:a.marker,fill:a.fill,fillcolor:a.fillcolor,textposition:a.textposition,textfont:a.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{"../../plots/template_attributes":840,"../scattergl/attributes":1169,"../scatterpolar/attributes":1190}],1198:[function(t,e,r){"use strict";var n=t("../scatter/colorscale_calc"),a=t("../scatter/calc").calcMarkerSize,i=t("../scattergl/convert"),o=t("../../plots/cartesian/axes"),s=t("../scattergl/constants").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=e._r=c.makeCalcdata(e,"r"),f=e._theta=u.makeCalcdata(e,"theta"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var g,v=d.opts=i.style(t,e);return p<s?g=a(e,p):v.marker&&(g=2*(v.marker.sizeAvg||Math.max(v.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{"../../plots/cartesian/axes":764,"../scatter/calc":1119,"../scatter/colorscale_calc":1121,"../scattergl/constants":1171,"../scattergl/convert":1172}],1199:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("../scatterpolar/defaults").handleRThetaDefaults,o=t("../scatter/marker_defaults"),s=t("../scatter/line_defaults"),l=t("../scatter/text_defaults"),c=t("../scatter/fillcolor_defaults"),u=t("../scatter/constants").PTS_LINESONLY,h=t("./attributes");e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,h,r,a)}var d=i(t,e,f,p);d?(p("thetaunit"),p("mode",d<u?"lines+markers":"lines"),p("text"),p("hovertext"),"fills"!==e.hoveron&&p("hovertemplate"),a.hasLines(e)&&(s(t,e,r,f,p),p("connectgaps")),a.hasMarkers(e)&&o(t,e,r,f,p),a.hasText(e)&&(p("texttemplate"),l(t,e,f,p)),p("fill"),"none"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{"../../lib":716,"../scatter/constants":1122,"../scatter/fillcolor_defaults":1126,"../scatter/line_defaults":1131,"../scatter/marker_defaults":1137,"../scatter/subtypes":1142,"../scatter/text_defaults":1143,"../scatterpolar/defaults":1192,"./attributes":1197}],1200:[function(t,e,r){"use strict";var n=t("../scatterpolar/format_labels");e.exports=function(t,e,r){var a=t.i;return"r"in t||(t.r=e._r[a]),"theta"in t||(t.theta=e._theta[a]),n(t,e,r)}},{"../scatterpolar/format_labels":1193}],1201:[function(t,e,r){"use strict";var n=t("../scattergl/hover"),a=t("../scatterpolar/hover").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,i){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,i);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,a(f,p,h,u),c}}}},{"../scattergl/hover":1176,"../scatterpolar/hover":1194}],1202:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"scatterpolargl",basePlotModule:t("../../plots/polar"),categories:["gl","regl","polar","symbols","showLegend","scatter-like"],attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),plot:t("./plot"),hoverPoints:t("./hover").hoverPoints,selectPoints:t("../scattergl/select"),meta:{}}},{"../../plots/polar":828,"../scatter/marker_colorbar":1136,"../scattergl/select":1180,"./attributes":1197,"./calc":1198,"./defaults":1199,"./format_labels":1200,"./hover":1201,"./plot":1203}],1203:[function(t,e,r){"use strict";var n=t("point-cluster"),a=t("fast-isnumeric"),i=t("../scattergl/plot"),o=t("../scattergl/scene_update"),s=t("../scattergl/convert"),l=t("../../lib"),c=t("../scattergl/constants").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach(function(r){if(r&&r[0]&&r[0].trace){var i,o=r[0],p=o.trace,d=o.t,g=p._length,v=d.r,m=d.theta,y=d.opts,x=v.slice(),b=m.slice();for(i=0;i<v.length;i++)e.isPtInside({r:v[i],theta:m[i]})||(x[i]=NaN,b[i]=NaN);var _=new Array(2*g),w=Array(g),k=Array(g);for(i=0;i<g;i++){var T,A,M=x[i];if(a(M)){var S=u.c2g(M),E=h.c2g(b[i],p.thetaunit);T=S*Math.cos(E),A=S*Math.sin(E)}else T=A=NaN;w[i]=_[2*i]=T,k[i]=_[2*i+1]=A}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!f.fill2d&&(f.fill2d=!0),y.marker&&!f.scatter2d&&(f.scatter2d=!0),y.line&&!f.line2d&&(f.line2d=!0),y.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(y.line),f.fillOptions.push(y.fill),f.markerOptions.push(y.marker),f.markerSelectedOptions.push(y.markerSel),f.markerUnselectedOptions.push(y.markerUnsel),f.textOptions.push(y.text),f.textSelectedOptions.push(y.textSel),f.textUnselectedOptions.push(y.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=k,d.rawx=w,d.rawy=k,d.r=v,d.theta=m,d.positions=_,d._scene=f,d.index=f.count,f.count++}}),i(t,e,r)}}},{"../../lib":716,"../scattergl/constants":1171,"../scattergl/convert":1172,"../scattergl/plot":1178,"../scattergl/scene_update":1179,"fast-isnumeric":227,"point-cluster":470}],1204:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../plots/template_attributes").texttemplateAttrs,i=t("../scatter/attributes"),o=t("../../plots/attributes"),s=t("../../components/colorscale/attributes"),l=t("../../components/drawing/attributes").dash,c=t("../../lib/extend").extendFlat,u=i.marker,h=i.line,f=u.line;e.exports={a:{valType:"data_array",editType:"calc"},b:{valType:"data_array",editType:"calc"},c:{valType:"data_array",editType:"calc"},sum:{valType:"number",dflt:0,min:0,editType:"calc"},mode:c({},i.mode,{dflt:"markers"}),text:c({},i.text,{}),texttemplate:a({editType:"plot"},{keys:["a","b","c","text"]}),hovertext:c({},i.hovertext,{}),line:{color:h.color,width:h.width,dash:l,shape:c({},h.shape,{values:["linear","spline"]}),smoothing:h.smoothing,editType:"calc"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:c({},i.fill,{values:["none","toself","tonext"],dflt:"none"}),fillcolor:i.fillcolor,marker:c({symbol:u.symbol,opacity:u.opacity,maxdisplayed:u.maxdisplayed,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,line:c({width:f.width,editType:"calc"},s("marker.line")),gradient:u.gradient,editType:"calc"},s("marker")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:c({},o.hoverinfo,{flags:["a","b","c","text","name"]}),hoveron:i.hoveron,hovertemplate:n()}},{"../../components/colorscale/attributes":598,"../../components/drawing/attributes":611,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/template_attributes":840,"../scatter/attributes":1118}],1205:[function(t,e,r){"use strict";var n=t("fast-isnumeric"),a=t("../scatter/colorscale_calc"),i=t("../scatter/arrays_to_calcdata"),o=t("../scatter/calc_selection"),s=t("../scatter/calc").calcMarkerSize,l=["a","b","c"],c={a:["b","c"],b:["a","c"],c:["a","b"]};e.exports=function(t,e){var r,u,h,f,p,d,g=t._fullLayout[e.subplot].sum,v=e.sum||g,m={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!m[h=l[r]]){for(p=m[c[h][0]],d=m[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=v-p[u]-d[u];m[h]=f}var y,x,b,_,w,k,T=e._length,A=new Array(T);for(r=0;r<T;r++)y=m.a[r],x=m.b[r],b=m.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),k=y,w=b-x,A[r]={x:w,y:k,a:y,b:x,c:b}):A[r]={x:!1,y:!1};return s(e,T),a(t,e),i(A,e),o(A,e),A}},{"../scatter/arrays_to_calcdata":1117,"../scatter/calc":1119,"../scatter/calc_selection":1120,"../scatter/colorscale_calc":1121,"fast-isnumeric":227}],1206:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/constants"),i=t("../scatter/subtypes"),o=t("../scatter/marker_defaults"),s=t("../scatter/line_defaults"),l=t("../scatter/line_shape_defaults"),c=t("../scatter/text_defaults"),u=t("../scatter/fillcolor_defaults"),h=t("./attributes");e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,h,r,a)}var d,g=p("a"),v=p("b"),m=p("c");if(g?(d=g.length,v?(d=Math.min(d,v.length),m&&(d=Math.min(d,m.length))):d=m?Math.min(d,m.length):0):v&&m&&(d=Math.min(v.length,m.length)),d){e._length=d,p("sum"),p("text"),p("hovertext"),"fills"!==e.hoveron&&p("hovertemplate"),p("mode",d<a.PTS_LINESONLY?"lines+markers":"lines"),i.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p("connectgaps")),i.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),i.hasText(e)&&(p("texttemplate"),c(t,e,f,p));var y=[];(i.hasMarkers(e)||i.hasText(e))&&(p("cliponaxis"),p("marker.maxdisplayed"),y.push("points")),p("fill"),"none"!==e.fill&&(u(t,e,r,p),i.hasLines(e)||l(t,e,p)),"tonext"!==e.fill&&"toself"!==e.fill||y.push("fills"),p("hoveron",y.join("+")||"points"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{"../../lib":716,"../scatter/constants":1122,"../scatter/fillcolor_defaults":1126,"../scatter/line_defaults":1131,"../scatter/line_shape_defaults":1133,"../scatter/marker_defaults":1137,"../scatter/subtypes":1142,"../scatter/text_defaults":1143,"./attributes":1204}],1207:[function(t,e,r){"use strict";e.exports=function(t,e,r,n,a){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[a]){var i=n[a];t.a=i.a,t.b=i.b,t.c=i.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1208:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes");e.exports=function(t,e,r){var a={},i=r[e.subplot]._subplot;return a.aLabel=n.tickText(i.aaxis,t.a,!0).text,a.bLabel=n.tickText(i.baxis,t.b,!0).text,a.cLabel=n.tickText(i.caxis,t.c,!0).text,a}},{"../../plots/cartesian/axes":764}],1209:[function(t,e,r){"use strict";var n=t("../scatter/hover");e.exports=function(t,e,r,a){var i=n(t,e,r,a);if(i&&!1!==i[0].index){var o=i[0];if(void 0===o.index){var s=1-o.y0/t.ya._length,l=t.xa._length,c=l*s/2,u=l-c;return o.x0=Math.max(Math.min(o.x0,u),c),o.x1=Math.max(Math.min(o.x1,u),c),i}var h=o.cd[o.index],f=o.trace,p=o.subplot;o.a=h.a,o.b=h.b,o.c=h.c,o.xLabelVal=void 0,o.yLabelVal=void 0;var d={};d[f.subplot]={_subplot:p};var g=f._module.formatLabels(h,f,d);o.aLabel=g.aLabel,o.bLabel=g.bLabel,o.cLabel=g.cLabel;var v=h.hi||f.hoverinfo,m=[];if(!f.hovertemplate){var y=v.split("+");-1!==y.indexOf("all")&&(y=["a","b","c"]),-1!==y.indexOf("a")&&x(p.aaxis,o.aLabel),-1!==y.indexOf("b")&&x(p.baxis,o.bLabel),-1!==y.indexOf("c")&&x(p.caxis,o.cLabel)}return o.extraText=m.join("<br>"),o.hovertemplate=f.hovertemplate,i}function x(t,e){m.push(t._hovertitle+": "+e)}}},{"../scatter/hover":1129}],1210:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),formatLabels:t("./format_labels"),calc:t("./calc"),plot:t("./plot"),style:t("../scatter/style").style,styleOnSelect:t("../scatter/style").styleOnSelect,hoverPoints:t("./hover"),selectPoints:t("../scatter/select"),eventData:t("./event_data"),moduleType:"trace",name:"scatterternary",basePlotModule:t("../../plots/ternary"),categories:["ternary","symbols","showLegend","scatter-like"],meta:{}}},{"../../plots/ternary":841,"../scatter/marker_colorbar":1136,"../scatter/select":1139,"../scatter/style":1141,"./attributes":1204,"./calc":1205,"./defaults":1206,"./event_data":1207,"./format_labels":1208,"./hover":1209,"./plot":1211}],1211:[function(t,e,r){"use strict";var n=t("../scatter/plot");e.exports=function(t,e,r){var a=e.plotContainer;a.select(".scatterlayer").selectAll("*").remove();var i={xaxis:e.xaxis,yaxis:e.yaxis,plot:a,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select("g.scatterlayer");n(t,i,r,o)}},{"../scatter/plot":1138}],1212:[function(t,e,r){"use strict";var n=t("../scatter/attributes"),a=t("../../components/colorscale/attributes"),i=t("../../plots/template_attributes").hovertemplateAttrs,o=t("../scattergl/attributes"),s=t("../../plots/cartesian/constants").idRegex,l=t("../../plot_api/plot_template").templatedArray,c=t("../../lib/extend").extendFlat,u=n.marker,h=u.line,f=c(a("marker.line",{editTypeOverride:"calc"}),{width:c({},h.width,{editType:"calc"}),editType:"calc"}),p=c(a("marker"),{symbol:u.symbol,size:c({},u.size,{editType:"markerSize"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:f,editType:"calc"});function d(t){return{valType:"info_array",freeLength:!0,editType:"calc",items:{valType:"subplotid",regex:s[t],editType:"plot"}}}p.color.editType=p.cmin.editType=p.cmax.editType="style",e.exports={dimensions:l("dimension",{visible:{valType:"boolean",dflt:!0,editType:"calc"},label:{valType:"string",editType:"calc"},values:{valType:"data_array",editType:"calc+clearAxisTypes"},axis:{type:{valType:"enumerated",values:["linear","log","date","category"],editType:"calc+clearAxisTypes"},matches:{valType:"boolean",dflt:!1,editType:"calc"},editType:"calc+clearAxisTypes"},editType:"calc+clearAxisTypes"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:i(),marker:p,xaxes:d("x"),yaxes:d("y"),diagonal:{visible:{valType:"boolean",dflt:!0,editType:"calc"},editType:"calc"},showupperhalf:{valType:"boolean",dflt:!0,editType:"calc"},showlowerhalf:{valType:"boolean",dflt:!0,editType:"calc"},selected:{marker:o.selected.marker,editType:"calc"},unselected:{marker:o.unselected.marker,editType:"calc"},opacity:o.opacity}},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plot_api/plot_template":754,"../../plots/cartesian/constants":770,"../../plots/template_attributes":840,"../scatter/attributes":1118,"../scattergl/attributes":1169}],1213:[function(t,e,r){"use strict";var n=t("regl-line2d"),a=t("../../registry"),i=t("../../lib/prepare_regl"),o=t("../../plots/get_data").getModuleCalcData,s=t("../../plots/cartesian"),l=t("../../plots/cartesian/axis_ids").getFromId,c=t("../../plots/cartesian/axes").shouldShowZeroLine,u="splom";function h(t,e,r){for(var n=r.matrixOptions.data.length,a=e._visibleDims,i=r.viewOpts.ranges=new Array(n),o=0;o<a.length;o++){var s=a[o],c=i[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:i},{ranges:i}):r.matrix.update({ranges:i})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,a=e._splomGrid;a||(a=e._splomGrid=n(r)),a.update(function(t){var e,r=t._fullLayout,n=r._size,a=[0,0,r.width,r.height],i={};function o(t,e,r,n,o,s){var l=e[t+"color"],c=e[t+"width"],u=String(l+c);u in i?i[u].data.push(NaN,NaN,r,n,o,s):i[u]={data:[r,n,o,s],join:"rect",thickness:c,color:l,viewport:a,range:a,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],h=u.xaxis,f=u.yaxis,p=h._gridVals,d=f._gridVals,g=n.b+f.domain[0]*n.h,v=-f._m,m=-v*f.r2l(f.range[0],f.calendar);if(h.showgrid)for(e=0;e<p.length;e++)s=h._offset+h.l2p(p[e].x),o("grid",h,s,g,s,g+f._length);if(f.showgrid)for(e=0;e<d.length;e++)l=g+m+v*d[e].x,o("grid",f,h._offset,l,h._offset+h._length,l);c(t,h,f)&&(s=h._offset+h.l2p(0),o("zeroline",h,s,g,s,g+f._length)),c(t,f,h)&&(l=g+m+0,o("zeroline",f,h._offset,l,h._offset+h._length,l))}var y=[];for(e in i)y.push(i[e]);return y}(t))}e.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=a.getModule(u),n=o(t.calcdata,r)[0];i(t,["ANGLE_instanced_arrays","OES_element_index_uint"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var a=e[n][0].trace,i=r._splomScenes[a.uid];"splom"===a.type&&i&&i.matrix&&h(t,a,i)}},updateGrid:f,clean:function(t,e,r,n){var a,i={};if(n._splomScenes){for(a=0;a<t.length;a++){var o=t[a];"splom"===o.type&&(i[o.uid]=1)}for(a=0;a<r.length;a++){var l=r[a];if(!i[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{"../../lib/prepare_regl":729,"../../plots/cartesian":775,"../../plots/cartesian/axes":764,"../../plots/cartesian/axis_ids":767,"../../plots/get_data":799,"../../registry":845,"regl-line2d":492}],1214:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axis_ids"),i=t("../scatter/calc").calcMarkerSize,o=t("../scatter/calc").calcAxisExpansion,s=t("../scatter/colorscale_calc"),l=t("../scattergl/convert").markerSelection,c=t("../scattergl/convert").markerStyle,u=t("./scene_update"),h=t("../../constants/numerical").BADNUM,f=t("../scattergl/constants").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,v,m,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],k=e._visibleDims=[];function T(t,r){for(var a=t.makeCalcdata({v:r.values,vcalendar:e.calendar},"v"),i=0;i<a.length;i++)a[i]=a[i]===h?NaN:a[i];_.push(a),w.push("log"===t.type?n.simpleMap(a,t.c2l):a)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=a.getFromId(t,e._diag[r][0]),v=a.getFromId(t,e._diag[r][1]),g&&v&&g.type!==v.type){n.log("Skipping splom dimension "+r+" with conflicting axis types");continue}g?(T(g,d),v&&"category"===v.type&&(v._categories=g._categories.slice())):T(v,d),k.push(r)}for(s(t,e),n.extendFlat(b,c(e)),m=_.length*x>f?2*(b.sizeAvg||Math.max(b.size,3)):i(e,x),p=0;p<k.length;p++)d=y[r=k[p]],g=a.getFromId(t,e._diag[r][0])||{},v=a.getFromId(t,e._diag[r][1])||{},o(t,e,g,v,_[p],_[p],m);var A=u(t,e);return A.matrix||(A.matrix=!0),A.matrixOptions=b,A.selectedOptions=l(e,e.selected),A.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{"../../constants/numerical":692,"../../lib":716,"../../plots/cartesian/axis_ids":767,"../scatter/calc":1119,"../scatter/colorscale_calc":1121,"../scattergl/constants":1171,"../scattergl/convert":1172,"./scene_update":1221}],1215:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/array_container_defaults"),i=t("./attributes"),o=t("../scatter/subtypes"),s=t("../scatter/marker_defaults"),l=t("../parcoords/merge_length"),c=/-open/;function u(t,e){function r(r,a){return n.coerce(t,e,i.dimensions,r,a)}r("label");var a=r("values");a&&a.length?r("visible"):e.visible=!1,r("axis.type"),r("axis.matches")}e.exports=function(t,e,r,h){function f(r,a){return n.coerce(t,e,i,r,a)}var p=a(t,e,{name:"dimensions",handleItemDefaults:u}),d=f("diagonal.visible"),g=f("showupperhalf"),v=f("showlowerhalf");if(l(e,p,"values")&&(d||g||v)){f("text"),f("hovertext"),f("hovertemplate"),s(t,e,r,h,f);var m=c.test(e.marker.symbol),y=o.isBubble(e);f("marker.line.width",m||y?1:0),function(t,e,r,n){var a,i,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(a=0;a<s;a++){var p=a?a+1:"";h[a]="x"+p,f[a]="y"+p}var d=n("xaxes",h),g=n("yaxes",f),v=e._diag=new Array(s);e._xaxes={},e._yaxes={};var m=[],y=[];function x(t,n,a,i){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e["_"+o+"axes"][t]=1,i.push(t),!(t in s)){var l=s[t]={};a&&(l.label=a.label||"",a.visible&&a.axis&&(a.axis.type&&(l.type=a.axis.type),a.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},a=0;a<s;a++){var w=o[a],k=0===a,T=a===s-1,A=k&&b||T&&_?void 0:d[a],M=k&&_||T&&b?void 0:g[a];x(A,M,w,m),x(M,A,w,y),v[a]=[A,M],e._axesDim[A]=a,e._axesDim[M]=a}for(a=0;a<m.length;a++)for(i=0;i<y.length;i++){var S=m[a]+y[i];a>i&&l?r._splomSubplots[S]=1:a<i&&c?r._splomSubplots[S]=1:a!==i||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside="bottom",r._splomGridDflt.yside="left")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{"../../lib":716,"../../plots/array_container_defaults":760,"../parcoords/merge_length":1089,"../scatter/marker_defaults":1137,"../scatter/subtypes":1142,"./attributes":1212}],1216:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/colorscale_calc"),i=t("../scattergl/convert").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){a(t,r),n.extendFlat(o.matrixOptions,i(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{"../../lib":716,"../scatter/colorscale_calc":1121,"../scattergl/convert":1172}],1217:[function(t,e,r){"use strict";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],a=t._visibleDims,i=0;i<a.length;i++){var o=a[i];if(t._diag[o][n]===r)return i}return!1}},{}],1218:[function(t,e,r){"use strict";var n=t("./helpers"),a=t("../scattergl/hover").calcHover;e.exports={hoverPoints:function(t,e,r){var i=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),h=t.distance,f=n.getDimIndex(i,s),p=n.getDimIndex(i,l);if(!1===f||!1===p)return[t];for(var d,g,v=o[f],m=o[p],y=h,x=0;x<v.length;x++){var b=v[x],_=m[x],w=s.c2p(b)-c,k=l.c2p(_)-u,T=Math.sqrt(w*w+k*k);T<y&&(y=g=T,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:[a(t,v,m,i)]}}},{"../scattergl/hover":1176,"./helpers":1217}],1219:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../components/grid");e.exports={moduleType:"trace",name:"splom",basePlotModule:t("./base_plot"),categories:["gl","regl","cartesian","symbols","showLegend","scatter-like"],attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:t("../scatter/marker_colorbar"),calc:t("./calc"),plot:t("./plot"),hoverPoints:t("./hover").hoverPoints,selectPoints:t("./select"),editStyle:t("./edit_style"),meta:{}},n.register(a)},{"../../components/grid":633,"../../registry":845,"../scatter/marker_colorbar":1136,"./attributes":1212,"./base_plot":1213,"./calc":1214,"./defaults":1215,"./edit_style":1216,"./hover":1218,"./plot":1220,"./select":1222}],1220:[function(t,e,r){"use strict";var n=t("regl-splom"),a=t("../../lib"),i=t("../../plots/cartesian/axis_ids");function o(t,e){var r,o,s,l,c,u=t._fullLayout,h=u._size,f=e.trace,p=e.t,d=u._splomScenes[f.uid],g=d.matrixOptions,v=g.cdata,m=u._glcanvas.data()[0].regl,y=u.dragmode;if(0!==v.length){g.lower=f.showupperhalf,g.upper=f.showlowerhalf,g.diagonal=f.diagonal.visible;var x=f._visibleDims,b=v.length,_=d.viewOpts={};for(_.ranges=new Array(b),_.domains=new Array(b),c=0;c<x.length;c++){s=x[c];var w=_.ranges[c]=new Array(4),k=_.domains[c]=new Array(4);(r=i.getFromId(t,f._diag[s][0]))&&(w[0]=r._rl[0],w[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(o=i.getFromId(t,f._diag[s][1]))&&(w[1]=o._rl[0],w[3]=o._rl[1],k[1]=o.domain[0],k[3]=o.domain[1])}_.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===d.matrix&&(d.matrix=n(m));var T=u.clickmode.indexOf("select")>-1,A=!0;if("lasso"===y||"select"===y||!!f.selectedpoints||T){var M=f._length;if(f.selectedpoints){d.selectBatch=f.selectedpoints;var S=f.selectedpoints,E={};for(s=0;s<S.length;s++)E[S[s]]=!0;var L=[];for(s=0;s<M;s++)E[s]||L.push(s);d.unselectBatch=L}var C=p.xpx=new Array(b),P=p.ypx=new Array(b);for(c=0;c<x.length;c++){if(s=x[c],r=i.getFromId(t,f._diag[s][0]))for(C[c]=new Array(M),l=0;l<M;l++)C[c][l]=r.c2p(v[c][l]);if(o=i.getFromId(t,f._diag[s][1]))for(P[c]=new Array(M),l=0;l<M;l++)P[c][l]=o.c2p(v[c][l])}if(d.selectBatch.length||d.unselectBatch.length){var O=a.extendFlat({},g,d.unselectedOptions,_),z=a.extendFlat({},g,d.selectedOptions,_);d.matrix.update(O,z),A=!1}}else p.xpx=p.ypx=null;if(A){var I=a.extendFlat({},g,_);d.matrix.update(I,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)o(t,r[n][0])}},{"../../lib":716,"../../plots/cartesian/axis_ids":767,"regl-splom":499}],1221:[function(t,e,r){"use strict";var n=t("../../lib");e.exports=function(t,e){var r=t._fullLayout,a=e.uid,i=r._splomScenes;i||(i=r._splomScenes={});var o={dirty:!0},s=i[e.uid];return s||((s=i[a]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{"../../lib":716}],1222:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../scatter/subtypes"),i=t("./helpers");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,h=t.yaxis,f=[];if(!l)return f;var p=!a.hasMarkers(o)&&!a.hasText(o);if(!0!==o.visible||p)return f;var d=i.getDimIndex(o,u),g=i.getDimIndex(o,h);if(!1===d||!1===g)return f;var v=s.xpx[d],m=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([v[w],m[w]],null,w,t)?(b.push(w),f.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var k=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},k,l.selectedOptions,l.viewOpts)):l.matrix.update(k,null),l.selectBatch=b,l.unselectBatch=_,f}},{"../../lib":716,"../scatter/subtypes":1142,"./helpers":1217}],1223:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../mesh3d/attributes"),o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat,l={x:{valType:"data_array",editType:"calc+clearAxisTypes"},y:{valType:"data_array",editType:"calc+clearAxisTypes"},z:{valType:"data_array",editType:"calc+clearAxisTypes"},u:{valType:"data_array",editType:"calc"},v:{valType:"data_array",editType:"calc"},w:{valType:"data_array",editType:"calc"},starts:{x:{valType:"data_array",editType:"calc"},y:{valType:"data_array",editType:"calc"},z:{valType:"data_array",editType:"calc"},editType:"calc"},maxdisplayed:{valType:"integer",min:0,dflt:1e3,editType:"calc"},sizeref:{valType:"number",editType:"calc",min:0,dflt:1},text:{valType:"string",dflt:"",editType:"calc"},hovertext:{valType:"string",dflt:"",editType:"calc"},hovertemplate:a({editType:"calc"},{keys:["tubex","tubey","tubez","tubeu","tubev","tubew","norm","divergence"]})};s(l,n("",{colorAttr:"u/v/w norm",showScaleDflt:!0,editTypeOverride:"calc"}));["opacity","lightposition","lighting"].forEach(function(t){l[t]=i[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:"calc",flags:["x","y","z","u","v","w","norm","divergence","text","name"],dflt:"x+y+z+norm+text+name"}),l.transforms=void 0,e.exports=l},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/template_attributes":840,"../mesh3d/attributes":1059}],1224:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/calc");function i(t){return n.distinctVals(t).vals}e.exports=function(t,e){var r,o,s,l,c,u,h=e.u,f=e.v,p=e.w,d=e.x,g=e.y,v=e.z,m=Math.min(d.length,g.length,v.length,h.length,f.length,p.length),y=0;e.starts&&(l=e.starts.x||[],c=e.starts.y||[],u=e.starts.z||[],y=Math.min(l.length,c.length,u.length));var x=0,b=1/0;for(r=0;r<m;r++){var _=h[r],w=f[r],k=p[r],T=Math.sqrt(_*_+w*w+k*k);x=Math.max(x,T),b=Math.min(b,T)}a(t,e,{vals:[b,x],containerStr:"",cLetter:"c"});var A,M,S,E,L,C,P=-1/0,O=1/0,z=-1/0,I=1/0,D=-1/0,R=1/0,F="";for(m&&(E=d[0],L=g[0],C=v[0]),r=0;r<m;r++)P=Math.max(P,d[r]),O=Math.min(O,d[r]),z=Math.max(z,g[r]),I=Math.min(I,g[r]),D=Math.max(D,v[r]),R=Math.min(R,v[r]),A||d[r]===E||(A=!0,F+="x"),M||g[r]===L||(M=!0,F+="y"),S||v[r]===C||(S=!0,F+="z");A||(F+="x"),M||(F+="y"),S||(F+="z");var B=i(e.x.slice(0,m)),N=i(e.y.slice(0,m)),j=i(e.z.slice(0,m));F=(F=(F=F.replace("x",(d[0]>d[m-1]?"-":"+")+"x")).replace("y",(g[0]>g[m-1]?"-":"+")+"y")).replace("z",(v[0]>v[m-1]?"-":"+")+"z");var V=function(){m=0,B=[],N=[],j=[]};(!m||m<B.length*N.length*j.length)&&V();var U=function(t){return"x"===t?d:"y"===t?g:v},q=function(t){return"x"===t?B:"y"===t?N:j},H=function(t){return t[m-1]<t[0]?-1:1},G=U(F[1]),Y=U(F[3]),W=U(F[5]),X=q(F[1]).length,Z=q(F[3]).length,J=q(F[5]).length,K=!1,Q=function(t,e,r){return X*(Z*t+e)+r},$=H(U(F[1])),tt=H(U(F[3])),et=H(U(F[5]));for(r=0;r<J-1;r++){for(o=0;o<Z-1;o++){for(s=0;s<X-1;s++){var rt=Q(r,o,s),nt=Q(r,o,s+1),at=Q(r,o+1,s),it=Q(r+1,o,s);if(G[rt]*$<G[nt]*$&&Y[rt]*tt<Y[at]*tt&&W[rt]*et<W[it]*et||(K=!0),K)break}if(K)break}if(K)break}for(K&&(n.warn("Encountered arbitrary coordinates! Unable to input data grid."),V()),r=0;r<y;r++){var ot=l[r];P=Math.max(P,ot),O=Math.min(O,ot);var st=c[r];z=Math.max(z,st),I=Math.min(I,st);var lt=u[r];D=Math.max(D,lt),R=Math.min(R,lt)}e._len=m,e._slen=y,e._normMax=x,e._xbnds=[O,P],e._ybnds=[I,z],e._zbnds=[R,D],e._Xs=B,e._Ys=N,e._Zs=j,e._gridFill=F}},{"../../components/colorscale/calc":599,"../../lib":716}],1225:[function(t,e,r){"use strict";var n=t("gl-streamtube3d"),a=n.createTubeMesh,i=t("../../lib"),o=t("../../lib/gl_format_color").parseColorScale,s=t("../../components/colorscale").extractOpts,l=t("../../plots/gl3d/zip3"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function p(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function d(t,e){var r=t.fullSceneLayout,a=t.dataScale,u=e._len,h={};function d(t,e){var n=r[e],o=a[c[e]];return i.simpleMap(t,function(t){return n.d2l(t)*o})}if(h.vectors=l(d(e.u,"xaxis"),d(e.v,"yaxis"),d(e.w,"zaxis"),u),!u)return{positions:[],cells:[]};var g=d(e._Xs,"xaxis"),v=d(e._Ys,"yaxis"),m=d(e._Zs,"zaxis");h.meshgrid=[g,v,m],h.gridFill=e._gridFill;var y=e._slen;if(y)h.startingPositions=l(d(e.starts.x.slice(0,y),"xaxis"),d(e.starts.y.slice(0,y),"yaxis"),d(e.starts.z.slice(0,y),"zaxis"));else{for(var x=v[0],b=f(g),_=f(m),w=new Array(b.length*_.length),k=0,T=0;T<b.length;T++)for(var A=0;A<_.length;A++)w[k++]=[b[T],x,_[A]];h.startingPositions=w}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var M=d(e._xbnds,"xaxis"),S=d(e._ybnds,"yaxis"),E=d(e._zbnds,"zaxis"),L=p(g),C=p(v),P=p(m),O=[[M[0]-L[0],S[0]-C[0],E[0]-P[0]],[M[1]+L[1],S[1]+C[1],E[1]+P[1]]],z=n(h,O),I=s(e);z.vertexIntensityBounds=[I.min/e._normMax,I.max/e._normMax];var D=e.lightposition;return z.lightPosition=[D.x,D.y,D.z],z.ambient=e.lighting.ambient,z.diffuse=e.lighting.diffuse,z.specular=e.lighting.specular,z.roughness=e.lighting.roughness,z.fresnel=e.lighting.fresnel,z.opacity=e.opacity,e._pad=z.tubeScale*e.sizeref*2,z}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var a=e[n],i=r[c[n]];return a.l2c(t)/i}if(t.object===this.mesh){var a=t.data.position,i=t.data.velocity;return t.traceCoordinate=[n(a[0],"xaxis"),n(a[1],"yaxis"),n(a[2],"zaxis"),n(i[0],"xaxis"),n(i[1],"yaxis"),n(i[2],"zaxis"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),i=a(r,n),o=new u(t,e.uid);return o.mesh=i,o.data=e,i._trace=o,t.glplot.add(i),o}},{"../../components/colorscale":603,"../../lib":716,"../../lib/gl_format_color":713,"../../plots/gl3d/zip3":815,"gl-streamtube3d":314}],1226:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/colorscale/defaults"),i=t("./attributes");e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}var l=s("u"),c=s("v"),u=s("w"),h=s("x"),f=s("y"),p=s("z");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s("starts.x"),s("starts.y"),s("starts.z"),s("maxdisplayed"),s("sizeref"),s("lighting.ambient"),s("lighting.diffuse"),s("lighting.specular"),s("lighting.roughness"),s("lighting.fresnel"),s("lightposition.x"),s("lightposition.y"),s("lightposition.z"),a(t,e,o,s,{prefix:"",cLetter:"c"}),s("text"),s("hovertext"),s("hovertemplate"),e._length=null):e.visible=!1}},{"../../components/colorscale/defaults":601,"../../lib":716,"./attributes":1223}],1227:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"streamtube",basePlotModule:t("../../plots/gl3d"),categories:["gl3d"],attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:{min:"cmin",max:"cmax"},calc:t("./calc"),plot:t("./convert"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{"../../plots/gl3d":804,"./attributes":1223,"./calc":1224,"./convert":1225,"./defaults":1226}],1228:[function(t,e,r){"use strict";var n=t("../../plots/attributes"),a=t("../../plots/template_attributes").hovertemplateAttrs,i=t("../../plots/template_attributes").texttemplateAttrs,o=t("../../components/colorscale/attributes"),s=t("../../plots/domain").attributes,l=t("../pie/attributes"),c=t("./constants"),u=t("../../lib/extend").extendFlat;e.exports={labels:{valType:"data_array",editType:"calc"},parents:{valType:"data_array",editType:"calc"},values:{valType:"data_array",editType:"calc"},branchvalues:{valType:"enumerated",values:["remainder","total"],dflt:"remainder",editType:"calc"},count:{valType:"flaglist",flags:["branches","leaves"],dflt:"leaves",editType:"calc"},level:{valType:"any",editType:"plot",anim:!0},maxdepth:{valType:"integer",editType:"plot",dflt:-1},marker:u({colors:{valType:"data_array",editType:"calc"},line:{color:u({},l.marker.line.color,{dflt:null}),width:u({},l.marker.line.width,{dflt:1}),editType:"calc"},editType:"calc"},o("marker",{colorAttr:"colors",anim:!1})),leaf:{opacity:{valType:"number",editType:"style",min:0,max:1},editType:"plot"},text:l.text,textinfo:{valType:"flaglist",flags:["label","text","value","current path","percent root","percent entry","percent parent"],extras:["none"],editType:"plot"},texttemplate:i({editType:"plot"},{keys:c.eventDataKeys.concat(["label","value"])}),hovertext:l.hovertext,hoverinfo:u({},n.hoverinfo,{flags:["label","text","value","name","current path","percent root","percent entry","percent parent"],dflt:"label+text+value+name"}),hovertemplate:a({},{keys:c.eventDataKeys}),textfont:l.textfont,insidetextfont:l.insidetextfont,outsidetextfont:l.outsidetextfont,domain:s({name:"sunburst",trace:!0,editType:"calc"})}},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/domain":789,"../../plots/template_attributes":840,"../pie/attributes":1092,"./constants":1231}],1229:[function(t,e,r){"use strict";var n=t("../../plots/plots");r.name="sunburst",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{"../../plots/plots":825}],1230:[function(t,e,r){"use strict";var n=t("d3-hierarchy"),a=t("fast-isnumeric"),i=t("../../lib"),o=t("../../components/colorscale").makeColorScaleFuncFromTrace,s=t("../pie/calc").makePullColorFn,l=t("../pie/calc").generateExtendedColors,c=t("../../components/colorscale").calc,u={},h={};r.calc=function(t,e){var r,l,u,h,f,p,d=t._fullLayout,g=e.ids,v=i.isArrayOrTypedArray(g),m=e.labels,y=e.parents,x=e.values,b=i.isArrayOrTypedArray(x),_=[],w={},k={},T=function(t){return t||"number"==typeof t},A=function(t){return!b||a(x[t])&&x[t]>=0};v?(r=Math.min(g.length,y.length),l=function(t){return T(g[t])&&A(t)},u=function(t){return String(g[t])}):(r=Math.min(m.length,y.length),l=function(t){return T(m[t])&&A(t)},u=function(t){return String(m[t])}),b&&(r=Math.min(r,x.length));for(var M=0;M<r;M++)if(l(M)){var S=u(M),E=T(y[M])?String(y[M]):"",L={i:M,id:S,pid:E,label:T(m[M])?String(m[M]):""};b&&(L.v=+x[M]),_.push(L),f=S,w[h=E]?w[h].push(f):w[h]=[f],k[f]=1}if(w[""]){if(w[""].length>1){for(var C=i.randstr(),P=0;P<_.length;P++)""===_[P].pid&&(_[P].pid=C);_.unshift({hasMultipleRoots:!0,id:C,pid:"",label:""})}}else{var O,z=[];for(O in w)k[O]||z.push(O);if(1!==z.length)return i.warn("Multiple implied roots, cannot build "+e.type+" hierarchy.");O=z[0],_.unshift({hasImpliedRoot:!0,id:O,pid:"",label:O})}try{p=n.stratify().id(function(t){return t.id}).parentId(function(t){return t.pid})(_)}catch(t){return i.warn("Failed to build "+e.type+" hierarchy. Error: "+t.message)}var I=n.hierarchy(p),D=!1;if(b)switch(e.branchvalues){case"remainder":I.sum(function(t){return t.data.v});break;case"total":I.each(function(t){var e=t.data.data,r=e.v;if(t.children){var n=t.children.reduce(function(t,e){return t+e.data.data.v},0);if((e.hasImpliedRoot||e.hasMultipleRoots)&&(r=n),r<n)return D=!0,i.warn(["Total value for node",t.data.data.id,"is smaller than the sum of its children.","\nparent value =",r,"\nchildren sum =",n].join(" "))}t.value=r})}else!function t(e,r,n){var a=0;var i=e.children;if(i){for(var o=i.length,s=0;s<o;s++)a+=t(i[s],r,n);n.branches&&a++}else n.leaves&&a++;e.value=e.data.data.value=a;r._values||(r._values=[]);r._values[e.data.data.i]=a;return a}(I,e,{branches:-1!==e.count.indexOf("branches"),leaves:-1!==e.count.indexOf("leaves")});if(!D){var R,F;I.sort(function(t,e){return e.value-t.value});var B=e.marker.colors||[],N=!!B.length;return e._hasColorscale?(N||(B=b?e.values:e._values),c(t,e,{vals:B,containerStr:"marker",cLetter:"c"}),F=o(e.marker)):R=s(d["_"+e.type+"colormap"]),I.each(function(t){var r=t.data.data;r.color=e._hasColorscale?F(B[r.i]):R(B[r.i],r.id)}),_[0].hierarchy=I,_}},r._runCrossTraceCalc=function(t,e){var r=e._fullLayout,n=e.calcdata,a=r[t+"colorway"],i=r["_"+t+"colormap"];r["extend"+t+"colors"]&&(a=l(a,"treemap"===t?h:u));var o=0;function s(t){var e=t.data.data,r=e.id;!1===e.color&&(i[r]?e.color=i[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(i[r]=e.color=a[o%a.length],o++):e.color="rgba(0,0,0,0)")}for(var c=0;c<n.length;c++){var f=n[c][0];f.trace.type===t&&f.hierarchy&&f.hierarchy.each(s)}},r.crossTraceCalc=function(t){return r._runCrossTraceCalc("sunburst",t)}},{"../../components/colorscale":603,"../../lib":716,"../pie/calc":1094,"d3-hierarchy":158,"fast-isnumeric":227}],1231:[function(t,e,r){"use strict";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:"linear",eventDataKeys:["currentPath","root","entry","percentRoot","percentEntry","percentParent"]}},{}],1232:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../plots/domain").defaults,o=t("../bar/defaults").handleText,s=t("../../components/colorscale"),l=s.hasColorscale,c=s.handleDefaults;e.exports=function(t,e,r,s){function u(r,i){return n.coerce(t,e,a,r,i)}var h=u("labels"),f=u("parents");if(h&&h.length&&f&&f.length){var p=u("values");p&&p.length?u("branchvalues"):u("count"),u("level"),u("maxdepth"),u("marker.line.width")&&u("marker.line.color",s.paper_bgcolor),u("marker.colors");var d=e._hasColorscale=l(t,"marker","colors");d&&c(t,e,s,u,{prefix:"marker.",cLetter:"c"}),u("leaf.opacity",d?1:.7);var g=u("text");u("texttemplate"),e.texttemplate||u("textinfo",Array.isArray(g)?"text+label":"label"),u("hovertext"),u("hovertemplate");o(t,e,s,u,"auto",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),i(e,s,u),e._length=null}else e.visible=!1}},{"../../components/colorscale":603,"../../lib":716,"../../plots/domain":789,"../bar/defaults":859,"./attributes":1228}],1233:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../registry"),i=t("../../components/fx/helpers").appendArrayPointValue,o=t("../../components/fx"),s=t("../../lib"),l=t("../../lib/events"),c=t("./helpers"),u=t("../pie/helpers").formatPieValue;function h(t,e,r){for(var n=t.data.data,a={curveNumber:e.index,pointNumber:n.i,data:e._input,fullData:e},o=0;o<r.length;o++){var s=r[o];s in t&&(a[s]=t[s])}return"parentString"in t&&!c.isHierarchyRoot(t)&&(a.parent=t.parentString),i(a,e,n.i),a}e.exports=function(t,e,r,i,f){var p=i[0],d=p.trace,g=p.hierarchy,v="sunburst"===d.type,m="treemap"===d.type;"_hasHoverLabel"in d||(d._hasHoverLabel=!1),"_hasHoverEvent"in d||(d._hasHoverEvent=!1);t.on("mouseover",function(a){var i=r._fullLayout;if(!r._dragging&&!1!==i.hovermode){var l=r._fullData[d.index],y=a.data.data,x=y.i,b=c.isHierarchyRoot(a),_=c.getParent(g,a),w=c.getValue(a),k=function(t){return s.castOption(l,x,t)},T=k("hovertemplate"),A=o.castHoverinfo(l,i,x),M=i.separators;if(T||A&&"none"!==A&&"skip"!==A){var S,E;v&&(S=p.cx+a.pxmid[0]*(1-a.rInscribed),E=p.cy+a.pxmid[1]*(1-a.rInscribed)),m&&(S=a._hoverX,E=a._hoverY);var L,C={},P=[],O=[],z=function(t){return-1!==P.indexOf(t)};A&&(P="all"===A?l._module.attributes.hoverinfo.flags:A.split("+")),C.label=y.label,z("label")&&C.label&&O.push(C.label),y.hasOwnProperty("v")&&(C.value=y.v,C.valueLabel=u(C.value,M),z("value")&&O.push(C.valueLabel)),C.currentPath=a.currentPath=c.getPath(a.data),z("current path")&&!b&&O.push(C.currentPath);var I=[],D=function(){-1===I.indexOf(L)&&(O.push(L),I.push(L))};C.percentParent=a.percentParent=w/c.getValue(_),C.parent=a.parentString=c.getPtLabel(_),z("percent parent")&&(L=c.formatPercent(C.percentParent,M)+" of "+C.parent,D()),C.percentEntry=a.percentEntry=w/c.getValue(e),C.entry=a.entry=c.getPtLabel(e),!z("percent entry")||b||a.onPathbar||(L=c.formatPercent(C.percentEntry,M)+" of "+C.entry,D()),C.percentRoot=a.percentRoot=w/c.getValue(g),C.root=a.root=c.getPtLabel(g),z("percent root")&&!b&&(L=c.formatPercent(C.percentRoot,M)+" of "+C.root,D()),C.text=k("hovertext")||k("text"),z("text")&&(L=C.text,s.isValidTextValue(L)&&O.push(L));var R={trace:l,y:E,text:O.join("<br>"),name:T||z("name")?l.name:void 0,color:k("hoverlabel.bgcolor")||y.color,borderColor:k("hoverlabel.bordercolor"),fontFamily:k("hoverlabel.font.family"),fontSize:k("hoverlabel.font.size"),fontColor:k("hoverlabel.font.color"),nameLength:k("hoverlabel.namelength"),textAlign:k("hoverlabel.align"),hovertemplate:T,hovertemplateLabels:C,eventData:[h(a,l,f.eventDataKeys)]};v&&(R.x0=S-a.rInscribed*a.rpx1,R.x1=S+a.rInscribed*a.rpx1,R.idealAlign=a.pxmid[0]<0?"left":"right"),m&&(R.x=S,R.idealAlign=S<0?"left":"right"),o.loneHover(R,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r}),d._hasHoverLabel=!0}if(m){var F=t.select("path.surface");f.styleOne(F,a,l,{hovered:!0})}d._hasHoverEvent=!0,r.emit("plotly_hover",{points:[h(a,l,f.eventDataKeys)],event:n.event})}}),t.on("mouseout",function(e){var a=r._fullLayout,i=r._fullData[d.index],s=n.select(this).datum();if(d._hasHoverEvent&&(e.originalEvent=n.event,r.emit("plotly_unhover",{points:[h(s,i,f.eventDataKeys)],event:n.event}),d._hasHoverEvent=!1),d._hasHoverLabel&&(o.loneUnhover(a._hoverlayer.node()),d._hasHoverLabel=!1),m){var l=t.select("path.surface");f.styleOne(l,s,i,{hovered:!1})}}),t.on("click",function(t){var e=r._fullLayout,i=r._fullData[d.index];if(!1===l.triggerHandler(r,"plotly_"+d.type+"click",{points:[h(t,i,f.eventDataKeys)],event:n.event})||v&&(c.isHierarchyRoot(t)||c.isLeaf(t)))e.hovermode&&(r._hoverdata=[h(t,i,f.eventDataKeys)],o.click(r,n.event));else if(!r._dragging&&!r._transitioning){a.call("_storeDirectGUIEdit",i,e._tracePreGUI[i.uid],{level:i.level});var s=c.getPtId(t),u=c.isEntry(t)?c.findEntryWithChild(g,s):c.findEntryWithLevel(g,s),p={data:[{level:c.getPtId(u)}],traces:[d.index]},m={frame:{redraw:!1,duration:f.transitionTime},transition:{duration:f.transitionTime,easing:f.transitionEasing},mode:"immediate",fromcurrent:!0};o.loneUnhover(e._hoverlayer.node()),a.call("animate",r,p,m)}})}},{"../../components/fx":629,"../../components/fx/helpers":626,"../../lib":716,"../../lib/events":706,"../../registry":845,"../pie/helpers":1097,"./helpers":1234,d3:164}],1234:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../../lib/setcursor"),o=t("../pie/helpers");function s(t){return t.data.data.pid}r.findEntryWithLevel=function(t,e){var n;return e&&t.eachAfter(function(t){if(r.getPtId(t)===e)return n=t.copy()}),n||t},r.findEntryWithChild=function(t,e){var n;return t.eachAfter(function(t){for(var a=t.children||[],i=0;i<a.length;i++){var o=a[i];if(r.getPtId(o)===e)return n=t.copy()}}),n||t},r.isEntry=function(t){return!t.parent},r.isLeaf=function(t){return!t.children},r.getPtId=function(t){return t.data.data.id},r.getPtLabel=function(t){return t.data.data.label},r.getValue=function(t){return t.value},r.isHierarchyRoot=function(t){return""===s(t)},r.setSliceCursor=function(t,e,n){var a=n.isTransitioning;if(!a){var o=t.datum();a=n.hideOnRoot&&r.isHierarchyRoot(o)||n.hideOnLeaves&&r.isLeaf(o)}i(t,a?null:"pointer")},r.getInsideTextFontKey=function(t,e,r,a){var i=r.data.data.i;return n.castOption(e,i,"insidetextfont."+t)||n.castOption(e,i,"textfont."+t)||a.size},r.getOutsideTextFontKey=function(t,e,r,a){var i=r.data.data.i;return n.castOption(e,i,"outsidetextfont."+t)||n.castOption(e,i,"textfont."+t)||a.size},r.isOutsideText=function(t,e){return!t._hasColorscale&&r.isHierarchyRoot(e)},r.determineTextFont=function(t,e,i,o){return r.isOutsideText(t,e)?function(t,e,n){return{color:r.getOutsideTextFontKey("color",t,e,n),family:r.getOutsideTextFontKey("family",t,e,n),size:r.getOutsideTextFontKey("size",t,e,n)}}(t,e,i):function(t,e,i,o){var s=e.data.data,l=s.i,c=n.castOption(t,l,"insidetextfont.color");return!c&&t._input.textfont&&(c=n.castOption(t._input,l,"textfont.color")),{color:c||a.contrast(s.color),family:r.getInsideTextFontKey("family",o||t,e,i),size:r.getInsideTextFontKey("size",o||t,e,i)}}(t,e,i,o)},r.hasTransition=function(t){return!!(t&&t.duration>0)},r.getMaxDepth=function(t){return t.maxdepth>=0?t.maxdepth:1/0},r.isHeader=function(t,e){return!(r.isLeaf(t)||t.depth===e._maxDepth-1)},r.getParent=function(t,e){return r.findEntryWithLevel(t,s(e))},r.listPath=function(t,e){var n=t.parent;if(!n)return[];var a=e?[n.data[e]]:[n];return r.listPath(n,e).concat(a)},r.getPath=function(t){return r.listPath(t,"label").join("/")+"/"},r.formatValue=o.formatPieValue,r.formatPercent=function(t,e){var r=n.formatPercent(t,0);return"0%"===r&&(r=o.formatPiePercent(t,e)),r}},{"../../components/color":591,"../../lib":716,"../../lib/setcursor":736,"../pie/helpers":1097}],1235:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"sunburst",basePlotModule:t("./base_plot"),categories:[],animatable:!0,attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults"),supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc").calc,crossTraceCalc:t("./calc").crossTraceCalc,plot:t("./plot").plot,style:t("./style").style,colorbar:t("../scatter/marker_colorbar"),meta:{}}},{"../scatter/marker_colorbar":1136,"./attributes":1228,"./base_plot":1229,"./calc":1230,"./defaults":1232,"./layout_attributes":1236,"./layout_defaults":1237,"./plot":1238,"./style":1239}],1236:[function(t,e,r){"use strict";e.exports={sunburstcolorway:{valType:"colorlist",editType:"calc"},extendsunburstcolors:{valType:"boolean",dflt:!0,editType:"calc"}}},{}],1237:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r("sunburstcolorway",e.colorway),r("extendsunburstcolors")}},{"../../lib":716,"./layout_attributes":1236}],1238:[function(t,e,r){"use strict";var n=t("d3"),a=t("d3-hierarchy"),i=t("../../components/drawing"),o=t("../../lib"),s=t("../../lib/svg_text_utils"),l=t("../pie/plot").transformInsideText,c=t("./style").styleOne,u=t("./fx"),h=t("./constants"),f=t("./helpers");function p(t,e,p,d){var g=t._fullLayout,v=f.hasTransition(d),m=n.select(p).selectAll("g.slice"),y=e[0],x=y.trace,b=y.hierarchy,_=f.findEntryWithLevel(b,x.level),w=f.getMaxDepth(x),k=g._size,T=x.domain,A=k.w*(T.x[1]-T.x[0]),M=k.h*(T.y[1]-T.y[0]),S=.5*Math.min(A,M),E=y.cx=k.l+k.w*(T.x[1]+T.x[0])/2,L=y.cy=k.t+k.h*(1-T.y[0])-M/2;if(!_)return m.remove();var C=null,P={};v&&m.each(function(t){P[f.getPtId(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!C&&f.isEntry(t)&&(C=t)});var O=function(t){return a.partition().size([2*Math.PI,t.height+1])(t)}(_).descendants(),z=_.height+1,I=0,D=w;y.hasMultipleRoots&&f.isHierarchyRoot(_)&&(O=O.slice(1),z-=1,I=1,D+=1),O=O.filter(function(t){return t.y1<=D});var R=Math.min(z,w),F=function(t){return(t-I)/R*S},B=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},N=function(t){return o.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,E,L)},j=function(t){return E+t.pxmid[0]*t.transform.rCenter+(t.transform.x||0)},V=function(t){return L+t.pxmid[1]*t.transform.rCenter+(t.transform.y||0)};(m=m.data(O,f.getPtId)).enter().append("g").classed("slice",!0),v?m.exit().transition().each(function(){var t=n.select(this);t.select("path.surface").transition().attrTween("d",function(t){var e=function(t){var e,r=f.getPtId(t),a=P[r],i=P[f.getPtId(_)];if(i){var o=t.x1>i.x1?2*Math.PI:0;e=t.rpx1<i.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=f.getPtId(t.parent);m.each(function(t){if(f.getPtId(t)===l)return s=t});var c,u=s.children;u.forEach(function(t,e){if(f.getPtId(t)===r)return c=e});var h=u.length,p=n.interpolate(s.x0,s.x1);e={rpx0:S,rpx1:S,x0:p(c/h),x1:p((c+1)/h)}}return n.interpolate(a,e)}(t);return function(t){return N(e(t))}}),t.select("g.slicetext").attr("opacity",0)}).remove():m.exit().remove(),m.order();var U=null;if(v&&C){var q=f.getPtId(C);m.each(function(t){null===U&&f.getPtId(t)===q&&(U=t.x1)})}var H=m;function G(t){var e=t.parent,r=P[f.getPtId(e)],a={};if(r){var i=e.children,o=i.indexOf(t),s=i.length,l=n.interpolate(r.x0,r.x1);a.x0=l(o/s),a.x1=l(o/s)}else a.x0=a.x1=0;return a}v&&(H=H.transition().each("end",function(){var e=n.select(this);f.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:!1})})),H.each(function(a){var p=n.select(this),d=o.ensureSingle(p,"path","surface",function(t){t.style("pointer-events","all")});a.rpx0=F(a.y0),a.rpx1=F(a.y1),a.xmid=(a.x0+a.x1)/2,a.pxmid=B(a.rpx1,a.xmid),a.midangle=-(a.xmid-Math.PI/2),a.halfangle=.5*Math.min(o.angleDelta(a.x0,a.x1)||Math.PI,Math.PI),a.ring=1-a.rpx0/a.rpx1,a.rInscribed=function(t){return 0===t.rpx0&&o.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(a),v?d.transition().attrTween("d",function(t){var e=function(t){var e,r=P[f.getPtId(t)],a={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(C)if(t.parent)if(U){var i=t.x1>U?2*Math.PI:0;e={x0:i,x1:i}}else e={rpx0:S,rpx1:S},o.extendFlat(e,G(t));else e={rpx0:0,rpx1:0};else e={x0:0,x1:0};return n.interpolate(e,a)}(t);return function(t){return N(e(t))}}):d.attr("d",N),p.call(u,_,t,e,{eventDataKeys:h.eventDataKeys,transitionTime:h.CLICK_TRANSITION_TIME,transitionEasing:h.CLICK_TRANSITION_EASING}).call(f.setSliceCursor,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:t._transitioning}),d.call(c,a,x);var m=o.ensureSingle(p,"g","slicetext"),b=o.ensureSingle(m,"text","",function(t){t.attr("data-notex",1)});b.text(r.formatSliceLabel(a,_,x,e,g)).classed("slicetext",!0).attr("text-anchor","middle").call(i.font,f.determineTextFont(x,a,g.font)).call(s.convertToTspans,t);var w=i.bBox(b.node());a.transform=l(w,a,y),a.translateX=j(a),a.translateY=V(a);var k=function(t,e){return"translate("+t.translateX+","+t.translateY+")"+(t.transform.scale<1?"scale("+t.transform.scale+")":"")+(t.transform.rotate?"rotate("+t.transform.rotate+")":"")+"translate("+-(e.left+e.right)/2+","+-(e.top+e.bottom)/2+")"};v?b.transition().attrTween("transform",function(t){var e=function(t){var e,r=P[f.getPtId(t)],a=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{scale:0,rotate:a.rotate,rCenter:a.rCenter,x:a.x,y:a.y}},C)if(t.parent)if(U){var i=t.x1>U?2*Math.PI:0;e.x0=e.x1=i}else o.extendFlat(e,G(t));else e.x0=e.x1=0;else e.x0=e.x1=0;var s=n.interpolate(e.rpx1,t.rpx1),l=n.interpolate(e.x0,t.x0),c=n.interpolate(e.x1,t.x1),u=n.interpolate(e.transform.scale,a.scale),h=n.interpolate(e.transform.rotate,a.rotate),p=0===a.rCenter?3:0===e.transform.rCenter?1/3:1,d=n.interpolate(e.transform.rCenter,a.rCenter);return function(t){var e=s(t),r=l(t),n=c(t),i=function(t){return d(Math.pow(t,p))}(t),o={pxmid:B(e,(r+n)/2),transform:{rCenter:i,x:a.x,y:a.y}},f={rpx1:s(t),translateX:j(o),translateY:V(o),transform:{scale:u(t),rotate:h(t),rCenter:i}};return f}}(t);return function(t){return k(e(t),w)}}):b.attr("transform",k(a,w))})}r.plot=function(t,e,r,a){var i,o,s=t._fullLayout._sunburstlayer,l=!r,c=f.hasTransition(r);((i=s.selectAll("g.trace.sunburst").data(e,function(t){return t[0].trace.uid})).enter().append("g").classed("trace",!0).classed("sunburst",!0).attr("stroke-linejoin","round"),i.order(),c)?(a&&(o=a()),n.transition().duration(r.duration).ease(r.easing).each("end",function(){o&&o()}).each("interrupt",function(){o&&o()}).each(function(){s.selectAll("g.trace").each(function(e){p(t,e,this,r)})})):i.each(function(e){p(t,e,this,r)});l&&i.exit().remove()},r.formatSliceLabel=function(t,e,r,n,a){var i=r.texttemplate,s=r.textinfo;if(!(i||s&&"none"!==s))return"";var l=a.separators,c=n[0],u=t.data.data,h=c.hierarchy,p=f.isHierarchyRoot(t),d=f.getParent(h,t),g=f.getValue(t);if(!i){var v,m=s.split("+"),y=function(t){return-1!==m.indexOf(t)},x=[];if(y("label")&&u.label&&x.push(u.label),u.hasOwnProperty("v")&&y("value")&&x.push(f.formatValue(u.v,l)),!p){y("current path")&&x.push(f.getPath(t.data));var b=0;y("percent parent")&&b++,y("percent entry")&&b++,y("percent root")&&b++;var _=b>1;if(b){var w,k=function(t){v=f.formatPercent(w,l),_&&(v+=" of "+t),x.push(v)};y("percent parent")&&!p&&(w=g/f.getValue(d),k("parent")),y("percent entry")&&(w=g/f.getValue(e),k("entry")),y("percent root")&&(w=g/f.getValue(h),k("root"))}}return y("text")&&(v=o.castOption(r,u.i,"text"),o.isValidTextValue(v)&&x.push(v)),x.join("<br>")}var T=o.castOption(r,u.i,"texttemplate");if(!T)return"";var A={};u.label&&(A.label=u.label),u.hasOwnProperty("v")&&(A.value=u.v,A.valueLabel=f.formatValue(u.v,l)),A.currentPath=f.getPath(t.data),p||(A.percentParent=g/f.getValue(d),A.percentParentLabel=f.formatPercent(A.percentParent,l),A.parent=f.getPtLabel(d)),A.percentEntry=g/f.getValue(e),A.percentEntryLabel=f.formatPercent(A.percentEntry,l),A.entry=f.getPtLabel(e),A.percentRoot=g/f.getValue(h),A.percentRootLabel=f.formatPercent(A.percentRoot,l),A.root=f.getPtLabel(h),u.hasOwnProperty("color")&&(A.color=u.color);var M=o.castOption(r,u.i,"text");return(o.isValidTextValue(M)||""===M)&&(A.text=M),A.customdata=o.castOption(r,u.i,"customdata"),o.texttemplateString(T,A,a._d3locale,A,r._meta||{})}},{"../../components/drawing":612,"../../lib":716,"../../lib/svg_text_utils":740,"../pie/plot":1101,"./constants":1231,"./fx":1233,"./helpers":1234,"./style":1239,d3:164,"d3-hierarchy":158}],1239:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../../lib");function o(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=i.castOption(r,s,"marker.line.color")||a.defaultLine,c=i.castOption(r,s,"marker.line.width")||0;t.style("stroke-width",c).call(a.fill,n.color).call(a.stroke,l).style("opacity",o?r.leaf.opacity:null)}e.exports={style:function(t){t._fullLayout._sunburstlayer.selectAll(".trace").each(function(t){var e=n.select(this),r=t[0].trace;e.style("opacity",r.opacity),e.selectAll("path.surface").each(function(t){n.select(this).call(o,t,r)})})},styleOne:o}},{"../../components/color":591,"../../lib":716,d3:164}],1240:[function(t,e,r){"use strict";var n=t("../../components/color"),a=t("../../components/colorscale/attributes"),i=t("../../plots/template_attributes").hovertemplateAttrs,o=t("../../plots/attributes"),s=t("../../lib/extend").extendFlat,l=t("../../plot_api/edit_types").overrideAll;function c(t){return{show:{valType:"boolean",dflt:!1},start:{valType:"number",dflt:null,editType:"plot"},end:{valType:"number",dflt:null,editType:"plot"},size:{valType:"number",dflt:null,min:0,editType:"plot"},project:{x:{valType:"boolean",dflt:!1},y:{valType:"boolean",dflt:!1},z:{valType:"boolean",dflt:!1}},color:{valType:"color",dflt:n.defaultLine},usecolormap:{valType:"boolean",dflt:!1},width:{valType:"number",min:1,max:16,dflt:2},highlight:{valType:"boolean",dflt:!0},highlightcolor:{valType:"color",dflt:n.defaultLine},highlightwidth:{valType:"number",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:"data_array"},x:{valType:"data_array"},y:{valType:"data_array"},text:{valType:"string",dflt:"",arrayOk:!0},hovertext:{valType:"string",dflt:"",arrayOk:!0},hovertemplate:i(),connectgaps:{valType:"boolean",dflt:!1,editType:"calc"},surfacecolor:{valType:"data_array"}},a("",{colorAttr:"z or surfacecolor",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:"calc"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:"boolean",dflt:!1},lightposition:{x:{valType:"number",min:-1e5,max:1e5,dflt:10},y:{valType:"number",min:-1e5,max:1e5,dflt:1e4},z:{valType:"number",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:"number",min:0,max:1,dflt:.8},diffuse:{valType:"number",min:0,max:1,dflt:.8},specular:{valType:"number",min:0,max:2,dflt:.05},roughness:{valType:"number",min:0,max:1,dflt:.5},fresnel:{valType:"number",min:0,max:5,dflt:.2}},opacity:{valType:"number",min:0,max:1,dflt:1},_deprecated:{zauto:s({},a.zauto,{}),zmin:s({},a.zmin,{}),zmax:s({},a.zmax,{})},hoverinfo:s({},o.hoverinfo)}),"calc","nested");u.x.editType=u.y.editType=u.z.editType="calc+clearAxisTypes",u.transforms=void 0},{"../../components/color":591,"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plots/attributes":761,"../../plots/template_attributes":840}],1241:[function(t,e,r){"use strict";var n=t("../../components/colorscale/calc");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:"",cLetter:"c"}):n(t,e,{vals:e.z,containerStr:"",cLetter:"c"})}},{"../../components/colorscale/calc":599}],1242:[function(t,e,r){"use strict";var n=t("gl-surface3d"),a=t("ndarray"),i=t("ndarray-homography"),o=t("ndarray-fill"),s=t("../../lib").isArrayOrTypedArray,l=t("../../lib/gl_format_color").parseColorScale,c=t("../../lib/str2rgbarray"),u=t("../../components/colorscale").extractOpts,h=t("../heatmap/interp2d"),f=t("../heatmap/find_empties");function p(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var d=p.prototype;d.getXat=function(t,e,r,n){var a=s(this.data.x)?s(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?a:n.d2l(a,0,r)},d.getYat=function(t,e,r,n){var a=s(this.data.y)?s(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?a:n.d2l(a,0,r)},d.getZat=function(t,e,r,n){var a=this.data.z[e][t];return null===a&&this.data.connectgaps&&this.data._interpolatedZ&&(a=this.data._interpolatedZ[e][t]),void 0===r?a:n.d2l(a,0,r)},d.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),a=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,a],t.traceCoordinate=[this.getXat(n,a),this.getYat(n,a),this.getZat(n,a)],t.dataCoordinate=[this.getXat(n,a,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,a,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,a,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var i=0;i<3;i++){var o=t.dataCoordinate[i];null!=o&&(t.dataCoordinate[i]*=this.scene.dataScale[i])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[a]&&void 0!==s[a][n]?t.textLabel=s[a][n]:t.textLabel=s||"",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var g=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function v(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<g.length;r++){var n=g[r];e.push(v(t,n))}return e}function y(t){for(var e=m(t),r=t,n=0;n<g.length;n++)if(e[n]>0){r=g[n];break}return r}function x(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),a=1,i=0;i<g.length;i++)a*=Math.pow(g[i],Math.max(r[i],n[i]));return a}}d.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),a=this.getXat(e,0);r[e-1]=a!==n&&null!=n&&null!=a?Math.abs(a-n):0}var i=0;for(e=1;e<t;e++)i+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(i/r[e-1]);return r},d.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),a=this.getYat(0,e);r[e-1]=a!==n&&null!=n&&null!=a?Math.abs(a-n):0}var i=0;for(e=1;e<t;e++)i+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(i/r[e-1]);return r};var b=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],_=b[9],w=b[13];function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}d.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=x(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<_;)r*=2;for(;r>w;)r--,r/=y(r),++r<_&&(r=w);var n=Math.round(r/t);return n>1?n:1},d.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],o=t[0].shape[1],s=0|Math.floor(t[0].shape[0]*e+1),l=0|Math.floor(t[0].shape[1]*r+1),c=1+n+1,u=1+o+1,h=a(new Float32Array(c*u),[c,u]),f=0;f<t.length;++f){this.surface.padField(h,t[f]);var p=a(new Float32Array(s*l),[s,l]);i(p,h,[e,0,0,0,r,0,0,0,1]),t[f]=p}},d.setContourLevels=function(){var t,e,r,n=[[],[],[]],a=[!1,!1,!1],i=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(i=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(a[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(i){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=a[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},d.update=function(t){var e,r,n,i,s=this.scene,p=s.fullSceneLayout,d=this.surface,g=t.opacity,v=l(t,g),m=s.dataScale,y=t.z[0].length,x=t._ylength,b=s.contourLevels;this.data=t;var _=[];for(e=0;e<3;e++)for(_[e]=[],r=0;r<y;r++)_[e][r]=[];for(r=0;r<y;r++)for(n=0;n<x;n++)_[0][r][n]=this.getXat(r,n,t.xcalendar,p.xaxis),_[1][r][n]=this.getYat(r,n,t.ycalendar,p.yaxis),_[2][r][n]=this.getZat(r,n,t.zcalendar,p.zaxis);if(t.connectgaps)for(t._emptypoints=f(_[2]),h(_[2],t._emptypoints),t._interpolatedZ=[],r=0;r<y;r++)for(t._interpolatedZ[r]=[],n=0;n<x;n++)t._interpolatedZ[r][n]=_[2][r][n];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null==(i=_[e][r][n])?_[e][r][n]=NaN:i=_[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(i=_[e][r][n])&&(this.minValues[e]>i&&(this.minValues[e]=i),this.maxValues[e]<i&&(this.maxValues[e]=i));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(i=_[e][r][n])&&(_[e][r][n]-=this.objectOffset[e]);var k=[a(new Float32Array(y*x),[y,x]),a(new Float32Array(y*x),[y,x]),a(new Float32Array(y*x),[y,x])];o(k[0],function(t,e){return _[0][t][e]}),o(k[1],function(t,e){return _[1][t][e]}),o(k[2],function(t,e){return _[2][t][e]}),_=[];var T={colormap:v,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacity:t.opacity},A=u(t);if(T.intensityBounds=[A.min,A.max],t.surfacecolor){var M=a(new Float32Array(y*x),[y,x]);o(M,function(e,r){return t.surfacecolor[r][e]}),k.push(M)}else T.intensityBounds[0]*=m[2],T.intensityBounds[1]*=m[2];(w<k[0].shape[0]||w<k[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(k[0].shape[0],0),this.dataScaleY=this.estimateScale(k[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(k)),t.surfacecolor&&(T.intensity=k.pop());var S=[!0,!0,!0],E=["x","y","z"];for(e=0;e<3;++e){var L=t.contours[E[e]];S[e]=L.highlight,T.showContour[e]=L.show||L.highlight,T.showContour[e]&&(T.contourProject[e]=[L.project.x,L.project.y,L.project.z],L.show?(this.showContour[e]=!0,T.levels[e]=b[e],d.highlightColor[e]=T.contourColor[e]=c(L.color),L.usecolormap?d.highlightTint[e]=T.contourTint[e]=0:d.highlightTint[e]=T.contourTint[e]=1,T.contourWidth[e]=L.width,this.contourStart[e]=L.start,this.contourEnd[e]=L.end,this.contourSize[e]=L.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),L.highlight&&(T.dynamicColor[e]=c(L.highlightcolor),T.dynamicWidth[e]=L.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(v)&&(T.vertexColor=!0),T.objectOffset=this.objectOffset,T.coords=k,d.update(T),d.visible=t.visible,d.enableDynamic=S,d.enableHighlight=S,d.snapToData=!0,"lighting"in t&&(d.ambientLight=t.lighting.ambient,d.diffuseLight=t.lighting.diffuse,d.specularLight=t.lighting.specular,d.roughness=t.lighting.roughness,d.fresnel=t.lighting.fresnel),"lightposition"in t&&(d.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z]),g&&g<1&&(d.supportsTransparency=!0)},d.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new p(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}},{"../../components/colorscale":603,"../../lib":716,"../../lib/gl_format_color":713,"../../lib/str2rgbarray":739,"../heatmap/find_empties":1004,"../heatmap/interp2d":1007,"gl-surface3d":317,ndarray:451,"ndarray-fill":441,"ndarray-homography":443}],1243:[function(t,e,r){"use strict";var n=t("../../registry"),a=t("../../lib"),i=t("../../components/colorscale/defaults"),o=t("./attributes");function s(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports=function(t,e,r,l){var c,u;function h(r,n){return a.coerce(t,e,o,r,n)}var f=h("x"),p=h("y"),d=h("z");if(!d||!d.length||f&&f.length<1||p&&p.length<1)e.visible=!1;else{e._xlength=Array.isArray(f)&&a.isArrayOrTypedArray(f[0])?d.length:d[0].length,e._ylength=d.length,n.getComponentMethod("calendars","handleTraceDefaults")(t,e,["x","y","z"],l),h("text"),h("hovertext"),h("hovertemplate"),["lighting.ambient","lighting.diffuse","lighting.specular","lighting.roughness","lighting.fresnel","lightposition.x","lightposition.y","lightposition.z","hidesurface","connectgaps","opacity"].forEach(function(t){h(t)});var g=h("surfacecolor"),v=["x","y","z"];for(c=0;c<3;++c){var m="contours."+v[c],y=h(m+".show"),x=h(m+".highlight");if(y||x)for(u=0;u<3;++u)h(m+".project."+v[u]);y&&(h(m+".color"),h(m+".width"),h(m+".usecolormap")),x&&(h(m+".highlightcolor"),h(m+".highlightwidth")),h(m+".start"),h(m+".end"),h(m+".size")}g||(s(t,"zmin","cmin"),s(t,"zmax","cmax"),s(t,"zauto","cauto")),i(t,e,l,h,{prefix:"",cLetter:"c"}),e._length=null}}},{"../../components/colorscale/defaults":601,"../../lib":716,"../../registry":845,"./attributes":1240}],1244:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),colorbar:{min:"cmin",max:"cmax"},calc:t("./calc"),plot:t("./convert"),moduleType:"trace",name:"surface",basePlotModule:t("../../plots/gl3d"),categories:["gl3d","2dMap"],meta:{}}},{"../../plots/gl3d":804,"./attributes":1240,"./calc":1241,"./convert":1242,"./defaults":1243}],1245:[function(t,e,r){"use strict";var n=t("../../components/annotations/attributes"),a=t("../../lib/extend").extendFlat,i=t("../../plot_api/edit_types").overrideAll,o=t("../../plots/font_attributes"),s=t("../../plots/domain").attributes;t("../../constants/docs").FORMAT_LINK;(e.exports=i({domain:s({name:"table",trace:!0}),columnwidth:{valType:"number",arrayOk:!0,dflt:null},columnorder:{valType:"data_array"},header:{values:{valType:"data_array",dflt:[]},format:{valType:"data_array",dflt:[]},prefix:{valType:"string",arrayOk:!0,dflt:null},suffix:{valType:"string",arrayOk:!0,dflt:null},height:{valType:"number",dflt:28},align:a({},n.align,{arrayOk:!0}),line:{width:{valType:"number",arrayOk:!0,dflt:1},color:{valType:"color",arrayOk:!0,dflt:"grey"}},fill:{color:{valType:"color",arrayOk:!0,dflt:"white"}},font:a({},o({arrayOk:!0}))},cells:{values:{valType:"data_array",dflt:[]},format:{valType:"data_array",dflt:[]},prefix:{valType:"string",arrayOk:!0,dflt:null},suffix:{valType:"string",arrayOk:!0,dflt:null},height:{valType:"number",dflt:20},align:a({},n.align,{arrayOk:!0}),line:{width:{valType:"number",arrayOk:!0,dflt:1},color:{valType:"color",arrayOk:!0,dflt:"grey"}},fill:{color:{valType:"color",arrayOk:!0,dflt:"white"}},font:a({},o({arrayOk:!0}))}},"calc","from-root")).transforms=void 0},{"../../components/annotations/attributes":574,"../../constants/docs":687,"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plots/domain":789,"../../plots/font_attributes":790}],1246:[function(t,e,r){"use strict";var n=t("../../plots/get_data").getModuleCalcData,a=t("./plot");r.name="table",r.plot=function(t){var e=n(t.calcdata,"table")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var a=n._has&&n._has("table"),i=e._has&&e._has("table");a&&!i&&n._paperdiv.selectAll(".table").remove()}},{"../../plots/get_data":799,"./plot":1253}],1247:[function(t,e,r){"use strict";var n=t("../../lib/gup").wrap;e.exports=function(){return n({})}},{"../../lib/gup":714}],1248:[function(t,e,r){"use strict";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\$.*\$$/,goldenRatio:1.618,lineBreaker:"<br>",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:"cubic-out",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:"cubic-out",uplift:5,wrapSpacer:" ",wrapSplitCharacter:" ",cn:{table:"table",tableControlView:"table-control-view",scrollBackground:"scroll-background",yColumn:"y-column",columnBlock:"column-block",scrollAreaClip:"scroll-area-clip",scrollAreaClipRect:"scroll-area-clip-rect",columnBoundary:"column-boundary",columnBoundaryClippath:"column-boundary-clippath",columnBoundaryRect:"column-boundary-rect",columnCells:"column-cells",columnCell:"column-cell",cellRect:"cell-rect",cellText:"cell-text",cellTextHolder:"cell-text-holder",scrollbarKit:"scrollbar-kit",scrollbar:"scrollbar",scrollbarSlider:"scrollbar-slider",scrollbarGlyph:"scrollbar-glyph",scrollbarCaptureZone:"scrollbar-capture-zone"}}},{}],1249:[function(t,e,r){"use strict";var n=t("./constants"),a=t("../../lib/extend").extendFlat,i=t("fast-isnumeric");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,a=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),a=Math.max(a,r[e].length);if(n!==a)for(e=0;e<r.length;e++){var i=a-r[e].length;i&&(r[e]=r[e].concat(c(i)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]="";return e}function u(t){return t.calcdata.columns.reduce(function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e},0)}function h(t,e){return Object.keys(t).map(function(r){return a({},t[r],{auxiliaryBlocks:e})})}function f(t,e){for(var r,n={},a=0,i=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((i+=r)>=e||c===t.length-1)&&(n[a]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},a+=i,s=c+1,i=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[""],d=l(d));var g=d.concat(p(r).map(function(){return c((d[0]||[""]).length)})),v=e.domain,m=Math.floor(t._fullLayout._size.w*(v.x[1]-v.x[0])),y=Math.floor(t._fullLayout._size.h*(v.y[1]-v.y[0])),x=e.header.values.length?g[0].map(function(){return e.header.height}):[n.emptyHeaderHeight],b=r.length?r[0].map(function(){return e.cells.height}):[],_=x.reduce(s,0),w=f(b,y-_+n.uplift),k=h(f(x,_),[]),T=h(w,k),A={},M=e._fullInput.columnorder.concat(p(r.map(function(t,e){return e}))),S=g.map(function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return i(n)?Number(n):1}),E=S.reduce(s,0);S=S.map(function(t){return t/E*m});var L=Math.max(o(e.header.line.width),o(e.cells.line.width)),C={key:e.uid+t._context.staticPlot,translateX:v.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-v.y[1]),size:t._fullLayout._size,width:m,maxLineWidth:L,height:y,columnOrder:M,groupHeight:y,rowBlocks:T,headerRowBlocks:k,scrollY:0,cells:a({},e.cells,{values:r}),headerCells:a({},e.header,{values:g}),gdColumns:g.map(function(t){return t[0]}),gdColumnsOriginalOrder:g.map(function(t){return t[0]}),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map(function(t,e){var r=A[t];return A[t]=(r||0)+1,{key:t+"__"+A[t],label:t,specIndex:e,xIndex:M[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}})};return C.columns.forEach(function(t){t.calcdata=C,t.x=u(t)}),C}},{"../../lib/extend":707,"./constants":1248,"fast-isnumeric":227}],1250:[function(t,e,r){"use strict";var n=t("../../lib/extend").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:"header",type:"header",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:"cells1",type:"cells",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:"cells2",type:"cells",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map(function(r,n){return{keyWithinBlock:n+("string"==typeof r&&r.match(/[<$&> ]/)?"_keybuster_"+Math.random():""),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}})}},{"../../lib/extend":707}],1251:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../plots/domain").defaults;e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}i(e,o,s),s("columnwidth"),s("header.values"),s("header.format"),s("header.align"),s("header.prefix"),s("header.suffix"),s("header.height"),s("header.line.width"),s("header.line.color"),s("header.fill.color"),n.coerceFont(s,"header.font",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,a=r.slice(0,n),i=a.slice().sort(function(t,e){return t-e}),o=a.map(function(t){return i.indexOf(t)}),s=o.length;s<n;s++)o.push(s);e("columnorder",o)}(e,s),s("cells.values"),s("cells.format"),s("cells.align"),s("cells.prefix"),s("cells.suffix"),s("cells.height"),s("cells.line.width"),s("cells.line.color"),s("cells.fill.color"),n.coerceFont(s,"cells.font",n.extendFlat({},o.font)),e._length=null}},{"../../lib":716,"../../plots/domain":789,"./attributes":1245}],1252:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("./calc"),plot:t("./plot"),moduleType:"trace",name:"table",basePlotModule:t("./base_plot"),categories:["noOpacity"],meta:{}}},{"./attributes":1245,"./base_plot":1246,"./calc":1247,"./defaults":1251,"./plot":1253}],1253:[function(t,e,r){"use strict";var n=t("./constants"),a=t("d3"),i=t("../../lib/gup"),o=t("../../components/drawing"),s=t("../../lib/svg_text_utils"),l=t("../../lib").raiseToTop,c=t("../../lib").cancelTransition,u=t("./data_preparation_helper"),h=t("./data_split_helpers"),f=t("../../components/color");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return"clip"+t._fullLayout._uid+"_scrollAreaBottomClip_"+e.key}function g(t,e){return"clip"+t._fullLayout._uid+"_columnBoundaryClippath_"+e.calcdata.key+"_"+e.specIndex}function v(t){return[].concat.apply([],t.map(function(t){return t})).map(function(t){return t.__data__})}function m(t,e,r){var o=t.selectAll("."+n.cn.scrollbarKit).data(i.repeat,i.keyFun);o.enter().append("g").classed(n.cn.scrollbarKit,!0).style("shape-rendering","geometricPrecision"),o.each(function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?I(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom}).attr("transform",function(t){return"translate("+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+" "+A(t)+")"});var s=o.selectAll("."+n.cn.scrollbar).data(i.repeat,i.keyFun);s.enter().append("g").classed(n.cn.scrollbar,!0);var l=s.selectAll("."+n.cn.scrollbarSlider).data(i.repeat,i.keyFun);l.enter().append("g").classed(n.cn.scrollbarSlider,!0),l.attr("transform",function(t){return"translate(0 "+(t.scrollbarState.topY||0)+")"});var c=l.selectAll("."+n.cn.scrollbarGlyph).data(i.repeat,i.keyFun);c.enter().append("line").classed(n.cn.scrollbarGlyph,!0).attr("stroke","black").attr("stroke-width",n.scrollbarWidth).attr("stroke-linecap","round").attr("y1",n.scrollbarWidth/2),c.attr("y2",function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2}).attr("stroke-opacity",function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4}),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr("stroke-opacity",0);var u=s.selectAll("."+n.cn.scrollbarCaptureZone).data(i.repeat,i.keyFun);u.enter().append("line").classed(n.cn.scrollbarCaptureZone,!0).attr("stroke","white").attr("stroke-opacity",.01).attr("stroke-width",n.scrollbarCaptureWidth).attr("stroke-linecap","butt").attr("y1",0).on("mousedown",function(r){var n=a.event.y,i=this.getBoundingClientRect(),o=r.scrollbarState,s=n-i.top,l=a.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)}).call(a.behavior.drag().origin(function(t){return a.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t}).on("drag",S(e,t)).on("dragend",function(){})),u.attr("y2",function(t){return t.scrollbarState.scrollableAreaHeight}),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll("."+n.cn.columnCell).data(h.splitToCells,function(t){return t.keyWithinBlock});return e.enter().append("g").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll("."+n.cn.columnCells).data(i.repeat,i.keyFun);return e.enter().append("g").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each(function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,a={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=a})}(l),function(t){t.attr("width",function(t){return t.column.columnWidth}).attr("stroke-width",function(t){return t.cellBorderWidth}).each(function(t){var e=a.select(this);f.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),f.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))})}(function(t){var e=t.selectAll("."+n.cn.cellRect).data(i.repeat,function(t){return t.keyWithinBlock});return e.enter().append("rect").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll("."+n.cn.cellText).data(i.repeat,function(t){return t.keyWithinBlock});return e.enter().append("text").classed(n.cn.cellText,!0).style("cursor",function(){return"auto"}).on("mousedown",function(){a.event.stopPropagation()}),e}(function(t){var e=t.selectAll("."+n.cn.cellTextHolder).data(i.repeat,function(t){return t.keyWithinBlock});return e.enter().append("g").classed(n.cn.cellTextHolder,!0).style("shape-rendering","geometricPrecision"),e}(l));!function(t){t.each(function(t){o.font(a.select(this),t.font)})}(c),x(c,e,s,t),O(l)}function x(t,e,r,i){t.text(function(t){var e=t.column.specIndex,r=t.rowNumber,i=t.value,o="string"==typeof i,s=o&&i.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&i.match(/[<&>]/);var c,u="string"==typeof(c=i)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?"":_(t.calcdata.cells.prefix,e,r)||"",d=u?"":_(t.calcdata.cells.suffix,e,r)||"",g=u?null:_(t.calcdata.cells.format,e,r)||null,v=p+(g?a.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=b(v)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?b(v):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var m=(" "===n.wrapSplitCharacter?v.replace(/<a href=/gi,"<a_href="):v).split(n.wrapSplitCharacter),y=" "===n.wrapSplitCharacter?m.map(function(t){return t.replace(/<a_href=/gi,"<a href=")}):m;t.fragments=y.map(function(t){return{text:t,width:null}}),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=v;return f}).attr("dy",function(t){return t.needsConvertToTspans?0:"0.75em"}).each(function(t){var o=a.select(this),l=t.wrappingNeeded?L:C;t.needsConvertToTspans?s.convertToTspans(o,i,l(r,this,e,i,t)):a.select(this.parentNode).attr("transform",function(t){return"translate("+P(t)+" "+n.cellPad+")"}).attr("text-anchor",function(t){return{left:"start",center:"middle",right:"end"}[t.align]})})}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr("transform","translate("+e.x+" "+r+")")}function k(t){return"cells"===t.type}function T(t){return"header"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce(function(t,e){return t+I(e,1/0)},0)}function M(t,e,r){var n=v(e)[0];if(void 0!==n){var a=n.rowBlocks,i=n.calcdata,o=z(a,a.length),s=n.calcdata.groupHeight-A(n),l=i.scrollY=Math.max(0,Math.min(o-s,i.scrollY)),c=function(t,e,r){for(var n=[],a=0,i=0;i<t.length;i++){for(var o=t[i],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<a+l&&e+r>a&&n.push(i),a+=l}return n}(a,l,s);1===c.length&&(c[0]===a.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each(function(t,e){t.page=c[e],t.scrollY=l}),e.attr("transform",function(t){return"translate(0 "+(z(t.rowBlocks,t.page)-t.scrollY)+")"}),t&&(E(t,r,e,c,n.prevPages,n,0),E(t,r,e,c,n.prevPages,n,1),m(r,t))}}function S(t,e,r,i){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter(function(t){return s.key===t.key}),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===i?s.scrollY+c*a.event.dy:i;var h=l.selectAll("."+n.cn.yColumn).selectAll("."+n.cn.columnBlock).filter(k);return M(t,h,l),s.scrollY===u}}function E(t,e,r,n,a,i,o){n[o]!==a[o]&&(clearTimeout(i.currentRepaint[o]),i.currentRepaint[o]=setTimeout(function(){var i=r.filter(function(t,e){return e===o&&n[e]!==a[e]});y(t,e,i,r),a[o]=n[o]}))}function L(t,e,r,i){return function(){var o=a.select(e.parentNode);o.each(function(t){var e=t.fragments;o.selectAll("tspan.line").each(function(t,r){e[r].width=this.getComputedTextLength()});var r,a,i=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value="";s.length;)c+(a=(r=s.shift()).width+i)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=a;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0}),o.selectAll("tspan.line").remove(),x(o.select("."+n.cn.cellText),r,t,i),a.select(e.parentNode.parentNode).call(O)}}function C(t,e,r,i,o){return function(){if(!o.settledY){var s=a.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,f=Math.max(h,u);f-l.rows[c].rowHeight&&(l.rows[c].rowHeight=f,t.selectAll("."+n.cn.columnCell).call(O),M(null,t.filter(k),0),m(r,i,!0)),s.attr("transform",function(){var t=this.parentNode.getBoundingClientRect(),e=a.select(this.parentNode).select("."+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),i=e.top-t.top+(r?r.matrix.f:n.cellPad);return"translate("+P(o,a.select(this.parentNode).select("."+n.cn.cellTextHolder).node().getBoundingClientRect().width)+" "+i+")"}),o.settledY=!0}}}function P(t,e){switch(t.align){case"left":return n.cellPad;case"right":return t.column.columnWidth-(e||0)-n.cellPad;case"center":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr("transform",function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce(function(t,e){return t+I(e,1/0)},0);return"translate(0 "+(I(R(t),t.key)+e)+")"}).selectAll("."+n.cn.cellRect).attr("height",function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r})}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=D(t[n]);return r}function I(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function D(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll("."+n.cn.table).data(e.map(function(e){var r=i.unwrap(e).trace;return u(t,r)}),i.keyFun);s.exit().remove(),s.enter().append("g").classed(n.cn.table,!0).attr("overflow","visible").style("box-sizing","content-box").style("position","absolute").style("left",0).style("overflow","visible").style("shape-rendering","crispEdges").style("pointer-events","all"),s.attr("width",function(t){return t.width+t.size.l+t.size.r}).attr("height",function(t){return t.height+t.size.t+t.size.b}).attr("transform",function(t){return"translate("+t.translateX+","+t.translateY+")"});var f=s.selectAll("."+n.cn.tableControlView).data(i.repeat,i.keyFun),x=f.enter().append("g").classed(n.cn.tableControlView,!0).style("box-sizing","content-box");r&&x.on("mousemove",function(e){f.filter(function(t){return e===t}).call(m,t)}).on("mousewheel",function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+a.event.deltaY;S(t,f,null,r)(e)||(a.event.stopPropagation(),a.event.preventDefault()),e.scrollbarState.wheeling=!1}}).call(m,t,!0),f.attr("transform",function(t){return"translate("+t.size.l+" "+t.size.t+")"});var b=f.selectAll("."+n.cn.scrollBackground).data(i.repeat,i.keyFun);b.enter().append("rect").classed(n.cn.scrollBackground,!0).attr("fill","none"),b.attr("width",function(t){return t.width}).attr("height",function(t){return t.height}),f.each(function(e){o.setClipUrl(a.select(this),d(t,e),t)});var _=f.selectAll("."+n.cn.yColumn).data(function(t){return t.columns},i.keyFun);_.enter().append("g").classed(n.cn.yColumn,!0),_.exit().remove(),_.attr("transform",function(t){return"translate("+t.x+" 0)"}),r&&_.call(a.behavior.drag().origin(function(e){return w(a.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,m(f.filter(function(t){return e.calcdata.key===t.key}),t),e}).on("drag",function(t){var e=a.select(this),r=function(e){return(t===e?a.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,a.event.x)),v(_).filter(function(e){return e.calcdata.key===t.calcdata.key}).sort(function(t,e){return r(t)-r(e)}).forEach(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)}),_.filter(function(e){return t!==e}).transition().ease(n.transitionEase).duration(n.transitionDuration).attr("transform",function(t){return"translate("+t.x+" 0)"}),e.call(c).attr("transform","translate("+t.x+" -"+n.uplift+" )")}).on("dragend",function(e){var r=a.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort(function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]}),e.columnorder=r,t.emit("plotly_restyle")}(t,n,n.columns.map(function(t){return t.xIndex}))})),_.each(function(e){o.setClipUrl(a.select(this),g(t,e),t)});var A=_.selectAll("."+n.cn.columnBlock).data(h.splitToPanels,i.keyFun);A.enter().append("g").classed(n.cn.columnBlock,!0).attr("id",function(t){return t.key}),A.style("cursor",function(t){return t.dragHandle?"ew-resize":t.calcdata.scrollbarState.barWiggleRoom?"ns-resize":"default"});var E=A.filter(T),L=A.filter(k);r&&L.call(a.behavior.drag().origin(function(t){return a.event.stopPropagation(),t}).on("drag",S(t,f,-1)).on("dragend",function(){})),y(t,f,E,A),y(t,f,L,A);var C=f.selectAll("."+n.cn.scrollAreaClip).data(i.repeat,i.keyFun);C.enter().append("clipPath").classed(n.cn.scrollAreaClip,!0).attr("id",function(e){return d(t,e)});var P=C.selectAll("."+n.cn.scrollAreaClipRect).data(i.repeat,i.keyFun);P.enter().append("rect").classed(n.cn.scrollAreaClipRect,!0).attr("x",-n.overdrag).attr("y",-n.uplift).attr("fill","none"),P.attr("width",function(t){return t.width+2*n.overdrag}).attr("height",function(t){return t.height+n.uplift}),_.selectAll("."+n.cn.columnBoundary).data(i.repeat,i.keyFun).enter().append("g").classed(n.cn.columnBoundary,!0);var O=_.selectAll("."+n.cn.columnBoundaryClippath).data(i.repeat,i.keyFun);O.enter().append("clipPath").classed(n.cn.columnBoundaryClippath,!0),O.attr("id",function(e){return g(t,e)});var z=O.selectAll("."+n.cn.columnBoundaryRect).data(i.repeat,i.keyFun);z.enter().append("rect").classed(n.cn.columnBoundaryRect,!0).attr("fill","none"),z.attr("width",function(t){return t.columnWidth+2*p(t)}).attr("height",function(t){return t.calcdata.height+2*p(t)+n.uplift}).attr("x",function(t){return-p(t)}).attr("y",function(t){return-p(t)}),M(null,L,f)}},{"../../components/color":591,"../../components/drawing":612,"../../lib":716,"../../lib/gup":714,"../../lib/svg_text_utils":740,"./constants":1248,"./data_preparation_helper":1249,"./data_split_helpers":1250,d3:164}],1254:[function(t,e,r){"use strict";var n=t("../../plots/template_attributes").hovertemplateAttrs,a=t("../../plots/template_attributes").texttemplateAttrs,i=t("../../components/colorscale/attributes"),o=t("../../plots/domain").attributes,s=t("../pie/attributes"),l=t("../sunburst/attributes"),c=t("./constants"),u=t("../../lib/extend").extendFlat;e.exports={labels:l.labels,parents:l.parents,values:l.values,branchvalues:l.branchvalues,count:l.count,level:l.level,maxdepth:l.maxdepth,tiling:{packing:{valType:"enumerated",values:["squarify","binary","dice","slice","slice-dice","dice-slice"],dflt:"squarify",editType:"plot"},squarifyratio:{valType:"number",min:1,dflt:1,editType:"plot"},flip:{valType:"flaglist",flags:["x","y"],dflt:"",editType:"plot"},pad:{valType:"number",min:0,dflt:3,editType:"plot"},editType:"calc"},marker:u({pad:{t:{valType:"number",min:0,editType:"plot"},l:{valType:"number",min:0,editType:"plot"},r:{valType:"number",min:0,editType:"plot"},b:{valType:"number",min:0,editType:"plot"},editType:"calc"},colors:l.marker.colors,depthfade:{valType:"enumerated",values:[!0,!1,"reversed"],editType:"style"},line:l.marker.line,editType:"calc"},i("marker",{colorAttr:"colors",anim:!1})),pathbar:{visible:{valType:"boolean",dflt:!0,editType:"plot"},side:{valType:"enumerated",values:["top","bottom"],dflt:"top",editType:"plot"},edgeshape:{valType:"enumerated",values:[">","<","|","/","\\"],dflt:">",editType:"plot"},thickness:{valType:"number",min:12,editType:"plot"},textfont:u({},s.textfont,{}),editType:"calc"},text:s.text,textinfo:l.textinfo,texttemplate:a({editType:"plot"},{keys:c.eventDataKeys.concat(["label","value"])}),hovertext:s.hovertext,hoverinfo:l.hoverinfo,hovertemplate:n({},{keys:c.eventDataKeys}),textfont:s.textfont,insidetextfont:s.insidetextfont,outsidetextfont:s.outsidetextfont,textposition:{valType:"enumerated",values:["top left","top center","top right","middle left","middle center","middle right","bottom left","bottom center","bottom right"],dflt:"top left",editType:"plot"},domain:o({name:"treemap",trace:!0,editType:"calc"})}},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plots/domain":789,"../../plots/template_attributes":840,"../pie/attributes":1092,"../sunburst/attributes":1228,"./constants":1257}],1255:[function(t,e,r){"use strict";var n=t("../../plots/plots");r.name="treemap",r.plot=function(t,e,a,i){n.plotBasePlot(r.name,t,e,a,i)},r.clean=function(t,e,a,i){n.cleanBasePlot(r.name,t,e,a,i)}},{"../../plots/plots":825}],1256:[function(t,e,r){"use strict";var n=t("../sunburst/calc");r.calc=function(t,e){return n.calc(t,e)},r.crossTraceCalc=function(t){return n._runCrossTraceCalc("treemap",t)}},{"../sunburst/calc":1230}],1257:[function(t,e,r){"use strict";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:"poly",eventDataKeys:["currentPath","root","entry","percentRoot","percentEntry","percentParent"],gapWithPathbar:1}},{}],1258:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../../components/color"),o=t("../../plots/domain").defaults,s=t("../bar/defaults").handleText,l=t("../bar/constants").TEXTPAD,c=t("../../components/colorscale"),u=c.hasColorscale,h=c.handleDefaults;e.exports=function(t,e,r,c){function f(r,i){return n.coerce(t,e,a,r,i)}var p=f("labels"),d=f("parents");if(p&&p.length&&d&&d.length){var g=f("values");g&&g.length?f("branchvalues"):f("count"),f("level"),f("maxdepth"),"squarify"===f("tiling.packing")&&f("tiling.squarifyratio"),f("tiling.flip"),f("tiling.pad");var v=f("text");f("texttemplate"),e.texttemplate||f("textinfo",Array.isArray(v)?"text+label":"label"),f("hovertext"),f("hovertemplate");s(t,e,c,f,"auto",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),f("textposition");var m=-1!==e.textposition.indexOf("bottom");f("marker.line.width")&&f("marker.line.color",c.paper_bgcolor);var y=f("marker.colors"),x=e._hasColorscale=u(t,"marker","colors");x?h(t,e,c,f,{prefix:"marker.",cLetter:"c"}):f("marker.depthfade",!(y||[]).length);var b=2*e.textfont.size;f("marker.pad.t",m?b/4:b),f("marker.pad.l",b/4),f("marker.pad.r",b/4),f("marker.pad.b",m?b:b/4),x&&h(t,e,c,f,{prefix:"marker.",cLetter:"c"}),e._hovered={marker:{line:{width:2,color:i.contrast(c.paper_bgcolor)}}},f("pathbar.visible")&&(n.coerceFont(f,"pathbar.textfont",c.font),f("pathbar.thickness",e.pathbar.textfont.size+2*l),f("pathbar.side"),f("pathbar.edgeshape")),o(e,c,f),e._length=null}else e.visible=!1}},{"../../components/color":591,"../../components/colorscale":603,"../../lib":716,"../../plots/domain":789,"../bar/constants":857,"../bar/defaults":859,"./attributes":1254}],1259:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../../lib/svg_text_utils"),s=t("./partition"),l=t("./style").styleOne,c=t("./constants"),u=t("../sunburst/helpers"),h=t("../sunburst/fx");e.exports=function(t,e,r,f,p){var d=p.barDifY,g=p.width,v=p.height,m=p.viewX,y=p.viewY,x=p.pathSlice,b=p.toMoveInsideSlice,_=p.strTransform,w=p.hasTransition,k=p.handleSlicesExit,T=p.makeUpdateSliceInterpolator,A=p.makeUpdateTextInterpolator,M={},S=t._fullLayout,E=e[0],L=E.trace,C=E.hierarchy,P=g/L._entryDepth,O=u.listPath(r.data,"id"),z=s(C.copy(),[g,v],{packing:"dice",pad:{inner:0,top:0,left:0,right:0,bottom:0}}).descendants();(z=z.filter(function(t){var e=O.indexOf(t.data.id);return-1!==e&&(t.x0=P*e,t.x1=P*(e+1),t.y0=d,t.y1=d+v,t.onPathbar=!0,!0)})).reverse(),(f=f.data(z,u.getPtId)).enter().append("g").classed("pathbar",!0),k(f,!0,M,[g,v],x),f.order();var I=f;w&&(I=I.transition().each("end",function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:!1})})),I.each(function(s){s._hoverX=m(s.x1-v/2),s._hoverY=y(s.y1-v/2);var f=n.select(this),p=a.ensureSingle(f,"path","surface",function(t){t.style("pointer-events","all")});w?p.transition().attrTween("d",function(t){var e=T(t,!0,M,[g,v]);return function(t){return x(e(t))}}):p.attr("d",x),f.call(h,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:t._transitioning}),p.call(l,s,L,{hovered:!1}),s._text=(u.getPtLabel(s)||"").split("<br>").join(" ")||"";var d=a.ensureSingle(f,"g","slicetext"),k=a.ensureSingle(d,"text","",function(t){t.attr("data-notex",1)});k.text(s._text||" ").classed("slicetext",!0).attr("text-anchor","start").call(i.font,u.determineTextFont(L,s,S.font,L.pathdir)).call(o.convertToTspans,t),s.textBB=i.bBox(k.node()),s.transform=b(s,{onPathbar:!0}),u.isOutsideText(L,s)&&(s.transform.targetY-=u.getOutsideTextFontKey("size",L,s,S.font)-u.getInsideTextFontKey("size",L,s,S.font)),w?k.transition().attrTween("transform",function(t){var e=A(t,!0,M,[g,v]);return function(t){return _(e(t))}}):k.attr("transform",_(s))})}},{"../../components/drawing":612,"../../lib":716,"../../lib/svg_text_utils":740,"../sunburst/fx":1233,"../sunburst/helpers":1234,"./constants":1257,"./partition":1264,"./style":1266,d3:164}],1260:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../../lib/svg_text_utils"),s=t("./partition"),l=t("./style").styleOne,c=t("./constants"),u=t("../sunburst/helpers"),h=t("../sunburst/fx"),f=t("../sunburst/plot").formatSliceLabel;e.exports=function(t,e,r,p,d){var g=d.width,v=d.height,m=d.viewX,y=d.viewY,x=d.pathSlice,b=d.toMoveInsideSlice,_=d.strTransform,w=d.hasTransition,k=d.handleSlicesExit,T=d.makeUpdateSliceInterpolator,A=d.makeUpdateTextInterpolator,M=d.prevEntry,S=t._fullLayout,E=e[0].trace,L=-1!==E.textposition.indexOf("left"),C=-1!==E.textposition.indexOf("right"),P=-1!==E.textposition.indexOf("bottom"),O=!P&&!E.marker.pad.t||P&&!E.marker.pad.b,z=s(r,[g,v],{packing:E.tiling.packing,squarifyratio:E.tiling.squarifyratio,flipX:E.tiling.flip.indexOf("x")>-1,flipY:E.tiling.flip.indexOf("y")>-1,pad:{inner:E.tiling.pad,top:E.marker.pad.t,left:E.marker.pad.l,right:E.marker.pad.r,bottom:E.marker.pad.b}}).descendants(),I=1/0,D=-1/0;z.forEach(function(t){var e=t.depth;e>=E._maxDepth?(t.x0=t.x1=(t.x0+t.x1)/2,t.y0=t.y1=(t.y0+t.y1)/2):(I=Math.min(I,e),D=Math.max(D,e))}),p=p.data(z,u.getPtId),E._maxVisibleLayers=isFinite(D)?D-I+1:0,p.enter().append("g").classed("slice",!0),k(p,!1,{},[g,v],x),p.order();var R=null;if(w&&M){var F=u.getPtId(M);p.each(function(t){null===R&&u.getPtId(t)===F&&(R={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})})}var B=function(){return R||{x0:0,x1:g,y0:0,y1:v}},N=p;return w&&(N=N.transition().each("end",function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!1,isTransitioning:!1})})),N.each(function(s){var p=u.isHeader(s,E);s._hoverX=m(s.x1-E.marker.pad.r),s._hoverY=y(P?s.y1-E.marker.pad.b/2:s.y0+E.marker.pad.t/2);var d=n.select(this),k=a.ensureSingle(d,"path","surface",function(t){t.style("pointer-events","all")});w?k.transition().attrTween("d",function(t){var e=T(t,!1,B(),[g,v]);return function(t){return x(e(t))}}):k.attr("d",x),d.call(h,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{isTransitioning:t._transitioning}),k.call(l,s,E,{hovered:!1}),s.x0===s.x1||s.y0===s.y1?s._text="":s._text=p?O?"":u.getPtLabel(s)||"":f(s,r,E,e,S)||"";var M=a.ensureSingle(d,"g","slicetext"),z=a.ensureSingle(M,"text","",function(t){t.attr("data-notex",1)});z.text(s._text||" ").classed("slicetext",!0).attr("text-anchor",C?"end":L||p?"start":"middle").call(i.font,u.determineTextFont(E,s,S.font)).call(o.convertToTspans,t),s.textBB=i.bBox(z.node()),s.transform=b(s,{isHeader:p}),w?z.transition().attrTween("transform",function(t){var e=A(t,!1,B(),[g,v]);return function(t){return _(e(t))}}):z.attr("transform",_(s))}),R}},{"../../components/drawing":612,"../../lib":716,"../../lib/svg_text_utils":740,"../sunburst/fx":1233,"../sunburst/helpers":1234,"../sunburst/plot":1238,"./constants":1257,"./partition":1264,"./style":1266,d3:164}],1261:[function(t,e,r){"use strict";e.exports={moduleType:"trace",name:"treemap",basePlotModule:t("./base_plot"),categories:[],animatable:!0,attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults"),supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc").calc,crossTraceCalc:t("./calc").crossTraceCalc,plot:t("./plot"),style:t("./style").style,colorbar:t("../scatter/marker_colorbar"),meta:{}}},{"../scatter/marker_colorbar":1136,"./attributes":1254,"./base_plot":1255,"./calc":1256,"./defaults":1258,"./layout_attributes":1262,"./layout_defaults":1263,"./plot":1265,"./style":1266}],1262:[function(t,e,r){"use strict";e.exports={treemapcolorway:{valType:"colorlist",editType:"calc"},extendtreemapcolors:{valType:"boolean",dflt:!0,editType:"calc"}}},{}],1263:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r("treemapcolorway",e.colorway),r("extendtreemapcolors")}},{"../../lib":716,"./layout_attributes":1262}],1264:[function(t,e,r){"use strict";var n=t("d3-hierarchy");e.exports=function(t,e,r){var a,i=r.flipX,o=r.flipY,s="dice-slice"===r.packing,l=r.pad[o?"bottom":"top"],c=r.pad[i?"right":"left"],u=r.pad[i?"left":"right"],h=r.pad[o?"top":"bottom"];s&&(a=c,c=l,l=a,a=u,u=h,h=a);var f=n.treemap().tile(function(t,e){switch(t){case"squarify":return n.treemapSquarify.ratio(e);case"binary":return n.treemapBinary;case"dice":return n.treemapDice;case"slice":return n.treemapSlice;default:return n.treemapSliceDice}}(r.packing,r.squarifyratio)).paddingInner(r.pad.inner).paddingLeft(c).paddingRight(u).paddingTop(l).paddingBottom(h).size(s?[e[1],e[0]]:e)(t);return(s||i||o)&&function t(e,r,n){var a;n.swapXY&&(a=e.x0,e.x0=e.y0,e.y0=a,a=e.x1,e.x1=e.y1,e.y1=a);n.flipX&&(a=e.x0,e.x0=r[0]-e.x1,e.x1=r[0]-a);n.flipY&&(a=e.y0,e.y0=r[1]-e.y1,e.y1=r[1]-a);var i=e.children;if(i)for(var o=0;o<i.length;o++)t(i[o],r,n)}(f,e,{swapXY:s,flipX:i,flipY:o}),f}},{"d3-hierarchy":158}],1265:[function(t,e,r){"use strict";var n=t("d3"),a=t("../sunburst/helpers").hasTransition,i=t("../sunburst/helpers"),o=t("../../lib"),s=t("../bar/constants").TEXTPAD,l=t("../bar/plot").toMoveInsideBar,c=t("./constants"),u=t("./draw_descendants"),h=t("./draw_ancestors");function f(t){return i.isHierarchyRoot(t)?"":i.getPtId(t)}function p(t,e,r,a){var p=t._fullLayout,d=e[0],g=d.trace,v=d.hierarchy,m=i.findEntryWithLevel(v,g.level),y=n.select(r),x=y.selectAll("g.pathbar"),b=y.selectAll("g.slice");if(!m)return x.remove(),void b.remove();var _=i.isHierarchyRoot(m),w=i.hasTransition(a),k=i.getMaxDepth(g),T=p._size,A=g.domain,M=T.w*(A.x[1]-A.x[0]),S=T.h*(A.y[1]-A.y[0]),E=M,L=g.pathbar.thickness,C=g.marker.line.width+c.gapWithPathbar,P=g.pathbar.visible?g.pathbar.side.indexOf("bottom")>-1?S+C:-(L+C):0,O={x0:E,x1:E,y0:P,y1:P+L},z=function(t,e,r){var n=g.tiling.pad,a=function(t){return t-n<=e.x0},i=function(t){return t+n>=e.x1},o=function(t){return t-n<=e.y0},s=function(t){return t+n>=e.y1};return{x0:a(t.x0-n)?0:i(t.x0-n)?r[0]:t.x0,x1:a(t.x1+n)?0:i(t.x1+n)?r[0]:t.x1,y0:o(t.y0-n)?0:s(t.y0-n)?r[1]:t.y0,y1:o(t.y1+n)?0:s(t.y1+n)?r[1]:t.y1}},I=null,D={},R={},F=null,B=function(t,e){return e?D[f(t)]:R[f(t)]},N=function(t,e,r,n){if(e)return D[f(v)]||O;var a=R[g.level]||r;return function(t){return t.data.depth-m.data.depth<k}(t)?z(t,a,n):{}};d.hasMultipleRoots&&_&&k++,g._maxDepth=k,g._backgroundColor=p.paper_bgcolor,g._entryDepth=m.data.depth,g._atRootLevel=_;var j=-M/2+T.l+T.w*(A.x[1]+A.x[0])/2,V=-S/2+T.t+T.h*(1-(A.y[1]+A.y[0])/2),U=function(t){return j+t},q=function(t){return V+t},H=q(0),G=U(0),Y=function(t){return G+t},W=function(t){return H+t};function X(t,e){return t+","+e}var Z=Y(0),J=function(t){t.x=Math.max(Z,t.x)},K=g.pathbar.edgeshape,Q=function(t,e){var r=t.x0,n=t.x1,a=t.y0,i=t.y1,o=t.textBB;r===n&&(r-=s,n+=s),a===i&&(a-=s,i+=s);var c=function(t){return-1!==g.textposition.indexOf(t)},u=c("bottom"),h=c("top")||e.isHeader&&!u?"start":u?"end":"middle",f=c("right"),p=c("left")||e.onPathbar,d=p?"left":f?"right":"center";!e.onPathbar&&e.isHeader||(r+=p?s:0,n-=f?s:0);var v=g.marker.pad;if(e.isHeader){if((r+=v.l-s)>=(n-=v.r-s)){var m=(r+n)/2;r=m-s,n=m+s}var y;u?a<(y=i-v.b)&&y<i&&(a=y):a<(y=a+v.t)&&y<i&&(i=y)}var x=l(r,n,a,i,o,{isHorizontal:!1,constrained:!0,angle:0,anchor:h});if("center"!==d){var b=(n-r)/2-x.scale*(o.right-o.left)/2;e.isHeader&&(b-=s),"left"===d?x.targetX-=b:"right"===d&&(x.targetX+=b)}return x.targetX=U(x.targetX),x.targetY=q(x.targetY),isNaN(x.targetX)||isNaN(x.targetY)?{}:{scale:x.scale,rotate:x.rotate,textX:x.textX,textY:x.textY,targetX:x.targetX,targetY:x.targetY}},$=function(t,e){for(var r,n=0,a=t;!r&&n<k;)n++,(a=a.parent)?r=B(a,e):n=k;return r||{}},tt=function(t,e,r,a){var i,s=B(t,e);if(s)i=s;else if(e)i=O;else if(I)if(t.parent){var l=F||r;l&&!e?i=z(t,l,a):(i={},o.extendFlat(i,$(t,e)))}else i=t;else i={};return n.interpolate(i,{x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})},et=function(t,e,r,a){var s=B(t,e),l={},c=N(t,e,r,a);return o.extendFlat(l,{transform:Q({x0:c.x0,x1:c.x1,y0:c.y0,y1:c.y1,textBB:t.textBB,_text:t._text},{isHeader:i.isHeader(t,g)})}),s?l=s:t.parent&&o.extendFlat(l,$(t,e)),n.interpolate(l,{transform:{scale:t.transform.scale,rotate:t.transform.rotate,textX:t.transform.textX,textY:t.transform.textY,targetX:t.transform.targetX,targetY:t.transform.targetY}})},rt=function(t,e,r,a,i){var o=a[0],s=a[1];w?t.exit().transition().each(function(){var t=n.select(this);t.select("path.surface").transition().attrTween("d",function(t){var r=function(t,e,r,a){var i,o=B(t,e);if(e)i=O;else{var s=B(m,e);i=s?z(t,s,a):{}}return n.interpolate(o,i)}(t,e,0,[o,s]);return function(t){return i(r(t))}}),t.select("g.slicetext").attr("opacity",0)}).remove():t.exit().remove()},nt=function(t){return o.getTextTransform({textX:t.transform.textX,textY:t.transform.textY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate})};w&&(x.each(function(t){D[f(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(D[f(t)].transform={textX:t.transform.textX,textY:t.transform.textY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate})}),b.each(function(t){R[f(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(R[f(t)].transform={textX:t.transform.textX,textY:t.transform.textY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate}),!I&&i.isEntry(t)&&(I=t)})),F=u(t,e,m,b,{width:M,height:S,viewX:U,viewY:q,pathSlice:function(t){var e=U(t.x0),r=U(t.x1),n=q(t.y0),a=q(t.y1),i=r-e,o=a-n;if(!i||!o)return"";return"M"+X(e,n+0)+"L"+X(r-0,n)+"L"+X(r,a-0)+"L"+X(e+0,a)+"Z"},toMoveInsideSlice:Q,prevEntry:I,makeUpdateSliceInterpolator:tt,makeUpdateTextInterpolator:et,handleSlicesExit:rt,hasTransition:w,strTransform:nt}),g.pathbar.visible&&h(t,e,m,x,{barDifY:P,width:E,height:L,viewX:Y,viewY:W,pathSlice:function(t){var e=Y(Math.max(Math.min(t.x0,t.x0),0)),r=Y(Math.min(Math.max(t.x1,t.x1),E)),n=W(t.y0),a=W(t.y1),i=L/2,o={},s={};o.x=e,s.x=r,o.y=s.y=(n+a)/2;var l={x:e,y:n},c={x:r,y:n},u={x:r,y:a},h={x:e,y:a};return">"===K?(l.x-=i,c.x-=i,u.x-=i,h.x-=i):"/"===K?(u.x-=i,h.x-=i,o.x-=i/2,s.x-=i/2):"\\"===K?(l.x-=i,c.x-=i,o.x-=i/2,s.x-=i/2):"<"===K&&(o.x-=i,s.x-=i),J(l),J(h),J(o),J(c),J(u),J(s),"M"+X(l.x,l.y)+"L"+X(c.x,c.y)+"L"+X(s.x,s.y)+"L"+X(u.x,u.y)+"L"+X(h.x,h.y)+"L"+X(o.x,o.y)+"Z"},toMoveInsideSlice:Q,makeUpdateSliceInterpolator:tt,makeUpdateTextInterpolator:et,handleSlicesExit:rt,hasTransition:w,strTransform:nt})}e.exports=function(t,e,r,i){var o,s,l=t._fullLayout._treemaplayer,c=!r;((o=l.selectAll("g.trace.treemap").data(e,function(t){return t[0].trace.uid})).enter().append("g").classed("trace",!0).classed("treemap",!0),o.order(),a(r))?(i&&(s=i()),n.transition().duration(r.duration).ease(r.easing).each("end",function(){s&&s()}).each("interrupt",function(){s&&s()}).each(function(){l.selectAll("g.trace").each(function(e){p(t,e,this,r)})})):o.each(function(e){p(t,e,this,r)});c&&o.exit().remove()}},{"../../lib":716,"../bar/constants":857,"../bar/plot":866,"../sunburst/helpers":1234,"./constants":1257,"./draw_ancestors":1259,"./draw_descendants":1260,d3:164}],1266:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../../lib"),o=t("../sunburst/helpers");function s(t,e,r,n){var s,l,c=(n||{}).hovered,u=e.data.data,h=u.i,f=u.color,p=o.isHierarchyRoot(e),d=1;if(c)s=r._hovered.marker.line.color,l=r._hovered.marker.line.width;else if(p&&"rgba(0,0,0,0)"===f)d=0,s="rgba(0,0,0,0)",l=0;else if(s=i.castOption(r,h,"marker.line.color")||a.defaultLine,l=i.castOption(r,h,"marker.line.width")||0,!r._hasColorscale&&!e.onPathbar){var g=r.marker.depthfade;if(g){var v,m=a.combine(a.addOpacity(r._backgroundColor,.75),f);if(!0===g){var y=o.getMaxDepth(r);v=isFinite(y)?o.isLeaf(e)?0:r._maxVisibleLayers-(e.data.depth-r._entryDepth):e.data.height+1}else v=e.data.depth-r._entryDepth,r._atRootLevel||v++;if(v>0)for(var x=0;x<v;x++){var b=.5*x/v;f=a.combine(a.addOpacity(m,b),f)}}}t.style("stroke-width",l).call(a.fill,f).call(a.stroke,s).style("opacity",d)}e.exports={style:function(t){t._fullLayout._treemaplayer.selectAll(".trace").each(function(t){var e=n.select(this),r=t[0].trace;e.style("opacity",r.opacity),e.selectAll("path.surface").each(function(t){n.select(this).call(s,t,r,{hovered:!1})})})},styleOne:s}},{"../../components/color":591,"../../lib":716,"../sunburst/helpers":1234,d3:164}],1267:[function(t,e,r){"use strict";var n=t("../box/attributes"),a=t("../../lib/extend").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:a({},n.name,{}),orientation:a({},n.orientation,{}),bandwidth:{valType:"number",min:0,editType:"calc"},scalegroup:{valType:"string",dflt:"",editType:"calc"},scalemode:{valType:"enumerated",values:["width","count"],dflt:"width",editType:"calc"},spanmode:{valType:"enumerated",values:["soft","hard","manual"],dflt:"soft",editType:"calc"},span:{valType:"info_array",items:[{valType:"any",editType:"calc"},{valType:"any",editType:"calc"}],editType:"calc"},line:{color:{valType:"color",editType:"style"},width:{valType:"number",min:0,dflt:2,editType:"style"},editType:"plot"},fillcolor:n.fillcolor,points:a({},n.boxpoints,{}),jitter:a({},n.jitter,{}),pointpos:a({},n.pointpos,{}),width:a({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:"boolean",dflt:!1,editType:"plot"},width:{valType:"number",min:0,max:1,dflt:.25,editType:"plot"},fillcolor:{valType:"color",editType:"style"},line:{color:{valType:"color",editType:"style"},width:{valType:"number",min:0,editType:"style"},editType:"style"},editType:"plot"},meanline:{visible:{valType:"boolean",dflt:!1,editType:"plot"},color:{valType:"color",editType:"style"},width:{valType:"number",min:0,editType:"style"},editType:"plot"},side:{valType:"enumerated",values:["both","positive","negative"],dflt:"both",editType:"calc"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:"flaglist",flags:["violins","points","kde"],dflt:"violins+points+kde",extras:["all"],editType:"style"}}},{"../../lib/extend":707,"../box/attributes":879}],1268:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../box/calc"),o=t("./helpers"),s=t("../../constants/numerical").BADNUM;function l(t,e,r){var a=e.max-e.min;if(!a)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,a/1e4);var i=r.length,o=n.stdev(r,i-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(i,o,e.q3-e.q1),a/100)}function c(t,e,r,n){var i,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var a=l[n],i="multicategory"===r.type?r.r2c(a):r.d2c(a,0,t[e.valLetter+"calendar"]);return i===s?u[n]:i}var f={type:"linear",range:i="soft"===o?u:"hard"===o?c:[h(0),h(1)]};return a.setConvert(f),f.cleanRange(),i}e.exports=function(t,e){var r=i(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=a.getFromId(t,e["h"===e.orientation?"xaxis":"yaxis"]),h=1/0,f=-1/0,p=0,d=0,g=0;g<r.length;g++){var v=r[g],m=v.pts.map(o.extractVal),y=v.bandwidth=l(e,v,m),x=v.span=c(e,v,u,y);if(v.min===v.max&&0===y)x=v.span=[v.min,v.max],v.density=[{v:1,t:x[0]}],v.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error("Something went wrong with computing the violin span"),r[0].t.empty=!0,r;var k=o.makeKDE(v,e,m);v.density=new Array(_);for(var T=0,A=x[0];A<x[1]+w/2;T++,A+=w){var M=k(A);v.density[T]={v:M,t:A},p=Math.max(p,M)}}d=Math.max(d,m.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=a.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,L=e.scalegroup,C=E[L];C?(C.maxKDE=Math.max(C.maxKDE,p),C.maxCount=Math.max(C.maxCount,d)):E[L]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,"kde:"),r}},{"../../constants/numerical":692,"../../lib":716,"../../plots/cartesian/axes":764,"../box/calc":880,"./helpers":1271}],1269:[function(t,e,r){"use strict";var n=t("../box/cross_trace_calc").setPositionOffset,a=["v","h"];e.exports=function(t,e){for(var r=t.calcdata,i=e.xaxis,o=e.yaxis,s=0;s<a.length;s++){for(var l=a[s],c="h"===l?o:i,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||"violin"!==d.type||p.empty||d.orientation!==l||d.xaxis!==i._id||d.yaxis!==o._id||u.push(h)}n("violin",t,u,c)}}},{"../box/cross_trace_calc":881}],1270:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../components/color"),i=t("../box/defaults"),o=t("./attributes");e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,o,r,a)}function c(r,a){return n.coerce2(t,e,o,r,a)}if(i.handleSampleDefaults(t,e,l,s),!1!==e.visible){l("bandwidth"),l("side"),l("width")||(l("scalegroup",e.name),l("scalemode"));var u,h=l("span");Array.isArray(h)&&(u="manual"),l("spanmode",u);var f=l("line.color",(t.marker||{}).color||r),p=l("line.width"),d=l("fillcolor",a.addOpacity(e.line.color,.5));i.handlePointsDefaults(t,e,l,{prefix:""});var g=c("box.width"),v=c("box.fillcolor",d),m=c("box.line.color",f),y=c("box.line.width",p);l("box.visible",Boolean(g||v||m||y))||(e.box={visible:!1});var x=c("meanline.color",f),b=c("meanline.width",p);l("meanline.visible",Boolean(x||b))||(e.meanline={visible:!1})}}},{"../../components/color":591,"../../lib":716,"../box/defaults":882,"./attributes":1267}],1271:[function(t,e,r){"use strict";var n=t("../../lib"),a=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,i=a,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,a=0;a<n;a++)e+=i((t-r[a])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var a,i;"h"===e.orientation?(a="y",i="x"):(a="x",i="y");var o=n.findPointOnPath(t.path,r,i,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[a];return[l,"both"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var a=t.pts.map(r.extractVal);return r.makeKDE(t,e,a)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{"../../lib":716}],1272:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../../plots/cartesian/axes"),i=t("../box/hover"),o=t("./helpers");e.exports=function(t,e,r,s,l){var c,u,h=t.cd,f=h[0].trace,p=f.hoveron,d=-1!==p.indexOf("violins"),g=-1!==p.indexOf("kde"),v=[];if(d||g){var m=i.hoverOnBoxes(t,e,r,s);if(g&&m.length>0){var y,x,b,_,w,k=t.xa,T=t.ya;"h"===f.orientation?(w=e,y="y",b=T,x="x",_=k):(w=r,y="x",b=k,x="y",_=T);var A=h[t.index];if(w>=A.span[0]&&w<=A.span[1]){var M=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(A,f,w),L=o.getPositionOnKdePath(A,f,S),C=b._offset,P=b._length;M[y+"0"]=L[0],M[y+"1"]=L[1],M[x+"0"]=M[x+"1"]=S,M[x+"Label"]=x+": "+a.hoverLabelText(_,w)+", "+h[0].t.labels.kde+" "+E.toFixed(3),M.spikeDistance=m[0].spikeDistance;var O=y+"Spike";M[O]=m[0][O],m[0].spikeDistance=void 0,m[0][O]=void 0,M.hovertemplate=!1,v.push(M),(u={stroke:t.color})[y+"1"]=n.constrain(C+L[0],C,C+P),u[y+"2"]=n.constrain(C+L[1],C,C+P),u[x+"1"]=u[x+"2"]=_._offset+S}}d&&(v=v.concat(m))}-1!==p.indexOf("points")&&(c=i.hoverOnPoints(t,e,r));var z=l.selectAll(".violinline-"+f.uid).data(u?[0]:[]);return z.enter().append("line").classed("violinline-"+f.uid,!0).attr("stroke-width",1.5),z.exit().remove(),z.attr(u),"closest"===s?c?[c]:v:c?(v.push(c),v):v}},{"../../lib":716,"../../plots/cartesian/axes":764,"../box/hover":884,"./helpers":1271}],1273:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults"),crossTraceDefaults:t("../box/defaults").crossTraceDefaults,supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc"),crossTraceCalc:t("./cross_trace_calc"),plot:t("./plot"),style:t("./style"),styleOnSelect:t("../scatter/style").styleOnSelect,hoverPoints:t("./hover"),selectPoints:t("../box/select"),moduleType:"trace",name:"violin",basePlotModule:t("../../plots/cartesian"),categories:["cartesian","svg","symbols","oriented","box-violin","showLegend","violinLayout","zoomScale"],meta:{}}},{"../../plots/cartesian":775,"../box/defaults":882,"../box/select":889,"../scatter/style":1141,"./attributes":1267,"./calc":1268,"./cross_trace_calc":1269,"./defaults":1270,"./hover":1272,"./layout_attributes":1274,"./layout_defaults":1275,"./plot":1276,"./style":1277}],1274:[function(t,e,r){"use strict";var n=t("../box/layout_attributes"),a=t("../../lib").extendFlat;e.exports={violinmode:a({},n.boxmode,{}),violingap:a({},n.boxgap,{}),violingroupgap:a({},n.boxgroupgap,{})}},{"../../lib":716,"../box/layout_attributes":886}],1275:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes"),i=t("../box/layout_defaults");e.exports=function(t,e,r){i._supply(t,e,r,function(r,i){return n.coerce(t,e,a,r,i)},"violin")}},{"../../lib":716,"../box/layout_defaults":887,"./layout_attributes":1274}],1276:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../box/plot"),s=t("../scatter/line_points"),l=t("./helpers");e.exports=function(t,e,r,c){var u=t._fullLayout,h=e.xaxis,f=e.yaxis;function p(t){var e=s(t,{xaxis:h,yaxis:f,connectGaps:!0,baseTolerance:.75,shape:"spline",simplify:!0,linearized:!0});return i.smoothopen(e[0],1)}a.makeTraceGroups(c,r,"trace violins").each(function(t){var r=n.select(this),i=t[0],s=i.t,c=i.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,v=e[s.valLetter+"axis"],m=e[s.posLetter+"axis"],y="both"===c.side,x=y||"positive"===c.side,b=y||"negative"===c.side,_=r.selectAll("path.violin").data(a.identity);_.enter().append("path").style("vector-effect","non-scaling-stroke").attr("class","violin"),_.exit().remove(),_.each(function(t){var e,r,a,i,o,l,h,f,_=n.select(this),w=t.density,k=w.length,T=m.c2l(t.pos+d,!0),A=m.l2p(T);if(c.width)e=s.maxKDE/g;else{var M=u._violinScaleGroupStats[c.scalegroup];e="count"===c.scalemode?M.maxKDE/g*(M.maxCount/t.pts.length):M.maxKDE/g}if(x){for(h=new Array(k),o=0;o<k;o++)(f=h[o]={})[s.posLetter]=T+w[o].v/e,f[s.valLetter]=v.c2l(w[o].t,!0);r=p(h)}if(b){for(h=new Array(k),l=0,o=k-1;l<k;l++,o--)(f=h[l]={})[s.posLetter]=T-w[o].v/e,f[s.valLetter]=v.c2l(w[o].t,!0);a=p(h)}if(y)i=r+"L"+a.substr(1)+"Z";else{var S=[A,v.c2p(w[0].t)],E=[A,v.c2p(w[k-1].t)];"h"===c.orientation&&(S.reverse(),E.reverse()),i=x?"M"+S+"L"+r.substr(1)+"L"+E:"M"+E+"L"+a.substr(1)+"L"+S}_.attr("d",i),t.posCenterPx=A,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)});var w,k,T,A=c.box,M=A.width,S=(A.line||{}).width;y?(w=g*M,k=0):x?(w=[0,g*M/2],k=S*{x:1,y:-1}[s.posLetter]):(w=[g*M/2,0],k=S*{x:-1,y:1}[s.posLetter]),o.plotBoxAndWhiskers(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),o.plotBoxMean(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(T=a.identity);var E=r.selectAll("path.meanline").data(T||[]);E.enter().append("path").attr("class","meanline").style("fill","none").style("vector-effect","non-scaling-stroke"),E.exit().remove(),E.each(function(t){var e=v.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr("d","h"===c.orientation?"M"+e+","+r[0]+"V"+r[1]:"M"+r[0]+","+e+"H"+r[1])}),o.plotPoints(r,{x:h,y:f},c,s)}})}},{"../../components/drawing":612,"../../lib":716,"../box/plot":888,"../scatter/line_points":1132,"./helpers":1271,d3:164}],1277:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/color"),i=t("../scatter/style").stylePoints;e.exports=function(t){var e=n.select(t).selectAll("g.trace.violins");e.style("opacity",function(t){return t[0].trace.opacity}),e.each(function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll("path.violin").style("stroke-width",r.line.width+"px").call(a.stroke,r.line.color).call(a.fill,r.fillcolor),o.selectAll("path.box").style("stroke-width",l.width+"px").call(a.stroke,l.color).call(a.fill,s.fillcolor);var h={"stroke-width":u+"px","stroke-dasharray":2*u+"px,"+u+"px"};o.selectAll("path.mean").style(h).call(a.stroke,c.color),o.selectAll("path.meanline").style(h).call(a.stroke,c.color),i(o,r,t)})}},{"../../components/color":591,"../scatter/style":1141,d3:164}],1278:[function(t,e,r){"use strict";var n=t("../../components/colorscale/attributes"),a=t("../isosurface/attributes"),i=t("../../plots/attributes"),o=t("../../lib/extend").extendFlat,s=t("../../plot_api/edit_types").overrideAll,l=e.exports=s(o({x:a.x,y:a.y,z:a.z,value:a.value,isomin:a.isomin,isomax:a.isomax,surface:a.surface,spaceframe:{show:{valType:"boolean",dflt:!1},fill:{valType:"number",min:0,max:1,dflt:1}},slices:a.slices,caps:a.caps,text:a.text,hovertext:a.hovertext,hovertemplate:a.hovertemplate},n("",{colorAttr:"`value`",showScaleDflt:!0,editTypeOverride:"calc"}),{colorbar:a.colorbar,opacity:a.opacity,opacityscale:{valType:"any",editType:"calc"},lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:o({},i.hoverinfo)}),"calc","nested");l.x.editType=l.y.editType=l.z.editType=l.value.editType="calc+clearAxisTypes",l.transforms=void 0},{"../../components/colorscale/attributes":598,"../../lib/extend":707,"../../plot_api/edit_types":747,"../../plots/attributes":761,"../isosurface/attributes":1054}],1279:[function(t,e,r){"use strict";var n=t("gl-mesh3d"),a=t("../../lib/gl_format_color").parseColorScale,i=t("../../lib/str2rgbarray"),o=t("../../components/colorscale").extractOpts,s=t("../../plots/gl3d/zip3"),l=t("../isosurface/convert").findNearestOnAxis,c=t("../isosurface/convert").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name="",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],a=this.data._z[e],i=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(a,this.data._Zs).id,h=t.index=u+o*c+o*i*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=c(t);var l={positions:s(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:s(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:i(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._intensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=a(t),this.mesh.update(l)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,a=n({gl:r}),i=new u(t,a,e.uid);return a._trace=i,i.update(e),t.glplot.add(a),i}},{"../../components/colorscale":603,"../../lib/gl_format_color":713,"../../lib/str2rgbarray":739,"../../plots/gl3d/zip3":815,"../isosurface/convert":1056,"gl-mesh3d":282}],1280:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./attributes"),i=t("../isosurface/defaults").supplyIsoDefaults;e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}i(t,e,r,o,s);var l=s("opacityscale");"max"===l?e.opacityscale=[[0,.1],[1,1]]:"min"===l?e.opacityscale=[[0,1],[1,.1]]:"extremes"===l?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var a=n/31,i=e+(1-e)*(1-Math.pow(Math.sin(t*a*Math.PI),2));r.push([a,Math.max(1,Math.min(0,i))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(l)||(e.opacityscale=void 0)}},{"../../lib":716,"../isosurface/defaults":1057,"./attributes":1278}],1281:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),supplyDefaults:t("./defaults"),calc:t("../isosurface/calc"),colorbar:{min:"cmin",max:"cmax"},plot:t("./convert"),moduleType:"trace",name:"volume",basePlotModule:t("../../plots/gl3d"),categories:["gl3d"],meta:{}}},{"../../plots/gl3d":804,"../isosurface/calc":1055,"./attributes":1278,"./convert":1279,"./defaults":1280}],1282:[function(t,e,r){"use strict";var n=t("../bar/attributes"),a=t("../scatter/attributes").line,i=t("../../plots/attributes"),o=t("../../plots/template_attributes").hovertemplateAttrs,s=t("../../plots/template_attributes").texttemplateAttrs,l=t("./constants"),c=t("../../lib/extend").extendFlat,u=t("../../components/color");function h(t){return{marker:{color:c({},n.marker.color,{arrayOk:!1,editType:"style"}),line:{color:c({},n.marker.line.color,{arrayOk:!1,editType:"style"}),width:c({},n.marker.line.width,{arrayOk:!1,editType:"style"}),editType:"style"},editType:"style"},editType:"style"}}e.exports={measure:{valType:"data_array",dflt:[],editType:"calc"},base:{valType:"number",dflt:null,arrayOk:!1,editType:"calc"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},i.hoverinfo,{flags:["name","x","y","text","initial","delta","final"]}),textinfo:{valType:"flaglist",flags:["label","text","initial","delta","final"],extras:["none"],editType:"plot",arrayOk:!1},texttemplate:s({editType:"plot"},{keys:l.eventDataKeys.concat(["label"])}),text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:h(),decreasing:h(),totals:h(),connector:{line:{color:c({},a.color,{dflt:u.defaultLine}),width:c({},a.width,{editType:"plot"}),dash:a.dash,editType:"plot"},mode:{valType:"enumerated",values:["spanning","between"],dflt:"between",editType:"plot"},visible:{valType:"boolean",dflt:!0,editType:"plot"},editType:"plot"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{"../../components/color":591,"../../lib/extend":707,"../../plots/attributes":761,"../../plots/template_attributes":840,"../bar/attributes":855,"../scatter/attributes":1118,"./constants":1284}],1283:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes"),a=t("../../lib").mergeArray,i=t("../scatter/calc_selection"),o=t("../../constants/numerical").BADNUM;function s(t){return"a"===t||"absolute"===t}function l(t){return"t"===t||"total"===t}e.exports=function(t,e){var r,c,u=n.getFromId(t,e.xaxis||"x"),h=n.getFromId(t,e.yaxis||"y");"h"===e.orientation?(r=u.makeCalcdata(e,"x"),c=h.makeCalcdata(e,"y")):(r=h.makeCalcdata(e,"y"),c=u.makeCalcdata(e,"x"));for(var f,p=Math.min(c.length,r.length),d=new Array(p),g=0,v=!1,m=0;m<p;m++){var y=r[m]||0,x=!1;(r[m]!==o||l(e.measure[m])||s(e.measure[m]))&&m+1<p&&(r[m+1]!==o||l(e.measure[m+1])||s(e.measure[m+1]))&&(x=!0);var b=d[m]={i:m,p:c[m],s:y,rawS:y,cNext:x};s(e.measure[m])?(g=b.s,b.isSum=!0,b.dir="totals",b.s=g):l(e.measure[m])?(b.isSum=!0,b.dir="totals",b.s=g):(b.isSum=!1,b.dir=b.rawS<0?"decreasing":"increasing",f=b.s,b.s=g+f,g+=f),"totals"===b.dir&&(v=!0),e.ids&&(b.id=String(e.ids[m])),b.v=(e.base||0)+g}return d.length&&(d[0].hasTotals=v),a(e.text,d,"tx"),a(e.hovertext,d,"htx"),i(d,e),d}},{"../../constants/numerical":692,"../../lib":716,"../../plots/cartesian/axes":764,"../scatter/calc_selection":1120}],1284:[function(t,e,r){"use strict";e.exports={eventDataKeys:["initial","delta","final"]}},{}],1285:[function(t,e,r){"use strict";var n=t("../bar/cross_trace_calc").setGroupPositions;e.exports=function(t,e){var r,a,i=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(a=0;a<o.length;a++){var p=o[a];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&"waterfall"===p.type&&(r=s[a],"h"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:i.waterfallmode,norm:i.waterfallnorm,gap:i.waterfallgap,groupgap:i.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),a=0;a<u.length;a++){r=u[a];for(var g=0;g<r.length;g++){var v=r[g];!1===v.isSum&&(v.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{"../bar/cross_trace_calc":858}],1286:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("../bar/defaults").handleGroupingDefaults,i=t("../bar/defaults").handleText,o=t("../scatter/xy_defaults"),s=t("./attributes"),l=t("../../components/color"),c=t("../../constants/delta.js"),u=c.INCREASING.COLOR,h=c.DECREASING.COLOR,f="#4499FF";function p(t,e,r){t(e+".marker.color",r),t(e+".marker.line.color",l.defaultLine),t(e+".marker.line.width")}e.exports={supplyDefaults:function(t,e,r,a){function l(r,a){return n.coerce(t,e,s,r,a)}if(o(t,e,a,l)){l("measure"),l("orientation",e.x&&!e.y?"h":"v"),l("base"),l("offset"),l("width"),l("text"),l("hovertext"),l("hovertemplate");var c=l("textposition");i(t,e,a,l,c,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),"none"!==e.textposition&&(l("texttemplate"),e.texttemplate||l("textinfo")),p(l,"increasing",u),p(l,"decreasing",h),p(l,"totals",f),l("connector.visible")&&(l("connector.mode"),l("connector.line.width")&&(l("connector.line.color"),l("connector.line.dash")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,i;function o(t){return n.coerce(i._input,i,s,t)}if("group"===e.waterfallmode)for(var l=0;l<t.length;l++)r=(i=t[l])._input,a(r,i,e,o)}}},{"../../components/color":591,"../../constants/delta.js":686,"../../lib":716,"../bar/defaults":859,"../scatter/xy_defaults":1144,"./attributes":1282}],1287:[function(t,e,r){"use strict";e.exports=function(t,e){return t.x="xVal"in e?e.xVal:e.x,t.y="yVal"in e?e.yVal:e.y,"initial"in e&&(t.initial=e.initial),"delta"in e&&(t.delta=e.delta),"final"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1288:[function(t,e,r){"use strict";var n=t("../../plots/cartesian/axes").hoverLabelText,a=t("../../components/color").opacity,i=t("../bar/hover").hoverOnBars,o=t("../../constants/delta.js"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=i(t,e,r,o);if(c){var u=c.cd,h=u[0].trace,f="h"===h.orientation,p=f?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var v=w(Math.abs(c.delta));c.deltaLabel=g<0?"("+v+")":v,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var m=d.hi||h.hoverinfo,y=[];if(m&&"none"!==m&&"skip"!==m){var x="all"===m,b=m.split("+"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_("final")||_(f?"x":"y")||y.push(c.finalLabel),_("delta")&&(g<0?y.push(c.deltaLabel+" "+l):y.push(c.deltaLabel+" "+s)),_("initial")&&y.push("Initial: "+c.initialLabel))}return y.length&&(c.extraText=y.join("<br>")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,i=r.line.color,o=r.line.width;if(a(n))return n;if(a(i)&&o)return i}(h,d),[c]}function w(t){return n(p,t)}}},{"../../components/color":591,"../../constants/delta.js":686,"../../plots/cartesian/axes":764,"../bar/hover":862}],1289:[function(t,e,r){"use strict";e.exports={attributes:t("./attributes"),layoutAttributes:t("./layout_attributes"),supplyDefaults:t("./defaults").supplyDefaults,crossTraceDefaults:t("./defaults").crossTraceDefaults,supplyLayoutDefaults:t("./layout_defaults"),calc:t("./calc"),crossTraceCalc:t("./cross_trace_calc"),plot:t("./plot"),style:t("./style").style,hoverPoints:t("./hover"),eventData:t("./event_data"),selectPoints:t("../bar/select"),moduleType:"trace",name:"waterfall",basePlotModule:t("../../plots/cartesian"),categories:["bar-like","cartesian","svg","oriented","showLegend","zoomScale"],meta:{}}},{"../../plots/cartesian":775,"../bar/select":867,"./attributes":1282,"./calc":1283,"./cross_trace_calc":1285,"./defaults":1286,"./event_data":1287,"./hover":1288,"./layout_attributes":1290,"./layout_defaults":1291,"./plot":1292,"./style":1293}],1290:[function(t,e,r){"use strict";e.exports={waterfallmode:{valType:"enumerated",values:["group","overlay"],dflt:"group",editType:"calc"},waterfallgap:{valType:"number",min:0,max:1,editType:"calc"},waterfallgroupgap:{valType:"number",min:0,max:1,dflt:0,editType:"calc"}}},{}],1291:[function(t,e,r){"use strict";var n=t("../../lib"),a=t("./layout_attributes");e.exports=function(t,e,r){var i=!1;function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&"waterfall"===l.type){i=!0;break}}i&&(o("waterfallmode"),o("waterfallgap",.2),o("waterfallgroupgap"))}},{"../../lib":716,"./layout_attributes":1290}],1292:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../lib"),i=t("../../components/drawing"),o=t("../bar/plot").plot;e.exports=function(t,e,r,s){var l=t._fullLayout;o(t,e,r,s,{mode:l.waterfallmode,norm:l.waterfallmode,gap:l.waterfallgap,groupgap:l.waterfallgroupgap}),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;a.makeTraceGroups(o,r,"trace bars").each(function(r){var o=n.select(this),c=r[0].trace,u=a.ensureSingle(o,"g","lines");if(c.connector&&c.connector.visible){var h="h"===c.orientation,f=c.connector.mode,p=u.selectAll("g.line").data(a.identity);p.enter().append("g").classed("line",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var c=function(t,e,r,n){var a=[],i=[],o=n?e:r,s=n?r:e;return a[0]=o.c2p(t.s0,!0),i[0]=s.c2p(t.p0,!0),a[1]=o.c2p(t.s1,!0),i[1]=s.c2p(t.p1,!0),a[2]=o.c2p(t.nextS0,!0),i[2]=s.c2p(t.nextP0,!0),n?[a,i]:[i,a]}(r,s,l,h),u=c[0],p=c[1],g="";"spanning"===f&&!r.isSum&&o>0&&(g+=h?"M"+u[0]+","+p[1]+"V"+p[0]:"M"+u[1]+","+p[0]+"H"+u[0]),"between"!==f&&(r.isSum||o<d-1)&&(g+=h?"M"+u[1]+","+p[0]+"V"+p[1]:"M"+u[0]+","+p[1]+"H"+u[1]),void 0!==u[2]&&void 0!==p[2]&&(g+=h?"M"+u[1]+","+p[1]+"V"+p[2]:"M"+u[1]+","+p[1]+"H"+u[2]),""===g&&(g="M0,0Z"),a.ensureSingle(n.select(this),"path").attr("d",g).call(i.setClipUrl,e.layerClipId,t)}})}else u.remove()})}(t,e,r,s)}},{"../../components/drawing":612,"../../lib":716,"../bar/plot":866,d3:164}],1293:[function(t,e,r){"use strict";var n=t("d3"),a=t("../../components/drawing"),i=t("../../components/color"),o=t("../../constants/interactions").DESELECTDIM,s=t("../bar/style").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll("g.waterfalllayer").selectAll("g.trace");l.style("opacity",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(".point > path").each(function(t){if(!t.isBlank){var e=l[t.dir].marker;n.select(this).call(i.fill,e.color).call(i.stroke,e.line.color).call(a.dashLine,e.line.dash,e.line.width).style("opacity",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(".lines").each(function(){var t=l.connector.line;a.lineGroupStyle(n.select(this).selectAll("path"),t.width,t.color,t.dash)})})}}},{"../../components/color":591,"../../components/drawing":612,"../../constants/interactions":691,"../bar/style":869,d3:164}],1294:[function(t,e,r){"use strict";var n=t("../plots/cartesian/axes"),a=t("../lib"),i=t("../plot_api/plot_schema"),o=t("./helpers").pointsAccessorFunction,s=t("../constants/numerical").BADNUM;r.moduleType="transform",r.name="aggregate";var l=r.attributes={enabled:{valType:"boolean",dflt:!0,editType:"calc"},groups:{valType:"string",strict:!0,noBlank:!0,arrayOk:!0,dflt:"x",editType:"calc"},aggregations:{_isLinkedToArray:"aggregation",target:{valType:"string",editType:"calc"},func:{valType:"enumerated",values:["count","sum","avg","median","mode","rms","stddev","min","max","first","last","change","range"],dflt:"first",editType:"calc"},funcmode:{valType:"enumerated",values:["sample","population"],dflt:"sample",editType:"calc"},enabled:{valType:"boolean",dflt:!0,editType:"calc"},editType:"calc"},editType:"calc"},c=l.aggregations;function u(t,e,r,i){if(i.enabled){for(var o=i.target,l=a.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,a=e.c2d;switch(r){case"count":return h;case"first":return f;case"last":return p;case"sum":return function(t,e){for(var r=0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r+=o)}return a(r)};case"avg":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,i++)}return i?a(r/i):s};case"min":return function(t,e){for(var r=1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:a(r)};case"max":return function(t,e){for(var r=-1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:a(r)};case"range":return function(t,e){for(var r=1/0,i=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),i=Math.max(i,l))}return i===-1/0||r===1/0?s:a(i-r)};case"change":return function(t,e){var r=n(t[e[0]]),i=n(t[e[e.length-1]]);return r===s||i===s?s:a(i-r)};case"median":return function(t,e){for(var r=[],i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&r.push(o)}if(!r.length)return s;r.sort();var l=(r.length-1)/2;return a((r[Math.floor(l)]+r[Math.ceil(l)])/2)};case"mode":return function(t,e){for(var r={},i=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>i&&(i=u,o=c)}}return i?a(o):s};case"rms":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,i++)}return i?a(Math.sqrt(r/i)):s};case"stddev":return function(e,r){var a,i=0,o=0,l=1,c=s;for(a=0;a<r.length&&c===s;a++)c=n(e[r[a]]);if(c===s)return s;for(;a<r.length;a++){var u=n(e[r[a]]);if(u!==s){var h=u-c;i+=h,o+=h*h,l++}}var f="sample"===t.funcmode?l-1:l;return f?Math.sqrt((o-i*i/l)/f):0}}}(i,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),"count"===i.func&&a.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return a.coerce(t,n,l,e,r)}if(!o("enabled"))return n;var s=i.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o("groups");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return a.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var v=g("target"),m=g("func");g("enabled")&&v&&(u[v]||"count"===m&&void 0===u[v])?("stddev"===m&&g("funcmode"),u[v]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,i=a.getTargetArray(e,{target:n});if(i){var s,l,c,h,f={},p={},d=[],g=o(e.transforms,r),v=i.length;for(e._length&&(v=Math.min(v,e._length)),s=0;s<v;s++)void 0===(c=f[l=i[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=g(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(g(s)));r._indexToPoints=p;var m=r.aggregations;for(s=0;s<m.length;s++)u(t,e,d,m[s]);"string"==typeof n&&u(t,e,d,{target:n,func:"first",enabled:!0}),e._length=d.length}}}},{"../constants/numerical":692,"../lib":716,"../plot_api/plot_schema":753,"../plots/cartesian/axes":764,"./helpers":1297}],1295:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../registry"),i=t("../plots/cartesian/axes"),o=t("./helpers").pointsAccessorFunction,s=t("../constants/filter_ops"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType="transform",r.name="filter",r.attributes={enabled:{valType:"boolean",dflt:!0,editType:"calc"},target:{valType:"string",strict:!0,noBlank:!0,arrayOk:!0,dflt:"x",editType:"calc"},operation:{valType:"enumerated",values:[].concat(l).concat(c).concat(u),dflt:"=",editType:"calc"},value:{valType:"any",dflt:0,editType:"calc"},preservegaps:{valType:"boolean",dflt:!1,editType:"calc"},editType:"calc"},r.supplyDefaults=function(t){var e={};function i(a,i){return n.coerce(t,e,r.attributes,a,i)}if(i("enabled")){var o=i("target");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;i("preservegaps"),i("operation"),i("value");var s=a.getComponentMethod("calendars","handleDefaults");s(t,e,"valuecalendar",null),s(t,e,"targetcalendar",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var a=n.getTargetArray(e,r);if(a){var s=r.target,h=a.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if("string"==typeof s){var g=n.nestedProperty(e,s+"calendar").get();g&&(f=g)}var v,m,y=function(t,e,r){var n=t.operation,a=t.value,i=Array.isArray(a);function o(t){return-1!==t.indexOf(n)}var s,h=function(r){return e(r,0,t.valuecalendar)},f=function(t){return e(t,0,r)};o(l)?s=h(i?a[0]:a):o(c)?s=i?[h(a[0]),h(a[1])]:[h(a),h(a)]:o(u)&&(s=i?a.map(h):[h(a)]);switch(n){case"=":return function(t){return f(t)===s};case"!=":return function(t){return f(t)!==s};case"<":return function(t){return f(t)<s};case"<=":return function(t){return f(t)<=s};case">":return function(t){return f(t)>s};case">=":return function(t){return f(t)>=s};case"[]":return function(t){var e=f(t);return e>=s[0]&&e<=s[1]};case"()":return function(t){var e=f(t);return e>s[0]&&e<s[1]};case"[)":return function(t){var e=f(t);return e>=s[0]&&e<s[1]};case"(]":return function(t){var e=f(t);return e>s[0]&&e<=s[1]};case"][":return function(t){var e=f(t);return e<=s[0]||e>=s[1]};case")(":return function(t){var e=f(t);return e<s[0]||e>s[1]};case"](":return function(t){var e=f(t);return e<=s[0]||e>s[1]};case")[":return function(t){var e=f(t);return e<s[0]||e>=s[1]};case"{}":return function(t){return-1!==s.indexOf(f(t))};case"}{":return function(t){return-1===s.indexOf(f(t))}}}(r,i.getDataToCoordFunc(t,e,s,a),f),x={},b={},_=0;d?(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},m=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},m=function(t,e){var r=x[t.astr][e];t.get().push(r)}),T(v);for(var w=o(e.transforms,r),k=0;k<h;k++){y(a[k])?(T(m,k),b[_++]=w(k)):d&&_++}r._indexToPoints=b,e._length=_}}function T(t,r){for(var a=0;a<p.length;a++){t(n.nestedProperty(e,p[a]),r)}}}},{"../constants/filter_ops":688,"../lib":716,"../plots/cartesian/axes":764,"../registry":845,"./helpers":1297}],1296:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plot_api/plot_schema"),i=t("../plots/plots"),o=t("./helpers").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,h,f,p,d,g,v=e.transform,m=e.transformIndex,y=t.transforms[m].groups,x=o(t.transforms,v);if(!Array.isArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,k=a.findArrayAttributes(t),T=v.styles||[],A={};for(r=0;r<T.length;r++)A[T[r].target]=T[r].value;v.styles&&(g=n.keyedContainer(v,"styles","target","value.name"));var M={},S={};for(r=0;r<b.length;r++){M[h=b[r]]=r,S[h]=0,(f=_[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[m]._indexToPoints={};var E=null;for(g&&(E=g.get(h)),f.name=E||""===E?E:n.templateString(v.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<k.length;s++)n.nestedProperty(f,k[s]).set([])}for(l=0;l<k.length;l++){for(c=k[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[M[y[s]]].push(u[s])}for(s=0;s<w;s++){(f=_[M[y[s]]]).transforms[m]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)h=b[r],f=_[r],i.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,A[h]||{});return _}r.moduleType="transform",r.name="groupby",r.attributes={enabled:{valType:"boolean",dflt:!0,editType:"calc"},groups:{valType:"data_array",dflt:[],editType:"calc"},nameformat:{valType:"string",editType:"calc"},styles:{_isLinkedToArray:"style",target:{valType:"string",editType:"calc"},value:{valType:"any",dflt:{},editType:"calc",_compareAsJSON:!0},editType:"calc"},editType:"calc"},r.supplyDefaults=function(t,e,a){var i,o={};function s(e,a){return n.coerce(t,o,r.attributes,e,a)}if(!s("enabled"))return o;s("groups"),s("nameformat",a._dataLength>1?"%{group} (%{trace})":"%{group}");var l=t.styles,c=o.styles=[];if(l)for(i=0;i<l.length;i++){var u=c[i]={};n.coerce(l[i],c[i],r.attributes.styles,"target");var h=n.coerce(l[i],c[i],r.attributes.styles,"value");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},r.transform=function(t,e){var r,n,a,i=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),a=0;a<r.length;a++)i.push(r[a]);return i}},{"../lib":716,"../plot_api/plot_schema":753,"../plots/plots":825,"./helpers":1297}],1297:[function(t,e,r){"use strict";r.pointsAccessorFunction=function(t,e){for(var r,n,a=0;a<t.length&&(r=t[a])!==e;a++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1298:[function(t,e,r){"use strict";var n=t("../lib"),a=t("../plots/cartesian/axes"),i=t("./helpers").pointsAccessorFunction;r.moduleType="transform",r.name="sort",r.attributes={enabled:{valType:"boolean",dflt:!0,editType:"calc"},target:{valType:"string",strict:!0,noBlank:!0,arrayOk:!0,dflt:"x",editType:"calc"},order:{valType:"enumerated",values:["ascending","descending"],dflt:"ascending",editType:"calc"},editType:"calc"},r.supplyDefaults=function(t){var e={};function a(a,i){return n.coerce(t,e,r.attributes,a,i)}return a("enabled")&&(a("target"),a("order")),e},r.calcTransform=function(t,e,r){if(r.enabled){var o=n.getTargetArray(e,r);if(o){var s=r.target,l=o.length;e._length&&(l=Math.min(l,e._length));var c,u,h=e._arrayAttrs,f=function(t,e,r,n){var a,i=new Array(n),o=new Array(n);for(a=0;a<n;a++)i[a]={v:e[a],i:a};for(i.sort(function(t,e){switch(t.order){case"ascending":return function(t,r){return e(t.v)-e(r.v)};case"descending":return function(t,r){return e(r.v)-e(t.v)}}}(t,r)),a=0;a<n;a++)o[a]=i[a].i;return o}(r,o,a.getDataToCoordFunc(t,e,s,o),l),p=i(e.transforms,r),d={};for(c=0;c<h.length;c++){var g=n.nestedProperty(e,h[c]),v=g.get(),m=new Array(l);for(u=0;u<l;u++)m[u]=v[f[u]];g.set(m)}for(u=0;u<l;u++)d[u]=p(f[u]);r._indexToPoints=d,e._length=l}}}},{"../lib":716,"../plots/cartesian/axes":764,"./helpers":1297}]},{},[26])(26)});
            });
            require(['plotly'], function(Plotly) {
                window._Plotly = Plotly;
            });
            }
            </script>




.. raw:: html

    <div>
    
    
                <div id="3e175323-c71e-4868-9180-73a72a4f7511" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("3e175323-c71e-4868-9180-73a72a4f7511")) {
                        Plotly.newPlot(
                            '3e175323-c71e-4868-9180-73a72a4f7511',
                            [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.9129452507276277, 0.836655638536056, -0.008851309290403876, -0.8462204041751706, -0.9055783620066239, -0.13235175009777303, 0.7625584504796028, 0.956375928404503, 0.27090578830786904, -0.6636338842129675, -0.9880316240928618, -0.404037645323065, 0.5514266812416906, 0.9999118601072672, 0.5290826861200238, -0.428182669496151, -0.9917788534431158, -0.6435381333569994, 0.2963685787093853, 0.9637953862840878, 0.7451131604793488, -0.158622668804709, -0.9165215479156338, -0.8317747426285983, 0.017701925105413577, 0.8509035245341184, 0.9017883476488092, 0.123573122745224, -0.7682546613236668, -0.9537526527594719, -0.26237485370392877, 0.6702291758433747, 0.9866275920404853, 0.3959251501818342, -0.5587890488516162, -0.9997551733586199, -0.5215510020869119, 0.43616475524782494, 0.9928726480845371, 0.6367380071391379, -0.3048106211022167, -0.9661177700083929, -0.7391806966492229, 0.16735570030280694, 0.9200260381967907, 0.8268286794901035, -0.026551154023966794, -0.8555199789753223, -0.8979276806892913, -0.11478481378318722, 0.7738906815578891, 0.9510546532543747, 0.25382336276203626, -0.6767719568873076, -0.9851462604682474, -0.38778163540943045, 0.5661076368981803, 0.9995201585807313, 0.5139784559875352, -0.4441126687075084, -0.9938886539233752, -0.629887994274454, 0.31322878243308516, 0.9683644611001854, 0.7331903200732921, -0.1760756199485871, -0.9234584470040598, -0.8218178366308225, 0.03539830273366069, 0.8600694058124533, 0.8939966636005579, 0.10598751175115685, -0.7794660696158047, -0.9482821412699473, -0.2452519854676543, 0.683261714736121, 0.9835877454343449, 0.37960773902752165, -0.5733818719904229, -0.9992068341863537, -0.5063656411097588, 0.45202578717835057, 0.9948267913584063, 0.6229886314423488, -0.32162240316253093, -0.9705352835374847, -0.7271425000808527, 0.18478174456066745, 0.926818505417785, 0.8167426066363169, -0.044242678085070965, -0.8645514486106083, -0.8899956043668333, -0.09718190589320902, 0.7849803886813105, 0.9454353340247703, 0.23666139336428602, -0.689697940935389, -0.9819521690440836, -0.3714041014380903, 0.5806111842123143, 0.9988152247235795, 0.4987131538963941, -0.45990349068959124, -0.9956869868891794, -0.6160404591886565, 0.3299908256737821, 0.972630067242408, 0.7210377105017316, -0.19347339203846847, -0.9301059501867618, -0.8116033871367005, 0.05308358714605824, 0.8689657562142357, 0.8859248164599484, 0.08836868610400142, -0.7904332067228887, -0.9425144545582509, -0.2280522595008612, 0.6960801312247415, 0.9802396594403116, 0.363171365373259, -0.5877950071674065, -0.9983453608739179, -0.49102159389846933, 0.4677451620451334, 0.9964691731217737, 0.6090440218832924, -0.3383333943242765, -0.9746486480944947, -0.7148764296291645, 0.2021498814156536, 0.933320523748862, 0.8064005807754863, -0.06192033725605731, -0.8733119827746476, -0.8817846188147811, -0.0795485428747221, 0.7958240965274552, 0.9395197317131483, 0.21942525837900473, -0.702407785577371, -0.9784503507933796, -0.35491017584493534, 0.5949327780232087, 0.9977972794498907, 0.4832915637282565, -0.47555018687189876, -0.9971732887740798, -0.6019998676776046, 0.3466494554970303, 0.9765908679435658, 0.7086591401823227, -0.21081053291348129, -0.9364619742512132, -0.8011345951780408, 0.07075223608034517, 0.8775897877771157, 0.8775753358042688, 0.07072216723899125, -0.8011526357338306, -0.936451400117644, -0.21078106590019152, 0.7086804082392084, 0.9765843832906294, 0.346621180094276, -0.6020239375552833, -0.997171023392149, -0.47552366901205834, 0.4833179536679627, 0.9977992786806003, 0.5949085484614269, -0.3549383576518463, -0.9784565746221131, -0.7023863292684921, 0.2194546679940636, 0.9395300555699313, 0.7958058429196471, -0.07957859166428352, -0.8817988360675502, -0.8732972972139945, -0.06189025071872073, 0.8064184068658304, 0.9333097001669604, 0.20212035931279124, -0.7148975077677644, -0.97464190312541, -0.33830502754097785, 0.6090679301910603, 0.9964666417661079, 0.46771851834275896, -0.491047853850463, -0.9983470937967718, -0.5877706198198406, 0.36319945137636067, 0.9802456219572225, 0.6960584883449115, -0.22808160941352787, -0.9425245273294025, -0.7904147414931815, 0.08839871248753149, 0.8859387978787574, 0.8689508382163493, 0.05305348526993529, -0.8116209973649744, -0.9300948780045254, -0.19344381715900788, 0.7210585970706318, 0.9726230624856244, 0.3299623697323973, -0.6160642040533644, -0.9956841897581032, -0.4598767232321427, 0.49873928180328125, 0.9988166912028082, 0.5805866409896447, -0.37143208943692263, -0.9819578697820255, -0.6896761131802671, 0.2366906812750767, 0.9454451549211168, 0.7849617132764033, -0.09721190751822434, -0.8900093488562771, -0.8645362993442719, -0.04421256322855966, 0.8167599996228085, 0.9268071855026884, 0.184752119221718, -0.727163193443649, -0.9705280195418053, -0.3215938602925038, 0.623012211003653, 0.9948237286710673, 0.45199889806298343, -0.5063916349244909, -0.9992080341070627, -0.5733571748155426, 0.37963562682930313, 0.9835931839466808, 0.6832397038158509, -0.24528120908194287, -0.9482917095220488, -0.7794471854988634, 0.10601748626711378, 0.8940101700837942, 0.8600540264645697, 0.035368177256176046, -0.8218350110128398, -0.9234468802429867, -0.17604594647121138, 0.7332108186087175, 0.9683569384347241, 0.3132001548706699, -0.6299114066849614, -0.9938853259197261, -0.4440856600409099, 0.5140043136735694, 0.99952109184891, 0.5660827877060441, -0.3878094208292295, -0.9851514363288851, -0.6767497645263834, 0.253852519790234, 0.9510639681125854, 0.7738715902084317, -0.11481475884166603, -0.8979409481081247, -0.8555043707508208, -0.026521020285755953, 0.8268456339220814, 0.9200142254959646, 0.1673259810118392, -0.739200998751274, -0.9661099892625297, -0.3047819110903029, 0.6367612505645516, 0.992869055025318, 0.4361376291460488, -0.5215767216183704, -0.9997558399011495, -0.5587640495890891, 0.39595283104274065, 0.9866325048439105, 0.6702068037805061, -0.2624039418616639, -0.9537617134939987, -0.7682353642374472, 0.12360303600011291, 0.9018013749637745, 0.8508876886558596, 0.017671785467370874, -0.8317914757822045, -0.9165094902005468, -0.15859290602857282, 0.7451332645574127, 0.9637873480674222, 0.29633978849732245, -0.6435612059762619, -0.9917749956098326, -0.42815542808445156, 0.5291082654818533, 0.9999122598719259, 0.551401533867395, -0.4040652194563607, -0.9880362734541701, -0.6636113342009432, 0.2709348053161655, 0.9563847343054627, 0.7625389491684937, -0.13238162920545193, -0.9055911481970673, -0.8462043418838514, -0.008821166113885877, 0.8366721491002946, 0.9129329489429682, 0.14984740573347818, -0.7510071512506542, -0.9613891968218607, -0.28787444850848604, 0.6503107401625526, 0.9906032333897737, 0.4201396822393068, -0.5365983551885637, -0.9999903395061709, -0.5439958173735323, 0.412145950487085, 0.9893626321783087, 0.6569638725243396, -0.279444441784382, -0.9589328250406132, -0.7567827912998033, 0.1411498506793914, 0.9093099708898409, 0.8414546973619527, -3.014435335948845e-05, -0.8414872714892108, -0.9092848819352602, -0.14109016531210986, 0.7568221986283603, 0.9589157234143065, 0.2793865543595699, -0.6570093243162466, -0.9893538601694428, -0.41209101962194344, 0.5440464039108651, 0.9999900726865629, 0.5365474803247321, -0.42019439103217676, -0.9906114770998198, -0.6502649395607762, 0.28793218456003195, 0.9614057860636483, 0.7509673416102893, -0.14990701345623575, -0.9129575516827102, -0.8366391272115635, 0.008881452458878848, 0.8462364656975445, 0.9055655749932976, 0.13232187086982847, -0.7625779510977886, -0.9563671216345017, -0.27087677105340535, 0.6636564336219596, 0.9880269738337468, 0.4040100708226276, -0.5514518281149146, -0.9999114594340064, -0.5290571062774264, 0.42820991051876856, 0.9917827103751873, 0.6435150601529656, -0.2963973686521434, -0.9638034236249698, -0.7450930557242139, 0.15865243143670757, 0.916533604797894, 0.8317580087191734, -0.017732064727370864], "y": [1.0, 0.5403023058681398, -0.4161468365471424, -0.9899924966004454, -0.6536436208636119, 0.2836621854632263, 0.9601702866503661, 0.7539022543433046, -0.14550003380861354, -0.9111302618846769, -0.8390715290764524, 0.004425697988050786, 0.8438539587324921, 0.9074467814501962, 0.1367372182078336, -0.7596879128588212, -0.9576594803233847, -0.27516333805159693, 0.6603167082440802, 0.9887046181866692, 0.40808206181339196, -0.5477292602242685, -0.9999608263946371, -0.5328330203333975, 0.4241790073369969, 0.9912028118634736, 0.6469193223286404, -0.2921388087338362, -0.9626058663135666, -0.7480575296890004, 0.15425144988758405, 0.9147423578045313, 0.8342233605065102, -0.013276747223059479, -0.8485702747846052, -0.9036922050915067, -0.12796368962740468, 0.7654140519453434, 0.9550736440472949, 0.2666429323599373, -0.6669380616522619, -0.9873392775238264, -0.3999853149883513, 0.5551133015206257, 0.9998433086476912, 0.5253219888177297, -0.4321779448847783, -0.9923354691509287, -0.6401443394691997, 0.3005925437436371, 0.9649660284921133, 0.7421541968137826, -0.16299078079570548, -0.9182827862121189, -0.8293098328631502, 0.022126756261955732, 0.853220107722584, 0.8998668269691938, 0.11918013544881928, -0.7710802229758452, -0.9524129804151563, -0.25810163593826746, 0.6735071623235862, 0.9858965815825497, 0.39185723042955, -0.562453851238172, -0.99964745596635, -0.5177697997895051, 0.4401430224960407, 0.9933903797222716, 0.6333192030862999, -0.3090227281660707, -0.9672505882738824, -0.7361927182273159, 0.17171734183077755, 0.9217512697247493, 0.8243313311075577, -0.030975031731216456, -0.8578030932449878, -0.8959709467909631, -0.11038724383904756, 0.7766859820216312, 0.9496776978825432, 0.2495401179733381, -0.6800234955873388, -0.9843766433940419, -0.38369844494974187, 0.569750334265312, 0.9993732836951247, 0.5101770449416688, -0.4480736161291701, -0.9943674609282015, -0.6264444479103392, 0.31742870151970165, 0.9694593666699876, 0.7301735609948197, -0.18043044929108393, -0.9251475365964139, -0.8192882452914593, 0.0398208803931389, 0.862318872287684, 0.8920048697881602, 0.10158570369662134, -0.782230889887116, -0.9468680107512126, -0.24095904923620143, 0.6864865509069841, 0.9827795820412206, 0.37550959776701204, -0.577002178942952, -0.999020813314648, -0.5025443191453852, 0.4559691044442761, 0.9952666362171313, 0.6195206125592099, -0.3258098052199642, -0.9715921906288022, -0.7240971967004738, 0.1891294205289584, 0.9284713207390763, 0.8141809705265618, -0.0486636092001539, -0.8667670910519801, -0.8879689066918555, -0.09277620459766088, 0.7877145121442345, 0.9439841391523142, 0.23235910202965793, -0.6928958219201651, -0.9811055226493881, -0.36729133045469653, 0.5842088171092893, 0.9985900724399912, 0.4948722204034305, -0.4638288688518717, -0.9960878351411849, -0.6125482394960996, 0.33416538263076073, 0.9736488930495181, 0.7179641014104721, -0.19781357400426822, -0.9317223617435201, -0.8090099069535975, 0.05750252534912421, 0.8711474010323434, 0.8838633737085002, 0.08395943674184846, -0.7931364191664784, -0.9410263090291437, -0.22374095013558368, 0.6992508064783751, 0.9793545963764285, 0.35904428689111606, -0.5913696841443248, -0.9980810948185003, -0.4871613498033415, 0.47165229356133864, 0.9968309933617175, 0.6055278749869899, -0.34249477911590703, -0.9756293127952373, -0.7117747556357235, 0.20648222933781113, 0.9349004048997503, 0.803775459710974, -0.06633693633562374, -0.875459459043705, -0.8796885924951523, -0.07513609089835323, 0.7984961861625555, 0.9379947521194415, 0.21510526876214114, -0.7055510066862999, -0.9775269404025313, -0.3507691132091306, 0.5984842190140996, 0.9974939203271522, 0.479412311470322, -0.47943876562917276, -0.9974960526543551, -0.5984600690578581, 0.3507973420904214, 0.9775332947055968, 0.7055296442942061, -0.21513470736462095, -0.9380052012169503, -0.7984780389030324, 0.07516615000819327, 0.879702927248347, 0.8754448901342752, 0.06630685835171127, -0.8037933932096717, -0.9348897059372352, -0.20645273449087873, 0.711795928940826, 0.9756226979194443, 0.3424664577455166, -0.6055518643146514, -0.9968285949694307, -0.47162571251991114, 0.48718767500700594, 0.9980829609135574, 0.591345375451585, -0.35907242107165305, -0.9793606896089245, -0.6992292566729736, 0.22377033018717848, 0.9410365074429887, 0.7931180595679168, -0.08398947462256867, -0.8838774731823718, -0.8711325991081119, -0.05747243084766546, 0.8090276252864301, 0.9317114137542325, 0.19778402522372224, -0.7179850839697137, -0.9736420181192547, -0.33413697099017103, 0.6125720663156843, 0.9960851708717215, 0.46380216301041793, -0.4948984145894023, -0.9985916721566993, -0.5841843515845697, 0.36731936773024515, 0.9811113543339269, 0.6928740863898233, -0.23238842122852268, -0.9439940860834779, -0.787695941645058, 0.09280621889587706, 0.8879827697817493, 0.8667520572726362, 0.048633500538969116, -0.8141984723053473, -0.9284601245807608, -0.18909982012986334, 0.7241179868699296, 0.9715850561826999, 0.3257813055351481, -0.619544275003953, -0.9952637062792294, -0.4559422758951242, 0.5025703802614232, 0.9990221465276736, 0.5769775585030581, -0.3755375359409301, -0.982785151720906, -0.68646463135462, 0.24098830528525864, 0.9468777054203809, 0.7822121099422712, -0.10161569206079699, -0.892018495407942, -0.8623036078310824, -0.03979075993115771, 0.8193055291449822, 0.9251360931462582, 0.18040079959254857, -0.7301941571456378, -0.9694519732670104, -0.3174001160235298, 0.6264679441263539, 0.9943642655514137, 0.44804666697426215, -0.510202970945957, -0.9993743503000143, -0.5697255608391865, 0.38372628183315116, 0.9843819506325049, 0.6800013937302881, -0.24956930858045798, -0.9496871395301657, -0.7766669941024745, 0.11041720391967796, 0.8959843338731037, 0.8577875993070563, 0.030944901828293042, -0.8243483956816764, -0.9217395798793158, -0.171687645155773, 0.7362131187458456, 0.9672429364932829, 0.30899405909813715, -0.6333425312327234, -0.9933869191569467, -0.44011595484676774, 0.5177955886508133, 0.9996482558795381, 0.5624289267667438, -0.3918849638415085, -0.9859016259639831, -0.6734848798934681, 0.2581307588164473, 0.9524221683015063, 0.7710610285700272, -0.11921006489861569, -0.8998799744648525, -0.8532043855172293, -0.022096619278683942, 0.8293266768209027, 0.9182708508872743, 0.1629610394708834, -0.7421744001016999, -0.9649581189333869, -0.3005637933500832, 0.6401674977183369, 0.9923317436681922, 0.43215076086181514, -0.5253476385155728, -0.9998438418065069, -0.5550882279566577, 0.4000129427560235, 0.987344058653017, 0.6669156003948422, -0.2666719852274808, -0.955082577452527, -0.7653946525566921, 0.12799358610147818, 0.903705111970614, 0.8485543255436181, 0.01324660552058789, -0.8342399825282195, -0.9147301779353751, -0.1542216662430943, 0.7480775341634341, 0.9625976995964054, 0.29210997926717525, -0.6469423088661069, -0.9911988217552068, -0.42415170907013605, 0.5328585288581932, 0.9999610927573088, 0.5477040395322043, -0.40810958177221934, -0.9887091356890289, -0.6602940699191361, 0.2751923186322931, 0.9576681585475916, 0.7596683100072248, -0.13676707936387883, -0.907459446701534, -0.8438377837054513, -0.004395553927897718, 0.8390879278598296, 0.911117838425468, 0.14547021017792156, -0.7539220584369601, -0.9601618634146094, -0.28363327918216646, 0.6536664338884767, 0.9899882421792622, 0.4161194261751267, -0.540327671221366, -0.999999999545659, -0.5402769400239504, 0.4161742465410129, 0.9899967501220404, 0.6536208072447929, -0.2836910914865273, -0.9601787090136331, -0.7538824495645917, 0.14552985730709223, 0.9111426845159583, 0.8390551295306261, -0.004455842044182302, -0.8438701329927379, -0.9074341153742778, -0.1367073569275377, 0.759707515020103, 0.9576508012289697, 0.27513435722086477, -0.6603393459690063, -0.9887000997858916, -0.40805454148374776, 0.5477544804186207, 0.9999605591233189, 0.5328075113244262, -0.42420630521841407, -0.9912068010710522, -0.6468963352033299, 0.29216763793503586, 0.9626140321560251, 0.7480375245348201, -0.15428123339190827, -0.9147545368424774, -0.8342067377267572, 0.013306888913466723, 0.8485862232545117, 0.9036792973912307, 0.12793379303705285, -0.7654334506384766, -0.9550647097742044, -0.26661387925010005, 0.6669605223036469, 0.9873344954974584, 0.3999576868572196, -0.5551383745801722, -0.9998427745803359], "z": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]}],
                            {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('3e175323-c71e-4868-9180-73a72a4f7511');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Representing the sphere in 3d with parametric equations
    sphere = np.asarray([[np.cos(s)*np.cos(t),np.cos(s)*np.sin(t),np.sin(s)] for t in range(20) for s in range(20)])
    plot_point_cloud(sphere)



.. raw:: html

    <div>
    
    
                <div id="3601f1f7-d627-4bcd-acda-bfbdd0511113" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("3601f1f7-d627-4bcd-acda-bfbdd0511113")) {
                        Plotly.newPlot(
                            '3601f1f7-d627-4bcd-acda-bfbdd0511113',
                            [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [1.0, 0.5403023058681398, -0.4161468365471424, -0.9899924966004454, -0.6536436208636119, 0.2836621854632263, 0.9601702866503661, 0.7539022543433046, -0.14550003380861354, -0.9111302618846769, -0.8390715290764524, 0.004425697988050786, 0.8438539587324921, 0.9074467814501962, 0.1367372182078336, -0.7596879128588212, -0.9576594803233847, -0.27516333805159693, 0.6603167082440802, 0.9887046181866692, 0.5403023058681398, 0.2919265817264289, -0.2248450953661529, -0.5348952287053772, -0.35316515556860967, 0.1532633328933771, 0.5187822199032656, 0.40733512642087627, -0.07861400377068618, -0.492285781442533, -0.4533522819483131, 0.0023912148280198268, 0.45593623971912356, 0.49029558847016286, 0.07387943429568748, -0.41046113105777554, -0.5174256254552092, -0.14867138603965227, 0.3567706400675362, 0.5341993850287361, -0.4161468365471424, -0.2248450953661529, 0.17317818956819406, 0.411982245665683, 0.27201172505161186, -0.11804512112857043, -0.39957182733611274, -0.3137340382107254, 0.06054937878695679, 0.3791639761656777, 0.3491769624619393, -0.0018417402172403875, -0.3511671554343095, -0.37763110743538525, -0.056902760795446275, 0.3161417216992996, 0.3985269632259569, 0.11450835266392399, -0.2747887092549964, -0.4114462991379327, -0.9899924966004454, -0.5348952287053772, 0.411982245665683, 0.9800851433251829, 0.6471022801057221, -0.280823435177878, -0.9505613792425612, -0.7463575749700321, 0.14404394172563853, 0.9020121226914289, 0.8306745178967504, -0.0043814078003899665, -0.8354090873717491, -0.8983655046999185, -0.13536882003177308, 0.752085333488286, 0.9480756998184328, 0.2724096400106128, -0.6537085865415448, -0.9788101533590108, -0.6536436208636119, -0.35316515556860967, 0.27201172505161186, 0.6471022801057221, 0.4272499830956933, -0.18541397800826867, -0.6276091828117975, -0.49278339930619736, 0.09510516893444011, 0.5955544834567112, 0.5484537524290998, -0.002892829257758318, -0.5515797570659992, -0.593146799968137, -0.08937741041618616, 0.49656515808736, 0.6259680102729421, 0.1798587606129639, -0.43161180409340183, -0.6462604665961094, 0.2836621854632263, 0.1532633328933771, -0.11804512112857043, -0.280823435177878, -0.18541397800826867, 0.0804642354617738, 0.2723640019280953, 0.21385356109267487, -0.04127285757512463, -0.2584532013278892, -0.23801286369779753, 0.0012554031634906897, 0.2393694581458539, 0.2574083372177333, 0.03878717815099614, -0.21549473363153024, -0.27165178111810884, -0.07805343383107252, 0.18730688055839936, 0.28045811277241534, 0.9601702866503661, 0.5187822199032656, -0.39957182733611274, -0.9505613792425612, -0.6276091828117975, 0.2723640019280953, 0.9219269793662461, 0.7238745436591679, -0.13970480916965441, -0.8748402047296334, -0.8056515505934984, 0.004249423705814672, 0.8102434974472231, 0.871303436264987, 0.13129101400238924, -0.7294297610544727, -0.9195161777355448, -0.2642036611726734, 0.6340164830347446, 0.9493247966568349, 0.7539022543433046, 0.40733512642087627, -0.3137340382107254, -0.7463575749700321, -0.49278339930619736, 0.21385356109267487, 0.7238745436591679, 0.5683686091039167, -0.10969280349534079, -0.6869031584352634, -0.6325779173260212, 0.0033365436902341155, 0.6361834018249477, 0.6841261742318789, 0.10308649705951811, -0.5727304301016253, -0.7219816411090373, -0.20744626086972773, 0.4978142549257622, 0.7453866405305661, -0.14550003380861354, -0.07861400377068618, 0.06054937878695679, 0.14404394172563853, 0.09510516893444011, -0.04127285757512463, -0.13970480916965441, -0.10969280349534079, 0.021170259838307684, 0.1325694839082714, 0.12208493584846888, -0.0006439392068881023, -0.12278077952510998, -0.1320335373805211, -0.019895269872135555, 0.11053461700495354, 0.13933948676419175, 0.04003627498939831, -0.09607610337390607, -0.1438565553728927, -0.9111302618846769, -0.492285781442533, 0.3791639761656777, 0.9020121226914289, 0.5955544834567112, -0.2584532013278892, -0.8748402047296334, -0.6869031584352634, 0.1325694839082714, 0.83015835412204, 0.7645034620274044, -0.0040323873668752005, -0.768860878412357, -0.8268022236291245, -0.12458541743508565, 0.6921746469936814, 0.8725525331033891, 0.2507096442600134, -0.6016345353092566, -0.9008386976950095, -0.8390715290764524, -0.4533522819483131, 0.3491769624619393, 0.8306745178967504, 0.5484537524290998, -0.23801286369779753, -0.8056515505934984, -0.6325779173260212, 0.12208493584846888, 0.7645034620274044, 0.704041030906696, -0.0037134771780643525, -0.7080538314708897, -0.7614127584669215, -0.11473230676330748, 0.6374324986633498, 0.8035448044895032, 0.23088172280473424, -0.5540529500610901, -0.8295938957868386, 0.004425697988050786, 0.0023912148280198268, -0.0018417402172403875, -0.0043814078003899665, -0.002892829257758318, 0.0012554031634906897, 0.004249423705814672, 0.0033365436902341155, -0.0006439392068881023, -0.0040323873668752005, -0.0037134771780643525, 1.958680268143678e-05, 0.003734642767371082, 0.004016085394927295, 0.0006051576315140706, -0.003362149267485786, -0.004238311635304965, -0.001217789831600291, 0.002922362327152144, 0.004375708039485263, 0.8438539587324921, 0.45593623971912356, -0.3511671554343095, -0.8354090873717491, -0.5515797570659992, 0.2393694581458539, 0.8102434974472231, 0.6361834018249477, -0.12278077952510998, -0.768860878412357, -0.7080538314708897, 0.003734642767371082, 0.7120895036684985, 0.7657525588658066, 0.11538624289074899, -0.6410656526671408, -0.8081247435885893, -0.23219767211288705, 0.557210868268975, 0.834322306073918, 0.9074467814501962, 0.49029558847016286, -0.37763110743538525, -0.8983655046999185, -0.593146799968137, 0.2574083372177333, 0.871303436264987, 0.6841261742318789, -0.1320335373805211, -0.8268022236291245, -0.7614127584669215, 0.004016085394927295, 0.7657525588658066, 0.8234596611643201, 0.12408174856715178, -0.6893763514303544, -0.8690250131447229, -0.24969608548801392, 0.5992022716338787, 0.8971968235784381, 0.1367372182078336, 0.07387943429568748, -0.056902760795446275, -0.13536882003177308, -0.08937741041618616, 0.03878717815099614, 0.13129101400238924, 0.10308649705951811, -0.019895269872135555, -0.12458541743508565, -0.11473230676330748, 0.0006051576315140706, 0.11538624289074899, 0.12408174856715178, 0.018697066843216703, -0.10387761191043031, -0.13094769332977918, -0.037625069397957095, 0.0902898698214492, 0.1351927191200834, -0.7596879128588212, -0.41046113105777554, 0.3161417216992996, 0.752085333488286, 0.49656515808736, -0.21549473363153024, -0.7294297610544727, -0.5727304301016253, 0.11053461700495354, 0.6921746469936814, 0.6374324986633498, -0.003362149267485786, -0.6410656526671408, -0.6893763514303544, -0.10387761191043031, 0.5771257249437919, 0.7275223318363354, 0.20903826197968392, -0.5016346219117525, -0.7511069478241085, -0.9576594803233847, -0.5174256254552092, 0.3985269632259569, 0.9480756998184328, 0.6259680102729421, -0.27165178111810884, -0.9195161777355448, -0.7219816411090373, 0.13933948676419175, 0.8725525331033891, 0.8035448044895032, -0.004238311635304965, -0.8081247435885893, -0.8690250131447229, -0.13094769332977918, 0.7275223318363354, 0.9171116802532552, 0.26351277932254014, -0.6323585556658738, -0.9468423508459761, -0.27516333805159693, -0.14867138603965227, 0.11450835266392399, 0.2724096400106128, 0.1798587606129639, -0.07805343383107252, -0.2642036611726734, -0.20744626086972773, 0.04003627498939831, 0.2507096442600134, 0.23088172280473424, -0.001217789831600291, -0.23219767211288705, -0.24969608548801392, -0.037625069397957095, 0.20903826197968392, 0.26351277932254014, 0.07571486260769741, -0.18169494961168353, -0.2720552630872735, 0.6603167082440802, 0.3567706400675362, -0.2747887092549964, -0.6537085865415448, -0.43161180409340183, 0.18730688055839936, 0.6340164830347446, 0.4978142549257622, -0.09607610337390607, -0.6016345353092566, -0.5540529500610901, 0.002922362327152144, 0.557210868268975, 0.5992022716338787, 0.0902898698214492, -0.5016346219117525, -0.6323585556658738, -0.18169494961168353, 0.4360181551862977, 0.6528581789067416, 0.9887046181866692, 0.5341993850287361, -0.4114462991379327, -0.9788101533590108, -0.6462604665961094, 0.28045811277241534, 0.9493247966568349, 0.7453866405305661, -0.1438565553728927, -0.9008386976950095, -0.8295938957868386, 0.004375708039485263, 0.834322306073918, 0.8971968235784381, 0.1351927191200834, -0.7511069478241085, -0.9468423508459761, -0.2720552630872735, 0.6528581789067416, 0.9775368220236473], "y": [0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.0, 0.0, -0.0, -0.0, -0.0, 0.0, 0.0, 0.8414709848078965, 0.4546487134128409, -0.35017548837401463, -0.833049961066805, -0.5500221413615028, 0.23869349855450123, 0.8079554366909638, 0.6343868724111538, -0.12243405673851628, -0.7666896787563757, -0.70605434589623, 0.0037240964444674213, 0.7100786216886722, 0.7635901368476526, 0.11506040166523798, -0.6392553361799678, -0.8058426660183369, -0.2315419650533054, 0.5556373507712546, 0.8319662487496519, 0.9092974268256817, 0.49129549643388193, -0.37840124765396416, -0.9001976297355174, -0.5943564625123038, 0.25793329532946097, 0.873080370965655, 0.6855213799524474, -0.13230280634522198, -0.8284884026347462, -0.7629655823119084, 0.004024275792442177, 0.7673142332921201, 0.8251390233539102, 0.12433480066768485, -0.6907822643530989, -0.8707973012332733, -0.2502053152470823, 0.6004242836963465, 0.8990265652078064, 0.1411200080598672, 0.07624746575887673, -0.05872664492762098, -0.13970774909946293, -0.09224219304455371, 0.040030409898850046, 0.13549923859094468, 0.10639069220927921, -0.020532965943782493, -0.12857870990075454, -0.11840978094607407, 0.0006245545357442651, 0.11908467745768014, 0.12805889711215224, 0.019296357335573302, -0.10720716438562054, -0.1351449135818443, -0.03883105248362133, 0.09318389918946958, 0.1395260036873307, -0.7568024953079282, -0.4089021333016356, 0.3149409643133779, 0.7492287917633427, 0.4946791233116909, -0.21467624978306998, -0.7266592688575257, -0.5705551073052852, 0.11011478865374665, 0.6895456557448896, 0.635011426946898, -0.0033493792808361126, -0.6386307816442235, -0.6867579885606566, -0.10348306794115315, 0.5749337081068278, 0.7247590843640312, 0.20824430085470755, -0.49972933249263707, -0.7482541221661436, -0.9589242746631385, -0.5181089967534271, 0.39905330338932815, 0.9493278367245317, 0.6267947350248265, -0.27201055544468494, -0.9207305956793, -0.7229351724130583, 0.13952351438338687, 0.8737049255013992, 0.8046060574101277, -0.004243909233069712, -0.809192045299173, -0.8701727466975289, -0.13112063778940214, 0.7284831808084986, 0.9183229225433798, 0.2638608043550156, -0.6331937205009058, -0.948092858850747, -0.27941549819892586, -0.1509688379721747, 0.11627787565772676, 0.2766192466508119, 0.18263815796815594, -0.07925961087140349, -0.26828645900021747, -0.21065197399062777, 0.04065496443459431, 0.2545839160486248, 0.23444958932143145, -0.0012366086082091943, -0.23578587428637512, -0.25355469452791835, -0.03820649794787706, 0.2122685766471497, 0.26758490079948294, 0.0768849011877664, -0.18450272200309445, -0.27625939346220696, 0.6569865987187891, 0.35497137421222796, -0.27340289471069096, -0.650411803098649, -0.4294350992454181, 0.18636225441262338, 0.6308190108172688, 0.4953036778474351, -0.09559157232538983, -0.5986003717453734, -0.551258749969712, 0.002907624268126074, 0.5544007421630454, 0.5961803744632768, 0.08983451990863348, -0.49910477795689273, -0.6291694447084636, -0.180778625558627, 0.43381922822646524, 0.6495656842400188, 0.9893582466233818, 0.5345525419802729, -0.4117183045441479, -0.979457240606921, -0.6466877066541816, 0.28064352244325413, 0.9499523912602761, 0.7458794124825067, -0.14395165833253265, -0.9014342383437266, -0.8301423367986789, 0.004378600801542554, 0.834873873017778, 0.8977899565995973, 0.135282094454261, -0.7516035014469798, -0.9474683043150028, -0.2722351176697648, 0.6532897806844863, 0.9781830674776032, 0.4121184852417566, 0.222668567867006, -0.1715018039159572, -0.40799420809968046, -0.2693786189182488, 0.11690243019347105, 0.3957039241084921, 0.3106970550803082, -0.05996325353583019, -0.375493623385838, -0.3457968875724721, 0.0018239119509729797, 0.3477678152380944, 0.3739755930087622, 0.05635193524398392, -0.31308143190384896, -0.3946691744082811, -0.11339989807188953, 0.27212872158137325, 0.4074634495986194, -0.5440211108893699, -0.2939358606544735, 0.22639266431147345, 0.538576817772715, 0.3555959287479723, -0.15431821725301084, -0.5223529059864969, -0.41013874190984484, 0.07915509002700281, 0.49567409723542444, 0.4564726253638139, -0.002407673135920238, -0.45907436805804286, -0.493670206117519, -0.07438793334934782, 0.4132862622826827, 0.5209869743392643, 0.14969466484285698, -0.3592262291577564, -0.5378761847273621, -0.9999902065507035, -0.5402970144449024, 0.4161427610341988, 0.9899828011591261, 0.653637219437953, -0.28365940743199564, -0.9601608832713477, -0.7538948710398021, 0.14549860886140978, 0.9111213387766547, 0.8390633116719762, -0.004425654645201939, -0.8438456944915336, -0.9074378944161527, -0.13673587907882015, 0.7596804728937654, 0.9576501015338208, 0.27516064325339745, -0.6603102414658784, -0.9886949353581218, -0.5365729180004349, -0.2899115848620313, 0.22329312240275023, 0.5312031626994367, 0.35072746497915824, -0.1522054465803839, -0.515201372485301, -0.40452353250009304, 0.0780713777098497, 0.4888878232979616, 0.45022305876763885, -0.0023747096836370645, -0.4527891810033119, -0.48691136745283475, -0.07336948817303948, 0.40762796017231784, 0.5138541418078986, 0.14764519522508548, -0.3543080629469679, -0.530512122020927, 0.4201670368266409, 0.22701721884721768, -0.1748511831967933, -0.41596221377721754, -0.27463950331890014, 0.11918549992585285, 0.4034319041908707, 0.31676487626435085, -0.06113431806354122, -0.38282690229916605, -0.3525501980576517, 0.0018595324095289254, 0.35455961735506175, 0.38127922523980134, 0.057452471798303255, -0.3191958192589063, -0.4023769461364174, -0.11561456439246677, 0.27744331467003674, 0.41542108972030817, 0.9906073556948704, 0.5352274384918789, -0.4122381173327502, -0.9806938492151301, -0.647504178830523, 0.2809978474523545, 0.9511517486755048, 0.7468211186274225, -0.1441334037446649, -0.9025723394191545, -0.8311904286572761, 0.004384128981047097, 0.8359279386526423, 0.8989234566061998, 0.13545289415393452, -0.752552434510432, -0.9486645254592718, -0.27257882669146616, 0.6541145882748095, 0.9794180673852028, 0.6502878401571169, 0.3513520195149026, -0.270615227526458, -0.6437800823860556, -0.4250564984438756, 0.18446206991912897, 0.6243870618889064, 0.490253468666489, -0.09461690272819079, -0.5924969301027749, -0.5456380123804558, 0.0028779775858372436, 0.5487479682321852, 0.5901016075667754, 0.08891855029746452, -0.4940158120464309, -0.6227543150654808, -0.1789353727919956, 0.4293959260237, 0.6429425907139761, -0.2879033166650653, -0.15555482586122002, 0.1198100544615971, 0.28502212324479664, 0.18818616636359636, -0.08166728400732373, -0.2764362100898869, -0.21705095946670702, 0.04188994230837897, 0.26231742431050803, 0.24157147614033844, -0.001274173129317728, -0.24294835350002963, -0.26125693807655015, -0.03936709863359005, 0.21871666974241574, 0.2757133406208453, 0.07922043764968532, -0.19010737035282896, -0.28465133877800913, -0.9613974918795568, -0.5194452817183707, 0.4000825249100346, 0.9517763032112488, 0.6284113376813485, -0.2727121136454194, -0.923105305362937, -0.7247997364479968, 0.13988336757199177, 0.8759583485514921, 0.806681263561646, -0.004254854945528427, -0.811279079438053, -0.872417059700395, -0.1314588186315989, 0.730362054033686, 0.9206914224575818, 0.2645413430600119, -0.6348268271520238, -0.9505381401343986, -0.750987246771676, -0.4057601411083023, 0.3125209670312812, 0.7434717393465864, 0.4908780232022332, -0.21302668367426486, -0.7210756400035294, -0.5661709783242381, 0.10926866979511646, 0.6842472068231297, 0.6301320174656253, -0.003323642747089206, -0.6337235611458938, -0.6814809599931017, -0.10268790703311885, 0.570515934083567, 0.7191900564728527, 0.20664415765587274, -0.49588942672155784, -0.742504559082448, 0.14987720966295234, 0.08097900197797579, -0.06237092667175042, -0.1483773129777346, -0.09796628200902689, 0.04251449684412324, 0.14390764336443396, 0.11299276623958389, -0.021807139073100227, -0.1365576612907504, -0.12575769948560547, 0.0006633112652599941, 0.12647447669786205, 0.13600559152138234, 0.020493792722064343, -0.11385990459395222, -0.14353133071814192, -0.04124071330871702, 0.09896642572544853, 0.14818428935469266], "z": [0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234]}],
                            {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('3601f1f7-d627-4bcd-acda-bfbdd0511113');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Representing the torus in 3d with parametric equations
    torus = np.asarray([[(2+np.cos(s))*np.cos(t),(2+np.cos(s))*np.sin(t),np.sin(s)] for t in range(20) for s in range(20)])
    plot_point_cloud(torus)



.. raw:: html

    <div>
    
    
                <div id="5cc94f9b-cfc5-42b4-81d5-6953d90409b8" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("5cc94f9b-cfc5-42b4-81d5-6953d90409b8")) {
                        Plotly.newPlot(
                            '5cc94f9b-cfc5-42b4-81d5-6953d90409b8',
                            [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [3.0, 2.5403023058681398, 1.5838531634528576, 1.0100075033995546, 1.3463563791363882, 2.283662185463226, 2.9601702866503663, 2.7539022543433047, 1.8544999661913866, 1.088869738115323, 1.1609284709235475, 2.004425697988051, 2.8438539587324922, 2.9074467814501963, 2.1367372182078337, 1.2403120871411788, 1.0423405196766153, 1.724836661948403, 2.66031670824408, 2.988704618186669, 1.6209069176044193, 1.3725311934627085, 0.8557595163701267, 0.5457093830309023, 0.7274394561676699, 1.2338679446296565, 1.5993868316395452, 1.4879397381571557, 1.0019906079655934, 0.5883188302937464, 0.6272523297879663, 1.0829958265642994, 1.536540851455403, 1.5709002002064425, 1.154484046031967, 0.670143480678504, 0.5631789862810703, 0.9319332256966273, 1.4373752518038156, 1.6148039967650156, -1.2484405096414273, -1.0571387684604376, -0.6591154835260907, -0.42031142742860184, -0.5602819480426731, -0.9503387942228552, -1.2318655004303978, -1.1460277113050101, -0.771744294307328, -0.45312969692860705, -0.48311671063234546, -0.8341354133115252, -1.1834608285285944, -1.20992478052967, -0.8891964338897311, -0.5161519513949852, -0.43376670986832794, -0.7177853204303608, -1.1070823823492812, -1.2437399722322175, -2.9699774898013365, -2.514880221906268, -1.5680027475352079, -0.9998998498757079, -1.3328827130951688, -2.260808428378769, -2.930546372443452, -2.726342568170923, -1.8359410514752523, -1.0779728705094618, -1.1493104753041403, -1.984366401001281, -2.81539408057264, -2.878350497900809, -2.115353813232664, -1.2278996597126048, -1.031909293382458, -1.707575353190278, -2.633693579742436, -2.958795146559902, -1.960930862590836, -1.6604523972958336, -1.035275516675612, -0.6601849616215018, -0.8800372586315307, -1.4927012197354925, -1.9348964245390214, -1.8000706410334213, -1.212182072792784, -0.7117327582705125, -0.758833489298124, -1.3101800709849822, -1.8588669987932231, -1.900434041695361, -1.39666465214341, -0.8107220836398639, -0.6813192314542817, -1.1274284811142599, -1.7388990458206257, -1.9535477083233332, 0.8509865563896789, 0.7205877038198297, 0.4492792497978822, 0.2865009357485746, 0.38191039291818396, 0.6477886063882263, 0.839688372854548, 0.7811779320191276, 0.526051513351328, 0.30887116959856337, 0.32931150722865504, 0.5685797740899433, 0.8066938290723066, 0.824732708144186, 0.6061115490774488, 0.35182963729492234, 0.29567258980834377, 0.48927093709538005, 0.754631251484852, 0.8477824836988679, 2.880510859951098, 2.439122793203998, 1.5207687459646195, 0.9697791940581709, 1.2927313904889348, 2.1927045752288272, 2.8422675526669785, 2.6442151169599004, 1.780635764131078, 1.0455003685710986, 1.1146890227072337, 1.9245899970065468, 2.7305840707479554, 2.791644009565719, 2.0516315873031217, 1.1909108122462595, 1.0008243955651872, 1.6561369121280587, 2.5543570563354767, 2.869665369957567, 2.2617067630299137, 1.9151396351074854, 1.1940704704758838, 0.7614469337165771, 1.015021109380412, 1.721658069779284, 2.2316790523457772, 2.076173117790526, 1.3981117051912686, 0.8209013502513457, 0.875226591360588, 1.5111410523768434, 2.143987910511557, 2.191930682918488, 1.6108910057461274, 0.9350740785849839, 0.7858228675775719, 1.3003582478168814, 2.0056187636123712, 2.2531911492171752, -0.4365001014258406, -0.36961407138791325, -0.23045068883027028, -0.14695612589158855, -0.19589489868278698, -0.3322729251923517, -0.4307048767868815, -0.40069287111256785, -0.2698298077789194, -0.15843058370895566, -0.16891513176875816, -0.2916440068241152, -0.4137808471423371, -0.42303360499774817, -0.31089533748936266, -0.18046545061227354, -0.15166058085303533, -0.25096379262782875, -0.3870761709911331, -0.4348566229901198, -2.7333907856540307, -2.314546305211887, -1.4430965476036761, -0.9202484010779249, -1.2267060403126429, -2.080713725097243, -2.6971007284989876, -2.5091636822046173, -1.6896910398610825, -0.9921021696473138, -1.0577570617419494, -1.8262929111362292, -2.591121402181711, -2.6490627473984785, -1.9468459412044397, -1.1300858767756725, -0.9497079906659648, -1.5715508795093405, -2.4238950590786104, -2.7230992214643632, -2.517214587229357, -2.131495340101218, -1.3289660956909657, -0.8474685402561545, -1.129689305723805, -1.9161559218507023, -2.4837946087464036, -2.310720975478926, -1.556058122304436, -0.9136395961255004, -0.9741020272462089, -1.6818565353309693, -2.3861968896237946, -2.4395558166198263, -1.7928753649162124, -1.040710559489555, -0.8745982536634017, -1.4472613353481707, -2.232196008213995, -2.5077369539397436, 0.013277093964152359, 0.0112426108041214, 0.007009655758861185, 0.004469988175711606, 0.005958566718343255, 0.010106799139592261, 0.013100819681916245, 0.012187939666335688, 0.00820745676921347, 0.004819008609226371, 0.00513791879803722, 0.00887098277878301, 0.012586038743472654, 0.012867481371028867, 0.009456553607615643, 0.005489246708615786, 0.004613084340796608, 0.007633606144501282, 0.011773758303253716, 0.013227104015586836, 2.5315618761974763, 2.1436441571841076, 1.3365407620306748, 0.8522988300932351, 1.1361281603989852, 1.9270773756108381, 2.4979514149122077, 2.323891319289932, 1.5649271379398744, 0.9188470390526272, 0.9796540859940944, 1.6914425602323553, 2.3997974211334827, 2.453460476330791, 1.8030941603557333, 1.0466422647978435, 0.879583173876395, 1.4555102453520972, 2.2449187857339594, 2.522030223538902, 2.7223403443505885, 2.305189151370555, 1.437262455465007, 0.9165280582004739, 1.2217467629322556, 2.0723019001181258, 2.6861969991653796, 2.4990197371322713, 1.6828600255198713, 0.9880913392712678, 1.053480804433471, 1.8189096482953198, 2.580646121766199, 2.6383532240647125, 1.9389753114675443, 1.125517211470038, 0.9458685497556695, 1.5651974774123785, 2.414095834534271, 2.7120903864788306, 0.41021165462350084, 0.3473538707113547, 0.21657167562022095, 0.13810561638389413, 0.18409702599948105, 0.31226161456666335, 0.4047654504180565, 0.3765609334751853, 0.2535791665435317, 0.14888901898058154, 0.15874212965235973, 0.2740795940471813, 0.3888606793064162, 0.39755618498281897, 0.2921715032588839, 0.1695968245052369, 0.14252674308588803, 0.23584936701771012, 0.3637643062371164, 0.4086671555357506, -2.279063738576464, -1.9298369567754179, -1.2032341040183427, -0.7672904922293564, -1.0228106676302824, -1.7348705593491727, -2.2488055867721153, -2.092106255819268, -1.408841208712689, -0.8272011787239609, -0.8819433270542925, -1.5227379749851282, -2.1604414783847834, -2.2087521771479968, -1.6232534376280727, -0.9422501007738505, -0.791853493881307, -1.3103375637379584, -2.021010447629395, -2.270482773541751, -2.872978440970154, -2.4327445861019785, -1.5167919974208124, -0.9672432608283366, -1.2893509503738274, -2.186970741764878, -2.8348351383823145, -2.6373006017558067, -1.7759794738825776, -1.0427664275433801, -1.111774156157266, -1.9195572722820744, -2.7234437042353585, -2.784343973791492, -2.0462666539765486, -1.1877966288104338, -0.9982072803935141, -1.651806181324229, -2.547677516312643, -2.8621613114927453, -0.8254900141547907, -0.6989980621428461, -0.43581832343926985, -0.27791703609258106, -0.37046791549023, -0.6283801099342663, -0.8145303372758673, -0.7577729369729216, -0.5102904011137955, -0.29961703184318045, -0.3194449532984596, -0.5515444659347941, -0.782524348216081, -0.8000227615912078, -0.5879517455011509, -0.3412884141235099, -0.2868138967806537, -0.4746118134954964, -0.7320216257148774, -0.8223819391904674, 1.9809501247322405, 1.6774040565556965, 1.045844707233164, 0.6669248299466155, 0.8890216123947586, 1.5079402970465596, 1.9546498995229051, 1.8184476714139226, 1.2245573131142544, 0.7189988811789036, 0.7665804664270702, 1.3235557788153125, 1.8778442847571355, 1.9198356881220393, 1.4109232863096095, 0.8189987945764079, 0.6882748608222865, 1.1389384668764768, 1.756651571674458, 1.973491595394902, 2.9661138545600076, 2.5116086214020745, 1.5659629372354058, 0.9985990830143276, 1.331148769777229, 2.2578673491457537, 2.9267340330301734, 2.7227958769039047, 1.8335526810004459, 1.0765705386783289, 1.1478153405864997, 1.9817849444128237, 2.8117315424472564, 2.8746060599517764, 2.112601955493422, 1.22630228854923, 1.0305668855273624, 1.7053539732860648, 2.63026741528008, 2.954946058396986], "y": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 2.5244129544236893, 2.137590683028634, 1.3327664812417783, 0.849892008548988, 1.1329198282542903, 1.921635468170294, 2.490897406306757, 2.317328842026947, 1.5605079128772767, 0.9162522908594172, 0.976887623719563, 1.6866660660602604, 2.3930205913044653, 2.4465321064634455, 1.7980023712810311, 1.0436866334358252, 0.8770993035974561, 1.4514000045624875, 2.2385793203870477, 2.514908218365445, 2.727892280477045, 2.3098903500852455, 1.4401936059973994, 0.918397223915846, 1.2242383911390597, 2.0765281489808243, 2.691675224617019, 2.504116233603811, 1.6862920473061416, 0.9901064510166171, 1.0556292713394548, 1.8226191294438057, 2.5859090869434835, 2.643733877005274, 1.9429296543190484, 1.1278125892982647, 0.9477975524180902, 1.5683895384042812, 2.41901913734771, 2.71762141885917, 0.4233600241796016, 0.3584874818786111, 0.22351337119211345, 0.1425322670202715, 0.18999782307518073, 0.32227042601858447, 0.41773925471067913, 0.38863070832901364, 0.26170705017595197, 0.1536613062189799, 0.16383023517366033, 0.2828645706554787, 0.40132469357741457, 0.41029891323188666, 0.30153637345530776, 0.17503285173411387, 0.14709510253789013, 0.24340896363611308, 0.375423915309204, 0.42176601980706513, -2.2704074859237844, -1.922507123917492, -1.1986640263024786, -0.7643761988525137, -1.0189258673041657, -1.7282812403989263, -2.240264259473382, -2.0841600979211417, -1.4034902019621098, -0.8240593348709667, -0.8785935636689582, -1.5169543698966925, -2.15223577226008, -2.2003629791765134, -1.6170880585570095, -0.9386712825090286, -0.7888459062518252, -1.3053606897611487, -2.0133343231084937, -2.261859112782, -2.8767728239894153, -2.435957546079704, -1.5187952459369487, -0.9685207126017452, -1.2910538143014505, -2.189859104770962, -2.838579145005577, -2.6407837217393353, -1.77832503494289, -1.0441436238248776, -1.1132424919161492, -1.9220924585593466, -2.72704059462545, -2.788021296023806, -2.048969187115679, -1.1893653685177783, -0.9995256267828971, -1.6539877449712612, -2.5510422698271826, -2.865941408177024, -0.8382464945967776, -0.7097998343700264, -0.442553120740125, -0.28221174974703983, -0.3761928384296958, -0.6380906072692552, -0.8271174553980692, -0.7694829703884796, -0.5181760319632575, -0.3042470803492269, -0.3243814070764202, -0.5600676050060609, -0.7946168706842268, -0.8123856909257701, -0.5970374943457288, -0.346562419750702, -0.2912460955983688, -0.4819460952100853, -0.7433337184009462, -0.8350903898600587, 1.9709597961563672, 1.6689445716498061, 1.040570302726887, 0.6635613943389291, 0.8845380981921601, 1.5003354518502015, 1.944792208254847, 1.8092768752850132, 1.2183816251121884, 0.7153728256922046, 0.7627144474678661, 1.3168808217057042, 1.8683739396006236, 1.9101535719008549, 1.4038077173462116, 0.8148684194806853, 0.6848037527291145, 1.1331945718789511, 1.7477924256640434, 1.963538881677597, 2.9680747398701453, 2.5132690352270366, 1.5669981887026159, 0.9992592526398426, 1.332028786592582, 2.2593600156900178, 2.9286688845070397, 2.72459590572927, 1.834764834914231, 1.0772822549030368, 1.1485741564480845, 1.983095094048306, 2.813590366264542, 2.876506449846361, 2.113998587701025, 1.2271129917997838, 1.0312481889317608, 1.7064813755769987, 2.6320062739312498, 2.956899560724367, 1.2363554557252698, 1.0469055383505192, 0.652735166567556, 0.41624276238383273, 0.5548583515652644, 0.9411394006769842, 1.2199408945920054, 1.1349340255638214, 0.7642737169476831, 0.4487433470976751, 0.47844008291104106, 0.8260608824344862, 1.1720047857216076, 1.1982125634922753, 0.8805889057274972, 0.5111555385796642, 0.4295677960752321, 0.7108370724116236, 1.0963656920648865, 1.2317004200821327, -1.6320633326681095, -1.3819780824332133, -0.8616495574672663, -0.5494654040060247, -0.7324462930307676, -1.2423604390317506, -1.6103951277652369, -1.4981809636885848, -1.008887131751737, -0.5923681245433152, -0.6315695964149258, -1.09044989491466, -1.5471165898367827, -1.5817124278962589, -1.1624301551280876, -0.674755959496057, -0.5670552474394754, -0.9383475569358828, -1.4472684509364961, -1.6259184065061019, -2.9999706196521103, -2.5402774275463096, -1.5838376520672082, -1.0099976119422809, -1.346343193663454, -2.2836398205334025, -2.960141296372755, -2.753875284141209, -1.8544818042399973, -1.0888590743247522, -1.1609171014294306, -2.004406067746609, -2.8438261075929407, -2.9074183075175597, -2.136716292180227, -1.2402999402076416, -1.0423303115675862, -1.7248197698480094, -2.660290654567285, -2.9886753484595285, -1.609718754001305, -1.3630574208629012, -0.8498527135981196, -0.5419426733014332, -0.7224183710217117, -1.2253512825812538, -1.588347208486171, -1.477669368500963, -0.9950744582910203, -0.5842580127029082, -0.622922777233231, -1.075520545684507, -1.5259350170041819, -1.5600572034537046, -1.1465153241739094, -0.665517875828552, -0.5592916941929713, -0.9255006407757844, -1.4274538989478378, -1.603657958021797, 1.2605011104799226, 1.0673512925004995, 0.6654828904564886, 0.4243718598760643, 0.5656945703343818, 0.9595195735791346, 1.2437659778441525, 1.1570989499176327, 0.7791997555897406, 0.4575071713541157, 0.4877838755956301, 0.8421936060628108, 1.1948936910083436, 1.2216132988930832, 0.8977865454515851, 0.5211382543943756, 0.43795712751686444, 0.7247195092608151, 1.1177773883233186, 1.25575516337359, 2.971822067084611, 2.5164421498816196, 1.5689765940569906, 1.0005208621746104, 1.3337105325592178, 2.262212558842095, 2.932366460065246, 2.728035830017163, 1.8370813076450758, 1.078642371970586, 1.1500242827324645, 1.9855988403707878, 2.817142650042383, 2.880138167995941, 2.1166676055436753, 1.2286622768793087, 1.0325501859304689, 1.7086358846982745, 2.63532929966455, 2.9606327787749436, 1.950863520471351, 1.6519276998291363, 1.029960452787776, 0.6567955979281783, 0.8755191818703583, 1.4850377502333627, 1.9249627422031403, 1.7908291489807229, 1.2059587775860432, 0.7080787502114589, 0.754937667933778, 1.303453657900071, 1.849323648546419, 1.8906772878810094, 1.3894942306116984, 0.806559868267803, 0.677821365248753, 1.1216403075222383, 1.729971606337934, 1.94351827102821, -0.8637099499951959, -0.7313614591913506, -0.4559965788685335, -0.29078451008533396, -0.3876204669665343, -0.6574739173374543, -0.8522428434200175, -0.7928575927968377, -0.5339166910217517, -0.31348920901962257, -0.33423515718979213, -0.5770808064594484, -0.8187549868301602, -0.8370635714066808, -0.6151737319637207, -0.3570899635877149, -0.3000932927092853, -0.49658619568044526, -0.7659140036829596, -0.8604579721081397, -2.8841924756386703, -2.4422402654774844, -1.522712458849079, -0.9710186805478648, -1.2943836460777653, -2.195507097404533, -2.845900289122051, -2.6475947202071106, -1.782911616187122, -1.0468366352076213, -1.1161137201974676, -1.927049838704642, -2.7340740631971667, -2.7952120434595087, -2.0542538023907126, -1.1924329297254277, -1.0021035613015319, -1.6582536406991017, -2.5576218109111375, -2.873333123893512, -2.252961740315028, -1.9077346346516544, -1.189453526512071, -0.7585027541967657, -1.011096470341119, -1.7150011772176168, -2.2230501335468817, -2.0681454718675902, -1.3927058237482357, -0.8177272867202223, -0.8718424760777267, -1.5052981362904414, -2.135698054689246, -2.1834554535364536, -1.604662400576471, -0.9314585594597851, -0.7827844370704994, -1.2953303358874793, -1.99786392026491, -2.2444790526258, 0.449631628988857, 0.3807334213038805, 0.23738349265415426, 0.1513771063481701, 0.2017881373168778, 0.3422689161700279, 0.4436620626903387, 0.4127471855654886, 0.27794728025280446, 0.16319675803515427, 0.17399671984029919, 0.30041773059116467, 0.42622889602376673, 0.43576001084728705, 0.32024821204796905, 0.18589451473195248, 0.15622308860776277, 0.25851370601718765, 0.39872084505135325, 0.4479387086805974], "z": [0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234, 0.0, 0.8414709848078965, 0.9092974268256817, 0.1411200080598672, -0.7568024953079282, -0.9589242746631385, -0.27941549819892586, 0.6569865987187891, 0.9893582466233818, 0.4121184852417566, -0.5440211108893699, -0.9999902065507035, -0.5365729180004349, 0.4201670368266409, 0.9906073556948704, 0.6502878401571169, -0.2879033166650653, -0.9613974918795568, -0.750987246771676, 0.14987720966295234]}],
                            {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('5cc94f9b-cfc5-42b4-81d5-6953d90409b8');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Saving the results into an array
    topological_spaces = np.asarray([circle,sphere,torus])

Computing persistent homology
-----------------------------

In the next section we will use giotto-tda to compute the persistent
homology groups of the topological spaces we just constructed.

We will use the Vietoris–Rips technique to generate a filtration out of
a point cloud:

.. figure:: https://miro.medium.com/max/1200/1*w3BiQI1OX93KXcezctRQTQ.gif
   :alt: segment

   SegmentLocal

.. code:: ipython3

    # The homology ranks we choose to consider
    homology_dimensions = (0, 1, 2)
    VR = VietorisRipsPersistence(
        metric='euclidean', max_edge_length=10, homology_dimensions=homology_dimensions)
    
    # Array of persistence diagrams, one per point cloud in the input
    diagrams = VR.fit_transform(topological_spaces)
    print(f'diagrams.shape = {diagrams.shape}')


.. parsed-literal::

    diagrams.shape = (3, 865, 3)


Persistence diagrams
--------------------

The topological information of the point cloud is synthesised in the
persistence diagram. The horizontal axis corresponds to the moment in
which an homological generator is born, while the vertical axis
corresponds to the moments in which a homological generator dies.

The generators of the homology groups (at given rank) are colored
differently.

.. code:: ipython3

    # Plotting the persistence diagram of the circle
    plot_diagram(diagrams[0])



.. raw:: html

    <div>
    
    
                <div id="d9e2a6a1-0315-4d16-b2d2-f1f53511b7bf" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("d9e2a6a1-0315-4d16-b2d2-f1f53511b7bf")) {
                        Plotly.newPlot(
                            'd9e2a6a1-0315-4d16-b2d2-f1f53511b7bf',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-200.0, 200.0], "y": [-200.0, 200.0]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008821251802146435, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.008881540037691593, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915, 0.01770261861383915]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [0.01770261861383915], "y": [1.733519196510315]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315, 1.733519196510315], "y": [1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458, 1.737931489944458]}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('d9e2a6a1-0315-4d16-b2d2-f1f53511b7bf');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Plotting the persistence diagram of the sphere
    plot_diagram(diagrams[1])



.. raw:: html

    <div>
    
    
                <div id="179f83fe-1930-4582-99a9-2277889f7c1b" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("179f83fe-1930-4582-99a9-2277889f7c1b")) {
                        Plotly.newPlot(
                            '179f83fe-1930-4582-99a9-2277889f7c1b',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-200.0, 200.0], "y": [-200.0, 200.0]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.0006651923176832497, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0012491090456023812, 0.0019041121704503894, 0.0019041121704503894, 0.0019041121704503894, 0.0019041121704503894, 0.020551910623908043, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021830052137374878, 0.021868981420993805, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04050416126847267, 0.04135766625404358, 0.0419892780482769, 0.0419892780482769, 0.0419892780482769, 0.04263506084680557, 0.06254780292510986, 0.08120864629745483, 0.08178015053272247, 0.08178015053272247, 0.08178015053272247, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09336519986391068, 0.09824410080909729, 0.09924708306789398, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.10743161290884018, 0.11331319808959961, 0.11418279260396957, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11745329201221466, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.11937356740236282, 0.12611432373523712, 0.12683314085006714, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.12894494831562042, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.1359502524137497, 0.136391282081604, 0.13694491982460022, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.14024706184864044, 0.1439383625984192, 0.14431574940681458, 0.14860452711582184, 0.14879809319972992, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.15249493718147278, 0.1565735638141632, 0.1565735638141632, 0.1565735638141632, 0.1565735638141632, 0.1565735638141632, 0.1565735638141632, 0.1790430098772049, 0.1790430098772049, 0.1790430098772049, 0.19138360023498535, 0.19138360023498535, 0.19138360023498535, 0.22040361166000366, 0.22040361166000366, 0.22040361166000366, 0.2450246512889862, 0.2450246512889862, 0.2450246512889862, 0.26475048065185547, 0.26475048065185547, 0.26475048065185547, 0.27351900935173035, 0.27918440103530884, 0.27918440103530884, 0.27918440103530884, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.4259701073169708]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [0.4259701073169708, 0.4259701073169708, 0.4259701073169708, 0.4259701073169708, 0.4259701073169708, 0.2880364656448364, 0.2880364656448364, 0.2880364656448364, 0.2880364656448364, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.27918440103530884, 0.27351900935173035, 0.27351900935173035, 0.27351900935173035, 0.27351900935173035, 0.27351900935173035, 0.26475048065185547, 0.2450246512889862, 0.22040361166000366, 0.19138360023498535, 0.1790430098772049, 0.1790430098772049, 0.1503022462129593, 0.08178015053272247, 0.0419892780482769, 0.0019041121704503894], "y": [0.43981873989105225, 0.43981873989105225, 0.4349362850189209, 0.43512967228889465, 0.43981873989105225, 0.388680100440979, 0.388680100440979, 0.388680100440979, 0.388680100440979, 0.3183557987213135, 0.29809635877609253, 0.2846529185771942, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.4302399754524231, 0.3455999195575714, 0.29916489124298096, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.4302399754524231, 0.3455999195575714, 0.29916489124298096, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.4302399754524231, 0.3455999195575714, 0.29916489124298096, 0.3046613931655884, 0.2930488586425781, 0.30160054564476013, 0.2976342439651489, 0.2976342439651489, 0.30160054564476013, 0.2930488586425781, 0.3046613931655884, 0.4302399754524231, 0.3455999195575714, 0.29916489124298096, 0.3488639295101166, 0.37844565510749817, 0.3649183213710785, 0.3649183213710785, 0.37844565510749817, 0.3488639295101166, 0.3222554922103882, 0.30478915572166443, 0.2906591594219208, 0.3162855803966522, 0.30339646339416504, 0.3129911422729492, 0.30840617418289185, 0.3087007999420166, 0.31274929642677307, 0.3037223219871521, 0.31611356139183044, 0.3488639295101166, 0.37844565510749817, 0.3649183213710785, 0.37844565510749817, 0.2736629247665405, 0.2736629247665405, 0.2736629247665405, 0.2736629247665405, 0.2736629247665405, 0.3649183213710785, 0.3488639295101166, 0.3455999195575714, 0.4302399754524231, 0.29916489124298096, 0.19762368500232697, 0.2119583785533905, 0.2736629247665405, 0.24772526323795319, 0.00804855115711689]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [0.43981873989105225, 0.24772526323795319, 0.00804855115711689], "y": [1.6589692831039429, 0.25651901960372925, 0.00830260943621397]}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('179f83fe-1930-4582-99a9-2277889f7c1b');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # plotting the persistence diagram of the torus
    plot_diagram(diagrams[2])



.. raw:: html

    <div>
    
    
                <div id="e6b5f5ff-8eb7-4e74-a531-ae6013af691d" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("e6b5f5ff-8eb7-4e74-a531-ae6013af691d")) {
                        Plotly.newPlot(
                            'e6b5f5ff-8eb7-4e74-a531-ae6013af691d',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-200.0, 200.0], "y": [-200.0, 200.0]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.1503022462129593, 0.15180638432502747, 0.1566661149263382, 0.16365955770015717, 0.17449015378952026, 0.1864216923713684, 0.2023603767156601, 0.23805667459964752, 0.259246826171875, 0.278735488653183, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.28506454825401306, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.2941901981830597, 0.3818131387233734, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4345456063747406, 0.4345456063747406, 0.4345456063747406, 0.4345456063747406]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [1.290719985961914, 1.290719985961914, 1.290719985961914, 1.290719985961914, 1.290719985961914, 1.2858601808547974, 1.2858601808547974, 1.2858601808547974, 1.2858601808547974, 1.2858601808547974, 1.2735836505889893, 1.2735836505889893, 1.2735836505889893, 1.2735836505889893, 1.2735836505889893, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8467200398445129, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8435320258140564, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8354784846305847, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8205978274345398, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.8026493787765503, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7772614359855652, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7508478164672852, 0.7420936822891235, 0.7420936822891235, 0.7420936822891235, 0.7420936822891235, 0.7420936822891235, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.7169749736785889, 0.6814369559288025, 0.6814369559288025, 0.6814369559288025, 0.6814369559288025, 0.6814369559288025, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6445408463478088, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.6030727624893188, 0.5792563557624817, 0.5792563557624817, 0.5792563557624817, 0.5792563557624817, 0.5792563557624817, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5657291412353516, 0.5336318612098694, 0.5336318612098694, 0.5336318612098694, 0.5336318612098694, 0.5336318612098694, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.5234140753746033, 0.4994778335094452, 0.4994778335094452, 0.4994778335094452, 0.4994778335094452, 0.4994778335094452, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4868179261684418, 0.4684752821922302, 0.4684752821922302, 0.4684752821922302, 0.4684752821922302, 0.4684752821922302, 0.4509067237377167, 0.4492090046405792, 0.4484565556049347, 0.4484565556049347, 0.4484565556049347, 0.4484565556049347, 0.4484565556049347, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44702672958374023, 0.44492024183273315, 0.4369957745075226, 0.4345456063747406, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4302399754524231, 0.4274376332759857, 0.4139176905155182, 0.39985156059265137, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3799956440925598, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.3500657081604004, 0.34323954582214355, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.327660471200943, 0.32115638256073, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30732262134552, 0.30126968026161194, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685, 0.28224000334739685], "y": [1.2970259189605713, 1.2970259189605713, 1.2970259189605713, 1.2970259189605713, 1.2970259189605713, 1.2992850542068481, 1.2992850542068481, 1.2992850542068481, 1.2992850542068481, 1.2992850542068481, 1.2798200845718384, 1.2798200845718384, 1.2798200845718384, 1.2798200845718384, 1.2798200845718384, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8583858609199524, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8785555958747864, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8661730289459229, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8470410108566284, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.8260308504104614, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.7980829477310181, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.8179599642753601, 0.7841995358467102, 0.7841995358467102, 0.7841995358467102, 0.7841995358467102, 0.7841995358467102, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7858082056045532, 0.7407718300819397, 0.7407718300819397, 0.7407718300819397, 0.7407718300819397, 0.7407718300819397, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6665545701980591, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6287417411804199, 0.6074414849281311, 0.6074414849281311, 0.6074414849281311, 0.6074414849281311, 0.6074414849281311, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5958746075630188, 0.5741539597511292, 0.5741539597511292, 0.5741539597511292, 0.5741539597511292, 0.5741539597511292, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.5600352883338928, 0.551047682762146, 0.551047682762146, 0.551047682762146, 0.551047682762146, 0.551047682762146, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.6083544492721558, 0.5321967005729675, 0.5321967005729675, 0.5321967005729675, 0.5321967005729675, 0.5321967005729675, 0.4744914472103119, 0.5253207087516785, 0.6164262294769287, 0.6164262294769287, 0.6164262294769287, 0.6164262294769287, 0.6164262294769287, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5844614505767822, 0.5194565057754517, 0.5104308724403381, 1.8367944955825806, 0.5547325015068054, 0.4790463149547577, 0.45704415440559387, 0.48740920424461365, 0.5677598714828491, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 0.8871729373931885, 0.5186228156089783, 1.3128210306167603, 1.3128210306167603, 1.3128210306167603, 1.3128210306167603, 0.8871729373931885, 0.5186228156089783, 1.8185948133468628, 0.5005707144737244, 0.4875434637069702, 0.5294119119644165, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.45185062289237976, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.4327152967453003, 0.42786338925361633, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.4195878207683563, 0.41131144762039185, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.40898191928863525, 0.39719343185424805, 0.3821181356906891, 0.3232707679271698, 0.33907127380371094, 0.33191734552383423, 0.3271026015281677]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [1.8367944955825806, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.8185948133468628, 1.3128210306167603], "y": [1.894774079322815, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752, 1.875999927520752]}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 2.2], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('e6b5f5ff-8eb7-4e74-a531-ae6013af691d');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Conclusion of the first part
----------------------------

As you can see from the persistence diagrams, all the betti numbers were
found. Some other persistent generators are also appearing, depending on
how dense the sampling is and how much noise there is. For example, we
see a rather neat persistence diagram over the Torus bottle (we see two
persistent generators for :math:`H_1` and one persistent generator for
:math:`H_2`). Notice though that there are other persistent :math:`H_1`
generators, possibly due to the non-uniform sampling method we used for
the torus.

On the other hand, the persistence diagram for the circle is as perfect
as it could be: one unique generator of :math:`H_1` and no other
persistent generator, as expected.

Classification of noisy orientable surfaces
-------------------------------------------

In the next section we generate hundreds of noisy spheres and noisy
tori. The effect of noise is to displace the points sampling the
aforementioned surfaces by a random amount in a random direction.

The Vietoris–Rips algorithm is used to compute persistence diagrams.
Afterwards, from each diagram, the *persistence entropy* is computed.

A simple linear classifier is then applied to the 3D-space of entropies
to classify shapes.

.. code:: ipython3

    # Building dataset
    n_train = 10
    n_range = 15
    eps = 0.3
    
    train_Xs = [np.asarray([[np.cos(s)*np.cos(t) + eps*(np.random.rand(1)[0]-0.5),np.cos(s)*np.sin(t) + eps*(np.random.rand(1)[0]-0.5),np.sin(s) + eps*(np.random.rand(1)[0] - 0.5)] for t in range(n_range) for s in range(n_range)]) for kk in range(n_train)]
    train_ys = np.zeros(n_train)
    train_Xt = [np.asarray([[(2+np.cos(s))*np.cos(t) + eps*(np.random.rand(1)[0]-0.5),(2+np.cos(s))*np.sin(t) + eps*(np.random.rand(1)[0]-0.5),np.sin(s) + eps*(np.random.rand(1)[0] - 0.5)] for t in range(n_range) for s in range(n_range)]) for kk in range(n_train)]
    train_yt = np.ones(n_train)
    
    # Training set
    train_X = np.concatenate((train_Xs, train_Xt))
    train_y = np.concatenate((train_ys, train_yt))
    
    test_Xs = [np.asarray([[np.cos(s)*np.cos(t) + eps*(np.random.rand(1)[0]-0.5),np.cos(s)*np.sin(t) + eps*(np.random.rand(1)[0]-0.5),np.sin(s) + eps*(np.random.rand(1)[0] - 0.5)] for t in range(n_range) for s in range(n_range)]) for kk in range(n_train)]
    test_ys = np.zeros(n_train)
    test_Xt = [np.asarray([[(2+np.cos(s))*np.cos(t) + eps*(np.random.rand(1)[0]-0.5),(2+np.cos(s))*np.sin(t) + eps*(np.random.rand(1)[0]-0.5),np.sin(s) + eps*(np.random.rand(1)[0] - 0.5)] for t in range(n_range) for s in range(n_range)]) for kk in range(n_train)]
    test_yt = np.ones(n_train)
    
    
    # Test set
    test_X = np.concatenate((test_Xs, test_Xt))
    test_y = np.concatenate((test_ys, test_yt))

.. code:: ipython3

    # Build persistence diagrams
    
    # The homology ranks we choose to consider
    homology_dimensions = (0, 1, 2)
    VR = VietorisRipsPersistence(
        metric='euclidean', max_edge_length=10, homology_dimensions=homology_dimensions)
    
    # List of all the time-ordered persistence diagrams obtained from the list of correlation matrices
    train_diagrams = VR.fit_transform(train_X)
    test_diagrams = VR.transform(test_X)

Extract and plot persistent entropies
-------------------------------------

.. code:: ipython3

    # Extract vector features from diagrams: persistence entropy
    PE = PersistenceEntropy()
    X_train = PE.fit_transform(train_diagrams)
    X_test = PE.transform(test_diagrams)

.. code:: ipython3

    plot_point_cloud(X_train)



.. raw:: html

    <div>
    
    
                <div id="804491b7-7795-4bcb-9a27-3801d38580de" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("804491b7-7795-4bcb-9a27-3801d38580de")) {
                        Plotly.newPlot(
                            '804491b7-7795-4bcb-9a27-3801d38580de',
                            [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [5.311947295846212, 5.322762109776713, 5.315024338816999, 5.333581512529468, 5.306642795884656, 5.314287525677649, 5.3128168542964636, 5.324999903071282, 5.3222873644605135, 5.310591864235093, 5.338262398613278, 5.343305321302533, 5.342148682922419, 5.347670072903819, 5.340606160760184, 5.3414048703610755, 5.351648247362492, 5.352656606770105, 5.341065340290131, 5.347449423033803], "y": [3.7982977403324765, 3.79091061357229, 3.766617126794471, 3.6948415998507675, 3.4904383982957485, 3.6580140687996225, 3.723704348232645, 3.833334066522209, 3.493639504888953, 3.532096103061199, 3.698992883025835, 3.7415792740388376, 3.690545286709881, 3.677264884463467, 3.729008206930133, 3.680807737214872, 3.7093699180593243, 3.6909758125241043, 3.65700272862705, 3.816409071453007], "z": [0.06783546219927304, -0.0, 0.02083295735789962, 0.28223636873457036, 0.16232648417055218, 0.37178011067183986, 0.23351990712222473, -0.0, -0.0, 0.013838951439695903, 2.721454526696171, 2.715657426954723, 2.790050755033054, 2.6181983511413938, 2.5885314775398713, 2.7264900926270386, 2.404185873440958, 2.4181791037953526, 2.7554947400686114, 2.7455949126295587]}],
                            {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('804491b7-7795-4bcb-9a27-3801d38580de');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Training logistic regression
    LR = LogisticRegression(solver='lbfgs')
    LR.fit(X_train, train_y)
    # Score
    LR.score(X_test, test_y)




.. parsed-literal::

    1.0



Generating non-orientable surfaces
----------------------------------

We are going to consider different classical shapes: the real projective
space and the Klein bottle. The purpose of the second part of the
tutorial is to define shapes via a distance matrix. We also add noise to
the distance matrix: the main reason is not to have overlapping points
in the persistence diagram.

Each of the topological spaces we are going to encounter will be sampled
discretely. Afterwards, the Vietoris–Rips technique will be applied to
the surface and the persistent homology groups will be computed.

.. code:: ipython3

    # Compute the adjacency matrix of the grid points, with boundaries identified as in the real projective space
    from sklearn.utils.graph_shortest_path import graph_shortest_path
    
    # This functions prepares the grid matrix with boundary identification
    def make_matrix(rows, cols):
        n = rows*cols
        M = np.zeros((n,n))
        for r in range(rows):
            for c in range(cols):
                i = r*cols + c
                # Two inner diagonals
                if c > 0: M[i-1,i] = M[i,i-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # Two outer diagonals
                if r > 0: M[i-cols,i] = M[i,i-cols] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # vertical twisted boundary identification
                if c == 0: M[n-i-1,i] = M[i,n-i-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # horizontal twisted boundary identification
                if r == 0: M[n-i-1,i] = M[i,n-i-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                    
        return M
    
    M = make_matrix(20,20)
    
    # Compute the distance matrix of the points over the Klein bottle
    
    rp2 = graph_shortest_path(M)
    
    # Plot of the distance matrix
    plot_heatmap(rp2, colorscale='viridis')



.. raw:: html

    <div>
    
    
                <div id="1491d4c3-4a62-467c-8d75-747eb00a30b3" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("1491d4c3-4a62-467c-8d75-747eb00a30b3")) {
                        Plotly.newPlot(
                            '1491d4c3-4a62-467c-8d75-747eb00a30b3',
                            [{"colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmap", "z": [[0.0, 1.0153836993669505, 2.006466077133121, 3.06601166191782, 4.005529043515654, 5.055987201519388, 6.037062499236741, 7.003063990908647, 8.022293481157249, 8.961008233808961, 9.889747708332909, 10.847179771092016, 11.920124247245568, 12.929981718808744, 13.8628030871863, 14.854485379638634, 15.90589883432572, 16.86862731777915, 17.92847337219134, 18.996289383899622, 1.0024633271472823, 1.9325197703337424, 2.9051603498260805, 3.8455061600881546, 4.827888371830043, 5.830859412562059, 6.878376832846984, 7.91979789160553, 8.934635404020291, 9.88784531039786, 10.887993069667562, 11.782063239518568, 12.730257587464884, 13.735312586919314, 14.685958721552405, 15.664684934469241, 16.70462140264048, 17.735523155983998, 18.714826573654612, 18.75665816697291, 2.0088169896424386, 2.8655513638050127, 3.907533370958781, 4.865960907056831, 5.773541597392242, 6.7447405319169995, 7.790648069573031, 8.834759213893184, 9.793577450453075, 10.834265002650817, 11.902335107470991, 12.728443131549382, 13.760212311639837, 14.729479953018194, 15.66038833934028, 16.695111705038002, 17.675670949404306, 18.67958093267032, 18.695096543850234, 17.79739038156583, 3.0211360982830002, 3.8233057146991998, 4.844744734891995, 5.876532892433098, 6.792165396984052, 7.722383134949247, 8.678773082312718, 9.708406654337034, 10.692214625019929, 11.678342926356859, 12.635723997738236, 13.663364790853608, 14.686635257337851, 15.662374762268302, 16.634878190430637, 17.60553919629095, 18.658224182440975, 18.782561952678293, 17.76661246077393, 16.826646600345875, 4.066427699371162, 4.815751729347608, 5.793590808433415, 6.857110245919767, 7.777798788661258, 8.704981350987538, 9.634659240561056, 10.673498525380268, 11.627354153509229, 12.600823696034977, 13.60838641089285, 14.598911750701923, 15.565428482926734, 16.5061623445092, 17.50075561086275, 18.464592470138978, 18.74403104267134, 17.850818387543114, 16.819586230955593, 15.875373180803303, 5.128537431019488, 5.822930005665395, 6.786640919573754, 7.789158640512188, 8.755346220235102, 9.718327254150854, 10.596374590939284, 11.628765137300594, 12.565522608491044, 13.56809342765612, 14.55017450318569, 15.494369582117509, 16.505743804309827, 17.490341340548316, 18.4667014518578, 18.688836112216563, 17.702628589827068, 16.81480394869688, 15.818456607402831, 14.817816444170374, 6.172729574498227, 6.786926219331952, 7.758120234050647, 8.776661863125863, 9.721285696023212, 10.685573579142453, 11.573163246768608, 12.624444385323045, 13.594050707123225, 14.554266896142881, 15.546250733527723, 16.43975819617205, 17.45070591829363, 18.474997464835937, 18.465948208568534, 17.618323938571756, 16.628050417814222, 15.78183848088908, 14.77716898296886, 13.848103154444328, 7.103358206478587, 7.78400639772916, 8.74733910603279, 9.785621816248069, 10.754511859058798, 11.694248120469597, 12.635083081600618, 13.581257338189937, 14.539541406626007, 15.548903185006436, 16.558653348808257, 17.42106620236055, 18.419220926645394, 18.278004293892984, 17.4923795426007, 16.54824156265071, 15.661337134510754, 14.82424202677023, 13.86899620172461, 12.859450235659313, 8.035776818870984, 8.73809294548334, 9.715401902911246, 10.682252830137214, 11.637910966396769, 12.620164574488493, 13.615083205193043, 14.550607110028473, 15.530875777596158, 16.54029826402981, 17.558212080863935, 18.447191066702473, 18.24022181404891, 17.313721035526473, 16.497887558176227, 15.570437672122644, 14.636423860708392, 13.804165797003353, 12.822857740642336, 11.891409507860603, 9.089518754705315, 9.796672260854686, 10.662864394702131, 11.656940588425616, 12.582882517280613, 13.56415352585898, 14.50044264966855, 15.505148636875234, 16.4772603180664, 17.40709815328761, 18.472807698010584, 18.24071547863378, 17.34407210517585, 16.32095132626212, 15.536012760951131, 14.655631432546691, 13.661933878666222, 12.870867895460627, 11.8703032071018, 10.897399568373688, 10.099442023061984, 10.741480430726856, 11.699701057570781, 12.696342060701182, 13.626060216397676, 14.554425682727494, 15.533212417026338, 16.492496930785595, 17.51149540860723, 18.40867625139807, 18.315286709306545, 17.275554990867526, 16.297942670976703, 15.38616291725318, 14.499321591912453, 13.58602920056084, 12.641392306071449, 11.81038289900354, 10.944932773290287, 9.951554903110214, 11.030939633339779, 11.751332984296551, 12.745061009869284, 13.752794947943297, 14.649075709965459, 15.608311587759907, 16.535200709439373, 17.423868566260538, 18.49503641738638, 18.229462749298918, 17.289952826301192, 16.32133619536078, 15.28994398519092, 14.415489457626801, 13.45854500415392, 12.564972498421497, 11.687849271269197, 10.753841987678681, 9.906186495311463, 8.980746998977011, 12.097254683973347, 12.787531417781457, 13.713546649303467, 14.647658413725845, 15.62070254031801, 16.55853948044303, 17.52867366791146, 18.41863984926028, 18.221840573905553, 17.206062419573172, 16.273260541912933, 15.32868512964731, 14.364725861848367, 13.427004470644443, 12.495157600734816, 11.609278334384737, 10.686175924923061, 9.740874285547468, 8.888686104728766, 8.055389016565819, 13.149627365214235, 13.83778276754682, 14.698705284004161, 15.580257022497834, 16.58510085565312, 17.515864639895867, 18.473941876333637, 18.245775471874847, 17.29654036785967, 16.355768360921427, 15.305366519630903, 14.377521570213263, 13.417411733295204, 12.493764495048588, 11.539577327706114, 10.684196277196586, 9.739417551930975, 8.795827941304411, 7.885388709086784, 7.125617121065918, 14.129183747300681, 14.82539550634715, 15.728978937881102, 16.651750657722133, 17.554835840644223, 18.455314482710268, 18.50024616864754, 17.470036170386532, 16.505283158573913, 15.524198000383223, 14.452295274935334, 13.405852827198297, 12.446907354405065, 11.489862080066487, 10.554064892482412, 9.630752737757216, 8.808196240938658, 7.863956291426984, 6.9587425235629, 6.068045552005399, 15.109450141177797, 15.897704990688249, 16.79987236341266, 17.610414606222207, 18.57144496523664, 18.49740484254005, 17.51663184123794, 16.5676224394864, 15.529573126222882, 14.52030709356373, 13.469143153289949, 12.507279181388709, 11.584927979550118, 10.60033781812939, 9.587591912079064, 8.697704505761601, 7.793908261525013, 6.849332793256151, 5.996310390939974, 5.037827279918496, 16.0502506834807, 16.947985480956437, 17.733179325812856, 18.583424675212445, 18.59153771861322, 17.525701350439157, 16.52245246638656, 15.57068632064036, 14.572312876673397, 13.595142827714387, 12.530098987107547, 11.539763628832077, 10.62017056306329, 9.580526981844683, 8.574996020868305, 7.738849973259264, 6.758302369315882, 5.851969231676704, 4.970626993385772, 3.999433935023264, 17.122822692494818, 17.999204668589876, 18.66298079921762, 18.507448585891055, 17.549313183113405, 16.497986715219636, 15.590476330281504, 14.580936329071609, 13.509763486483228, 12.5816123040042, 11.580570092379567, 10.57069942472229, 9.590590591395005, 8.625906776809165, 7.633788352166565, 6.68840927339679, 5.759015675074463, 4.84001809148525, 3.9205492026531474, 2.985874774087282, 18.100097388672424, 19.009983757455437, 18.61028903925605, 17.603469249155882, 16.54879209373816, 15.545942276574115, 14.60298909929933, 13.664093792111633, 12.727052518862697, 11.791285935454727, 10.813513098209542, 9.830591341980998, 8.842982524700714, 7.857245657320393, 6.798955185506676, 5.779530364034114, 4.81835075797379, 3.8548652169360853, 2.9058401216461194, 1.9527283340334407, 19.03613847276549, 18.888763817191652, 17.85967270394388, 16.870020975173734, 15.795212736772356, 14.879910959887464, 13.877838396796637, 12.853391636739083, 11.813079925763626, 10.83447481691189, 9.997975194696622, 8.954615214847308, 7.930405969720392, 6.95468547261957, 6.0010658623993685, 5.024567487091846, 4.009524750507991, 3.029217157998948, 2.07868757315112, 1.010968976110916], [1.0153836993669505, 0.0, 0.9910823777661704, 2.0506279625508697, 2.9901453441487043, 4.040603502152438, 5.021678799869791, 5.987680291541697, 7.006909781790299, 7.945624534442012, 8.87436400896596, 9.831796071725067, 10.90474054787862, 11.914598019441796, 12.847419387819352, 13.839101680271686, 14.890515134958772, 15.853243618412202, 16.91308967282439, 17.980905684532672, 1.8746122527363742, 0.944555809549914, 1.917196389042252, 2.8575421993043264, 3.8399244110462147, 4.842895451778231, 5.8904128720631554, 6.931833930821702, 7.946671443236463, 8.87246161103091, 9.872609370300612, 10.76667954015162, 11.714873888097936, 12.719928887552365, 13.670575022185457, 14.649301235102293, 15.68923770327353, 16.720139456617048, 17.699442874287662, 18.715177381757307, 2.8781820342165356, 1.8775874030211843, 2.9195694101749528, 3.8779969462730026, 4.785577636608414, 5.756776571133171, 6.802684108789203, 7.846795253109356, 8.805613489669247, 9.846301041866989, 10.914371146687163, 11.713059432182433, 12.744828612272888, 13.714096253651245, 14.645004639973331, 15.679728005671056, 16.660287250037356, 17.66419723330337, 18.020163893461586, 18.36357992522453, 3.8810976350104687, 2.835341753915371, 3.856780774108166, 4.88856893164927, 5.804201436200223, 6.734419174165419, 7.69080912152889, 8.720442693553206, 9.7042506642361, 10.69037896557303, 11.64776003695441, 12.675400830069782, 13.698671296554025, 14.656432291411843, 15.628935719574178, 16.59959672543449, 17.652281711584514, 18.01228115712488, 17.091679810385283, 17.392836144004576, 4.876986495899049, 3.827787768563779, 4.805626847649587, 5.869146285135939, 6.78983482787743, 7.717017390203709, 8.646695279777227, 9.685534564596438, 10.639390192725399, 11.612859735251147, 12.620422450109023, 13.610947789918097, 14.577464522142908, 15.518198383725373, 16.512791650078924, 17.47662850935515, 17.876507369003395, 17.080537591989703, 16.049305435402182, 16.441562724462006, 5.853041075801244, 4.834966044881567, 5.798676958789926, 6.80119467972836, 7.767382259451273, 8.730363293367024, 9.608410630155454, 10.640801176516764, 11.577558647707214, 12.58012946687229, 13.562210542401864, 14.506405621333682, 15.517779843525998, 16.502377379764486, 17.47873749107397, 17.821312438548617, 16.83510491615912, 16.04452315314347, 15.04817581184942, 15.384005987829076, 6.738919118156928, 5.798962258548124, 6.770156273266819, 7.788697902342035, 8.733321735239382, 9.697609618358623, 10.585199285984778, 11.636480424539215, 12.606086746339395, 13.566302935359051, 14.558286772743896, 15.451794235388222, 16.4627419575098, 17.487033504052107, 17.598424534900587, 16.75080026490381, 15.760526744146276, 15.011557685335669, 14.006888187415448, 14.41429269810303, 7.669547750137288, 6.796042436945331, 7.759375145248962, 8.79765785546424, 9.766547898274968, 10.706284159685767, 11.647119120816788, 12.593293377406107, 13.551577445842177, 14.560939224222606, 15.570689388024427, 16.433102241576723, 17.431256965861568, 17.410480620225037, 16.62485586893275, 15.680717888982763, 14.793813460842808, 14.003482936707758, 13.057272277768213, 13.425639779318015, 8.601966362529685, 7.7501289846995105, 8.727437942127418, 9.694288869353386, 10.64994700561294, 11.632200613704665, 12.627119244409213, 13.562643149244643, 14.542911816812328, 15.552334303245981, 16.570248120080105, 17.459227105918647, 17.37269814038096, 16.446197361858527, 15.63036388450828, 14.702913998454697, 13.768900187040446, 12.936642123335407, 11.99466744691444, 12.457599051519304, 9.655708298364017, 8.808708300070858, 9.674900433918303, 10.668976627641788, 11.594918556496783, 12.57618956507515, 13.51247868888472, 14.517184676091404, 15.48929635728257, 16.41913419250378, 17.484843737226754, 17.373191804965835, 16.476548431507908, 15.453427652594174, 14.668489087283186, 13.788107758878747, 12.794410204998275, 12.00334422179268, 11.042112913373904, 11.46358911203239, 10.665631566720686, 9.753516469943028, 10.711737096786955, 11.708378099917354, 12.638096255613846, 13.566461721943664, 14.545248456242508, 15.504532970001765, 16.5235314478234, 17.42071229061424, 17.4477630356386, 16.40803131719958, 15.43041899730876, 14.518639243585236, 13.631797918244509, 12.718505526892896, 11.7738686324035, 10.942859225335594, 10.11674247956239, 10.517744446768916, 11.59712917699848, 10.763369023512723, 11.757097049085456, 12.764830987159469, 13.661111749181629, 14.620347626976077, 15.547236748655541, 16.435904605476708, 17.50707245660255, 17.36193907563097, 16.42242915263325, 15.453812521692832, 14.422420311522975, 13.547965783958857, 12.591021330485976, 11.697448824753552, 10.820325597601249, 9.886318314010735, 9.077996201583568, 9.546936542635713, 12.663444227632048, 11.799567456997629, 12.725582688519639, 13.659694452942016, 14.63273857953418, 15.5705755196592, 16.54070970712763, 17.43067588847645, 17.354316900237606, 16.338538745905225, 15.405736868244988, 14.461161455979365, 13.497202188180422, 12.559480796976498, 11.62763392706687, 10.741754660716792, 9.818652251255113, 8.873350611879522, 8.060495811000871, 8.62157856022452, 13.715816908872936, 12.84981880676299, 13.710741323220333, 14.592293061714006, 15.597136894869294, 16.527900679112037, 17.485977915549807, 17.378251798206904, 16.429016694191727, 15.488244687253482, 14.437842845962958, 13.509997896545318, 12.549888059627259, 11.626240821380643, 10.67205365403817, 9.816672603528641, 8.871893878263027, 7.928304267636464, 7.057198415358889, 7.70464475365376, 14.695373290959383, 13.83743154556332, 14.741014977097272, 15.663786696938304, 16.566871879860397, 17.467350521926438, 17.525287074450617, 16.540266243476513, 15.637759484905965, 14.656674326715278, 13.58477160126739, 12.538329153530352, 11.57938368073712, 10.622338406398542, 9.686541218814467, 8.763229064089272, 7.940672567270711, 6.996432617759037, 6.130552229835005, 6.799345987182426, 15.675639684836499, 14.909741029904419, 15.811908402628832, 16.62245064543838, 17.583481004452814, 17.504960125085216, 16.524187123783104, 15.575177722031565, 14.662049452554935, 13.652783419895783, 12.601619479622002, 11.639755507720762, 10.717404305882173, 9.732814144461445, 8.72006823841112, 7.830180832093657, 6.926384587857067, 5.981809119588205, 5.168120097212079, 5.909976205507588, 16.616440227139403, 15.960021520172608, 16.745215365029026, 17.59546071442862, 17.576279767887733, 16.53325663298432, 15.530007748931725, 14.578241603185527, 13.70478920300545, 12.72761915404644, 11.6625753134396, 10.67223995516413, 9.752646889395345, 8.713003308176738, 7.70747234720036, 6.87132629959132, 5.890778695647937, 4.984445558008758, 4.104756871899944, 4.871582860612356, 17.68901223615352, 17.011240707806046, 17.67501683843379, 17.492064886524105, 16.53392948374646, 15.48260301585269, 14.59803161282667, 13.588491611616774, 12.642239812815282, 11.714088630336253, 10.71304641871162, 9.703175751054344, 8.723066917727058, 7.758383103141219, 6.7662646784986205, 5.820885599728845, 4.891492001406517, 3.9724944178173045, 3.0546790811673197, 3.858023699676374, 18.666286932331126, 18.022019796671607, 17.594905339889102, 16.588085549788936, 15.533408394371214, 14.530558577207168, 13.587605399932384, 12.648710092744686, 11.71166881949575, 10.77590223608778, 9.814255815156413, 8.831334058927869, 7.843725241647585, 6.93817385215712, 5.93143151183873, 4.9120066903661685, 3.9508270843058444, 2.9873415432681396, 2.0383164479781737, 2.8248772596225327, 18.898960073756996, 17.873380117824702, 16.844289004576932, 15.854637275806787, 14.779829037405408, 13.864527260520516, 12.862454697429689, 11.838007937372135, 10.797696226396678, 9.819091117544941, 8.982591495329673, 7.939231515480358, 6.915022270353442, 5.93930177325262, 4.985682163032418, 4.009183787724896, 2.9941410511410407, 2.013833458631998, 1.0664784132305571, 2.0263526754778667], [2.006466077133121, 0.9910823777661704, 0.0, 1.0595455847846993, 1.999062966382534, 3.049521124386267, 4.030596422103621, 4.996597913775526, 6.015827404024129, 6.954542156675841, 7.8832816311997895, 8.840713693958897, 9.913658170112448, 10.923515641675625, 11.856337010053181, 12.848019302505515, 13.899432757192601, 14.862161240646032, 15.922007295058222, 16.989823306766503, 2.865694630502545, 1.9356381873160844, 1.0363058206599793, 1.9766516309220536, 2.928217179889133, 3.931188220621149, 4.978705640906073, 6.020126699664619, 6.9555913533706955, 7.88137923326474, 8.881526992534441, 9.775597162385449, 10.723791510331765, 11.728846509786194, 12.679492644419286, 13.658218857336122, 14.69815532550736, 15.729057078850875, 16.70836049652149, 17.72409500399114, 3.869264411982706, 2.8686697807873545, 2.0879727507088646, 2.99710637789073, 3.873870405451332, 4.84506933997609, 5.890976877632121, 6.935088021952274, 7.893906258512164, 8.930051020123765, 9.938389262149238, 10.721977054416262, 11.753746234506718, 12.723013875885075, 13.65392226220716, 14.688645627904885, 15.669204872271186, 16.673114855537197, 17.612627312719365, 18.634120532812776, 4.872180012776639, 3.8264241316815415, 3.025184114642078, 4.007678363266997, 4.892494205043143, 5.822711943008337, 6.779101890371808, 7.808735462396124, 8.792543433079018, 9.778671734415948, 10.736052805797325, 11.763693598912697, 12.73931241742548, 13.665349913645672, 14.637853341808007, 15.60851434766832, 16.66119933381834, 17.13479155426882, 17.910728532494716, 18.383918521770745, 5.86806887366522, 4.8188701463299495, 4.0029569040084265, 5.046361069905019, 5.878127596720349, 6.805310159046628, 7.7349880486201466, 8.773827333439357, 9.727682961568318, 10.701152504094066, 11.708715218951939, 12.699240558761012, 13.665757290985823, 14.606491152568289, 15.60108441892184, 16.564921278198067, 16.94828303540108, 16.20304798913364, 16.868354157511614, 17.432645102228175, 6.8441234535674145, 5.826048422647737, 4.996007015148765, 5.995842846906798, 6.8556750282941925, 7.818656062209943, 8.696703398998375, 9.729093945359685, 10.665851416550133, 11.668422235715209, 12.65050331124478, 13.594698390176598, 14.606072612368914, 15.590670148607403, 16.567030259916887, 16.8930881049463, 15.906880582556806, 15.167033550287407, 15.867224533958852, 16.375088365595246, 7.730001495923099, 6.790044636314295, 6.013325749664984, 7.0041304541056215, 7.821614504082302, 8.785902387201542, 9.6734920548277, 10.724773193382136, 11.694379515182316, 12.65459570420197, 13.646579541586812, 14.540087004231138, 15.551034726352714, 16.575326272895023, 16.67020020129827, 15.822575931301493, 14.83230241054396, 14.114058528143898, 14.82593690952488, 15.4053750758692, 8.66063012790346, 7.787124814711502, 7.038777844458262, 8.013090407227827, 8.854840667117887, 9.794576928528686, 10.735411889659709, 11.681586146249028, 12.639870214685098, 13.649231993065525, 14.658982156867346, 15.521395010419637, 16.519549734704484, 16.48225628662272, 15.696631535330434, 14.752493555380447, 13.865589127240492, 13.075258603105446, 13.876320999877645, 14.416722157084186, 9.593048740295856, 8.741211362465682, 8.00684064133672, 8.973691568562687, 9.780664325533815, 10.76291793362554, 11.715412013252134, 12.650935918087564, 13.631204585655249, 14.6406270720889, 15.658540888923024, 16.54751987476156, 16.44447380677865, 15.517973028256213, 14.702139550905965, 13.774689664852382, 12.84067585343813, 12.008417789733095, 12.813716169023872, 13.448681429285475, 10.646790676130188, 9.799790677837029, 8.954303133127604, 9.94837932685109, 10.725635876417659, 11.706906884996027, 12.643196008805596, 13.605477444934325, 14.57758912612549, 15.507426961346699, 16.573136506069673, 16.444967471363523, 15.548324097905594, 14.52520331899186, 13.740264753680872, 12.859883425276433, 11.86618587139596, 11.075119888190368, 11.861161635483336, 12.45467148979856, 11.656713944486857, 10.744598847709199, 9.991139795996254, 10.987780799126655, 11.768813575534722, 12.69717904186454, 13.675965776163384, 14.635250289922642, 15.631611157129152, 16.50900505945716, 16.519538702036286, 15.479806983597268, 14.502194663706446, 13.590414909982922, 12.703573584642195, 11.790281193290582, 10.845644298801187, 10.01463489173328, 10.935791201671822, 11.508826824535086, 12.588211554764651, 11.754451401278894, 11.047273704907877, 12.04423368636877, 12.791829069102505, 13.751064946896953, 14.677954068576417, 15.566621925397584, 16.637789776523427, 16.433714742028656, 15.494204819030934, 14.525588188090518, 13.494195977920661, 12.619741450356543, 11.662796996883662, 10.769224491151238, 9.892101263998935, 8.958093980408421, 9.897044923693, 10.538018920401884, 13.654526605398217, 12.7906498347638, 12.01575934434206, 12.949871108764437, 13.763455899455057, 14.701292839580077, 15.671427027048507, 16.561393208397327, 16.426092566635294, 15.410314412302913, 14.477512534642674, 13.532937122377051, 12.568977854578108, 11.631256463374184, 10.699409593464557, 9.813530327114478, 8.890427917652799, 7.9451262782772085, 8.879544533110304, 9.612660937990691, 14.706899286639105, 13.840901184529162, 13.000917979042754, 13.882469717536427, 14.77418609181992, 15.658617999032913, 16.616695235470686, 16.450027464604588, 15.500792360589413, 14.560020353651169, 13.509618512360644, 12.581773562943004, 11.621663726024945, 10.698016487778329, 9.743829320435855, 8.888448269926327, 7.943669544660713, 7.000079934034152, 7.944302491970413, 8.69572713141993, 15.686455668725552, 14.828513923329492, 14.031191632919693, 14.953963352760725, 15.743921076811024, 16.598067841847314, 16.534204696684444, 15.54918386571034, 14.709535151303653, 13.728449993112964, 12.656547267665076, 11.610104819928038, 10.651159347134806, 9.694114072796228, 8.758316885212153, 7.835004730486958, 7.012448233668397, 6.068208284156725, 7.017656306446529, 7.790428364948597, 16.66672206260267, 15.900823407670591, 15.102085058451253, 15.9126273012608, 16.76053020140344, 16.513877747319043, 15.533104746016932, 14.584095344265393, 13.733825118952623, 12.724559086293471, 11.67339514601969, 10.71153117411845, 9.78917997227986, 8.804589810859131, 7.791843904808806, 6.901956498491343, 5.998160254254753, 5.053584785985892, 6.118645834770874, 6.901058583273759, 17.607522604905576, 16.95110389793878, 16.035392020851447, 16.88563737025104, 16.58519739012156, 15.542174255218146, 14.538925371165552, 13.587159225419354, 12.750640893932031, 11.799394820444128, 10.734350979837288, 9.744015621561818, 8.82442255579303, 7.784778974574423, 6.779248013598046, 5.943101965989006, 4.962554362045623, 4.056221224406445, 5.0615868673448325, 5.8626652383785265, 18.680094613919692, 18.00232308557222, 16.965193494256212, 16.500982508757936, 15.542847105980286, 14.491520638086518, 13.606949235060497, 12.597409233850602, 11.682411929643703, 10.754260747164674, 9.784822085109308, 8.774951417452032, 7.794842584124745, 6.830158769538905, 5.8380403448963065, 4.892661266126531, 3.963267667804203, 3.044270084214991, 4.024504938144938, 4.849106077442545, 18.56396743485483, 17.54097627536717, 16.60382296212293, 15.597003172022763, 14.542326016605042, 13.539476199440996, 12.596523022166211, 11.657627714978513, 10.720586441729578, 9.784819858321608, 8.823173437390242, 7.840251681161697, 6.852642863881414, 5.947091474390948, 4.977711685053914, 3.983782356763855, 3.0226027507035305, 2.059117209665826, 3.008142304955792, 3.815959637388703, 17.907877695990827, 16.882297740058533, 15.85320662681076, 14.863554898040617, 13.788746659639237, 12.873444882754345, 11.871372319663518, 10.846925559605964, 9.806613848630507, 8.82800873977877, 7.991509117563503, 6.9481491377141875, 5.9239398925872715, 4.948219395486448, 3.994599785266247, 3.0181014099587253, 2.00305867337487, 1.0227510808658276, 2.0369400155800346, 3.0174350532440366], [3.06601166191782, 2.0506279625508697, 1.0595455847846993, 0.0, 0.9395173815978346, 1.9899755396015677, 2.9710508373189213, 3.937052328990827, 4.95628181923943, 5.894996571891142, 6.823736046415091, 7.781168109174198, 8.85411258532775, 9.863970056890926, 10.796791425268482, 11.788473717720816, 12.839887172407902, 13.802615655861333, 14.862461710273521, 15.9302777219818, 3.810712876489343, 2.880656433302883, 1.908015853810545, 0.9676700435484706, 1.8686715951044335, 2.8716426358364497, 3.919160056121374, 4.96058111487992, 5.896045768585997, 6.821833648480041, 7.821981407749743, 8.71605157760075, 9.664245925547066, 10.669300925001496, 11.619947059634587, 12.598673272551423, 13.63860974072266, 14.669511494066178, 15.648814911736794, 16.66454941920644, 4.814282657969505, 3.8136880267741535, 2.9596827838594297, 1.988124790517147, 2.8143248206666325, 3.78552375519139, 4.831431292847421, 5.875542437167574, 6.834360673727464, 7.870505435339066, 8.878843677364541, 9.662431469631564, 10.694200649722019, 11.663468291100376, 12.594376677422462, 13.629100043120186, 14.609659287486487, 15.6135692707525, 16.553081727934668, 17.57457494802808, 5.8171982587634385, 4.771442377668341, 3.896894147792643, 2.998696775893414, 3.8329486202584424, 4.763166358223637, 5.719556305587108, 6.749189877611424, 7.7329978482943185, 8.719126149631249, 9.676507221012628, 10.704148014128, 11.679766832640782, 12.605804328860973, 13.578307757023309, 14.548968762883622, 15.601653749033643, 16.58952063651947, 17.48156581101097, 18.421531671439027, 6.813087119652019, 5.7638883923167485, 4.874666937158992, 4.037379482531436, 4.818582011935649, 5.745764574261928, 6.675442463835447, 7.714281748654658, 8.66813737678362, 9.641606919309368, 10.649169634167242, 11.639694973976315, 12.606211706201126, 13.546945567783592, 14.541538834137143, 15.505375693413368, 16.002351606710437, 16.918186783217916, 17.771056622891493, 18.377663348214973, 7.789141699554213, 6.7710666686345355, 5.867717048299331, 4.986861259533215, 5.796129443509493, 6.759110477425244, 7.6371578142136745, 8.669548360574984, 9.606305831765434, 10.60887665093051, 11.590957726460083, 12.5351528053919, 13.546527027584217, 14.531124563822706, 15.50748467513219, 15.94715667625566, 14.960949153866164, 15.882172344371682, 16.76992699933873, 17.320106611582045, 8.675019741909898, 7.735062882301093, 6.8850357828155495, 5.9951488667320385, 6.762068919297603, 7.726356802416843, 8.613946470042999, 9.665227608597435, 10.634833930397615, 11.595050119417271, 12.587033956802115, 13.48054141944644, 14.491489141568017, 15.515780688110327, 15.724268772607628, 14.876644502610851, 13.886370981853318, 14.829197322228174, 15.728639374904755, 16.350393321856, 9.605648373890258, 8.7321430606983, 7.910487877608827, 7.004108819854244, 7.795295082333188, 8.735031343743985, 9.675866304875008, 10.622040561464328, 11.580324629900398, 12.589686408280826, 13.599436572082647, 14.46184942563494, 15.460004149919786, 15.463925849490536, 14.750700106639792, 13.806562126689805, 12.91965769854985, 13.901154831775738, 14.77902346525752, 15.361740403070984, 10.538066986282654, 9.68622960845248, 8.878550674487283, 7.9935376687668755, 8.721118740749114, 9.703372348840839, 10.655866428467434, 11.591390333302863, 12.571659000870548, 13.581081487304202, 14.598995304138326, 15.487974289976862, 15.42614336964646, 14.499642591124026, 13.756208122215323, 12.82875823616174, 11.894744424747488, 12.834314018403386, 13.716418634403746, 14.393699675272273, 11.591808922116986, 10.744808923823827, 9.826013166278168, 9.040280207317535, 9.666090291632958, 10.647361300211326, 11.583650424020895, 12.545931860149624, 13.51804354134079, 14.447881376561998, 15.51359092128497, 15.426637034231334, 14.529993660773407, 13.506872881859673, 12.721934316548685, 11.841552988144246, 10.920254442705318, 11.90101611686066, 12.763864100863211, 13.399689735785358, 12.601732190473655, 11.689617093695997, 10.862849829146818, 10.0796816795931, 10.709267990750021, 11.63763345707984, 12.616420191378683, 13.575704705137941, 14.572065572344451, 15.449459474672459, 15.501208264904097, 14.46147654646508, 13.483864226574259, 12.572084472850735, 11.685243147510008, 10.771950756158395, 9.899712870110545, 10.917337357113157, 11.838493667051697, 12.453845070521885, 13.53322980075145, 12.699469647265692, 11.91898373805844, 11.136134566835215, 11.732283484317804, 12.691519362112253, 13.618408483791717, 14.507076340612883, 15.578244191738724, 15.41538430489647, 14.475874381898747, 13.507257750958331, 12.475865540788474, 11.601411013224356, 10.644466559751475, 9.750894054019051, 8.946169835308293, 9.860796445788298, 10.799747389072875, 11.483037166388682, 14.599544851385016, 13.735668080750598, 12.887469377492623, 12.109070872815463, 12.703910314670356, 13.641747254795376, 14.611881442263806, 15.501847623612628, 15.407762129503109, 14.391983975170726, 13.459182097510487, 12.514606685244864, 11.550647417445921, 10.612926026241997, 9.68107915633237, 8.79519988998229, 7.944496488962157, 8.847828743657084, 9.782246998490178, 10.55767918397749, 15.651917532625903, 14.78591943051596, 13.872628012193317, 13.041669481587453, 13.71464050703522, 14.599072414248212, 15.557149650685986, 15.431697027472401, 14.482461923457226, 13.541689916518981, 12.491288075228457, 11.563443125810817, 10.603333288892758, 9.679686050646142, 8.725498883303668, 7.87011783279414, 6.997738115970071, 7.9027823994140265, 8.847004957350288, 9.64074537740673, 16.631473914712352, 15.77353216931629, 14.902901666070257, 14.113163116811752, 14.684375492026323, 15.538522257062613, 15.474659111899747, 14.489638280925643, 13.659117367866095, 12.707585874269748, 11.638216830532889, 10.591774382795851, 9.632828910002619, 8.675783635664041, 7.739986448079966, 6.816674293354771, 6.066516804977755, 6.9709107495366, 7.920358771826404, 8.735446610935396, 17.611740308589468, 16.84584165365739, 15.973795091601817, 15.071827065311826, 15.70098461661874, 15.454332162534348, 14.473559161232235, 13.524549759480696, 12.683407335515065, 11.683476587170563, 10.632312646896782, 9.670448674995543, 8.77084953514767, 7.786259373726943, 6.773513467676619, 5.883626061359156, 5.052228825564111, 5.956287251365767, 7.021348300150748, 7.846076829260557, 18.552540850892374, 17.87505817335773, 16.90710205400201, 16.044837134302064, 15.525651805336864, 14.48262867043345, 13.479379786380855, 12.527613640634657, 11.691095309147334, 10.751969711412674, 9.69326848071438, 8.70293312243891, 7.8060921186608425, 6.766448537442236, 5.760917576465859, 4.924771528856819, 4.01662293335498, 4.95892368978632, 5.964289332724707, 6.807683484365325, 18.48169654624774, 17.492209779448036, 16.453089238338492, 15.441436923973237, 14.483301521195589, 13.431975053301821, 12.5474036502758, 11.537863649065905, 10.622866344859005, 9.694715162379977, 8.7437395859864, 7.733868918329124, 6.753760085001837, 5.811828332406718, 4.8197099077641194, 3.874330828994344, 3.0173362391135603, 3.9469725495948658, 4.936017783921873, 5.794124323429343, 17.504421850070134, 16.481430690582474, 15.544277377338233, 14.537457587238066, 13.482780431820345, 12.479930614656299, 11.536977437381514, 10.598082130193816, 9.661040856944881, 8.725274273536911, 7.763627852605543, 6.780706096376998, 5.793097279096715, 4.8875458896062485, 3.918166100269215, 2.9411492478488697, 2.0766713220128876, 3.0401568630505924, 3.9891819583405583, 4.760977883375501, 16.848332111206126, 15.822752155273832, 14.793661042026061, 13.804009313255918, 12.729201074854538, 11.813899297969646, 10.811826734878819, 9.787379974821265, 8.747068263845808, 7.768463154994072, 6.931963532778804, 5.888603552929489, 4.864394307802573, 3.8886738107017487, 2.935054200481548, 1.9671576178981711, 1.0403530004042085, 2.020660592913251, 3.0348495276274576, 4.076980638028736], [4.005529043515654, 2.9901453441487043, 1.999062966382534, 0.9395173815978346, 0.0, 1.050458158003733, 2.0315334557210867, 2.9975349473929924, 4.016764437641595, 4.955479190293308, 5.884218664817256, 6.841650727576363, 7.914595203729915, 8.924452675293091, 9.857274043670648, 10.848956336122981, 11.900369790810068, 12.863098274263498, 13.922944328675687, 14.990760340383966, 4.750230258087178, 3.820173814900717, 2.8475332354083793, 1.9071874251463052, 0.9291542135065989, 1.932125254238615, 2.979642674523539, 4.0210637332820856, 4.956528386988162, 5.882316266882206, 6.882464026151909, 7.776534196002915, 8.724728543949231, 9.729783543403661, 10.680429678036752, 11.659155890953588, 12.699092359124826, 13.729994112468344, 14.70929753013896, 15.725032037608607, 5.753800039567339, 4.753205408371987, 3.8725907889774662, 2.8721993789994826, 1.8748074390687979, 2.8460063735935552, 3.8919139112495866, 4.93602505556974, 5.89484329212963, 6.930988053741231, 7.939326295766706, 8.722914088033729, 9.754683268124184, 10.723950909502541, 11.654859295824627, 12.689582661522351, 13.670141905888652, 14.674051889154665, 15.613564346336831, 16.635057566430245, 6.756715640361271, 5.710959759266174, 4.809802152910679, 3.822582443380231, 2.893431238660608, 3.823648976625803, 4.780038923989274, 5.809672496013589, 6.793480466696484, 7.779608768033413, 8.736989839414791, 9.764630632530164, 10.740249451042947, 11.666286947263139, 12.638790375425474, 13.609451381285787, 14.662136367435808, 15.650003254921634, 16.542048429413136, 17.482014289841192, 7.752604501249853, 6.703405773914582, 5.787574942277027, 4.80975976403716, 3.8790646303378145, 4.8062471926640935, 5.735925082237612, 6.774764367056823, 7.728619995185785, 8.702089537711533, 9.709652252569406, 10.700177592378479, 11.66669432460329, 12.607428186185755, 13.602021452539306, 14.565858311815532, 15.597652189002085, 16.58174682005681, 17.584422804396237, 18.433287709383762, 8.728659081152047, 7.71058405023237, 6.761759261977373, 5.759241541038939, 4.856612061911658, 5.819593095827409, 6.69764043261584, 7.730030978977149, 8.6667884501676, 9.669359269332675, 10.651440344862246, 11.595635423794064, 12.60700964598638, 13.59160718222487, 14.567967293534354, 15.018789116900102, 15.807819960471441, 16.72904315097696, 17.616797805944007, 18.259623993179876, 9.614537123507732, 8.674580263898928, 7.779077996493592, 6.767529148237763, 5.822551537699768, 6.786839420819009, 7.674429088445164, 8.7257102269996, 9.69531654879978, 10.655532737819437, 11.647516575204278, 12.541024037848604, 13.551971759970181, 14.576263306512491, 14.787739914070592, 13.948276943255296, 14.733241788458596, 15.676068128833451, 16.575510181510033, 17.28991070345383, 10.545165755488092, 9.671660442296137, 8.80453009128687, 7.776489101359968, 6.855777700735353, 7.795513962146151, 8.736348923277173, 9.682523179866493, 10.640807248302563, 11.650169026682992, 12.659919190484812, 13.522332044037103, 14.52048676832195, 14.524408467892702, 13.814171248102756, 12.87819456733425, 13.766528505155128, 14.748025638381016, 15.625894271862798, 16.301257784668817, 11.477584367880489, 10.625746990050317, 9.704110422636802, 8.737259495410834, 7.78160135915128, 8.763854967243004, 9.716349046869599, 10.651872951705029, 11.632141619272714, 12.641564105706367, 13.659477922540491, 14.548456908379025, 14.486625988048626, 13.560125209526191, 12.819679263678287, 11.900390676806184, 12.741615231352766, 13.681184825008664, 14.563289441009024, 15.333217056870108, 12.53132630371482, 11.652194816081325, 10.651572914427687, 9.669442240707383, 8.726572910035124, 9.707843918613491, 10.64413304242306, 11.60641447855179, 12.578526159742955, 13.508363994964164, 14.574073539687136, 14.487119652633499, 13.590476279175572, 12.567355500261838, 11.78241693495085, 10.902035606546411, 11.767125249310595, 12.747886923465938, 13.610734907468489, 14.339207117383193, 13.54124957207149, 12.597002985953495, 11.688409577296337, 10.708843712982949, 9.769750609152187, 10.698116075482005, 11.676902809780849, 12.636187323540106, 13.632548190746617, 14.509942093074624, 14.561690883306262, 13.521959164867246, 12.544346844976424, 11.6325670912529, 10.745725765912173, 9.83243337456056, 10.74658367671582, 11.764208163718433, 12.685364473656975, 13.39336245211972, 14.472747182349284, 13.60685553952319, 12.74454348620796, 11.765296600225064, 10.79276610271997, 11.752001980514418, 12.678891102193882, 13.567558959015049, 14.63872681014089, 14.475866923298636, 13.536357000300912, 12.567740369360497, 11.53634815919064, 10.661893631626521, 9.70494917815364, 8.811376672421217, 9.793040641913569, 10.707667252393573, 11.646618195678151, 12.422554547986516, 15.53906223298285, 14.643053973008096, 13.67234467062769, 12.738232906205312, 11.764392933072521, 12.702229873197542, 13.672364060665972, 14.562330242014793, 14.468244747905274, 13.452466593572892, 12.519664715912652, 11.57508930364703, 10.611130035848086, 9.673408644644162, 8.741561774734535, 7.855682508384456, 8.791367295567433, 9.69469955026236, 10.629117805095454, 11.497196565575324, 16.59143491422374, 15.693305322773458, 14.657503305328383, 13.670831514977301, 12.775123125437386, 13.659555032650378, 14.617632269088151, 14.492179645874566, 13.542944541859391, 12.602172534921147, 11.551770693630623, 10.623925744212983, 9.663815907294923, 8.740168669048307, 7.785981501705834, 6.930600451196305, 7.844608922575347, 8.749653206019303, 9.693875763955564, 10.580262759004565, 17.570991296310186, 16.680918061573788, 15.687776959205323, 14.711769839290437, 13.744858110428488, 14.599004875464779, 14.535141730301913, 13.550120899327808, 12.71959998626826, 11.768068492671913, 10.698699448935054, 9.652257001198016, 8.693311528404784, 7.736266254066207, 6.8004690664821315, 5.877156911756936, 6.913387611583031, 7.817781556141876, 8.76722957843168, 9.67496399253323, 18.551257690187303, 17.703688660266938, 16.64167462005454, 15.670433787790511, 14.761467235020906, 14.514814780936513, 13.5340417796344, 12.585032377882861, 11.74388995391723, 10.743959205572729, 9.692795265298948, 8.730931293397708, 7.831332153549837, 6.846741992129108, 5.833996086078784, 4.944108679761321, 5.899099632169387, 6.803158057971043, 7.868219106756024, 8.769515524924229, 18.37576142441336, 17.411329449501142, 16.443373330145423, 15.519085886207764, 14.58613442373903, 13.543111288835615, 12.53986240478302, 11.588096259036822, 10.7515779275495, 9.812452329814839, 8.753751099116545, 7.763415740841076, 6.866574737063008, 5.8269311558444015, 4.8214001948680245, 3.985254147258984, 4.863493739960256, 5.805794496391596, 6.811160139329983, 7.731122180028996, 17.542179164649905, 16.5526923978502, 15.51357185674066, 14.501919542375402, 13.543784139597754, 12.492457671703987, 11.607886268677966, 10.59834626746807, 9.683348963261171, 8.755197780782142, 7.804222204388566, 6.794351536731289, 5.814242703404003, 4.872310950808884, 3.880192526166285, 2.9348134473965093, 3.8642070457188367, 4.793843356200142, 5.782888590527149, 6.7175630190930145, 16.5649044684723, 15.54191330898464, 14.604759995740398, 13.597940205640231, 12.54326305022251, 11.540413233058464, 10.59746005578368, 9.658564748595982, 8.721523475347047, 7.7857568919390765, 6.8241104710077085, 5.841188714779164, 4.85357989749888, 3.948028508008414, 2.9786487186713804, 2.001631866251035, 2.9628114723113597, 3.926297013349064, 4.87532210863903, 5.700495264973336, 15.90881472960829, 14.883234773675998, 13.854143660428226, 12.864491931658083, 11.789683693256704, 10.874381916371812, 9.872309353280984, 8.84786259322343, 7.807550882247973, 6.828945773396238, 5.992446151180969, 4.949086171331654, 3.924876926204738, 2.949156429103914, 1.9955368188837133, 1.0276402363003365, 1.9798703820020431, 2.9601779745110854, 3.9743669092252922, 5.01649801962657], [5.055987201519388, 4.040603502152438, 3.049521124386267, 1.9899755396015677, 1.050458158003733, 0.0, 0.9810752977173537, 1.9470767893892593, 2.966306279637862, 3.905021032289575, 4.833760506813523, 5.7911925695726305, 6.864137045726181, 7.873994517289357, 8.806815885666914, 9.798498178119248, 10.849911632806334, 11.812640116259765, 12.872486170671955, 13.940302182380234, 5.768595411668706, 4.838538968482245, 3.8658983889899075, 2.925552578727833, 1.9431703669859446, 0.9401993262539287, 1.935851672604414, 2.9772727313629606, 3.9060702289844285, 4.831858108878474, 5.832005868148176, 6.726076037999182, 7.674270385945498, 8.679325385399927, 9.629971520033019, 10.608697732949855, 11.648634201121093, 12.679535954464608, 13.658839372135224, 14.674573879604871, 6.772165193148867, 5.771570561953515, 4.8750031843898585, 3.874611774411875, 2.87721983448119, 1.9060208999564328, 2.8981436802274625, 3.9238422458283413, 4.882660482388231, 5.8805298957374985, 6.888868137762973, 7.672455930029997, 8.704225110120452, 9.67349275149881, 10.604401137820894, 11.639124503518618, 12.619683747884919, 13.62359373115093, 14.563106188333096, 15.584599408426508, 7.7750807939428, 6.729324912847702, 5.812214548323071, 4.782749849389724, 3.8535986446701003, 2.8836635029886803, 3.838078725421612, 4.8677122974459275, 5.851520268128822, 6.837648569465752, 7.79502964084713, 8.723683720132799, 9.689791293039216, 10.615828789259407, 11.588332217421742, 12.558993223282055, 13.611678209432077, 14.599545096917899, 15.491590271409398, 16.431556131837453, 8.770969654831381, 7.72177092749611, 6.7899873376894195, 5.744365496686613, 4.813670362987267, 3.886487800660988, 4.813037206534737, 5.8518764913539485, 6.80573211948291, 7.779201662008658, 8.767692054001744, 9.659230679981114, 10.625747412205925, 11.56648127378839, 12.561074540141941, 13.524911399418167, 14.55670527660472, 15.531288662053075, 16.5339646463925, 17.382829551380024, 9.747024234733574, 8.728949203813897, 7.696364994626825, 6.693847273688392, 5.791217794561111, 4.899833703824303, 5.774752556912965, 6.807143103274274, 7.743900574464725, 8.7464713936298, 9.709480146294585, 10.653675225226403, 11.590791204258949, 12.567694826174623, 13.544054937484107, 14.487212983758996, 15.546060785580096, 16.56730310089931, 17.535094269945265, 18.440386288012952, 10.624834603470543, 9.684877743861739, 8.713683729143044, 7.702134880887216, 6.757157270349221, 5.867080028815902, 6.751541212742289, 7.802822351296726, 8.772428673096906, 9.732644862116562, 10.705556376636617, 11.599063839280943, 12.53575331824275, 13.560044864785059, 13.84659530976172, 14.81514063686007, 15.639679231963239, 16.582505572338096, 17.481947625014676, 18.300208183416643, 11.555463235450903, 10.681957922258947, 9.739135823936321, 8.71109483400942, 7.790383433384806, 6.908817288145128, 7.8134610475742985, 8.759635304163618, 9.717919372599688, 10.727281150980117, 11.737031314781937, 12.580371845469442, 13.52101668308682, 13.583263863583827, 12.873026643793883, 13.745058260939023, 14.67296594865977, 15.654463081885659, 16.53233171536744, 17.31155526463163, 12.4878818478433, 11.618730879972503, 10.638716155286255, 9.671865228060287, 8.716207091800733, 7.945388116909168, 8.793461171166724, 9.728985076002154, 10.709253743569839, 11.718676230003492, 12.736590046837616, 13.606496709811363, 13.545481383739753, 12.618980605217319, 11.878534659369414, 12.767254370410958, 13.648052674857409, 14.587622268513307, 15.469726884513667, 16.34351453683292, 13.54162378367763, 12.586800548730778, 11.58617864707714, 10.604047973356835, 9.661178642684575, 8.923629715957025, 9.797547231088974, 10.683526602848914, 11.65563828404008, 12.585476119261289, 13.651185663984261, 13.527816022230665, 12.6493316748667, 11.626210895952966, 10.841272330641978, 11.768899300151185, 12.673562692815239, 13.654324366970581, 14.517172350973132, 15.349504597346003, 14.478356312589302, 13.531608718602948, 12.623015309945792, 11.6434494456324, 10.704356341801638, 9.991499496267705, 10.830316998446762, 11.739707719720235, 12.709660315043742, 13.58705421737175, 13.570282150361285, 12.562655534464412, 11.603202240667551, 10.691422486944028, 9.8045811616033, 10.738870818065205, 11.653021120220465, 12.670645607223078, 13.591801917161618, 14.40365993208253, 15.409853922867097, 14.541461272172644, 13.679149218857415, 12.699902332874515, 11.727371835369421, 11.045385401300118, 11.832305290859795, 12.671079355195179, 13.74224720632102, 13.484458190353658, 12.544948267355934, 11.608436738957662, 10.595203554881767, 9.720749027317648, 8.763804573844768, 9.717814115925862, 10.699478085418214, 11.614104695898218, 12.553055639182796, 13.432852027949327, 16.476168973500663, 15.577659705657549, 14.606950403277141, 13.672838638854763, 12.698998665721973, 11.995613293983242, 12.883647775782212, 13.665850638194923, 13.476836014960297, 12.461057860627914, 11.528255982967675, 10.583950681075798, 9.669985431539214, 8.73226404033529, 7.800417170425663, 8.762119951889101, 9.697804739072078, 10.601136993767005, 11.5355552486001, 12.507494045538134, 17.528541654741552, 16.62791105542291, 15.592109037977835, 14.605437247626753, 13.709728858086837, 12.952938453436078, 13.828915984204391, 13.500770912929589, 12.551535808914414, 11.61076380197617, 10.560361960685645, 9.632517011268005, 8.72267130298605, 7.799024064739435, 6.844836897396962, 7.83703789470095, 8.751046366079992, 9.656090649523948, 10.600313207460209, 11.590560238967376, 18.508098036828, 17.61552379422324, 16.622382691854774, 15.646375571939888, 14.67946384307794, 13.892388296250479, 13.48468357229818, 12.499662741324077, 11.669141828264529, 10.717610334668182, 9.704197143722194, 8.660848268253039, 7.752166924095912, 6.795121649757335, 5.85932446217326, 6.783594355261581, 7.819825055087676, 8.72421899964652, 9.673667021936325, 10.606463726759504, 18.266103808712533, 17.388236174754283, 16.326222134541887, 15.441637797194272, 14.434202491083227, 13.464356622932781, 12.483583621630668, 11.53457421987913, 10.693431795913499, 9.693501047568997, 8.642337107295216, 7.680473135393976, 6.8358537104112145, 5.898016681473945, 4.892851481769912, 5.850546123265966, 6.805537075674032, 7.709595501475689, 8.774656550260671, 9.675952968428874, 17.325303266409627, 16.36087129149741, 15.392915172141691, 14.468627728204032, 13.535676265735297, 12.492653130831883, 11.489404246779289, 10.53763810103309, 9.701119769545768, 8.761994171811107, 7.703292941112813, 6.712957582837343, 5.8252289662164, 4.878205845189238, 3.8802555905591527, 4.89169159076363, 5.769931183464902, 6.712231939896242, 7.717597582834629, 8.637559623533642, 16.491721006646173, 15.50223423984647, 14.463113698736928, 13.45146138437167, 12.493325981594023, 11.441999513700255, 10.557428110674234, 9.547888109464338, 8.63289080525744, 7.70473962277841, 6.753764046384833, 5.743893378727557, 4.76378454540027, 3.9235856401537204, 2.939047921857413, 3.841250890901155, 4.770644489223482, 5.700280799704788, 6.6893260340317955, 7.624000462597661, 15.514446310468568, 14.491455150980908, 13.554301837736666, 12.5474820476365, 11.492804892218778, 10.489955075054732, 9.547001897779948, 8.60810659059225, 7.671065317343314, 6.735298733935344, 5.773652313003976, 4.790730556775431, 3.8031217394951478, 2.8975703500046808, 1.9281905606676473, 2.908069309755681, 3.8692489158160055, 4.83273445685371, 5.781759552143676, 6.718860418554864, 14.858356571604556, 13.832776615672264, 12.803685502424493, 11.81403377365435, 10.73922553525297, 9.823923758368078, 8.82185119527725, 7.797404435219696, 6.757092724244241, 5.778487615392505, 4.941987993177237, 3.8986280133279214, 2.8744187682010054, 1.898698271100181, 0.9450786608799803, 1.9340776798049824, 2.949120416388838, 3.9294280088978804, 4.943616943612088, 6.011335540652292], [6.037062499236741, 5.021678799869791, 4.030596422103621, 2.9710508373189213, 2.0315334557210867, 0.9810752977173537, 0.0, 0.9660014916719055, 1.9852309819205083, 2.923945734572221, 3.8526852090961694, 4.810117271855277, 5.883061748008828, 6.892919219572003, 7.82574058794956, 8.817422880401892, 9.868836335088979, 10.83156481854241, 11.891410872954598, 12.959226884662877, 6.749670709386059, 5.819614266199599, 4.846973686707261, 3.906627876445187, 2.9242456647032986, 1.9212746239712823, 0.9547763748870604, 1.996197433645607, 2.924994931267075, 3.8507828111611198, 4.850930570430822, 5.745000740281829, 6.693195088228144, 7.698250087682573, 8.648896222315663, 9.6276224352325, 10.667558903403737, 11.698460656747255, 12.67776407441787, 13.693498581887518, 7.7532404908662205, 6.752645859670869, 5.856078482107212, 4.8556870721292285, 3.8582951321985437, 2.8870961976737863, 1.917068382510109, 2.9427669481109877, 3.901585184670878, 4.899454598020145, 5.9077928400456186, 6.691380632312644, 7.723149812403098, 8.692417453781456, 9.623325840103538, 10.658049205801262, 11.638608450167563, 12.642518433433576, 13.582030890615743, 14.603524110709154, 8.756156091660154, 7.710400210565056, 6.764881725910363, 5.712479721468773, 4.783328516749149, 3.8133933750677294, 2.8570034277042584, 3.886636999728574, 4.8704449704114685, 5.856573271748398, 6.813954343129776, 7.742608422415445, 8.70871599532186, 9.634753491542053, 10.607256919704389, 11.577917925564702, 12.630602911714723, 13.618469799200545, 14.510514973692045, 15.450480834120102, 9.710074738323957, 8.660876010988687, 7.68303693190288, 6.619517494416527, 5.6888223607171815, 4.7616397983909025, 3.8319619088173837, 4.870801193636595, 5.824656821765556, 6.798126364291305, 7.78661675628439, 8.678155382263759, 9.64467211448857, 10.585405976071035, 11.579999242424586, 12.543836101700812, 13.575629978887365, 14.550213364335722, 15.552889348675146, 16.401754253662673, 10.627023887081327, 9.60894885616165, 8.57151699235674, 7.568999271418306, 6.666369792291025, 5.761483989305256, 4.793677259195611, 5.826067805556921, 6.762825276747371, 7.765396095912446, 8.728404848577231, 9.672599927509049, 10.609715906541593, 11.586619528457266, 12.56297963976675, 13.506137686041638, 14.564985487862739, 15.586227803181956, 16.554018972227908, 17.459310990295602, 11.499986601200456, 10.560029741591652, 9.588835726872958, 8.57728687861713, 7.632309268079135, 6.728730314296855, 5.7704659150249356, 6.821747053579372, 7.791353375379552, 8.751569564399206, 9.724481078919263, 10.617988541563589, 11.554678020525394, 12.578969567067704, 13.510278087252159, 14.562980912679844, 15.58664266283671, 16.529469003211567, 17.534138501131785, 18.429024280021647, 12.430615233180816, 11.55710991998886, 10.614287821666235, 9.586246831739336, 8.66553543111472, 7.770467573626082, 6.832385749856945, 7.7785600064462646, 8.736844074882335, 9.746205853262762, 10.755956017064582, 11.599296547752088, 12.539941385369465, 12.837973628719794, 13.822923009787333, 14.712419775506627, 15.640327463227377, 16.621824596453266, 17.49969322993505, 18.18670726236154, 13.363033845573213, 12.493882877702417, 11.513868153016169, 10.547017225790201, 9.591359089530647, 8.807038402390122, 7.812385873449371, 8.747909778284802, 9.728178445852487, 10.737600932286137, 11.75551474912026, 12.62542141209401, 12.800191148875719, 11.873690370353284, 12.828431025362864, 13.734615884978561, 14.615414189425016, 15.554983783080914, 16.437088399081276, 17.218666534562832, 14.416775781407544, 13.461952546460692, 12.461330644807054, 11.47919997108675, 10.53633064041449, 9.752761057181191, 8.816471933371622, 9.702451305131563, 10.674562986322728, 11.604400821543937, 12.67011036626691, 12.546740724513313, 11.802218872870592, 10.88092066108893, 11.808633845209581, 12.736260814718788, 13.640924207382845, 14.621685881538188, 15.484533865540739, 16.224656595075917, 15.353508310319215, 14.406760716332862, 13.498167307675704, 12.518601443362316, 11.579508339531554, 10.820630837491871, 9.84924170072941, 10.758632422002883, 11.72858501732639, 12.605978919654397, 12.589206852643933, 11.58158023674706, 10.756089438671443, 9.946132252079993, 10.771942676170903, 11.706232332632808, 12.62038263478807, 13.638007121790682, 14.559163431729225, 15.278811929812443, 16.285005920597012, 15.416613269902557, 14.554301216587326, 13.57505433060443, 12.602523833099337, 11.866829371797326, 10.851229993142443, 11.690004057477825, 12.761171908603666, 12.503382892636306, 11.563872969638583, 10.62736144124031, 9.748090752885659, 8.975458792453614, 9.73116608841237, 10.685175630493465, 11.666839599985819, 12.581466210465823, 13.520417153750401, 14.30800402567924, 17.351320971230578, 16.452811703387464, 15.482102401007056, 14.547990636584679, 13.574150663451888, 12.81705726448045, 11.90257247806486, 12.68477534047757, 12.495760717242945, 11.479982562910562, 10.547180685250323, 9.602875383358446, 8.822872629543106, 7.986973805471255, 8.767778684993266, 9.729481466456704, 10.665166253639683, 11.56849850833461, 12.502916763167704, 13.382646043268048, 18.403693652471468, 17.503063053152825, 16.46726103570775, 15.480589245356668, 14.584880855816753, 13.774382423933286, 12.84784068648704, 12.519695615212237, 11.570460511197062, 10.629688504258818, 9.579286662968293, 8.651441713550653, 7.875558500989943, 7.053733829875401, 7.812198411964564, 8.804399409268553, 9.718407880647597, 10.623452164091553, 11.567674722027814, 12.46571223669729, 18.265294904872295, 17.456677034911785, 16.41604026235609, 15.41922644797699, 14.469736317958287, 13.460986850659502, 12.503608274580824, 11.51858744360672, 10.688066530547173, 9.736535036950828, 8.72312184600484, 7.679772970535686, 6.905054122099803, 6.003067190457228, 6.826685976740862, 7.750955869829184, 8.78718656965528, 9.691580514214126, 10.64102853650393, 11.57332879846251, 17.28502851099518, 16.40716087703693, 15.345146836824531, 14.460562499476916, 13.45312719336587, 12.483281325215424, 11.502508323913311, 10.553498922161772, 9.712356498196144, 8.712425749851644, 7.661261809577862, 6.699397837676623, 5.854778412693861, 4.9581389756011465, 5.8602129963375145, 6.817907637833569, 7.772898590241635, 8.676957016043293, 9.742018064828274, 10.643314482996477, 16.344227968692273, 15.379795993780057, 14.411839874424336, 13.487552430486677, 12.554600968017942, 11.511577833114528, 10.508328949061934, 9.556562803315735, 8.720044471828412, 7.780918874093752, 6.722217643395459, 5.7318822851199895, 4.844153668499047, 3.9383281393164395, 4.847617105126755, 5.859053105331232, 6.737292698032505, 7.679593454463845, 8.684959097402231, 9.604921138101245, 15.51064570892882, 14.521158942129116, 13.482038401019572, 12.470386086654315, 11.512250683876667, 10.4609242159829, 9.576352812956879, 8.566812811746983, 7.651815507540084, 6.723664325061055, 5.77268874866748, 4.762818081010203, 3.7827092476829165, 2.9837079342809214, 3.9064094364250153, 4.808612405468757, 5.738006003791085, 6.667642314272391, 7.656687548599399, 8.591361977165263, 14.533371012751214, 13.510379853263554, 12.573226540019313, 11.566406749919146, 10.511729594501423, 9.508879777337377, 8.565926600062593, 7.627031292874895, 6.689990019625959, 5.754223436217989, 4.792577015286622, 3.8096552590580774, 2.8220464417777937, 1.957692644131882, 2.89555207523525, 3.8754308243232836, 4.836610430383608, 5.800095971421313, 6.749121066711279, 7.6999357162722175, 13.877281273887201, 12.851701317954909, 11.822610204707138, 10.832958475936994, 9.758150237535615, 8.842848460650725, 7.840775897559896, 6.8163291375023425, 5.776017426526886, 4.797412317675151, 3.960912695459882, 2.9175527156105674, 1.8933434704836514, 0.9588205652273821, 1.9124401754475828, 2.901439194372585, 3.91648193095644, 4.896789523465483, 5.91097845817969, 6.978697055219893], [7.003063990908647, 5.987680291541697, 4.996597913775526, 3.937052328990827, 2.9975349473929924, 1.9470767893892593, 0.9660014916719055, 0.0, 1.0192294902486028, 1.9579442429003158, 2.886683717424264, 3.8441157801833716, 4.917060256336923, 5.926917727900098, 6.8597390962776545, 7.851421388729988, 8.902834843417075, 9.865563326870506, 10.925409381282694, 11.993225392990974, 7.715672201057965, 6.785615757871504, 5.812975178379166, 4.872629368117092, 3.890247156375204, 2.887276115643188, 1.9207778665589659, 1.069203198290647, 1.9589934395951694, 2.8847813194892145, 3.8849290787589164, 4.7789992486099235, 5.727193596556239, 6.732248596010668, 7.682894730643758, 8.661620943560594, 9.701557411731832, 10.732459165075348, 11.711762582745964, 12.72749709021561, 8.719241982538126, 7.718647351342774, 6.822079973779118, 5.821688563801135, 4.82429662387045, 3.853097689345692, 2.8830698741820147, 2.0157727127560277, 2.974590949315918, 3.9334531063482396, 4.941791348373713, 5.725379140640738, 6.757148320731193, 7.72641596210955, 8.657324348431633, 9.692047714129357, 10.672606958495658, 11.676516941761669, 12.616029398943835, 13.637522619037247, 9.722157583332057, 8.67640170223696, 7.730883217582269, 6.678481213140679, 5.7493300084210555, 4.7793948667396355, 3.8230049193761646, 3.017553342481829, 3.949816570068045, 4.935944871404975, 5.893325942786353, 6.776606930743539, 7.742714503649956, 8.668751999870148, 9.641255428032483, 10.611916433892796, 11.664601420042818, 12.652468307528638, 13.544513482020138, 14.484479342448195, 10.676076229995862, 9.626877502660593, 8.649038423574785, 7.585518986088434, 6.654823852389088, 5.727641290062809, 4.79796340048929, 4.056774216439533, 4.978322362698869, 5.94943622671678, 6.865988355940967, 7.712153890591853, 8.678670622816664, 9.61940448439913, 10.61399775075268, 11.577834610028907, 12.60962848721546, 13.584211872663815, 14.586887857003239, 15.435752761990765, 11.593025378753234, 10.574950347833557, 9.537518484028647, 8.535000763090213, 7.632371283962931, 6.727485480977163, 5.7596787508675185, 5.1164598194288065, 5.916490817680684, 6.916705958337921, 7.807776448233808, 8.723576729771965, 9.643714414869688, 10.620618036785363, 11.596978148094847, 12.540136194369735, 13.598983996190835, 14.620226311510049, 15.588017480556003, 16.493309498623695, 12.465988092872363, 11.52603123326356, 10.554837218544865, 9.543288370289037, 8.59831075975104, 7.694731805968762, 6.736467406696843, 6.125584651010255, 6.958769379713294, 7.902879426824683, 8.80385267857584, 9.668965343826505, 10.588676528853489, 11.612968075395798, 12.544276595580254, 13.596979421007939, 14.620641171164804, 15.56346751153966, 16.568137009459882, 17.46302278834974, 13.396616724852723, 12.523111411660768, 11.580289313338142, 10.552248323411243, 9.631536922786626, 8.736469065297989, 7.798387241528852, 7.082397603877148, 7.91171319047092, 8.897515715688238, 9.870000777830066, 10.650273350015004, 11.57393989369756, 12.512144528472673, 13.51784526154809, 14.537628445245264, 15.485048364564133, 16.469333955119406, 17.42457978016503, 18.434125746230325, 14.32903533724512, 13.459884369374324, 12.479869644688076, 11.513018717462108, 10.557360581202554, 9.773039894062029, 8.778387365121278, 8.055759072141441, 8.913821440124291, 9.888910794711613, 10.889839064654192, 11.676398214356926, 11.879162073275339, 12.671374006669213, 13.626114661678793, 14.553564547732377, 15.487578359146628, 16.441065524049915, 17.34736506762174, 18.18466802623474, 15.382777273079451, 14.427954038132599, 13.427332136478961, 12.445201462758657, 11.502332132086398, 10.718762548853096, 9.782473425043527, 9.010300598988202, 9.860205980594532, 10.790043815815741, 11.855753360538714, 11.580739232841406, 10.836217381198686, 11.67860429740486, 12.675734404024015, 13.603361373533222, 14.527005948351846, 15.507767622507188, 16.394810534081206, 17.190658086747824, 16.31950980199112, 15.372762208004769, 14.464168799347611, 13.484602935034223, 12.54550983120346, 11.786632329163776, 10.815243192401315, 10.066481715859522, 10.914228011598194, 11.791621913926202, 11.623205360972026, 10.615578745075153, 9.790087946999538, 10.743815888395922, 11.639043234985337, 12.573877785043994, 13.506464375757073, 14.548283790331148, 15.46944010026969, 16.24481342148435, 17.251007412268915, 16.382614761574462, 15.520302708259234, 14.541055822276338, 13.568525324771244, 12.832830863469232, 11.817231484814348, 10.997853351334467, 11.980262707488873, 11.5373814009644, 10.597871477966676, 9.661359949568403, 8.782089261213754, 9.773142428769543, 10.598266647226804, 11.55282108290465, 12.552921340954821, 13.491742879006289, 14.430693822290866, 15.274005517351148, 18.31732246290248, 17.418813195059368, 16.448103892678965, 15.513992128256586, 14.540152155123796, 13.783058756152355, 12.868573969736765, 11.992624634334211, 11.529759225571038, 10.513981071238655, 9.581179193578416, 8.63687389168654, 7.856871137871201, 8.784657441787184, 9.634879243807699, 10.59712691886789, 11.551247994608685, 12.478775176875075, 13.41319343170817, 14.348647534939955, 18.27884979528684, 17.47828828204021, 16.480312424561127, 15.460742293829009, 14.45589846067372, 13.434435201802, 12.480588928521971, 11.55369412354033, 10.604459019525155, 9.66368701258691, 8.613285171296386, 7.685440221878746, 6.909557009318037, 7.851417466191329, 8.679298970778998, 9.68709396701593, 10.6044896216166, 11.533728832632018, 12.477951390568279, 13.431713728369196, 17.29929341320039, 16.49067554323988, 15.450038770684188, 14.453224956305087, 13.503734826286383, 12.494985358987599, 11.53760678290892, 10.552585951934816, 9.722065038875268, 8.77053354527892, 7.757120354332932, 6.713771478863779, 5.939052630427898, 6.8007508267731565, 7.6937865355552955, 8.63365042757656, 9.673268310624282, 10.60185718275459, 11.551305205044395, 12.484101909867574, 16.319027019323276, 15.441159385365026, 14.379145345152628, 13.494561007805013, 12.487125701693966, 11.51727983354352, 10.536506832241407, 9.587497430489869, 8.746355006524238, 7.746424258179736, 6.695260317905955, 5.7333963460047155, 4.888776921021956, 5.755822611917075, 6.727313555151948, 7.700602195580945, 8.683175258782102, 9.587233684583758, 10.65229473336874, 11.553591151536946, 15.37822647702037, 14.413794502108153, 13.445838382752433, 12.521550938814773, 11.588599476346038, 10.545576341442622, 9.542327457390028, 8.590561311643832, 7.754042980156507, 6.8149173824218465, 5.756216151723553, 4.765880793448083, 3.8781521768271405, 4.736011775632368, 5.7147176639411885, 6.741747663078609, 7.647569366572972, 8.589870123004312, 9.595235765942698, 10.515197806641712, 14.544644217256916, 13.555157450457212, 12.516036909347669, 11.504384594982412, 10.546249192204764, 9.494922724310996, 8.610351321284973, 7.600811320075079, 6.6858140158681785, 5.7576628333891495, 4.806687256995573, 3.796816589338297, 2.8167077560110108, 3.78139157059685, 4.773509995239449, 5.718889074009224, 6.648282672331552, 7.577918982812858, 8.566964217139866, 9.50163864570573, 13.56736952107931, 12.54437836159165, 11.60722504834741, 10.600405258247243, 9.54572810282952, 8.542878285665473, 7.599925108390688, 6.661029801202989, 5.723988527954054, 4.788221944546084, 3.8265755236147165, 2.8436537673861717, 1.8560449501058882, 2.841781817486209, 3.8615535669071557, 4.841432315995189, 5.8026119220555135, 6.766097463093218, 7.715122558383184, 8.665937207944124, 12.911279782215297, 11.885699826283005, 10.856608713035234, 9.866956984265089, 8.79214874586371, 7.876846968978819, 6.87477440588799, 5.850327645830437, 4.810015934854981, 3.8314108260032453, 2.994911203787977, 1.951551223938662, 0.9273419788117458, 1.9248220568992878, 2.8784416671194886, 3.8674406860444908, 4.882483422628346, 5.862791015137389, 6.876979949851596, 7.9446985468918], [8.02229348115725, 7.0069097817903, 6.0158274040241295, 4.95628181923943, 4.016764437641595, 2.966306279637862, 1.9852309819205083, 1.0192294902486028, 0.0, 0.9387147526517129, 1.8674542271756611, 2.8248862899347684, 3.89783076608832, 4.907688237651495, 5.840509606029052, 6.832191898481385, 7.883605353168472, 8.846333836621904, 9.906179891034093, 10.973995902742372, 8.734901691306566, 7.804845248120107, 6.832204668627769, 5.891858858365695, 4.909476646623807, 3.9065056058917906, 2.940007356807569, 1.9546014617613277, 0.9397639493465666, 1.8655518292406117, 2.8656995885103136, 3.7597697583613203, 4.707964106307636, 5.713019105762065, 6.663665240395155, 7.642391453311992, 8.68232792148323, 9.713229674826746, 10.692533092497362, 11.708267599967009, 9.73847147278673, 8.737876841591378, 7.84130946402772, 6.8409180540497365, 5.843526114119052, 4.872327179594294, 3.9022993644306174, 2.9011709762267084, 1.9619413349022667, 2.914223616099637, 3.9225618581251105, 4.706149650392135, 5.737918830482589, 6.707186471860946, 7.63809485818303, 8.672818223880755, 9.653377468247056, 10.657287451513067, 11.596799908695234, 12.618293128788645, 10.741387073580661, 9.695631192485564, 8.750112707830873, 7.697710703389282, 6.768559498669658, 5.798624356988238, 4.842234409624767, 3.9029516059525102, 2.937166955654394, 3.9232952569913238, 4.880676328372702, 5.757377440494936, 6.723485013401352, 7.649522509621544, 8.62202593778388, 9.592686943644193, 10.645371929794214, 11.633238817280036, 12.525283991771536, 13.465249852199593, 11.695305720244466, 10.646106992909196, 9.668267913823389, 8.604748476337036, 7.6740533426376905, 6.746870780311411, 5.817192890737893, 4.919528376414179, 3.965672748285217, 4.936786612303129, 5.853338741527316, 6.69292440034325, 7.659441132568061, 8.600174994150526, 9.594768260504077, 10.558605119780303, 11.590398996966856, 12.564982382415213, 13.567658366754637, 14.416523271742163, 12.612254869001836, 11.594179838082159, 10.556747974277249, 9.554230253338815, 8.651600774211534, 7.746714971225765, 6.77890824111612, 5.965007388548591, 4.903841203267032, 5.90405634392427, 6.795126833820157, 7.704347239523361, 8.624484924621084, 9.601388546536757, 10.577748657846241, 11.52090670412113, 12.57975450594223, 13.600996821261447, 14.568787990307401, 15.474080008375092, 13.485217583120965, 12.545260723512161, 11.574066708793467, 10.562517860537639, 9.617540249999644, 8.713961296217363, 7.7556968969454445, 6.915726087099824, 5.946119765299644, 6.8902298124110315, 7.79120306416219, 8.649735853577901, 9.569447038604885, 10.593738585147195, 11.52504710533165, 12.577749930759335, 13.6014116809162, 14.544238021291056, 15.548907519211276, 16.443793298101138, 14.415846215101325, 13.54234090190937, 12.599518803586744, 11.571477813659845, 10.650766413035228, 9.755698555546589, 8.817616731777454, 7.8573476444933394, 6.899063576057269, 7.8848661012745875, 8.857351163416416, 9.6310438597664, 10.554710403448956, 11.49291503822407, 12.498615771299486, 13.51839895499666, 14.465818874315529, 15.450104464870805, 16.405350289916427, 17.414896255981724, 15.348264827493722, 14.479113859622926, 13.499099134936678, 12.53224820771071, 11.576590071451156, 10.792269384310629, 9.766233017593065, 8.830709112757635, 7.901171825710641, 8.876261180297963, 9.877189450240541, 10.657168724108322, 11.591640183903182, 12.45719829659058, 13.41193895160016, 14.339388837653743, 15.273402649067995, 16.238998915140048, 17.28418935760201, 18.324895814665847, 16.402006763328053, 15.447183528381201, 14.446561626727563, 13.464430953007259, 12.521561622335, 11.706608201324883, 10.770319077515314, 9.785250639604396, 8.847556366180882, 9.77739420140209, 10.843103746125063, 10.791455427700006, 11.780597897286398, 12.639924404144455, 13.641344742273748, 14.568971711782956, 15.546235438600451, 16.526997112755794, 17.414040024329807, 18.209887576996426, 17.338739292239723, 16.39199169825337, 15.483398289596213, 14.503832425282825, 13.564739321452063, 12.774477981635563, 11.800716270234973, 10.841431756475716, 9.901578397184544, 10.778972299512551, 10.810244898499827, 9.826294939933753, 10.73446846308725, 11.705135995135517, 12.65827272523394, 13.593107275292597, 14.525693866005676, 15.56751328057975, 16.488669590518292, 17.26404291173295, 18.270236902517517, 17.401844251823064, 16.539532198507835, 15.56028531252494, 14.587754815019846, 13.81830394130289, 12.802704562648007, 11.77280339195066, 10.967613093075222, 10.7244209384922, 9.784911015494476, 8.872076144427004, 9.726469777301466, 10.734462535509138, 11.617496137475408, 12.572050573153254, 13.572150831203425, 14.51097236925489, 15.449923312539468, 16.293235007599748, 18.311992986279122, 17.353968836802178, 16.308223176774774, 15.374111412352397, 14.335873549065923, 13.372530871006234, 12.406627646695549, 11.556367428345364, 10.716798763098838, 9.701020608766456, 8.768218731106217, 7.84759008654514, 8.801251653958913, 9.755461085285573, 10.654108734056303, 11.616356409116493, 12.570477484857289, 13.498004667123677, 14.432422921956771, 15.367877025188557, 17.259620305038236, 16.45905879179161, 15.461082934312525, 14.441512803580407, 13.436668970425119, 12.415205711553398, 11.46135943827337, 10.5591999593815, 9.730352403922202, 8.800575928420924, 7.800324708824187, 6.896156416737346, 7.853937525405749, 8.870646956439932, 9.698528461027601, 10.706323457264533, 11.623719111865203, 12.55295832288062, 13.497180880816881, 14.450943218617798, 16.28006392295179, 15.471446052991277, 14.430809280435586, 13.433995466056485, 12.484505336037781, 11.475755868738997, 10.518377292660318, 9.533356461686214, 8.702835548626666, 7.870615947527787, 6.871049179822479, 5.924487673722379, 6.8834331465156104, 7.819980317021759, 8.713016025803899, 9.652879917825164, 10.692497800872886, 11.621086673003193, 12.570534695292997, 13.503331400116176, 15.299797529074672, 14.421929895116424, 13.359915854904026, 12.47533151755641, 11.467896211445364, 10.498050343294919, 9.517277341992806, 8.568267940241267, 7.7271255162756365, 6.846506660428602, 5.809189143395502, 4.9441125408633155, 5.9080064112705575, 6.775052102165677, 7.746543045400551, 8.719831685829549, 9.702404749030704, 10.60646317483236, 11.671524223617341, 12.572820641785544, 14.358996986771768, 13.394565011859552, 12.42660889250383, 11.502321448566171, 10.569369986097437, 9.52634685119402, 8.523097967141426, 7.57133182139523, 6.734813489907905, 5.795687892173245, 4.862645561682055, 3.9765969883066834, 4.897381667075743, 5.75524126588097, 6.733947154189791, 7.760977153327212, 8.666798856821574, 9.609099613252914, 10.6144652561913, 11.534427296890312, 13.525414727008314, 12.53592796020861, 11.496807419099067, 10.48515510473381, 9.527019701956162, 8.475693234062392, 7.5911218310363715, 6.581581829826477, 5.666584525619577, 4.738433343140548, 3.9108312305534856, 3.007532784196897, 3.8359372462596135, 4.800621060845453, 5.792739485488052, 6.738118564257827, 7.667512162580154, 8.59714847306146, 9.586193707388466, 10.52086813595433, 12.548140030830709, 11.525148871343049, 10.587995558098807, 9.58117576799864, 8.526498612580918, 7.523648795416871, 6.580695618142086, 5.6418003109543875, 4.704759037705451, 3.7689924542974813, 2.921999784290926, 2.0020290899067588, 2.8752744403544908, 3.8610113077348114, 4.880783057155758, 5.860661806243792, 6.821841412304116, 7.785326953341821, 8.734352048631788, 9.685166698192726, 11.892050291966695, 10.866470336034403, 9.837379222786632, 8.847727494016485, 7.772919255615107, 6.857617478730217, 5.8555449156393875, 4.831098155581834, 3.790786444606378, 2.8121813357546426, 1.975681713539374, 0.9323217336900592, 1.9465714690603486, 2.9440515471478905, 3.8976711573680913, 4.8866701762930935, 5.901712912876949, 6.8820205053859915, 7.896209440100199, 8.963928037140402], [8.961008233808963, 7.945624534442013, 6.954542156675842, 5.894996571891143, 4.955479190293309, 3.905021032289575, 2.9239457345722215, 1.9579442429003158, 0.9387147526517129, 0.0, 0.9287394745239482, 1.8861715372830554, 2.959116013436607, 3.9689734849997826, 4.901794853377339, 5.893477145829673, 6.94489060051676, 7.90761908397019, 8.96746513838238, 10.03528115009066, 9.67361644395828, 8.74356000077182, 7.770919421279482, 6.830573611017408, 5.848191399275519, 4.845220358543504, 3.878722109459282, 2.8933162144130407, 1.8784787019982794, 0.9268370765888987, 1.9269848358586008, 2.8210550057096073, 3.7692493536559226, 4.7743043531103515, 5.724950487743442, 6.703676700660278, 7.743613168831516, 8.774514922175033, 9.75381833984565, 10.769552847315296, 10.677186225438442, 9.67659159424309, 8.780024216679434, 7.77963280670145, 6.782240866770765, 5.811041932246008, 4.841014117082331, 3.8398857288784214, 2.9006560875539797, 1.9755088634479236, 2.983847105473398, 3.767434897740422, 4.799204077830876, 5.768471719209233, 6.699380105531317, 7.734103471229041, 8.714662715595342, 9.718572698861355, 10.658085156043521, 11.679578376136933, 11.680101826232374, 10.634345945137277, 9.688827460482585, 8.636425456040994, 7.707274251321372, 6.737339109639952, 5.780949162276481, 4.841666358604223, 3.875881708306107, 3.020456840717942, 3.97783791209932, 4.818662687843223, 5.78477026074964, 6.710807756969832, 7.683311185132168, 8.653972190992482, 9.706657177142503, 10.694524064628324, 11.586569239119823, 12.52653509954788, 12.63402047289618, 11.58482174556091, 10.606982666475103, 9.54346322898875, 8.612768095289404, 7.685585532963125, 6.755907643389606, 5.858243129065891, 4.90438750093693, 4.033948196029748, 4.950500325253934, 5.754209647691537, 6.720726379916348, 7.661460241498815, 8.656053507852365, 9.61989036712859, 10.651684244315144, 11.6262676297635, 12.628943614102925, 13.47780851909045, 13.55096962165355, 12.532894590733873, 11.495462726928963, 10.49294500599053, 9.590315526863249, 8.68542972387748, 7.717622993767835, 6.903722141200305, 5.842555955918746, 5.001217927650889, 5.892288417546775, 6.765632486871649, 7.685770171969371, 8.662673793885046, 9.63903390519453, 10.582191951469419, 11.641039753290519, 12.662282068609734, 13.630073237655688, 14.535365255723379, 14.42393233577268, 13.483975476163875, 12.512781461445181, 11.501232613189353, 10.556255002651358, 9.652676048869079, 8.694411649597159, 7.854440839751536, 6.884834517951356, 5.98739139613765, 6.888364647888807, 7.711021100926189, 8.630732285953172, 9.655023832495482, 10.586332352679937, 11.639035178107623, 12.662696928264488, 13.605523268639343, 14.610192766559564, 15.505078545449425, 15.35456096775304, 14.481055654561084, 13.538233556238458, 12.51019256631156, 11.589481165686944, 10.694413308198305, 9.756331484429168, 8.796062397145052, 7.837778328708982, 6.982027685001206, 7.954512747143033, 8.692329107114688, 9.615995650797243, 10.554200285572357, 11.559901018647773, 12.579684202344948, 13.527104121663816, 14.511389712219092, 15.466635537264713, 16.476181503330007, 16.286979580145438, 15.417828612274642, 14.437813887588394, 13.470962960362426, 12.515304824102872, 11.730984136962345, 10.704947770244777, 9.769423865409347, 8.839886578362353, 7.9734227640245825, 8.974351033967158, 9.71845397145661, 10.65292543125147, 11.518483543938867, 12.473224198948447, 13.40067408500203, 14.334687896416282, 15.300284162488337, 16.3454746049503, 17.38618106201414, 17.34072151597977, 16.38589828103292, 15.38527637937928, 14.403145705658975, 13.460276374986716, 12.645322953976596, 11.709033830167026, 10.723965392256108, 9.786271118832595, 8.968110548911872, 10.027205985380098, 10.72212506581382, 11.695870123328122, 12.51125325320322, 13.510486527675884, 14.399029155261804, 15.309177878458453, 16.233582064031065, 17.298029138490836, 18.328662701629035, 18.277454044891442, 17.33070645090509, 16.42211304224793, 15.442547177934541, 14.503454074103779, 13.713192734287276, 12.739431022886686, 11.780146509127428, 10.840293149836256, 9.969688647022332, 9.871530145848114, 10.714520761715466, 11.622694284868963, 12.59336181691723, 13.585733748427312, 14.53182202794431, 15.464408618657389, 16.506228033231466, 17.427384343170008, 18.202757664384666, 18.40002223999584, 17.33172208912998, 16.337994063557247, 15.395527721858253, 14.368785626766762, 13.384044011037645, 12.519255378966253, 11.612423958693396, 10.73534652393251, 9.785706185840485, 8.846196262842764, 9.760301966208717, 10.614695599083179, 11.622688357290851, 12.55621089012712, 13.510765325804966, 14.510865583855137, 15.449687121906607, 16.388638065191184, 17.231949760251464, 17.37327823362741, 16.415254084150465, 15.369508424123062, 14.435396659700684, 13.39715879641421, 12.433816118354521, 11.467912894043836, 10.617652675693652, 9.778084010447124, 8.762305856114741, 7.829503978454503, 8.735815908326853, 9.689477475740626, 10.643686907067286, 11.592823486708015, 12.555071161768206, 13.509192237509001, 14.436719419775393, 15.371137674608487, 16.30659177784027, 16.32090555238652, 15.520344039139893, 14.522368181660813, 13.502798050928694, 12.497954217773406, 11.476490958901685, 10.522644685621657, 9.620485206729787, 8.79163765127049, 7.86186117576921, 6.861609956172474, 7.7843822385190595, 8.742163347187462, 9.779370882054074, 10.637243213679314, 11.645038209916246, 12.562433864516915, 13.491673075532336, 14.435895633468597, 15.389657971269513, 15.341349170300074, 14.532731300339563, 13.492094527783872, 12.495280713404771, 11.545790583386069, 10.537041116087284, 9.579662540008606, 8.594641709034502, 7.764120795974954, 6.9319011948760725, 5.932334427170766, 6.812713495504092, 7.771658968297324, 8.728704242635901, 9.651730778455612, 10.591594670476876, 11.631212553524598, 12.559801425654909, 13.509249447944713, 14.442046152767892, 14.361082776422958, 13.48321514246471, 12.421201102252311, 11.536616764904696, 10.529181458793651, 9.559335590643206, 8.578562589341093, 7.629553187589554, 6.788410763623924, 5.907791907776888, 4.870474390743789, 5.832338362645029, 6.846721163922272, 7.713766854817391, 8.685257798052264, 9.658546438481261, 10.641119501682418, 11.545177927484076, 12.610238976269057, 13.51153539443726, 13.420282234120053, 12.455850259207837, 11.487894139852116, 10.563606695914457, 9.630655233445722, 8.587632098542308, 7.584383214489714, 6.632617068743516, 5.796098737256193, 4.856973139521531, 3.923930809030342, 4.9142661673058115, 5.836096419727457, 6.693956018532684, 7.672661906841505, 8.699691905978925, 9.605513609473288, 10.547814365904628, 11.553180008843015, 12.473142049542027, 12.586699974356598, 11.597213207556894, 10.558092666447353, 9.546440352082096, 8.588304949304447, 7.53697848141068, 6.652407078384659, 5.642867077174763, 4.727869772967863, 3.799718590488834, 2.9721164779017726, 3.9462475368486096, 4.7746519989113265, 5.739335813497166, 6.731454238139765, 7.676833316909541, 8.606226915231868, 9.535863225713173, 10.52490846004018, 11.459582888606045, 11.609425278178993, 10.586434118691333, 9.649280805447091, 8.642461015346925, 7.587783859929203, 6.584934042765157, 5.641980865490373, 4.703085558302674, 3.7660442850537383, 2.8302777016457683, 1.983285031639213, 2.9407438425584713, 3.813989193006204, 4.799726060386525, 5.819497809807471, 6.7993765588955055, 7.76055616495583, 8.724041705993534, 9.6730668012835, 10.62388145084444, 10.953335539314983, 9.927755583382691, 8.89866447013492, 7.909012741364774, 6.834204502963394, 5.918902726078504, 4.916830162987675, 3.8923834029301214, 2.8520716919546656, 1.8734665831029296, 1.0369669608876613, 1.871036486341772, 2.885286221712062, 3.8827662997996035, 4.836385910019804, 5.825384928944807, 6.840427665528662, 7.820735258037705, 8.834924192751911, 9.902642789792115], [9.88974770833291, 8.87436400896596, 7.8832816311997895, 6.823736046415091, 5.884218664817256, 4.8337605068135225, 3.852685209096169, 2.8866837174242637, 1.8674542271756611, 0.9287394745239482, 0.0, 0.9574320627591073, 2.030376538912659, 3.0402340104758343, 3.973055378853391, 4.964737671305724, 6.0161511259928115, 6.978879609446242, 8.038725663858433, 9.106541675566712, 10.602355918482228, 9.672299475295768, 8.699658895803429, 7.759313085541355, 6.776930873799467, 5.773959833067451, 4.80746158398323, 3.822055688936989, 2.8072181765222277, 1.855576551112847, 1.0698848290455376, 1.8923155311856594, 2.8405098791319747, 3.845564878586404, 4.796211013219494, 5.7749372261363305, 6.814873694307568, 7.845775447651085, 8.8250788653217, 9.840813372791347, 11.60592569996239, 10.605331068767038, 9.708763691203382, 8.708372281225397, 7.710980341294713, 6.739781406769955, 5.769753591606278, 4.76862520340237, 3.829395562077928, 2.9042483379718718, 2.126747098660335, 2.8386954232164743, 3.870464603306929, 4.839732244685286, 5.770640631007369, 6.805363996705093, 7.785923241071394, 8.789833224337407, 9.729345681519574, 10.750838901612985, 12.608841300756321, 11.563085419661224, 10.617566935006533, 9.565164930564942, 8.636013725845318, 7.666078584163899, 6.709688636800428, 5.770405833128171, 4.804621182830055, 3.94919631524189, 3.192997121718384, 3.8899232133192756, 4.856030786225692, 5.782068282445884, 6.754571710608221, 7.725232716468534, 8.777917702618556, 9.765784590104376, 10.657829764595876, 11.597795625023933, 13.562759947420128, 12.513561220084858, 11.53572214099905, 10.472202703512698, 9.541507569813351, 8.614325007487071, 7.684647117913554, 6.7869826035898395, 5.833126975460878, 4.962687670553695, 4.165659534872998, 4.82547017316759, 5.791986905392401, 6.732720766974867, 7.727314033328418, 8.691150892604645, 9.722944769791198, 10.697528155239553, 11.700204139578977, 12.549069044566503, 14.479709096177498, 13.46163406525782, 12.42420220145291, 11.421684480514477, 10.519055001387196, 9.614169198401427, 8.646362468291782, 7.832461615724252, 6.771295430442693, 5.9299574021748365, 5.107447627165839, 5.836893012347701, 6.7570306974454235, 7.733934319361099, 8.710294430670583, 9.653452476945471, 10.712300278766572, 11.733542594085787, 12.701333763131741, 13.606625781199432, 15.352671810296627, 14.412714950687823, 13.441520935969129, 12.4299720877133, 11.484994477175306, 10.581415523393026, 9.623151124121106, 8.783180314275484, 7.813573992475304, 6.916130870661598, 6.103523857507872, 6.782281626402241, 7.701992811429225, 8.726284357971535, 9.65759287815599, 10.710295703583675, 11.73395745374054, 12.676783794115396, 13.681453292035616, 14.576339070925478, 16.28330044227699, 15.409795129085031, 14.466973030762405, 13.438932040835507, 12.518220640210892, 11.623152782722252, 10.685070958953116, 9.724801871669, 8.76651780323293, 7.910767159525154, 7.169671956762098, 7.763589632590741, 8.687256176273296, 9.62546081104841, 10.631161544123826, 11.650944727821, 12.598364647139869, 13.582650237695145, 14.537896062740765, 15.54744202880606, 17.215719054669385, 16.346568086798587, 15.366553362112342, 14.399702434886374, 13.44404429862682, 12.659723611486292, 11.633687244768725, 10.698163339933295, 9.768626052886301, 8.902162238548529, 8.189510243586223, 8.789714496932664, 9.724185956727522, 10.58974406941492, 11.5444847244245, 12.471934610478083, 13.405948421892335, 14.37154468796439, 15.416735130426353, 16.45744158749019, 18.269460990503717, 17.314637755556866, 16.31401585390323, 15.331885180182923, 14.389015849510663, 13.574062428500543, 12.637773304690974, 11.652704866780056, 10.715010593356542, 9.896850023435817, 9.242365194999163, 9.793385591289875, 10.767130648804175, 11.582513778679273, 12.581747053151936, 13.470289680737856, 14.380438403934505, 15.304842589507116, 16.36928966396689, 17.399923227105088, 18.354208225432235, 17.412835168175725, 16.465388497944918, 15.463595745842738, 14.437555907875929, 13.50919044154611, 12.574340633403647, 11.61505611964439, 10.955615255171624, 9.945088206645693, 10.230299721715264, 10.758546079056128, 11.751066933812929, 12.51730218768821, 13.509674119198293, 14.459417868367073, 15.400979976529278, 16.365327585964202, 17.294660097778404, 18.29607058953274, 17.47128276547189, 16.40298261460603, 15.409254589033297, 14.466788247334305, 13.440046152242815, 12.455304536513697, 11.590515904442306, 10.683684484169447, 9.889580559280946, 8.959512109670055, 9.70981940685828, 10.623925110224233, 11.478318743098695, 12.486311501306368, 13.432604685907002, 14.387159121584848, 15.388668815869751, 16.378426596430554, 17.31737753971513, 18.16068923477541, 16.44453875910346, 15.486514609626518, 14.440768949599114, 13.506657185176737, 12.468419321890263, 11.505076643830574, 10.539173419519889, 9.688913201169703, 8.93231804579556, 7.936111779944311, 8.69312712247002, 9.599439052342369, 10.553100619756142, 11.507310051082802, 12.469217282487897, 13.431464957548087, 14.403419801874255, 15.36545889429934, 16.299877149132435, 17.23533125236422, 15.392166077862573, 14.591604564615945, 13.593628707136865, 12.574058576404747, 11.569214743249459, 10.547751484377738, 9.59390521109771, 8.691745732205838, 7.862898176746541, 6.933121701245263, 7.725233100187991, 8.648005382534576, 9.605786491202979, 10.64299402606959, 11.513637009459195, 12.5392657742815, 13.45666142888217, 14.420412550056284, 15.364635107992545, 16.318397445793458, 14.412609695776126, 13.603991825815616, 12.563355053259924, 11.566541238880824, 10.61705110886212, 9.608301641563337, 8.650923065484658, 7.665902234510552, 6.835381321451004, 6.003161720352125, 6.795957571186283, 7.676336639519609, 8.63528211231284, 9.592327386651418, 10.528124574235493, 11.48582223484213, 12.525440117889852, 13.488540900178856, 14.43798892246866, 15.37078562729184, 13.43234330189901, 12.554475667940762, 11.492461627728364, 10.607877290380749, 9.600441984269702, 8.630596116119257, 7.649823114817145, 6.700813713065606, 5.859671289099975, 4.9790524332529404, 5.7340975347593055, 6.695961506660545, 7.730324068094161, 8.642506329341337, 9.613997272576212, 10.587285913005209, 11.569858976206365, 12.473917402008023, 13.538978450793005, 14.440274868961207, 12.491542759596106, 11.52711078468389, 10.559154665328169, 9.63486722139051, 8.701915758921775, 7.658892624018359, 6.655643739965765, 5.703877594219568, 4.8673592627322435, 3.928233664997583, 4.787553953045859, 5.777889311321329, 6.752234042763628, 7.622695493056631, 8.601401381365452, 9.628431380502873, 10.534253083997235, 11.476553840428576, 12.481919483366962, 13.401881524065974, 11.657960499832653, 10.668473733032949, 9.629353191923405, 8.617700877558148, 7.6595654747805, 6.608239006886731, 5.72366760386071, 4.714127602650815, 3.799130298443915, 2.870979115964886, 3.8357396219172895, 4.835333626173413, 5.703391473435274, 6.668075288021114, 7.6601937126637125, 8.605572791433488, 9.534966389755816, 10.464602700237121, 11.453647934564128, 12.388322363129992, 10.680685803655047, 9.657694644167387, 8.720541330923146, 7.713721540822978, 6.659044385405256, 5.656194568241209, 4.713241390966425, 3.7743460837787257, 2.83730481052979, 1.90153822712182, 2.84690817565473, 3.8298299318832747, 4.742728667530152, 5.728465534910472, 6.74823728433142, 7.728116033419453, 8.689295639479777, 9.652781180517481, 10.601806275807448, 11.552620925368387, 10.024596064791034, 8.999016108858742, 7.96992499561097, 6.980273266840825, 5.905465028439446, 4.990163251554556, 3.9880906884637266, 2.9636439284061735, 1.9233322174307173, 0.9447271085789813, 1.9005901049031781, 2.7997759608657202, 3.8140256962360093, 4.811505774323551, 5.765125384543753, 6.754124403468754, 7.76916714005261, 8.749474732561652, 9.763663667275859, 10.831382264316062], [10.847179771092017, 9.831796071725067, 8.840713693958897, 7.781168109174198, 6.841650727576363, 5.7911925695726305, 4.810117271855277, 3.844115780183371, 2.8248862899347684, 1.8861715372830554, 0.9574320627591073, 0.0, 1.0729444761535514, 2.082801947716727, 3.015623316094284, 4.007305608546617, 5.0587190632337045, 6.021447546687135, 7.081293601099325, 8.149109612807605, 11.559787981241337, 10.629731538054877, 9.657090958562538, 8.716745148300463, 7.7343629365585755, 6.731391895826559, 5.764893646742337, 4.779487751696096, 3.764650239281335, 2.813008613871954, 1.927522931177219, 0.934883468426552, 1.8830778163728674, 2.8881328158272965, 3.8387789504603873, 4.8175051633772235, 5.857441631548461, 6.888343384891978, 7.867646802562593, 8.88338131003224, 12.563357762721498, 11.562763131526147, 10.66619575396249, 9.665804343984506, 8.668412404053822, 7.697213469529063, 6.727185654365385, 5.726057266161477, 4.786827624837035, 3.861680400730979, 2.9184521825610155, 1.8812633604573668, 2.913032540547821, 3.882300181926178, 4.813208568248262, 5.847931933945986, 6.828491178312287, 7.8324011615783, 8.771913618760466, 9.793406838853878, 13.56627336351543, 12.520517482420333, 11.57499899776564, 10.522596993324049, 9.593445788604425, 8.623510646923005, 7.667120699559535, 6.727837895887278, 5.762053245589162, 4.906628378000997, 3.96013194367554, 2.9324911505601676, 3.898598723466584, 4.824636219686775, 5.797139647849112, 6.7678006537094255, 7.820485639859448, 8.808352527345269, 9.700397701836769, 10.640363562264826, 14.520192010179235, 13.470993282843965, 12.493154203758158, 11.429634766271805, 10.498939632572458, 9.571757070246179, 8.64207918067266, 7.744414666348947, 6.790559038219985, 5.920119733312802, 4.871321303897137, 3.8680381104084818, 4.834554842633292, 5.775288704215758, 6.769881970569309, 7.733718829845535, 8.765512707032089, 9.740096092480446, 10.74277207681987, 11.591636981807396, 15.437141158936605, 14.419066128016928, 13.381634264212018, 12.379116543273584, 11.476487064146303, 10.571601261160533, 9.603794531050887, 8.78989367848336, 7.7287274932018, 6.816984399629898, 5.813109396189978, 4.8794609495885926, 5.799598634686315, 6.77650225660199, 7.752862367911474, 8.696020414186362, 9.754868216007463, 10.77611053132668, 11.743901700372634, 12.649193718440324, 16.310103873055734, 15.37014701344693, 14.398952998728236, 13.387404150472408, 12.442426539934413, 11.538847586152132, 10.580583186880212, 9.74061237703459, 8.77100605523441, 7.803157868116659, 6.791246445724067, 5.8248495636431326, 6.744560748670116, 7.768852295212426, 8.700160815396881, 9.752863640824566, 10.776525390981432, 11.719351731356287, 12.724021229276508, 13.61890700816637, 17.240732505036096, 16.367227191844137, 15.424405093521512, 14.396364103594614, 13.475652702969999, 12.580584845481358, 11.642503021712221, 10.682233934428107, 9.723949865992036, 8.792104489851072, 7.782354326049251, 6.806157569831632, 7.729824113514186, 8.6680287482893, 9.673729481364717, 10.693512665061892, 11.64093258438076, 12.625218174936036, 13.580463999981657, 14.590009966046953, 18.173151117428493, 17.304000149557694, 16.32398542487145, 15.35713449764548, 14.401476361385926, 13.617155674245398, 12.591119307527832, 11.655595402692402, 10.726058115645408, 9.783499568874447, 8.802192612873377, 7.832282434173554, 8.766753893968414, 9.632312006655809, 10.587052661665389, 11.514502547718973, 12.448516359133224, 13.414112625205279, 14.459303067667243, 15.500009524731079, 18.36937137187461, 17.477148075658725, 16.537183868999566, 15.543107675276081, 14.600238344603822, 13.662904262181836, 12.726615138372267, 11.790741974126542, 11.158784979735076, 10.778187353761735, 9.781943717946332, 8.835953528530764, 9.809698586045066, 10.625081715920162, 11.624314990392826, 12.512857617978746, 13.423006341175395, 14.347410526748005, 15.411857601207778, 16.442491164345977, 17.396776162673124, 16.532339905786554, 15.58489323555575, 14.583100483453569, 13.557060645486759, 12.62869517915694, 11.69384537101448, 10.734560857255222, 10.104762948731414, 10.9025202694048, 10.769878244662433, 9.801114016297017, 10.793634871053818, 11.5598701249291, 12.552242056439182, 13.501985805607962, 14.443547913770168, 15.407895523205092, 16.337228035019294, 17.33863852677363, 16.556662555980704, 15.52248735221686, 14.528759326644128, 13.586292984945135, 12.559550889853645, 11.574809274124528, 10.710020642053136, 9.803189221780277, 9.038728252840736, 9.916944172429162, 10.667251469617387, 10.755332811803767, 11.786725021973623, 12.53054358455548, 13.493090165590424, 14.447714932225775, 15.39709094857242, 16.431455335524998, 17.375974312998117, 18.30944643090683, 15.520994245298242, 14.60601934723735, 13.560273687209945, 12.626161922787567, 11.587924059501093, 10.624581381441404, 9.65867815713072, 8.808417938780533, 8.08146573935535, 8.893543842703417, 9.650559185229127, 10.556871115101474, 11.51053268251525, 12.46474211384191, 13.426649345247004, 14.388897020307194, 15.360851864633362, 16.322890957058448, 17.257309211891542, 18.19276331512333, 14.511670815473403, 13.711109302226777, 12.713133444747694, 11.693563314015577, 10.68871948086029, 9.667256221988568, 8.71340994870854, 7.8112504698166685, 7.0120458703063315, 7.89055376400437, 8.682665162947098, 9.605437445293681, 10.563218553962086, 11.600426088828698, 12.471069072218302, 13.496697837040607, 14.414093491641276, 15.377844612815391, 16.32206717075165, 17.275829508552565, 13.532114433386957, 12.723496563426446, 11.682859790870754, 10.686045976491654, 9.736555846472951, 8.727806379174167, 7.7704278030954885, 6.7854069721213826, 5.984529015010795, 6.960593783111232, 7.75338963394539, 8.633768702278715, 9.592714175071947, 10.549759449410525, 11.4855566369946, 12.443254297601237, 13.48287218064896, 14.445972962937963, 15.395420985227767, 16.32821769005095, 12.55184803950984, 11.673980405551593, 10.611966365339194, 9.72738202799158, 8.719946721880534, 7.750100853730088, 6.769327852427975, 5.820318450676436, 5.008818982659765, 5.9364844960120475, 6.691529597518413, 7.653393569419652, 8.687756130853268, 9.599938392100446, 10.57142933533532, 11.544717975764318, 12.527291038965474, 13.43134946476713, 14.496410513552112, 15.397706931720315, 11.611047497206936, 10.64661552229472, 9.678659402939, 8.75437195900134, 7.821420496532605, 6.77839736162919, 5.775148477576596, 4.823382331830398, 4.016506956292034, 4.88566572775669, 5.744986015804966, 6.735321374080436, 7.709666105522735, 8.58012755581574, 9.558833444124561, 10.585863443261982, 11.491685146756344, 12.433985903187684, 13.43935154612607, 14.359313586825083, 10.777465237443483, 9.787978470643779, 8.748857929534235, 7.737205615168978, 6.77907021239133, 5.727743744497562, 4.843172341471541, 3.8336323402616457, 2.9482779920037046, 3.8284111787239934, 4.7931716846763965, 5.79276568893252, 6.660823536194382, 7.625507350780222, 8.617625775422821, 9.563004854192597, 10.492398452514925, 11.42203476299623, 12.411079997323236, 13.345754425889101, 9.800190541265877, 8.777199381778217, 7.840046068533975, 6.833226278433808, 5.778549123016086, 4.775699305852039, 3.832746128577255, 2.8938508213895564, 1.9568095481406207, 2.8589702898809275, 3.8043402384138374, 4.787261994642382, 5.70016073028926, 6.68589759766958, 7.705669347090527, 8.685548096178561, 9.646727702238886, 10.61021324327659, 11.559238338566557, 12.510052988127496, 9.067164002031927, 8.041584046099635, 7.012492932851863, 6.022841204081718, 4.948032965680339, 4.032731188795449, 3.0306586257046195, 2.006211865647066, 1.0292305735373763, 1.9021591713380888, 2.8580221676622855, 3.7572080236248278, 4.771457758995117, 5.768937837082659, 6.72255744730286, 7.7115564662278615, 8.726599202811716, 9.706906795320759, 10.721095730034966, 11.788814327075169], [11.92012424724557, 10.90474054787862, 9.913658170112448, 8.85411258532775, 7.914595203729915, 6.864137045726181, 5.883061748008828, 4.917060256336923, 3.8978307660883202, 2.9591160134366072, 2.030376538912659, 1.0729444761535514, 0.0, 1.0098574715631756, 1.9426788399407322, 2.9343611323930654, 3.9857745870801526, 4.948503070533583, 6.008349124945773, 7.076165136654052, 12.632732457394887, 11.702676014208427, 10.730035434716088, 9.789689624454013, 8.807307412712126, 7.80433637198011, 6.837838122895889, 5.852432227849648, 4.837594715434887, 3.885953090025506, 2.9331563745951637, 1.9405169118444965, 0.9923225638981811, 1.9438926787843753, 2.8945388134174657, 3.8732650263343023, 4.9132014945055404, 5.928955494239493, 6.908258911910108, 7.923993419379755, 13.636302238875048, 12.635707607679697, 11.73914023011604, 10.738748820138056, 9.741356880207372, 8.770157945682614, 7.800130130518937, 6.799001742315029, 5.859772100990587, 4.934624876884531, 3.92408562597896, 2.8868968038753113, 2.0301518089826693, 2.982320126665471, 3.86896843120534, 4.903691796903065, 5.8842510412693665, 6.873013270925815, 7.812525728107982, 8.834018948201393, 14.63921783966898, 13.593461958573883, 12.647943473919192, 11.5955414694776, 10.666390264757977, 9.696455123076557, 8.740065175713086, 7.80078237204083, 6.834997721742714, 5.9231464584748625, 4.965765387093485, 3.938124593978112, 3.0157179919014325, 3.924656164426069, 4.897159592588405, 5.8533806587149995, 6.895065649381566, 7.848964636692785, 8.741009811184284, 9.680975671612341, 15.593136486332787, 14.543937758997517, 13.56609867991171, 12.502579242425357, 11.57188410872601, 10.64470154639973, 9.715023656826212, 8.817359142502498, 7.863503514373537, 6.9366378137866676, 5.8769547473150805, 4.873671553826426, 3.959317199236025, 4.900051060818491, 5.894644327172042, 6.858481186448268, 7.890275063634821, 8.780708201827963, 9.783384186167385, 10.632249091154911, 16.510085635090157, 15.49201060417048, 14.45457874036557, 13.452061019427136, 12.549431540299855, 11.644545737314084, 10.67673900720444, 9.862838154636911, 8.801671969355352, 7.8226178430478415, 6.818742839607921, 5.885094393006538, 4.924360991289048, 5.901264613204723, 6.877624724514207, 7.820782770789095, 8.879630572610195, 9.816722640674197, 10.78451380972015, 11.68980582778784, 17.38304834920929, 16.443091489600484, 15.471897474881787, 14.46034862662596, 13.515371016087965, 12.611792062305684, 11.653527663033763, 10.802608805462308, 9.833002483662128, 8.808791311534602, 7.796879889142012, 6.830483007061078, 5.86932310527285, 6.8936146518151595, 7.824923171999614, 8.877625997427298, 9.901287747584163, 10.844114087959019, 11.82580143415412, 12.659519117513886, 18.31367698118965, 17.440171667997692, 16.497349569675066, 15.469308579748166, 14.54859717912355, 13.65352932163491, 12.715447497865773, 11.744230362855824, 10.785946294419753, 9.797737933269017, 8.787987769467197, 7.811791013249578, 6.85458647011692, 7.792791104892034, 8.79849183796745, 9.818275021664626, 10.765694940983494, 11.74998053153877, 12.70522635658439, 13.6481720362989, 18.43398216602029, 17.45123183543039, 16.471217110744146, 15.50436618351818, 14.548708047258625, 13.644644013000653, 12.684305557579691, 11.748781652744261, 11.788054544073125, 10.789133012292393, 9.807826056291322, 8.8379158775915, 7.891516250571147, 8.757074363258543, 9.711815018268123, 10.639264904321706, 11.573278715735958, 12.538874981808013, 13.584065424269976, 14.616212764097611, 17.492508919900537, 16.480646227429688, 15.540682020770527, 14.546605827047042, 13.603736496374783, 12.666402413952795, 11.730113290143226, 10.7942401258975, 11.783466567328858, 11.783820797179681, 10.787577161364279, 9.841586971948711, 8.9344609426478, 9.749844072522896, 10.74907734699556, 11.63761997458148, 12.547768697778128, 13.472172883350739, 14.536619957810512, 15.56725352094871, 16.482585651543868, 15.535838057557516, 14.58839138732671, 13.58659863522453, 12.56055879725772, 11.632193330927901, 10.697343522785438, 9.73805900902618, 10.757057486847817, 11.716722237941479, 11.77551168808038, 10.806747459714964, 9.980590376846948, 10.684632481531834, 11.677004413041915, 12.626748162210696, 13.568310270372901, 14.532657879807825, 15.461990391622026, 16.46340088337636, 15.594285654853682, 14.52598550398782, 13.532257478415088, 12.589791136716096, 11.563049041624605, 10.578307425895488, 9.713518793824097, 8.806687373551238, 9.784592453801006, 10.73114614096584, 11.614719715226112, 11.760966255221714, 10.988589062632732, 11.655305941158213, 12.617852522193157, 13.572477288828509, 14.521853305175153, 15.556217692127731, 16.500736669600848, 17.43420878750956, 14.567541648485252, 13.609517499008309, 12.563771838980905, 11.629660074558528, 10.591422211272054, 9.628079533212365, 8.66217630890168, 7.8119160905514935, 8.82732994031562, 9.707745811240097, 10.598027430837853, 11.5043393607102, 11.913807185975285, 12.643790928140572, 13.581239925612262, 14.52817145286527, 15.523526651521289, 16.499633781644395, 17.43405203647749, 18.359566769920754, 13.515168967244364, 12.714607453997736, 11.716631596518656, 10.697061465786538, 9.69221763263125, 8.670754373759529, 7.716908100479501, 6.814748621587629, 7.763983725602804, 8.704755732541049, 9.630133408555823, 10.552905690902406, 11.510686799570811, 12.547894334437423, 13.418537317827028, 14.444166082649332, 15.361561737250002, 16.4225965106064, 17.36681906854266, 18.34877398470612, 12.535612585157917, 11.726994715197407, 10.686357942641715, 9.689544128262614, 8.740053998243914, 7.7313045309451285, 6.77392595486645, 5.788905123892344, 6.753658135704962, 7.79441934746704, 8.700857879554116, 9.58123694788744, 10.540182420680672, 11.49722769501925, 12.433024882603325, 13.390722543209963, 14.430340426257684, 15.490724860728974, 16.44017288301878, 17.372969587841958, 11.555346191280801, 10.677478557322553, 9.615464517110155, 8.73088017976254, 7.723444873651496, 6.75359900550105, 5.7728260041989365, 4.823816602447398, 5.855516553451715, 6.847671035948544, 7.638997843127138, 8.600861815028377, 9.635224376461993, 10.619814537882721, 11.641225230410623, 12.61451387083962, 13.597086934040776, 14.501145359842432, 15.566206408627414, 16.467502826795616, 10.614545648977897, 9.65011367406568, 8.68215755470996, 7.7578701107723, 6.824918648303566, 5.781895513400151, 4.778646629347557, 3.8268804836013603, 4.863204527083984, 5.796852267693186, 6.692454261413691, 7.682789619689161, 8.657134351131461, 9.649923450891041, 10.628629339199863, 11.655659338337284, 12.561481041831646, 13.503781798262986, 14.509147441201373, 15.429109481900385, 9.780963389214442, 8.791476622414738, 7.752356081305196, 6.740703766939939, 5.782568364162291, 4.731241896268523, 3.8466704932425024, 2.8371304920326073, 3.8258586902725376, 4.739597718660489, 5.740639930285122, 6.750510597942398, 7.730619431269685, 8.695303245855523, 9.687421670498123, 10.632800749267899, 11.562194347590227, 12.491830658071532, 13.480875892398538, 14.415550320964403, 8.803688693036836, 7.780697533549177, 6.843544220304936, 5.836724430204769, 4.782047274787047, 3.7791974576230007, 2.8362442803482164, 1.897348973160518, 2.8343902464094537, 3.7701568298174237, 4.843174754845714, 5.826096511074259, 6.7731052064428106, 7.758842073823131, 8.77861382324408, 9.758492572332113, 10.719672178392438, 11.683157719430142, 12.632182814720109, 13.582997464281046, 7.994219525878375, 6.968639569946083, 5.939548456698311, 4.9498967279281665, 3.875088489526787, 2.959786712641897, 1.9577141495510682, 0.9332673894935147, 1.997456002132585, 2.97510364749164, 3.930966643815837, 4.83015249977838, 5.844402235148668, 6.84188231323621, 7.795501923456412, 8.784500942381413, 9.799543678965268, 10.77985127147431, 11.794040206188518, 12.861758803228721], [12.929981718808744, 11.914598019441794, 10.923515641675623, 9.863970056890924, 8.92445267529309, 7.873994517289357, 6.892919219572003, 5.926917727900098, 4.907688237651495, 3.9689734849997826, 3.0402340104758343, 2.082801947716727, 1.0098574715631756, 0.0, 0.9328213683775566, 1.92450366082989, 2.9759171155169772, 3.9386455989704077, 4.998491653382597, 6.066307665090877, 13.642589928958063, 12.712533485771603, 11.739892906279264, 10.79954709601719, 9.817164884275302, 8.814193843543286, 7.847695594459063, 6.862289699412823, 5.847452186998062, 4.880071776642313, 3.8799240173726113, 2.887284554621944, 1.9390902066756288, 0.9340352072211998, 1.8846813418542903, 2.863407554771127, 3.903344022942365, 4.919098022676318, 5.898401440346933, 6.91413594781658, 14.646159710438225, 13.645565079242873, 12.748997701679217, 11.748606291701233, 10.751214351770548, 9.78001541724579, 8.809987602082112, 7.808859213878204, 6.869629572553762, 5.928743563501338, 4.870853268756408, 3.833664446652759, 2.9417302964806527, 1.9724626551022957, 2.8591109596421647, 3.8938343253398893, 4.874393569706191, 5.86315579936264, 6.8026682565448064, 7.824161476638219, 15.649075311232156, 14.60331943013706, 13.657800945482364, 12.605398941040775, 11.676247736321152, 10.706312594639732, 9.74992264727626, 8.810639843604006, 7.844855193305889, 6.86991410125231, 5.912533029870932, 4.88489223675556, 3.8905381977933438, 2.9147986928628935, 3.8873021210252294, 4.843523187151824, 5.885208177818391, 6.83910716512961, 7.73115233962111, 8.671118200049166, 16.60299395789596, 15.55379523056069, 14.575956151474882, 13.51243671398853, 12.581741580289183, 11.654559017962905, 10.724881128389386, 9.795963912110281, 8.84210828398132, 7.868638741455571, 6.8039373308414, 5.800654137352746, 4.834137405127936, 3.8993727745817193, 4.89396604093527, 5.857802900211496, 6.880692542485049, 7.770850730264787, 8.77352671460421, 9.622391619591737, 17.519943106653326, 16.50186807573365, 15.464436211928742, 14.461918490990309, 13.559289011863028, 12.654403208877259, 11.686596478767614, 10.841442924244694, 9.780276738963135, 8.74960042657416, 7.745725423134241, 6.810555419373275, 5.799181197180959, 4.900586326967951, 5.876946438277435, 6.820104484552323, 7.878952286373423, 8.80686516911102, 9.774656338156975, 10.679948356224665, 18.392905820772462, 17.452948961163656, 16.481754946444962, 15.470206098189133, 14.525228487651137, 13.621649533868858, 12.663385134596938, 11.729591388988625, 10.759985067188445, 9.735773895060921, 8.722340915508749, 7.755944033427815, 6.74414331116476, 5.956831263385711, 6.855526797160233, 7.89061665819713, 8.914278408353995, 9.857104748728851, 10.815943962590946, 11.649661645950712, 18.39440659391645, 17.604330164718878, 16.64099745641525, 15.674196537656917, 14.6762492544672, 13.901095954009032, 12.93408058590224, 12.671212946382141, 11.712928877946071, 10.713508320313117, 9.703758156511297, 8.727561400293677, 7.72940667600883, 6.983070792538822, 7.829095463128069, 8.848878646825245, 9.796298566144113, 10.780584156699389, 11.73582998174501, 12.638314564735726, 17.516791179928756, 16.652949384223042, 15.672934659536795, 14.706083732310827, 13.750425596051272, 12.864525125244992, 11.954080462309815, 12.758639124307438, 12.715037127599443, 11.704903399336493, 10.723596443335422, 9.745909602104978, 8.766336456463057, 7.947354050905331, 8.823587447552539, 9.751037333606122, 10.685051145020374, 11.650647411092429, 12.695837853554393, 13.606355292534436, 16.56457349870517, 15.645325090536902, 14.742399569563174, 13.74832337583969, 12.80545404516743, 11.886283526197134, 10.949994402387565, 11.804097597460677, 12.793324038892035, 12.699591184223781, 11.695570885877757, 10.74958069646219, 9.809281148539709, 8.940123760169685, 9.860849776279975, 10.749392403865896, 11.659541127062544, 12.583945312635155, 13.648392387094928, 14.600365232021352, 15.5546502303485, 14.700516920664732, 13.753070250433927, 12.788316184017177, 11.762276346050367, 10.833910879720548, 9.917224635029777, 10.747916480589357, 11.766914958410993, 12.726579709504655, 12.683505412593858, 11.714741184228442, 10.855410582738857, 9.874912169178623, 10.867284100688705, 11.817027849857485, 12.68008269965732, 13.644430309092243, 14.573762820906442, 15.546209897284825, 14.635613894620583, 13.690664367095037, 12.696936341522305, 11.767275243645992, 10.764766590417253, 9.780024974688136, 8.915236342616744, 9.816544845114414, 10.794449925364182, 11.741003612529017, 12.624577186789288, 12.668959979735192, 11.853578387012675, 10.845585628805003, 11.808132209839947, 12.762756976475298, 13.63362573445957, 14.66799012141215, 15.612509098885266, 16.517017801418028, 13.569298843987015, 12.774196362115525, 11.728450702088121, 10.794338937665744, 9.793139760064701, 8.829797082005012, 7.863893857694327, 8.82177356211467, 9.837187411878796, 10.717603282803273, 11.607884902401029, 12.514196832273376, 12.778796510355228, 11.834070615787361, 12.771519613259052, 13.718451140512059, 14.635299080805707, 15.611406210928815, 16.54582446576191, 17.44237578382922, 12.551993879606965, 11.815310019404578, 10.817334161925498, 9.861740328893754, 8.893935181423897, 7.872471922552177, 6.9186256492721485, 7.8246060931508055, 8.77384119716598, 9.714613204104225, 10.639990880118999, 11.562763162465583, 12.520544271133987, 12.767310591383216, 13.72149775872569, 14.64353319770021, 15.582057453797793, 16.556452555171873, 17.549121861403894, 18.39685983297741, 11.572437497520518, 10.827697280604248, 9.787060508048556, 8.790246693669456, 7.932245249185721, 6.933022079737776, 5.975643503659097, 6.79876259545552, 7.763515607268138, 8.804276819030216, 9.710715351117292, 10.591094419450616, 11.550039892243849, 12.507085166582426, 13.442882354166501, 14.400580014773139, 15.44019789782086, 16.50058233229215, 17.450030354581955, 18.382827059405134, 10.592171103643402, 9.778181122729395, 8.716167082516996, 7.831582745169381, 6.915636124593303, 5.945790256442857, 4.974543552991584, 5.833674074010574, 6.865374025014891, 7.85752850751172, 8.648855314690314, 9.610719286591554, 10.64508184802517, 11.629672009445898, 12.651082701973799, 13.624371342402796, 14.606944405603953, 15.511002831405609, 16.576063880190592, 17.477360298358793, 9.671835241544022, 8.750816239472522, 7.782860120116801, 6.858572676179142, 5.925621213710407, 4.892099275134987, 3.960058727003875, 4.836737955164536, 5.8730619986471595, 6.8067097392563625, 7.7023117329768676, 8.692647091252336, 9.666991822694635, 10.659780922454217, 11.63848681076304, 12.66551680990046, 13.571338513394823, 14.513639269826163, 15.519004912764549, 16.43896695346356, 8.817924182288195, 7.892179187821579, 6.853058646712038, 5.84140633234678, 4.883270929569132, 3.8395294124900787, 3.02808259089882, 3.846987963595783, 4.835716161835713, 5.7494551902236655, 6.750497401848298, 7.760368069505574, 8.74047690283286, 9.7051607174187, 10.6972791420613, 11.642658220831075, 12.572051819153403, 13.501688129634708, 14.490733363961715, 15.42540779252758, 7.904391258443677, 6.881400098956018, 5.944246785711776, 4.9374269956116095, 3.8827498401938874, 2.8874849738445567, 2.0070863603346067, 2.907206444723694, 3.8442477179726295, 4.7800143013806, 5.8530322264088905, 6.835953982637435, 7.782962678005986, 8.768699545386307, 9.788471294807254, 10.768350043895287, 11.729529649955612, 12.693015190993316, 13.642040286283283, 14.592854935844223, 6.984362054315199, 5.958782098382907, 4.929690985135136, 3.940039256364991, 2.8652310179636116, 1.9499292410787212, 0.9478566779878925, 1.9431248610566905, 3.0073134736957607, 3.9849611190548155, 4.940824115379012, 5.840009971341554, 6.854259706711844, 7.851739784799386, 8.805359395019586, 9.794358413944588, 10.809401150528442, 11.789708743037485, 12.803897677751692, 13.871616274791895], [13.862803087186302, 12.847419387819352, 11.856337010053181, 10.796791425268482, 9.857274043670648, 8.806815885666914, 7.82574058794956, 6.8597390962776545, 5.840509606029052, 4.901794853377339, 3.973055378853391, 3.015623316094284, 1.9426788399407322, 0.9328213683775566, 0.0, 0.9916822924523334, 2.0430957471394207, 3.005824230592851, 4.065670285005041, 5.13348629671332, 14.57541129733562, 13.64535485414916, 12.67271427465682, 11.732368464394746, 10.749986252652858, 9.747015211920843, 8.78051696283662, 7.79511106779038, 6.780273555375619, 5.81289314501987, 4.812745385750167, 3.8201059229995007, 2.8719115750531854, 1.8668565755987565, 1.0082561600313265, 1.9564389158509468, 2.996375384022185, 3.986276654298761, 4.965580071969376, 5.981314579439023, 15.578981078815781, 14.57838644762043, 13.681819070056774, 12.68142766007879, 11.684035720148104, 10.712836785623347, 9.742808970459668, 8.74168058225576, 7.802450940931319, 6.8615649318788945, 5.803674637133964, 4.7664858150303155, 3.8745516648582092, 2.9052840234798523, 1.982685777819201, 2.9868656864197094, 3.967424930786011, 4.930334430985083, 5.86984688816725, 6.891340108260662, 16.581896679609713, 15.536140798514616, 14.590622313859921, 13.538220309418332, 12.609069104698708, 11.639133963017288, 10.682744015653817, 9.743461211981563, 8.777676561683446, 7.802735469629867, 6.845354398248489, 5.817713605133116, 4.8233595661709, 3.84762006124045, 3.017726649593355, 3.936554548231644, 4.978239538898211, 5.906285796752053, 6.798330971243553, 7.73829683167161, 17.535815326273518, 16.486616598938248, 15.508777519852439, 14.445258082366086, 13.51456294866674, 12.587380386340461, 11.657702496766943, 10.728785280487838, 9.774929652358876, 8.801460109833128, 7.7367586992189565, 6.733475505730302, 5.766958773505492, 4.832194142959276, 4.067100846584356, 4.986541613319863, 5.973723903564869, 6.83802936188723, 7.840705346226655, 8.68957025121418, 18.452764475030882, 17.434689444111207, 16.3972575803063, 15.394739859367865, 14.492110380240584, 13.587224577254815, 12.61941784714517, 11.77426429262225, 10.713098107340691, 9.682421794951717, 8.678546791511797, 7.743376787750831, 6.732002565558515, 5.833407695345508, 5.0875050052973965, 6.030663051572285, 7.015126356409143, 7.874043800733463, 8.841834969779418, 9.747126987847109, 18.39221385751926, 17.6792036710073, 16.74424287909974, 15.750262109149338, 14.787268745393995, 14.036123675063562, 13.596206502974495, 12.662412757366182, 11.692806435566002, 10.668595263438478, 9.655162283886305, 8.688765401805371, 7.6769646795423165, 6.889652631763267, 6.066085364180195, 7.101175225217092, 8.089704528421988, 8.927018822876972, 9.88312259421339, 10.716840277573155, 17.461585225538897, 16.682123492610092, 15.718790784306462, 14.751989865548127, 13.75404258235841, 12.994386415734336, 13.824611008309418, 13.604034314759698, 12.645750246323628, 11.646329688690674, 10.636579524888853, 9.660382768671234, 8.662228044386387, 7.915892160916378, 7.03965403014803, 8.059437213845206, 9.006857133164074, 9.965818747915424, 10.832738503860625, 11.70549319635817, 16.5839698115512, 15.730742712114253, 14.750727987428006, 13.783877060202038, 12.828218923942483, 11.957815586970296, 12.844610884716992, 13.68608899607809, 13.647858495977, 12.63772476771405, 11.656417811712979, 10.678730970482535, 9.699157824840613, 8.880175419282889, 8.0341460145725, 8.961595900626083, 9.895609712040335, 10.86120597811239, 11.8953433347144, 12.67353392415688, 15.631752130327612, 14.712503722159347, 13.820192897454385, 12.8261167037309, 11.88324737305864, 10.97957398792244, 11.840524824794743, 12.731547469231328, 13.720773910662686, 13.632412552601338, 12.628392254255314, 11.682402064839746, 10.742102516917265, 9.872945128547242, 9.071408343299936, 9.959950970885856, 10.870099694082505, 11.794503879655116, 12.847897868254936, 13.667543863643795, 14.621828861970943, 13.767695552287178, 12.820248882056372, 11.866109511908387, 10.840069673941578, 9.91170420761176, 10.807755057436955, 11.675366352360008, 12.694364830181645, 13.655885354710446, 13.616326780971415, 12.647562552605999, 11.788231951116414, 10.80773353755618, 10.108099512338613, 11.029553202871707, 11.890641266677278, 12.854988876112202, 13.77326830206645, 14.613388528907269, 13.702792526243027, 12.757842998717482, 11.76411497314475, 10.834453875268437, 9.842559918308464, 8.857818302579346, 9.805766765023922, 10.743994716885064, 11.721899797134832, 12.670309257734807, 13.553882831995077, 13.601781348112748, 12.786399755390232, 11.77840699718256, 11.148876100097146, 12.05060990501105, 12.84418430147953, 13.878548688432108, 14.812014580045272, 15.584196433040471, 12.636477475609459, 11.841374993737972, 10.795629333710567, 9.86151756928819, 8.870933087955912, 7.907590409896223, 8.754424280101505, 9.74922343388532, 10.764637283649446, 11.646908928009063, 12.537190547606818, 13.443502477479164, 13.711617878732785, 12.766891984164918, 12.112263503516251, 13.006304069047811, 13.845857647825666, 14.821964777948773, 15.756383032781867, 16.509554415451664, 11.619172511229408, 10.882488651027021, 9.884512793547941, 8.9289189605162, 7.969158865799266, 6.950265250443387, 7.809156071679326, 8.753911738356596, 9.70314684237177, 10.643918849310015, 11.569296525324788, 12.492068807671371, 13.449849916339776, 13.700131959760773, 13.067843776544953, 13.931386126235962, 14.792616020817752, 15.76701112219183, 16.75968042842385, 17.464038464599852, 10.639616129142961, 9.894875912226691, 8.854239139671, 7.8574253252919, 6.999423880808164, 6.010815407628986, 6.866173926066275, 7.72806824066131, 8.692821252473928, 9.733582464236006, 10.64002099632308, 11.520400064656405, 12.479345537449637, 13.436390811788215, 14.053356211768655, 14.984829665675331, 15.723837331810069, 16.698882772069258, 17.64833079435906, 18.521610033660373, 9.659349735265845, 8.845359754351838, 7.78334571413944, 6.898761376791825, 5.982814756215746, 5.0129688880653, 5.8650739753987615, 6.762979719216363, 7.794679670220681, 8.786834152717509, 9.578160959896103, 10.540024931797342, 11.574387493230958, 12.558977654651686, 13.580388347179587, 14.553676987608585, 15.536250050809741, 16.4403084766114, 17.505369525396382, 18.406665943564583, 8.739013873166465, 7.817994871094965, 6.850038751739245, 5.925751307801585, 4.992799845332851, 3.95927790675743, 4.850589149411053, 5.766043600370326, 6.80236764385295, 7.736015384462151, 8.631617378182655, 9.621952736458125, 10.596297467900424, 11.589086567660006, 12.567792455968828, 13.594822455106248, 14.500644158600611, 15.442944915031951, 16.448310557970338, 17.36827259866935, 7.885102813910639, 6.959357819444023, 5.920237278334481, 4.908584963969224, 3.9504495611915753, 2.906708044112522, 3.9186130133059978, 4.776293608801573, 5.765021807041503, 6.678760835429454, 7.679803047054087, 8.689673714711363, 9.669782548038649, 10.634466362624488, 11.626584787267088, 12.571963866036864, 13.501357464359192, 14.430993774840497, 15.420039009167503, 16.35471343773337, 6.97156989006612, 5.948578730578461, 5.01142541733422, 4.004605627234053, 2.9499284718163308, 1.9546636054670001, 2.8976167827417845, 3.8365120899294833, 4.773553363178419, 5.709319946586389, 6.782337871614679, 7.765259627843224, 8.715784046383543, 9.701520913763865, 10.72129266318481, 11.701171412272844, 12.662351018333169, 13.625836559370873, 14.57486165466084, 15.52567630422178, 6.051540685937644, 5.025960730005352, 3.99686961675758, 3.0072178879874345, 1.932409649586055, 1.0171078727011647, 1.880678046365449, 2.875946229434247, 3.9401348420733173, 4.917782487432373, 5.87364548375657, 6.772831339719111, 7.7870810750894, 8.784561153176941, 9.738180763397143, 10.727179782322144, 11.742222518905999, 12.722530111415042, 13.736719046129249, 14.804437643169452], [14.854485379638634, 13.839101680271684, 12.848019302505513, 11.788473717720814, 10.84895633612298, 9.798498178119246, 8.817422880401892, 7.851421388729987, 6.832191898481384, 5.893477145829672, 4.964737671305723, 4.007305608546616, 2.9343611323930654, 1.92450366082989, 0.9916822924523334, 0.0, 1.051413454687087, 2.0141419381405177, 3.0739879925527074, 4.141804004260987, 15.567093589787952, 14.637037146601491, 13.664396567109153, 12.724050756847078, 11.74166854510519, 10.738697504373174, 9.772199255288953, 8.786793360242712, 7.771955847827951, 6.804575437472203, 5.804427678202501, 4.811788215451834, 3.863593867505519, 2.85853886805109, 1.94348283631545, 0.9647566233986133, 2.0046930915698518, 2.9945943618464277, 3.973897779517043, 4.98963228698669, 16.57066337126811, 15.570068740072761, 14.673501362509105, 13.67310995253112, 12.675718012600436, 11.704519078075679, 10.734491262912002, 9.733362874708092, 8.79413323338365, 7.853247224331228, 6.795356929586298, 5.758168107482649, 4.828480440194051, 3.859212798815694, 2.9179124541033246, 1.9951833939673758, 2.975742638333678, 3.93865213853275, 4.8781645957149165, 5.899657815808329, 17.573578972062045, 16.527823090966947, 15.582304606312256, 14.529902601870665, 13.600751397151042, 12.630816255469622, 11.67442630810615, 10.735143504433895, 9.769358854135778, 8.785580672487736, 7.828199601106357, 6.800558807990985, 5.7772883415067415, 4.801548836576291, 3.9155332616396237, 2.9448722557793103, 3.9865572464458774, 4.91460350429972, 5.80664867879122, 6.7466145392192765, 18.52749761872585, 17.47829889139058, 16.500459812304772, 15.436940374818422, 14.506245241119075, 13.579062678792795, 12.649384789219276, 11.682714055823679, 10.728858427694718, 9.75538888516897, 8.690687474554798, 7.687404281066144, 6.7208875488413335, 5.786122918295117, 4.958696180143756, 3.9948593208675294, 4.982041611112535, 5.846347069434897, 6.849023053774322, 7.697887958761847, 18.444723708545666, 17.694563684896305, 16.823699370451525, 15.948745039911865, 14.943403544745808, 14.578906869707149, 13.611100139597504, 12.728193067958092, 11.667026882676533, 10.636350570287558, 9.632475566847639, 8.697305563086672, 7.685931340894356, 6.787336470681349, 5.979100338856796, 5.044683796228289, 6.023444063956809, 6.88236150828113, 7.850152677327085, 8.755444695394777, 17.400531565066927, 16.730567471229747, 15.806380635935307, 14.94045743271304, 13.977464068957698, 14.925711426662138, 14.587888795426828, 13.616341532702025, 12.646735210901845, 11.62252403877432, 10.609091059222147, 9.642694177141212, 8.630893454878157, 7.843581407099109, 6.957680697739594, 6.1151959698730955, 7.098022235969655, 7.935336530424639, 8.891440301761056, 9.725157985120823, 16.469902933086566, 15.733487292832539, 14.78092854114203, 13.94218518911183, 12.944237905922114, 13.883974167332912, 14.781965343719017, 14.55796309009554, 13.59967902165947, 12.600258464026515, 11.590508300224695, 10.614311544007075, 9.616156819722228, 8.86982093625222, 7.93124936370743, 7.185278345794142, 8.064735519273123, 8.974136455463091, 9.841056211408292, 10.713810903905838, 15.592287519098868, 14.779400745078359, 13.812865744263574, 12.97407238376574, 12.018414247506186, 12.915169922379896, 13.801965220126592, 14.643443331487687, 14.601787271312842, 13.59165354304989, 12.61034658704882, 11.632659745818376, 10.653086600176454, 9.834104194618728, 8.925741348131899, 8.163082236322207, 9.089648793075485, 10.040977268835443, 10.903661042262065, 11.681851631704548, 14.64006983787528, 13.720821429707012, 12.865403252472689, 11.938625942333783, 11.073442696622344, 11.936928323332038, 12.797879160204342, 13.688901804640926, 14.678128246072284, 14.586341327937179, 13.582321029591155, 12.636330840175587, 11.696031292253107, 10.826873903883081, 9.963003676859335, 9.16143730658198, 10.064138775117655, 10.974275170378169, 11.8562155758026, 12.675861571191463, 13.630146569518612, 12.776013259834842, 11.828566589604037, 10.899224470058217, 10.030264997505281, 10.869058543021358, 11.765109392846554, 12.632720687769606, 13.651719165591242, 14.613239690120045, 14.570255556307256, 13.60149132794184, 12.742160726452255, 11.76166231289202, 10.999694845898013, 10.231039538567831, 11.084680347712428, 12.034760166835255, 12.781586009614115, 13.621706236454937, 12.711110233790695, 11.766160706265147, 10.772432680692415, 9.842771582816102, 9.007249503937498, 9.815172637988946, 10.763121100433521, 11.701349052294663, 12.67925413254443, 13.627663593144407, 14.511237167404676, 14.55571012344859, 13.740328530726071, 12.732335772518399, 12.040471433656545, 11.252096240707175, 12.03822338251468, 13.072587769467258, 13.820332287592937, 14.59251414058814, 11.644795183157127, 10.849692701285637, 9.803947041258231, 8.869835276835854, 8.035622673584946, 8.864944745305822, 9.711778615511104, 10.706577769294919, 11.721991619059045, 12.604263263418662, 13.494544883016417, 14.400856812888764, 14.665546654068624, 13.720820759500757, 13.00385883707565, 12.207790404743935, 13.039896728860816, 14.016003858983924, 14.837832678175634, 15.517872122999332, 10.627490218777075, 9.89080635857469, 8.892830501095606, 7.937236668063865, 7.024892481220082, 7.907619585852986, 8.766510407088925, 9.711266073766195, 10.66050117778137, 11.601273184719615, 12.526650860734387, 13.44942314308097, 14.407204251749375, 14.654060735096612, 13.959439110104352, 13.132872461932086, 13.986655101852902, 14.96105020322698, 15.841130073817615, 16.47235617214752, 9.647933836690628, 8.903193619774358, 7.862556847218666, 6.865743032839567, 6.05515749622898, 6.968169743038585, 7.823528261475874, 8.68542257607091, 9.650175587883528, 10.690936799645606, 11.59737533173268, 12.477754400066004, 13.436699872859236, 14.393745147197814, 14.944951545328054, 14.186316001371456, 14.917876412845219, 15.892921853104408, 16.7677762593415, 17.52992774120804, 8.667667442813512, 7.853677461899505, 6.791663421687106, 5.907079084339491, 5.038548371636562, 5.9703232234748995, 6.822428310808361, 7.720334054625963, 8.75203400563028, 9.744188488127108, 10.535515295305702, 11.497379267206941, 12.531741828640557, 13.516331990061285, 14.537742682589187, 15.11936423336707, 15.932164392258864, 16.90754535127524, 17.730208391964425, 18.560146013294943, 7.747331580714132, 6.826312578642631, 5.858356459286911, 4.934069015349252, 4.001117552880517, 4.916632242167029, 5.807943484820652, 6.723397935779925, 7.759721979262549, 8.69336971987175, 9.588971713592255, 10.579307071867724, 11.553651803310023, 12.546440903069605, 13.525146791378427, 14.552176790515848, 15.45799849401021, 16.40029925044155, 17.405664893379935, 18.32562693407895, 6.893420521458306, 5.967675526991689, 4.928554985882147, 3.91690267151689, 2.958767268739242, 3.8640623795221214, 4.875967348715597, 5.733647944211172, 6.722376142451102, 7.636115170839053, 8.637157382463686, 9.647028050120962, 10.627136883448248, 11.591820698034088, 12.583939122676687, 13.529318201446463, 14.45871179976879, 15.388348110250096, 16.377393344577104, 17.31206777314297, 5.979887597613787, 4.956896438126128, 4.019743124881886, 3.0129233347817195, 1.9582461793639974, 2.9120179408765994, 3.8549711181513837, 4.793866425339083, 5.730907698588018, 6.666674281995988, 7.739692207024278, 8.722613963252822, 9.707466338835875, 10.693203206216197, 11.712974955637144, 12.692853704725177, 13.654033310785502, 14.617518851823206, 15.566543947113173, 16.51735859667411, 5.05985839348531, 4.034278437553018, 3.0051873243052465, 2.015535595535101, 0.9407273571337217, 1.9744622081107641, 2.8723603388177823, 3.86762852188658, 4.93181713452565, 5.909464779884705, 6.865327776208902, 7.764513632171443, 8.778763367541734, 9.776243445629275, 10.729863055849476, 11.718862074774478, 12.733904811358332, 13.714212403867375, 14.728401338581582, 15.796119935621785], [15.905898834325722, 14.890515134958772, 13.899432757192601, 12.839887172407902, 11.900369790810068, 10.849911632806334, 9.86883633508898, 8.902834843417075, 7.883605353168472, 6.94489060051676, 6.0161511259928115, 5.0587190632337045, 3.9857745870801526, 2.9759171155169772, 2.0430957471394207, 1.051413454687087, 0.0, 0.9627284834534307, 2.02257453786562, 3.0903905495738995, 16.618507044475038, 15.68845060128858, 14.71581002179624, 13.775464211534166, 12.793081999792278, 11.790110959060263, 10.823612709976041, 9.8382068149298, 8.823369302515038, 7.85598889215929, 6.855841132889588, 5.863201670138921, 4.915007322192606, 3.909952322738177, 2.978710456810466, 1.9999842438936293, 0.9600477757223911, 1.9431809071593404, 2.9224843248299557, 3.9382188322996026, 17.6220768259552, 16.62148219475985, 15.724914817196193, 14.724523407218209, 13.727131467287524, 12.755932532762767, 11.78590471759909, 10.78477632939518, 9.845546688070739, 8.904660679018315, 7.846770384273385, 6.809581562169736, 5.863708060689066, 4.894440419310709, 3.9531400745983403, 2.9945542227520754, 1.9310973224862171, 2.8872386838456627, 3.8267511410278297, 4.848244361121242, 18.624992426749134, 17.579236545654037, 16.633718060999342, 15.581316056557753, 14.65216485183813, 13.68222971015671, 12.725839762793239, 11.786556959120983, 10.80693659431968, 9.82080829298275, 8.863427221601373, 7.835786428486001, 6.812515962001758, 5.836776457071307, 4.914904090424324, 3.94424308456401, 2.941911930598417, 3.863190049612632, 4.7552352241041325, 5.695201084532189, 18.455419985506904, 17.795232883606833, 16.910240403984602, 16.08782363882921, 15.557658695806161, 14.630476133479883, 13.700798243906364, 12.717941676318695, 11.764086048189734, 10.790616505663985, 9.725915095049814, 8.72263190156116, 7.75611516933635, 6.821350538790133, 5.933027031727855, 4.969190172451629, 3.937396295265075, 4.794933614747809, 5.7976095990872345, 6.64647450407476, 17.393310253858576, 16.788054607289045, 15.917190292844264, 15.138341861827431, 15.86719778192767, 15.630320324394237, 14.662513594284592, 13.763420688453108, 12.702254503171549, 11.671578190782574, 10.667703187342655, 9.732533183581689, 8.721158961389373, 7.822564091176365, 6.953431190440895, 6.019014647812389, 4.978798748109349, 5.830948053594042, 6.798739222639997, 7.70403124070769, 16.349118110379838, 15.824058393622487, 14.899871558328046, 14.130054254628607, 14.90125830613956, 15.849505663844, 15.639302250113916, 14.65156915319704, 13.68196283139686, 12.657751659269335, 11.644318679717163, 10.677921797636229, 9.666121075373173, 8.863320069508148, 7.932011549323693, 7.077038670279059, 6.053376920122194, 6.883923075737552, 7.840026847073969, 8.673744530433735, 15.418489478399476, 14.826978215225278, 13.87441946353477, 13.121094301506401, 13.868032143103976, 14.807768404514775, 15.833378798406105, 15.593190710590555, 14.634906642154485, 13.635486084521531, 12.62573592071971, 11.649539164502091, 10.651384440217244, 9.88955959866126, 8.905580215291529, 7.967510122744531, 7.020090203425663, 7.922723000776004, 8.789642756721204, 9.66239744921875, 14.54087406441178, 13.872891667471098, 12.906356666656313, 12.131665452593769, 12.942208484688049, 13.924462092779773, 14.85337867481368, 15.694856786174777, 15.637014891807857, 14.626881163544907, 13.645574207543836, 12.667887366313392, 11.68831422067147, 10.82750455433576, 9.87276389932618, 8.945314013272597, 8.045003477228025, 8.989563814148354, 9.852247587574979, 10.63043817701746, 13.588656383188193, 12.814312352099751, 11.958894174865428, 11.084922914043108, 11.997236933804205, 12.95029448132764, 13.84929261489143, 14.740315259328016, 15.729541700759373, 15.621568948432195, 14.61754865008617, 13.671558460670603, 12.731258912748123, 11.820274263600114, 10.871296053041577, 9.94366908353237, 9.019493459270196, 9.92286171569108, 10.804802121115515, 11.624448116504375, 12.578733114831524, 11.869504182227582, 10.922057511996776, 10.045521441767542, 10.954059234687142, 11.88242470101696, 12.816522847533642, 13.684134142456696, 14.703132620278332, 15.664653144807133, 15.605483176802272, 14.636718948436856, 13.777388346947271, 12.755062672609052, 11.907987222080255, 11.013271315518221, 10.04003503186497, 10.983346712148169, 11.730172554927028, 12.570292781767849, 11.659696779103605, 10.859651628657886, 9.865923603085154, 8.989068554525428, 9.931043741119359, 10.864186929789991, 11.81453455512061, 12.752762506981751, 13.730667587231519, 14.679077047831495, 15.562650622091764, 15.590937743943606, 14.733728890443103, 13.725736132235431, 12.948763809838788, 11.995087760952126, 10.993578066667222, 12.0279424536198, 12.76891883290585, 13.541100685901052, 10.593381728470039, 9.943183623678376, 8.89743796365097, 8.01613224854518, 8.959416910766807, 9.913959037106867, 10.763192070198192, 11.757991223982007, 12.773405073746133, 13.65567671810575, 14.545958337703505, 15.452270267575852, 15.658947013785657, 14.71422111921779, 13.912151213257893, 12.950781924988886, 11.995251413013358, 12.971358543136466, 13.786419223488547, 14.466458668312244, 9.576076764089988, 8.910255186429357, 7.912279328950276, 7.083533639773191, 7.948686718401942, 8.956633877654031, 9.817923861776013, 10.762679528453283, 11.711914632468458, 12.652686639406703, 13.578064315421475, 14.500836597768059, 15.458617706436463, 15.647461094813645, 14.867731486286594, 13.875863982177037, 12.942009786005444, 13.916404887379523, 14.789716619130528, 15.420942717460433, 8.596520382003542, 7.922642447629027, 6.882005675073335, 6.012040004548893, 6.97895173341084, 8.01718403483963, 8.874941716162962, 9.736836030757997, 10.701589042570616, 11.742350254332694, 12.648788786419768, 13.529167854753092, 14.488113327546325, 15.445158601884902, 15.853243921510296, 14.912848980045483, 13.873231096997761, 14.84827653725695, 15.716362804654413, 16.47851428652095, 7.616253988126425, 6.873126289754174, 5.811112249541775, 5.053376056048817, 6.080869653700407, 7.021736678161988, 7.873841765495448, 8.77174750931305, 9.803447460317367, 10.795601942814196, 11.58692874999279, 12.54879272189403, 13.583155283327645, 14.567745444748374, 15.589156137276275, 15.845897212041098, 14.887519076411406, 15.862900035427783, 16.67879493727734, 17.508732558607853, 6.6959181260270455, 5.845761406497301, 4.877805287141581, 4.080365987058578, 5.0525310075676035, 5.968045696854118, 6.859356939507739, 7.774811390467012, 8.811135433949635, 9.744783174558838, 10.640385168279343, 11.630720526554812, 12.605065257997111, 13.597854357756693, 14.576560246065515, 15.603590245202936, 15.923124968620536, 16.86026359700723, 17.742158162589472, 18.547125903503087, 5.8420070667712185, 4.941034579668825, 3.948003813736817, 3.0631996432262154, 4.010180723426329, 4.915475834209209, 5.927380803402684, 6.785061398898259, 7.77378959713819, 8.687528625526141, 9.688570837150774, 10.69844150480805, 11.678550338135336, 12.643234152721176, 13.635352577363776, 14.580731656133551, 15.510125254455879, 16.439761564937186, 17.428806799264194, 18.36348122783006, 4.94448602289129, 3.9302554908032636, 2.9967396355072866, 2.068207743349556, 3.0096596340510846, 3.9634313955636866, 4.906384572838471, 5.84527988002617, 6.782321153275106, 7.718087736683076, 8.791105661711367, 9.77402741793991, 10.758879793522965, 11.744616660903286, 12.764388410324232, 13.744267159412265, 14.70544676547259, 15.668932306510294, 16.61795740180026, 17.568772051361197, 4.008444938798223, 2.9828649828659306, 1.9537738696181592, 1.00702826342652, 1.9921408118208088, 3.0258756627978514, 3.9237737935048695, 4.919041976573667, 5.983230589212738, 6.960878234571793, 7.91674123089599, 8.815927086858531, 9.830176822228822, 10.827656900316363, 11.781276510536564, 12.770275529461566, 13.78531826604542, 14.765625858554463, 15.77981479326867, 16.847533390308875], [16.868627317779154, 15.853243618412204, 14.862161240646033, 13.802615655861334, 12.8630982742635, 11.812640116259766, 10.831564818542413, 9.865563326870507, 8.846333836621904, 7.90761908397019, 6.978879609446242, 6.021447546687135, 4.948503070533583, 3.9386455989704077, 3.005824230592851, 2.0141419381405177, 0.9627284834534307, 0.0, 1.0598460544121897, 2.127662066120469, 17.58123552792847, 16.65117908474201, 15.678538505249673, 14.738192694987598, 13.75581048324571, 12.752839442513695, 11.786341193429474, 10.800935298383232, 9.78609778596847, 8.81871737561272, 7.8185696163430185, 6.825930153592352, 5.8777358056460365, 4.872680806191608, 3.9414389402638963, 2.9627127273470597, 1.9227762591758217, 0.9804524237059098, 1.9597558413765253, 2.975490348846172, 18.584805309408633, 17.58421067821328, 16.687643300649626, 15.687251890671641, 14.689859950740956, 13.718661016216199, 12.748633201052522, 11.747504812848613, 10.808275171524171, 9.867389162471746, 8.809498867726814, 7.772310045623167, 6.826436544142497, 5.85716890276414, 4.915868558051771, 3.9572827062055067, 2.893825805939648, 1.9245102003922319, 2.864022657574399, 3.885515877667811, 18.537983103141638, 17.82495041480181, 16.925284709897518, 16.544044540011186, 15.614893335291562, 14.644958193610142, 13.688568246246671, 12.749285442574415, 11.769665077773112, 10.783536776436183, 9.826155705054804, 8.798514911939431, 7.775244445455188, 6.799504940524738, 5.877632573877755, 4.9069715680174415, 3.9046404140518476, 2.9004615661592013, 3.792506740650702, 4.732472601078759, 17.492691502053475, 16.8325044001534, 15.94751192053117, 16.854072181132768, 16.520387179259593, 15.593204616933315, 14.663526727359796, 13.680670159772127, 12.726814531643166, 11.753344989117418, 10.688643578503246, 9.685360385014592, 8.718843652789781, 7.784079022243564, 6.875703723447131, 5.911866864170905, 4.880072986984352, 3.832205131294378, 4.834881115633804, 5.68374602062133, 16.430581770405148, 15.825326123835614, 14.954461809390832, 15.904590404130989, 16.633446324231222, 16.59304880784767, 15.625242077738024, 14.72614917190654, 13.664982986624981, 12.634306674236006, 11.630431670796087, 10.69526166703512, 9.683887444842805, 8.785292574629796, 7.896107882160171, 6.961691339531665, 5.921475439828626, 4.868219570140611, 5.836010739186567, 6.741302757254259, 15.386389626926407, 14.861329910169056, 13.937143074874614, 14.896302796932165, 15.667506848443114, 16.615754206147557, 16.602030733567346, 15.614297636650472, 14.644691314850292, 13.620480142722768, 12.607047163170595, 11.64065028108966, 10.628849558826605, 9.805996761227425, 8.87468824104297, 7.887682682815841, 6.864020932658976, 5.92119459228412, 6.877298363620539, 7.711016046980306, 14.455760994946047, 13.864249731771848, 12.911690980081337, 13.887342843809959, 14.63428068540753, 15.574016946818329, 16.61348939794707, 16.555919194043987, 15.597635125607917, 14.598214567974964, 13.588464404173143, 12.612267647955523, 11.614112923670676, 10.832236290380536, 9.797937318978487, 8.778154135281312, 7.830734215962445, 6.959994517322572, 7.826914273267774, 8.699668965765321, 13.578145580958351, 12.910163184017668, 11.94362818320288, 12.897913994897326, 13.708457026991603, 14.690710635083327, 15.656918207363015, 16.560726223233683, 16.59974337526129, 15.589609646998339, 14.58318349427445, 13.544222491036898, 12.564649345394976, 11.638148566872541, 10.683407911862961, 9.755958025809377, 8.855647489764808, 8.026835330694924, 8.889519104121549, 9.667709693564031, 12.625927899734764, 11.85158386864632, 10.996165691411996, 11.851171456346666, 12.76348547610776, 13.716543023631196, 14.652832147440765, 15.60618469638692, 16.595411137818278, 16.55959331953265, 15.493883774809676, 14.547893585394108, 13.607594037471628, 12.630918276136894, 11.681940065578358, 10.75431309606915, 9.830137471806978, 8.96013323223765, 9.842073637662084, 10.661719633050946, 11.616004631378095, 10.906775698774151, 9.959329028543346, 10.8117699840711, 11.720307776990698, 12.648673243320516, 13.648023143161465, 14.5500035795156, 15.569002057337237, 16.613726186244037, 16.481818301525777, 15.513054073160362, 14.62944279760369, 13.565706685145832, 12.718631234617035, 11.823915328055001, 10.850679044401751, 10.020618228694737, 10.767444071473598, 11.60756429831442, 10.696968295650176, 9.896923145204456, 8.903195119631723, 9.755317096828986, 10.697292283422914, 11.630435472093549, 12.646034850748432, 13.618631944040656, 14.596537024290424, 15.641805531284925, 16.525379105545195, 16.46727286866711, 15.544372902979884, 14.536380144772211, 13.759407822375568, 12.805731773488906, 11.804222079204003, 11.077159140019596, 11.806190349452422, 12.578372202447623, 9.63065324501661, 8.980455140224944, 7.934709480197539, 8.782380790848737, 9.725665453070363, 10.680207579410425, 11.629061507257097, 12.623860661040911, 13.639274510805038, 14.618405201559181, 15.508686821156935, 16.414998751029284, 16.469591026322437, 15.52486513175457, 14.722795225794673, 13.761425937525667, 12.805895425550139, 12.09012684215081, 12.823690740035119, 13.503730184858815, 8.613348280636558, 7.947526702975927, 6.949550845496845, 7.849782182076748, 8.714935260705499, 9.722882419957589, 10.683793298834917, 11.725408011906714, 12.674643115921889, 13.615415122860133, 14.540792798874906, 15.463565081221489, 16.421346189889896, 16.458105107350423, 15.678375498823375, 14.686507994713818, 13.752653798542225, 13.035173186393866, 13.8269881356771, 14.458214234007004, 7.633791898550111, 6.9599139641755965, 5.919277191619905, 6.778288546852449, 7.745200275714397, 8.783432577143188, 9.740811153221866, 10.699564514211428, 11.664317526024046, 12.705078737786124, 13.611517269873199, 14.491896338206523, 15.450841810999755, 16.40788708533833, 16.66388793404708, 15.723492992582264, 14.683875109534542, 13.967044836271294, 14.753634321200984, 15.515785803067523, 6.653525504672994, 5.910397806300743, 4.848383766088345, 5.819624598352374, 6.847118196003963, 7.816964064154409, 8.797737065456522, 9.73447599276648, 10.766175943770797, 11.758330426267626, 12.54965723344622, 13.51152120534746, 14.545883766781076, 15.530473928201804, 16.551884620729705, 16.65654122457788, 15.698163088948187, 14.981668334442126, 15.71606645382391, 16.546004075154425, 5.733189642573615, 4.883032923043871, 3.9150768036881507, 4.870419721298905, 5.864408338933772, 6.930244707107836, 7.82208542296117, 8.737539873920442, 9.773863917403066, 10.707511658012269, 11.603113651732773, 12.593449010008243, 13.567793741450542, 14.560582841210124, 15.539288729518946, 16.566318728656366, 16.73376898115732, 15.979031896021574, 16.779429679136044, 17.584397420049658, 4.879278583317788, 3.978306096215394, 2.9852753302833865, 3.9969276446486433, 4.955063047426291, 5.8782043176626395, 6.890109286856115, 7.7477898823516895, 8.73651808059162, 9.650257108979572, 10.651299320604204, 11.66116998826148, 12.641278821588767, 13.605962636174606, 14.598081060817206, 15.543460139586982, 16.472853737909308, 16.990983036213027, 17.82950746986867, 18.597956580985638, 3.9817575394378597, 2.967527007349833, 2.034011152053856, 3.0309362268029867, 3.972388117504515, 4.926159879017117, 5.869113056291901, 6.8080083634796, 7.745049636728536, 8.680816220136506, 9.753834145164797, 10.736755901393341, 11.721608276976397, 12.707345144356719, 13.727116893777664, 14.706995642865698, 15.668175248926023, 16.63166078996373, 17.580685885253693, 18.53150053481463, 3.0457164553447926, 2.0201364994125, 0.9910453861647287, 1.9697567468799506, 2.9548692952742392, 3.988604146251282, 4.8865022769583, 5.881770460027098, 6.945959072666168, 7.923606718025224, 8.87946971434942, 9.778655570311964, 10.792905305682254, 11.790385383769795, 12.744004993989996, 13.733004012914998, 14.748046749498853, 15.728354342007895, 16.742543276722103, 17.810261873762308], [17.92847337219134, 16.91308967282439, 15.92200729505822, 14.862461710273521, 13.922944328675687, 12.872486170671953, 11.8914108729546, 10.925409381282694, 9.90617989103409, 8.967465138382378, 8.03872566385843, 7.081293601099324, 6.008349124945773, 4.998491653382597, 4.065670285005041, 3.0739879925527074, 2.02257453786562, 1.0598460544121897, 0.0, 1.0678160117082796, 18.641081582340657, 17.7110251391542, 16.73838455966186, 15.798038749399785, 14.815656537657897, 13.812685496925882, 12.84618724784166, 11.860781352795419, 10.845943840380658, 9.87856343002491, 8.878415670755208, 7.8857762080045415, 6.937581860058226, 5.932526860603797, 5.001284994676086, 4.022558781759249, 2.982622313588011, 2.0069231239162777, 1.0276197062456625, 2.0433542137153093, 18.672394753528415, 18.088002969583233, 17.74748935506181, 16.747097945083826, 15.749706005153143, 14.778507070628386, 13.80847925546471, 12.8073508672608, 11.868121225936358, 10.927235216883934, 9.869344922139003, 8.832156100035355, 7.886282598554686, 6.917014957176329, 5.97571461246396, 5.0171287606176955, 3.9536718603518373, 2.9256276565027863, 1.9861151993206194, 3.0026219991223897, 17.660075644887854, 17.130248618689045, 17.77199744702071, 17.603890594423373, 16.67473938970375, 15.704804248022329, 14.748414300658858, 13.809131496986602, 12.8295111321853, 11.84338283084837, 10.886001759466993, 9.85836096635162, 8.835090499867377, 7.859350994936927, 6.937478628289944, 5.96681762242963, 4.915812028739248, 3.9015790222697557, 2.9145992823969227, 3.8545651428249794, 16.61478404379969, 16.137802604040637, 16.79422465765436, 17.70078491825596, 17.580233233671784, 16.653050671345504, 15.723372781771983, 14.740516214184316, 13.786660586055355, 12.813191043529606, 11.748489632915435, 10.74520643942678, 9.77868970720197, 8.843925076655752, 7.876821179557686, 6.91298432028146, 5.881190443094907, 4.833322587404933, 3.9569736573800247, 4.80583856236755, 15.552674312151366, 15.130624327722849, 15.801174546514023, 16.75130314125418, 17.480159061354417, 17.652894862259856, 16.685088132150213, 15.785995226318729, 14.72482904103717, 13.694152728648195, 12.690277725208276, 11.75510772144731, 10.743733499254994, 9.845138629041983, 8.897225338270726, 7.9628087956422196, 6.9225928959391805, 5.8693370262511655, 4.958103280932788, 5.86339529900048, 14.508482168672627, 14.16662811405629, 14.783855811997805, 15.743015534055356, 16.51421958556631, 17.46246694327075, 17.661876787979537, 16.674143691062664, 15.704537369262482, 14.680326197134956, 13.666893217582784, 12.70049633550185, 11.688695613238794, 10.807114217337979, 9.875805697153524, 8.888800138926396, 7.86513838876953, 6.922312048394675, 5.999390905366759, 6.833108588726526, 13.577853536692267, 13.169547935659082, 13.758403717204528, 14.73405558093315, 15.480993422530725, 16.420729683941524, 17.46020213507027, 17.615765248456178, 16.657481180020106, 15.658060622387152, 14.648310458585332, 13.672113702367712, 12.673958978082865, 11.83335374649109, 10.799054775089042, 9.779271591391867, 8.831851672072998, 7.9042526400596165, 6.949006815013995, 7.821761507511541, 12.70023812270457, 12.215461387904902, 12.790340920326072, 13.744626732020517, 14.555169764114797, 15.537423372206522, 16.503630944486208, 17.40743896035687, 17.62556319591639, 16.60221476721913, 15.584300950385005, 14.545339947147452, 13.56576680150553, 12.639266022983096, 11.684525367973515, 10.757075481919932, 9.85676494587536, 8.971093453431967, 8.01161164586777, 8.789802235310251, 11.748020441480984, 11.156882072533556, 11.842878428535187, 12.697884193469857, 13.610198213230953, 14.563255760754389, 15.499544884563958, 16.45289743351011, 17.44212387494147, 17.5607107756432, 16.49500123092023, 15.549011041504663, 14.608711493582183, 13.632035732247449, 12.683057521688912, 11.755430552179705, 10.83125492791753, 9.904391354974694, 8.964166179408306, 9.783812174797166, 10.738097173124315, 10.212073902661386, 10.806041765666537, 11.658482721194291, 12.56702051411389, 13.495385980443709, 14.494735880284656, 15.396716316638791, 16.415714794460428, 17.460438923367228, 17.48293575763633, 16.514171529270918, 15.630560253714245, 14.566824141256387, 13.71974869072759, 12.825032784165556, 11.851796500512304, 10.907206624262225, 9.88953661321982, 10.72965684006064, 9.819060837396396, 9.20222134909169, 9.749907856754914, 10.602029833952177, 11.544005020546107, 12.47714820921674, 13.492747587871623, 14.465344681163847, 15.443249761413615, 16.500788742849696, 17.42688257517245, 17.468390324777666, 16.545490359090437, 15.537497600882766, 14.760525278486123, 13.80684922959946, 12.805339535314555, 11.947579787316483, 10.928282891198641, 11.700464744193843, 8.75274578676283, 8.166022915606785, 8.781422217320731, 9.629093527971929, 10.572378190193556, 11.526920316533616, 12.475774244380288, 13.470573398164102, 14.485987247928229, 15.477388413123952, 16.41019029078419, 17.40407879494086, 17.47070848243299, 16.525982587865126, 15.723912681905228, 14.76254339363622, 13.807012881660691, 12.880201536614432, 11.945783281781338, 12.625822726605035, 7.735440822382778, 7.115771565841423, 7.796263582620036, 8.696494919199939, 9.561647997828691, 10.56959515708078, 11.530506035958108, 12.584391223471485, 13.53362632748666, 14.474398334424905, 15.524800175715429, 16.452645125133067, 17.44025696273176, 17.45922256346098, 16.67949295493393, 15.68762545082437, 14.753771254652778, 13.82524788085749, 12.94908067742332, 13.580306775753224, 6.755884440296332, 6.1281588270410925, 6.765989928743096, 7.6250012839756405, 8.591913012837589, 9.630145314266379, 10.587523890345057, 11.558547725776199, 12.523300737588817, 13.564061949350895, 14.630428042715064, 15.510807111048388, 16.46975258384162, 17.426797858180194, 17.665005390157635, 16.724610448692818, 15.684992565645095, 14.757119530734917, 13.875726862947204, 14.637878344813743, 5.775618046419215, 5.055849342699992, 5.695096503211536, 6.666337335475565, 7.693830933127154, 8.6636768012776, 9.644449802579713, 10.593459204331252, 11.661421103843562, 12.670687136502714, 13.568568006288086, 14.530431978189325, 15.564794539622941, 16.549384701043667, 17.570795393571572, 17.65765868068843, 16.699280545058738, 15.77174302890575, 14.83815899557013, 15.668096616900645, 4.855282184319835, 4.005568852431804, 4.761789540811341, 5.717132458422095, 6.711121076056962, 7.7769574442310265, 8.78020632828362, 9.756450646762307, 10.792774690244931, 11.726422430854134, 12.622024424574638, 13.612359782850108, 14.586704514292407, 15.579493614051989, 16.55819950236081, 17.585229501498233, 17.734886437267868, 16.769106590485197, 15.901522220882264, 16.706489961795878, 3.9197657576244693, 2.954349664798366, 3.831988067406577, 4.843640381771834, 5.801775784549482, 6.861375427677433, 7.90902005969798, 8.766700655193555, 9.755428853433486, 10.669167881821437, 11.67021009344607, 12.680080761103346, 13.660189594430632, 14.624873409016471, 15.616991833659071, 16.562370912428847, 17.491764510751175, 17.78105773067665, 16.95160001161489, 17.720049122731858, 2.942491061446864, 1.9435705759328048, 2.880723889177047, 3.887543679277214, 4.942220834694936, 5.945070651858982, 6.8880238291337665, 7.826919136321465, 8.763960409570402, 9.699726992978372, 10.772744918006662, 11.755666674235206, 12.74327549151549, 13.729012358895812, 14.786962948189851, 15.766841697277885, 16.72802130333821, 17.691506844375915, 17.967962644804036, 18.7531955627857, 2.006449977353797, 0.9961800679954719, 2.025271181243243, 3.02960280129214, 4.014715349686429, 5.0484502006634715, 5.94634833137049, 6.941616514439287, 8.005805127078357, 8.983452772437412, 9.939315768761608, 10.83850162472415, 11.852751360094441, 12.850231438181982, 13.803851048402183, 14.792850067327185, 15.80789280391104, 16.78820039642008, 17.802389331134286, 18.87010792817449], [18.99628938389962, 17.98090568453267, 16.9898233067665, 15.930277721981799, 14.990760340383964, 13.940302182380231, 12.959226884662877, 11.993225392990972, 10.97399590274237, 10.035281150090658, 9.10654167556671, 8.149109612807603, 7.076165136654052, 6.066307665090877, 5.13348629671332, 4.141804004260987, 3.0903905495738995, 2.127662066120469, 1.0678160117082796, 0.0, 18.772844180557136, 18.778841150862476, 17.806200571370137, 16.865854761108064, 15.883472549366175, 14.88050150863416, 13.914003259549938, 12.928597364503698, 11.913759852088937, 10.94637944173319, 9.94623168246349, 8.953592219712823, 8.005397871766506, 7.000342872312077, 6.063251700303361, 5.084525487386525, 4.0445890192152865, 3.01368726587177, 2.0343838482011547, 1.0186493407315076, 17.766490518061982, 18.463909648341936, 18.815305366770087, 17.814913956792104, 16.81752201686142, 15.846323082336664, 14.876295267172987, 13.875166878969079, 12.935937237644637, 11.995051228592216, 10.937160933847284, 9.899972111743637, 8.948249304181962, 7.978981662803605, 7.037681318091236, 6.059533483655591, 4.9960765833897325, 3.9323917984582786, 2.9928793412761117, 1.977917126138588, 16.75417140942142, 17.506155297447748, 18.469321151251496, 18.67170660613165, 17.742555401412027, 16.77262025973061, 15.816230312367136, 14.87239369879868, 13.888585728115785, 12.902457426778856, 11.945076355397479, 10.917435562282106, 9.894165095797863, 8.918425590867413, 7.9459221627050765, 6.975261156844763, 5.92257617069474, 4.908343164225248, 3.8886267677866013, 2.9486609073585446, 15.708879808333258, 16.51370928279934, 17.491548361885148, 18.48304703999012, 18.648049245380058, 17.720866683053778, 16.79118879348026, 15.780738956431541, 14.82688332830258, 13.853413785776832, 12.78871237516266, 11.785429181674006, 10.818912449449195, 9.87817858786673, 8.883585321513179, 7.919748462236953, 6.8879545850504, 5.840086729360425, 4.845374575431155, 3.899934326901115, 14.64677007668493, 15.506531006481554, 16.531047542049908, 17.53356526298834, 18.434254694647855, 18.72071087396813, 17.752904143858487, 16.826217968565953, 15.765051783284395, 14.73437547089542, 13.730500467455501, 12.795330463694535, 11.783956241502219, 10.87939214025296, 9.903989480226219, 8.966573581410586, 7.9077257795894855, 6.842851540277967, 5.846504198983918, 4.957491063534045, 13.602577933206192, 14.542534792814996, 15.51372880753369, 16.532270436608908, 17.468315218859747, 18.416562576564186, 18.72969279968781, 17.714366433309888, 16.744760111509706, 15.720548939382182, 14.70711595983001, 13.740719077749075, 12.72891835548602, 11.811439115848705, 10.88013059566425, 9.827427770236564, 8.8037660200797, 7.860939679704844, 6.856270181784623, 5.927204353260091, 12.671949301225832, 13.73641456464193, 14.639895891839382, 15.628112871099527, 16.43508905582416, 17.374825317234958, 18.414297768363703, 18.6559879907034, 17.69770392226733, 16.69827077275394, 15.688520608952121, 14.712323852734501, 13.714169128449655, 12.775964493674541, 11.712620610048798, 10.692837426351623, 9.745417507032755, 8.76113191647748, 7.805886091431859, 6.9158572720451055, 11.794333887238135, 12.78232801688775, 13.671833094960926, 14.638684022186894, 15.509265397408235, 16.49151900549996, 17.45772657777965, 18.36153459365031, 18.539129030876143, 17.515780602178886, 16.497866785344762, 15.458905782107209, 14.479332636465287, 13.552831857942852, 12.598091202933272, 11.670641316879689, 10.770330780835117, 9.827972729849831, 8.868490922285634, 7.883897999843816, 10.842116206014548, 11.723748701516403, 12.72437060317004, 13.651979826763297, 14.564293846524393, 15.517351394047829, 16.453640517857398, 17.406993066803548, 18.396219508234907, 18.474276610602956, 17.408567065879986, 16.462576876464418, 15.52227732854194, 14.545601567207205, 13.596623356648669, 12.668996387139462, 11.7420323055479, 10.761270631392557, 9.82104545582617, 8.877907939330731, 9.83219293765788, 10.778940531644233, 11.760137398959976, 12.61257835448773, 13.52111614740733, 14.449481613737149, 15.448831513578096, 16.35081194993223, 17.369810427753865, 18.414534556660666, 18.396501592596085, 17.427737364230673, 16.544126088674002, 15.480389976216143, 14.633314525687346, 13.738598619125312, 12.762573878142675, 11.764085900680088, 10.746415889637683, 9.823752604594205, 8.91315660192996, 9.883158873362166, 10.704003490048354, 11.556125467245616, 12.498100653839547, 13.43124384251018, 14.446843221165063, 15.419440314457287, 16.397345394707052, 17.454884376143134, 18.38097820846589, 18.38195615973742, 17.45905619405019, 16.45106343584252, 15.672251373865182, 14.71762660722983, 13.716116912944926, 12.804459063734347, 11.785162167616505, 10.794560508727407, 7.846841551296394, 8.846960439877261, 9.73551785061417, 10.583189161265368, 11.526473823486995, 12.481015949827055, 13.429869877673728, 14.424669031457542, 15.440082881221668, 16.431484046417392, 17.36428592407763, 18.358174428234303, 18.384274317392745, 17.43954842282488, 16.63556844632678, 15.67332077126659, 14.628290209984247, 13.652183079861139, 12.717764825028045, 11.7199184911386, 6.825145073196773, 7.796709090111899, 8.750359215913477, 9.650590552493378, 10.515743631122131, 11.52369079037422, 12.484601669251548, 13.538486856764925, 14.4877219607801, 15.428493967718344, 16.47889580900887, 17.40674075842651, 18.3943525960252, 18.372788398420735, 17.59114871935548, 16.56806762680438, 15.575048582976333, 14.597229424104196, 13.698879579735005, 12.674402540286788, 5.8455886911103265, 6.88372518191307, 7.720085562036536, 8.57909691726908, 9.546008646131028, 10.584240947559818, 11.541619523638497, 12.512643359069639, 13.477396370882257, 14.518157582644335, 15.584523676008502, 16.464902744341828, 17.42384821713506, 18.380893491473635, 18.50358543762301, 17.54588777701637, 16.50626989396865, 15.529101073981623, 14.625525765258889, 13.731974109347307, 4.8653222972332095, 5.81141569757197, 6.6491921365049755, 7.620432968769005, 8.647926566420594, 9.61777243457104, 10.598545435873152, 11.547554837624691, 12.615516737137002, 13.624782769796152, 14.522663639581523, 15.484527611482763, 16.51889017291638, 17.503480334337105, 18.524891026865006, 18.478936009011985, 17.520557873382295, 16.543724572152456, 15.587957897881815, 14.762192381434211, 3.9245217549303053, 4.888953729842521, 5.7158851741047805, 6.671228091715535, 7.665216709350402, 8.731053077524466, 9.73430196157706, 10.710546280055745, 11.746870323538369, 12.680518064147572, 13.576120057868076, 14.566455416143546, 15.540800147585845, 16.53358924734543, 17.51229513565425, 18.539325134791667, 18.53241338137179, 17.541088133731904, 16.65132112319395, 15.800585726329444, 2.8519497459161895, 3.8957361826271844, 4.786083700700016, 5.797736015065272, 6.75587141784292, 7.815471060970871, 8.86311569299142, 9.720796288486993, 10.709524486726924, 11.623263515114875, 12.624305726739507, 13.634176394396784, 14.61428522772407, 15.57896904230991, 16.57108746695251, 17.516466545722285, 18.445860144044612, 18.553039273923357, 17.701398913926575, 16.814144887265424, 1.8746750497385842, 2.8976662092262435, 3.8348195224704855, 4.841639312570653, 5.896316467988375, 6.899166285152422, 7.842119462427206, 8.781014769614904, 9.71805604286384, 10.65382262627181, 11.7268405513001, 12.709762307528644, 13.697371124808928, 14.68310799218925, 15.741398464002966, 16.760823285475528, 17.72200289153585, 18.685488432573557, 18.71776154711572, 17.847291327319265, 0.9386339656455174, 1.9642139215778096, 2.993305034825581, 4.009434544715091, 5.082531361394708, 6.116266212371751, 7.014164343078769, 8.009432526147567, 9.073621138786637, 10.051268784145691, 11.007131780469887, 11.90631763643243, 12.920567371802719, 13.91804744989026, 14.871667060110461, 15.860666079035463, 16.87570881561932, 17.85601640812836, 18.870205342842567, 18.798976974856114], [1.0024633271472823, 1.8746122527363742, 2.865694630502545, 3.810712876489343, 4.750230258087178, 5.768595411668706, 6.749670709386059, 7.715672201057965, 8.734901691306568, 9.67361644395828, 10.602355918482228, 11.559787981241335, 12.632732457394887, 13.642589928958063, 14.57541129733562, 15.567093589787953, 16.61850704447504, 17.581235527928474, 18.641081582340664, 18.772844180557136, 0.0, 0.9300564431864602, 1.9026970226787983, 2.8430428329408723, 3.8254250446827607, 4.828396085414777, 5.875913505699701, 6.917334564458248, 7.932172076873009, 8.937005873312328, 9.93715363258203, 10.929793095332696, 11.877987443279013, 12.883042442733442, 13.833688577366534, 14.81241479028337, 15.852351258454608, 16.883253011798125, 17.86255642946874, 17.75419483982563, 1.0063536624951561, 1.8630880366577305, 2.9050700438114987, 3.8634975799095486, 4.77107827024496, 5.742277204769717, 6.788184742425749, 7.832295886745902, 8.791114123305793, 9.831801675503534, 10.899871780323709, 11.87617298736351, 12.907942167453966, 13.877209808832323, 14.808118195154409, 15.842841560852133, 16.823400805218434, 17.827310788484446, 17.692633216702948, 16.794927054418547, 2.0186727711357175, 2.8208423875519175, 3.842281407744712, 4.874069565285816, 5.789702069836769, 6.719919807801965, 7.676309755165436, 8.705943327189752, 9.689751297872647, 10.675879599209576, 11.633260670590953, 12.660901463706326, 13.684171930190569, 14.65991143512102, 15.632414863283355, 16.60307586914367, 17.655760855293693, 17.78009862553101, 16.764149133626645, 15.82418327319859, 3.0639643722238796, 3.8132884022003255, 4.791127481286133, 5.8546469187724846, 6.775335461513976, 7.702518023840255, 8.632195913413774, 9.671035198232985, 10.624890826361947, 11.598360368887695, 12.605923083745568, 13.59644842355464, 14.562965155779452, 15.503699017361917, 16.498292283715468, 17.462129142991696, 17.74156771552406, 16.848355060395832, 15.817122903808313, 14.87290985365602, 4.126074103872206, 4.8204666785181125, 5.784177592426472, 6.7866953133649055, 7.752882893087819, 8.71586392700357, 9.593911263792002, 10.626301810153311, 11.563059281343762, 12.565630100508837, 13.547711176038408, 14.491906254970226, 15.503280477162543, 16.48787801340103, 17.464238124710516, 17.68637278506928, 16.700165262679786, 15.812340621549598, 14.81599328025555, 13.815353117023092, 5.170266247350945, 5.78446289218467, 6.755656906903365, 7.774198535978581, 8.718822368875928, 9.683110251995169, 10.570699919621326, 11.621981058175763, 12.591587379975943, 13.551803568995599, 14.54378740638044, 15.437294869024766, 16.448242591146343, 17.47253413768865, 17.46348488142125, 16.615860611424473, 15.62558709066694, 14.779375153741798, 13.774705655821577, 12.845639827297045, 6.100894879331305, 6.781543070581877, 7.744875778885508, 8.783158489100787, 9.752048531911512, 10.691784793322311, 11.632619754453335, 12.578794011042655, 13.537078079478725, 14.546439857859154, 15.556190021660974, 16.418602875213267, 17.416757599498112, 17.2755409667457, 16.489916215453416, 15.545778235503427, 14.658873807363472, 13.821778699622948, 12.866532874577327, 11.856986908512031, 7.0333134917237015, 7.7356296183360564, 8.712938575763964, 9.679789502989932, 10.635447639249486, 11.617701247341211, 12.612619878045761, 13.54814378288119, 14.528412450448876, 15.537834936882529, 16.555748753716653, 17.44472773955519, 17.237758486901626, 16.31125770837919, 15.495424231028945, 14.567974344975362, 13.63396053356111, 12.801702469856071, 11.820394413495054, 10.88894618071332, 8.087055427558033, 8.794208933707404, 9.660401067554849, 10.654477261278334, 11.58041919013333, 12.561690198711698, 13.497979322521267, 14.502685309727951, 15.474796990919117, 16.404634826140327, 17.4703443708633, 17.2382521514865, 16.341608778028572, 15.318487999114836, 14.533549433803849, 13.65316810539941, 12.65947055151894, 11.868404568313345, 10.867839879954518, 9.894936241226405, 9.096978695914702, 9.739017103579574, 10.697237730423499, 11.6938787335539, 12.623596889250393, 13.551962355580212, 14.530749089879055, 15.490033603638313, 16.50903208145995, 17.406212924250788, 17.312823382159262, 16.273091663720244, 15.295479343829422, 14.383699590105898, 13.496858264765171, 12.583565873413558, 11.638928978924165, 10.807919571856258, 9.942469446143004, 8.949091575962932, 10.028476306192497, 10.74886965714927, 11.742597682722002, 12.750331620796015, 13.646612382818176, 14.605848260612625, 15.532737382292089, 16.421405239113255, 17.492573090239098, 17.226999422151636, 16.28748949915391, 15.318872868213495, 14.287480658043638, 13.413026130479519, 12.456081677006638, 11.562509171274215, 10.685385944121913, 9.7513786605314, 8.90372316816418, 7.978283671829729, 11.094791356826065, 11.785068090634175, 12.711083322156185, 13.645195086578562, 14.618239213170728, 15.556076153295749, 16.526210340764177, 17.416176522113, 17.21937724675827, 16.20359909242589, 15.27079721476565, 14.326221802500028, 13.362262534701085, 12.42454114349716, 11.492694273587533, 10.606815007237454, 9.683712597775777, 8.738410958400186, 7.886222777581483, 7.052925689418537, 12.147164038066952, 12.835319440399537, 13.696241956856879, 14.577793695350552, 15.58263752850584, 16.513401312748584, 17.471478549186354, 17.243312144727565, 16.294077040712388, 15.353305033774145, 14.30290319248362, 13.37505824306598, 12.414948406147921, 11.491301167901305, 10.537114000558832, 9.681732950049303, 8.736954224783691, 7.793364614157128, 6.8829253819395015, 6.123153793918636, 13.126720420153399, 13.822932179199867, 14.72651561073382, 15.64928733057485, 16.55237251349694, 17.452851155562985, 17.49778284150025, 16.467572843239243, 15.502819831426626, 14.52173467323594, 13.449831947788052, 12.403389500051015, 11.444444027257783, 10.487398752919205, 9.55160156533513, 8.628289410609934, 7.805732913791375, 6.861492964279702, 5.956279196415617, 5.065582224858117, 14.106986814030515, 14.895241663540967, 15.79740903626538, 16.607951279074925, 17.568981638089358, 17.494941515392764, 16.514168514090652, 15.565159112339114, 14.527109799075596, 13.517843766416446, 12.466679826142665, 11.504815854241425, 10.582464652402836, 9.597874490982107, 8.585128584931782, 7.695241178614319, 6.791444934377731, 5.846869466108869, 4.993847063792692, 4.035363952771214, 15.04778735633342, 15.945522153809156, 16.730715998665573, 17.580961348065163, 17.58907439146593, 16.523238023291867, 15.519989139239275, 14.568222993493077, 13.569849549526115, 12.592679500567105, 11.527635659960263, 10.537300301684793, 9.617707235916008, 8.5780636546974, 7.572532693721023, 6.736386646111982, 5.7558390421686, 4.849505904529422, 3.96816366623849, 2.9969706078759817, 16.120359365347536, 16.996741341442593, 17.66051747207034, 17.600230346526878, 16.64209494374923, 15.590768475855459, 14.58801300313422, 13.578473001924324, 12.507300159335944, 11.579148976856915, 10.578106765232283, 9.568236097575006, 8.58812726424772, 7.623443449661882, 6.631325025019283, 5.685945946249507, 4.7565523479271805, 3.837554764337968, 2.918085875505865, 1.98341144694, 17.09763406152514, 18.007520430308155, 17.703070799891872, 16.696251009791705, 15.641573854373982, 14.638724037209936, 13.695770859935152, 12.756875552747454, 11.819834279498519, 10.884067696090549, 9.811049771062258, 8.828128014833714, 7.840519197553431, 6.85478233017311, 5.796491858359394, 4.777067036886832, 3.815887430826508, 2.852401889788803, 1.9033767944988371, 0.9502650068861584, 18.033675145618208, 18.954910938245487, 18.572280914093202, 17.582629185323054, 16.507820946921676, 15.576279769975772, 14.590446606945957, 13.565999846888403, 12.525688135912945, 11.547083027061209, 10.710583404845941, 9.667223424996628, 8.643014179869711, 7.667293682768888, 6.713674072548686, 5.7510586668375305, 4.851065876893552, 3.888445711368372, 2.8752148292464534, 1.9019506544230085], [1.9325197703337424, 0.944555809549914, 1.9356381873160844, 2.880656433302883, 3.8201738149007176, 4.838538968482245, 5.819614266199599, 6.785615757871504, 7.804845248120107, 8.74356000077182, 9.672299475295768, 10.629731538054875, 11.702676014208427, 12.712533485771603, 13.64535485414916, 14.637037146601493, 15.68845060128858, 16.65117908474201, 17.711025139154202, 18.778841150862483, 0.9300564431864602, 0.0, 0.9726405794923381, 1.9129863897544124, 2.8953686014963007, 3.8983396422283167, 4.945857062513241, 5.987278121271787, 7.002115633686548, 8.006949430125868, 9.00709718939557, 9.999736652146236, 10.947931000092552, 11.952985999546982, 12.903632134180073, 13.88235834709691, 14.922294815268147, 15.953196568611663, 16.932499986282277, 17.948234493751926, 1.9336262246666216, 0.9330315934712703, 1.9750136006250385, 2.933441136723089, 3.8410218270585, 4.812220761583258, 5.858128299239289, 6.902239443559442, 7.861057680119332, 8.901745232317074, 9.969815337137248, 10.94611654417705, 11.977885724267505, 12.947153365645862, 13.878061751967948, 14.912785117665672, 15.893344362031973, 16.897254345297984, 17.836766802480152, 17.419024115674617, 2.9365418254605546, 1.890785944365457, 2.912224964558252, 3.9440131220993564, 4.85964562665031, 5.789863364615505, 6.746253311978976, 7.775886884003292, 8.759694854686186, 9.745823156023116, 10.703204227404495, 11.730845020519867, 12.75411548700411, 13.72985499193456, 14.702358420096896, 15.673019425957209, 16.72570441210723, 17.739937418576723, 17.38824619488272, 16.44828033445466, 3.932430686349136, 2.883231959013865, 3.861071038099673, 4.924590475586025, 5.845279018327517, 6.772461580653796, 7.702139470227315, 8.740978755046525, 9.694834383175486, 10.668303925701235, 11.675866640559109, 12.666391980368182, 13.632908712592993, 14.573642574175459, 15.56823584052901, 16.532072699805237, 17.563866576991792, 17.4724521216519, 16.44121996506438, 15.49700691491209, 4.908485266251329, 3.8904102353316525, 4.854121149240012, 5.856638870178445, 6.822826449901361, 7.785807483817111, 8.663854820605543, 9.696245366966853, 10.633002838157301, 11.635573657322377, 12.61765473285195, 13.561849811783768, 14.573224033976084, 15.557821570214573, 16.534181681524057, 17.477339727798945, 17.42087672738557, 16.436437682805668, 15.440090341511619, 14.439450178279161, 5.794363308607014, 4.85440644899821, 5.825600463716905, 6.844142092792122, 7.788765925689471, 8.75305380880871, 9.640643476434867, 10.691924614989304, 11.661530936789484, 12.621747125809138, 13.613730963193982, 14.507238425838308, 15.518186147959884, 16.542477694502193, 17.473786214686648, 17.369960305529588, 16.346298555372723, 15.403472214997867, 14.398802717077647, 13.469736888553115, 6.724991940587374, 5.851486627395419, 6.814819335699049, 7.853102045914327, 8.821992088725056, 9.761728350135854, 10.702563311266877, 11.648737567856196, 12.607021636292266, 13.616383414672693, 14.626133578474514, 15.488546432026807, 16.486701156311653, 17.42490579108677, 17.319266486751708, 16.375128506801722, 15.430161351434293, 14.445875760879018, 13.490629935833397, 12.4810839697681, 7.657410552979771, 6.805573175149598, 7.782882132577505, 8.749733059803473, 9.705391196063028, 10.687644804154752, 11.682563434859302, 12.618087339694732, 13.598356007262417, 14.607778493696069, 15.625692310530193, 16.51467129636873, 17.49424444201065, 17.24131415156565, 16.324774502327237, 15.397324616273655, 14.463310804859404, 13.49771453878735, 12.452524096325385, 11.51304324196939, 8.711152488814102, 7.8641524905209454, 8.73034462436839, 9.724420818091875, 10.650362746946872, 11.63163375552524, 12.567922879334809, 13.572628866541493, 14.544740547732658, 15.474578382953867, 16.54028792767684, 17.486278117092407, 17.27166522121503, 16.248544442301295, 15.463605876990309, 14.558321305852518, 13.548396192797355, 12.567634518642013, 11.49996956278485, 10.519033302482475, 9.721075757170771, 8.808960660393115, 9.76718128723704, 10.763822290367441, 11.693540446063935, 12.621905912393753, 13.600692646692597, 14.559977160451854, 15.57897563827349, 16.47615648106433, 17.456099270629984, 17.203148106906703, 16.225535787015883, 15.313756033292359, 14.426914707951632, 13.513622316600019, 12.54061085066864, 11.592269140015741, 10.574599128973336, 9.573188637219001, 10.652573367448566, 9.81881321396281, 10.812541239535543, 11.820275177609556, 12.716555939631718, 13.675791817426166, 14.60268093910563, 15.491348795926797, 16.56251664705264, 17.461732578039967, 17.21754594234037, 16.248929311399955, 15.217537101230098, 14.34308257366598, 13.386138120193099, 12.492565614460675, 11.587067815866389, 10.622255041528359, 9.619946540573551, 8.602380733085798, 11.718888418082134, 10.855011647447716, 11.781026878969726, 12.715138643392104, 13.68818276998427, 14.62601971010929, 15.59615389757772, 16.48612007892654, 17.501533928690666, 17.13365553561235, 16.20085365795211, 15.256278245686488, 14.292318977887545, 13.35459758668362, 12.422750716773994, 11.536871450423915, 10.585394469520253, 9.609287339397145, 8.674869084564051, 7.677022750674606, 12.771261099323022, 11.905262997213079, 12.76618551367042, 13.647737252164093, 14.652581085319381, 15.583344869562126, 16.5414221059999, 17.483287547890402, 17.22413348389885, 16.283361476960607, 15.232959635670081, 14.305114686252441, 13.345004849334382, 12.421357611087766, 11.467170443745292, 10.611789393235764, 9.667010667970153, 8.668906554622923, 7.714233067979576, 6.760088944103846, 13.750817481409468, 12.892875736013409, 13.796459167547361, 14.719230887388392, 15.622316070310484, 16.522794712376527, 17.480173288455205, 17.33820170980632, 16.43287627461309, 15.4517911164224, 14.379888390974513, 13.333445943237475, 12.374500470444243, 11.417455196105665, 10.48165800852159, 9.558345853796395, 8.735789356977836, 7.737034904745496, 6.787586882455692, 5.854790177632512, 14.731083875286584, 13.965185220354508, 14.867352593078921, 15.677894835888466, 16.638925194902903, 17.52064123194021, 17.32212259011291, 16.373113188361373, 15.457166242262058, 14.447900209602908, 13.396736269329127, 12.434872297427887, 11.512521095589296, 10.527930934168568, 9.515185028118243, 8.62529762180078, 7.721501377564191, 6.776925909295329, 5.923903506979152, 4.965420395957675, 15.671884417589489, 15.015465710622697, 15.800659555479116, 16.650904904878704, 17.64489352251357, 17.33119209931413, 16.327943215261534, 15.376177069515334, 14.499905992712577, 13.522735943753567, 12.457692103146725, 11.467356744871255, 10.547763679102468, 9.508120097883861, 8.502589136907483, 7.6664430892984425, 6.6858954853550605, 5.779562347715882, 4.89822010942495, 3.927027051062442, 16.744456426603605, 16.066684898256135, 16.73046102888388, 17.668071248711065, 17.331864950076266, 16.280538482182497, 15.395967079156478, 14.386427077946582, 13.437356602522406, 12.509205420043378, 11.508163208418745, 10.498292540761469, 9.518183707434183, 8.553499892848343, 7.561381468205743, 6.616002389435968, 5.686608791113641, 4.767611207524428, 3.8481423186923256, 2.9134678901264603, 17.72173112278121, 17.077463987121696, 17.68172520711341, 17.386021016118743, 16.331343860701022, 15.328494043536976, 14.385540866262192, 13.446645559074494, 12.509604285825558, 11.573837702417588, 10.61219128148622, 9.629269525257676, 8.641660707977392, 7.736109318486927, 6.726548301545854, 5.707123480073292, 4.745943874012968, 3.7824583329752635, 2.8334332376852975, 1.8803214500726186, 18.657772206874277, 18.024854495059028, 17.64222447090674, 16.652572742136595, 15.577764503735215, 14.662462726850324, 13.660390163759496, 12.635943403701942, 11.595631692726485, 10.617026583874749, 9.780526961659481, 8.737166981810166, 7.71295773668325, 6.737237239582427, 5.783617629362226, 4.847814051201054, 3.9210094337070913, 2.9583892681819117, 2.011034222780471, 2.832007097609469], [2.9051603498260805, 1.917196389042252, 1.0363058206599793, 1.908015853810545, 2.8475332354083793, 3.865898388989907, 4.846973686707261, 5.812975178379166, 6.832204668627769, 7.770919421279482, 8.699658895803429, 9.657090958562536, 10.730035434716088, 11.739892906279264, 12.67271427465682, 13.664396567109154, 14.71581002179624, 15.678538505249671, 16.73838455966186, 17.80620057137014, 1.9026970226787983, 0.9726405794923381, 0.0, 0.9403458102620743, 1.9227280220039624, 2.9256990627359785, 3.9732164830209022, 5.014637541779448, 6.02947505419421, 7.034308850633529, 8.03445660990323, 9.027096072653897, 9.975290420600214, 10.980345420054643, 11.930991554687735, 12.90971776760457, 13.949654235775808, 14.980555989119324, 15.95985940678994, 16.975593914259587, 2.9062668041589594, 1.9056721729636084, 1.051666930048885, 1.9608005572307508, 2.8683812475661616, 3.839580182090919, 4.88548771974695, 5.929598864067104, 6.888417100626993, 7.929104652824735, 8.99717475764491, 9.973475964684711, 11.005245144775166, 11.974512786153523, 12.90542117247561, 13.940144538173334, 14.920703782539634, 15.924613765805645, 16.864126222987814, 17.885619443081225, 3.9091824049528925, 2.863426523857795, 1.9888782939820984, 2.9713725426070177, 3.8870050471579716, 4.817222785123167, 5.7736127324866375, 6.803246304510953, 7.787054275193848, 8.773182576530777, 9.730563647912156, 10.758204441027528, 11.781474907511772, 12.757214412442222, 13.729717840604557, 14.70037884646487, 15.753063832614892, 16.767296839084384, 17.787494506734056, 17.420920913947, 4.905071265841474, 3.855872538506203, 2.966651083348447, 4.010055249245039, 4.872638438835178, 5.799821001161457, 6.729498890734976, 7.768338175554186, 8.722193803683147, 9.695663346208896, 10.70322606106677, 11.693751400875843, 12.660268133100654, 13.60100199468312, 14.59559526103667, 15.559432120312897, 16.59122599749945, 17.23935380979362, 17.413860544556723, 16.46964749440443, 5.881125845743668, 4.863050814823991, 3.959701194488786, 4.959537026246818, 5.850185870409022, 6.813166904324772, 7.6912142411132045, 8.723604787474514, 9.660362258664962, 10.662933077830038, 11.645014153359611, 12.589209232291429, 13.600583454483745, 14.585180990722234, 15.561541102031718, 16.504699148306607, 16.86896500767671, 16.203339370947386, 16.41273092100396, 15.4120907577715, 6.767003888099352, 5.827047028490548, 4.977019929005005, 5.967824633445642, 6.816125346197132, 7.7804132293163715, 8.668002896942529, 9.719284035496965, 10.688890357297145, 11.6491065463168, 12.641090383701643, 13.534597846345969, 14.545545568467546, 15.569837115009856, 16.50114563519431, 16.784660356421398, 15.794386835663865, 15.150364348803878, 15.371443296569986, 14.442377468045454, 7.697632520079712, 6.824127206887756, 6.0024720237982825, 6.976784586567847, 7.849351509232717, 8.789087770643516, 9.729922731774538, 10.676096988363858, 11.634381056799928, 12.643742835180355, 13.653492998982175, 14.515905852534468, 15.514060576819315, 16.45226521159443, 16.65871596045034, 15.714577980500351, 14.827673552360396, 14.111564423765426, 14.463270515325735, 13.45372454926044, 8.63005113247211, 7.778213754641935, 6.970534820676739, 7.937385747902707, 8.775175167648644, 9.757428775740369, 10.709922855366964, 11.645446760202393, 12.625715427770078, 13.63513791420373, 14.653051731037854, 15.54203071687639, 16.52160386251831, 16.407658444934572, 15.66422397602587, 14.736774089972286, 13.802760278558035, 13.044723610393074, 13.425164675817724, 12.485683821461729, 9.683793068306441, 8.836793070013282, 7.917997312467624, 8.912073506191108, 9.720146718532487, 10.701417727110854, 11.637706850920424, 12.599988287049154, 13.57209996824032, 14.501937803461528, 15.5676473481845, 16.51363753760007, 16.438009514583953, 15.414888735670218, 14.62995017035923, 13.74956884195479, 12.828270296515864, 12.111425708850348, 12.472610142277189, 11.491673881974814, 10.69371633666311, 9.781601239885452, 8.954833975336275, 9.951474978466674, 10.76332441764955, 11.691689883979368, 12.670476618278212, 13.62976113203747, 14.626121999243981, 15.503515901571989, 16.483458691137642, 16.369492400275625, 15.391880080384803, 14.48010032666128, 13.593259001320552, 12.67996660996894, 11.80772872392109, 11.05094071239326, 11.547239708465675, 10.54582921671134, 11.625213946940905, 10.791453793455148, 10.010967884247897, 11.007927865708789, 11.786339911217333, 12.745575789011781, 13.672464910691245, 14.561132767512412, 15.632300618638252, 16.48909199854763, 16.38389023570929, 15.415273604768876, 14.383881394599019, 13.5094268670349, 12.55248241356202, 11.658909907829596, 10.854185689118838, 9.9943998010684, 10.59258712006589, 9.575021312578137, 12.691528997574473, 11.827652226940053, 10.97945352368208, 11.913565288104458, 12.757966741569884, 13.695803681694905, 14.665937869163335, 15.555904050512156, 16.571317900276284, 16.29999982898127, 15.367197951321032, 14.422622539055409, 13.458663271256466, 12.520941880052542, 11.589095010142914, 10.703215743792835, 9.852512342772702, 8.981432098937187, 9.64750966405639, 8.649663330166945, 13.74390167881536, 12.877903576705414, 11.964612158382774, 12.846163896876448, 13.768696933934748, 14.65312884114774, 15.611206077585514, 16.55307151947602, 16.39047777726777, 15.449705770329526, 14.399303929039002, 13.471458979621362, 12.511349142703303, 11.587701904456686, 10.633514737114213, 9.778133686604685, 8.905753969780616, 8.03638575469413, 8.686873647471915, 7.732729523596184, 14.723458060901807, 13.865516315505744, 12.994885812259714, 13.917657532100746, 14.738431918925851, 15.592578683962142, 16.54995726004082, 16.36556113031398, 15.535040217254434, 14.583508723658086, 13.546232684343433, 12.499790236606396, 11.540844763813164, 10.583799489474586, 9.64800230189051, 8.724690147165315, 7.974532658788299, 7.104514104816703, 7.7602274619480305, 6.8274307571248505, 15.703724454778923, 14.937825799846843, 14.065779237791274, 14.87632148060082, 15.755041043518268, 16.590425203525825, 16.349482010620573, 15.400472608869034, 14.559330184903404, 13.559399436558902, 12.50823549628512, 11.546371524383881, 10.678865388958217, 9.694275227537489, 8.681529321487163, 7.7916419151697, 6.9602446793746555, 6.089890606645871, 6.89654408647149, 5.938060975450012, 16.644524997081827, 15.96704231954719, 14.999086200191469, 15.84933154959106, 16.79247186227431, 16.358551519821788, 15.355302635769194, 14.403536490022995, 13.567018158535673, 12.627892560801012, 11.569191330102718, 10.578855971827249, 9.691127355206307, 8.674464391252782, 7.668933430276404, 6.832787382667363, 5.924638787165525, 5.092527045066424, 5.870860688917288, 4.89966763055478, 17.717097006095944, 16.98454541254062, 15.928887673596233, 16.86649789342342, 16.359224370583927, 15.30789790269016, 14.423326499664139, 13.413786498454243, 12.498789194247344, 11.570638011768315, 10.619662435374739, 9.609791767717462, 8.629682934390177, 7.719844186217263, 6.727725761574664, 5.782346682804889, 4.925352092924105, 4.08057590487497, 4.820782898184664, 3.886108469618798, 18.021535531762478, 17.817305165070003, 16.88015185182576, 16.413380436626404, 15.358703281208683, 14.355853464044637, 13.412900286769853, 12.474004979582155, 11.53696370633322, 10.60119712292525, 9.639550701993882, 8.656628945765338, 7.669020128485054, 6.763468738994589, 5.794088949657555, 4.849165101659414, 3.9846871758234323, 3.0954230303258052, 3.8060738171776354, 2.8529620295649565, 18.724254960594465, 17.69867500466217, 16.6695838914144, 15.679932162644256, 14.605123924242877, 13.689822147357985, 12.687749584267157, 11.663302824209604, 10.622991113234146, 9.64438600438241, 8.807886382167142, 7.764526402317828, 6.740317157190912, 5.764596660090088, 4.810977049869887, 3.875173471708716, 2.9483688542147535, 2.059056901525807, 2.9836748022728092, 3.8046476771018067], [3.8455061600881546, 2.8575421993043264, 1.9766516309220536, 0.9676700435484706, 1.9071874251463052, 2.925552578727833, 3.9066278764451865, 4.872629368117092, 5.891858858365695, 6.830573611017408, 7.759313085541356, 8.716745148300463, 9.789689624454015, 10.799547096017191, 11.732368464394748, 12.724050756847081, 13.775464211534167, 14.738192694987598, 15.798038749399787, 16.865854761108068, 2.8430428329408723, 1.9129863897544124, 0.9403458102620743, 0.0, 0.9823822117418882, 1.9853532524739044, 3.032870672758828, 4.074291731517375, 5.0891292439321365, 6.093963040371456, 7.094110799641158, 8.086750262391826, 9.034944610338142, 10.039999609792572, 10.990645744425663, 11.9693719573425, 13.009308425513737, 14.040210178857254, 15.01951359652787, 16.035248103997517, 3.8466126144210344, 2.846017983225683, 1.9920127403109593, 1.0204547469686764, 1.9280354373040873, 2.899234371828845, 3.9451419094848763, 4.9892530538050295, 5.948071290364919, 6.988758842562662, 8.056828947382837, 9.03313015442264, 10.064899334513095, 11.034166975891452, 11.965075362213538, 12.999798727911262, 13.980357972277563, 14.984267955543576, 15.923780412725742, 16.945273632819156, 4.849528215214967, 3.80377233411987, 2.929224104244173, 2.0310267323449436, 2.946659236895897, 3.8768769748610925, 4.8332669222245634, 5.862900494248879, 6.8467084649317735, 7.832836766268703, 8.790217837650081, 9.817858630765453, 10.841129097249697, 11.816868602180147, 12.789372030342482, 13.760033036202795, 14.812718022352817, 15.82695102882231, 16.847148696471983, 17.78711455690004, 5.845417076103549, 4.796218348768278, 3.9069968936105215, 3.069709438982965, 3.9322926285731037, 4.859475190899383, 5.789153080472902, 6.827992365292113, 7.781847993421074, 8.755317535946823, 9.762880250804695, 10.753405590613768, 11.71992232283858, 12.660656184421045, 13.655249450774596, 14.619086310050822, 15.650880187237375, 16.69874804292735, 17.741282569892757, 17.409993304666504, 6.821471656005743, 5.803396625086066, 4.90004700475086, 4.019191215984744, 4.909840060146948, 5.872821094062699, 6.7508684308511295, 7.783258977212439, 8.72001644840289, 9.722587267567965, 10.704668343097536, 11.648863422029354, 12.66023764422167, 13.64483518046016, 14.621195291769643, 15.564353338044532, 15.928619197414633, 16.84984238792015, 17.353076731266032, 16.352436568033575, 7.707349698361427, 6.767392838752623, 5.917365739267079, 5.027478823183568, 5.875779535935058, 6.840067419054298, 7.727657086680454, 8.77893822523489, 9.74854454703507, 10.708760736054726, 11.700744573439568, 12.594252036083894, 13.60519975820547, 14.62949130474778, 15.560799824932236, 15.844314546159321, 14.854041025401788, 15.796867365776643, 16.31178910683206, 15.382723278307529, 8.637978330341788, 7.764473017149831, 6.942817834060357, 6.036438776305773, 6.909005698970643, 7.848741960381441, 8.789576921512463, 9.735751178101783, 10.694035246537853, 11.703397024918281, 12.713147188720102, 13.575560042272393, 14.57371476655724, 15.511919401332353, 15.718370150188262, 14.774232170238275, 13.88732774209832, 14.868824875324208, 15.403616325587809, 14.394070359522514, 9.570396942734185, 8.71855956490401, 7.910880630938813, 7.025867625218405, 7.834829357386569, 8.817082965478294, 9.769577045104889, 10.705100949940318, 11.685369617508004, 12.694792103941657, 13.71270592077578, 14.601684906614315, 15.581258052256237, 15.467312634672497, 14.723878165763793, 13.79642827971021, 12.862414468295958, 13.801984061951856, 14.365510486079799, 13.426029631723804, 10.624138878568516, 9.777138880275357, 8.858343122729698, 8.072610163769065, 8.779800908270413, 9.761071916848781, 10.69736104065835, 11.659642476787079, 12.631754157978245, 13.561591993199453, 14.627301537922426, 15.573291727337994, 15.497663704321878, 14.474542925408144, 13.689604360097157, 12.809223031692715, 11.887924486253787, 12.86868616040913, 13.412955952539264, 12.432019692236889, 11.634062146925185, 10.721947050147527, 9.895179785598348, 9.112011636044631, 9.822978607387476, 10.751344073717295, 11.730130808016138, 12.689415321775396, 13.685776188981906, 14.563170091309914, 15.543112880875567, 15.429146590013552, 14.45153427012273, 13.539754516399206, 12.65291319105848, 11.739620799706865, 10.867382913659014, 11.885007400661626, 12.48758551872775, 11.486175026973415, 12.56555975720298, 11.731799603717223, 10.95131369450997, 10.168464523286746, 10.84599410095526, 11.805229978749708, 12.732119100429172, 13.620786957250338, 14.69195480837618, 15.548746188285552, 15.443544425447218, 14.474927794506803, 13.443535584336946, 12.569081056772827, 11.612136603299946, 10.718564097567521, 9.913839878856763, 10.828466489336767, 11.532932930327966, 10.515367122840212, 13.631874807836546, 12.767998037202128, 11.919799333944153, 11.141400829266994, 11.817620931307811, 12.755457871432831, 13.725592058901261, 14.615558240250083, 15.63097209001421, 15.359654018719198, 14.426852141058959, 13.482276728793336, 12.518317460994393, 11.580596069790468, 10.648749199880841, 9.76286993353076, 8.912166532510627, 9.815498787205554, 10.587855474318465, 9.59000914042902, 14.684247489077434, 13.81824938696749, 12.904957968644847, 12.073999438038983, 12.828351123672675, 13.712783030885667, 14.670860267323441, 15.612725709213947, 15.450131967005698, 14.509359960067453, 13.458958118776929, 12.531113169359289, 11.57100333244123, 10.647356094194613, 9.69316892685214, 8.83778787634261, 7.965408159518541, 8.870452442962497, 9.62721945773399, 8.67307533385826, 15.66380387116388, 14.80586212576782, 13.935231622521787, 13.145493073263282, 13.798086108663778, 14.652232873700068, 15.609611449778747, 15.425215320051908, 14.59469440699236, 13.643162913396013, 12.60588687408136, 11.559444426344323, 10.60049895355109, 9.643453679212513, 8.707656491628438, 7.78434433690324, 7.0341868485262244, 7.93858079308507, 8.700573272210105, 7.7677765673869255, 16.644070265040998, 15.87817161010892, 15.006125048053347, 14.104157021763356, 14.814695233256195, 15.650079393263754, 15.4091362003585, 14.46012679860696, 13.61898437464133, 12.619053626296829, 11.567889686023047, 10.606025714121808, 9.738519578696142, 8.753929417275414, 7.741183511225089, 6.851296104907625, 6.0198988691125805, 6.923957294914238, 7.836889896733564, 6.8784067857120865, 17.584870807343904, 16.907388129809263, 15.939432010453542, 15.077167090753596, 15.85212605201224, 15.418205709559714, 14.41495682550712, 13.463190679760922, 12.6266723482736, 11.687546750538939, 10.628845519840645, 9.638510161565176, 8.750781544944232, 7.734118580990707, 6.72858762001433, 5.892441572405289, 4.9842929769034505, 5.926593733334791, 6.811206499179362, 5.840013440816854, 17.939036338469133, 17.924891222802692, 16.869233483858306, 16.09433343458596, 15.418878560321854, 14.367552092428086, 13.482980689402066, 12.47344068819217, 11.55844338398527, 10.630292201506242, 9.679316625112666, 8.66944595745539, 7.6893371241281026, 6.779498375955189, 5.78737995131259, 4.8420008725428145, 3.985006282662031, 4.914642593143337, 5.761128708446738, 4.826454279880872, 17.081189721500408, 17.41700772970874, 16.479854416464498, 15.473034626364331, 14.41835747094661, 13.415507653782564, 12.47255447650778, 11.533659169320082, 10.596617896071146, 9.660851312663176, 8.699204891731808, 7.7162831355032635, 6.72867431822298, 5.823122928732514, 4.85374313939548, 3.9088192913973403, 3.0443413655613583, 4.007826906599063, 4.7464196274397095, 3.7933078398270306, 17.78390915033239, 16.758329194400098, 15.729238081152326, 14.739586352382183, 13.664778113980804, 12.749476337095912, 11.747403774005084, 10.72295701394753, 9.682645302972073, 8.704040194120337, 7.867540571905069, 6.824180592055754, 5.799971346928838, 4.824250849828013, 3.870631239607813, 2.9348276614466418, 2.0080230439526794, 2.988330636461722, 3.9240206125348838, 4.744993487363881], [4.827888371830043, 3.8399244110462143, 2.928217179889133, 1.8686715951044335, 0.9291542135065989, 1.9431703669859446, 2.924245664703298, 3.890247156375204, 4.909476646623807, 5.848191399275519, 6.776930873799468, 7.734362936558575, 8.807307412712126, 9.817164884275302, 10.749986252652858, 11.741668545105192, 12.793081999792278, 13.755810483245709, 14.815656537657897, 15.883472549366177, 3.8254250446827607, 2.8953686014963003, 1.9227280220039624, 0.9823822117418882, 0.0, 1.002971040732016, 2.05048846101694, 3.0919095197754864, 4.106747032190247, 5.111580828629567, 6.111728587899269, 7.104368050649936, 8.052562398596251, 9.057617398050681, 10.008263532683772, 10.986989745600608, 12.026926213771846, 13.057827967115362, 14.037131384785978, 15.052865892255625, 4.828994826162922, 3.8284001949675703, 2.9434365754708676, 1.9430451654928838, 0.9456532255621991, 1.9168521600869566, 2.962759697742988, 4.006870842063141, 4.965689078623031, 6.006376630820773, 7.074446735640946, 8.05074794268075, 9.082517122771206, 10.051784764149563, 10.982693150471647, 12.017416516169371, 12.997975760535672, 14.001885743801683, 14.94139820098385, 15.962891421077261, 5.8319104269568545, 4.786154545861757, 3.880647939404081, 2.8934282298736322, 1.9642770251540091, 2.894494763119204, 3.850884710482675, 4.880518282506991, 5.864326253189885, 6.850454554526815, 7.807835625908193, 8.835476419023564, 9.858746885507808, 10.834486390438258, 11.806989818600593, 12.777650824460906, 13.830335810610928, 14.84456881708042, 15.864766484730092, 16.80473234515815, 6.827799287845436, 5.778600560510165, 4.8584207287704295, 3.880605550530562, 2.949910416831216, 3.877092979157495, 4.806770868731014, 5.845610153550224, 6.799465781679185, 7.7729353242049335, 8.780498039062806, 9.77102337887188, 10.73754011109669, 11.678273972679156, 12.672867239032707, 13.636704098308932, 14.668497975495486, 15.71636583118546, 16.758900358150868, 17.70434060668091, 7.80385386774763, 6.785778836827953, 5.832605048470775, 4.8300873275323415, 3.92745784840506, 4.89043888232081, 5.768486219109242, 6.8008767654705515, 7.737634236661, 8.740205055826076, 9.722286131355647, 10.666481210287465, 11.677855432479781, 12.66245296871827, 13.638813080027754, 14.581971126302642, 15.640818928123743, 16.70569316743526, 17.702040508729308, 17.33481877977546, 8.689731910103315, 7.74977505049451, 6.849923782986994, 5.838374934731165, 4.893397324193169, 5.857685207312409, 6.745274874938566, 7.796556013493003, 8.766162335293183, 9.726378524312837, 10.718362361697679, 11.611869824342005, 12.622817546463581, 13.647109093005891, 14.578417613190346, 14.877431156761894, 15.662396001965195, 16.605222342340053, 17.294171318573948, 16.365105490049416, 9.620360542083676, 8.746855228891718, 7.875375877780272, 6.84733488785337, 5.926623487228754, 6.866359748639552, 7.807194709770576, 8.753368966359895, 9.711653034795965, 10.721014813176392, 11.730764976978213, 12.593177830530504, 13.59133255481535, 14.529537189590464, 14.743325461609356, 13.807348780840847, 14.695682718661727, 15.677179851887615, 16.385998537329698, 15.376452571264402, 10.552779154476072, 9.700941776645898, 8.774956209130204, 7.808105281904236, 6.852447145644682, 7.834700753736406, 8.787194833363001, 9.72271873819843, 10.702987405766116, 11.712409892199767, 12.730323709033891, 13.619302694872426, 14.598875840514348, 14.48927942303279, 13.748833477184887, 12.829544890312782, 13.670769444859365, 14.610339038515264, 15.347892697821687, 14.408411843465691, 11.606521090310403, 10.723040602574727, 9.72241870092109, 8.740288027200785, 7.797418696528525, 8.778689705106894, 9.714978828916463, 10.677260265045192, 11.649371946236357, 12.579209781457566, 13.644919326180538, 14.590909515596106, 14.519630492682172, 13.496509713768438, 12.71157114845745, 11.831189820053009, 12.696279462817195, 13.677041136972537, 14.395338164281151, 13.414401903978776, 12.61459636643325, 11.667848772446897, 10.759255363789741, 9.779689499476351, 8.840596395645589, 9.768961861975408, 10.747748596274251, 11.707033110033509, 12.703393977240019, 13.580787879568026, 14.56073066913368, 14.451113378373845, 13.473501058483023, 12.5617213047595, 11.674879979418773, 10.761587588067158, 11.67573789022242, 12.693362377225032, 13.469967730469637, 12.468557238715302, 13.546093976711045, 12.677701326016592, 11.815389272701363, 10.836142386718466, 9.863611889213372, 10.82284776700782, 11.749736888687284, 12.638404745508453, 13.709572596634294, 14.566363976543665, 14.465511213807511, 13.496894582867096, 12.46550237269724, 11.59104784513312, 10.63410339166024, 9.740530885927814, 10.722194855420168, 11.636821465900173, 12.515315142069852, 11.4977493345821, 14.612409027344611, 13.713899759501498, 12.743190457121091, 11.809078692698714, 10.835238719565924, 11.773075659690944, 12.743209847159374, 13.633176028508197, 14.648589878272324, 14.381620807079491, 13.448818929419252, 12.504243517153629, 11.540284249354686, 10.602562858150762, 9.670715988241135, 8.784836721891054, 9.720521509074032, 10.62385376376896, 11.558272018602054, 10.572391352170907, 15.6647817085855, 14.764151109266859, 13.728349091821785, 12.741677301470704, 11.845968911930788, 12.73040081914378, 13.688478055581554, 14.630343497472062, 14.472098755365991, 13.531326748427746, 12.480924907137222, 11.553079957719582, 10.592970120801523, 9.669322882554907, 8.715135715212433, 7.859754664702903, 8.773763136081946, 9.678807419525903, 10.609601669475877, 9.655457545600148, 16.644338090671948, 15.751763848067188, 14.758622745698727, 13.782615625783839, 12.81570389692189, 13.669850661958181, 14.62722923803686, 14.442833108310019, 13.612312195250471, 12.660780701654126, 11.627853662441654, 10.581411214704616, 9.622465741911384, 8.665420467572806, 7.729623279988731, 6.806311125263534, 7.84254182508963, 8.746935769648475, 9.682955483951993, 8.750158779128814, 17.624604484549064, 16.77453444676034, 15.712520406547943, 14.741279574283913, 13.832313021514308, 14.667697181521866, 14.42675398861661, 13.477744586865072, 12.636602162899441, 11.636671414554941, 10.58550747428116, 9.62364350237992, 8.760486367056435, 7.775896205635708, 6.763150299585384, 5.873262893267919, 6.828253845675986, 7.732312271477642, 8.797373320262624, 7.860788997453975, 17.805449386653006, 17.613783488303856, 16.645827368948137, 15.714289643274153, 14.869743840270353, 14.435823497817825, 13.432574613765231, 12.480808468019033, 11.64429013653171, 10.70516453879705, 9.646463308098758, 8.656127949823288, 7.768399333202344, 6.756085369351001, 5.750554408374624, 4.914408360765583, 5.792647953466855, 6.7349487098981955, 7.740314352836583, 6.822395652558742, 16.956654126727237, 17.445404606832412, 16.40628406572287, 15.394631751357613, 14.436496348579965, 13.385169880686197, 12.500598477660176, 11.49105847645028, 10.576061172243381, 9.647909989764353, 8.696934413370776, 7.687063745713501, 6.706954912386214, 5.801465164315483, 4.809346739672884, 3.8639676609031084, 4.793361259225436, 5.722997569706742, 6.712042804033748, 5.808836491622761, 16.098807509758515, 16.43462551796685, 15.497472204722609, 14.490652414622442, 13.43597525920472, 12.433125442040675, 11.49017226476589, 10.551276957578192, 9.614235684329257, 8.678469100921287, 7.71682267998992, 6.733900923761375, 5.746292106481092, 4.840740716990625, 3.871360927653592, 2.930786079757634, 3.8919656858179588, 4.8554512268556635, 5.728801839181598, 4.775690051568919, 16.801526938590502, 15.775946982658208, 14.746855869410437, 13.757204140640294, 12.682395902238914, 11.767094125354022, 10.765021562263195, 9.740574802205641, 8.700263091230186, 7.721657982378449, 6.885158360163181, 5.841798380313866, 4.8175891351869495, 3.8418686380861256, 2.8882490278659247, 1.9567944498069354, 2.909024595508642, 3.8893321880176845, 4.903521122731892, 5.727375699105769], [5.830859412562059, 4.842895451778231, 3.931188220621149, 2.8716426358364497, 1.932125254238615, 0.9401993262539287, 1.9212746239712823, 2.887276115643188, 3.9065056058917906, 4.845220358543504, 5.773959833067452, 6.731391895826559, 7.80433637198011, 8.814193843543286, 9.747015211920843, 10.738697504373176, 11.790110959060263, 12.752839442513693, 13.812685496925884, 14.880501508634163, 4.828396085414777, 3.8983396422283167, 2.925699062735979, 1.9853532524739044, 1.002971040732016, 0.0, 1.047517420284924, 2.0889384790434704, 3.1037759914582317, 4.108609787897551, 5.1087575471672535, 6.10139700991792, 7.0495913578642355, 8.054646357318665, 9.005292491951757, 9.984018704868593, 11.02395517303983, 12.054856926383348, 13.034160344053964, 14.04989485152361, 5.831965866894938, 4.831371235699587, 3.93480385813593, 2.9344124481579463, 1.9370205082272616, 0.9658215737025041, 2.009809427907973, 3.035507993508851, 3.9943262300687414, 5.035013782266484, 6.103083887086657, 7.047776901948735, 8.07954608203919, 9.048813723417547, 9.979722109739631, 11.014445475437356, 11.995004719803656, 12.99891470306967, 13.938427160251836, 14.959920380345247, 6.834881467688872, 5.789125586593774, 4.872015222069143, 3.842550523135795, 2.9133993184161717, 1.9434641767347518, 2.8998541240982227, 3.9294876961225382, 4.913295666805433, 5.899423968142362, 6.85680503952374, 7.884445832639113, 8.907716299123356, 9.883455804053806, 10.855959232216142, 11.826620238076455, 12.879305224226476, 13.893538230695968, 14.866911243328138, 15.806877103756195, 7.830770328577453, 6.781571601242182, 5.849788011435491, 4.804166170432684, 3.8734710367333385, 2.9462884744070594, 3.874812605211348, 4.913651890030559, 5.86750751815952, 6.840977060685269, 7.8294674526783545, 8.819992792487428, 9.786509524712239, 10.727243386294704, 11.721836652648255, 12.685673511924481, 13.717467389111034, 14.765335244801008, 15.807869771766418, 16.753310020296457, 8.806824908479646, 7.788749877559969, 6.756165668372897, 5.753647947434463, 4.851018468307182, 3.959634377570375, 4.836527955589576, 5.868918501950885, 6.805675973141335, 7.80824679230641, 8.771255544971195, 9.715450623903013, 10.72682484609533, 11.711422382333819, 12.687782493643303, 13.63094053991819, 14.689788341739291, 15.754662581050809, 16.751009922344856, 17.76525529931814, 9.684635277216614, 8.74467841760781, 7.773484402889116, 6.761935554633287, 5.816957944095292, 4.926880702561974, 5.8133166114189, 6.864597749973337, 7.834204071773517, 8.79442026079317, 9.767331775313227, 10.660839237957553, 11.67178696007913, 12.69607850662144, 13.627387026805895, 14.68008985223358, 15.703751602390446, 16.6465779427653, 17.651247440685523, 17.360008857162715, 10.615263909196974, 9.741758596005019, 8.798936497682392, 7.770895507755492, 6.850184107130877, 5.9686179618912, 6.875236446250909, 7.821410702840229, 8.779694771276299, 9.789056549656726, 10.798806713458546, 11.642147244146052, 12.640301968430899, 13.578506603206012, 13.813225970047814, 14.685257587192954, 15.613165274913703, 16.59466240813959, 17.380901904442997, 16.3713559383777, 11.54768252158937, 10.678531553718575, 9.698516829032327, 8.731665901806359, 7.7760077655468045, 7.0051887906552395, 7.855236569843336, 8.790760474678766, 9.771029142246451, 10.780451628680101, 11.798365445514225, 12.668272108487974, 13.647845254129896, 13.559179931471249, 12.818733985623345, 13.707453696664889, 14.588252001111341, 15.52782159476724, 16.342796064934987, 15.40331521057899, 12.601424457423702, 11.64660122247685, 10.645979320823212, 9.663848647102906, 8.720979316430647, 7.983430389703097, 8.859322629765586, 9.745302001525527, 10.717413682716693, 11.647251517937901, 12.712961062660874, 13.658951252076442, 13.589531001120628, 12.566410222206896, 11.781471656895908, 12.709098626405115, 13.61376201906917, 14.594523693224513, 15.39024153139445, 14.409305271092075, 13.538156986335373, 12.59140939234902, 11.682815983691864, 10.703250119378472, 9.76415701554771, 9.051300170013777, 9.892092397123374, 10.801483118396847, 11.771435713720354, 12.648829616048362, 13.628772405614015, 13.50285486071834, 12.54340156692148, 11.631621813197958, 10.74478048785723, 11.679070144319134, 12.593220446474396, 13.610844933477008, 14.464871097582936, 13.463460605828601, 14.469654596613168, 13.601261945918715, 12.738949892603486, 11.759703006620587, 10.787172509115493, 10.10518607504619, 10.894080689536407, 11.732854753871791, 12.804022604997632, 13.634405713024, 13.485147593609863, 12.548636065211591, 11.535402881135695, 10.660948353571579, 9.704003900098698, 10.65801344217979, 11.639677411672144, 12.554304022152149, 13.493254965436726, 12.492652701695398, 15.535969647246734, 14.63746037940362, 13.666751077023212, 12.732639312600835, 11.758799339468045, 11.055413967729313, 11.945423174458824, 12.727626036871536, 13.743039886635662, 13.401257186881843, 12.468455309221603, 11.524150007329727, 10.610184757793142, 9.67246336658922, 8.740616496679593, 9.70231927814303, 10.638004065326008, 11.541336320020935, 12.47575457485403, 11.567294719284206, 16.58834232848762, 15.687711729168981, 14.651909711723906, 13.665237921372825, 12.769529531832909, 12.012739127182149, 12.890691382881004, 13.7247935058354, 13.491735135168343, 12.550963128230098, 11.500561286939574, 10.572716337521934, 9.662870629239979, 8.739223390993365, 7.7850362236508905, 8.777237220954879, 9.691245692333922, 10.596289975777879, 11.54051253371414, 10.650360912713447, 17.567898710574067, 16.67532446796931, 15.682183365600846, 14.70617624568596, 13.739264516824012, 12.95218896999655, 13.833673528494055, 13.439862067578002, 12.609341154518457, 11.65780966092211, 10.644396469976122, 9.601047594506968, 8.69236625034984, 7.735320976011264, 6.799523788427188, 7.7237936815155095, 8.760024381341605, 9.664418325900451, 10.613866348190255, 9.75312981986083, 17.72308950434812, 17.69809506666246, 16.636081026450064, 15.664840194186034, 14.755873641416429, 13.950035489560236, 13.423782947884593, 12.474773546133054, 11.633631122167428, 10.633700373822926, 9.582536433549144, 8.620672461647905, 7.776053036665143, 6.8382160077278735, 5.833050808023841, 6.7907454495198944, 7.74573640192796, 8.649794827729618, 9.7148558765146, 8.86376003818599, 16.807594145251052, 17.30107061775134, 16.33311449839562, 15.408827054457959, 14.475875591989224, 13.43285245708581, 12.429603573033216, 11.477837427287017, 10.641319095799696, 9.702193498065036, 8.64349226736674, 7.653156909091272, 6.765428292470329, 5.818405171443167, 4.820454916813081, 5.831890917017558, 6.71013050971883, 7.65243126615017, 8.657796909088557, 7.825366693290759, 15.953683085995223, 16.442433566100398, 15.403313024990855, 14.391660710625597, 13.43352530784795, 12.382198839954182, 11.49762743692816, 10.488087435718265, 9.573090131511368, 8.644938949032339, 7.693963372638762, 6.684092704981485, 5.703983871654199, 4.863784966407649, 3.8792472481113416, 4.781450217155084, 5.710843815477411, 6.6404801259587165, 7.629525360285724, 6.811807532354777, 15.095836469026501, 15.431654477234837, 14.494501163990595, 13.487681373890428, 12.433004218472705, 11.43015440130866, 10.487201224033875, 9.548305916846177, 8.611264643597242, 7.675498060189272, 6.713851639257904, 5.73092988302936, 4.743321065749076, 3.8377696762586093, 2.868389886921576, 3.8482686360096094, 4.809448242069934, 5.772933783107638, 6.721958878397604, 5.778661092300935, 15.798555897858485, 14.772975941926193, 13.743884828678421, 12.754233099908278, 11.679424861506899, 10.764123084622007, 9.76205052153118, 8.737603761473625, 7.697292050498169, 6.718686941646434, 5.882187319431165, 4.83882733958185, 3.814618094454934, 2.8388975973541095, 1.885277987133909, 2.874277006058911, 3.8893197426427664, 4.869627335151809, 5.883816269866016, 6.730346739837786], [6.878376832846983, 5.890412872063154, 4.978705640906073, 3.919160056121373, 2.9796426745235385, 1.935851672604414, 0.9547763748870604, 1.9207778665589659, 2.940007356807569, 3.878722109459282, 4.80746158398323, 5.764893646742337, 6.837838122895889, 7.847695594459064, 8.780516962836622, 9.772199255288955, 10.823612709976041, 11.786341193429472, 12.846187247841662, 13.914003259549942, 5.8759135056997005, 4.94585706251324, 3.9732164830209022, 3.032870672758828, 2.05048846101694, 1.047517420284924, 0.0, 1.0414210587585466, 2.0562585711733075, 3.0610923676126265, 4.061240126882328, 5.053879589632995, 6.00207393757931, 7.007128937033739, 7.95777507166683, 8.936501284583667, 9.976437752754904, 11.007339506098422, 11.986642923769038, 13.002377431238685, 6.879483287179862, 5.87888865598451, 4.977181829712506, 3.976790419734522, 2.9793984798038373, 2.00819954527908, 0.9622920076230486, 1.9879905732239274, 2.9468088097838177, 3.98749636198156, 5.055566466801734, 6.00025948166381, 7.032028661754264, 8.001296303132621, 8.932204689454704, 9.96692805515243, 10.94748729951873, 11.951397282784743, 12.89090973996691, 13.912402960060321, 7.882398887973794, 6.836643006878697, 5.810105351023303, 4.757703346581713, 3.8285521418620894, 2.8586170001806694, 1.9022270528171983, 2.931860624841514, 3.9156685955244086, 4.901796896861338, 5.859177968242716, 6.8868187613580885, 7.910089227842332, 8.885828732772783, 9.858332160935118, 10.828993166795431, 11.881678152945453, 12.895911159414945, 13.819393823043212, 14.759359683471269, 8.755298363436896, 7.7060996361016265, 6.728260557015819, 5.6647411195294675, 4.734045985830122, 3.806863423503842, 2.8771855339303234, 3.916024818749534, 4.869880446878495, 5.843349989404244, 6.83184038139733, 7.822365721206403, 8.788882453431214, 9.72961631501368, 10.72420958136723, 11.688046440643456, 12.719840317830009, 13.767708173519983, 14.810242700485393, 15.710633103013839, 9.672247512194266, 8.654172481274589, 7.61674061746968, 6.614222896531246, 5.711593417403965, 4.806707614418196, 3.8389008843085515, 4.871291430669861, 5.80804890186031, 6.810619721025385, 7.773628473690171, 8.71782355262199, 9.729197774814306, 10.713795311052795, 11.69015542236228, 12.633313468637168, 13.692161270458268, 14.757035509769786, 15.753382851063835, 16.767628228037122, 10.545210226313397, 9.605253366704593, 8.634059351985899, 7.62251050373007, 6.677532893192075, 5.773953939409795, 4.815689540137876, 5.866970678692312, 6.836577000492492, 7.7967931895121465, 8.769704704032204, 9.66321216667653, 10.674159888798107, 11.698451435340417, 12.629759955524872, 13.682462780952557, 14.706124531109422, 15.648950871484278, 16.6536203694045, 17.582686197929032, 11.475838858293757, 10.602333545101802, 9.659511446779176, 8.631470456852275, 7.71075905622766, 6.815691198739021, 5.877609374969886, 6.823783631559205, 7.782067699995275, 8.791429478375703, 9.801179642177523, 10.644520172865029, 11.642674897149876, 12.580879531924989, 13.603328621492707, 14.623111805189883, 15.57053172450875, 16.554817315064025, 17.510063140109647, 17.231930887474483, 12.408257470686154, 11.539106502815358, 10.55909177812911, 9.592240850903142, 8.636582714643588, 7.852262027503061, 6.857609498562312, 7.793133403397743, 8.773402070965428, 9.782824557399078, 10.800738374233202, 11.67064503720695, 12.650218182848873, 12.828466745240345, 13.783207400249925, 14.689392259865622, 15.570190564312076, 16.509760157967975, 17.20337101403177, 16.263890159675775, 13.461999406520485, 12.507176171573633, 11.506554269919995, 10.52442359619969, 9.58155426552743, 8.79798468229413, 7.861695558484562, 8.747674930244504, 9.71978661143567, 10.649624446656878, 11.71533399137985, 12.661324180795418, 12.756995247757652, 11.835697035975992, 12.763410220096642, 13.691037189605849, 14.595700582269906, 15.576462256425248, 16.250816480491235, 15.269880220188858, 14.398731935432156, 13.451984341445803, 12.543390932788647, 11.563825068475255, 10.624731964644493, 9.86585446260481, 8.894465325842349, 9.803856047115824, 10.773808642439331, 11.651202544767338, 12.631145334332992, 12.536356611634117, 11.710865813558504, 10.900908626967054, 11.726719051057964, 12.66100870751987, 13.575159009675131, 14.592783496677743, 15.325446046679719, 14.324035554925384, 15.330229545709951, 14.461836895015498, 13.59952484170027, 12.62027795571737, 11.647747458212276, 10.912052996910266, 9.896453618255382, 10.735227682590768, 11.806395533716609, 12.636778641742977, 12.51864934452564, 11.582137816127368, 10.70286712777272, 9.930235167340674, 10.685942463299432, 11.639952005380525, 12.62161597487288, 13.536242585352884, 14.370793458279934, 13.353227650792181, 16.396544596343517, 15.498035328500404, 14.527326026119995, 13.593214261697618, 12.619374288564828, 11.86228088959339, 10.947796103177799, 11.729998965590513, 12.745412815354639, 12.43475893779762, 11.50195706013738, 10.557651758245504, 9.777649004430167, 8.941750180358316, 9.722555059880326, 10.684257841343765, 11.619942628526744, 12.52327488322167, 13.425716002270434, 12.427869668380989, 17.448917277584407, 16.548286678265764, 15.51248466082069, 14.525812870469608, 13.630104480929692, 12.819606049046225, 11.893064311599979, 12.727166434554377, 12.52523688608412, 11.584464879145875, 10.53406303785535, 9.60621808843771, 8.830334875877003, 8.00851020476246, 8.766974786851625, 9.759175784155614, 10.673184255534657, 11.578228538978614, 12.477995313922513, 11.51093586181023, 17.66067898094262, 17.535899417066094, 16.54275831469763, 15.566751194782743, 14.599839465920795, 13.759055891860626, 12.83604645721303, 12.47336381849378, 11.642842905434234, 10.691311411837887, 9.6778982208919, 8.634549345422744, 7.859830496986864, 6.957843565344288, 7.781462351627923, 8.705732244716245, 9.74196294454234, 10.646356889101186, 11.551349128398629, 10.61855242357545, 16.680412587065504, 17.361937251923987, 16.29992321171159, 15.415338874363977, 14.40790356825293, 13.438057700102485, 12.457284698800372, 11.508275297048833, 10.667132873083204, 9.667202124738703, 8.616038184464921, 7.654174212563682, 6.809554787580922, 5.912915350488206, 6.814989371224575, 7.77268401272063, 8.727674965128696, 9.631733390930354, 10.696794439715335, 9.82608473912746, 15.760076724966124, 16.334572368667118, 15.366616249311397, 14.442328805373737, 13.509377342905003, 12.466354208001588, 11.463105323948994, 10.511339178202796, 9.674820846715473, 8.735695248980813, 7.676994018282519, 6.6866586600070494, 5.798930043386107, 4.8931045142034995, 5.802393480013816, 6.813829480218293, 7.6920690729195655, 8.634369829350906, 9.639735472289292, 8.872884113575681, 14.906165665710297, 15.475935317016177, 14.436814775906633, 13.425162461541376, 12.467027058763728, 11.41570059086996, 10.53112918784394, 9.521589186634044, 8.606591882427145, 7.678440699948116, 6.7274651235545395, 5.717594455897263, 4.737485622569976, 3.9384843091679818, 4.861185811312076, 5.763388780355818, 6.692782378678146, 7.622418689159452, 8.61146392348646, 7.8593249526397, 14.048319048741575, 14.465156228150615, 13.528002914906374, 12.521183124806207, 11.466505969388484, 10.463656152224438, 9.520702974949653, 8.581807667761955, 7.64476639451302, 6.70899981110505, 5.747353390173682, 4.764431633945137, 3.776822816664854, 2.912469019018942, 3.8503284501223103, 4.830207199210344, 5.791386805270668, 6.754872346308373, 7.703897441598339, 6.826178512585859, 14.832057648774263, 13.806477692841971, 12.7773865795942, 11.787734850824057, 10.712926612422677, 9.797624835537786, 8.795552272446956, 7.771105512389403, 6.730793801413947, 5.752188692562211, 4.915689070346943, 3.872329090497628, 2.8481198453707117, 1.9135969401144424, 2.867216550334643, 3.8562155692596454, 4.871258305843501, 5.851565898352543, 6.865754833066751, 7.777864160122709], [7.919797891605529, 6.9318339308217, 6.020126699664619, 4.96058111487992, 4.0210637332820856, 2.9772727313629606, 1.996197433645607, 1.069203198290647, 1.9546014617613277, 2.8933162144130407, 3.822055688936989, 4.779487751696096, 5.852432227849647, 6.862289699412822, 7.795111067790379, 8.786793360242712, 9.838206814929798, 10.800935298383228, 11.860781352795417, 12.928597364503696, 6.917334564458247, 5.987278121271786, 5.014637541779448, 4.074291731517374, 3.0919095197754864, 2.0889384790434704, 1.0414210587585466, 0.0, 1.014837512414761, 2.01967130885408, 3.019819068123782, 4.012458530874449, 4.960652878820764, 5.965707878275193, 6.916354012908283, 7.8950802258251205, 8.935016693996358, 9.965918447339874, 10.94522186501049, 11.960956372480137, 7.920904345938408, 6.920309714743056, 6.005570480874992, 5.005179070897008, 4.0077871309663236, 3.036588196441566, 1.9906806587855344, 0.9465695144653808, 1.905387751025271, 2.9460753032230134, 4.014145408043187, 4.958838422905264, 5.990607602995718, 6.959875244374075, 7.890783630696158, 8.925506996393883, 9.906066240760184, 10.909976224026195, 11.849488681208362, 12.870981901301773, 8.92381994673234, 7.878064065637243, 6.838494002185788, 5.786091997744198, 4.856940793024575, 3.887005651343155, 2.930615703979684, 1.9483501441911826, 2.880613371777398, 3.866741673114328, 4.824122744495706, 5.851763537611078, 6.875034004095322, 7.850773509025772, 8.823276937188108, 9.793937943048421, 10.846622929198443, 11.860855935667935, 12.777972764284664, 13.71793862471272, 9.783687014599382, 8.734488287264112, 7.756649208178304, 6.693129770691953, 5.762434636992607, 4.835252074666328, 3.905574185092809, 2.9875710181488864, 3.9091191644082213, 4.880233028426133, 5.79678515765032, 6.7873104974593925, 7.7538272296842035, 8.694561091266669, 9.68915435762022, 10.652991216896446, 11.684785094082999, 12.732652949772973, 13.775187476738383, 14.669212044255291, 10.700636163356751, 9.682561132437074, 8.645129268632164, 7.642611547693732, 6.739982068566451, 5.835096265580682, 4.867289535471038, 4.0472566211381595, 4.847287619390037, 5.847502760047274, 6.738573249943161, 7.68276832887498, 8.694142551067296, 9.678740087305785, 10.65510019861527, 11.598258244890157, 12.657106046711258, 13.721980286022777, 14.718327627316826, 15.72676878088822, 11.573598877475881, 10.633642017867077, 9.662448003148382, 8.650899154892556, 7.705921544354561, 6.802342590572281, 5.844078191300362, 5.0563814527196085, 5.889566181422648, 6.833676228534036, 7.734649480285194, 8.62815694292952, 9.639104665051097, 10.663396211593406, 11.594704731777862, 12.647407557205547, 13.671069307362412, 14.613895647737268, 15.618565145657488, 16.54763097418202, 12.504227509456241, 11.630722196264285, 10.68790009794166, 9.659859108014762, 8.739147707390146, 7.844079849901508, 6.905998026132371, 6.013194405586501, 6.842509992180274, 7.828312517397592, 8.80079757953942, 9.609464949118019, 10.607619673402866, 11.545824308177979, 12.568273397745697, 13.588056581442872, 14.53547650076174, 15.519762091317016, 16.47500791636264, 17.484553882427935, 13.436646121848637, 12.567495153977843, 11.587480429291595, 10.620629502065627, 9.664971365806073, 8.880650678665548, 7.885998149724798, 6.986555873850795, 7.844618241833645, 8.819707596420967, 9.820635866363546, 10.63558981345994, 11.615162959101863, 12.510107566544487, 13.464848221554067, 14.392298107607651, 15.326311919021903, 16.291908185093956, 17.337098627555918, 17.29227881083826, 14.490388057682969, 13.535564822736118, 12.53494292108248, 11.552812247362176, 10.609942916689917, 9.826373333456617, 8.890084209647048, 7.941097400697557, 8.791002782303886, 9.720840617525095, 10.786550162248068, 11.639260907817151, 11.905420579489332, 12.747807495695508, 13.74493760231466, 14.672564571823868, 15.596209146642494, 16.576970820797836, 17.27920513165372, 16.298268871351343, 15.427120586594642, 14.480372992608288, 13.57177958395113, 12.592213719637742, 11.65312061580698, 10.894243113767297, 9.922853977004836, 8.997278517568876, 9.845024813307548, 10.722418715635555, 11.702361505201209, 11.6847819433658, 10.859291145290184, 11.81301908668657, 12.708246433275983, 13.64308098333464, 14.57566757404772, 15.617486988621796, 16.353834697842203, 15.352424206087868, 16.35861819687244, 15.490225546177983, 14.627913492862753, 13.648666606879857, 12.676136109374763, 11.940441648072753, 10.92484226941787, 9.928650153043819, 10.911059509198227, 11.707994812611194, 11.667074676257323, 10.730563147859051, 9.8512924595044, 10.84234562706019, 11.66746984551745, 12.622024281195296, 13.622124539245469, 14.560946077296936, 15.399182109442417, 14.381616301954665, 17.424933247506004, 16.52642397966289, 15.555714677282483, 14.621602912860105, 13.647762939727315, 12.888354777295808, 11.918220589827378, 10.923421436043563, 11.868322022683612, 11.583184269529303, 10.650382391869064, 9.706077089977187, 8.926074336161847, 9.853860640077832, 10.704082442098345, 11.666330117158536, 12.620451192899333, 13.547978375165723, 14.454104653432918, 13.456258319543473, 17.553862271759492, 17.57667532942825, 16.540873311983177, 15.554201521632095, 14.658493132092179, 13.845679936748644, 12.863488798249557, 11.920588905007428, 11.673662217815803, 10.732890210877558, 9.682488369587034, 8.754643420169394, 7.978760207608683, 8.920620664481977, 9.748502169069644, 10.756297165306577, 11.673692819907247, 12.602932030922666, 13.506383965084998, 12.539324512972714, 16.619257922184072, 17.426047514752604, 16.38541074219691, 15.388596927817812, 14.43910679779911, 13.430357330500325, 12.472978754421646, 11.487957923447542, 10.657437010387994, 9.825217409289115, 8.825650641583808, 7.782974677154427, 7.008255828718544, 7.869954025063803, 8.762989733845941, 9.702853625867208, 10.74247150891493, 11.671060381045239, 12.579737779561114, 11.646941074737935, 15.638991528306956, 16.37653135687775, 15.314517316665352, 14.429932979317737, 13.422497673206692, 12.452651805056247, 11.471878803754134, 10.522869402002595, 9.681726978036965, 8.80110812218993, 7.76379060515683, 6.802599544295363, 5.957980119312602, 6.8250258102077215, 7.796516753442595, 8.769805393871593, 9.752378457072748, 10.656436882874406, 11.721497931659387, 10.854473390289945, 14.718655666207576, 15.349166473620878, 14.381210354265157, 13.456922910327497, 12.523971447858763, 11.480948312955348, 10.477699428902755, 9.525933283156556, 8.689414951669233, 7.750289353934573, 6.817247023443383, 5.83508399173873, 4.9473553751177874, 5.8052149739230146, 6.783920862231835, 7.810950861369256, 8.716772564863618, 9.659073321294958, 10.664438964233344, 9.914305172334227, 13.86474460695175, 14.490529421969935, 13.451408880860393, 12.439756566495136, 11.481621163717488, 10.43029469582372, 9.5457232927977, 8.536183291587804, 7.621185987380905, 6.693034804901876, 5.865432692314814, 4.866019787628944, 3.8859109543016577, 4.850594768887497, 5.842713193530096, 6.788092272299871, 7.717485870622198, 8.647122181103503, 9.63616741543051, 8.900746011398246, 13.006897989983027, 13.479750333104374, 12.542597019860132, 11.535777229759965, 10.481100074342244, 9.478250257178198, 8.535297079903414, 7.596401772715716, 6.659360499466779, 5.723593916058809, 4.876601246052254, 3.9128569656768186, 2.925248148396535, 3.9109850157768555, 4.8917495088808565, 5.871628257968891, 6.832807864029215, 7.79629340506692, 8.745318500356886, 7.867599571344405, 13.84665175372802, 12.821071797795728, 11.791980684547957, 10.802328955777813, 9.727520717376434, 8.812218940491544, 7.810146377400715, 6.785699617343162, 5.745387906367706, 4.766782797515971, 3.930283175300702, 2.886923195451387, 1.9965451771023928, 2.955017998872989, 3.90863760909319, 4.897636628018192, 5.912679364602048, 6.89298695711109, 7.907175891825298, 8.819285218881255], [8.934635404020291, 7.946671443236461, 6.955591353370695, 5.896045768585996, 4.956528386988161, 3.9060702289844285, 2.924994931267075, 1.9589934395951694, 0.9397639493465666, 1.8784787019982794, 2.8072181765222277, 3.764650239281335, 4.837594715434886, 5.847452186998061, 6.780273555375618, 7.771955847827951, 8.823369302515038, 9.786097785968469, 10.84594384038066, 11.913759852088939, 7.932172076873008, 7.0021156336865475, 6.02947505419421, 5.089129243932136, 4.106747032190247, 3.1037759914582317, 2.0562585711733075, 1.014837512414761, 0.0, 1.004833796439319, 2.004981555709021, 2.997621018459688, 3.9458153664060034, 4.950870365860433, 5.901516500493523, 6.880242713410359, 7.920179181581597, 8.951080934925113, 9.930384352595729, 10.946118860065376, 8.935741858353168, 7.935147227157818, 7.020407993289752, 6.020016583311769, 5.022624643381084, 4.051425708856327, 3.005518171200295, 1.961407026880142, 1.0221773855557001, 2.053505583298344, 3.061843825323818, 3.944000910490503, 4.975770090580958, 5.945037731959315, 6.875946118281398, 7.910669483979122, 8.891228728345423, 9.895138711611434, 10.8346511687936, 11.856144388887012, 9.938657459147102, 8.892901578052005, 7.85333151460055, 6.8009295101589595, 5.871778305439336, 4.901843163757916, 3.945453216394445, 2.9631876566059434, 1.9974030063078272, 2.983531307644757, 3.940912379026135, 4.968553172141507, 5.961336273499721, 6.887373769719913, 7.859877197882249, 8.830538203742563, 9.883223189892584, 10.871090077378403, 11.763135251869903, 12.70310111229796, 10.798524527014143, 9.749325799678873, 8.771486720593066, 7.707967283106714, 6.777272149407368, 5.850089587081089, 4.9204116975075705, 3.9797644270676122, 3.0259087989386506, 3.997022662956562, 4.913574792180749, 5.904100131989821, 6.870616864214632, 7.811350725797099, 8.805943992150649, 9.769780851426875, 10.801574728613428, 11.80283364251358, 12.805509626853004, 13.65437453184053, 11.715473675771515, 10.697398644851837, 9.659966781046927, 8.657449060108494, 7.754819580981212, 6.849933777995443, 5.882127047885799, 5.025243439202025, 3.964077253920466, 4.964292394577703, 5.85536288447359, 6.799557963405409, 7.810932185597725, 8.795529721836214, 9.771889833145698, 10.715047879420586, 11.773895681241687, 12.838769920553204, 13.806639250405768, 14.711931268473458, 12.588436389890644, 11.64847953028184, 10.677285515563145, 9.665736667307318, 8.720759056769321, 7.8171801029870425, 6.858915703715123, 5.975962137753257, 5.006355815953077, 5.950465863064465, 6.851439114815623, 7.744946577459949, 8.755894299581525, 9.780185846123835, 10.71149436630829, 11.764197191735976, 12.787858941892841, 13.730685282267697, 14.735354780187917, 15.66442060871245, 13.519065021871004, 12.645559708679048, 11.702737610356422, 10.674696620429524, 9.753985219804907, 8.85891736231627, 7.9208355385471325, 6.917583695146773, 5.959299626710703, 6.945102151928021, 7.917587214069849, 8.726254583648448, 9.724409307933294, 10.662613942708408, 11.685063032276126, 12.704846215973301, 13.65226613529217, 14.636551725847445, 15.591797550893066, 16.601343516958362, 14.4514836342634, 13.582332666392604, 12.602317941706357, 11.635467014480389, 10.679808878220834, 9.891568775233583, 8.826469068246498, 7.890945163411067, 6.961407876364074, 7.936497230951397, 8.937425500893974, 9.75237944799037, 10.731952593632291, 11.626897201074918, 12.581637856084498, 13.509087742138082, 14.443101553552333, 15.408697819624388, 16.453888262086352, 17.49459471915019, 15.505225570097732, 14.55040233515088, 13.549780433497242, 12.567649759776938, 11.624780429104678, 10.766844251978316, 9.830555128168747, 8.845486690257829, 7.907792416834316, 8.837630252055526, 9.903339796778498, 10.75605054234758, 11.76339342115423, 12.619666910339271, 13.618900184811935, 14.507442812397855, 15.417591535594504, 16.341995721167116, 17.406442795626887, 17.313106383766105, 16.4419580990094, 15.49521050502305, 14.586617096365892, 13.607051232052504, 12.667958128221741, 11.834714032288996, 10.860952320888407, 9.901667807129149, 8.961814447837977, 9.839208350165986, 10.81915113973164, 10.76605888928032, 11.674232412433817, 12.644899944482084, 13.598036674580506, 14.532871224639162, 15.465457815352242, 16.507277229926316, 17.368672210256964, 16.36726171850263, 17.373455709287196, 16.505063058592743, 15.642751005277514, 14.663504119294618, 13.690973621789524, 12.878539991956323, 11.86294061330144, 10.833039442604093, 10.027849143728655, 10.824784447141624, 10.724674964841043, 9.81184009377357, 10.666233726648032, 11.674226484855705, 12.557260086821973, 13.511814522499819, 14.51191478054999, 15.450736318601457, 16.389687261886035, 15.396453814369428, 17.53232779620965, 17.54126149207765, 16.570552189697246, 15.636440425274866, 14.662600452142076, 13.792744066856082, 12.822609879387652, 11.827810725603838, 10.985111657214041, 10.640784558113022, 9.707982680452783, 8.787354035891706, 9.74101560330548, 10.69522503463214, 11.593872683402868, 12.556120358463058, 13.510241434203854, 14.437768616470244, 15.372186871303338, 14.471095831958236, 16.583976791855758, 17.398822741138172, 16.400846883659092, 15.381276752926974, 14.376432919771686, 13.354969660899965, 12.401123387619936, 11.498963908728067, 10.670116353268767, 9.74033987776749, 8.740088658170754, 7.835920366083913, 8.793701474752316, 9.8104109057865, 10.638292410374167, 11.646087406611098, 12.563483061211768, 13.492722272227187, 14.436944830163448, 13.554162025387477, 15.604420409769311, 16.411210002337842, 15.370573229782151, 14.37375941540305, 13.424269285384348, 12.415519818085563, 11.458141242006885, 10.473120411032781, 9.642599497973231, 8.810379896874352, 7.810813129169046, 6.864251623068946, 7.823197095862177, 8.759744266368326, 9.652779975150464, 10.592643867171729, 11.63226175021945, 12.56085062234976, 13.510298644639564, 12.661778587152698, 14.624154015892195, 15.36169384446299, 14.29967980425059, 13.415095466902976, 12.40766016079193, 11.437814292641486, 10.457041291339372, 9.508031889587834, 8.666889465622202, 7.786270609775167, 6.7489530927420684, 5.883876490209882, 6.847770360617124, 7.714816051512244, 8.686306994747117, 9.659595635176114, 10.64216869837727, 11.546227124178927, 12.611288172963908, 11.869310902704706, 13.703818153792815, 14.334328961206117, 13.366372841850396, 12.442085397912736, 11.509133935444002, 10.466110800540585, 9.462861916487991, 8.511095770741795, 7.67457743925447, 6.73545184151981, 5.802409511028622, 4.91636093765325, 5.83714561642231, 6.695005215227537, 7.673711103536358, 8.700741102673778, 9.60656280616814, 10.54886356259948, 11.554229205537867, 10.929142684748989, 12.849907094536988, 13.475691909555174, 12.436571368445632, 11.424919054080375, 10.466783651302727, 9.415457183408959, 8.530885780382937, 7.521345779173042, 6.606348474966142, 5.678197292487113, 4.850595179900052, 3.9472967335434634, 4.77570119560618, 5.7403850101920195, 6.732503434834618, 7.677882513604394, 8.607276111926721, 9.536912422408026, 10.525957656735033, 9.915583523813007, 11.992060477568266, 12.464912820689612, 11.52775950744537, 10.520939717345204, 9.466262561927483, 8.463412744763437, 7.520459567488651, 6.5815642603009525, 5.644522987052017, 4.708756403644047, 3.861763733637493, 2.941793039253325, 3.8150383897010576, 4.800775257081378, 5.820547006502325, 6.800425755590358, 7.761605361650682, 8.725090902688386, 9.674115997978353, 8.882437083759166, 12.83181424131326, 11.806234285380969, 10.777143172133197, 9.787491443363052, 8.712683204961673, 7.797381428076783, 6.795308864985953, 5.7708621049284, 4.730550393952945, 3.751945285101209, 2.915445662885941, 1.8720856830366257, 2.886335418406915, 3.883815496494457, 4.837435106714658, 5.8264341256396595, 6.841476862223515, 7.8217844547325575, 8.835973389446764, 9.834122731296016], [9.88784531039786, 8.87246161103091, 7.88137923326474, 6.821833648480041, 5.882316266882206, 4.831858108878474, 3.85078281116112, 2.8847813194892145, 1.8655518292406117, 0.9268370765888987, 1.855576551112847, 2.813008613871954, 3.8859530900255055, 4.880071776642313, 5.81289314501987, 6.804575437472203, 7.85598889215929, 8.81871737561272, 9.878563430024911, 10.94637944173319, 8.937005873312328, 8.006949430125868, 7.034308850633529, 6.093963040371455, 5.111580828629567, 4.10860978789755, 3.0610923676126265, 2.01967130885408, 1.004833796439319, 0.0, 1.0001477592697021, 1.992787222020369, 2.9409815699666844, 3.9460365694211132, 4.896682704054204, 5.87540891697104, 6.9153453851422775, 7.946247138485794, 8.92555055615641, 9.941285063626056, 9.94057565479249, 8.939981023597138, 8.02524178972907, 7.024850379751087, 6.0274584398204025, 5.056259505295645, 4.010351967639614, 2.9662408233194606, 2.027011181995019, 1.048671786859025, 2.0570100288844992, 2.939167114051184, 3.970936294141638, 4.940203935519995, 5.871112321842078, 6.905835687539803, 7.8863949319061035, 8.890304915172116, 9.829817372354283, 10.851310592447694, 10.943491255586421, 9.897735374491324, 8.858165311039869, 7.805763306598278, 6.876612101878655, 5.906676960197235, 4.950287012833764, 3.968021453045262, 3.002236802747146, 2.0936197641290435, 3.0510008355104214, 3.990394904153985, 4.956502477060401, 5.882539973280593, 6.85504340144293, 7.825704407303244, 8.878389393453265, 9.866256280939085, 10.758301455430585, 11.698267315858642, 11.803358323453462, 10.754159596118193, 9.776320517032385, 8.712801079546033, 7.782105945846687, 6.854923383520408, 5.925245493946889, 4.98459822350693, 4.030742595377969, 3.1071111194408485, 4.023663248665035, 4.925941864002299, 5.89245859622711, 6.833192457809576, 7.827785724163127, 8.791622583439354, 9.823416460625907, 10.797999846074262, 11.800675830413686, 12.649540735401212, 12.720307472210832, 11.702232441291155, 10.664800577486245, 9.662282856547812, 8.75965337742053, 7.854767574434761, 6.886960844325117, 6.030077235641343, 4.968911050359784, 4.07438085106199, 4.965451340957876, 5.909646419889695, 6.857502388280133, 7.834406010195808, 8.810766121505292, 9.75392416778018, 10.81277196960128, 11.834014284920496, 12.80180545396645, 13.70709747203414, 13.593270186329962, 12.653313326721157, 11.682119312002463, 10.670570463746635, 9.72559285320864, 8.82201389942636, 7.863749500154441, 6.9807959341925745, 6.0111896123923945, 5.060554319548752, 5.961527571299909, 6.855035033944235, 7.802464502263934, 8.826756048806244, 9.758064568990699, 10.810767394418384, 11.83442914457525, 12.777255484950105, 13.781924982870326, 14.676810761760187, 14.523898818310322, 13.650393505118366, 12.70757140679574, 11.679530416868841, 10.758819016244225, 9.863751158755585, 8.92566933498645, 7.92241749158609, 6.96413342315002, 6.055190608412308, 7.027675670554135, 7.836343040132735, 8.787727867108005, 9.725932501883118, 10.731633234958535, 11.75141641865571, 12.698836337974578, 13.683121928529854, 14.638367753575475, 15.64791371964077, 15.456317430702718, 14.587166462831922, 13.607151738145674, 12.640300810919706, 11.684642674660152, 10.896402571672901, 9.831302864685815, 8.895778959850386, 7.966241672803392, 7.046585687435684, 8.04751395737826, 8.862467904474657, 9.824657647562232, 10.690215760249629, 11.644956415259209, 12.572406301312792, 13.506420112727044, 14.472016378799099, 15.517206821261063, 16.5579132783249, 16.51005936653705, 15.555236131590197, 14.55461422993656, 13.572483556216255, 12.629614225543996, 11.771678048417634, 10.835388924608065, 9.850320486697147, 8.912626213273633, 8.041273472322972, 9.1003689087912, 9.866138998831868, 10.867602339638884, 11.682985469513982, 12.682218743986645, 13.570761371572566, 14.480910094769214, 15.405314280341825, 16.469761354801598, 17.500394917939797, 17.44679189544872, 16.500044301462367, 15.59145089280521, 14.611885028491821, 13.672791924661059, 12.839547828728314, 11.865786117327724, 10.906501603568467, 9.966648244277295, 9.042851570433433, 10.022794359999086, 10.831299486598121, 11.823820341354923, 12.61777387852292, 13.610145810033002, 14.559889559201782, 15.501451667363987, 16.46579927679891, 17.395131788613114, 17.372095514941947, 17.614566309574528, 17.50989685503206, 16.64758480171683, 15.668337915733936, 14.695807418228842, 13.883373788395641, 12.867774409740758, 11.837873239043411, 11.032682940167973, 10.02842766740907, 9.773033339431661, 10.687139042797615, 11.541532675672077, 12.549525433879749, 13.48304796671602, 14.437602402393866, 15.437702660444037, 16.376524198495506, 17.315475141780084, 16.401287610808744, 16.578897998892057, 17.342091160739365, 16.29634550071196, 15.362233736289584, 14.32399587300311, 13.36065319494342, 12.394749970632736, 11.544489752282551, 10.704921087036023, 9.689142932703641, 8.756341055043402, 9.66265298491575, 10.616314552329523, 11.570523983656184, 12.519660563296915, 13.481908238357105, 14.436029314097901, 15.363556496364293, 16.297974751197387, 15.475929628397553, 15.57914299541644, 16.447181115728792, 15.449205258249712, 14.429635127517594, 13.424791294362306, 12.403328035490585, 11.449481762210556, 10.547322283318687, 9.718474727859387, 8.78869825235811, 7.788447032761372, 8.711219315107957, 9.66900042377636, 10.706207958642972, 11.564080290268214, 12.571875286505145, 13.489270941105815, 14.418510152121236, 15.362732710057497, 14.558995821826795, 14.599586613329993, 15.459568376928463, 14.418931604372771, 13.42211778999367, 12.472627659974968, 11.463878192676184, 10.506499616597505, 9.521478785623401, 8.690957872563851, 7.858738271464972, 6.859171503759664, 7.73955057209299, 8.698496044886221, 9.655541319224799, 10.578567855044511, 11.518431747065776, 12.558049630113498, 13.486638502243808, 14.436086524533613, 13.666612383592016, 13.619320219452877, 14.41005221905361, 13.348038178841211, 12.463453841493596, 11.456018535382551, 10.486172667232106, 9.505399665929993, 8.556390264178454, 7.715247840212822, 6.8346289843657875, 5.797311467332687, 6.7591754392339265, 7.77355824051117, 8.64060393140629, 9.612094874641164, 10.585383515070161, 11.567956578271318, 12.472015004072976, 13.537076052857957, 12.874144699144026, 12.698984357353497, 13.382687335796737, 12.414731216441016, 11.490443772503356, 10.557492310034622, 9.514469175131206, 8.511220291078612, 7.559454145332415, 6.7229358138450905, 5.78381021611043, 4.85076788561924, 5.84110324389471, 6.762933496316355, 7.6207930951215825, 8.599498983430404, 9.626528982567825, 10.532350686062188, 11.474651442493528, 12.480017085431914, 11.93397648118831, 11.84507329809767, 12.524050284145794, 11.484929743036252, 10.473277428670995, 9.515142025893347, 8.463815557999578, 7.579244154973557, 6.569704153763662, 5.654706849556762, 4.726555667077733, 3.8989535544906713, 4.873084613437509, 5.701489075500225, 6.666172890086065, 7.658291314728664, 8.60367039349844, 9.533063991820768, 10.462700302302073, 11.45174553662908, 10.920417320252328, 10.987226681128949, 11.513271195280232, 10.576117882035991, 9.569298091935824, 8.514620936518103, 7.511771119354056, 6.568817942079272, 5.629922634891573, 4.6928813616426375, 3.757114778234667, 2.9101221082281117, 3.8675809191473705, 4.740826269595103, 5.7265631369754235, 6.746334886396371, 7.726213635484403, 8.687393241544727, 9.650878782582431, 10.599903877872398, 9.887270880198487, 11.864433830957513, 10.83885387502522, 9.80976276177745, 8.820111033007304, 7.745302794605925, 6.830001017721035, 5.8279284546302055, 4.8192204795190206, 3.7789087685435643, 2.8003036596918283, 1.96380403747656, 2.797873562930671, 3.8121232983009605, 4.809603376388503, 5.763222986608703, 6.752222005533705, 7.76726474211756, 8.747572334626602, 9.76176126934081, 10.829479866381012], [10.887993069667562, 9.872609370300612, 8.881526992534441, 7.8219814077497425, 6.882464026151908, 5.832005868148175, 4.850930570430822, 3.8849290787589164, 2.8656995885103136, 1.9269848358586008, 1.0698848290455376, 1.927522931177219, 2.9331563745951637, 3.8799240173726117, 4.812745385750168, 5.804427678202502, 6.855841132889589, 7.818569616343019, 8.87841567075521, 9.94623168246349, 9.93715363258203, 9.00709718939557, 8.03445660990323, 7.0941107996411565, 6.111728587899268, 5.108757547167253, 4.061240126882328, 3.019819068123782, 2.004981555709021, 1.0001477592697021, 0.0, 0.9926394627506671, 1.9408338106969825, 2.945888810151412, 3.896534944784502, 4.875261157701338, 5.915197625872576, 6.9460993792160926, 7.925402796886708, 8.941137304356355, 10.940723414062191, 9.94012878286684, 9.025389548998774, 8.02499813902079, 7.027606199090105, 6.0564072645653475, 5.010499726909316, 3.966388582589163, 3.0271589412647213, 2.048819546128727, 1.0568622696147971, 1.9390193547814818, 2.9707885348719363, 3.9400561762502933, 4.870964562572377, 5.905687928270101, 6.886247172636402, 7.890157155902415, 8.829669613084581, 9.851162833177993, 11.943639014856123, 10.897883133761026, 9.85831307030957, 8.80591106586798, 7.876759861148357, 6.906824719466937, 5.950434772103466, 4.968169212314964, 4.002384562016848, 3.080493364054224, 2.123112292672846, 2.990247144884283, 3.9563547177906995, 4.882392214010891, 5.854895642173227, 6.825556648033541, 7.8782416341835635, 8.866108521669384, 9.758153696160884, 10.69811955658894, 12.803506082723166, 11.754307355387896, 10.776468276302088, 9.712948838815736, 8.78225370511639, 7.85507114279011, 6.925393253216591, 5.984745982776633, 5.0308903546476715, 4.093984719366029, 3.09577470582746, 3.925794104732597, 4.8923108369574075, 5.833044698539874, 6.827637964893425, 7.791474824169651, 8.823268701356204, 9.79785208680456, 10.800528071143985, 11.64939297613151, 13.720455231480535, 12.702380200560858, 11.664948336755948, 10.662430615817515, 9.759801136690234, 8.854915333704465, 7.88710860359482, 7.0302249949110465, 5.969058809629487, 5.041437801560221, 4.037562798120301, 4.937216943912708, 5.85735462901043, 6.834258250926106, 7.81061836223559, 8.753776408510479, 9.81262421033158, 10.833866525650794, 11.801657694696749, 12.70694971276444, 14.593417945599665, 13.65346108599086, 12.682267071272166, 11.670718223016339, 10.725740612478344, 9.822161658696064, 8.863897259424144, 7.980943693462278, 7.011337371662098, 6.027611270046982, 5.033639028462334, 5.882605557967248, 6.802316742994232, 7.826608289536542, 8.757916809720996, 9.810619635148681, 10.834281385305546, 11.777107725680402, 12.781777223600622, 13.676663002490486, 15.524046577580025, 14.65054126438807, 13.707719166065443, 12.679678176138545, 11.75896677551393, 10.86389891802529, 9.925817094256153, 8.922565250855794, 7.9642811824197235, 7.022247558910538, 6.09978712771656, 6.863913564155748, 7.787580107838302, 8.725784742613415, 9.731485475688832, 10.751268659386007, 11.698688578704875, 12.68297416926015, 13.638219994305771, 14.647765960371068, 16.456465189972423, 15.587314222101627, 14.60729949741538, 13.640448570189411, 12.684790433929857, 11.896550330942603, 10.831450623955517, 9.895926719120087, 8.966389432073095, 8.013642637933915, 7.119625414540686, 7.89003842849767, 8.824509888292528, 9.690068000979924, 10.644808655989504, 11.572258542043087, 12.506272353457339, 13.471868619529394, 14.517059061991358, 15.557765519055193, 17.510207125806755, 16.555383890859904, 15.554761989206265, 14.57263131548596, 13.629761984813701, 12.771825807687335, 11.835536683877766, 10.850468245966848, 9.912773972543336, 9.008330422821203, 8.172480365953627, 8.89370952285488, 9.86745458036918, 10.682837710244277, 11.68207098471694, 12.57061361230286, 13.48076233549951, 14.40516652107212, 15.469613595531893, 16.500247158670092, 17.45453215699724, 17.500192060732076, 16.591598652074914, 15.612032787761526, 14.672939683930764, 13.839695587998015, 12.865933876597426, 11.906649362838168, 10.966796003546998, 10.009908520931663, 9.160414892669728, 9.858870010621134, 10.851390865377935, 11.617626119253215, 12.609998050763297, 13.559741799932077, 14.501303908094282, 15.465651517529206, 16.39498402934341, 17.396394521097744, 16.61441855030482, 17.45001028339408, 16.456282257821346, 15.513815916122354, 14.487073821030863, 13.502332205301746, 12.637543573230355, 11.730712152957498, 10.959465388326482, 10.029396938715593, 10.185748775675078, 10.813088806127883, 11.84448101629774, 12.588299578879594, 13.550846159914538, 14.50547092654989, 15.454846942896534, 16.489211329849113, 17.433730307322232, 17.40143537007845, 15.578750239622357, 16.53354227841457, 15.487796618387163, 14.553684853964786, 13.515446990678312, 12.552104312618622, 11.586201088307938, 10.735940869957753, 10.002202874841096, 9.005996608989848, 9.756488814313103, 10.66280074418545, 11.616462311599225, 12.570671742925885, 13.519808322566616, 14.482055997626807, 15.436177073367602, 16.363704255633994, 17.29812251046709, 16.476077387667257, 14.578995236146739, 15.550559253061865, 14.640656375924912, 13.621086245192796, 12.616242412037508, 11.594779153165787, 10.640932879885758, 9.738773400993889, 8.932783005792079, 8.0030065302908, 8.788594792031073, 9.711367074377657, 10.669148183046062, 11.706355717912674, 12.564228049537915, 13.572023045774847, 14.489418700375516, 15.418657911390937, 16.362880469327198, 15.559143581096498, 13.599438854060292, 14.637575344863036, 13.610382722047973, 12.613568907668872, 11.66407877765017, 10.655329310351386, 9.697950734272707, 8.712929903298603, 7.9052661504965425, 7.073046549397663, 7.8593192630293665, 8.73969833136269, 9.698643804155923, 10.6556890784945, 11.578715614314213, 12.518579506335477, 13.5581973893832, 14.48678626151351, 15.436234283803314, 14.666760142861719, 12.619172460183176, 13.565265860521937, 12.539489296516413, 11.654904959168798, 10.647469653057753, 9.677623784907308, 8.696850783605194, 7.747841381853656, 6.929556118145513, 6.0489372622984785, 6.797459226602389, 7.759323198503628, 8.773705999780871, 9.640751690675991, 10.612242633910865, 11.585531274339862, 12.568104337541019, 13.472162763342677, 14.537223812127658, 13.874292458413729, 11.698836598083796, 12.574138453471939, 11.606182334116218, 10.681894890178558, 9.748943427709824, 8.70592029280641, 7.702671408753815, 6.750905263007618, 5.937244091777782, 4.998118494043121, 5.850915644888943, 6.8412510031644125, 7.763081255586057, 8.620940854391284, 9.599646742700106, 10.626676741837526, 11.532498445331889, 12.47479920176323, 13.480164844701616, 12.934124240458011, 10.844925538827969, 11.715501401820998, 10.676380860711454, 9.664728546346197, 8.706593143568549, 7.655266675674781, 6.77069527264876, 5.761155271438865, 4.869015127489453, 3.9408639450104235, 4.899101313760373, 5.873232372707211, 6.701636834769927, 7.666320649355766, 8.658439073998366, 9.603818152768142, 10.53321175109047, 11.462848061571774, 12.451893295898781, 11.92056507952203, 9.987078921859247, 10.704722312955436, 9.767568999711195, 8.760749209611028, 7.706072054193305, 6.703222237029259, 5.760269059754474, 4.8213737525667755, 3.8843324793178398, 2.9714230561673576, 3.910269867497814, 4.867728678417072, 5.740974028864804, 6.726710896245125, 7.746482645666072, 8.726361394754106, 9.68754100081443, 10.651026541852135, 11.600051637142101, 10.887418639468189, 10.864286071687811, 9.83870611575552, 8.809615002507748, 7.819963273737603, 6.745155035336223, 5.829853258451333, 4.827780695360504, 3.8664237640886783, 2.9567535047145954, 2.014611937624519, 2.963951796746262, 3.798021322200373, 4.812271057570662, 5.809751135658204, 6.7633707458784045, 7.752369764803406, 8.76741250138726, 9.747720093896303, 10.76190902861051, 11.829627625650714], [11.78206323951857, 10.76667954015162, 9.775597162385449, 8.71605157760075, 7.776534196002915, 6.726076037999182, 5.745000740281829, 4.7789992486099235, 3.7597697583613208, 2.8210550057096078, 1.8923155311856594, 0.934883468426552, 1.9405169118444965, 2.8872845546219446, 3.820105922999501, 4.811788215451834, 5.863201670138921, 6.825930153592352, 7.8857762080045415, 8.95359221971282, 10.929793095332696, 9.999736652146236, 9.027096072653897, 8.086750262391822, 7.104368050649935, 6.101397009917919, 5.053879589632995, 4.012458530874449, 2.997621018459688, 1.992787222020369, 0.9926394627506671, 0.0, 0.9481943479463154, 1.9532493474007446, 2.9038954820338354, 3.882621694950672, 4.92255816312191, 5.953459916465427, 6.932763334136042, 7.948497841605689, 11.933362876812858, 10.932768245617506, 10.01802901174944, 9.017637601771456, 8.020245661840772, 7.049046727316014, 6.003139189659983, 4.95902804533983, 4.019798404015388, 3.041459008879394, 1.9835687141344631, 0.9463798920308147, 1.9781490721212691, 2.947416713499626, 3.87832509982171, 4.913048465519434, 5.893607709885736, 6.897517693151749, 7.8370301503339155, 8.858523370427328, 12.93627847760679, 11.890522596511692, 10.850952533060237, 9.798550528618646, 8.869399323899023, 7.899464182217604, 6.943074234854133, 5.95256581865019, 4.968757847967296, 3.982629546630366, 3.025248475248988, 1.9976076821336157, 2.9637152550400323, 3.889752751260224, 4.86225617942256, 5.832917185282874, 6.885602171432896, 7.873469058918719, 8.765514233410219, 9.705480093838275, 13.796145545473832, 12.746946818138563, 11.769107739052755, 10.705588301566403, 9.774893167867056, 8.847710605540776, 7.918032715967258, 6.923446072596881, 5.9695904444679195, 4.996120901942171, 3.9364378354705845, 2.93315464198193, 3.8996713742067404, 4.8404052357892065, 5.834998502142757, 6.798835361418983, 7.830629238605537, 8.805212624053896, 9.80788860839332, 10.656753513380846, 14.713094694231202, 13.695019663311525, 12.657587799506615, 11.655070078568182, 10.7524405994409, 9.847554796455132, 8.879748066345487, 7.9689250847312945, 6.907758899449735, 5.882100931203346, 4.878225927763426, 3.944577481162041, 4.864715166259764, 5.841618788175438, 6.817978899484922, 7.7611369457598105, 8.81998474758091, 9.841227062900128, 10.809018231946084, 11.714310250013774, 15.586057408350332, 14.646100548741527, 13.674906534022833, 12.663357685767005, 11.71838007522901, 10.814801121446731, 9.85653672217481, 8.862091893617812, 7.892485571817632, 6.868274399690107, 5.856362977297516, 4.8899660952165815, 5.809677280243565, 6.833968826785875, 7.765277346970329, 8.817980172398014, 9.84164192255488, 10.784468262929735, 11.789137760849956, 12.68402353973982, 16.516686040330693, 15.643180727138736, 14.70035862881611, 13.672317638889211, 12.751606238264596, 11.856538380775957, 10.831514733018876, 9.803713451011328, 8.845429382575258, 7.857221021424521, 6.8474708576227, 5.871274101405081, 6.794940645087635, 7.7331452798627485, 8.738846012938165, 9.75862919663534, 10.706049115954208, 11.690334706509484, 12.645580531555105, 13.655126497620401, 17.44910465272309, 16.579953684852292, 15.599938960166046, 14.633088032940078, 13.677429896680524, 12.777698531098139, 11.712598824111053, 10.777074919275623, 9.84753763222863, 8.848616100447897, 7.867309144446827, 6.897398965747003, 7.8318704255418625, 8.697428538229257, 9.652169193238837, 10.57961907929242, 11.513632890706672, 12.479229156778727, 13.52441959924069, 14.565126056304527, 17.434487903448055, 17.54802335361057, 16.547401451956933, 15.565270778236627, 14.622401447564368, 13.652974007842872, 12.716684884033302, 11.731616446122384, 10.773141720556394, 9.843303885335185, 8.847060249519782, 7.901070060104214, 8.874815117618516, 9.69019824749361, 10.689431521966274, 11.577974149552194, 12.488122872748843, 13.412527058321453, 14.476974132781226, 15.507607695919425, 16.461892694246572, 17.408640288232924, 16.519776703982302, 15.51798395188012, 14.491944113913311, 13.563578647583492, 12.628728839441031, 11.669444325681773, 11.039646417157966, 10.814937565801536, 9.834994776235883, 8.866230547870467, 9.858751402627268, 10.624986656502548, 11.61735858801263, 12.56710233718141, 13.508664445343616, 14.47301205477854, 15.40234456659274, 16.403755058347073, 15.621779087554152, 16.457370820643412, 15.46364279507068, 14.521176453371687, 13.494434358280197, 12.50969274255108, 11.644904110479688, 10.73807269020683, 9.973611721267288, 10.851827640855713, 10.813977797798133, 9.820449343377216, 10.851841553547073, 11.595660116128927, 12.558206697163872, 13.512831463799223, 14.462207480145867, 15.496571867098446, 16.441090844571562, 17.374562962480276, 14.58611077687169, 15.540902815663902, 14.495157155636496, 13.561045391214119, 12.522807527927645, 11.559464849867956, 10.593561625557271, 9.743301407207085, 9.016349207781902, 9.82842731112997, 10.58544265365568, 10.84493540125908, 11.777059676889627, 12.584145103111286, 13.521594100582977, 14.468525627835984, 15.463880826492003, 16.43998795661511, 17.374406211448203, 17.468716850417927, 13.586355773396074, 14.5579197903112, 13.648016913174246, 12.62844678244213, 11.623602949286841, 10.60213969041512, 9.648293417135092, 8.74613393824322, 7.946929338732883, 8.825437232430922, 9.61754863137365, 10.540320913720233, 11.498102022388638, 12.53530955725525, 13.405952540644854, 14.431581305467159, 15.348976960067828, 16.312728081241943, 17.256950639178207, 16.551783043847163, 12.606799391309627, 13.644935882112371, 12.617743259297306, 11.620929444918206, 10.671439314899501, 9.662689847600719, 8.70531127152204, 7.7202904405479345, 6.9194124834373465, 7.895477251537784, 8.688273102371943, 9.568652170705267, 10.527597643498499, 11.484642917837077, 12.420440105421152, 13.37813776602779, 14.417755649075511, 15.380856431364515, 16.33030445365432, 15.659399605612386, 11.626532997432511, 12.572626397771272, 11.546849833765746, 10.662265496418131, 9.654830190307084, 8.68498432215664, 7.704211320854527, 6.755201919102988, 5.943702451086317, 6.871367964438599, 7.6264130659449645, 8.588277037846204, 9.62263959927982, 10.534821860526998, 11.506312803761872, 12.47960144419087, 13.462174507392026, 14.366232933193682, 15.431293981978664, 14.866931921164396, 10.70619713533313, 11.581498990721272, 10.613542871365551, 9.689255427427891, 8.756303964959157, 7.713280830055741, 6.710031946003147, 5.75826580025695, 4.951390424718586, 5.820549196183242, 6.679869484231518, 7.670204842506988, 8.644549573949288, 9.515011024242291, 10.493716912551113, 11.520746911688533, 12.426568615182896, 13.368869371614236, 14.374235014552623, 13.926763703208678, 9.852286076077306, 10.72286193907033, 9.683741397960787, 8.67208908359553, 7.713953680817882, 6.6626272129241135, 5.778055809898092, 4.768515808688197, 3.8831614604302565, 4.763294647150545, 5.728055153102948, 6.727649157359072, 7.595707004620934, 8.560390819206773, 9.552509243849373, 10.497888322619149, 11.427281920941477, 12.356918231422782, 13.345963465749788, 12.913204542272696, 8.99443945910858, 9.71208285020477, 8.774929536960528, 7.76810974686036, 6.713432591442638, 5.710582774278591, 4.767629597003807, 3.8287342898161083, 2.8916930165671726, 3.7938537583074794, 4.739223706840389, 5.722145463068934, 6.6350441987158115, 7.620781066096132, 8.64055281551708, 9.620431564605113, 10.581611170665438, 11.545096711703142, 12.494121806993109, 11.880058102218856, 9.871646608937143, 8.84606665300485, 7.81697553975708, 6.827323810986935, 5.752515572585556, 4.837213795700666, 3.8351412326098373, 2.873784301338011, 1.9641140419639282, 2.8370426397646407, 3.7929056360888374, 4.69209149205138, 5.706341227421669, 6.703821305509211, 7.657440915729412, 8.646439934654413, 9.661482671238268, 10.64179026374731, 11.655979198461518, 12.723697795501721], [12.730257587464886, 11.714873888097936, 10.723791510331765, 9.664245925547066, 8.724728543949231, 7.674270385945498, 6.693195088228144, 5.727193596556239, 4.707964106307636, 3.769249353655923, 2.8405098791319747, 1.8830778163728674, 0.9923225638981811, 1.9390902066756288, 2.8719115750531854, 3.863593867505519, 4.915007322192606, 5.8777358056460365, 6.937581860058226, 8.005397871766506, 11.877987443279013, 10.947931000092552, 9.975290420600214, 9.034944610338139, 8.052562398596251, 7.0495913578642355, 6.002073937579311, 4.960652878820764, 3.9458153664060034, 2.9409815699666844, 1.9408338106969825, 0.9481943479463154, 0.0, 1.005054999454429, 1.9557011340875197, 2.9344273470043563, 3.9743638151755944, 5.0052655685191105, 5.984568986189726, 7.000303493659373, 12.881557224759174, 11.880962593563822, 10.966223359695757, 9.965831949717773, 8.968440009787088, 7.9972410752623295, 6.951333537606298, 5.907222393286145, 4.967992751961703, 3.989653356825709, 2.931763062080779, 1.8945742399771301, 1.0378292450844884, 2.007096886462845, 2.930130751875394, 3.9648541175731187, 4.945413361939421, 5.949323345205433, 6.888835802387599, 7.910329022481012, 13.884472825553106, 12.838716944458008, 11.799146881006553, 10.746744876564962, 9.817593671845339, 8.847658530163919, 7.891268582800448, 6.9007601665965055, 5.916952195913611, 4.930823894576681, 3.9734428231953034, 2.945802030079931, 2.0233954280032513, 2.949432924223443, 3.921936352385779, 4.892597358246093, 5.945282344396115, 6.925274710972403, 7.8173198854639026, 8.75728574589196, 14.744339893420149, 13.695141166084879, 12.717302086999071, 11.653782649512719, 10.723087515813372, 9.795904953487092, 8.866227063913573, 7.871640420543196, 6.917784792414235, 5.944315249888486, 4.884632183416899, 3.881348989928245, 2.966994635337844, 3.90772849692031, 4.902321763273861, 5.866158622550087, 6.89795249973664, 7.8570182761075795, 8.859694260447004, 9.70855916543453, 15.661289042177518, 14.643214011257841, 13.605782147452931, 12.603264426514498, 11.700634947387217, 10.795749144401446, 9.827942414291801, 8.917119432677609, 7.85595324739605, 6.83029527914966, 5.82642027570974, 4.892771829108357, 3.9320384273908666, 4.908942049306542, 5.885302160616026, 6.828460206890914, 7.887308008712013, 8.893032714953812, 9.860823883999768, 10.766115902067458, 16.534251756296648, 15.594294896687844, 14.62310088196915, 13.611552033713322, 12.666574423175327, 11.762995469393045, 10.804731070121125, 9.810286241564127, 8.840679919763947, 7.816468747636422, 6.804557325243831, 5.838160443162897, 4.8770005413746675, 5.9012920879169775, 6.832600608101432, 7.885303433529116, 8.908965183685982, 9.851791524060838, 10.856461021981058, 11.735829191793504, 17.46488038827701, 16.59137507508505, 15.648552976762426, 14.620511986835528, 13.699800586210912, 12.804732728722271, 11.77970908096519, 10.751907798957642, 9.793623730521572, 8.805415369370836, 7.795665205569016, 6.819468449351397, 5.862263906218738, 6.800468540993851, 7.806169274069267, 8.825952457766443, 9.77337237708531, 10.757657967640586, 11.712903792686207, 12.722449758751502, 17.441659602122108, 17.528148032798608, 16.548133308112362, 15.581282380886394, 14.62562424462684, 13.725892879044451, 12.660793172057366, 11.725269267221936, 10.795731980174944, 9.796810448394211, 8.815503492393141, 7.8455933136933185, 6.899193686672965, 7.7647517993603605, 8.719492454369941, 9.646942340423525, 10.580956151837777, 11.546552417909831, 12.591742860371795, 13.632449317435631, 16.50181116457916, 17.420771719236203, 16.53300458466871, 15.538928390945225, 14.596059060272966, 13.658724977850977, 12.722435854041407, 11.786562689795682, 11.721336068502708, 10.7914982332815, 9.795254597466096, 8.849264408050528, 7.942138378749618, 8.757521508624714, 9.756754783097378, 10.645297410683298, 11.555446133879947, 12.479850319452558, 13.54429739391233, 14.57493095705053, 15.529215955377678, 16.47596354936403, 15.580713951224894, 14.578921199122712, 13.552881361155903, 12.624515894826084, 11.68966608668362, 10.730381572924362, 11.749380050745998, 11.76313191374785, 10.783189124182197, 9.814424895816781, 8.988267812948767, 9.692309917633652, 10.684681849143734, 11.634425598312514, 12.57598770647472, 13.540335315909644, 14.469667827723844, 15.47107831947818, 14.689102348685257, 15.518308067886004, 14.524580042313271, 13.58211370061428, 12.555371605522788, 11.570629989793671, 10.705841357722278, 9.79900993744942, 10.776915017699187, 11.723468704864022, 11.762172145744447, 10.76864369132353, 9.99626649873455, 10.662983377260032, 11.625529958294976, 12.580154724930328, 13.529530741276972, 14.56389512822955, 15.508414105702666, 16.44188622361138, 13.653434038002791, 14.601840062906494, 13.556094402879088, 12.62198263845671, 11.583744775170237, 10.620402097110548, 9.654498872799861, 8.804238654449675, 9.819652504213801, 10.700068375138278, 11.533637001601996, 11.793129749205395, 10.921484622077104, 11.65146836424239, 12.588917361714081, 13.535848888967088, 14.531204087623108, 15.507311217746215, 16.44172947257931, 17.367244206022573, 12.638161425449757, 13.609725442364883, 12.708954160416837, 11.689384029684721, 10.684540196529433, 9.663076937657712, 8.709230664377682, 7.80707118548581, 8.756306289500985, 9.69707829643923, 10.565742979319966, 11.48851526166655, 11.868798750630267, 12.584708339838246, 13.538895507180719, 14.460930946155239, 15.453949989983286, 16.452357561989274, 17.445026868221294, 17.49997739179348, 11.65860504336331, 12.696741534166055, 11.678680506539896, 10.681866692160796, 9.732376562142093, 8.72362709484331, 7.766248518764631, 6.781227687790525, 7.745980699603143, 8.78674191136522, 9.636467450318259, 10.516846518651583, 11.475791991444815, 12.432837265783393, 13.368634453367468, 14.326332113974106, 15.365949997021827, 16.32905077931083, 17.278498801600634, 16.607593953558702, 10.678338649486195, 11.624432049824955, 10.607787081008336, 9.723202743660721, 8.715767437549676, 7.745921569399231, 6.765148568097118, 5.816139166345579, 6.847839117349896, 7.819562312384916, 8.57460741389128, 9.53647138579252, 10.570833947226136, 11.483016208473314, 12.454507151708189, 13.427795792137186, 14.410368855338342, 15.314427281139999, 16.379488329924982, 15.815126269110712, 9.758002787386815, 10.642436237963862, 9.674480118608141, 8.750192674670481, 7.817241212201747, 6.7742180772983325, 5.7709691932457385, 4.819203047499541, 5.855527090982164, 6.768743544129558, 7.628063832177834, 8.618399190453303, 9.592743921895602, 10.463205372188607, 11.44191126049743, 12.46894125963485, 13.374762963129212, 14.317063719560553, 15.322429362498939, 14.874958051154994, 8.90409172813099, 9.78379918631292, 8.744678645203377, 7.73302633083812, 6.774890928060472, 5.723564460166704, 4.838993057140684, 3.8294530559307884, 4.818181254170719, 5.711488995096861, 6.676249501049265, 7.675843505305388, 8.54390135256725, 9.50858516715309, 10.50070359179569, 11.446082670565465, 12.375476268887793, 13.305112579369098, 14.294157813696104, 13.861398890219013, 8.046245111162264, 8.77302009744736, 7.835866784203117, 6.82904699410295, 5.774369838685228, 4.771520021521182, 3.8285668442463976, 2.889671537058699, 3.826712810307635, 4.742048106253795, 5.687418054786705, 6.67033981101525, 7.583238546662127, 8.568975414042448, 9.588747163463395, 10.568625912551429, 11.529805518611754, 12.493291059649458, 13.442316154939425, 12.828252450165172, 8.923452260990828, 7.897872305058536, 6.868781191810765, 5.87912946304062, 4.80432122463924, 3.8890194477543503, 2.886946884663521, 1.9255899533916958, 2.912308389910244, 3.785236987710956, 4.741099984035153, 5.640285839997695, 6.6545355753679845, 7.652015653455527, 8.605635263675728, 9.59463428260073, 10.609677019184584, 11.589984611693627, 12.604173546407834, 13.671892143448037], [13.735312586919315, 12.719928887552365, 11.728846509786194, 10.669300925001496, 9.729783543403661, 8.679325385399927, 7.698250087682573, 6.732248596010668, 5.713019105762065, 4.774304353110352, 3.845564878586404, 2.8881328158272965, 1.9438926787843753, 0.9340352072211998, 1.8668565755987565, 2.85853886805109, 3.909952322738177, 4.872680806191608, 5.932526860603797, 7.000342872312077, 12.883042442733442, 11.952985999546982, 10.980345420054643, 10.039999609792568, 9.057617398050681, 8.054646357318665, 7.007128937033741, 5.965707878275195, 4.950870365860434, 3.946036569421114, 2.945888810151412, 1.9532493474007446, 1.005054999454429, 0.0, 0.9506461346330906, 1.9293723475499271, 2.969308815721165, 4.000210569064682, 4.979513986735297, 5.995248494204944, 13.886612224213604, 12.886017593018252, 11.971278359150187, 10.970886949172202, 9.973495009241518, 9.00229607471676, 7.956388537060729, 6.912277392740576, 5.973047751416134, 4.994708356280139, 3.9368180615352077, 2.8996292394315595, 2.0076950892594527, 1.0384274478810958, 1.9250757524209652, 2.9597991181186893, 3.940358362484991, 4.944268345751004, 5.88378080293317, 6.905274023026583, 14.889527825007535, 13.843771943912438, 12.804201880460983, 11.751799876019392, 10.822648671299769, 9.852713529618349, 8.896323582254878, 7.905815166050935, 6.922007195368041, 5.935878894031111, 4.978497822649733, 3.950857029534361, 2.956502990572144, 1.9807634856416936, 2.9532669138040295, 3.909487979930624, 4.951172970597191, 5.920219711517974, 6.812264886009474, 7.75223074643753, 15.749394892874578, 14.700196165539309, 13.722357086453501, 12.658837648967149, 11.728142515267802, 10.800959952941522, 9.871282063368003, 8.861928704889083, 7.908073076760122, 6.934603534234373, 5.869902123620202, 4.866618930131547, 3.9001021979067363, 2.9653375673605193, 3.9599308337140697, 4.923767692990296, 5.946657335263849, 6.851963276653151, 7.854639260992576, 8.703504165980101, 16.666344041631948, 15.648269010712271, 14.610837146907361, 13.608319425968928, 12.705689946841646, 11.800804143855876, 10.83299741374623, 9.907407717023496, 8.846241531741937, 7.815565219352963, 6.811690215913043, 5.8765202121520765, 4.8651459899597596, 3.966551119746751, 4.942911231056235, 5.886069277331123, 6.944917079152223, 7.8879777154993835, 8.85576888454534, 9.76106090261303, 17.53930675575108, 16.599349896142275, 15.628155881423579, 14.616607033167751, 13.671629422629756, 12.768050468847475, 11.809786069575555, 10.795556181767429, 9.825949859967249, 8.801738687839723, 7.788305708287551, 6.8219088262066165, 5.810108103943561, 5.022796056164511, 5.921491589939033, 6.95658145097593, 7.9802432011327955, 8.923069541507651, 9.897056508979311, 10.730774192339076, 17.47551914030482, 17.596430074539484, 16.653607976216858, 15.625566986289957, 14.704855585665342, 13.804451472297236, 12.764979021168493, 11.737177739160945, 10.778893670724875, 9.779473113091917, 8.769722949290097, 7.793526193072478, 6.795371468787631, 6.049035585317622, 6.895060255906869, 7.914843439604044, 8.862263358922911, 9.846548949478187, 10.801794774523808, 11.71942711112409, 16.59790372631712, 17.585897855966735, 16.606969866757993, 15.640118939532027, 14.684460803272472, 13.798560332466192, 12.888115669531015, 12.710539207425239, 11.781001920378246, 10.770868192115293, 9.789561236114222, 8.81187439488378, 7.832301249241858, 7.013318843684131, 7.889552240331338, 8.81700212638492, 9.751015937799172, 10.716612203871227, 11.76180264633319, 12.687467838922801, 15.645686045093534, 16.527318540595388, 15.676434776784374, 14.68235858306089, 13.73948925238863, 12.820318733418334, 11.884029609608765, 12.738132804681877, 12.69539381222379, 11.765555977002581, 10.761535678656559, 9.815545489240991, 8.87524594131851, 8.006088552948485, 8.926814569058774, 9.815357196644694, 10.725505919841343, 11.649910105413953, 12.714357179873726, 13.681477778409716, 14.635762776736865, 15.582510370723218, 14.687105457655127, 13.722351391238377, 12.696311553271567, 11.767946086941748, 10.851259842250977, 11.681951687810557, 12.700950165632193, 12.729412994938313, 11.74947020537266, 10.780705977007244, 9.921375375517659, 8.940876961957423, 9.933248893467505, 10.882992642636285, 11.746047492436116, 12.71039510187104, 13.63972761368524, 14.62732244367319, 13.716726441008948, 14.624699574316237, 13.630971548743505, 12.701310450867192, 11.698801797638453, 10.714060181909336, 9.849271549837944, 10.750580052335614, 11.728485132585382, 12.675038819750217, 12.72845322693491, 11.734924772513994, 10.919543179791475, 9.911550421583803, 10.874097002618747, 11.828721769254098, 12.699590527238367, 13.733954914190946, 14.678473891664062, 15.598130347806393, 12.65041139037538, 13.654921792675818, 12.662485909309321, 11.728374144886944, 10.727174967285901, 9.763832289226212, 8.797929064915527, 9.75580876933587, 10.771222619099996, 11.651638490024473, 12.538692001056425, 12.759410830395858, 11.844761303134028, 10.900035408566161, 11.837484406037852, 12.784415933290859, 13.701263873584503, 14.677371003707611, 15.611789258540705, 16.523488330217585, 11.63310642599533, 12.604670442910455, 11.751369369146698, 10.795775536114954, 9.827970388645097, 8.806507129773376, 7.852660856493348, 8.758641300372005, 9.70787640438718, 10.648648411325425, 11.570797978774396, 12.49357026112098, 12.792075431687191, 11.833275384162016, 12.78746255150449, 13.70949799047901, 14.64802224657659, 15.622417347950668, 16.615086654182686, 17.477972379365774, 10.653550043908883, 11.691686534711627, 10.721095715269756, 9.724281900890656, 8.86628045640692, 7.867057286958976, 6.909678710880297, 7.7327978026767195, 8.697550814489338, 9.738312026251416, 10.641522449772689, 11.521901518106013, 12.480846990899245, 12.88394202358019, 13.772974986728192, 14.73067264733483, 15.579243557568907, 16.554288997828095, 17.5037370201179, 17.61264895301313, 9.673283650031767, 10.619377050370527, 9.650202289738196, 8.765617952390581, 7.849671331814503, 6.879825463664057, 5.908578760212784, 6.767709281231773, 7.799409232236091, 8.79156371473292, 9.57966241334571, 10.54152638524695, 11.575888946680566, 12.488071207927744, 13.459562151162618, 14.432850791591616, 15.415423854792772, 16.31948228059443, 17.38454332937941, 16.82018126856514, 8.752947787932387, 9.684851446693722, 8.716895327338001, 7.792607883400342, 6.859656420931607, 5.826134482356187, 4.894093934225075, 5.770773162385735, 6.807097205868359, 7.740744946477562, 8.633118831632263, 9.623454189907733, 10.597798921350032, 11.468260371643037, 12.446966259951859, 13.47399625908928, 14.379817962583642, 15.322118719014982, 16.32748436195337, 15.880013050609424, 7.89903672867656, 8.82621439504278, 7.7870938539332375, 6.77544153956798, 5.817306136790332, 4.773564619711279, 3.96211779812002, 4.781023170816982, 5.769751369056912, 6.683490397444865, 7.681304500503694, 8.680898504759817, 9.54895635202168, 10.51364016660752, 11.50575859125012, 12.451137670019895, 13.380531268342223, 14.310167578823528, 15.299212813150534, 14.866453889673442, 7.041190111707835, 7.815435306177218, 6.878281992932976, 5.871462202832809, 4.816785047415087, 3.8215201810657566, 2.9411215675558067, 3.8412416519448933, 4.778282925193829, 5.714049508601799, 6.692473054241135, 7.67539481046968, 8.588293546116557, 9.574030413496878, 10.593802162917823, 11.573680912005857, 12.534860518066182, 13.498346059103886, 14.447371154393853, 13.833307449619602, 7.918397261536399, 6.892817305604107, 5.863726192356336, 4.874074463586191, 3.7992662251848115, 2.8839644482999214, 1.8818918852090922, 2.87716006827789, 3.917363389364673, 4.790291987165386, 5.746154983489583, 6.645340839452124, 7.659590574822413, 8.657070652909955, 9.610690263130156, 10.599689282055158, 11.614732018639012, 12.595039611148055, 13.609228545862262, 14.676947142902465], [14.685958721552405, 13.670575022185455, 12.679492644419284, 11.619947059634585, 10.68042967803675, 9.629971520033017, 8.648896222315663, 7.682894730643758, 6.663665240395155, 5.724950487743443, 4.796211013219494, 3.838778950460387, 2.8945388134174657, 1.8846813418542903, 1.0082561600313265, 1.94348283631545, 2.978710456810466, 3.9414389402638967, 5.0012849946760864, 6.063251700303361, 13.833688577366532, 12.903632134180071, 11.930991554687733, 10.990645744425658, 10.00826353268377, 9.005292491951755, 7.9577750716668305, 6.916354012908284, 5.901516500493523, 4.8966827040542045, 3.896534944784502, 2.903895482033835, 1.9557011340875197, 0.9506461346330906, 0.0, 0.9787262129168366, 2.018662681088075, 3.0495644344315913, 4.0288678521022065, 5.044602359571853, 14.837258358846693, 13.836663727651342, 12.921924493783276, 11.921533083805292, 10.924141143874607, 9.95294220934985, 8.907034671693818, 7.862923527373665, 6.923693886049223, 5.945354490913229, 4.887464196168298, 3.85027537406465, 2.8849976038786007, 1.9157299625002437, 0.9744296177878745, 2.009152983485599, 2.989712227851901, 3.9936222111179136, 4.93313466830008, 5.954627888393492, 15.836649277732162, 14.790893396637065, 13.749545978422528, 12.697143973980939, 11.767992769261316, 10.798057627579896, 9.841667680216425, 8.812034108192108, 7.828226137509215, 6.842097836172285, 5.884716764790907, 4.857075971675535, 3.833805505191292, 2.8580660002608416, 2.009470489562028, 2.958841845297534, 4.0005268359641, 4.969573576884883, 5.861618751376383, 6.80158461180444, 16.65618333383402, 15.606984606498747, 14.62914552741294, 13.565626089926587, 12.63493095622724, 11.70774839390096, 10.778070504327442, 9.73923121950823, 8.78537559137927, 7.811906048853521, 6.747204638239349, 5.743921444750695, 4.777404712525884, 3.8426400819796673, 3.0588446865530297, 4.008828910385753, 4.996011200630758, 5.90131714202006, 6.903993126359485, 7.752858031347011, 17.573132482591383, 16.555057451671708, 15.5176255878668, 14.515107866928366, 13.612478387801085, 12.707592584815314, 11.73978585470567, 10.784710231642643, 9.723544046361084, 8.69286773397211, 7.68899273053219, 6.753822726771224, 5.742448504578907, 4.8438536343658996, 4.07924884526607, 5.0224068915409585, 6.037413653475032, 6.937331580866293, 7.905122749912248, 8.81041476797994, 17.45550163765209, 17.506138337101714, 16.53494432238302, 15.52339547412719, 14.578417863589195, 13.674838909806914, 12.716574510534993, 11.672858696386575, 10.703252374586395, 9.67904120245887, 8.665608222906698, 7.699211340825764, 6.6874106185627085, 5.900098570783659, 5.057829204148868, 6.092919065185765, 7.111991825487877, 7.9903066030098024, 8.94641037434622, 9.780128057705987, 16.52487300567173, 17.589338269087825, 16.72441137745748, 15.760246025579454, 14.762298742389737, 14.002642575765663, 13.642281535787639, 12.61448025378009, 11.65619618534402, 10.656775627711065, 9.647025463909245, 8.670828707691625, 7.672673983406779, 6.92633809993677, 6.031397870116704, 7.051181053813879, 7.998600973132747, 8.982886563688023, 9.896026283993455, 10.768780976491001, 15.647257591684031, 16.635251721333645, 15.756348580579024, 14.792133220233364, 13.83647508397381, 12.966071747001623, 13.838761804164106, 13.587841722044384, 12.658304434997392, 11.64817070673444, 10.66686375073337, 9.689176909502928, 8.709603763861006, 7.89062135830328, 7.025889854541173, 7.953339740594757, 8.887353552009008, 9.852949818081063, 10.898140260543027, 11.736821704289712, 14.695039910460444, 15.576672405962299, 14.808886088788139, 13.834372863762226, 12.891503533089967, 11.987830147953765, 12.834675744241856, 13.68877893931497, 13.572696326842937, 12.642858491621729, 11.638838193275706, 10.692848003860139, 9.752548455937658, 8.883391067567633, 8.06315218326861, 8.95169481085453, 9.861843534051179, 10.78624771962379, 11.850694794083562, 12.730831643776627, 13.685116642103775, 14.631864236090129, 13.772049425919487, 12.842707306373667, 11.848325833972904, 10.919960367643085, 11.801905976884068, 12.63259782244365, 13.651596300265286, 13.60671550955746, 12.626772719991807, 11.658008491626392, 10.798677890136807, 9.81817947657657, 9.099843352307287, 10.02129704284038, 10.882385106645952, 11.846732716080876, 12.776065227895076, 13.6766763090401, 12.766080306375859, 13.709643542580597, 12.715915517007865, 11.786254419131552, 10.85081607833979, 9.866074462610673, 10.799917684471035, 11.701226186968706, 12.679131267218473, 13.625684954383308, 13.605755741554058, 12.612227287133141, 11.796845694410623, 10.78885293620295, 10.14061994006582, 11.042353744979724, 11.835928141448203, 12.870292528400782, 13.814811505873898, 14.647484213173303, 11.69976525574229, 12.704275658042725, 11.747429877573682, 10.813318113151304, 9.879189247987238, 8.915846569927549, 9.748575199548618, 10.706454903968961, 11.721868753733087, 12.602284624657564, 13.489338135689515, 13.636713345015005, 12.722063817753176, 11.777337923185309, 11.104007343484925, 11.998047909016485, 12.83760148779434, 13.813708617917447, 14.748126872750541, 15.572842195584496, 10.682460291362238, 11.654024308277364, 10.836313337411056, 9.880719504379314, 8.968375317535532, 7.958521410474713, 8.803306991126439, 9.709287435005097, 10.658522539020272, 11.599294545958516, 12.521444113407485, 13.444216395754069, 13.669377946306339, 12.710577898781164, 12.059587616513626, 12.923129966204636, 13.784359860786426, 14.758754962160504, 15.751424268392523, 16.527326244732684, 9.702903909275792, 10.741040400078536, 9.806039683534117, 8.809225869155016, 7.99864033254443, 7.019071567660312, 7.860324845513388, 8.68344393730981, 9.648196949122429, 10.688958160884507, 11.592168584405778, 12.472547652739102, 13.431493125532334, 13.761244538199337, 13.045100051737329, 13.976573505644005, 14.715581171778743, 15.690626612037931, 16.640074634327735, 17.572871339150915, 8.722637515398675, 9.668730915737436, 8.735146258002557, 7.8505619206549415, 6.982031207952012, 6.0212250480966265, 6.859224894845874, 7.718355415864864, 8.750055366869182, 9.74220984936601, 10.5303085479788, 11.49217251988004, 12.526535081313655, 13.438717342560834, 14.011573032140676, 14.90962173763962, 15.729869151192387, 16.705250110208762, 17.60250676695066, 17.72696970952458, 7.8023016532992955, 8.766733628211512, 7.8018392956023614, 6.877551851664702, 5.944600389195967, 4.967534066788756, 5.844740068858165, 6.7214192970188265, 7.757743340501451, 8.691391081110652, 9.583764966265353, 10.574100324540822, 11.548445055983121, 12.418906506276127, 13.397612394584948, 14.424642393722369, 15.330464097216732, 16.27276485364807, 17.278130496586456, 16.830659185242514, 6.948390594043469, 7.911158363307139, 6.872037822197598, 5.860385507832341, 4.9022501050546925, 3.9149642041438484, 4.91276393275311, 5.731669305450073, 6.720397503690004, 7.634136532077955, 8.631950635136784, 9.631544639392907, 10.49960248665477, 11.464286301240609, 12.456404725883209, 13.401783804652984, 14.331177402975312, 15.260813713456617, 16.249858947783625, 15.817100024306532, 6.090543977074745, 6.900379274441578, 5.963225961197336, 4.95640617109717, 3.9017290156794475, 2.9629197654983264, 3.891767702188897, 4.791887786577984, 5.728929059826919, 6.664695643234889, 7.643119188874225, 8.626040945102769, 9.538939680749646, 10.524676548129968, 11.544448297550915, 12.524327046638948, 13.485506652699273, 14.448992193736977, 15.398017289026944, 14.783953584252691, 6.9871553956086885, 5.9615754396763965, 4.932484326428625, 3.9590184318505512, 2.8842101934491717, 2.025364032732491, 2.8325380198421826, 3.8278062029109803, 4.868009523997763, 5.740938121798476, 6.696801118122673, 7.595986974085214, 8.610236709455505, 9.607716787543046, 10.561336397763247, 11.550335416688249, 12.565378153272103, 13.545685745781146, 14.559874680495353, 15.627593277535556], [15.664684934469241, 14.64930123510229, 13.65821885733612, 12.598673272551421, 11.659155890953587, 10.608697732949853, 9.6276224352325, 8.661620943560594, 7.642391453311991, 6.703676700660279, 5.7749372261363305, 4.8175051633772235, 3.8732650263343027, 2.863407554771127, 1.9564389158509468, 0.9647566233986133, 1.9999842438936293, 2.9627127273470597, 4.022558781759249, 5.084525487386524, 14.812414790283368, 13.882358347096908, 12.909717767604569, 11.969371957342494, 10.986989745600606, 9.98401870486859, 8.936501284583667, 7.8950802258251205, 6.880242713410359, 5.875408916971041, 4.875261157701338, 3.8826216949506716, 2.9344273470043563, 1.9293723475499271, 0.9787262129168366, 0.0, 1.0399364681712382, 2.0708382215147547, 3.05014163918537, 4.065876146655016, 15.81598457176353, 14.815389940568178, 13.900650706700112, 12.900259296722128, 11.902867356791443, 10.931668422266686, 9.885760884610654, 8.841649740290501, 7.90242009896606, 6.924080703830065, 5.866190409085135, 4.829001586981486, 3.8637238167954373, 2.8944561754170803, 1.953155830704711, 1.0304267705687624, 2.0109860149350642, 3.014895998201077, 3.954408455383244, 4.975901675476656, 16.815375490649004, 15.769619609553905, 14.728272191339368, 13.675870186897777, 12.746718982178153, 11.776783840496734, 10.820393893133263, 9.790760321108946, 8.806952350426052, 7.820824049089122, 6.863442977707744, 5.835802184592372, 4.812531718108128, 3.836792213177678, 2.9507766382410106, 1.980115632380697, 3.0218006230472643, 3.9908473639680464, 4.882892538459547, 5.822858398887604, 17.634909546750855, 16.585710819415585, 15.607871740329776, 14.544352302843423, 13.613657169144076, 12.686474606817796, 11.756796717244278, 10.717957432425067, 9.764101804296105, 8.790632261770357, 7.7259308511561855, 6.722647657667531, 5.75613092544272, 4.821366294896504, 3.9939395567451417, 3.030102697468916, 4.017284987713922, 4.922590929103223, 5.925266913442649, 6.774131818430175, 17.52096756821399, 17.533783664588544, 16.496351800783636, 15.493834079845202, 14.591204600717921, 13.68631879773215, 12.718512067622505, 11.76343644455948, 10.70227025927792, 9.671593946888946, 8.667718943449026, 7.73254893968806, 6.721174717495743, 5.822579847282736, 5.014343715458182, 4.0799271728296755, 5.058687440558196, 5.958605367949456, 6.926396536995412, 7.831688555063105, 16.47677542473525, 17.416732284344057, 16.771137259333923, 15.905214056111655, 14.942220692356312, 14.65356512272375, 13.69530072345183, 12.651584909303411, 11.681978587503231, 10.657767415375707, 9.644334435823534, 8.6779375537426, 7.666136831479545, 6.878824783700495, 5.99292407434098, 5.150439346474482, 6.133265612571041, 7.011580390092965, 7.967684161429384, 8.80140184478915, 15.546146792754891, 16.61061205617099, 15.745685164540644, 14.906941812510444, 13.908994529320728, 14.848730790731526, 14.621007748704475, 13.593206466696927, 12.634922398260857, 11.635501840627903, 10.625751676826082, 9.649554920608463, 8.651400196323616, 7.9050643128536064, 6.966492740308816, 6.220521722395528, 7.09997889587451, 8.050380315131417, 8.91730007107662, 9.790054763574165, 14.668531378767195, 15.65652550841681, 14.777622367662188, 13.938829007164355, 12.9831708709048, 13.87992654577851, 14.766721843525206, 14.56656793496122, 13.637030647914228, 12.626896919651278, 11.645589963650208, 10.667903122419764, 9.688329976777842, 8.869347571220116, 7.960984724733285, 7.198325612923593, 8.124892169676873, 9.090488435748927, 9.979904901930393, 10.758095491372876, 13.716313697543608, 14.597946193045463, 13.830159875871303, 12.903382565732397, 12.038199320020958, 12.901684946730652, 13.762635783602956, 14.65365842803954, 14.551422539759775, 13.621584704538567, 12.617564406192542, 11.671574216776975, 10.731274668854494, 9.862117280484469, 8.998247053460721, 8.196680683183367, 9.099382151719043, 10.023786337291654, 10.932459435470928, 11.75210543085979, 12.70639042918694, 13.653138023173293, 12.793323213002651, 11.86398109345683, 10.995021620903895, 11.833815166419972, 12.729866016245168, 13.59747731116822, 14.616475788989856, 14.585441722474297, 13.605498932908644, 12.636734704543228, 11.777404103053643, 10.796905689493407, 10.034938222499399, 9.266282915169217, 10.119923724313818, 11.084271333748742, 11.857829869282442, 12.697950096123265, 11.787354093459022, 12.730917329663761, 11.737189304091029, 10.807528206214716, 9.972006127336112, 10.77992926138756, 11.727877723832135, 12.666105675693277, 13.644010755943045, 14.59242021654302, 14.584481954470894, 13.590953500049977, 12.775571907327459, 11.767579149119786, 11.075714810257931, 10.287339617308561, 11.07346675911607, 12.107831146068648, 12.896576147261264, 13.668758000256467, 10.721039042825455, 11.725549445125889, 10.768703664656845, 9.834591900234468, 9.00037929698356, 9.829701368704436, 10.676535238909718, 11.671334392693533, 12.686748242457659, 13.569019886817276, 14.45930150641503, 14.615439557931841, 13.700790030670012, 12.756064136102145, 12.039102213677037, 11.243033781345321, 12.075140105462205, 13.051247235585313, 13.914076537843961, 14.59411598266766, 9.703734078445402, 10.675298095360528, 9.85758712449422, 8.901993291462478, 7.989649104618696, 8.8723762092516, 9.731267030487539, 10.67602269716481, 11.625257801179984, 12.566029808118229, 13.491407484133001, 14.414179766479585, 14.648104159223175, 13.689304111698, 12.994682486705738, 12.168115838533472, 13.021898478454291, 13.99629357982837, 14.917373933485942, 15.548600031815848, 8.724177696358955, 9.7623141871617, 8.827313470617279, 7.830499656238181, 7.019914119627594, 7.932926366437199, 8.788284884874487, 9.650179199469523, 10.614932211282142, 11.65569342304422, 12.562131955131294, 13.442511023464618, 14.40145649625785, 14.739970751116173, 13.98019492192944, 13.221559377972842, 13.953119789446609, 14.928165229705797, 15.844020119009826, 16.60617160087637, 7.743911302481839, 8.6900047028206, 7.756420045085719, 6.871835707738105, 6.003304995035176, 6.9350798468735135, 7.787184934206975, 8.685090678024576, 9.716790629028894, 10.708945111525722, 11.500271918704316, 12.462135890605555, 13.496498452039171, 14.41744355547767, 14.946667902332788, 14.154607609968457, 14.967407768860253, 15.94278872787663, 16.806452251632752, 17.63638987296327, 6.823575440382459, 7.788007415294675, 6.8231130826855235, 5.898825638747866, 4.965874176279131, 5.881388865565643, 6.772700108219266, 7.688154559178539, 8.724478602661163, 9.658126343270364, 10.553728336990869, 11.544063695266338, 12.518408426708637, 13.397632719192963, 14.376338607501784, 15.113462142470793, 16.003013661069385, 16.940152289456076, 17.869815476944886, 17.80938539815935, 5.969664381126633, 6.932432150390303, 5.89331160928076, 4.8816592949155035, 3.9235238921378555, 4.828819002920735, 5.840723972114211, 6.698404567609786, 7.687132765849716, 8.600871794237667, 9.6019140058623, 10.610270852309743, 11.478328699571605, 12.443012514157445, 13.435130938800045, 14.38051001756982, 15.309903615892148, 16.239539926373453, 17.22858516070046, 16.79582623722337, 5.111817764157908, 5.921653061524742, 4.9844997482805, 3.977679958180333, 2.923002802762611, 3.876774564275213, 4.819727741549998, 5.758623048737697, 6.695664321986632, 7.631430905394602, 8.621845401791061, 9.604767158019605, 10.517665893666482, 11.503402761046804, 12.52317451046775, 13.503053259555784, 14.46423286561611, 15.427718406653813, 16.37674350194378, 15.762679797169527, 6.008429182691852, 4.98284922675956, 3.9537581135117885, 2.980292218933714, 1.9054839805323351, 2.9392188315093777, 3.8112642327590196, 4.806532415827817, 5.846735736914599, 6.719664334715312, 7.675527331039509, 8.57471318700205, 9.58896292237234, 10.586443000459882, 11.540062610680083, 12.529061629605085, 13.54410436618894, 14.524411958697982, 15.53860089341219, 16.606319490452393], [16.70462140264048, 15.68923770327353, 14.69815532550736, 13.63860974072266, 12.699092359124826, 11.648634201121093, 10.667558903403739, 9.701557411731834, 8.68232792148323, 7.743613168831517, 6.814873694307568, 5.857441631548461, 4.9132014945055404, 3.903344022942365, 2.996375384022185, 2.0046930915698518, 0.9600477757223911, 1.9227762591758217, 2.9826223135880117, 4.0445890192152865, 15.852351258454606, 14.922294815268145, 13.949654235775807, 13.009308425513732, 12.026926213771844, 11.023955173039829, 9.976437752754904, 8.935016693996358, 7.920179181581597, 6.915345385142278, 5.915197625872576, 4.922558163121909, 3.974363815175594, 2.969308815721165, 2.018662681088075, 1.0399364681712382, 0.0, 1.0309017533435165, 2.0102051710141318, 3.0259396784837786, 16.855921039934767, 15.855326408739415, 14.94058717487135, 13.940195764893366, 12.942803824962681, 11.971604890437924, 10.925697352781892, 9.881586208461739, 8.942356567137297, 7.964017172001303, 6.906126877256373, 5.868938055152724, 4.9036602849666755, 3.9343926435883185, 2.993092298875949, 2.0345064470296848, 0.971049546763826, 1.9749595300298388, 2.9144719872120057, 3.9359652073054177, 17.85531195882024, 16.809556077725144, 15.768208659510606, 14.715806655069015, 13.786655450349391, 12.816720308667971, 11.8603303613045, 10.830696789280184, 9.84688881859729, 8.86076051726036, 7.903379445878983, 6.87573865276361, 5.852468186279367, 4.876728681348917, 3.9548563147019333, 2.9841953088416195, 1.9818641548760259, 2.950910895796808, 3.8429560702883085, 4.782921930716365, 17.54314083169108, 17.62564728758682, 16.64780820850101, 15.584288771014661, 14.653593637315314, 13.726411074989034, 12.796733185415516, 11.757893900596304, 10.804038272467343, 9.830568729941595, 8.765867319327423, 7.762584125838769, 6.796067393613959, 5.861302763067743, 4.9729792560054635, 4.009142396729238, 2.977348519542684, 3.882654460931985, 4.885330445271411, 5.734195350258936, 16.481031100042753, 17.340792029839378, 16.877238068566655, 16.098389637549822, 15.631141068889159, 14.726255265903388, 13.758448535793743, 12.803372912730717, 11.742206727449158, 10.711530415060183, 9.707655411620264, 8.772485407859298, 7.761111185666982, 6.862516315453974, 5.993383414718504, 5.058966872089997, 4.018750972386958, 4.918668899778218, 5.8864600688241735, 6.791752086891866, 15.436838956564014, 16.37679581617282, 15.859919334050437, 15.090102030350998, 15.861306081861951, 15.693501590894988, 14.735237191623067, 13.691521377474649, 12.721915055674469, 11.697703883546945, 10.684270903994772, 9.717874021913838, 8.706073299650782, 7.903272293785756, 6.971963773601302, 6.116990894556668, 5.093329144399803, 5.971643921921728, 6.927747693258145, 7.761465376617912, 14.506210324583654, 15.570675587999752, 14.83446723925716, 14.081142077228792, 14.828079918826367, 15.767816180237165, 15.660944216875713, 14.633142934868165, 13.674858866432094, 12.67543830879914, 11.66568814499732, 10.6894913887797, 9.691336664494854, 8.929511822938867, 7.945532439569138, 7.00746234702214, 6.060042427703272, 7.01044384696018, 7.877363602905381, 8.750118295402928, 13.628594910595957, 14.616589040245572, 13.866404442378704, 13.09171322831616, 13.90225626041044, 14.884509868502164, 15.806658311696443, 15.606504403132458, 14.676967116085466, 13.666833387822516, 12.685526431821446, 11.707839590591002, 10.72826644494908, 9.867456778613368, 8.912716123603788, 7.9852662375502055, 7.084955701505635, 8.05055196757769, 8.939968433759155, 9.718159023201638, 12.67637722937237, 13.558009724874225, 12.918941950587818, 12.0449706897655, 12.957284709526595, 13.910342257050031, 14.802572251774194, 15.693594896210778, 15.591359007931013, 14.661521172709804, 13.65750087436378, 12.711510684948212, 11.771211137025732, 10.860226487877721, 9.911248277319187, 8.98362130780998, 8.059445683547805, 8.983849869120416, 9.89252296729969, 10.712168962688553, 11.666453961015701, 12.613201555002055, 11.882105287719167, 11.005569217489933, 11.914107010409532, 12.842472476739351, 13.769802484416406, 14.637413779339457, 15.656412257161094, 15.625378190645534, 14.645435401079881, 13.676671172714466, 12.81734057122488, 11.79501489688666, 10.947939446357864, 10.05322353979583, 9.07998725614258, 10.044334865577504, 10.817893401111204, 11.658013627952027, 10.747417625287785, 11.721811410439557, 10.825971378807544, 9.949116330247818, 10.89109151684175, 11.819865729558797, 12.767814192003373, 13.706042143864515, 14.683947224114283, 15.632356684714258, 15.624418422642131, 14.630889968221215, 13.773681114720711, 12.765688356513039, 11.988716034116397, 11.035039985229735, 10.033530290944832, 11.06789467789741, 11.856639679090026, 12.62882153208523, 9.681102574654217, 10.685612976954651, 9.857485739373361, 8.97618002426757, 9.919464686489198, 10.869637836875674, 11.716471707080956, 12.71127086086477, 13.726684710628897, 14.608956354988514, 15.499237974586269, 15.65537602610308, 14.698899238063264, 13.754173343495397, 12.952103437535502, 11.990734149266496, 11.035203637290968, 12.011310767414075, 12.874140069672723, 13.554179514496422, 8.663797610274164, 9.63536162718929, 8.872327104672667, 8.04358141549558, 8.908734494124333, 9.912312677422838, 10.771203498658776, 11.715959165336047, 12.665194269351222, 13.605966276289466, 14.531343952304239, 15.454116234650822, 15.646213366616427, 14.687413319091252, 13.907683710564203, 12.915816206454647, 11.981962010283054, 12.956357111657132, 13.877437465314705, 14.50866356364461, 7.684241228187718, 8.722377718990462, 7.842053450795728, 6.972087780271283, 7.938999509133231, 8.972862834608437, 9.828221353045725, 10.690115667640761, 11.65486867945338, 12.695629891215457, 13.602068423302532, 14.482447491635856, 15.441392964429088, 15.738079958509426, 14.893196145787906, 13.952801204323093, 12.91318332127537, 13.88822876153456, 14.804083650838589, 15.56623513270513, 6.703974834310601, 7.650068234649361, 6.771160025264168, 6.013423831771208, 7.040917429422798, 7.975016315044751, 8.827121402378213, 9.725027146195814, 10.756727097200132, 11.74888157969696, 12.540208386875554, 13.502072358776793, 14.536434920210409, 15.457380023648911, 15.859669126191253, 14.885849436318708, 13.927471300689016, 14.902852259705393, 15.766515783461514, 16.596453404792033, 5.783638972211222, 6.748070947123438, 5.837853062863973, 5.040413762780968, 6.005810644450369, 6.921325333736881, 7.812636576390504, 8.728091027349777, 9.764415070832401, 10.698062811441602, 11.593664805162106, 12.584000163437576, 13.558344894879875, 14.437569187364204, 15.416275075673026, 15.844703968821044, 14.963077192898146, 15.900215821284839, 16.82987900877365, 17.634846749687267, 4.929727912955395, 5.901082355391216, 4.908051589459208, 4.023247418948606, 4.963460360309094, 5.868755471091974, 6.880660440285449, 7.738341035781024, 8.727069234020954, 9.640808262408905, 10.641850474033538, 11.65020732048098, 12.518265167742847, 13.482948982328686, 14.475067406971286, 15.420446485741062, 15.962363887139565, 16.89200019762087, 17.879956799506274, 17.835762705394604, 4.07188129598667, 4.890303266525654, 3.9567874112296777, 3.028255519071947, 3.962939270933849, 4.916711032446451, 5.8596642097212355, 6.798559516908934, 7.73560079015787, 8.67136737356584, 9.661781869962299, 10.644703626190843, 11.557602361837723, 12.543339229218045, 13.56311097863899, 14.542989727727024, 15.504169333787349, 16.467654874825055, 17.41667997011502, 16.802616265340763, 4.968492714520614, 3.9429127585883217, 2.9138216453405503, 1.967076039148911, 2.9454204487035733, 3.979155299680616, 4.851200700930257, 5.846468883999055, 6.886672205085837, 7.75960080288655, 8.715463799210747, 9.61464965517329, 10.62889939054358, 11.626379468631121, 12.579999078851323, 13.568998097776324, 14.584040834360179, 15.564348426869222, 16.57853736158343, 17.646255958623634], [17.735523155983994, 16.720139456617044, 15.729057078850873, 14.669511494066175, 13.72999411246834, 12.679535954464606, 11.698460656747253, 10.732459165075348, 9.713229674826746, 8.774514922175033, 7.845775447651085, 6.888343384891978, 5.928955494239493, 4.919098022676318, 3.986276654298761, 2.9945943618464277, 1.9431809071593404, 0.9804524237059098, 2.0069231239162777, 3.01368726587177, 16.88325301179812, 15.953196568611663, 14.980555989119324, 14.040210178857249, 13.057827967115362, 12.054856926383346, 11.007339506098422, 9.965918447339876, 8.951080934925114, 7.946247138485795, 6.9460993792160926, 5.953459916465426, 5.0052655685191105, 4.000210569064682, 3.0495644344315913, 2.0708382215147547, 1.0309017533435165, 0.0, 0.9793034176706154, 1.9950379251402621, 17.886822793278284, 16.886228162082933, 15.971488928214868, 14.971097518236883, 13.973705578306198, 13.002506643781441, 11.95659910612541, 10.912487961805256, 9.973258320480815, 8.99491892534482, 7.937028630599889, 6.899839808496241, 5.934562038310192, 4.965294396931835, 4.023994052219466, 3.0654082003732013, 2.0019513001073426, 0.9440577766863222, 1.883570233868489, 2.905063453961901, 17.557530679435725, 17.84045783106866, 16.799110412854123, 15.746708408412532, 14.817557203692909, 13.847622062011489, 12.891232114648018, 11.861598542623701, 10.877790571940807, 9.891662270603877, 8.934281199222498, 7.906640406107126, 6.883369939622883, 5.907630434692432, 4.957588140933121, 3.986927135072807, 2.9342421489227846, 1.9200091424532917, 2.812054316944792, 3.7520201773728488, 16.512239078347562, 17.317068552813645, 16.927964344237083, 16.615190524358173, 15.684495390658828, 14.75731282833255, 13.827634938759031, 12.78879565393982, 11.834940025810859, 10.86147048328511, 9.796769072670939, 8.793485879182285, 7.826969146957475, 6.889844566094773, 5.895251299741222, 4.931414440464996, 3.899620563278443, 2.8517527075884685, 3.854428691927894, 4.70329359691542, 15.450129346699235, 16.309890276495857, 15.934914233096745, 16.885042827836898, 16.66204282223267, 15.757157019246904, 14.789350289137259, 13.834274666074233, 12.773108480792674, 11.742432168403699, 10.73855716496378, 9.803387161202814, 8.792012939010498, 7.891058118481005, 6.915655458454262, 5.981238915825756, 4.941023016122717, 3.8877671464347014, 4.855558315480657, 5.760850333548349, 14.405937203220496, 15.3458940628293, 14.917595498580527, 15.876755220638076, 16.647959272149027, 16.724403344238503, 15.766138944966583, 14.722423130818166, 13.752816809017986, 12.72860563689046, 11.715172657338288, 10.748775775257354, 9.736975052994298, 8.825544337521515, 7.89423581733706, 6.907230259109932, 5.883568508953067, 4.940742168578211, 5.896845939914629, 6.730563623274396, 13.475308571240136, 14.539773834656234, 13.89214340378725, 14.86779526751587, 15.614733109113443, 16.55446937052424, 16.69184597021923, 15.664044688211682, 14.705760619775612, 13.706340062142656, 12.696589898340836, 11.720393142123216, 10.72223841783837, 9.851783866674626, 8.81748489527258, 7.797701711575404, 6.850281792256536, 5.979542093616663, 6.846461849561864, 7.71921654205941, 12.59769315725244, 13.585687286902054, 12.924080606908793, 13.878366418603237, 14.688909450697516, 15.67116305878924, 16.63737063106893, 16.624261983667612, 15.643993316099927, 14.620644887402667, 13.602731070568543, 12.56377006733099, 11.584196921689069, 10.657696143166634, 9.702955488157054, 8.77550560210347, 7.8751950660588985, 7.046382906989015, 7.909066680415639, 8.68725726985812, 11.645475476028853, 12.527107971530707, 11.976618115117908, 12.831623880052577, 13.743937899813673, 14.696995447337109, 15.633284571146678, 16.586637120092828, 16.50897873104795, 15.579140895826741, 14.513431351103769, 13.567441161688201, 12.62714161376572, 11.650465852430987, 10.70148764187245, 9.773860672363243, 8.849685048101069, 7.979680808531741, 8.861621213956173, 9.681267209345036, 10.635552207672184, 11.582299801658538, 10.939781452249257, 11.792222407777011, 12.70076020069661, 13.629125667026429, 14.628475566867376, 15.53045600322151, 16.549454481043146, 16.481308667385523, 15.50136587781987, 14.532601649454454, 13.648990373897783, 12.585254261439925, 11.738178810911128, 10.843462904349094, 9.870226620695842, 9.040165804988828, 9.786991647767687, 10.62711187460851, 9.716515871944267, 10.690909657096043, 9.883647543337634, 10.735769520534896, 11.677744707128827, 12.61088789579946, 13.626487274454343, 14.599084367746567, 15.576989447996334, 16.622257954990836, 16.480348899382122, 15.486820444961204, 14.563920479273976, 13.555927721066304, 12.77895539866966, 11.825279349782997, 10.823769655498094, 10.096706716313687, 10.825737925746509, 11.597919778741712, 8.6502008213107, 9.654711223611137, 8.915161903903451, 9.762833214554648, 10.706117876776275, 11.660660003116336, 12.609513930963008, 13.604313084746822, 14.619726934510949, 15.59885762526509, 16.489139244862844, 16.453097870415473, 15.48913860261653, 14.544412708048663, 13.742342802088766, 12.780973513819758, 11.82544300184423, 11.1096744184449, 11.843238316329206, 12.523277761152904, 7.632895856930648, 8.604459873845775, 7.930003269202756, 8.830234605782659, 9.695387684411411, 10.7033348436635, 11.664245722540828, 12.705860435612623, 13.655095539627798, 14.595867546566042, 15.521245222580815, 16.444017504927398, 16.43645273116969, 15.477652683644518, 14.697923075117467, 13.706055571007909, 12.772201374836316, 12.054720762687957, 12.846535711971187, 13.477761810301093, 6.653339474844201, 7.691475965646944, 6.899729615325816, 7.75874097055836, 8.725652699420309, 9.763885000849099, 10.721263576927777, 11.680016937917337, 12.644769949729955, 13.685531161492033, 14.591969693579108, 15.472348761912432, 16.431294234705664, 16.52831932306269, 15.68343551034117, 14.743040568876355, 13.703422685828633, 12.986592412565384, 13.773181897495071, 14.535333379361612, 5.673073080967084, 6.619166481305845, 5.828836189794256, 6.800077022058285, 7.827570619709874, 8.79741648786032, 9.778189489162433, 10.71492841647239, 11.746628367476706, 12.738782849973536, 13.53010965715213, 14.49197362905337, 15.526336190486985, 16.488281776992423, 16.649908490744515, 15.67608880087197, 14.717710665242278, 14.001215910736217, 14.735614030117997, 15.565551651448516, 4.752737218867704, 5.71716919377992, 4.895529227394061, 5.850872145004815, 6.844860762639682, 7.910697130813746, 8.80253784666708, 9.71799229762635, 10.754316341108975, 11.687964081718178, 12.583566075438682, 13.573901433714152, 14.548246165156451, 15.468470940707718, 16.44717682901654, 16.634943333374306, 15.753316557451408, 14.998579472315665, 15.798977255430131, 16.60394499634375, 3.898826159611878, 4.942612596322872, 3.965727753989296, 4.977380068354552, 5.9355154711322005, 6.8586567413685495, 7.870561710562025, 8.728242306057599, 9.71697050429753, 10.630709532685481, 11.631751744310113, 12.64162241196739, 13.54916692108636, 14.5138507356722, 15.5059691603148, 16.451348239084574, 16.752603251692825, 16.010530612507118, 16.849055046162757, 17.61750415727973, 3.0409795426431536, 3.947979431055743, 3.0144635757597658, 4.011388650508896, 4.952840541210425, 5.906612302723027, 6.849565479997811, 7.78846078718551, 8.725502060434446, 9.661268643842416, 10.692683623305815, 11.675605379534359, 12.588504115181237, 13.574240982561559, 14.594012731982504, 15.573891481070538, 16.535071087130863, 16.995683487056283, 17.865417679351904, 17.83351801868428, 3.9523212315172875, 3.0005889231184097, 1.9714978098706384, 2.95020917058586, 3.9353217189801493, 4.969056569957192, 5.86695470066421, 6.862222883733008, 7.9175739584293545, 8.790502556230066, 9.746365552554263, 10.645551408516805, 11.659801143887094, 12.657281221974635, 13.610900832194837, 14.599899851119838, 15.614942587703693, 16.595250180212734, 17.60943911492694, 18.677157711967144], [18.71482657365461, 17.69944287428766, 16.70836049652149, 15.648814911736789, 14.709297530138954, 13.65883937213522, 12.677764074417867, 11.711762582745962, 10.69253309249736, 9.753818339845648, 8.8250788653217, 7.867646802562593, 6.908258911910108, 5.898401440346933, 4.965580071969376, 3.973897779517043, 2.9224843248299557, 1.9597558413765253, 1.0276197062456625, 2.0343838482011547, 17.862556429468736, 16.932499986282277, 15.959859406789938, 15.019513596527863, 14.037131384785976, 13.03416034405396, 11.986642923769036, 10.94522186501049, 9.930384352595729, 8.92555055615641, 7.925402796886708, 6.932763334136041, 5.984568986189726, 4.979513986735297, 4.0288678521022065, 3.05014163918537, 2.0102051710141318, 0.9793034176706154, 0.0, 1.0157345074696469, 17.644775047282753, 17.865531579753547, 16.950792345885482, 15.950400935907497, 14.953008995976813, 13.981810061452055, 12.935902523796024, 11.89179137947587, 10.952561738151429, 9.974222343015434, 8.916332048270505, 7.879143226166856, 6.913865455980807, 5.94459781460245, 5.003297469890081, 4.0251496354544365, 2.961692735188578, 1.8980079502571239, 0.9584954930749571, 1.9750022928767272, 16.63245593864219, 17.384439826668522, 17.775521720827943, 16.723119716386353, 15.793968511666732, 14.824033369985312, 13.86764342262184, 12.838009850597524, 11.85420187991463, 10.8680735785777, 9.910692507196323, 8.88305171408095, 7.859781247596708, 6.884041742666258, 5.911538314503922, 4.940877308643608, 3.8881923224935857, 2.8739593160240933, 1.8869795761512602, 2.826945436579317, 15.58716433755403, 16.391993812020115, 17.369832891105922, 17.57274997864874, 16.642054844949396, 15.714872282623116, 14.785194393049597, 13.746355108230386, 12.792499480101425, 11.819029937575676, 10.754328526961505, 9.75104533347285, 8.78452860124804, 7.843794739665574, 6.849201473312023, 5.885364614035797, 4.853570736849244, 3.80570288115927, 2.9293539511343623, 3.778218856121888, 14.525054605905703, 15.384815535702327, 16.409332071270683, 17.411849792209118, 17.61960227652324, 16.714716473537468, 15.746909743427825, 14.791834120364799, 13.73066793508324, 12.699991622694265, 11.696116619254346, 10.76094661549338, 9.749572393301063, 8.845008292051805, 7.869605632025063, 6.935189089396557, 5.894973189693518, 4.841717320005503, 3.930483574687125, 4.835775592754818, 13.480862462426964, 14.420819322035769, 15.392013336754463, 16.41055496582968, 17.373548329585024, 17.681962798529067, 16.72369839925715, 15.67998258510873, 14.71037626330855, 13.686165091181026, 12.672732111628854, 11.70633522954792, 10.694534507284864, 9.779494511092317, 8.848185990907862, 7.861180432680733, 6.837518682523868, 5.894692342149012, 4.971771199121097, 5.805488882480864, 12.550233830446604, 13.614699093862702, 14.518180421060155, 15.5063974003203, 16.39845034608315, 17.338186607493945, 17.649405424509794, 16.621604142502246, 15.663320074066176, 14.663899516433222, 13.654149352631402, 12.677952596413782, 11.679797872128935, 10.805734040245428, 9.77143506884338, 8.751651885146204, 7.804231965827337, 6.876632933813954, 5.921387108768332, 6.794141801265878, 11.672618416458908, 12.660612546108522, 13.550117624181699, 14.516968551407667, 15.472626687667221, 16.454880295758944, 17.461246849096746, 17.57821215723841, 16.597943489670726, 15.574595060973467, 14.556681244139343, 13.51772024090179, 12.538147095259868, 11.611646316737433, 10.656905661727853, 9.72945577567427, 8.8291452396297, 7.943473747186306, 6.983991939622107, 7.762182529064589, 10.720400735235321, 11.602033230737176, 12.602655132390813, 13.596731326114298, 14.539600656786558, 15.520871665364925, 16.457160789174495, 17.451158465040876, 17.462928904618753, 16.533091069397543, 15.467381524674568, 14.521391335259, 13.58109178733652, 12.604416026001786, 11.65543781544325, 10.727810845934043, 9.80363522167187, 8.876771648729033, 7.936546473162642, 8.756192468551504, 9.710477466878652, 10.657225060865006, 11.678327624013093, 12.656743752725058, 13.565281545644657, 14.493647011974476, 15.492996911815423, 16.394977348169558, 17.413975825991194, 17.435258840956323, 16.455316051390668, 15.486551823025254, 14.602940547468583, 13.539204435010724, 12.692128984481927, 11.797413077919893, 10.824176794266645, 9.879586918016562, 8.861916906974157, 9.702037133814978, 8.791441131150734, 9.76583491630251, 10.706015916352644, 11.600290865482943, 12.542266052076874, 13.475409240747506, 14.49100861940239, 15.463605712694614, 16.44151079294438, 17.499049774380467, 17.43429907295292, 16.440770618532003, 15.517870652844776, 14.509877894637103, 13.73290557224046, 12.7792295233538, 11.777719829068896, 10.91996008107082, 9.900663184952979, 10.67284503794818, 7.725126080517167, 8.729636482817604, 9.737530276918461, 10.627354559502695, 11.570639221724322, 12.525181348064383, 13.474035275911055, 14.46883442969487, 15.484248279458996, 16.47564944465472, 17.40845132231496, 17.407048043986272, 16.443088776187327, 15.498362881619462, 14.696292975659565, 13.73492368739056, 12.779393175415033, 11.85258183036877, 10.918163575535676, 11.598203020359373, 6.707821116137116, 7.679385133052242, 8.752371642217767, 9.694755950730706, 10.559909029359458, 11.567856188611547, 12.528767067488875, 13.582652255002252, 14.531887359017427, 15.472659365955671, 16.50054864025143, 17.423320922598013, 17.39040290474049, 16.431602857215317, 15.651873248688267, 14.660005744578712, 13.726151548407119, 12.797628174611827, 11.921460971177657, 12.552687069507561, 5.728264734050669, 6.766401224853412, 7.764250960273863, 8.623262315506407, 9.590174044368355, 10.628406345797146, 11.585784921875824, 12.556808757306966, 13.521561769119584, 14.562322980881662, 15.571273111249722, 16.451652179583046, 17.41059765237628, 17.48226949663349, 16.63738568391197, 15.696990742447158, 14.657372859399436, 13.729499824489254, 12.848107156701541, 13.61025863856808, 4.747998340173552, 5.694091740512313, 6.693357534742303, 7.664598367006332, 8.692091964657921, 9.661937832808366, 10.64271083411048, 11.591720235862018, 12.659682135374329, 13.66894816803348, 14.509413074822744, 15.471277046723984, 16.5056396081576, 17.467585194663037, 17.603858664315318, 16.630038974442773, 15.67166083881308, 14.744123322660087, 13.810539289324467, 14.640476910654982, 3.827662478074173, 4.7920944529863885, 5.7600505723421085, 6.715393489952863, 7.70938210758773, 8.775218475761793, 9.778467359814387, 10.697295715296965, 11.73361975877959, 12.667267499388792, 13.562869493109297, 14.553204851384766, 15.527549582827065, 16.447774358378332, 17.426480246687152, 17.58889350694511, 16.707266731022212, 15.741486884239535, 14.873902514636601, 15.678870255550216, 2.968764998526704, 3.9819693710440283, 4.85960777365224, 5.871260088017497, 6.829395490795145, 7.837960159039165, 8.84986512823264, 9.707545723728213, 10.696273921968144, 11.610012950356095, 12.611055161980728, 13.620925829638004, 14.528470338756975, 15.493154153342815, 16.485272577985413, 17.430651656755188, 17.683074334912295, 16.753438024430988, 15.923980305369225, 16.692429416486195, 2.0616761249725384, 2.9711902821784673, 3.9083435954227093, 4.9151633855228765, 5.93214395888104, 6.885915720393642, 7.828868897668427, 8.767764204856125, 9.70480547810506, 10.64057206151303, 11.671987040976429, 12.654908797204973, 13.567807532851852, 14.553544400232173, 15.573316149653119, 16.55319489874115, 17.514374504801474, 17.738590898980153, 16.94034293855837, 17.725575856540036, 2.9730178138466723, 2.023799774241134, 2.950801227541254, 3.9295125882564754, 4.9146251366507645, 5.948359987627807, 6.846258118334825, 7.841526301403623, 8.896877376099969, 9.76980597390068, 10.725668970224877, 11.62485482618742, 12.639104561557708, 13.63658463964525, 14.590204249865451, 15.579203268790453, 16.59424600537431, 17.57455359788335, 17.912180973305986, 18.677261504076885], [18.75665816697291, 18.715177381757307, 17.72409500399114, 16.664549419206438, 15.725032037608603, 14.67457387960487, 13.693498581887516, 12.72749709021561, 11.708267599967007, 10.769552847315294, 9.840813372791347, 8.88338131003224, 7.923993419379755, 6.91413594781658, 5.981314579439023, 4.98963228698669, 3.9382188322996026, 2.975490348846172, 2.0433542137153093, 1.0186493407315076, 17.75419483982563, 17.948234493751922, 16.975593914259584, 16.03524810399751, 15.052865892255623, 14.049894851523607, 13.002377431238683, 11.960956372480137, 10.946118860065376, 9.941285063626056, 8.941137304356355, 7.948497841605687, 7.000303493659372, 5.995248494204943, 5.0446023595718525, 4.065876146655016, 3.0259396784837786, 1.9950379251402621, 1.0157345074696469, 0.0, 16.747841177330475, 17.445260307610432, 17.966526853355127, 16.966135443377144, 15.96874350344646, 14.997544568921702, 13.95163703126567, 12.907525886945518, 11.968296245621076, 10.98995685048508, 9.93206655574015, 8.894877733636502, 7.929599963450453, 6.960332322072096, 6.019031977359727, 5.040884142924083, 3.9774272426582247, 2.9137424577267708, 1.9742300005446038, 0.9592677854070804, 15.735522068689912, 16.487505956716245, 17.450671810519992, 17.738854223856002, 16.80970301913638, 15.83976787745496, 14.88337793009149, 13.853744358067173, 12.869936387384278, 11.883808086047349, 10.926427014665972, 9.8987862215506, 8.875515755066356, 7.899776250135905, 6.927272821973569, 5.956611816113255, 4.903926829963233, 3.88969382349374, 2.8699774270550935, 1.9300115666270368, 14.69023046760175, 15.495059942067835, 16.472899021153644, 17.464397699258612, 17.657789352419044, 16.730606790092764, 15.800928900519244, 14.762089615700033, 13.808233987571072, 12.834764445045323, 11.770063034431152, 10.766779840942498, 9.800263108717687, 8.859529247135221, 7.86493598078167, 6.901099121505444, 5.869305244318891, 4.821437388628917, 3.826725234699647, 2.8812849861696073, 13.628120735953424, 14.487881665750047, 15.512398201318401, 16.514915922256833, 17.44255393542085, 17.730450981007117, 16.762644250897473, 15.807568627834446, 14.746402442552887, 13.715726130163912, 12.711851126723992, 11.776681122963026, 10.76530690077071, 9.860742799521454, 8.88534013949471, 7.947924240679077, 6.889076438857978, 5.824202199546459, 4.82785485825241, 3.938841722802537, 12.583928592474685, 13.523885452083489, 14.495079466802183, 15.513621095877399, 16.476614459632742, 17.482989996870895, 17.739432906726798, 16.69571709257838, 15.726110770778199, 14.701899598650673, 13.6884666190985, 12.722069737017566, 11.71026901475451, 10.792789775117198, 9.861481254932743, 8.808778429505058, 7.785116679348192, 6.842290338973336, 5.837620841053115, 4.908555012528583, 11.653299960494325, 12.717765223910423, 13.621246551107875, 14.60946353036802, 15.501516476130869, 16.441252737541667, 17.480725188670412, 17.637338649971895, 16.679054581535823, 15.679621432022435, 14.669871268220614, 13.693674512002994, 12.695519787718148, 11.757315152943034, 10.693971269317291, 9.674188085620116, 8.726768166301248, 7.7424825757459725, 6.787236750700351, 5.897207931313598, 10.775684546506628, 11.763678676156243, 12.653183754229419, 13.620034681455387, 14.575692817714941, 15.557946425806666, 16.564312979144464, 17.499836883979896, 17.520479690144636, 16.49713126144738, 15.479217444613255, 14.440256441375702, 13.46068329573378, 12.534182517211345, 11.579441862201765, 10.651991976148182, 9.75168144010361, 8.809323389118324, 7.849841581554125, 6.865248659112308, 9.823466865283041, 10.705099360784896, 11.705721262438534, 12.699797456162019, 13.642666786834278, 14.623937795412646, 15.560226919222215, 16.554224595088595, 17.543451036519954, 17.455627269871457, 16.389917725148482, 15.443927535732913, 14.503627987810432, 13.526952226475698, 12.577974015917162, 11.650347046407955, 10.723382964816393, 9.74262129066105, 8.80239611509466, 7.859258598599224, 8.813543596926372, 9.760291190912726, 10.781393754060813, 11.759809882772778, 12.668347675692377, 13.596713142022196, 14.596063041863143, 15.498043478217276, 16.517041956038913, 17.561766084945713, 17.37785225186458, 16.409088023499166, 15.525476747942495, 14.461740635484636, 13.61466518495584, 12.719949278393806, 11.743924537411168, 10.74543655994858, 9.727766548906175, 8.805103263862698, 7.894507261198453, 8.86890104635023, 9.809082046400365, 10.703356995530664, 11.645332182124594, 12.578475370795227, 13.59407474945011, 14.566671842742334, 15.544576922992102, 16.60211590442818, 17.528209736750938, 17.363306819005913, 16.440406853318688, 15.432414095111016, 14.653602033133675, 13.698977266498323, 12.69746757221342, 11.78580972300284, 10.766512826884998, 9.7759111679959, 6.828192210564886, 7.832702612865323, 8.840596406966181, 9.730420689550416, 10.673705351772043, 11.628247478112103, 12.577101405958775, 13.57190055974259, 14.587314409506716, 15.57871557470244, 16.51151745236268, 17.50540595651935, 17.36562497666124, 16.420899082093374, 15.616919105595274, 14.654671430535084, 13.60964086925274, 12.633533739129632, 11.699115484296538, 10.701269150407093, 5.810887246184835, 6.782451263099961, 7.8554377722654865, 8.797822080778426, 9.662975159407178, 10.670922318659267, 11.631833197536595, 12.685718385049972, 13.634953489065147, 14.575725496003392, 15.626127337293916, 16.553972286711556, 17.565619163789506, 17.354139057689228, 16.572499378623977, 15.549418286072871, 14.556399242244826, 13.578580083372689, 12.680230239003498, 11.655753199555281, 4.831330864098389, 5.869467354901133, 6.867317090321583, 7.7263284455541275, 8.693240174416076, 9.731472475844866, 10.688851051923544, 11.659874887354686, 12.624627899167304, 13.665389110929382, 14.73729183637727, 15.636169312106134, 16.595114784899366, 17.55216005923794, 17.484936096891502, 16.527238436284865, 15.487620553237143, 14.510451733250116, 13.606876424527382, 12.7133247686158, 3.8510644702212717, 4.797157870560032, 5.796423664790023, 6.767664497054052, 7.795158094705641, 8.765003962856087, 9.7457769641582, 10.694786365909739, 11.762748265422049, 12.7720142980812, 13.693930207345831, 14.65579417924707, 15.690156740680687, 16.674746902101415, 17.696157594629312, 17.460286668280478, 16.501908532650788, 15.52507523142095, 14.569308557150308, 13.743543040702704, 2.9307286081218926, 3.8951605830341087, 4.863116702389829, 5.818459620000583, 6.81244823763545, 7.878284605809514, 8.881533489862107, 9.881812847820052, 10.918136891302677, 11.85178463191188, 12.747386625632384, 13.737721983907853, 14.712066715350153, 15.704855815109735, 16.683561703418555, 17.710591702555973, 17.513764040640282, 16.522438793000397, 15.632671782462442, 14.781936385597938, 1.9530304910570573, 2.996816927768052, 3.9573502684643227, 4.96900258282958, 5.927137985607228, 6.986737628735178, 8.034382260755725, 8.8920628562513, 9.880791054491231, 10.794530082879183, 11.795572294503815, 12.805442962161091, 13.785551795488377, 14.750235610074217, 15.742354034716817, 16.687733113486594, 17.617126711808922, 17.53438993319185, 16.682749573195068, 15.79549554653392, 1.0459416175028915, 2.0689327769905503, 3.0060860902347923, 4.0129058803349595, 5.067583035752682, 6.070432852916728, 7.013386030191512, 7.952281337379211, 8.889322610628147, 9.825089194036117, 10.898107119064408, 11.881028875292952, 12.868637692573236, 13.854374559953557, 14.912665031767274, 15.932089853239836, 16.89326945930016, 17.856755000337866, 17.699112206384214, 16.828641986587762, 1.957283306377025, 2.9828632623093174, 3.966535735010901, 4.945247095726122, 5.930359644120411, 6.964094495097454, 7.861992625804472, 8.85726080887327, 9.816901585231392, 10.781900312578955, 11.737763308903151, 12.640589333657067, 13.654839069027357, 14.652319147114898, 15.6059387573351, 16.594937776260103, 17.609980512843958, 18.590288105353, 18.67095024113183, 17.78032763412461], [2.0088169896424386, 2.8781820342165356, 3.869264411982706, 4.814282657969504, 5.753800039567339, 6.772165193148867, 7.7532404908662205, 8.719241982538126, 9.738471472786728, 10.67718622543844, 11.605925699962388, 12.563357762721495, 13.636302238875047, 14.646159710438223, 15.57898107881578, 16.57066337126811, 17.622076825955197, 18.58480530940863, 18.672394753528412, 17.76649051806198, 1.0063536624951561, 1.9336262246666216, 2.9062668041589594, 3.8466126144210335, 4.828994826162922, 5.831965866894938, 6.879483287179863, 7.920904345938409, 8.93574185835317, 9.94057565479249, 10.940723414062191, 11.933362876812858, 12.881557224759174, 13.886612224213604, 14.837258358846695, 15.815984571763531, 16.85592103993477, 17.886822793278288, 17.64477504728275, 16.74784117733047, 0.0, 1.0005946311953513, 2.0425766383491197, 3.0429680483271033, 4.040359988257788, 5.0115589227825454, 6.057466460438577, 7.10157760475873, 8.06039584131862, 9.101083393516362, 10.169153498336536, 11.206342320440184, 12.23811150053064, 13.207379141908996, 14.148679486621365, 15.19650546393602, 16.25996236420188, 17.323647149133333, 16.686279554207793, 15.788573391923391, 1.0123191086405616, 1.9583489820895381, 2.979788002282333, 4.032190006723923, 4.961341211443546, 5.931276353124966, 6.887666300488437, 7.917299872512753, 8.901107843195646, 9.887236144532576, 10.844617215913953, 11.872258009029325, 12.895528475513569, 13.871267980444019, 14.843771408606354, 15.814432414466667, 16.86711740061669, 16.773744963035853, 15.757795471131491, 14.817829610703434, 2.0576107097287233, 2.950794996737946, 3.928634075823754, 4.992153513310106, 5.9228486470094515, 6.8500312093357305, 7.779709098909249, 8.81854838372846, 9.772404011857422, 10.74587355438317, 11.810574964997341, 12.80780496887764, 13.774321701102451, 14.715055562684917, 15.709648829038468, 16.673485688314695, 16.83182845647862, 15.842001397900674, 14.810769241313157, 13.866556191160864, 3.1197204413770496, 3.9579732730557335, 4.921684186964093, 5.9242019079025265, 6.900396078583295, 7.863377112499046, 8.741424449287477, 9.773814995648786, 10.710572466839237, 11.713143286004312, 12.717018289444232, 13.66121336837605, 14.672587590568366, 15.657185126806855, 16.63354523811634, 16.80395539140831, 15.790426003634343, 14.805986959054442, 13.809639617760393, 12.808999454527935, 4.1639125848557885, 4.921969486722291, 5.893163501440986, 6.911705130516202, 7.866335554371405, 8.830623437490646, 9.718213105116801, 10.769494243671238, 11.739100565471418, 12.699316754491074, 13.713094519786264, 14.60660198243059, 15.617549704552166, 16.641841251094476, 16.58106748776028, 15.7334432177635, 14.715847831621497, 13.773021491246642, 12.768351993326421, 11.839286164801889, 5.094541216836149, 5.919049665119498, 6.882382373423129, 7.920665083638407, 8.89956171740699, 9.839297978817788, 10.78013293994881, 11.72630719653813, 12.6845912649742, 13.693953043354629, 14.70370320715645, 15.587909988619089, 16.586064712903934, 16.44491625625358, 15.607498821792442, 14.663360841842454, 13.7764564137025, 12.81542503712779, 11.86017921208217, 10.850633246016875, 6.026959829228545, 6.8731362128736775, 7.850445170301585, 8.817296097527553, 9.772954233787107, 10.755207841878832, 11.760133063541236, 12.695656968376666, 13.67592563594435, 14.685348122378004, 15.703261939212128, 16.614034852961012, 16.40713377640951, 15.480632997887072, 14.613006837367973, 13.685556951314389, 12.751543139900138, 11.867263815036122, 10.822073372574158, 9.882592518218164, 7.080701765062876, 7.931715528245025, 8.79790766209247, 9.791983855815955, 10.71792578467095, 11.699196793249317, 12.635485917058887, 13.650198495223426, 14.622310176414592, 15.5521480116358, 16.61785755635877, 16.407627440994382, 15.510984067536453, 14.48786328862272, 13.702924723311732, 12.78697827091313, 11.777053157857967, 10.937183794890785, 9.869518839033622, 8.88858257873125, 8.090625033419546, 8.876523698117195, 9.834744324961122, 10.831385328091521, 11.761103483788013, 12.689468950117831, 13.668255684416675, 14.627540198175932, 15.646538675997569, 16.55372610974626, 16.482198671667145, 15.442466953228127, 14.464854633337305, 13.553074879613781, 12.666233554273054, 11.747288705381115, 10.756511585263194, 9.894696687447771, 8.944148405222109, 7.9427379134677745, 9.02212264369734, 9.88637625168689, 10.880104277259623, 11.887838215333636, 12.784118977355796, 13.743354855150244, 14.670243976829708, 15.558911833650875, 16.630079684776717, 16.39637471165952, 15.456864788661793, 14.488248157721378, 13.45685594755152, 12.582401419987402, 11.625456966514522, 10.731884460782098, 9.802968550460943, 8.838155776122912, 7.9462660293299745, 6.971930009334573, 10.088437694330906, 10.922574685171796, 11.848589916693806, 12.782701681116183, 13.755745807708347, 14.693582747833368, 15.663716935301798, 16.553683116650618, 16.388752536266153, 15.372974381933773, 14.440172504273534, 13.49559709200791, 12.531637824208968, 11.593916433005043, 10.662069563095416, 9.776190296745337, 8.801295204114806, 7.8251880739917, 6.928765638747278, 6.04657202692338, 11.140810375571794, 11.972826034937157, 12.8337485513945, 13.715300289888173, 14.720144123043461, 15.650907907286204, 16.608985143723977, 16.412687434235448, 15.463452330220273, 14.522680323282028, 13.472278481991504, 12.544433532573864, 11.584323695655804, 10.660676457409188, 9.706489290066715, 8.851108239557187, 7.906329514291574, 6.880141729748643, 5.925468243105296, 5.123596921818752, 12.12036675765824, 12.960438773737486, 13.86402220527144, 14.786793925112471, 15.689879108034564, 16.590357750100605, 16.667158131008136, 15.636948132747131, 14.672195120934513, 13.691109962743823, 12.619207237295935, 11.572764789558898, 10.613819316765666, 9.656774042427088, 8.720976854843013, 7.797664700117817, 6.975108203299258, 5.948270079871216, 4.998822057581412, 4.066025352758232, 13.100633151535357, 14.032748258078586, 14.934915630803, 15.745457873612546, 16.70648823262698, 16.66431680490065, 15.683543803598539, 14.734534401847, 13.696485088583483, 12.68721905592433, 11.63605511565055, 10.67419114374931, 9.751839941910719, 8.76724978048999, 7.754503874439666, 6.864616468122202, 5.960820223885614, 5.005606028724659, 4.048549624751256, 3.090066513729778, 14.041433693838261, 15.005865668750477, 15.868222593203194, 16.718467942602786, 16.75844968097382, 15.692613312799754, 14.68936442874716, 13.737598283000962, 12.739224839033998, 11.762054790074988, 10.697010949468147, 9.706675591192678, 8.787082525423891, 7.747438944205284, 6.741907983228907, 5.905761935619866, 4.925214331676483, 4.008242467145212, 3.057323883359376, 2.0516731688345455, 15.114005702852376, 16.057084856383916, 16.798024066607958, 16.83667585880579, 15.87854045602814, 14.81894081290019, 13.757388292642105, 12.74784829143221, 11.67667544884383, 10.7485242663648, 9.747482054740168, 8.737611387082891, 7.7575025537556055, 6.792818739169766, 5.800700314527167, 4.855321235757391, 3.925927637435064, 2.9962913269537585, 2.0072460926267515, 1.0725716640608862, 16.09128039902998, 17.067863945249478, 17.749288244837487, 17.530148468909022, 16.4754713134913, 15.472621496327253, 14.529668319052469, 13.590773011864771, 12.653731738615836, 11.717965155207866, 10.688695933169557, 9.705774176941013, 8.718165359660729, 7.818834029318805, 6.80284552085455, 5.783420699381988, 4.822241093321664, 3.8587555522839594, 2.9097304569939935, 1.9566186693813146, 17.027321483123046, 18.01525445318681, 18.792254010726616, 18.518720318471512, 17.443912080070135, 16.41017722909309, 15.588898001399183, 14.554854595531774, 13.529257917393105, 12.550652808541368, 11.635014003921109, 10.670793206476787, 9.646583961349872, 8.670863464249049, 7.7172438540288475, 6.757412329332687, 5.854635658373713, 4.892015492848533, 3.88156849174161, 2.908304316918165], [2.8655513638050127, 1.8775874030211843, 2.8686697807873545, 3.8136880267741535, 4.753205408371988, 5.771570561953515, 6.752645859670869, 7.718647351342774, 8.737876841591376, 9.676591594243089, 10.605331068767036, 11.562763131526143, 12.635707607679695, 13.645565079242871, 14.578386447620428, 15.570068740072761, 16.62148219475985, 17.58421067821328, 18.08800296958323, 18.463909648341932, 1.8630880366577305, 0.9330315934712703, 1.9056721729636084, 2.846017983225683, 3.8284001949675712, 4.831371235699587, 5.878888655984511, 6.920309714743057, 7.9351472271578185, 8.939981023597138, 9.94012878286684, 10.932768245617506, 11.880962593563822, 12.886017593018252, 13.836663727651343, 14.81538994056818, 15.855326408739417, 16.886228162082933, 17.865531579753547, 17.445260307610425, 1.0005946311953513, 0.0, 1.0419820071537682, 2.042373417131752, 3.0397653570624366, 4.010964291587194, 5.056871829243225, 6.1009829735633785, 7.059801210123268, 8.10048876232101, 9.168558867141185, 10.205747689244832, 11.237516869335288, 12.206784510713645, 13.148084855426013, 14.195910832740669, 15.259367733006528, 16.32305251793798, 17.26256497512015, 16.485992522203347, 2.003510231989284, 0.9577543508941868, 1.9791933710869816, 3.0315953755285716, 3.9607465802481947, 4.930681721929615, 5.887071669293086, 6.916705241317401, 7.900513212000296, 8.886641513337226, 9.844022584718605, 10.871663377833977, 11.89493384431822, 12.870673349248671, 13.843176777411006, 14.81383778327132, 15.86652276942134, 16.880755775890833, 16.45521460141145, 15.51524874098339, 2.9993990928778658, 1.950200365542595, 2.928039444628403, 3.991558882114755, 4.922254015814101, 5.84943657814038, 6.779114467713899, 7.817953752533109, 8.77180938066207, 9.745278923187819, 10.80998033380199, 11.807210337682292, 12.773727069907103, 13.714460931489569, 14.70905419784312, 15.672891057119346, 16.7046849343059, 16.53942052818063, 15.508188371593112, 14.56397532144082, 3.975453672780059, 2.9573786418603825, 3.921089555768742, 4.923607276707175, 5.8998014473879445, 6.862782481303695, 7.740829818092127, 8.773220364453437, 9.709977835643885, 10.71254865480896, 11.71642365824888, 12.660618737180698, 13.671992959373014, 14.656590495611503, 15.632950606920987, 16.576108653195877, 16.4878451339143, 15.503406089334398, 14.507058748040349, 13.506418584807891, 4.861331715135744, 3.92137485552694, 4.892568870245635, 5.911110499320852, 6.8657409231760544, 7.830028806295294, 8.717618473921451, 9.768899612475888, 10.738505934276068, 11.698722123295722, 12.712499888590912, 13.606007351235238, 14.616955073356815, 15.641246619899125, 16.57255514008358, 16.436928712058318, 15.413266961901453, 14.470440621526597, 13.465771123606377, 12.536705295081845, 5.791960347116104, 4.918455033924149, 5.881787742227779, 6.920070452443057, 7.8989670862116395, 8.838703347622438, 9.77953830875346, 10.72571256534278, 11.68399663377885, 12.693358412159277, 13.703108575961098, 14.587315357423737, 15.585470081708584, 16.523674716483697, 16.386234893280438, 15.44209691333045, 14.497129757963023, 13.512844167407748, 12.557598342362127, 11.54805237629683, 6.724378959508501, 5.872541581678328, 6.849850539106235, 7.816701466332203, 8.772359602591758, 9.754613210683482, 10.759538432345886, 11.695062337181316, 12.675331004749001, 13.684753491182652, 14.702667308016776, 15.613440221765659, 16.59301336740758, 16.34648356386555, 15.391742908855969, 14.464293022802385, 13.530279211388134, 12.564682945316079, 11.519492502854115, 10.58001164849812, 7.778120895342831, 6.931120897049675, 7.79731303089712, 8.791389224620605, 9.717331153475602, 10.69860216205397, 11.634891285863539, 12.649603864028077, 13.621715545219242, 14.55155338044045, 15.617262925163423, 16.56325311457899, 16.511578698731807, 15.475260467003089, 14.552916681890455, 13.625289712381248, 12.615364599326085, 11.634602925170743, 10.56693796931358, 9.586001709011205, 8.788044163699501, 7.875929066921846, 8.83414969376577, 9.830790696896171, 10.760508852592665, 11.688874318922483, 12.667661053221327, 13.626945566980584, 14.64594404480222, 15.553131478550911, 16.533074268116565, 16.44306158442348, 15.465449264532658, 14.540472057994151, 13.54810012648407, 12.598356377315291, 11.60757925719737, 10.659237546544471, 9.641567535502066, 8.640157043747731, 9.719541773977296, 8.88578162049154, 9.879509646064273, 10.887243584138286, 11.783524346160448, 12.742760223954896, 13.66964934563436, 14.558317202455527, 15.629485053581368, 16.53870757552655, 16.457459419857148, 15.488842788916731, 14.457450578746874, 13.572717264350318, 12.610170683315374, 11.655545916680023, 10.654036222395119, 9.689223448057088, 8.68691494710228, 7.669349139614528, 10.785856824610864, 9.921980053976446, 10.847995285498456, 11.782107049920834, 12.755151176513, 13.69298811663802, 14.66312230410645, 15.553088485455271, 16.5685023352194, 16.373569013129124, 15.440767135468887, 14.496191723203264, 13.532232455404321, 12.594511064200397, 11.66266419429077, 10.703204484895009, 9.652362876048983, 8.676255745925875, 7.74183749109278, 6.743991157203336, 11.838229505851752, 10.972231403741809, 11.83315392019915, 12.714705658692823, 13.719549491848111, 14.650313276090856, 15.60839051252863, 16.550255954419136, 16.464046961415626, 15.523274954477381, 14.472873113186857, 13.545028163769217, 12.584918326851158, 11.661271088604542, 10.707083921262068, 9.788628100565877, 8.795609056737831, 7.735874961151652, 6.781201474508306, 5.827057350632576, 12.817785887938198, 11.959844142542138, 12.863427574076091, 13.786199293917122, 14.689284476839214, 15.589763118905257, 16.547141694983935, 16.63754276394248, 15.672789752129864, 14.691704593939177, 13.619801868491288, 12.573359420754251, 11.614413947961019, 10.657368673622441, 9.721571486038366, 8.79825933131317, 7.864387745745515, 6.804003311274226, 5.854555288984422, 4.921758584161242, 13.798052281815314, 13.032153626883238, 13.934320999607651, 14.744863242417196, 15.705893601431631, 16.58760963846894, 16.68413843479389, 15.735129033042352, 14.697079719778834, 13.687813687119682, 12.636649746845901, 11.674785774944661, 10.752434573106072, 9.767844411685344, 8.755098505635019, 7.8652110993175555, 6.961414855080966, 6.006200659920011, 5.028668579589906, 4.070185468568429, 14.738852824118219, 14.082434117151427, 14.867627962007846, 15.717873311407436, 16.711861929042303, 16.693207943995105, 15.689959059942511, 14.738192914196313, 13.73981947022935, 12.76264942127034, 11.697605580663499, 10.70727022238803, 9.787677156619244, 8.748033575400637, 7.742502614424259, 6.9063565668152185, 5.925808962871836, 5.008837098340564, 4.057918514554728, 3.042864292183268, 15.811424833132333, 15.133653304784865, 15.79742943541261, 16.7350396552398, 16.879135087223492, 15.819535444095541, 14.757982923837456, 13.74844292262756, 12.67727008003918, 11.749118897560152, 10.74807668593552, 9.738206018278243, 8.758097184950957, 7.793413370365118, 6.801294945722519, 5.855915866952744, 4.926522268630416, 3.99688595814911, 3.007840723822103, 2.0731662952562377, 16.788699529309937, 16.144432393650426, 16.74869361364214, 17.730031555116458, 17.264375454172292, 16.261525637008244, 15.318572459733458, 14.37967715254576, 13.442635879296825, 12.506869295888855, 11.545222874957492, 10.562301118728948, 9.574692301448664, 8.669140911958197, 7.659579895017124, 6.6401550735445625, 5.678975467484238, 4.7154899264465335, 3.7664648311565676, 2.8133530435438887, 17.724740613403004, 17.091822901587758, 17.791659379531268, 17.58560433560786, 16.510796097206484, 15.595494320321592, 14.593421757230765, 13.56897499717321, 12.528663286197753, 11.550058177346017, 10.71355855513075, 9.670198575281436, 8.64598933015452, 7.670268833053697, 6.716649222833496, 5.780845644672325, 4.854041027178362, 3.891420861653182, 2.9440658162517415, 3.765038691080739], [3.907533370958781, 2.9195694101749528, 2.0879727507088646, 2.9596827838594297, 3.8725907889774662, 4.8750031843898585, 5.856078482107212, 6.822079973779117, 7.84130946402772, 8.780024216679433, 9.70876369120338, 10.666195753962487, 11.739140230116039, 12.748997701679215, 13.681819070056772, 14.673501362509105, 15.724914817196192, 16.687643300649622, 17.747489355061813, 18.815305366770094, 2.9050700438114987, 1.9750136006250385, 1.051666930048885, 1.9920127403109593, 2.9434365754708676, 3.93480385813593, 4.977181829712506, 6.005570480874991, 7.020407993289752, 8.02524178972907, 9.025389548998772, 10.018029011749439, 10.966223359695755, 11.971278359150185, 12.921924493783276, 13.900650706700112, 14.94058717487135, 15.971488928214868, 16.950792345885482, 17.966526853355127, 2.0425766383491197, 1.0419820071537682, 0.0, 1.0003914099779838, 1.9977833499086683, 2.9689822844334257, 4.014889822089457, 5.05900096640961, 6.0178192029695, 7.058506755167242, 8.126576859987416, 9.163765682091064, 10.19553486218152, 11.164802503559876, 12.106102848272245, 13.1539288255869, 14.21738572585276, 15.281070510784213, 16.22058296796638, 17.24207618805979, 3.0243146632428477, 1.9785587821477504, 0.9372113639332134, 1.9896133683748034, 2.9187645730944265, 3.8886997147758464, 4.845089662139317, 5.874723234163633, 6.8585312048465275, 7.844659506183457, 8.802040577564835, 9.829681370680207, 10.85295183716445, 11.828691342094901, 12.801194770257236, 13.77185577611755, 14.82454076226757, 15.838773768737063, 16.858971436386735, 16.457871607826164, 3.9420219597206403, 2.89282323238537, 1.914984153299562, 2.978503590785914, 3.904397964771633, 4.831580527097913, 5.761258416671431, 6.8000977014906425, 7.753953329619604, 8.727422872145352, 9.77470299071945, 10.765228330528522, 11.731745062753333, 12.672478924335799, 13.66707219068935, 14.630909049965576, 15.662702927152129, 16.710570782842105, 16.450811238435886, 15.506598188283593, 4.9180765396228345, 3.9000015087031574, 2.908034264439901, 3.9105519853783344, 4.881945396345477, 5.8449264302612285, 6.722973767049659, 7.755364313410968, 8.692121784601419, 9.694692603766494, 10.698567607206414, 11.642762686138232, 12.654136908330548, 13.638734444569037, 14.615094555878521, 15.55825260215341, 16.617100403974508, 16.44602895617717, 15.449681614883122, 14.449041451650665, 5.803954581978519, 4.863997722369715, 3.9253529989561198, 4.918839592577158, 5.847884872133587, 6.812172755252828, 7.699762422878983, 8.75104356143342, 9.7206498832336, 10.680866072253256, 11.694643837548446, 12.588151300192772, 13.599099022314348, 14.623390568856658, 15.554699089041113, 16.6074019144688, 16.35588982874423, 15.413063488369371, 14.40839399044915, 13.479328161924618, 6.734583213958879, 5.861077900766922, 4.9508050937493975, 5.927799545699363, 6.881111035169172, 7.82084729657997, 8.761682257710993, 9.707856514300312, 10.666140582736382, 11.675502361116811, 12.685252524918631, 13.56945930638127, 14.567614030666117, 15.50581866544123, 16.528267755008947, 16.384719780173224, 15.439752624805795, 14.45546703425052, 13.500221209204899, 12.490675243139604, 7.667001826351276, 6.815164448521101, 5.918867890627854, 6.885718817853822, 7.806934693585099, 8.789188301676823, 9.741682381303418, 10.677206286138848, 11.657474953706533, 12.666897440140186, 13.68481125697431, 14.595584170723193, 15.575157316365114, 16.47010192380774, 16.334365775698743, 15.406915889645159, 14.472902078230907, 13.507305812158853, 12.462115369696889, 11.522634515340894, 8.720743762185608, 7.866952284072378, 6.866330382418739, 7.860406576142223, 8.751906244468941, 9.733177253047309, 10.669466376856878, 11.631747812985608, 12.603859494176774, 13.533697329397983, 14.599406874120955, 15.545397063536523, 16.552739942343173, 16.417883333845865, 15.495539548733229, 14.567912579224021, 13.557987466168859, 12.577225792013516, 11.509560836156354, 10.528624575853978, 9.730667030542277, 8.811760453944547, 7.90316704528739, 8.899808048417789, 9.795083943586004, 10.723449409915823, 11.702236144214666, 12.661520657973924, 13.657881525180436, 14.535275427508443, 15.515218217074096, 16.510557551302778, 16.41693763395389, 15.483094924836927, 14.490722993326845, 13.540979244158065, 12.550202124040144, 11.601860413387245, 10.58419040234484, 9.582779910590505, 10.662164640820071, 9.821613007514243, 8.959300954199012, 9.956260935659904, 10.818099437153787, 11.777335314948235, 12.7042244366277, 13.592892293448866, 14.664060144574707, 15.520851524484081, 16.54055210007945, 16.440331158337962, 15.408938948168107, 14.515340131193092, 13.552793550158148, 12.598168783522796, 11.596659089237892, 10.631846314899862, 9.629537813945056, 8.611972006457302, 11.72847969145364, 10.857811440999148, 9.927786593633195, 10.861898358055573, 11.789726267506339, 12.72756320763136, 13.69769739509979, 14.58766357644861, 15.603077426212737, 16.544251854209826, 16.39225550489012, 15.447680092624497, 14.483720824825554, 13.54599943362163, 12.608075026797973, 11.645827351737783, 10.594985742891756, 9.618878612768649, 8.684460357935555, 7.6866140240461105, 12.780852372694527, 11.908062790764511, 10.91294522833389, 11.794496966827563, 12.79934079998285, 13.684888367084195, 14.642965603521969, 15.584831045412475, 16.53406614942765, 16.474763323898614, 15.42436148260809, 14.49651653319045, 13.53640669627239, 12.612759458025774, 11.658572290683301, 10.731250967408656, 9.738231923580608, 8.678497827994429, 7.723824341351081, 6.769680217475351, 13.760408754780974, 12.89567552956484, 11.943218882210829, 12.86599060205186, 13.769075784973953, 14.624338209898596, 15.581716785977274, 16.61067454310776, 16.544145012654383, 15.592613519058037, 14.571290237912521, 13.524847790175484, 12.565902317382251, 11.608857043043674, 10.673059855459599, 9.749747700734401, 8.807010612588291, 7.746626178117001, 6.797178155827197, 5.864381451004017, 14.74067514865809, 13.96798501390594, 13.014112307742389, 13.824654550551935, 14.78568490956637, 15.622184729462282, 16.582816736644787, 16.409577404268983, 15.568434980303353, 14.568504231958853, 13.517340291685072, 12.555476319783832, 11.703922942527303, 10.719332781106575, 9.706586875056251, 8.816699468738786, 8.003396862234736, 7.036352495217663, 5.971291446432681, 5.012808335411203, 15.681475690960994, 14.915375389498305, 13.947419270142584, 14.797664619542175, 15.79165323717704, 16.675875710770153, 16.364407431169145, 15.412641285422945, 14.576122953935622, 13.636997356200961, 12.57829612550267, 11.5879607672272, 10.700232150606258, 9.699521944821868, 8.693990983845492, 7.85784493623645, 6.967790970025605, 6.050819105494333, 5.091147262218825, 4.063668723436832, 16.75404769997511, 15.932878482491734, 14.877220743547348, 15.814830963374536, 16.772966366152183, 16.317002698090107, 15.432431295064088, 14.422891293854192, 13.507893989647293, 12.579742807168264, 11.62876723077469, 10.618896563117413, 9.638787729790128, 8.74490173978635, 7.752783315143751, 6.8074042363739755, 5.968504275784185, 5.038867965302879, 4.049822730975872, 3.115148302410006, 17.731322396152716, 16.76563823502112, 15.828484921776878, 16.809822863251195, 16.367808076608632, 15.364958259444586, 14.422005082169802, 13.483109774982104, 12.546068501733169, 11.610301918325199, 10.648655497393833, 9.665733741165289, 8.678124923885004, 7.77257353439454, 6.803193745057506, 5.874222655228501, 5.036354105872317, 4.14708996037469, 4.808446838310336, 3.855335050697657, 18.667363480245783, 17.713028742958453, 16.871450687666005, 16.689036958044206, 15.614228719642828, 14.698926942757936, 13.696854379667109, 12.672407619609555, 11.632095908634097, 10.653490799782361, 9.816991177567093, 8.77363119771778, 7.749421952590863, 6.773701455490039, 5.820081845269839, 4.900231025277803, 4.0000357842636385, 3.110723831574692, 3.98604782340551, 4.807020698234507], [4.865960907056832, 3.877996946273003, 2.99710637789073, 1.988124790517147, 2.8721993789994826, 3.874611774411875, 4.8556870721292285, 5.821688563801134, 6.8409180540497365, 7.779632806701449, 8.708372281225397, 9.665804343984504, 10.738748820138056, 11.748606291701233, 12.68142766007879, 13.673109952531123, 14.724523407218209, 15.68725189067164, 16.74709794508383, 17.81491395679211, 3.8634975799095495, 2.933441136723089, 1.9608005572307508, 1.0204547469686764, 1.9430451654928838, 2.9344124481579463, 3.976790419734522, 5.005179070897007, 6.020016583311769, 7.024850379751088, 8.02499813902079, 9.017637601771456, 9.965831949717773, 10.970886949172202, 11.921533083805294, 12.90025929672213, 13.940195764893367, 14.971097518236885, 15.950400935907501, 16.966135443377148, 3.0429680483271033, 2.042373417131752, 1.0003914099779838, 0.0, 0.9973919399306846, 1.9685908744554421, 3.0144984121114735, 4.058609556431627, 5.0174277929915165, 6.058115345189259, 7.126185450009433, 8.163374272113082, 9.195143452203537, 10.164411093581894, 11.105711438294263, 12.153537415608918, 13.216994315874777, 14.28067910080623, 15.220191557988397, 16.241684778081808, 4.024706073220832, 2.978950192125734, 1.9376027739111972, 1.0105719853762671, 1.9397231900958904, 2.90965833177731, 3.866048279140781, 4.895681851165096, 5.879489821847991, 6.8656181231849205, 7.822999194566298, 8.85063998768167, 9.873910454165914, 10.849649959096364, 11.8221533872587, 12.792814393119013, 13.845499379269034, 14.859732385738527, 15.879930053388199, 16.819895913816254, 4.942413369698624, 3.8932146423633536, 2.9153755632775455, 2.049254692014289, 2.925356581773097, 3.852539144099376, 4.782217033672895, 5.821056318492106, 6.774911946621067, 7.748381489146816, 8.795661607720913, 9.786186947529986, 10.752703679754797, 11.693437541337262, 12.688030807690813, 13.65186766696704, 14.683661544153592, 15.731529399843566, 16.774063926808974, 16.50698959826158, 5.918467949600818, 4.900392918681141, 3.9084256744178845, 2.998736469016068, 3.9029040133469413, 4.865885047262692, 5.7439323840511225, 6.776322930412432, 7.713080401602882, 8.715651220767958, 9.719526224207877, 10.663721303139695, 11.675095525332011, 12.6596930615705, 13.636053172879985, 14.579211219154873, 15.638059020975973, 16.70293326028749, 16.45007302486111, 15.44943286162865, 6.804345991956502, 5.864389132347698, 4.925744408934103, 4.007024076214892, 4.868843489135051, 5.833131372254291, 6.720721039880447, 7.772002178434883, 8.741608500235063, 9.70182468925472, 10.71560245454991, 11.609109917194235, 12.620057639315812, 13.644349185858122, 14.575657706042577, 15.628360531470262, 15.874495772370466, 16.413454898347354, 15.408785400427135, 14.479719571902603, 7.734974623936862, 6.861469310744907, 5.951196503727381, 5.015984029337097, 5.902069652170636, 6.8418059135814335, 7.782640874712456, 8.728815131301776, 9.687099199737846, 10.696460978118274, 11.706211141920095, 12.590417923382734, 13.588572647667581, 14.526777282442694, 15.549226372010413, 15.750393946333732, 14.907782489066998, 15.455858444228506, 14.500612619182885, 13.491066653117588, 8.667393236329259, 7.815555858499086, 6.919259300605837, 6.005412878249729, 6.827893310586562, 7.810146918678287, 8.762640998304882, 9.698164903140311, 10.678433570707996, 11.68785605714165, 12.705769873975774, 13.616542787724656, 14.596115933366578, 15.491060540809205, 15.69187864267777, 14.772590055805667, 13.882869215264636, 14.507697222136837, 13.462506779674873, 12.523025925318878, 9.72113517216359, 8.86734369405036, 7.8667217923967225, 7.052155416800388, 7.7728648614704055, 8.754135870048774, 9.690424993858343, 10.652706429987072, 11.624818111178238, 12.554655946399446, 13.620365491122419, 14.566355680537987, 15.573698559344637, 15.43955487926132, 14.654616313950333, 13.774234985545894, 12.908379233222465, 13.577617201991501, 12.509952246134338, 11.529015985831963, 10.73105844052026, 9.81215186392253, 8.903558455265372, 8.091556889075953, 8.81604256058747, 9.744408026917288, 10.723194761216131, 11.682479274975389, 12.6788401421819, 13.556234044509907, 14.53617683407556, 15.53151616830424, 15.416546223975907, 14.504766470252383, 13.617925144911656, 12.704632753560043, 11.887837660627692, 12.60225182336523, 11.584581812322824, 10.58317132056849, 11.662556050798054, 10.822004417492225, 9.959692364176995, 9.148009776318068, 9.839058054155252, 10.7982939319497, 11.725183053629165, 12.613850910450331, 13.685018761576172, 14.541810141485545, 15.56151071708091, 15.43993974835998, 14.408547538190122, 13.534093010626004, 12.577148557153123, 11.6835760514207, 10.93429462582544, 11.632237724877847, 10.629929223923039, 9.612363416435286, 12.728871101431622, 11.858202850977131, 10.928178003611178, 10.120946082298316, 10.810684884507804, 11.748521824632824, 12.718656012101254, 13.608622193450076, 14.624036043214202, 15.565210471211289, 15.391864094912135, 14.447288682646512, 13.483329414847569, 12.545608023643645, 11.613761153734018, 10.727881887383939, 9.932621279479305, 10.619270022746633, 9.684851767913539, 8.687005434024094, 13.78124378267251, 12.908454200742494, 11.913336638311872, 11.053544691070305, 11.821415076872668, 12.70584698408566, 13.663924220523434, 14.60578966241394, 15.555024766429115, 15.47437191392063, 14.423970072630105, 13.496125123212465, 12.536015286294406, 11.61236804804779, 10.658180880705316, 9.802799830195788, 8.985862906487219, 9.678889237972411, 8.724215751329064, 7.770071627453334, 14.760800164758956, 13.896066939542823, 12.943610292188811, 12.125038326294604, 12.791150061863771, 13.645296826900061, 14.60267540297874, 15.631633160109226, 15.5437536026764, 14.592222109080055, 13.570898827934537, 12.524456380197499, 11.565510907404267, 10.60846563306569, 9.672668445481614, 8.749356290756419, 8.054641595494902, 8.747017588094984, 7.79756956580518, 6.864772860982001, 15.741066558636073, 14.968376423883923, 14.014503717720372, 13.083702274794678, 13.807759186456188, 14.643143346463747, 15.603775353646252, 15.409185994291, 14.56804357032537, 13.56811282198087, 12.516948881707089, 11.55508490980585, 10.70353153254932, 9.718941371128592, 8.706195465078267, 7.816308058760804, 7.040353616081257, 7.944412041882914, 6.9716828564106645, 6.013199745389187, 16.681867100938977, 15.915766799476287, 14.947810680120567, 14.056712343784918, 14.845190005212233, 15.696834327771617, 15.36401602119116, 14.412249875444962, 13.57573154395764, 12.636605946222979, 11.577904715524687, 10.587569357249217, 9.699840740628275, 8.699130534843885, 7.693599573867507, 6.857453526258467, 6.004747723872127, 6.947048480303467, 6.091538672196809, 5.0640601334148165, 17.235447483731786, 16.933269892469717, 15.87761215352533, 15.07387868761728, 15.887540289353508, 15.316611288112126, 14.432039885086105, 13.42249988387621, 12.50750257966931, 11.579351397190282, 10.628375820796707, 9.61850515313943, 8.638396319812145, 7.744510329808366, 6.7523919051657675, 5.807012826395992, 5.005461029630707, 5.935097340112013, 5.050214140953855, 4.1155397123879895, 18.01207706088004, 17.7660296449991, 16.82887633175486, 16.06887058749394, 15.36741666663065, 14.364566849466604, 13.42161367219182, 12.482718365004121, 11.545677091755186, 10.609910508347216, 9.64826408741585, 8.665342331187306, 7.677733513907022, 6.772182124416557, 5.802802335079523, 4.873831245250518, 4.0647961125300345, 5.028281653567739, 5.766874374408387, 4.813762586795708, 18.732968346016435, 17.70738839008414, 16.678297276836368, 15.688645548066225, 14.613837309664845, 13.698535532779953, 12.696462969689126, 11.672016209631572, 10.631704498656115, 9.653099389804378, 8.81659976758911, 7.773239787739795, 6.749030542612879, 5.773310045512057, 4.8196904352918555, 3.899839615299819, 3.0284777909213556, 4.008785383430398, 4.94447535950356, 5.765448234332558], [5.773541597392242, 4.785577636608414, 3.8738704054513318, 2.8143248206666325, 1.8748074390687979, 2.87721983448119, 3.8582951321985437, 4.824296623870449, 5.843526114119052, 6.782240866770764, 7.710980341294713, 8.66841240405382, 9.741356880207372, 10.751214351770548, 11.684035720148104, 12.675718012600438, 13.727131467287524, 14.689859950740955, 15.749706005153143, 16.817522016861425, 4.77107827024496, 3.8410218270584995, 2.8683812475661616, 1.9280354373040873, 0.9456532255621991, 1.9370205082272616, 2.9793984798038378, 4.0077871309663236, 5.022624643381085, 6.027458439820403, 7.027606199090106, 8.020245661840773, 8.96844000978709, 9.97349500924152, 10.92414114387461, 11.902867356791447, 12.942803824962684, 13.973705578306202, 14.953008995976818, 15.968743503446465, 4.040359988257788, 3.0397653570624366, 1.9977833499086683, 0.9973919399306846, 0.0, 0.9711989345247575, 2.017106472180789, 3.061217616500943, 4.020035853060833, 5.060723405258575, 6.128793510078748, 7.165982332182397, 8.197751512272852, 9.167019153651209, 10.108319498363578, 11.156145475678233, 12.219602375944092, 13.283287160875545, 14.222799618057712, 15.244292838151123, 5.022098013151517, 3.976342132056419, 2.9349947138418817, 1.947775004311433, 1.01862379959181, 1.948841537557005, 2.905231484920476, 3.9348650569447914, 4.918673027627686, 5.9048013289646155, 6.8621824003459935, 7.889823193461366, 8.91309365994561, 9.88883316487606, 10.861336593038395, 11.831997598898708, 12.88468258504873, 13.898915591518222, 14.919113259167894, 15.85907911959595, 5.939805309629309, 4.890606582294038, 3.9127675032082303, 2.934952324968363, 2.0042571912690166, 2.9314397535952956, 3.8611176431688143, 4.8999569279880255, 5.853812556116987, 6.827282098642735, 7.834844813500608, 8.82537015330968, 9.791886885534492, 10.732620747116957, 11.727214013470508, 12.691050872746734, 13.722844749933287, 14.770712605623261, 15.813247132588671, 16.758687381118712, 6.915859889531502, 5.897784858611825, 4.886951822908575, 3.884434101970142, 2.9818046228428607, 3.944785656758611, 4.822832993547042, 5.855223539908351, 6.791981011098802, 7.7945518302638765, 8.776632905793448, 9.720827984725267, 10.732202206917583, 11.716799743156072, 12.693159854465556, 13.636317900740444, 14.695165702561544, 15.760039941873064, 16.75638728316711, 16.446824801559334, 7.801737931887186, 6.861781072278382, 5.904270557424794, 4.892721709168965, 3.94774409863097, 4.912031981750211, 5.799621649376366, 6.850902787930803, 7.820509109730983, 8.780725298750637, 9.77270913613548, 10.666216598779807, 11.677164320901383, 12.701455867443693, 13.632764387628148, 14.685467213055833, 15.709128963212699, 16.651955303587556, 16.406177340357818, 15.477111511833288, 8.732366563867547, 7.85886125067559, 6.9297226522180715, 5.90168166229117, 4.980970261666555, 5.920706523077353, 6.8615414842083755, 7.807715740797695, 8.765999809233765, 9.775361587614192, 10.785111751416013, 11.647524604968305, 12.645679329253152, 13.583883964028265, 14.606333053595984, 14.753002006403047, 15.641335944223927, 16.45325038415919, 15.498004559113568, 14.488458593048273, 9.664785176259944, 8.809317708254252, 7.829302983568004, 6.862452056342036, 5.906793920082482, 6.889047528174206, 7.841541607800802, 8.777065512636232, 9.757334180203918, 10.766756666637567, 11.784670483471691, 12.673649469310227, 13.65322261495215, 14.548167222394774, 14.694486702747085, 13.775198115874982, 14.616422670421565, 15.505089162067522, 14.459898719605558, 13.520417865249563, 10.718527112094275, 9.777387377012527, 8.77676547535889, 7.794634801638585, 6.851765470966325, 7.833036479544693, 8.769325603354261, 9.731607039482993, 10.703718720674159, 11.633556555895368, 12.69926610061834, 13.645256290033908, 14.652599168840558, 14.442162939330636, 13.657224374019648, 12.776843045615209, 13.641932688379395, 14.575009141922186, 13.507344186065023, 12.526407925762648, 11.66894314087105, 10.722195546884697, 9.813602138227541, 8.834036273914151, 7.894943170083389, 8.823308636413207, 9.802095370712049, 10.761379884471307, 11.75774075167782, 12.635134654005828, 13.615077443571481, 14.610416777800161, 14.419154284045222, 13.507374530321698, 12.62053320498097, 11.707240813629358, 12.62139111578462, 13.599643763295914, 12.581973752253509, 11.580563260499174, 12.600440751148845, 11.732048100454392, 10.869736047139163, 9.890489161156266, 8.917958663651172, 9.87719454144562, 10.804083663125082, 11.692751519946249, 12.76391937107209, 13.620710750981466, 14.640411326576832, 14.442547808429294, 13.411155598259437, 12.536701070695319, 11.579756617222438, 10.686184111490014, 11.667848080982369, 12.582474691462373, 11.627321163853725, 10.609755356365971, 13.666755801782411, 12.768246533939298, 11.797537231558891, 10.863425467136514, 9.889585494003724, 10.827422434128744, 11.797556621597174, 12.687522802945994, 13.70293665271012, 14.64411108070721, 14.39447215498145, 13.449896742715827, 12.485937474916884, 11.54821608371296, 10.616369213803333, 9.730489947453254, 10.666174734636233, 11.56950698933116, 10.682243707844224, 9.684397373954779, 14.7191284830233, 13.818497883704659, 12.782695866259585, 11.796024075908504, 10.900315686368588, 11.78474759358158, 12.742824830019353, 13.684690271909858, 14.633925375925033, 14.476979973989945, 13.42657813269942, 12.49873318328178, 11.538623346363721, 10.614976108117105, 9.660788940774632, 8.805407890265103, 9.719416361644146, 10.624460645088103, 9.721607691259749, 8.767463567384018, 15.698684865109746, 14.806110622504988, 13.812969520136527, 12.836962400221639, 11.87005067135969, 12.72419743639598, 13.68157601247466, 14.710533769605144, 14.546361662745717, 13.59483016914937, 12.573506888003852, 11.527064440266814, 10.568118967473582, 9.611073693135005, 8.67527650555093, 7.751964350825734, 8.78819505065183, 9.692588995210675, 8.794961505735865, 7.8621648009126845, 16.678951258986864, 15.828881221198142, 14.766867180985743, 13.795626348721713, 12.886659795952108, 13.722043955959666, 14.682675963142172, 14.411794054360318, 13.570651630394687, 12.570720882050185, 11.519556941776404, 10.557692969875164, 9.706139592618635, 8.721549431197907, 7.708803525147582, 6.818916118830119, 7.773907071238185, 8.677965497039843, 7.969074796341349, 7.010591685319872, 16.859796161090806, 16.66813026274166, 15.700174143385938, 14.768636417711953, 13.924090614708152, 14.775734937267536, 14.366624081260477, 13.414857935514279, 12.578339604026956, 11.639214006292296, 10.580512775594002, 9.590177417318532, 8.702448800697589, 7.701738594913199, 6.696207633936822, 5.860061586327782, 6.738301179029055, 7.680601935460395, 7.088930612127494, 6.061452073345501, 16.2380555438011, 17.281841980512095, 16.629975616790702, 15.785802761544314, 14.966440898849427, 14.319219348181443, 13.434647945155422, 12.425107943945527, 11.510110639738627, 10.581959457259599, 9.630983880866022, 8.621113213208746, 7.641004379881459, 6.747118389877682, 5.754999965235083, 4.809620886465307, 5.739014484787635, 6.668650795268941, 6.04760608088454, 5.112931652318674, 17.014685120949355, 17.368674985462096, 16.431521672217855, 15.424701882117688, 14.370024726699967, 13.36717490953592, 12.424221732261136, 11.485326425073438, 10.548285151824503, 9.612518568416533, 8.650872147485165, 7.66795039125662, 6.680341573976337, 5.774790184485871, 4.805410395148837, 3.876439305319833, 4.837618911380157, 5.801104452417862, 6.674455064743797, 5.721343277131118, 17.735576406085748, 16.709996450153454, 15.680905336905683, 14.69125360813554, 13.61644536973416, 12.701143592849268, 11.699071029758441, 10.674624269700887, 9.63431255872543, 8.655707449873693, 7.819207827658426, 6.775847847809111, 5.751638602682195, 4.775918105581371, 3.8222984953611703, 2.9024476753691344, 3.8546778210708412, 4.834985413579884, 5.849174348294091, 6.673028924667968], [6.7447405319169995, 5.756776571133171, 4.845069339976089, 3.78552375519139, 2.8460063735935552, 1.9060208999564328, 2.8870961976737863, 3.8530976893456916, 4.872327179594294, 5.811041932246007, 6.739781406769955, 7.697213469529062, 8.770157945682614, 9.78001541724579, 10.712836785623347, 11.70451907807568, 12.755932532762767, 13.718661016216197, 14.778507070628386, 15.846323082336665, 5.742277204769717, 4.812220761583257, 3.839580182090919, 2.899234371828845, 1.9168521600869566, 0.9658215737025041, 2.00819954527908, 3.0365881964415657, 4.051425708856327, 5.056259505295646, 6.056407264565348, 7.049046727316015, 7.99724107526233, 9.00229607471676, 9.952942209349851, 10.931668422266688, 11.971604890437925, 13.002506643781441, 13.981810061452057, 14.997544568921704, 5.0115589227825454, 4.010964291587194, 2.9689822844334257, 1.9685908744554421, 0.9711989345247575, 0.0, 1.0459075376560316, 2.090018681976185, 3.0488369185360753, 4.089524470733817, 5.157594575553991, 6.194783397657639, 7.226552577748094, 8.19582021912645, 9.137120563838819, 10.184946541153474, 11.248403441419333, 12.312088226350786, 13.251600683532953, 14.273093903626364, 5.993296947676274, 4.947541066581176, 3.906193648366639, 2.8767289494332906, 1.9475777447136673, 0.9776426030322476, 1.9340325503957185, 2.963666122420034, 3.9474740931029286, 4.933602394439858, 5.890983465821236, 6.9186242589366085, 7.941894725420852, 8.917634230351302, 9.890137658513638, 10.86079866437395, 11.913483650523972, 12.927716656993464, 13.947914324643136, 14.887880185071193, 6.911004244154066, 5.861805516818795, 4.883966437732988, 3.8383445967301806, 2.9076494630308343, 1.980466900704555, 2.908991031508844, 3.9478303163280546, 4.901685944457016, 5.875155486982765, 6.86364587897585, 7.854171218784923, 8.820687951009733, 9.761421812592198, 10.75601507894575, 11.719851938221975, 12.751645815408528, 13.799513671098502, 14.842048198063912, 15.787488446593951, 7.845850989394981, 6.8277759584753035, 5.7903440946703935, 4.78782637373196, 3.8851968946046784, 2.99381280386787, 3.870706381887072, 4.903096928248381, 5.839854399438831, 6.842425218603906, 7.805433971268691, 8.74962905020051, 9.761003272392825, 10.745600808631314, 11.721960919940798, 12.665118966215687, 13.723966768036787, 14.788841007348307, 15.785188348642356, 16.799433725615643, 8.718813703514112, 7.778856843905308, 6.807662829186612, 5.796113980930784, 4.851136370392788, 3.9610591288594694, 4.847495037716396, 5.898776176270832, 6.868382498071012, 7.828598687090667, 8.801510201610723, 9.69501766425505, 10.705965386376626, 11.730256932918936, 12.66156545310339, 13.714268278531076, 14.737930028687941, 15.680756369062797, 16.685425866983017, 16.394187283460212, 9.649442335494472, 8.775937022302516, 7.83311492397989, 6.805073934052989, 5.884362533428373, 5.002796388188695, 5.909414872548405, 6.855589129137725, 7.813873197573795, 8.823234975954223, 9.832985139756044, 10.676325670443548, 11.674480394728395, 12.612685029503508, 13.635134119071227, 14.654917302768402, 15.60233722208727, 16.586622812642545, 16.415080330740494, 15.405534364675198, 10.581860947886868, 9.71270998001607, 8.732695255329823, 7.765844328103855, 6.8101861918443, 6.039367216952735, 6.8894149961408315, 7.824938900976262, 8.805207568543947, 9.814630054977599, 10.832543871811723, 11.70245053478547, 12.682023680427392, 13.576968287870017, 13.784555559325849, 14.673275270367393, 15.554073574813843, 16.422164933694447, 15.376974491232483, 14.437493636876487, 11.6356028837212, 10.680779648774346, 9.680157747120708, 8.698027073400404, 7.7551577427281435, 7.0176088160005925, 7.893501056063081, 8.779480427823023, 9.751592109014188, 10.681429944235397, 11.74713948895837, 12.693129678373937, 13.700472557180587, 13.5322317959094, 12.747293230598412, 13.67492020010762, 14.579583592771673, 15.49208491354911, 14.424419957691947, 13.443483697389572, 12.572335412632869, 11.625587818646515, 10.716994409989358, 9.73742854567597, 8.798335441845207, 8.085478596311273, 8.926270823420868, 9.835661544694343, 10.80561414001785, 11.683008042345858, 12.66295083191151, 13.65829016614019, 13.509223140623986, 12.597443386900462, 11.710602061559735, 12.644891718021638, 13.5590420201769, 14.516719534922839, 13.499049523880434, 12.497639032126099, 13.503833022910664, 12.63544037221621, 11.77312831890098, 10.793881432918084, 9.82135093541299, 9.139364501343685, 9.928259115833901, 10.767033180169285, 11.838201031295126, 12.668584139321496, 13.688284714916861, 13.514457638914093, 12.501224454838201, 11.626769927274083, 10.669825473801202, 11.623835015882294, 12.605498985374648, 13.520125595854651, 12.544396935480648, 11.526831127992896, 14.570148073544232, 13.671638805701116, 12.70092950332071, 11.766817738898332, 10.792977765765542, 10.089592394026809, 10.979601600756318, 11.76180446316903, 12.777218312933156, 13.69198446904724, 13.434276882924106, 12.48997158103223, 11.576006331495648, 10.638284940291724, 9.706438070382097, 10.668140851845534, 11.603825639028512, 12.507157893723438, 11.599319479471148, 10.601473145581704, 15.62252075478512, 14.721890155466479, 13.686088138021404, 12.699416347670322, 11.803707958130406, 11.046917553479645, 11.924869809178498, 12.758971932132894, 13.70820703614807, 13.5167847019326, 12.466382860642076, 11.538537911224436, 10.628692202942485, 9.705044964695869, 8.750857797353396, 9.743058794657383, 10.657067266036426, 11.562111549480381, 10.651598791123227, 9.684539339010945, 16.602077136871568, 15.709502894266809, 14.716361791898343, 13.740354671983457, 12.773442943121509, 11.986367396294046, 12.867851954791549, 13.78481542982818, 13.57516272822096, 12.623631234624613, 11.610218043678625, 10.56686916820947, 9.658187824052346, 8.701142549713769, 7.765345362129692, 8.689615255218014, 9.72584595504411, 10.630239899602953, 9.724952605599343, 8.792155900776164, 16.757267930645614, 16.73227349295996, 15.670259452747562, 14.699018620483532, 13.790052067713926, 12.984213915857731, 13.868951905459062, 13.44059511983556, 12.59945269586993, 11.599521947525428, 10.548358007251647, 9.586494035350407, 8.741874610367647, 7.804037581430378, 6.798872381726345, 7.756567023222399, 8.711557975630464, 9.61561640143212, 8.940273730866107, 7.981790619844629, 15.888597226566048, 16.853029201478265, 16.603566415147757, 15.672028689473771, 14.827482886469971, 14.037904897165602, 13.39542514673572, 12.443659000989522, 11.607140669502199, 10.668015071767538, 9.609313841069245, 8.618978482793775, 7.731249866172832, 6.784226745145671, 5.7862764905155855, 6.797712490720063, 7.675952083421334, 8.618252839852675, 8.060129546652252, 7.032651007870259, 15.266856609276342, 16.310643045987337, 16.369134598693357, 15.357482284328102, 14.399346881550454, 13.348020413656686, 12.463449010630665, 11.45390900942077, 10.53891170521387, 9.610760522734841, 8.659784946341265, 7.649914278683989, 6.669805445356702, 5.829606540110153, 4.845068821813846, 5.747271790857588, 6.676665389179915, 7.606301699661221, 7.018805015409297, 6.084130586843432, 16.043486186424595, 16.39747605093734, 15.460322737693097, 14.45350294759293, 13.39882579217521, 12.395975975011163, 11.453022797736379, 10.514127490548681, 9.577086217299746, 8.641319633891776, 7.679673212960408, 6.696751456731863, 5.70914263945158, 4.803591249961114, 3.83421146062408, 4.814090209712114, 5.775269815772438, 6.738755356810143, 7.645653999268554, 6.6925422116558755, 16.76437747156099, 15.738797515628697, 14.709706402380926, 13.720054673610782, 12.645246435209403, 11.729944658324511, 10.727872095233684, 9.70342533517613, 8.663113624200673, 7.684508515348937, 6.8480088931336685, 5.804648913284353, 4.780439668157437, 3.8047191710566137, 2.851099560836413, 3.840098579761415, 4.825876755595599, 5.806184348104641, 6.820373282818848, 7.644227859192726], [7.790648069573032, 6.802684108789203, 5.890976877632122, 4.831431292847422, 3.8919139112495875, 2.8981436802274625, 1.917068382510109, 2.8830698741820147, 3.9022993644306174, 4.84101411708233, 5.769753591606278, 6.727185654365385, 7.800130130518937, 8.809987602082114, 9.74280897045967, 10.734491262912004, 11.78590471759909, 12.74863320105252, 13.808479255464711, 14.87629526717299, 6.7881847424257495, 5.858128299239289, 4.885487719746951, 3.9451419094848768, 2.9627596977429884, 2.009809427907973, 0.9622920076230486, 1.9906806587855344, 3.005518171200295, 4.010351967639615, 5.010499726909317, 6.003139189659984, 6.951333537606299, 7.956388537060728, 8.907034671693818, 9.885760884610654, 10.925697352781892, 11.95659910612541, 12.935902523796026, 13.951637031265673, 6.057466460438578, 5.056871829243226, 4.014889822089458, 3.014498412111474, 2.017106472180789, 1.0459075376560316, 0.0, 1.0441111443201534, 2.0029293808800435, 3.043616933077786, 4.111687037897959, 5.148875860001608, 6.180645040092062, 7.149912681470419, 8.091213026182789, 9.139039003497444, 10.202495903763303, 11.266180688694757, 12.205693145876923, 13.227186365970335, 6.934916642709888, 5.88916076161479, 4.8478133434002535, 3.7954113389586634, 2.8662601342390404, 1.8963249925576207, 0.9399350451941497, 1.9695686172184654, 2.95337658790136, 3.9395048892382896, 4.8968859606196675, 5.92452675373504, 6.947797220219283, 7.9235367251497335, 8.89604015331207, 9.866701159172383, 10.919386145322404, 11.933619151791897, 12.953816819441569, 13.893782679869625, 7.793006355813849, 6.743807628478578, 5.76596854939277, 4.702449111906419, 3.7717539782070726, 2.8445714158807935, 1.9148935263072748, 2.9537328111264856, 3.907588439255447, 4.881057981781195, 5.869548373774282, 6.860073713583354, 7.826590445808165, 8.76732430739063, 9.761917573744181, 10.725754433020407, 11.75754831020696, 12.805416165896935, 13.847950692862344, 14.793390941392383, 8.709955504571218, 7.6918804736515405, 6.654448609846631, 5.651930888908198, 4.749301409780917, 3.8444156067951476, 2.876608876685503, 3.9089994230468124, 4.845756894237263, 5.848327713402337, 6.8113364660671225, 7.7555315449989415, 8.766905767191258, 9.751503303429747, 10.72786341473923, 11.671021461014119, 12.72986926283522, 13.794743502146737, 14.791090843440786, 15.805336220414073, 9.582918218690349, 8.642961359081545, 7.67176734436285, 6.660218496107022, 5.715240885569027, 4.811661931786746, 3.853397532514827, 4.904678671069264, 5.874284992869444, 6.834501181889098, 7.8074126964091555, 8.700920159053481, 9.711867881175058, 10.736159427717368, 11.667467947901823, 12.720170773329508, 13.743832523486374, 14.68665886386123, 15.69132836178145, 16.62039419030598, 10.513546850670709, 9.640041537478753, 8.697219439156127, 7.669178449229227, 6.748467048604612, 5.853399191115972, 4.915317367346837, 5.861491623936156, 6.819775692372226, 7.829137470752654, 8.838887634554474, 9.68222816524198, 10.680382889526827, 11.61858752430194, 12.641036613869659, 13.660819797566834, 14.608239716885702, 15.592525307440978, 16.5477711324866, 16.269638879851435, 11.445965463063105, 10.576814495192309, 9.596799770506061, 8.629948843280093, 7.674290707020539, 6.889970019880012, 5.895317490939264, 6.830841395774694, 7.81111006334238, 8.82053254977603, 9.838446366610153, 10.708353029583902, 11.687926175225824, 12.58287078266845, 13.53761143767803, 14.465061323731614, 15.399075135145866, 16.36467140121792, 16.241079006408718, 15.301598152052724, 12.499707398897437, 11.544884163950584, 10.544262262296947, 9.56213158857664, 8.619262257904381, 7.835692674671082, 6.899403550861513, 7.785382922621456, 8.75749460381262, 9.68733243903383, 10.753041983756802, 11.69903217317237, 12.70637505197902, 12.79798904359904, 13.72570222771969, 14.653329197228897, 15.557992589892955, 16.356189428725347, 15.288524472868184, 14.30758821256581, 13.436439927809108, 12.489692333822754, 11.581098925165598, 10.601533060852207, 9.662439957021444, 8.903562454981763, 7.9321733182193, 8.841564039492775, 9.811516634816282, 10.68891053714429, 11.668853326709943, 12.664192660938623, 12.673157821181551, 11.863200634590102, 12.689011058681013, 13.623300715142918, 14.53745101729818, 15.380824050099076, 14.36315403905667, 13.361743547302336, 14.367937538086903, 13.49954488739245, 12.63723283407722, 11.657985948094321, 10.685455450589227, 9.949760989287217, 8.934161610632334, 9.77293567496772, 10.84410352609356, 11.674486634119928, 12.694187209715293, 12.544429823750416, 11.665159135395767, 10.892527174963723, 11.64823447092248, 12.602244013003574, 13.583907982495928, 14.410809951611693, 13.408501450656885, 12.390935643169133, 15.434252588720469, 14.535743320877355, 13.565034018496947, 12.63092225407457, 11.65708228094178, 10.89998888197034, 9.98550409555475, 10.767706957967464, 11.78312080773159, 12.697886963845672, 12.464249067760429, 11.519943765868552, 10.739941012053213, 9.904042187981364, 10.684847067503375, 11.646549848966814, 12.582234636149792, 13.39784224948048, 12.463423994647385, 11.46557766075794, 16.48662526996136, 15.585994670642716, 14.55019265319764, 13.56352086284656, 12.667812473306643, 11.857314041423177, 10.93077230397693, 11.764874426931328, 12.714109530946503, 12.546756886768923, 11.4963550454784, 10.56851009606076, 9.79262688350005, 8.97080221238551, 9.729266794474674, 10.721467791778663, 11.635476263157706, 12.470376792942812, 11.515703306299464, 10.548643854187182, 16.743436819321165, 16.573607409443046, 15.58046630707458, 14.604459187159694, 13.637547458297746, 12.796763884237578, 11.873754449589981, 12.790717924626614, 12.605134913057283, 11.653603419460936, 10.640190228514948, 9.596841353045793, 8.822122504609911, 7.920135572967337, 8.743754359250971, 9.668024252339293, 10.704254952165389, 11.538505143065384, 10.58905712077558, 9.656260415952401, 15.763170425444049, 16.70926382578281, 16.5343639679238, 15.563123135659769, 14.654156582890163, 13.794610403801263, 12.874854400257494, 12.470567304671881, 11.629424880706253, 10.629494132361751, 9.57833019208797, 8.61646622018673, 7.77184679520397, 6.875207358111255, 7.777281378847624, 8.734976020343678, 9.689966972751744, 10.594025398553402, 9.822275842525888, 8.863792731504411, 14.89449972136448, 15.858931696276697, 16.328908256934447, 15.404620812996786, 14.471669350528051, 13.428646215624637, 12.425397331572043, 11.473631185825845, 10.637112854338522, 9.697987256603861, 8.639286025905568, 7.648950667630098, 6.761222051009155, 5.855396521826548, 6.764685487636864, 7.776121487841341, 8.654361080542614, 9.596661836973954, 9.001749241685866, 7.974270702903873, 14.22094907162031, 15.264735508331306, 15.399106783529682, 14.387454469164425, 13.429319066386777, 12.377992598493009, 11.493421195466988, 10.483881194257092, 9.568883890050193, 8.640732707571164, 7.689757131177588, 6.679886463520312, 5.699777630193025, 4.90077631679103, 5.823477818935125, 6.725680787978867, 7.6550743863011945, 8.5847106967825, 8.064712553065329, 7.130038124499464, 14.997578648768563, 15.427448235773664, 14.490294922529422, 13.483475132429255, 12.428797977011532, 11.425948159847486, 10.482994982572702, 9.544099675385004, 8.607058402136069, 7.671291818728099, 6.709645397796731, 5.726723641568186, 4.739114824287903, 3.8747610266419907, 4.812620457745359, 5.7924992068333925, 6.753678812893717, 7.717164353931421, 8.666189449221388, 7.738449749311908, 15.794349656397312, 14.76876970046502, 13.739678587217249, 12.750026858447105, 11.675218620045726, 10.759916843160834, 9.757844280070007, 8.733397520012453, 7.693085809036996, 6.71448070018526, 5.8779810779699915, 4.834621098120676, 3.8104118529937603, 2.875888947737491, 3.8295085579576917, 4.818507576882694, 5.833550313466549, 6.813857905975592, 7.828046840689799, 8.690135396848758], [8.834759213893184, 7.846795253109356, 6.935088021952273, 5.875542437167574, 4.93602505556974, 3.9238422458283413, 2.9427669481109877, 2.0157727127560277, 2.901170976226709, 3.839885728878422, 4.76862520340237, 5.726057266161477, 6.799001742315028, 7.808859213878203, 8.74168058225576, 9.733362874708094, 10.78477632939518, 11.74750481284861, 12.807350867260801, 13.87516687896908, 7.832295886745902, 6.902239443559441, 5.929598864067104, 4.9892530538050295, 4.006870842063141, 3.035507993508851, 1.9879905732239274, 0.9465695144653808, 1.961407026880142, 2.966240823319461, 3.966388582589163, 4.95902804533983, 5.907222393286145, 6.912277392740574, 7.862923527373664, 8.841649740290501, 9.881586208461739, 10.912487961805255, 11.89179137947587, 12.907525886945518, 7.10157760475873, 6.1009829735633785, 5.05900096640961, 4.058609556431627, 3.0612176165009424, 2.090018681976185, 1.0441111443201534, 0.0, 0.9588182365598902, 1.9995057887576326, 3.067575893577806, 4.104764715681455, 5.136533895771909, 6.105801537150266, 7.047101881862635, 8.09492785917729, 9.158384759443148, 10.222069544374602, 11.161582001556768, 12.18307522165018, 7.9790277870300415, 6.933271905934944, 5.8919244877204076, 4.8395224832788175, 3.910371278559194, 2.940436136877774, 1.9840461895143031, 1.0017806297258016, 1.9340438573120173, 2.9201721586489473, 3.8775532300303253, 4.905194023145698, 5.928464489629941, 6.904203994560391, 7.876707422722728, 8.84736842858304, 9.900053414733062, 10.914286421202554, 11.934484088852226, 12.874449949280283, 8.837117500134001, 7.787918772798731, 6.8100796937129235, 5.746560256226572, 4.815865122527226, 3.888682560200947, 2.9590046706274284, 2.041001503683505, 2.9625496499428405, 3.9336635139607523, 4.8502156431849395, 5.840740982994012, 6.807257715218823, 7.747991576801289, 8.74258484315484, 9.706421702431065, 10.738215579617618, 11.786083435307592, 12.828617962273002, 13.774058210803041, 9.75406664889137, 8.735991617971694, 7.6985597541667845, 6.696042033228351, 5.79341255410107, 4.888526751115301, 3.9207200210056565, 3.1006871066727784, 3.900718104924656, 4.900933245581894, 5.79200373547778, 6.736198814409599, 7.747573036601915, 8.732170572840404, 9.708530684149888, 10.651688730424777, 11.710536532245877, 12.775410771557397, 13.771758112851446, 14.786003489824733, 10.627029363010502, 9.687072503401698, 8.715878488683003, 7.704329640427175, 6.75935202988918, 5.8557730761069005, 4.897508676834981, 4.109811938254227, 4.942996666957267, 5.887106714068655, 6.788079965819813, 7.681587428464139, 8.692535150585716, 9.716826697128026, 10.64813521731248, 11.700838042740166, 12.724499792897031, 13.667326133271887, 14.671995631192107, 15.60106145971664, 11.557657994990862, 10.684152681798906, 9.74133058347628, 8.71328959354938, 7.792578192924765, 6.897510335436127, 5.9594285116669905, 5.066624891121119, 5.895940477714893, 6.881743002932211, 7.8542280650740395, 8.662895434652638, 9.661050158937485, 10.599254793712598, 11.621703883280317, 12.641487066977492, 13.58890698629636, 14.573192576851635, 15.528438401897256, 16.53798436796255, 12.490076607383259, 11.620925639512462, 10.640910914826215, 9.674059987600247, 8.718401851340692, 7.934081164200167, 6.939428635259417, 6.039986359385414, 6.8980487273682645, 7.873138081955587, 8.874066351898165, 9.68902029899456, 10.668593444636482, 11.563538052079107, 12.518278707088687, 13.44572859314227, 14.379742404556522, 15.345338670628577, 16.39052911309054, 16.345709296372878, 13.54381854321759, 12.588995308270738, 11.5883734066171, 10.606242732896796, 9.663373402224536, 8.879803818991235, 7.943514695181666, 6.994527886232175, 7.8444332678385065, 8.774271103059716, 9.839980647782689, 10.69269139335177, 11.70003427215842, 12.55630776134346, 13.555541035816123, 14.444083663402044, 15.354232386598692, 16.278636572171305, 16.332635617188338, 15.351699356885963, 14.480551072129261, 13.533803478142907, 12.62521006948575, 11.645644205172362, 10.7065511013416, 9.947673599301915, 8.976284462539454, 8.050709003103496, 8.898455298842167, 9.775849201170177, 10.75579199073583, 11.657851881118024, 11.805860659755565, 12.75958860115195, 13.654815947741366, 14.589650497800022, 15.522237088513101, 16.424935194419227, 15.407265183376824, 14.405854691622489, 15.412048682407056, 14.543656031712603, 13.681343978397372, 12.702097092414476, 11.729566594909382, 10.99387213360737, 9.978272754952487, 8.982080638578438, 9.964489994732846, 10.761425298145815, 11.78112587374118, 11.67713266232443, 10.79786197396978, 11.788915141525571, 12.614039359982833, 13.568593795660679, 14.56869405371085, 15.454921095931846, 14.45261259497704, 13.435046787489286, 16.478363733040624, 15.579854465197508, 14.609145162817102, 13.675033398394724, 12.701193425261934, 11.941785262830427, 10.971651075361997, 9.976851921578183, 10.921752508218232, 11.784825627871559, 11.596951906334443, 10.652646604442566, 9.872643850627227, 10.800430154543212, 11.650651956563728, 12.612899631623918, 13.567020707364714, 14.441953393800633, 13.507535138967539, 12.509688805078094, 16.60729275729411, 16.63010581496287, 15.594303797517796, 14.607632007166714, 13.711923617626798, 12.899110422283263, 11.916919283784177, 10.974019390542047, 11.923254494557222, 11.679459725342937, 10.629057884052413, 9.701212934634773, 8.925329722074064, 9.867190178947357, 10.695071683535026, 11.702866679771958, 12.620262334372628, 13.514487937262965, 12.559814450619617, 11.592754998507335, 15.724104088731822, 16.762240579534566, 16.624577451394735, 15.64857033147985, 14.681658602617901, 13.817280005475906, 12.859901429397228, 11.999862888237333, 11.604006524853375, 10.771786923754496, 9.772220156049189, 8.729544191619807, 7.954825343183924, 8.816523539529184, 9.709559248311324, 10.649423140332589, 11.68904102338031, 12.582616287385537, 11.633168265095733, 10.700371560272554, 14.743837694854706, 15.689931095193467, 16.261086831130733, 15.376502493783118, 14.369067187672073, 13.399221319521628, 12.418448318219514, 11.469438916467976, 10.628296492502345, 9.747677636655311, 8.71036011962221, 7.749169058760744, 6.904549633777982, 7.771595324673102, 8.743086267907977, 9.716374908336974, 10.698947971538129, 11.603006397339787, 10.866386986846042, 9.907903875824564, 13.875166990775138, 14.839598965687355, 15.327779868730538, 14.403492424792878, 13.470540962324144, 12.42751782742073, 11.424268943368135, 10.472502797621937, 9.635984466134614, 8.696858868399953, 7.763816537908764, 6.781653506204111, 5.893924889583168, 6.751784488388395, 7.730490376697216, 8.757520375834638, 9.663342079328999, 10.605642835760339, 10.04586038600602, 9.018381847224026, 13.176837927300156, 14.220624364011151, 14.397978395325774, 13.386326080960517, 12.428190678182869, 11.376864210289101, 10.49229280726308, 9.482752806053185, 8.567755501846285, 7.6396043193672565, 6.812002206780194, 5.812589302094325, 4.832480468767038, 5.797164283352878, 6.7892827079954765, 7.734661786765252, 8.664055385087579, 9.593691695568884, 9.10882369738548, 8.174149268819615, 13.953467504448408, 14.426319847569754, 13.489166534325513, 12.482346744225346, 11.427669588807625, 10.424819771643579, 9.481866594368794, 8.542971287181096, 7.60593001393216, 6.67016343052419, 5.823170760517635, 4.859426480142199, 3.8718176628619156, 4.857554530242236, 5.838319023346237, 6.818197772434272, 7.779377378494596, 8.7428629195323, 9.691888014822267, 8.782560893632061, 14.793221268193403, 13.76764131226111, 12.73855019901334, 11.748898470243196, 10.674090231841816, 9.758788454956925, 8.756715891866095, 7.732269131808542, 6.691957420833087, 5.713352311981351, 4.876852689766083, 3.833492709916768, 2.9431146915677733, 3.9015875133383697, 4.8552071235585705, 5.844206142483573, 6.859248879067429, 7.839556471576471, 8.853745406290678, 9.734246541168911], [9.793577450453075, 8.805613489669247, 7.893906258512164, 6.834360673727465, 5.8948432921296305, 4.882660482388232, 3.901585184670878, 2.974590949315918, 1.9619413349022667, 2.9006560875539797, 3.829395562077928, 4.786827624837035, 5.859772100990586, 6.8696295725537615, 7.802450940931318, 8.79413323338365, 9.845546688070737, 10.808275171524167, 11.868121225936356, 12.935937237644636, 8.791114123305793, 7.861057680119332, 6.888417100626994, 5.94807129036492, 4.965689078623032, 3.994326230068742, 2.9468088097838177, 1.905387751025271, 1.0221773855557001, 2.027011181995019, 3.0271589412647213, 4.019798404015388, 4.967992751961703, 5.973047751416132, 6.9236938860492225, 7.90242009896606, 8.942356567137297, 9.973258320480813, 10.952561738151429, 11.968296245621076, 8.06039584131862, 7.059801210123269, 6.017819202969501, 5.017427792991517, 4.020035853060833, 3.0488369185360753, 2.0029293808800435, 0.9588182365598902, 0.0, 1.0406875521977423, 2.1087576570179163, 3.145946479121565, 4.177715659212019, 5.146983300590376, 6.088283645302745, 7.136109622617401, 8.19956652288326, 9.263251307814713, 10.20276376499688, 11.22425698509029, 8.937846023589932, 7.892090142494834, 6.850742724280297, 5.798340719838707, 4.869189515119084, 3.899254373437664, 2.942864426074193, 1.9590335914350214, 0.975225620752127, 1.9613539220890568, 2.9187349934704345, 3.946375786585807, 4.96964625307005, 5.9453857580005005, 6.917889186162837, 7.888550192023151, 8.941235178173173, 9.955468184642665, 10.975665852292337, 11.915631712720394, 9.795935736693892, 8.746737009358622, 7.768897930272814, 6.705378492786462, 5.774683359087116, 4.847500796760837, 3.9178229071873183, 2.957587041511912, 2.0037314133829502, 2.9748452774008616, 3.8913974066250487, 4.881922746434121, 5.848439478658932, 6.7891733402413985, 7.783766606594949, 8.747603465871176, 9.77939734305773, 10.827265198747703, 11.869799725713113, 12.815239974243152, 10.712884885451261, 9.694809854531584, 8.657377990726674, 7.654860269788241, 6.75223079066096, 5.84734498767519, 4.879538257565546, 4.003066053646324, 2.9418998683647657, 3.942115009022003, 4.8331854989178895, 5.7773805778497085, 6.788754800042025, 7.773352336280514, 8.749712447589998, 9.692870493864886, 10.751718295685986, 11.816592534997504, 12.812939876291553, 13.82718525326484, 11.585847599570391, 10.645890739961587, 9.674696725242892, 8.663147876987065, 7.71817026644907, 6.814591312666789, 5.85632691339487, 4.953784752197556, 3.9841784303973764, 4.928288477508764, 5.8292617292599225, 6.7227691919042485, 7.733716914025826, 8.758008460568135, 9.68931698075259, 10.742019806180275, 11.76568155633714, 12.708507896711996, 13.713177394632217, 14.642243223156749, 12.516476231550751, 11.642970918358795, 10.70014882003617, 9.67210783010927, 8.751396429484654, 7.856328571996016, 6.9182467482268795, 5.895406309591072, 4.937122241155002, 5.92292476637232, 6.895409828514149, 7.704077198092748, 8.702231922377594, 9.640436557152707, 10.662885646720426, 11.682668830417601, 12.630088749736469, 13.614374340291745, 14.569620165337366, 15.579166131402662, 13.448894843943147, 12.579743876072351, 11.599729151386104, 10.632878224160136, 9.677220087900581, 8.869391389677883, 7.804291682690797, 6.868767777855367, 5.939230490808374, 6.914319845395696, 7.915248115338275, 8.730202062434671, 9.709775208076593, 10.604719815519218, 11.559460470528798, 12.486910356582381, 13.420924167996633, 14.386520434068688, 15.431710876530651, 16.47241733359449, 14.502636779777479, 13.547813544830626, 12.547191643176989, 11.565060969456685, 10.622191638784425, 9.744666866422616, 8.808377742613047, 7.8233093047021285, 6.885615031278616, 7.815452866499824, 8.881162411222796, 9.733873156791882, 10.741216035598532, 11.59748952478357, 12.596722799256234, 13.485265426842155, 14.395414150038803, 15.319818335611414, 16.384265410071187, 16.31051759344585, 15.43936930868915, 14.492621714702796, 13.584028306045639, 12.60446244173225, 11.665369337901488, 10.812536646733296, 9.838774935332706, 8.879490421573449, 7.9396370622822765, 8.817030964610286, 9.796973754175939, 10.699033644558135, 11.691554499314936, 12.532277933792509, 13.52464986530259, 14.47439361447137, 15.415955722633576, 16.3803033320685, 16.366083419936714, 15.364672928182378, 16.370866918966946, 15.502474268272492, 14.640162214957261, 13.660915328974365, 12.688384831469271, 11.856362606400623, 10.84076322774574, 9.810862057048393, 9.005671758172955, 9.802607061585924, 10.82230763718129, 10.83401747932927, 11.688411112203733, 12.696403870411405, 13.572857596542724, 14.52741203222057, 15.52751229027074, 16.413739332491733, 15.41143083153693, 14.393865024049175, 16.51015041065395, 16.5386727017574, 15.56796339937699, 14.633851634954613, 13.660011661821823, 12.770566681300382, 11.800432493831952, 10.805633340048137, 9.962934271658341, 10.826007391311668, 10.730160066008484, 9.809531421447407, 10.76319298886118, 11.71740242018784, 12.609470193123618, 13.571717868183809, 14.525838943924605, 15.400771630360522, 14.466353375527428, 13.468507041637983, 15.648474520734222, 16.62003853764935, 16.553122034077685, 15.566450243726603, 14.670741854186687, 13.727891840753218, 12.745700702254132, 11.802800809012002, 11.032354140707358, 10.762517263323192, 9.762266043726454, 8.858097751639614, 9.815878860308016, 10.826008415507248, 11.653889920094917, 12.661684916331849, 13.579080570932518, 14.473306173822856, 13.518632687179508, 12.551573235067224, 14.765285852171933, 15.803422342974677, 16.392750615337853, 15.39593680095875, 14.446446670940048, 13.437697203641264, 12.480318627562585, 11.495297796588481, 10.664776883528933, 9.832557282430054, 8.832990514724747, 7.8864290086246465, 8.845374481417878, 9.775341776089075, 10.668377484871215, 11.60824137689248, 12.647859259940201, 13.541434523945428, 12.591986501655624, 11.659189796832445, 13.785019458294817, 14.731112858633578, 15.321857189806291, 14.437272852458676, 13.429837546347631, 12.459991678197186, 11.479218676895073, 10.530209275143534, 9.689066851177904, 8.80844799533087, 7.771130478297769, 6.906053875765583, 7.863367870337873, 8.730413561232993, 9.701904504467867, 10.675193144896864, 11.657766208098021, 12.561824633899679, 11.825205223405932, 10.866722112384455, 12.91634875421525, 13.880780729127466, 14.388550227406096, 13.464262783468437, 12.531311320999702, 11.488288186096288, 10.485039302043694, 9.533273156297495, 8.696754824810172, 7.757629227075512, 6.824586896584322, 5.938538323208951, 6.852743126143059, 7.710602724948286, 8.689308613257108, 9.716338612394528, 10.622160315888891, 11.564461072320231, 11.00467862256591, 9.977200083783917, 12.218019690740267, 13.261806127451262, 13.458748754001332, 12.447096439636075, 11.488961036858427, 10.43763456896466, 9.553063165938639, 8.543523164728743, 7.628525860521844, 6.700374678042815, 5.872772565455753, 4.969474119099164, 5.791298705326929, 6.755982519912768, 7.748100944555367, 8.693480023325144, 9.622873621647472, 10.552509932128777, 10.06764193394537, 9.132967505379506, 13.014237863123967, 13.487090206245313, 12.549936893001071, 11.543117102900904, 10.488439947483183, 9.485590130319137, 8.542636953044353, 7.603741645856655, 6.6667003726077185, 5.7309337891997485, 4.883941119193193, 3.9639704248090255, 4.830635899421806, 5.816372766802127, 6.797137259906128, 7.777016008994161, 8.738195615054485, 9.701681156092189, 10.650706251382156, 9.741379130191952, 13.85399162686896, 12.828411670936667, 11.799320557688896, 10.809668828918753, 9.734860590517373, 8.819558813632483, 7.817486250541654, 6.793039490484101, 5.752727779508645, 4.77412267065691, 3.9376230484416412, 2.894263068592326, 3.901932928127664, 4.86040574989826, 5.81402536011846, 6.803024379043462, 7.818067115627318, 8.79837470813636, 9.812563642850566, 10.693064777728802], [10.834265002650817, 9.846301041866989, 8.930051020123765, 7.870505435339066, 6.930988053741231, 5.8805298957374985, 4.899454598020145, 3.933453106348239, 2.9142236160996364, 1.9755088634479236, 2.9042483379718718, 3.861680400730979, 4.934624876884531, 5.928743563501339, 6.861564931878895, 7.853247224331229, 8.904660679018315, 9.867389162471746, 10.927235216883936, 11.995051228592216, 9.831801675503534, 8.901745232317074, 7.929104652824736, 6.988758842562662, 6.006376630820774, 5.035013782266484, 3.98749636198156, 2.9460753032230134, 2.053505583298344, 1.048671786859025, 2.048819546128727, 3.0414590088793942, 3.9896533568257095, 4.994708356280139, 5.945354490913229, 6.924080703830066, 7.964017172001304, 8.99491892534482, 9.974222343015436, 10.989956850485083, 9.101083393516362, 8.10048876232101, 7.058506755167243, 6.058115345189259, 5.060723405258575, 4.089524470733817, 3.043616933077786, 1.9995057887576326, 1.0406875521977423, 0.0, 1.0680701048201737, 2.105258926923822, 3.1370281070142765, 4.1062957483926334, 5.047596093105002, 6.095422070419658, 7.1588789706855165, 8.22256375561697, 9.162076212799137, 10.183569432892549, 9.978533575787674, 8.932777694692577, 7.89143027647804, 6.83902827203645, 5.909877067316827, 4.939941925635407, 3.9835519782719357, 2.9997211436327635, 2.0159131729498694, 1.0449479772700185, 2.0023290486513963, 3.0299698417667686, 4.053240308251012, 5.028979813181462, 6.001483241343799, 6.972144247204112, 8.024829233354135, 9.039062239823627, 10.0592599074733, 10.999225767901356, 10.836623288891634, 9.787424561556364, 8.809585482470556, 7.746066044984205, 6.815370911284859, 5.88818834895858, 4.958510459385061, 3.985764503236533, 3.0319088751075713, 2.0584393325818233, 2.9749914618060105, 3.965516801615083, 4.932033533839894, 5.87276739542236, 6.867360661775911, 7.831197521052137, 8.862991398238691, 9.910859253928665, 10.953393780894075, 11.898834029424114, 11.753572437649005, 10.735497406729328, 9.698065542924418, 8.695547821985985, 7.7929183428587026, 6.888032539872934, 5.92022580976329, 5.031243515370946, 3.970077330089387, 3.0257090642029647, 3.9167795540988513, 4.86097463303067, 5.872348855222986, 6.856946391461475, 7.833306502770959, 8.776464549045848, 9.835312350866948, 10.900186590178468, 11.896533931472517, 12.910779308445804, 12.626535151768135, 11.68657829215933, 10.715384277440636, 9.703835429184808, 8.758857818646812, 7.855278864864533, 6.897014465592614, 5.981962213922177, 5.012355892121997, 4.011882532689726, 4.912855784440884, 5.80636324708521, 6.817310969206788, 7.841602515749098, 8.772911035933552, 9.825613861361237, 10.849275611518102, 11.792101951892958, 12.796771449813178, 13.72583727833771, 13.557163783748495, 12.683658470556539, 11.740836372233913, 10.712795382307014, 9.792083981682396, 8.89701612419376, 7.95138505332324, 6.923583771315693, 5.965299702879623, 5.006518821553282, 5.9790038836951105, 6.78767125327371, 7.785825977558557, 8.72403061233367, 9.746479701901388, 10.766262885598563, 11.71368280491743, 12.697968395472707, 13.653214220518327, 14.662760186583622, 14.489582396140891, 13.620431428270093, 12.640416703583846, 11.673565776357878, 10.717907640098323, 9.897568851402504, 8.832469144415418, 7.8969452395799875, 6.967407952532994, 5.997913900576658, 6.998842170519237, 7.813796117615632, 8.793369263257553, 9.688313870700181, 10.643054525709761, 11.570504411763345, 12.504518223177596, 13.470114489249651, 14.515304931711615, 15.55601138877545, 15.543324331975223, 14.588501097028368, 13.58787919537473, 12.605748521654426, 11.662879190982167, 10.772844328147237, 9.836555204337667, 8.85148676642675, 7.913792493003236, 6.9926016854639474, 8.051697121932177, 8.817467211972842, 9.824810090779492, 10.681083579964534, 11.680316854437198, 12.568859482023118, 13.479008205219767, 14.403412390792377, 15.46785946525215, 16.49849302839035, 16.48005686088689, 15.533309266900538, 14.62471585824338, 13.645149993929993, 12.70605689009923, 11.840714108457917, 10.866952397057327, 9.90766788329807, 8.967814524006897, 7.994179783574409, 8.974122573140063, 9.782627699739095, 10.775148554495896, 11.615871988973472, 12.608243920483554, 13.557987669652334, 14.49954977781454, 15.463897387249464, 16.393229899063666, 16.40536048038012, 16.612664420025077, 16.54316182047023, 15.680849767155003, 14.701602881172107, 13.729072383667013, 12.884540068125244, 11.86894068947036, 10.839039518773014, 10.033849219897576, 8.979755880550048, 9.999456456145413, 10.736846495245844, 11.768238705415701, 12.586545448599852, 13.549092029634796, 14.503716796270147, 15.453092812616791, 16.48745719956937, 16.45211838373467, 15.434552576246919, 15.593744465834911, 16.65978053257553, 16.608650951574734, 15.674539187152355, 14.700699214019565, 13.798744143025003, 12.828609955556573, 11.833810801772758, 10.991111733382962, 10.003156210275792, 9.805012841902427, 10.711324771774773, 11.664986339188548, 12.619195770515208, 13.56833235015594, 14.53058002521613, 15.484701100956926, 16.412228283223318, 15.507040927725171, 14.509194593835726, 14.732068575915184, 15.70363259283031, 16.497877045108737, 15.478306914376619, 14.47346308122133, 13.45199982234961, 12.498153549069581, 11.595994070177712, 10.767146514718412, 9.837370039217134, 8.837118819620397, 9.75989110196698, 10.717672210635385, 11.754879745501997, 12.612752077127238, 13.62054707336417, 14.53794272796484, 15.46718193898026, 14.559320239377252, 13.592260787264967, 13.848879907352895, 14.88701639815564, 15.467603391231796, 14.470789576852695, 13.521299446833993, 12.512549979535208, 11.55517140345653, 10.570150572482426, 9.739629659422876, 8.907410058323997, 7.90784329061869, 8.788222358952014, 9.747167831745246, 10.704213106083824, 11.627239641903536, 12.5671035339248, 13.606721416972523, 14.535310289102833, 13.632674053853368, 12.699877349030189, 12.868613513475779, 13.81470691381454, 14.396709965700236, 13.51212562835262, 12.504690322241576, 11.53484445409113, 10.554071452789017, 9.605062051037478, 8.763919627071846, 7.883300771224812, 6.8459832541917125, 7.807847226092951, 8.822230027370194, 9.689275718265314, 10.660766661500189, 11.634055301929186, 12.616628365130342, 13.520686790932, 12.865892775603674, 11.907409664582197, 11.999942809396211, 12.964374784308427, 13.46340300330004, 12.539115559362381, 11.606164096893647, 10.56314096199023, 9.559892077937636, 8.60812593219144, 7.771607600704115, 6.832482002969455, 5.899439672478266, 6.889775030753736, 7.81160528317538, 8.669464881980607, 9.648170770289429, 10.67520076942685, 11.581022472921212, 12.523323229352552, 12.045366174763652, 11.017887635981658, 11.177332138542525, 12.22111857525352, 12.533601529895277, 11.52194921553002, 10.563813812752372, 9.512487344858604, 8.627915941832581, 7.618375940622687, 6.703378636415787, 5.775227453936758, 4.9476253413496964, 5.921756400296533, 6.75016086235925, 7.71484467694509, 8.70696310158769, 9.652342180357465, 10.581735778679793, 11.511372089161098, 11.108329486143113, 10.173655057577248, 12.035898467987973, 12.561942982139257, 11.624789668895016, 10.617969878794849, 9.563292723377128, 8.560442906213082, 7.617489728938296, 6.6785944217505975, 5.741553148501662, 4.805786565093692, 3.958793895087137, 4.916252706006395, 5.789498056454128, 6.775234923834448, 7.795006673255395, 8.774885422343429, 9.736065028403754, 10.699550569441458, 11.648575664731425, 10.782066682389694, 12.913105617816537, 11.887525661884245, 10.858434548636474, 9.86878281986633, 8.793974581464951, 7.87867280458006, 6.876600241489231, 5.867892266378045, 4.827580555402589, 3.848975446550853, 3.012475824335585, 3.8465453497896958, 4.860795085159985, 5.858275163247527, 6.811894773467728, 7.8008937923927295, 8.815936528976584, 9.796244121485627, 10.810433056199834, 11.733752329926544], [11.902335107470993, 10.914371146687165, 9.93838926214924, 8.878843677364541, 7.939326295766707, 6.888868137762973, 5.907792840045619, 4.941791348373714, 3.922561858125111, 2.983847105473398, 2.126747098660335, 2.918452182561015, 3.9240856259789596, 4.870853268756408, 5.803674637133964, 6.795356929586298, 7.846770384273385, 8.809498867726816, 9.869344922139007, 10.937160933847286, 10.89987178032371, 9.96981533713725, 8.997174757644911, 8.056828947382837, 7.074446735640948, 6.103083887086658, 5.055566466801734, 4.014145408043188, 3.0618438253238183, 2.0570100288844992, 1.0568622696147971, 1.9835687141344631, 2.9317630620807784, 3.9368180615352077, 4.887464196168298, 5.866190409085135, 6.906126877256373, 7.937028630599889, 8.916332048270505, 9.932066555740152, 10.169153498336538, 9.168558867141186, 8.126576859987418, 7.126185450009434, 6.128793510078749, 5.157594575553992, 4.11168703789796, 3.0675758935778066, 2.1087576570179163, 1.0680701048201737, 0.0, 1.0371888221036485, 2.068958002194103, 3.03822564357246, 3.9795259882848293, 5.027351965599484, 6.090808865865343, 7.1544936507967964, 8.094006107978963, 9.115499328072374, 11.018182535999305, 9.972426654904208, 8.931079236689671, 7.878677232248081, 6.949526027528457, 5.9795908858470375, 5.0232009384835665, 3.993567366459251, 3.0097593957763564, 2.023631094439427, 1.0662500230580487, 2.0884166122064496, 3.054524185112866, 3.9805616813330578, 4.953065109495394, 5.9237261153557075, 6.97641110150573, 7.990644107975222, 9.010841775624895, 9.950807636052952, 11.876272249103266, 10.827073521767996, 9.849234442682189, 8.785715005195836, 7.85501987149649, 6.927837309170211, 5.998159419596692, 4.964447620405942, 4.01059199227698, 3.037122449751232, 2.0389124362126627, 3.0239635720547637, 3.9904803042795742, 4.93121416586204, 5.925807432215591, 6.889644291491817, 7.921438168678371, 8.9223876731104, 9.96492220007581, 10.902081055595522, 12.793221397860636, 11.775146366940959, 10.737714503136049, 9.735196782197615, 8.832567303070334, 7.927681500084565, 6.95987476997492, 6.009926632540354, 4.948760447258795, 3.9845755319454232, 2.9807005285055035, 3.924895607437322, 4.936269829629639, 5.920867365868128, 6.897227477177612, 7.8403855234525, 8.8992333252736, 9.958402111956634, 10.954749453250683, 11.95963779222845, 13.666184111979765, 12.726227252370961, 11.755033237652267, 10.74348438939644, 9.798506778858444, 8.894927825076163, 7.9366634258042446, 6.960645331091586, 5.991039009291406, 4.970749000432185, 3.976776758847536, 4.870284221491862, 5.88123194361344, 6.90552349015575, 7.8368320103402045, 8.88953483576789, 9.913196585924755, 10.85602292629961, 11.860692424219831, 12.789758252744363, 14.596812743960125, 13.72330743076817, 12.780485332445544, 11.752444342518645, 10.831732941894028, 9.936665084405389, 8.93006817049265, 7.9022668884851015, 6.9439828200490314, 5.965385289295741, 5.042924858101762, 5.851592227680362, 6.8497469519652086, 7.787951586740322, 8.81040067630804, 9.830183860005215, 10.777603779324084, 11.76188936987936, 12.71713519492498, 13.726681160990275, 15.529231356352522, 14.660080388481726, 13.680065663795478, 12.71321473656951, 11.757556600309956, 10.87625196857191, 9.811152261584825, 8.875628356749395, 7.946091069702403, 6.956780368319117, 6.0627631449258885, 6.877717092022284, 7.857290237664205, 8.75223484510683, 9.70697550011641, 10.634425386169994, 11.568439197584246, 12.5340354636563, 13.579225906118264, 14.6199323631821, 16.582973292186853, 15.628150057240001, 14.627528155586363, 13.645397481866059, 12.7025281511938, 11.751527445316643, 10.815238321507074, 9.830169883596156, 8.881305988427615, 7.951468153206406, 7.115618096338828, 7.881388186379494, 8.888731065186144, 9.745004554371183, 10.744237828843847, 11.632780456429767, 12.542929179626416, 13.467333365199027, 14.5317804396588, 15.562414002796999, 16.516699001124145, 16.57295822711217, 15.664364818455013, 14.684798954141625, 13.745705850310863, 12.819397225627323, 11.845635514226734, 10.886351000467476, 9.935328019431276, 8.953046251316866, 8.103552623054929, 8.846548674145748, 9.839069528902549, 10.679792963380121, 11.672164894890203, 12.621908644058983, 13.563470752221189, 14.527818361656113, 15.457150873470313, 16.458561365224647, 15.676585394431726, 16.744885545297585, 16.720498727366635, 15.74125184138374, 14.768721343878646, 13.86322318529465, 12.847623806639767, 11.81772263594242, 11.001362715321955, 9.938622348292505, 9.12888650606028, 9.800767469652497, 10.832159679822354, 11.6504664230065, 12.613013004041445, 13.567637770676797, 14.51701378702344, 15.551378173976019, 16.495897151449135, 16.474201536458548, 14.657665440241564, 15.723701506982184, 16.478725869770958, 15.54461410534858, 14.506376242062107, 13.543033564002418, 12.577130339691733, 11.726870121341548, 10.999917921916362, 10.062858878604645, 10.145578790448539, 10.825253527534361, 11.757377803164907, 12.63895140998886, 13.57640040746055, 14.523331934713557, 15.518687133369577, 16.494794263492683, 16.5466898879368, 15.548843554047357, 13.795989550321837, 14.767553567236963, 15.63158562730871, 14.612015496576591, 13.607171663421303, 12.585708404549582, 11.631862131269553, 10.729702652377684, 9.930498052867344, 9.059868799905598, 9.845457061645872, 10.768229343992456, 11.72601045266086, 12.763217987527472, 13.621090319152712, 14.628885315389644, 15.546280969990313, 16.475520181005734, 15.598969199588883, 14.631909747476598, 12.852126933524303, 13.890263424327047, 14.60131197343177, 13.60449815905267, 12.655008029033965, 11.64625856173518, 10.688879985656502, 9.703859154682398, 8.902981197571808, 8.12990881901246, 8.916181532644165, 9.79656060097749, 10.755506073770722, 11.712551348109299, 12.63557788392901, 13.575441775950274, 14.615059658997996, 15.543648531128307, 14.672323014064999, 13.73952630924182, 11.871860539647187, 12.817953939985948, 13.53041854790021, 12.645834210552595, 11.638398904441548, 10.668553036291103, 9.68778003498899, 8.73877063323745, 7.927271165220779, 7.105799531913275, 7.854321496217187, 8.816185468118427, 9.830568269395668, 10.697613960290788, 11.669104903525662, 12.64239354395466, 13.624966607155816, 14.529025032957474, 13.905541735815307, 12.94705862479383, 10.951524677547807, 11.915956652460023, 12.597111585500015, 11.672824141562355, 10.73987267909362, 9.696849544190204, 8.69360066013761, 7.741834514391414, 6.934959138853047, 6.054980763657918, 6.907777914503741, 7.89811327277921, 8.819943525200854, 9.677803124006081, 10.656509012314903, 11.683539011452323, 12.589360714946686, 13.531661471378026, 13.085015134975283, 12.05753659619329, 10.109262033722352, 11.153048470433347, 11.667310112095251, 10.655657797729994, 9.697522394952346, 8.646195927058576, 7.761624524032555, 6.752084522822661, 5.866730174564719, 4.997726214625221, 5.955963583375171, 6.9300946423220084, 7.7584991043847245, 8.723182918970563, 9.715301343613163, 10.660680422382939, 11.590074020705266, 12.519710331186571, 12.176399590963289, 11.241725162397424, 10.978008173243044, 11.695651564339233, 10.758498251094991, 9.751678460994825, 8.697001305577102, 7.694151488413055, 6.75119831113827, 5.812303003950571, 4.875261730701635, 4.028285325782155, 4.967132137112611, 5.92459094803187, 6.797836298479602, 7.783573165859923, 8.80334491528087, 9.783223664368904, 10.74440327042923, 11.707888811466933, 12.6569139067569, 11.85013678720987, 11.855215323071608, 10.829635367139316, 9.800544253891545, 8.810892525121398, 7.736084286720019, 6.820782509835129, 5.8187099467443, 4.857353015472475, 3.9476827560983914, 3.071474207239316, 4.020814066361059, 4.85488359181517, 5.86913332718546, 6.866613405273002, 7.820233015493203, 8.809232034418205, 9.82427477100206, 10.804582363511102, 11.81877129822531, 12.80182243474672], [12.728443131549383, 11.713059432182433, 10.721977054416262, 9.662431469631564, 8.722914088033729, 7.672455930029996, 6.691380632312643, 5.7253791406407375, 4.706149650392135, 3.767434897740422, 2.838695423216474, 1.8812633604573668, 2.8868968038753113, 3.833664446652759, 4.7664858150303155, 5.758168107482649, 6.809581562169736, 7.772310045623167, 8.832156100035355, 9.899972111743635, 11.876172987363512, 10.946116544177052, 9.973475964684713, 9.033130154422638, 8.05074794268075, 7.047776901948735, 6.000259481663811, 4.958838422905264, 3.944000910490503, 2.939167114051184, 1.9390193547814818, 0.9463798920308147, 1.8945742399771301, 2.899629239431559, 3.8502753740646494, 4.8290015869814855, 5.868938055152723, 6.89983980849624, 7.879143226166855, 8.894877733636502, 11.206342320440186, 10.205747689244834, 9.163765682091066, 8.163374272113082, 7.165982332182397, 6.194783397657639, 5.148875860001608, 4.104764715681455, 3.1459464791215646, 2.105258926923822, 1.0371888221036485, 0.0, 1.0317691800904545, 2.0010368214688112, 2.9423371661811806, 3.990163143495836, 5.053620043761694, 6.117304828693149, 7.056817285875315, 8.078310505968727, 12.030801096159427, 10.98504521506433, 9.943697796849793, 8.891295792408204, 7.962144587688582, 6.992209446007162, 6.035819498643691, 5.006185926619375, 4.022377955936481, 3.036249654599551, 2.0788685832181732, 1.051227790102801, 2.0173353630092175, 2.943372859229409, 3.915876287391745, 4.886537293252059, 5.939222279402081, 6.9534552858715735, 7.9736529535212455, 8.913618813949302, 12.88889080926339, 11.83969208192812, 10.861853002842313, 9.79833356535596, 8.867638431656614, 7.940455869330335, 7.010777979756816, 5.977066180566066, 5.023210552437105, 4.049741009911356, 2.99005794343977, 1.9867747499511155, 2.953291482175926, 3.8940253437583925, 4.888618610111943, 5.852455469388169, 6.884249346574723, 7.88519885100675, 8.92773337797216, 9.864892233491872, 13.80583995802076, 12.787764927101083, 11.750333063296173, 10.74781534235774, 9.845185863230459, 8.94030006024469, 7.972493330135045, 7.022545192700479, 5.96137900741892, 4.935721039172531, 3.931846035732611, 2.9981975891312267, 3.918335274228949, 4.895238896144624, 5.871599007454108, 6.8147570537289965, 7.873604855550097, 8.921213289852982, 9.917560631147031, 10.922448970124801, 14.67880267213989, 13.738845812531085, 12.767651797812391, 11.756102949556563, 10.811125339018568, 9.907546385236289, 8.949281985964369, 7.915712001586997, 6.946105679786817, 5.921894507659292, 4.909983085266701, 3.9435862031857667, 4.86329738821275, 5.88758893475506, 6.818897454939514, 7.871600280367199, 8.895262030524064, 9.83808837089892, 10.84275786881914, 11.771823697343672, 15.60943130412025, 14.735925990928294, 13.793103892605668, 12.76506290267877, 11.844351502054153, 10.924607292116805, 9.885134840988062, 8.857333558980514, 7.899049490544443, 6.910841129393706, 5.9010909655918855, 4.9248942093742665, 5.84856075305682, 6.7867653878319345, 7.79246612090735, 8.812249304604526, 9.759669223923394, 10.74395481447867, 11.69920063952429, 12.708746605589585, 16.541849916512646, 15.67269894864185, 14.692684223955602, 13.725833296729634, 12.77017516047008, 11.831318639067323, 10.766218932080237, 9.830695027244808, 8.901157740197814, 7.902236208417082, 6.920929252416012, 5.951019073716188, 6.885490533511048, 7.751048646198444, 8.705789301208025, 9.633239187261609, 10.56725299867586, 11.532849264747915, 12.578039707209879, 13.618746164273714, 16.488108011417243, 16.625432550439807, 15.624810648786168, 14.630734455062683, 13.687865124390424, 12.706594115812056, 11.770304992002487, 10.785236554091568, 9.82676182852558, 8.896923993304371, 7.900680357488967, 6.954690168073398, 7.928435225587701, 8.743818355462798, 9.743051629935461, 10.631594257521382, 11.54174298071803, 12.466147166290641, 13.530594240750414, 14.561227803888613, 15.515512802215762, 16.462260396202115, 16.661647311654818, 15.670135927338249, 14.702829362452555, 13.774463896122736, 12.800702184722146, 11.841417670962889, 10.880783859529242, 9.86855767377072, 8.888614884205067, 7.919850655839651, 8.912371510596452, 9.678606764471736, 10.670978695981818, 11.620722445150598, 12.562284553312804, 13.526632162747728, 14.455964674561928, 15.457375166316263, 14.67539919552334, 15.7419653850664, 16.410022687101495, 15.467556345402503, 14.440814250311012, 13.456072634581895, 12.591284002510504, 11.684452582237645, 10.9199916132981, 10.854133770746358, 9.867597905767317, 8.8740694513464, 9.905461661516258, 10.649280224098115, 11.61182680513306, 12.566451571768411, 13.515827588115055, 14.550191975067634, 15.49471095254075, 16.428183070449464, 13.639730884840874, 14.705766951581495, 15.441537047667312, 14.507425283244935, 13.46918741995846, 12.505844741898771, 11.539941517588087, 10.6896812992379, 9.962729099812714, 10.774807203160783, 10.884290190155577, 9.898555509228265, 10.83067978485881, 11.637765211080474, 12.575214208552165, 13.522145735805172, 14.517500934461191, 15.493608064584299, 16.428026319417395, 16.56146211420748, 12.778054994921145, 13.749619011836272, 14.594396805205061, 13.574826674472945, 12.569982841317657, 11.548519582445936, 10.594673309165907, 9.692513830274036, 8.893309230763697, 9.771817124461736, 10.563928523404465, 10.849989179036058, 11.777993913411974, 12.571005186676329, 13.525192354018802, 14.447227792993322, 15.44024683682137, 16.438654408827357, 16.611587759749007, 15.644528307636723, 11.814938111420654, 12.853074602223398, 13.564123151328122, 12.567309336949021, 11.617819206930319, 10.609069739631535, 9.651691163552856, 8.66667033257875, 7.8657923754681605, 8.841857143568598, 9.634652994402758, 10.515032062736083, 11.473977535529315, 12.431022809867892, 13.366819997451968, 14.324517658058605, 15.364135541106327, 16.32723632339533, 15.684941574225123, 14.752144869401944, 10.834671717543538, 11.780765117882298, 12.493229725796562, 11.608645388448947, 10.601210082337902, 9.631364214187457, 8.650591212885343, 7.701581811133804, 6.890082343117131, 7.817747856469413, 8.57279295797578, 9.53465692987702, 10.569019491310636, 11.481201752557812, 12.452692695792686, 13.425981336221684, 14.40855439942284, 15.312612825224498, 14.918160295975431, 13.959677184953954, 9.914335855444158, 10.878767830356374, 11.559922763396367, 10.635635319458707, 9.702683856989973, 8.659660722086556, 7.6564118380339625, 6.704645692287766, 5.8977703167493996, 6.766929088214056, 7.626249376262333, 8.616584734537803, 9.590929465980102, 10.461390916273105, 11.440096804581927, 12.467126803719347, 13.37294850721371, 14.31524926364505, 14.097633695135405, 13.070155156353412, 9.072073211618704, 10.1158596483297, 10.630121289991603, 9.618468975626346, 8.660333572848698, 7.609007104954929, 6.724435701928908, 5.714895700719013, 4.829541352461071, 5.709674539181359, 6.674435045133763, 7.674029049389887, 8.542086896651748, 9.506770711237587, 10.498889135880187, 11.444268214649963, 12.37366181297229, 13.303298123453596, 13.213588413066937, 12.278913984501072, 9.940819351139393, 10.658462742235585, 9.721309428991344, 8.714489638891177, 7.659812483473454, 6.656962666309407, 5.7140094890346225, 4.775114181846924, 3.8380729085979874, 4.740233650338293, 5.685603598871204, 6.6685253550997485, 7.5814240907466255, 8.567160958126946, 9.586932707547893, 10.566811456635927, 11.527991062696252, 12.491476603733956, 13.440501699023923, 12.826437994249671, 10.818026500967958, 9.792446545035666, 8.763355431787895, 7.77370370301775, 6.6988954646163705, 5.78359368773148, 4.781521124640651, 3.820164193368826, 2.910493933994743, 3.783422531795455, 4.739285528119652, 5.638471384082194, 6.652721119452483, 7.650201197540025, 8.603820807760226, 9.592819826685227, 10.607862563269082, 11.588170155778124, 12.602359090492332, 13.670077687532535], [13.760212311639838, 12.744828612272888, 11.753746234506718, 10.694200649722019, 9.754683268124184, 8.70422511012045, 7.723149812403097, 6.757148320731192, 5.737918830482589, 4.799204077830876, 3.870464603306928, 2.913032540547821, 2.0301518089826693, 2.9417302964806527, 3.8745516648582092, 4.828480440194051, 5.863708060689067, 6.8264365441424975, 7.886282598554687, 8.948249304181962, 12.907942167453966, 11.977885724267505, 11.005245144775166, 10.064899334513091, 9.082517122771204, 8.079546082039188, 7.032028661754264, 5.990607602995718, 4.975770090580957, 3.970936294141638, 2.9707885348719363, 1.9781490721212691, 1.0378292450844884, 2.0076950892594527, 2.8849976038786007, 3.8637238167954373, 4.9036602849666755, 5.934562038310192, 6.913865455980807, 7.929599963450454, 12.238111500530641, 11.23751686933529, 10.195534862181521, 9.195143452203537, 8.197751512272852, 7.226552577748094, 6.180645040092062, 5.136533895771909, 4.177715659212019, 3.1370281070142765, 2.068958002194103, 1.0317691800904545, 0.0, 0.969267641378357, 1.9105679860907263, 2.9583939634053817, 4.02185086367124, 5.0855356486026935, 6.02504810578486, 7.046541325878272, 12.988409955459636, 11.942654074364539, 10.901306656150002, 9.848904651708411, 8.919753446988787, 7.949818305307367, 6.9934283579438965, 5.963794785919581, 4.979986815236686, 3.993858513899757, 3.036477442518379, 2.0088366494030065, 0.9855661829187632, 1.9116036791389548, 2.8841071073012907, 3.8547681131616045, 4.907453099311627, 5.921686105781119, 6.941883773430792, 7.881849633858849, 13.807944011561487, 12.758745284226217, 11.78090620514041, 10.717386767654057, 9.78669163395471, 8.85950907162843, 7.929831182054912, 6.890991897235701, 5.93713626910674, 4.963666726580992, 3.8989653159668207, 2.895682122478166, 1.9291653902533556, 2.8698992518358217, 3.864492518189372, 4.828329377465598, 5.860123254652152, 6.853429670916296, 7.895964197881706, 8.833123053401419, 14.724893160318857, 13.70681812939918, 12.66938626559427, 11.666868544655836, 10.764239065528555, 9.859353262542784, 8.89154653243314, 7.936470909370115, 6.875304724088556, 5.844628411699582, 4.840753408259662, 3.905583404498695, 2.8942091823063785, 3.8711128042220535, 4.8474729155315375, 5.790630961806426, 6.849478763627525, 7.889444109762529, 8.885791451056578, 9.890679790034348, 15.597855874437986, 14.657899014829182, 13.686705000110488, 12.67515615185466, 11.730178541316665, 10.826599587534384, 9.868335188262463, 8.824619374114048, 7.855013052313868, 6.8308018801863435, 5.817368900634169, 4.850972018553235, 3.83917129629018, 4.863462842832489, 5.7947713630169435, 6.847474188444628, 7.871135938601493, 8.81396227897635, 9.81863177689657, 10.747697605421102, 16.528484506418348, 15.65497919322639, 14.712157094903764, 13.684116104976866, 12.76340470435225, 11.833514664643856, 10.794042213515112, 9.766240931507564, 8.807956863071494, 7.808536305438537, 6.798786141636716, 5.822589385419097, 4.824434661134251, 5.762639295909365, 6.768340028984779, 7.788123212681954, 8.735543132000823, 9.719828722556098, 10.675074547601719, 11.684620513667014, 16.403830357037624, 16.591752150939946, 15.6117374262537, 14.644886499027733, 13.689228362768178, 12.740226011594373, 11.675126304607288, 10.739602399771858, 9.810065112724866, 8.799931384461912, 7.818624428460843, 6.840937587230399, 5.861364441588478, 6.726922554275874, 7.681663209285455, 8.609113095339039, 9.54312690675329, 10.508723172825345, 11.553913615287309, 12.594620072351145, 15.463981919494675, 16.382942474151715, 16.533718021313216, 15.539641827589733, 14.596772496917474, 13.615501488339106, 12.679212364529537, 11.694143926618619, 10.724457004570409, 9.7946191693492, 8.790598871003176, 7.844608681587609, 6.904309133665131, 7.719692263540228, 8.718925538012892, 9.607468165598812, 10.51761688879546, 11.442021074368071, 12.506468148827844, 13.537101711966043, 14.491386710293192, 15.438134304279545, 16.459236867427634, 15.616750444207199, 14.590710606240389, 13.66234513991057, 12.727495331768107, 11.76821081800885, 11.77847903557407, 10.75847618728493, 9.778533397719277, 8.809769169353862, 7.95043856786428, 8.654480672549166, 9.646852604059248, 10.596596353228026, 11.538158461390235, 12.50250607082516, 13.431838582639358, 14.433249074393693, 13.651273103600772, 14.717839293143829, 15.562409287397758, 14.619942945698766, 13.593200850607275, 12.608459234878158, 11.743670602806766, 10.836839182533907, 11.814744262783675, 11.744052284260569, 10.757516419281528, 9.763987964860611, 8.958437253650064, 9.625154132175545, 10.58770071321049, 11.542325479845841, 12.491701496192487, 13.526065883145066, 14.470584860618182, 15.404056978526896, 12.615604792918303, 13.681640859658923, 14.593923647963575, 13.659811883541197, 12.621574020254723, 11.658231342195034, 10.69232811788435, 9.842067899534163, 10.85748174929829, 11.737897620222766, 11.774208703669787, 10.788474022742475, 9.883655376992618, 10.613639119157904, 11.551088116629595, 12.498019643882602, 13.493374842538623, 14.46948197266173, 15.403900227494825, 16.329414960938088, 11.753928902998576, 12.725492919913702, 13.721310941289659, 12.727213274769207, 11.72236944161392, 10.700906182742198, 9.74705990946217, 8.844900430570299, 9.794135534585473, 10.734907541523718, 11.59569770349492, 11.739907692550268, 10.83096950554578, 11.54687909475376, 12.501066262096233, 13.423101701070753, 14.416120744898798, 15.414528316904788, 16.407197623136806, 16.563581509934817, 10.7831689313302, 11.821305422132944, 12.691037287412717, 11.694223473033617, 10.770205807226581, 9.761456339927797, 8.804077763849119, 7.8190569328750135, 8.783809944687631, 9.824571156449709, 10.666422174493214, 11.546801242826538, 11.80147388443592, 12.597545734171932, 13.486578697319935, 14.444276357926572, 15.347342055891115, 16.346399966782215, 16.60399477652322, 15.67119807170004, 9.802902537453084, 10.748995937791845, 11.620143861881157, 10.735559524533542, 9.753596682634164, 8.783750814483719, 7.802977813181606, 6.853968411430067, 7.885668362434384, 8.849517036559869, 9.604562138066235, 10.566426109967475, 11.60078867140109, 12.512970932648267, 13.484461875883142, 14.457750516312139, 15.440323579513295, 16.34438200531495, 15.837213498273528, 14.87873038725205, 8.882566675353704, 9.84699865026592, 10.686836899480962, 9.762549455543303, 8.829597993074568, 7.812047322382821, 6.808798438330227, 5.857032292584029, 6.8933563360666525, 7.798698268304511, 8.658018556352788, 9.648353914628258, 10.622698646070557, 11.49316009636356, 12.471865984672382, 13.498895983809803, 14.404717687304165, 15.347018443735505, 15.055242554435614, 14.02776401565362, 8.04030403152825, 9.084090468239244, 9.757035426076198, 8.745383111710941, 7.787247708933293, 6.7613937052511925, 5.876822302225172, 4.867282301015276, 5.856010499255207, 6.741443719271814, 7.706204225224218, 8.705798229480342, 9.573856076742203, 10.538539891328043, 11.530658315970642, 12.476037394740418, 13.405430993062746, 14.33506730354405, 14.245357593157392, 13.310683164591527, 8.975541580953346, 9.785376878320179, 8.848223565075937, 7.84140377497577, 6.786726619558048, 5.80934926660567, 4.866396089330886, 3.9275007821431873, 4.864542055392123, 5.7720028304287485, 6.717372778961659, 7.700294535190204, 8.61319327083708, 9.598930138217401, 10.618701887638348, 11.598580636726382, 12.559760242786707, 13.523245783824411, 14.472270879114378, 13.858207174340125, 9.87215299948729, 8.846573043554997, 7.817481930307226, 6.844016035729152, 5.7692077973277724, 4.891659537559374, 3.8895869744685454, 2.963419198476184, 3.9422631140851974, 4.81519171188591, 5.771054708210107, 6.670240564172648, 7.684490299542937, 8.68197037763048, 9.63558998785068, 10.624589006775683, 11.639631743359537, 12.61993933586858, 13.634128270582787, 14.70184686762299], [14.729479953018195, 13.714096253651245, 12.723013875885075, 11.663468291100376, 10.723950909502541, 9.673492751498808, 8.692417453781454, 7.726415962109549, 6.707186471860946, 5.768471719209233, 4.839732244685285, 3.882300181926178, 2.9823201266654715, 1.9724626551022957, 2.9052840234798523, 3.859212798815694, 4.89444041931071, 5.8571689027641405, 6.91701495717633, 7.978981662803605, 13.877209808832323, 12.947153365645862, 11.974512786153523, 11.034166975891448, 10.051784764149561, 9.048813723417545, 8.001296303132621, 6.959875244374075, 5.945037731959314, 4.940203935519995, 3.9400561762502933, 2.947416713499626, 2.007096886462845, 1.0384274478810958, 1.9157299625002437, 2.8944561754170803, 3.9343926435883185, 4.965294396931835, 5.94459781460245, 6.960332322072097, 13.207379141908998, 12.206784510713646, 11.164802503559878, 10.164411093581894, 9.167019153651209, 8.195820219126452, 7.149912681470419, 6.105801537150266, 5.146983300590376, 4.1062957483926334, 3.03822564357246, 2.0010368214688112, 0.969267641378357, 0.0, 0.9413003447123692, 1.9891263220270248, 3.052583222292883, 4.1162680072243365, 5.055780464406503, 6.077273684499915, 13.920919315231918, 12.875163434136821, 11.833816015922284, 10.781414011480695, 9.852262806761072, 8.882327665079652, 7.925937717716181, 6.8963041456918655, 5.912496175008971, 4.926367873672041, 3.9689868022906634, 2.941346009175291, 1.918075542691048, 0.9423360377605978, 1.9148394659229337, 2.8855004717832475, 3.93818545793327, 4.952418464402762, 5.972616132052435, 6.912581992480492, 14.740453371333773, 13.691254643998503, 12.713415564912696, 11.649896127426343, 10.719200993726997, 9.792018431400717, 8.862340541827198, 7.823501257007987, 6.8696456288790255, 5.896176086353277, 4.831474675739106, 3.828191482250451, 2.8616747500256405, 1.9269101194794236, 2.921503385832974, 3.8853402451092, 4.917134122295753, 5.884162029537939, 6.926696556503349, 7.863855412023063, 15.657402520091143, 14.639327489171466, 13.601895625366556, 12.599377904428122, 11.696748425300841, 10.79186262231507, 9.824055892205426, 8.8689802691424, 7.8078140838608405, 6.777137771471867, 5.773262768031946, 4.83809276427098, 3.8267185420786634, 2.9281236718656554, 3.9044837831751398, 4.847641829450028, 5.906489631271128, 6.920176468384172, 7.916523809678221, 8.921412148655993, 16.530365234210272, 15.590408374601468, 14.619214359882774, 13.607665511626946, 12.662687901088951, 11.75910894730667, 10.80084454803475, 9.757128733886333, 8.787522412086153, 7.763311239958628, 6.7498782604064544, 5.78348137832552, 4.771680656062465, 3.984368608283415, 4.883064142057938, 5.918154003094835, 6.9418157532517, 7.884642093626557, 8.889311591546777, 9.81837742007131, 16.450907354190107, 16.587488552998675, 15.64466645467605, 14.616625464749152, 13.695914064124537, 12.76602402441614, 11.726551573287397, 10.698750291279849, 9.740466222843779, 8.741045665210821, 7.731295501409001, 6.755098745191382, 5.756944020906535, 5.010608137436526, 5.856632808025774, 6.876415991722949, 7.823835911041817, 8.808121501597093, 9.763367326642713, 10.772913292708008, 15.573291940202411, 16.61098337268785, 16.544246786025987, 15.577395858800019, 14.621737722540464, 13.67273537136666, 12.607635664379574, 11.672111759544144, 10.74257447249715, 9.732440744234196, 8.751133788233126, 7.773446947002683, 6.793873801360762, 5.974891395803035, 6.851124792450243, 7.778574678503826, 8.712588489918078, 9.678184755990133, 10.723375198452096, 11.740954020506718, 14.63344350265946, 15.552404057316503, 16.553025958970142, 15.720786030941987, 14.777916700269728, 13.85874618129943, 12.922457057489861, 12.626653286390905, 11.656966364342694, 10.727128529121485, 9.72310823077546, 8.777118041359893, 7.836818493437415, 6.967661105067389, 7.888387121177679, 8.7769297487636, 9.687078471960248, 10.611482657532859, 11.675929731992632, 12.706563295130831, 13.66084829345798, 14.607595887444333, 15.62869845059242, 14.75843726887391, 13.734739001152665, 12.806373534822846, 11.889687290132073, 12.720379135691655, 12.710988395346355, 11.690985547057215, 10.711042757491562, 9.742278529126146, 8.882947927636565, 7.902449514076326, 8.894821445586407, 9.844565194755187, 10.707620044555021, 11.671967653989945, 12.601300165804146, 13.60271065755848, 12.770212622592865, 13.806132072184823, 14.631645479508109, 13.701984381631796, 12.73722924551955, 11.752487629790433, 10.88769899771904, 11.78900750021671, 12.766912580466478, 12.676561644032853, 11.690025779053812, 10.696497324632896, 9.881115731910377, 8.873122973702705, 9.835669554737649, 10.790294321373, 11.661163079357273, 12.695527466309851, 13.640046443782968, 14.573518561691683, 11.703897571959297, 12.769933638699918, 13.663159840073925, 12.729048075651548, 11.765602415166999, 10.80225973710731, 9.836356512796623, 10.794236217216966, 11.809650066981092, 12.690065937905569, 12.706718063442072, 11.72098338251476, 10.80633385525293, 9.861607960685063, 10.799056958156754, 11.745988485409761, 12.662836425703409, 13.638943555826517, 14.57336181065961, 15.498876544102876, 10.79345767203829, 11.765021688953416, 12.7520432999113, 11.796449466879558, 10.866397836526195, 9.844934577654474, 8.891088304374444, 9.797068748253102, 10.746303852268277, 11.687075859206521, 12.564965344873276, 12.672417052322553, 11.753647983806093, 10.794847936280918, 11.749035103623392, 12.671070542597912, 13.609594798695495, 14.583989900069573, 15.576659206301592, 16.453360593251066, 9.813901289951843, 10.852037780754587, 11.72176964603436, 10.72495583165526, 9.904707904288015, 8.905484734840073, 7.9481061587613935, 8.771225250557816, 9.735978262370434, 10.776739474132512, 11.635689815871569, 12.516068884204893, 12.724152362696232, 11.845514575699092, 12.734547538847094, 13.692245199453732, 14.540816109687812, 15.515861549947001, 16.465309572236805, 16.603707431472326, 8.833634896074727, 9.779728296413488, 10.6508762205028, 9.766291883155185, 8.888098779695598, 7.918252911545153, 6.94700620809388, 7.806136729112869, 8.837836680117187, 9.818784677938226, 10.57382977944459, 11.53569375134583, 12.570056312779446, 12.890442790555174, 13.701020519250442, 14.625293431449347, 15.555104089101457, 16.530485048117832, 16.769722858045814, 15.811239747024336, 7.913299033975347, 8.877731008887563, 9.717569258102605, 8.793281814164946, 7.860330351696211, 6.864561930237283, 5.932521382106171, 6.809200610266831, 7.845524653749456, 8.767965909682868, 9.627286197731143, 10.617621556006613, 11.591966287448912, 12.462427737741919, 13.44113362605074, 14.468163625188161, 15.373985328682524, 16.316286085113862, 15.987751914207896, 14.960273375425903, 7.071036390149892, 8.114822826860888, 8.787767784697841, 7.776115470332584, 6.817980067554936, 5.811992067592374, 5.000545246001116, 5.819450618698078, 6.808178816938009, 7.710711360650171, 8.675471866602575, 9.675065870858699, 10.543123718120562, 11.507807532706401, 12.499925957349001, 13.445305036118777, 14.374698634441105, 15.30433494492241, 15.214625234535749, 14.279950805969884, 8.006273939574989, 8.816109236941822, 7.87895592369758, 6.872136133597413, 5.817458978179691, 4.859947628946852, 3.979549015436903, 4.879669099825989, 5.816710373074924, 6.7412704718071055, 7.686640420340016, 8.66956217656856, 9.582460912215438, 10.56819777959576, 11.587969529016705, 12.567848278104739, 13.529027884165064, 14.492513425202768, 15.441538520492735, 14.827474815718482, 8.902885358108932, 7.87730540217664, 6.848214288928869, 5.874748394350795, 4.7999401559494155, 3.9223918961810167, 2.9203193330901884, 3.915587516158986, 4.911530755463554, 5.784459353264267, 6.740322349588464, 7.639508205551005, 8.653757940921295, 9.651238019008836, 10.604857629229038, 11.59385664815404, 12.608899384737894, 13.589206977246937, 14.603395911961144, 15.671114509001347], [15.66038833934028, 14.64500463997333, 13.653922262207159, 12.59437667742246, 11.654859295824625, 10.604401137820892, 9.623325840103538, 8.657324348431633, 7.638094858183029, 6.699380105531317, 5.770640631007368, 4.813208568248261, 3.8689684312053405, 2.859110959642165, 1.982685777819201, 2.917912454103324, 3.9531400745983403, 4.915868558051771, 5.97571461246396, 7.037681318091236, 14.808118195154407, 13.878061751967946, 12.905421172475608, 11.965075362213533, 10.982693150471645, 9.97972210973963, 8.932204689454705, 7.890783630696159, 6.875946118281398, 5.871112321842078, 4.870964562572376, 3.8783250998217094, 2.930130751875394, 1.9250757524209652, 0.9744296177878745, 1.953155830704711, 2.993092298875949, 4.023994052219466, 5.003297469890081, 6.019031977359728, 14.148679486621367, 13.148084855426015, 12.106102848272247, 11.105711438294263, 10.108319498363578, 9.13712056383882, 8.091213026182789, 7.047101881862635, 6.088283645302745, 5.047596093105003, 3.9795259882848297, 2.942337166181181, 1.9105679860907263, 0.9413003447123692, 0.0, 1.0478259773146554, 2.111282877580514, 3.174967662511968, 4.114480119694135, 5.135973339787547, 14.862219659944289, 13.816463778849192, 12.775116360634655, 11.722714356193066, 10.793563151473442, 9.823628009792023, 8.867238062428552, 7.837604490404235, 6.853796519721341, 5.867668218384411, 4.910287147003033, 3.8826463538876608, 2.8593758874034174, 1.8836363824729672, 1.0350408717741535, 1.99751483912659, 3.050199825276612, 4.064432831746105, 5.042964202770438, 5.982930063198495, 15.68175371604614, 14.63255498871087, 13.654715909625063, 12.59119647213871, 11.660501338439364, 10.733318776113085, 9.803640886539567, 8.764801601720356, 7.810945973591394, 6.837476431065646, 5.7727750204514745, 4.76949182696282, 3.80297509473801, 2.868210464191793, 2.0844150687651553, 3.0475019042148093, 4.0456841899432705, 4.996176396881282, 6.038710923846692, 6.934203482741066, 16.59870286480351, 15.580627833883833, 14.543195970078923, 13.54067824914049, 12.638048770013208, 11.73316296702744, 10.765356236917794, 9.810280613854768, 8.74911442857321, 7.7184381161842355, 6.714563112744315, 5.779393108983349, 4.768018886791033, 3.8694240165780247, 3.1048192274781954, 4.047977273753084, 5.087086642787544, 6.032190835727515, 7.028538177021564, 7.991760219373996, 16.581871430473523, 16.531708719313837, 15.56051470459514, 14.548965856339313, 13.603988245801318, 12.700409292019039, 11.742144892747119, 10.698429078598702, 9.728822756798522, 8.704611584670996, 7.691178605118823, 6.724781723037889, 5.7129810007748345, 4.9256689529957844, 4.0833995863609935, 5.118489447397891, 6.142151197554756, 7.084977537929612, 8.069825801455536, 8.961473509100042, 15.651242798493163, 16.72436466480722, 16.58596679938842, 15.55792580946152, 14.637214408836904, 13.707324369128509, 12.667851917999766, 11.640050635992218, 10.681766567556148, 9.682346009923192, 8.672595846121371, 7.6963990899037515, 6.698244365618905, 5.9519084821488955, 5.056968252328829, 6.076751436026004, 7.024171355344873, 8.008456945900148, 8.963702770945769, 9.950126427885056, 14.773627384505467, 15.811318816990905, 16.700823895064083, 15.76656283802124, 14.810904701761686, 13.940501364789498, 13.54893600909194, 12.613412104256511, 11.683874817209519, 10.673741088946567, 9.692434132945497, 8.714747291715053, 7.735174146073132, 6.916191740515405, 6.051460236753298, 6.978910122806882, 7.912923934221134, 8.878520200293188, 9.923710642755152, 10.918167155683767, 13.833778946962518, 14.752739501619558, 15.753361403273196, 14.808802481550101, 13.865933150877842, 12.96225976574164, 13.809105362029731, 13.567953631103272, 12.598266709055064, 11.668428873833856, 10.664408575487831, 9.718418386072264, 8.778118838149785, 7.908961449779759, 7.088722565480735, 7.977265193066655, 8.887413916263306, 9.811818101835915, 10.876265176295687, 11.906898739433887, 12.861183737761035, 13.807931331747389, 14.74647904370736, 13.81713692416154, 12.822755451760779, 11.89438998543096, 12.776335594671943, 13.607027440231526, 13.652288740058726, 12.632285891769586, 11.652343102203933, 10.683578873838517, 9.824248272348933, 8.843749858788696, 8.125413734519412, 9.046867425052506, 9.907955488858079, 10.872303098293003, 11.801635610107201, 12.803046101861536, 11.947425757769913, 12.921819542921686, 13.690345134795738, 12.760684036919425, 11.825245696127665, 10.840504080398548, 11.77434730225891, 12.675655804756582, 13.65356088500635, 13.617861988745224, 12.631326123766183, 11.637797669345266, 10.822416076622748, 9.814423318415075, 9.166190322277945, 10.06792412719185, 10.86149852366033, 11.895862910612909, 12.840381888086025, 13.773854005994739, 10.881110707136346, 11.88562110943678, 12.721859495361555, 11.787747730939177, 10.853618865775113, 9.890276187715424, 10.723004817336493, 11.680884521756838, 12.696298371520964, 13.57671424244544, 13.648018408154442, 12.66228372722713, 11.747634199965301, 10.802908305397434, 10.12957772569705, 11.02361829122861, 11.863171870006466, 12.839279000129574, 13.773697254962668, 14.699211988405931, 9.863805742756293, 10.83536975967142, 11.81074295519893, 10.855149122167187, 9.942804935323405, 8.932951028262588, 9.777736608914314, 10.683717052792973, 11.632952156808148, 12.573724163746393, 13.495873731195358, 13.613717397034923, 12.694948328518464, 11.736148280993289, 11.085157998725752, 11.94870034841676, 12.809930242998552, 13.78432534437263, 14.77699465060465, 15.65369603755412, 8.884249360669846, 9.92238585147259, 10.78046930132199, 9.78365548694289, 8.973069950332302, 7.993501185448187, 8.834754463301262, 9.657873555097687, 10.622626566910306, 11.663387778672384, 12.566598202193651, 13.446977270526975, 13.665452707408603, 12.786814920411462, 12.070670433949454, 13.00214388785613, 13.74115155399087, 14.716196994250058, 15.665645016539862, 16.59844172136304, 7.90398296679273, 8.850076367131491, 9.70957587579043, 8.824991538442815, 7.956460825739885, 6.995654665884501, 7.833654512633749, 8.69278503365274, 9.724484984657057, 10.716639467153884, 11.504738165766673, 12.466602137667913, 13.500964699101528, 13.831743135267544, 13.037143414352801, 13.935192119851745, 14.755439533404514, 15.730820492420891, 16.628077149162788, 16.7525400917367, 6.98364710469335, 7.9480790796055665, 8.776268913390235, 7.851981469452575, 6.91903000698384, 5.941963684576631, 6.81916968664604, 7.695848914806701, 8.732172958289325, 9.665820698898527, 10.558194584053226, 11.548529942328695, 12.522874673770994, 13.393336124064003, 14.04973930556356, 14.894046652354081, 15.791045425613644, 16.728184054000337, 16.929052258920265, 15.901573720138273, 6.129736045437524, 7.173522482148519, 7.846467439985471, 6.834815125620214, 5.876679722842566, 4.889393821931724, 5.887193550540985, 6.706098923237948, 7.6948271214778785, 8.60856614986583, 9.606380252924657, 10.60597425718078, 11.474032104442646, 12.438715919028486, 13.430834343671085, 14.37621342244086, 15.305607020763189, 16.235243331244494, 16.15592557924812, 15.221251150682253, 7.06497359486262, 7.874808892229452, 6.93765557898521, 5.930835788885044, 4.8761586334673215, 3.937349383286201, 4.866197319976772, 5.766317404365859, 6.703358677614794, 7.639125261022764, 8.617548806662098, 9.600470562890642, 10.513369298537523, 11.499106165917844, 12.51887791533879, 13.498756664426823, 14.459936270487148, 15.423421811524852, 16.37244690681482, 15.758383202040566, 7.961585013396562, 6.93600505746427, 5.906913944216499, 4.933448049638425, 3.8586398112370457, 2.999793650520366, 3.8069676376300574, 4.802235820698855, 5.842439141785638, 6.71536773958635, 7.671230735910547, 8.570416591873089, 9.58466632724338, 10.58214640533092, 11.535766015551122, 12.524765034476124, 13.539807771059978, 14.52011536356902, 15.534304298283228, 16.602022895323433], [16.695111705038002, 15.679728005671052, 14.688645627904881, 13.629100043120182, 12.689582661522348, 11.639124503518614, 10.65804920580126, 9.692047714129355, 8.672818223880753, 7.734103471229041, 6.8053639967050925, 5.847931933945985, 4.903691796903065, 3.8938343253398893, 2.9868656864197094, 1.9951833939673758, 2.994554222752076, 3.9572827062055067, 5.017128760617696, 6.059533483655591, 15.842841560852131, 14.91278511766567, 13.940144538173332, 12.999798727911257, 12.01741651616937, 11.014445475437354, 9.96692805515243, 8.925506996393883, 7.910669483979122, 6.905835687539803, 5.9056879282701, 4.9130484655194335, 3.9648541175731182, 2.9597991181186893, 2.009152983485599, 1.0304267705687624, 2.0345064470296848, 3.0654082003732013, 4.0251496354544365, 5.040884142924083, 15.196505463936022, 14.19591083274067, 13.153928825586902, 12.153537415608918, 11.156145475678233, 10.184946541153476, 9.139039003497444, 8.094927859177291, 7.136109622617401, 6.095422070419659, 5.027351965599485, 3.9901631434958365, 2.9583939634053817, 1.9891263220270248, 1.0478259773146554, 0.0, 1.0634569002658585, 2.127141685197312, 3.066654142379479, 4.088147362472891, 15.871436573305905, 14.825680692210808, 13.784333273996271, 12.731931269554682, 11.802780064835058, 10.832844923153639, 9.876454975790168, 8.846821403765851, 7.8630134330829575, 6.876885131746028, 5.91950406036465, 4.891863267249278, 3.8685928007650343, 2.892853295834584, 1.9203498676722481, 0.9496888618119346, 2.0023738479619566, 3.0166068544314495, 3.995138225455782, 4.935104085883839, 16.690970629407758, 15.641771902072486, 14.663932822986679, 13.600413385500326, 12.66971825180098, 11.742535689474701, 10.812857799901183, 9.774018515081972, 8.82016288695301, 7.846693344427262, 6.7819919338130905, 5.778708740324436, 4.812192008099626, 3.87742737755341, 2.9635127861763797, 1.9996759269001536, 2.997858212628615, 3.9483504195666264, 4.990884946532036, 5.88637750542641, 16.633213255210226, 16.589844747245447, 15.552412883440539, 14.549895162502105, 13.647265683374824, 12.742379880389056, 11.77457315027941, 10.819497527216384, 9.758331341934825, 8.72765502954585, 7.723780026105931, 6.788610022344965, 5.777235800152649, 4.878640929939642, 3.98391694488942, 3.049500402260913, 4.039260665472889, 4.984364858412859, 5.980712199706908, 6.943934242059339, 15.589021111731487, 16.528977971340293, 16.56973161795676, 15.55818276970093, 14.613205159162934, 13.709626205380655, 12.751361806108735, 11.707645991960318, 10.738039670160138, 9.713828498032612, 8.70039551848044, 7.733998636399505, 6.7221979141364505, 5.893805823956672, 4.962497303772218, 4.1200125759057205, 5.1138388374857335, 6.0373398805563685, 7.02199982414088, 7.913647531785386, 14.658392479751127, 15.722857743167225, 16.62633907036468, 15.937368583079207, 14.93942129988949, 14.716541282490125, 13.677068831361382, 12.649267549353834, 11.690983480917764, 10.691562923284808, 9.681812759482987, 8.705616003265368, 7.707461278980521, 6.920045353109783, 5.936065969740054, 5.190094951826767, 6.080552120789203, 7.064837711344478, 7.9716157337881155, 8.9023004505704, 13.78077706576343, 14.768771195413045, 15.658276273486221, 14.969255777733117, 14.013597641473563, 14.910353316347273, 14.558152922453557, 13.622629017618127, 12.693091730571135, 11.682958002308183, 10.701651046307113, 9.723964205076669, 8.744391059434747, 7.884328611476293, 6.930557954164523, 6.167898842354832, 7.101912653769085, 8.067508919841138, 9.03422056464189, 9.870341178369111, 12.828559384539844, 13.710191880041698, 14.710813781695336, 13.933809336301158, 13.068626090589719, 13.932111717299415, 14.79306255417172, 14.577170544464888, 13.60748362241668, 12.677645787195472, 11.673625488849448, 10.72763529943388, 9.7873357515114, 8.877098320740647, 7.967820282891959, 7.166253912614605, 8.076402635811256, 9.000806821383865, 9.986775098182425, 10.864351117856026, 11.818636116183175, 12.765383710169528, 13.786486273317616, 12.894407864025592, 12.025448391472656, 12.864241936988735, 13.760292786813931, 14.627904081736983, 14.661505653420342, 13.641502805131202, 12.661560015565549, 11.692795787200133, 10.833465185710548, 9.811886729749585, 9.004511451930636, 8.235856144600456, 9.096944208406029, 10.061291817840953, 10.91214553199394, 11.8101957831195, 10.899599780455258, 11.87399356560703, 12.76761607465979, 11.837954976783477, 11.002432897904873, 11.810356031956323, 12.758304494400898, 13.69653244626204, 14.674437526511808, 14.62707890210684, 13.640543037127799, 12.647014582706882, 11.790552947583636, 10.782560189375964, 10.045288039689169, 9.2569128467398, 10.05048724320828, 11.084851630160859, 11.950891809972763, 12.781003687252703, 9.83328472982169, 10.837795132122125, 11.799130435225607, 10.865018670803229, 10.030806067552321, 10.860128139273199, 11.706962009478481, 12.701761163262296, 13.717175013026422, 14.59944665738604, 14.657235321516058, 13.671500640588746, 12.71577107092619, 11.771045176358323, 11.008675443108274, 10.21260701077656, 11.052160589554417, 12.028267719677524, 12.962685974510618, 13.706361669663895, 8.815979765441638, 9.787543782356764, 10.860530291522288, 9.93242006203124, 9.020075875187457, 9.902802979820363, 10.761693801056301, 11.706449467733572, 12.655684571748747, 13.596456578686992, 14.521834254701764, 14.62293431039654, 13.663085199479353, 12.704285151954178, 11.964255716136975, 11.137689067964711, 11.998918962546503, 12.973314063920581, 13.9659833701526, 14.660845718812084, 7.836423383355191, 8.874559874157935, 9.857740241186042, 8.860926426806941, 8.050340890196354, 8.963353137005962, 9.81871165544325, 10.680605970038286, 11.645358981850904, 12.686120193612982, 13.592558725700057, 14.472937794033381, 14.633589578369492, 13.754951791372351, 12.949768151360677, 12.19113260740408, 12.93014027353882, 13.905185713798009, 14.854633736087813, 15.718417287872603, 6.856156989478074, 7.802250389816835, 8.786846815654481, 7.9022624783068665, 7.033731765603937, 7.965506617442276, 8.817611704775738, 9.715517448593339, 10.747217399597655, 11.739371882094485, 12.530698689273079, 13.492562661174318, 14.526925222607934, 14.799880006228433, 13.916241131764025, 13.124180839399695, 13.944428252952465, 14.919809211968841, 15.817065868710738, 16.748635559959506, 5.935821127378695, 6.900253102290911, 7.853539853254286, 6.929252409316627, 5.996300946847892, 6.911815636134406, 7.803126878788028, 8.7185813297473, 9.754905373229924, 10.688553113839127, 11.584155107559631, 12.574490465835101, 13.5488351972774, 14.428059489761726, 14.928837022974784, 14.083035371902032, 14.980034145161595, 15.917172773548288, 16.880429094022873, 16.91079063349989, 5.081910068122868, 6.125696504833863, 6.923738379849523, 5.9120860654842655, 4.953950662706617, 5.859245773489498, 6.871150742682973, 7.728831338178548, 8.717559536418479, 9.63129856480643, 10.632340776431063, 11.640697622878506, 12.508755470140368, 13.473439284726208, 14.465557709368808, 15.133476071764505, 15.979320839403014, 16.90895714988432, 17.203751556562775, 16.26907712799691, 6.059184764300474, 6.924809713555339, 5.991293858259363, 5.0081067287490955, 3.9534295733313733, 4.907201334843975, 5.85015451211876, 6.789049819306459, 7.726091092555395, 8.661857675963365, 9.652272172359822, 10.635193928588366, 11.548092664235245, 12.533829531615567, 13.553601281036512, 14.533480030124545, 15.49465963618487, 16.458145177222576, 17.40717027251254, 16.79310656773829, 6.995225848393541, 5.977419205618006, 4.948328092370235, 4.001582486178596, 2.9359107511010976, 3.96964560207814, 4.841691003327782, 5.836959186396579, 6.877162507483362, 7.750091105284074, 8.70595410160827, 9.605139957570813, 10.619389692941102, 11.616869771028643, 12.570489381248844, 13.559488400173846, 14.5745311367577, 15.554838729266743, 16.56902766398095, 17.636746261021155], [17.675670949404303, 16.660287250037353, 15.669204872271182, 14.609659287486483, 13.670141905888649, 12.619683747884915, 11.638608450167562, 10.672606958495656, 9.653377468247054, 8.714662715595342, 7.785923241071394, 6.828491178312287, 5.8842510412693665, 4.874393569706191, 3.967424930786011, 2.975742638333678, 1.9310973224862171, 2.893825805939648, 3.9536718603518377, 4.9960765833897325, 16.82340080521843, 15.893344362031971, 14.920703782539633, 13.980357972277558, 12.99797576053567, 11.995004719803655, 10.94748729951873, 9.906066240760184, 8.891228728345423, 7.886394931906104, 6.886247172636402, 5.893607709885735, 4.94541336193942, 3.940358362484991, 2.989712227851901, 2.0109860149350642, 0.971049546763826, 2.0019513001073426, 2.961692735188578, 3.9774272426582247, 16.25996236420188, 15.25936773300653, 14.217385725852761, 13.216994315874777, 12.219602375944092, 11.248403441419335, 10.202495903763303, 9.15838475944315, 8.19956652288326, 7.1588789706855165, 6.090808865865343, 5.053620043761694, 4.02185086367124, 3.0525832222928835, 2.111282877580514, 1.0634569002658585, 0.0, 1.063684784931454, 2.003197242113621, 3.024690462207033, 16.93489347357177, 15.88913759247667, 14.847790174262133, 13.795388169820543, 12.866236965100919, 11.896301823419499, 10.939911876056028, 9.910278304031712, 8.926470333348817, 7.940342032011887, 6.982960960630509, 5.955320167515136, 4.932049701030893, 3.9563101961004423, 2.9838067679381064, 2.013145762077793, 1.0108146081121998, 2.0250476145816925, 2.931681325189924, 3.871647185617981, 16.631866086592694, 16.705228802338347, 15.727389723252537, 14.663870285766185, 13.733175152066838, 12.80599258974056, 11.876314700167041, 10.83747541534783, 9.88361978721887, 8.91015024469312, 7.845448834078949, 6.842165640590295, 5.875648908365485, 4.9408842778192685, 4.0019297092416375, 3.0380928499654116, 2.006298972778858, 2.9567911797168693, 3.974055700173026, 4.822920605160552, 15.569756354944367, 16.42951728474099, 16.615869783706398, 15.613352062767964, 14.710722583640683, 13.805836780654914, 12.83803005054527, 11.882954427482243, 10.821788242200684, 9.79111192981171, 8.78723692637179, 7.852066922610824, 6.840692700418508, 5.9420978302055, 5.022333867954678, 4.087917325326171, 3.0477014256231323, 3.9928056185631022, 4.975185323725789, 5.8804773417934815, 14.525564211465628, 15.465521071074432, 16.43671508579313, 16.061151577114824, 15.676662059428793, 14.773083105646514, 13.814818706374593, 12.771102892226176, 11.801496570425996, 10.77728539829847, 9.763852418746298, 8.797455536665364, 7.785654814402309, 6.93222274702193, 6.000914226837476, 5.145941347792842, 4.122279597635977, 5.045780640706612, 6.016472948159761, 6.850190631519528, 13.594935579485268, 14.659400842901366, 15.562882170098819, 15.052191623992618, 15.799129465590193, 15.779998182755984, 14.74052573162724, 13.712724449619692, 12.754440381183622, 11.755019823550667, 10.745269659748846, 9.769072903531226, 8.77091817924638, 7.958462276175041, 6.9744828928053115, 6.036412800258314, 5.088992880939446, 6.073278471494722, 6.966088857806996, 7.838843550304542, 12.717320165497572, 13.705314295147186, 14.594819373220362, 14.062762775079985, 14.873305807174265, 15.85555941526599, 15.621609822719416, 14.686085917883986, 13.756548630836994, 12.746414902574042, 11.765107946572972, 10.787421105342528, 9.807847959700606, 8.896407231849542, 7.941666576839962, 7.014216690786379, 6.113906154741809, 7.079502420813863, 8.02869368866077, 8.806884278103253, 11.765102484273985, 12.64673497977584, 13.647356881429477, 13.016020236529325, 13.928334256290421, 14.881391803813857, 15.773621798538022, 15.640627444730747, 14.670940522682539, 13.74110268746133, 12.737082389115306, 11.791092199699738, 10.850792651777258, 9.889176941113895, 8.94019873055536, 8.012571761046154, 7.088396136783979, 8.01280032235659, 8.981248222201305, 9.800894217590168, 10.755179215917316, 11.70192680990367, 12.723029373051757, 11.97661876425376, 12.885156557173358, 13.813522023503177, 14.740852031180234, 15.608463326103287, 15.7249625536862, 14.70495970539706, 13.725016915831407, 12.756252687465992, 11.887701462580692, 10.823965350122833, 9.976889899594038, 9.082173993032004, 8.108937709378754, 9.073285318813678, 9.906618656012819, 10.746738882853641, 9.8361428801894, 10.810536665341175, 11.75071766539131, 10.920165877011645, 11.862141063605575, 12.790915276322623, 13.7388637387672, 14.677091690628343, 15.65499677087811, 15.690535802372699, 14.703999937393657, 13.710471482972741, 12.802631567956885, 11.794638809749213, 11.017666487352571, 10.06399043846591, 9.062480744181006, 10.096845131133584, 10.945364933991641, 11.717546786986844, 8.769827829555831, 9.77433823185627, 10.782232025957127, 9.947229571031396, 10.890514233253024, 11.8406873836395, 12.687521253844784, 13.682320407628598, 14.697734257392725, 15.58000590175234, 15.720692221781917, 14.691808959098381, 13.727849691299438, 12.783123796731571, 11.981053890771676, 11.01968460250267, 10.064154090527142, 11.04026122065025, 11.962865324574338, 12.642904769398037, 7.75252286517578, 8.724086882090907, 9.797073391256433, 9.014630962259407, 9.87978404088816, 10.883362224186664, 11.742253045422604, 12.687008712099873, 13.636243816115048, 14.577015823053292, 15.502393499068065, 15.643242628906174, 14.675163819852601, 13.716363772327426, 12.936634163800377, 11.94476665969082, 11.010912463519228, 11.985307564893306, 12.96616272021632, 13.597388818546225, 6.772966483089333, 7.811102973892076, 8.808952709312527, 7.943137327035109, 8.910049055897057, 9.943912381372263, 10.799270899809553, 11.661165214404587, 12.625918226217205, 13.666679437979283, 14.573117970066358, 15.453497038399682, 15.64566819874274, 14.7670304117456, 13.92214659902408, 12.981751657559267, 11.942133774511545, 12.917179214770734, 13.866627237060538, 14.654960387606744, 5.792700089212216, 6.738793489550977, 7.7380592837809665, 6.984473378535034, 8.011966976186624, 8.946065861808577, 9.79817094914204, 10.69607669295964, 11.727776643963956, 12.719931126460786, 13.51125793363938, 14.47312190554062, 15.507484466974235, 15.811958626601681, 14.888619579427427, 13.914799889554882, 12.95642175392519, 13.931802712941566, 14.829059369683463, 15.685178659693648, 4.872364227112836, 5.836796202025052, 6.804752321380772, 6.011463309544794, 6.976860191214195, 7.892374880500707, 8.78368612315433, 9.699140574113601, 10.735464617596225, 11.669112358205428, 12.564714351925932, 13.555049710201402, 14.529394441643701, 15.408618734128027, 15.900684421194638, 14.873654422057218, 13.99202764613432, 14.929166274521013, 15.892422594995598, 16.72357200458888, 4.01845316785701, 5.0622396045680045, 5.879101136223035, 4.994296965712432, 5.93450990707292, 6.8398050178558, 7.851709987049275, 8.709390582544849, 9.69811878078478, 10.611857809172731, 11.612900020797364, 12.621256867244806, 13.48931471450667, 14.453998529092509, 15.446116953735109, 15.920707938698067, 14.99131434037574, 15.920950650857044, 16.909995885184053, 17.332534028262764, 4.995727864034616, 5.861352813289481, 4.927836957993504, 3.999305065835773, 4.933988817697675, 5.887760579210277, 6.8307137564850615, 7.76960906367276, 8.706650336921696, 9.642416920329666, 10.632831416726123, 11.615753172954667, 12.528651908601546, 13.514388775981867, 14.534160525402813, 15.514039274490846, 15.931979257476412, 16.895464798514116, 17.84448989380408, 17.77366581210459, 5.931768948127683, 4.913962305352149, 3.884871192104377, 2.9381255859127373, 3.9164699954673994, 4.950204846444442, 5.822250247694083, 6.817518430762881, 7.857721751849663, 8.730650349650375, 9.686513345974571, 10.585699201937114, 11.599948937307403, 12.597429015394944, 13.551048625615145, 14.540047644540147, 15.555090381124002, 16.535397973633042, 17.549586908347248, 18.617305505387453], [18.679580932670316, 17.664197233303366, 16.673114855537197, 15.613569270752496, 14.674051889154661, 13.623593731150928, 12.642518433433574, 11.676516941761669, 10.657287451513067, 9.718572698861355, 8.789833224337407, 7.8324011615783, 6.873013270925815, 5.86315579936264, 4.930334430985083, 3.93865213853275, 2.8872386838456627, 1.9245102003922319, 2.9256276565027863, 3.932391798458278, 17.827310788484443, 16.897254345297984, 15.924613765805645, 14.98426795554357, 14.001885743801683, 12.998914703069667, 11.951397282784743, 10.909976224026197, 9.895138711611436, 8.890304915172116, 7.890157155902415, 6.897517693151748, 5.949323345205433, 4.944268345751004, 3.9936222111179136, 3.014895998201077, 1.9749595300298388, 0.9440577766863222, 1.8980079502571239, 2.9137424577267708, 17.323647149133333, 16.32305251793798, 15.281070510784215, 14.28067910080623, 13.283287160875545, 12.312088226350788, 11.266180688694757, 10.222069544374603, 9.263251307814713, 8.22256375561697, 7.1544936507967964, 6.117304828693148, 5.0855356486026935, 4.1162680072243365, 3.1749676625119676, 2.127141685197312, 1.063684784931454, 0.0, 0.9395124571821668, 1.9610056772755788, 16.613472902749404, 16.918861188785364, 15.877513770570825, 14.825111766129234, 13.895960561409611, 12.926025419728191, 11.96963547236472, 10.940001900340404, 9.956193929657509, 8.97006562832058, 8.0126845569392, 6.985043763823828, 5.961773297339585, 4.986033792409135, 4.013530364246798, 3.0428693583864845, 1.9901843722364623, 0.9759513657669695, 1.8679965402584697, 2.8079624006865265, 15.568181301661241, 16.373010776127323, 16.73826146587797, 15.674742028391618, 14.744046894692271, 13.816864332365993, 12.887186442792474, 11.848347157973263, 10.894491529844302, 9.921021987318554, 8.856320576704382, 7.853037383215728, 6.886520650990918, 5.9457867894084515, 4.951193523054901, 3.9873566637786744, 2.955562786592121, 1.9076949309021465, 2.9103709152415718, 3.7592358202290974, 14.506071570012914, 15.365832499809537, 16.39034903537789, 16.6242238053934, 15.721594326266116, 14.816708523280347, 13.848901793170702, 12.893826170107676, 11.832659984826117, 10.801983672437142, 9.798108668997223, 8.862938665236257, 7.851564443043941, 6.947000341794683, 5.971597681767941, 5.037181139139434, 3.9969652394363946, 2.9437093697483796, 3.9115005387943347, 4.816792556862027, 13.461879426534175, 14.401836286142979, 15.373030300861673, 16.39157192993689, 16.687533802054226, 15.783954848271947, 14.825690449000026, 13.78197463485161, 12.81236831305143, 11.788157140923904, 10.774724161371731, 9.808327279290797, 8.796526557027741, 7.881486560835193, 6.950178040650739, 5.9631724824236105, 4.939510732266745, 3.996684391891889, 4.952788163228306, 5.786505846588073, 12.531250794553815, 13.595716057969913, 14.499197385167365, 15.48741436442751, 16.379467310190357, 16.790869925381415, 15.751397474252673, 14.723596192245125, 13.765312123809055, 12.7658915661761, 11.75614140237428, 10.77994464615666, 9.781789921871813, 8.907726089988305, 7.873427118586258, 6.8536439348890825, 5.906224015570214, 5.035484316930341, 5.902404072875542, 6.775158765373088, 11.653635380566119, 12.641629510215733, 13.531134588288909, 14.497985515514877, 15.453643651774431, 16.435897259866156, 16.61572811181672, 15.680204206981287, 14.699935539413602, 13.676587110716344, 12.65867329388222, 11.619712290644667, 10.640139145002745, 9.71363836648031, 8.75889771147073, 7.831447825417148, 6.931137289372577, 6.102325130302693, 6.965008903729316, 7.743199493171798, 10.701417699342532, 11.583050194844386, 12.583672096498024, 13.577748290221509, 14.520617620893768, 15.501888629472136, 16.438177753281703, 16.554147395792985, 15.564920954361627, 14.635083119140418, 13.569373574417446, 12.623383385001878, 11.683083837079398, 10.706408075744664, 9.757429865186129, 8.829802895676922, 7.9056272714147475, 7.035623031845419, 7.917563437269852, 8.737209432658714, 9.691494430985863, 10.638242024972216, 11.659344588120303, 12.637760716832268, 13.546298509751868, 14.474663976081686, 15.474013875922633, 16.375994312276767, 16.581975019606002, 15.5372508906992, 14.557308101133547, 13.588543872768131, 12.70493259721146, 11.641196484753602, 10.794121034224807, 9.899405127662773, 8.92616884400952, 8.096108028302506, 8.842933871081366, 9.683054097922188, 8.772458095257942, 9.746851880409718, 10.687032880459853, 11.581307829590154, 12.523283016184084, 13.456426204854717, 14.4720255835096, 15.444622676801824, 16.42252775705159, 16.52282698767484, 15.536291122695797, 14.54276266827488, 13.619862702587653, 12.61186994437998, 11.83489762198334, 10.881221573096676, 9.879711878811772, 9.152648939627365, 9.881680149060188, 10.65386200205539, 7.706143044624376, 8.710653446924812, 9.71854724102567, 10.608371523609906, 11.551656185831533, 12.506198312171593, 13.455052240018265, 14.44985139380208, 15.465265243566206, 16.45666640876193, 16.548739795960262, 15.50904009372915, 14.545080825930206, 13.60035493136234, 12.798285025402445, 11.836915737133436, 10.881385225157908, 10.165616641758579, 10.899180539642884, 11.579219984466583, 6.6888380802443255, 7.6604020971594515, 8.733388606324976, 9.675772914837916, 10.540925993466669, 11.548873152718757, 12.509784031596086, 13.563669219109462, 14.512904323124637, 15.453676330062882, 16.465302999267138, 16.460473763536942, 15.49239495448337, 14.533594906958195, 13.753865298431146, 12.761997794321587, 11.828143598149994, 11.110662986001635, 11.902477935284866, 12.533704033614772, 5.709281698157879, 6.747418188960623, 7.745267924381073, 8.604279279613618, 9.571191008475566, 10.609423309904356, 11.566801885983034, 12.537825721414176, 13.502578733226795, 14.543339944988873, 15.536027470265429, 16.416406538598753, 16.46289933337351, 15.584261546376368, 14.739377733654848, 13.798982792190033, 12.759364909142311, 12.042534635879063, 12.82912412080875, 13.59127560267529, 4.729015304280762, 5.6751087046195225, 6.674374498849513, 7.645615331113542, 8.673108928765132, 9.642954796915577, 10.62372779821769, 11.572737199969229, 12.64069909948154, 13.64996513214069, 14.474167433838451, 15.43603140573969, 16.470393967173308, 16.62918976123245, 15.705850714058196, 14.732031024185648, 13.773652888555956, 13.057158134049896, 13.791556253431676, 14.621493874762194, 3.8086794421813823, 4.773111417093599, 5.741067536449319, 6.696410454060073, 7.69039907169494, 8.756235439869005, 9.746595623353402, 10.662050074312672, 11.698374117795296, 12.6320218584045, 13.527623852125004, 14.517959210400473, 15.492303941842772, 16.41252871739404, 16.717915555825407, 15.690885556687984, 14.809258780765086, 14.054521695629344, 14.85491947874381, 15.659887219657428, 2.9547683829255558, 3.9985548196365506, 4.909785530675618, 5.921437845040876, 6.879573247818524, 7.802714518054872, 8.814619487248347, 9.67230008274392, 10.661028280983851, 11.574767309371802, 12.575809520996435, 13.585680188653711, 14.493224697772682, 15.457908512358522, 16.45002693700112, 16.737939073328832, 15.808545475006506, 15.066472835820798, 15.904997269476434, 16.673446380593408, 3.932043079103161, 4.869198232435591, 3.958521352446088, 4.955446427195218, 5.896898317896747, 6.850670079409349, 7.793623256684134, 8.732518563871832, 9.669559837120767, 10.605326420528737, 11.636741399992136, 12.61966315622068, 13.532561891867559, 14.51829875924788, 15.538070508668826, 16.517949257756857, 16.74921039210718, 16.05162571036996, 16.92135990266558, 17.70659282064725, 4.868084163196228, 3.921807724498258, 2.9155555865569607, 3.8942669472721825, 4.8793794956664716, 5.913114346643514, 6.811012477350532, 7.80628066041933, 8.861631735115676, 9.734560332916388, 10.690423329240584, 11.589609185203127, 12.603858920573416, 13.601338998660957, 14.554958608881158, 15.54395762780616, 16.559000364390016, 17.08799183916996, 17.893197937413195, 18.658278468184097], [18.695096543850234, 18.020163893461586, 17.612627312719365, 16.553081727934664, 15.61356434633683, 14.563106188333096, 13.582030890615743, 12.616029398943837, 11.596799908695234, 10.658085156043521, 9.729345681519574, 8.771913618760466, 7.812525728107982, 6.8026682565448064, 5.86984688816725, 4.8781645957149165, 3.826751141027829, 2.864022657574399, 1.9861151993206194, 2.9928793412761117, 17.69263321670295, 17.83676680248015, 16.86412622298781, 15.923780412725737, 14.94139820098385, 13.938427160251834, 12.89090973996691, 11.849488681208364, 10.834651168793602, 9.829817372354283, 8.829669613084581, 7.837030150333915, 6.888835802387599, 5.88378080293317, 4.93313466830008, 3.9544084553832435, 2.9144719872120053, 1.883570233868489, 0.9584954930749571, 1.9742300005446038, 16.686279554207797, 17.26256497512015, 16.22058296796638, 15.220191557988397, 14.222799618057712, 13.251600683532955, 12.205693145876923, 11.16158200155677, 10.20276376499688, 9.162076212799137, 8.094006107978963, 7.056817285875315, 6.025048105784861, 5.055780464406504, 4.114480119694135, 3.0666541423794795, 2.003197242113621, 0.9395124571821668, 0.0, 1.0214932200934121, 15.673960445567236, 16.425944333593566, 16.81702622775299, 15.7646242233114, 14.835473018591776, 13.865537876910356, 12.909147929546885, 11.879514357522568, 10.895706386839674, 9.909578085502744, 8.952197014121367, 7.924556221005995, 6.901285754521751, 5.925546249591301, 4.953042821428965, 3.982381815568651, 2.9296968294186287, 1.9154638229491363, 0.928484083076303, 1.8684499435043598, 14.628668844479074, 15.433498318945158, 16.411337398030966, 16.614254485573785, 15.68355935187444, 14.75637678954816, 13.826698899974641, 12.78785961515543, 11.834003987026469, 10.86053444450072, 9.795833033886549, 8.792549840397895, 7.8260331081730845, 6.885299246590618, 5.890705980237067, 4.926869120960841, 3.8950752437742877, 2.847207388084313, 1.9708584580594048, 2.8197233630469305, 13.566559112830747, 14.42632004262737, 15.450836578195725, 16.45335429913416, 16.661106783448282, 15.756220980462514, 14.788414250352869, 13.833338627289843, 12.772172442008284, 11.741496129619309, 10.73762112617939, 9.802451122418423, 8.791076900226107, 7.88651279897685, 6.911110138950107, 5.976693596321601, 4.936477696618562, 3.883221826930546, 2.971988081612168, 3.8772800996798598, 12.522366969352008, 13.462323828960812, 14.433517843679507, 15.452059472754723, 16.415052836510068, 16.723467305454115, 15.765202906182193, 14.721487092033774, 13.751880770233594, 12.72766959810607, 11.714236618553898, 10.747839736472963, 9.736039014209908, 8.82099901801736, 7.889690497832905, 6.902684939605777, 5.879023189448912, 4.936196849074055, 4.01327570604614, 4.846993389405906, 11.591738337371648, 12.656203600787745, 13.559684927985197, 14.547901907245341, 15.43995485300819, 16.37969111441899, 16.690909931434838, 15.66310864942729, 14.70482458099122, 13.705404023358266, 12.695653859556446, 11.719457103338826, 10.721302379053979, 9.847238547170472, 8.812939575768425, 7.793156392071249, 6.845736472752381, 5.918137440738997, 4.962891615693375, 5.8356463081909205, 10.714122923383952, 11.702117053033565, 12.59162213110674, 13.558473058332709, 14.514131194592263, 15.496384802683988, 16.502751356021786, 16.619716664163455, 15.63944799659577, 14.616099567898512, 13.598185751064388, 12.559224747826836, 11.579651602184914, 10.653150823662479, 9.698410168652899, 8.770960282599315, 7.870649746554744, 6.984978254111349, 6.02549644654715, 6.803687035989631, 9.761905242160363, 10.643537737662218, 11.644159639315856, 12.63823583303934, 13.5811051637116, 14.562376172289968, 15.498665296099537, 16.49266297196592, 16.504433411543797, 15.574595576322587, 14.508886031599614, 13.562895842184046, 12.622596294261566, 11.645920532926832, 10.696942322368296, 9.769315352859088, 8.845139728596914, 7.918276155654075, 6.978050980087685, 7.797696975476547, 8.751981973803694, 9.698729567790048, 10.719832130938135, 11.698248259650102, 12.606786052569701, 13.53515151889952, 14.534501418740467, 15.436481855094602, 16.45548033291624, 16.47676334788137, 15.496820558315715, 14.5280563299503, 13.644445054393628, 12.58070894193577, 11.733633491406973, 10.838917584844939, 9.865681301191689, 8.921091424941604, 7.903421413899199, 8.743541640740021, 7.832945638075776, 8.807339423227551, 9.747520423277686, 10.641795372407987, 11.583770559001918, 12.51691374767255, 13.532513126327434, 14.505110219619658, 15.483015299869425, 16.540554281305507, 16.475803579877965, 15.482275125457049, 14.559375159769822, 13.55138240156215, 12.774410079165506, 11.820734030278844, 10.81922433599394, 9.961464587995865, 8.942167691878023, 9.714349544873224, 6.766630587442209, 7.771140989742646, 8.779034783843503, 9.66885906642774, 10.612143728649366, 11.566685854989426, 12.515539782836099, 13.510338936619913, 14.52575278638404, 15.517153951579763, 16.44995582924, 16.44855255091132, 15.484593283112375, 14.539867388544508, 13.737797482584611, 12.776428194315605, 11.820897682340076, 10.894086337293814, 9.95966808246072, 10.639707527284417, 5.749325623062158, 6.720889639977284, 7.793876149142809, 8.73626045765575, 9.601413536284502, 10.60936069553659, 11.570271574413919, 12.624156761927296, 13.57339186594247, 14.514163872880715, 15.56456571417124, 16.492410663588878, 16.431907411665538, 15.473107364140363, 14.693377755613312, 13.701510251503755, 12.767656055332163, 11.83913268153687, 10.962965478102701, 11.594191576432605, 4.7697692409757115, 5.807905731778456, 6.805755467198907, 7.664766822431451, 8.6316785512934, 9.66991085272219, 10.627289428800868, 11.59831326423201, 12.563066276044628, 13.603827487806706, 14.675730213254594, 15.703855719992609, 16.66280119278584, 16.523774003558536, 15.678890190837015, 14.738495249372201, 13.69887736632448, 12.771004331414298, 11.889611663626585, 12.651763145493124, 3.789502847098595, 4.735596247437356, 5.734862041667347, 6.706102873931376, 7.733596471582965, 8.70344233973341, 9.684215341035523, 10.633224742787062, 11.701186642299373, 12.710452674958525, 13.761616615232306, 14.723480587133546, 15.757843148567162, 16.742433309987888, 16.645363171240362, 15.671543481367816, 14.713165345738124, 13.785627829585131, 12.85204379624951, 13.681981417580026, 2.8691669849992154, 3.8335989599114315, 4.8015550792671515, 5.756897996877906, 6.750886614512773, 7.816722982686837, 8.819971866739431, 9.848432602940179, 10.884756646422803, 11.861926695381813, 12.926970535988655, 13.917305894264125, 14.891650625706424, 15.931294206925031, 16.94136394742955, 16.630398013870153, 15.748771237947254, 14.782991391164579, 13.915407021561645, 14.72037476247526, 2.0152559257433893, 3.059042362454384, 4.114700101398769, 5.126352415764027, 6.084487818541675, 7.144087461669625, 8.205639981927709, 9.215179983137604, 10.286352825725984, 11.214504008205013, 12.215546219829646, 13.225416887486922, 14.205525720814208, 15.170209535400048, 16.162327960042646, 17.10770703881242, 16.72457884183734, 15.794942531356034, 14.96548481229427, 15.733933923411241, 2.9925306219209946, 3.929685775253424, 4.866839088497666, 5.8736588785978325, 6.836410775078914, 7.790182536591516, 8.7331357138663, 9.672031021053998, 10.609072294302933, 11.544838877710903, 12.576253857174303, 13.559175613402846, 14.472074349049727, 15.457811216430049, 16.477582965850992, 17.45746171493903, 17.66524375893801, 16.7800954059052, 15.981847445483416, 16.767080363465084, 3.9285717060140612, 2.982295267316091, 3.8550680437391276, 4.833779404454349, 5.818891952848638, 6.852626803825681, 7.750524934532699, 8.745793117601497, 9.801144192297842, 10.674072790098554, 11.62993578642275, 12.529121642385293, 13.543371377755584, 14.540851455843125, 15.494471066063326, 16.48347008498833, 17.498512821572184, 17.816461534705198, 16.95368548023103, 17.718766011001932], [17.79739038156583, 18.363579925224535, 18.634120532812776, 17.574574948028076, 16.63505756643024, 15.584599408426508, 14.603524110709154, 13.637522619037249, 12.618293128788647, 11.679578376136934, 10.750838901612987, 9.79340683885388, 8.834018948201395, 7.824161476638219, 6.891340108260662, 5.899657815808329, 4.848244361121242, 3.885515877667811, 3.0026219991223897, 1.977917126138588, 16.794927054418547, 17.41902411567462, 17.885619443081225, 16.945273632819152, 15.962891421077263, 14.959920380345247, 13.912402960060323, 12.870981901301777, 11.856144388887015, 10.851310592447696, 9.851162833177995, 8.858523370427328, 7.910329022481012, 6.905274023026583, 5.954627888393492, 4.975901675476656, 3.9359652073054177, 2.905063453961901, 1.9750022928767272, 0.9592677854070804, 15.788573391923393, 16.48599252220335, 17.24207618805979, 16.241684778081808, 15.244292838151123, 14.273093903626366, 13.227186365970335, 12.183075221650181, 11.22425698509029, 10.183569432892549, 9.115499328072374, 8.078310505968727, 7.046541325878272, 6.077273684499915, 5.135973339787546, 4.088147362472891, 3.0246904622070327, 1.9610056772755788, 1.0214932200934121, 0.0, 14.776254283282832, 15.528238171309162, 16.49140402511291, 16.780067709659946, 15.850916504940324, 14.880981363258904, 13.924591415895433, 12.894957843871117, 11.911149873188222, 10.925021571851293, 9.967640500469916, 8.939999707354543, 7.916729240870301, 6.9409897359398505, 5.968486307777514, 4.9978253019172, 3.945140315767178, 2.9309073092976856, 1.9107096416480132, 0.9707437812199565, 13.73096268219467, 14.535792156660754, 15.513631235746562, 16.505129913851533, 16.699002838222988, 15.771820275896708, 14.84214238632319, 13.803303101503978, 12.849447473375017, 11.875977930849269, 10.811276520235097, 9.807993326746443, 8.841476594521632, 7.900742732939166, 6.906149466585616, 5.94231260730939, 4.910518730122837, 3.8626508744328625, 2.8674574492925666, 1.9220172007625274, 12.668852950546343, 13.528613880342967, 14.55313041591132, 15.555648136849754, 16.48328615001377, 16.77166446681106, 15.803857736701417, 14.848782113638391, 13.787615928356832, 12.756939615967857, 11.753064612527938, 10.817894608766972, 9.806520386574656, 8.901956285325397, 7.926553625298656, 6.988656455271997, 5.929808653450897, 4.864934414139379, 3.8685870728453295, 2.9795739373954566, 11.624660807067604, 12.564617666676408, 13.535811681395103, 14.554353310470319, 15.517346674225662, 16.523722211463813, 16.78064639253074, 15.736930578382323, 14.767324256582143, 13.743113084454619, 12.729680104902446, 11.763283222821512, 10.751482500558456, 9.833521989710118, 8.902213469525663, 7.849510644097977, 6.825848893941112, 5.8830225535662555, 4.878353055646035, 3.949287227121503, 10.694032175087244, 11.758497438503342, 12.661978765700795, 13.65019574496094, 14.542248690723788, 15.481984952134587, 16.52145740326333, 16.67855213577584, 15.720268067339768, 14.720353646615354, 13.710603482813534, 12.734406726595914, 11.736252002311067, 10.798047367535954, 9.734703483910211, 8.714920300213036, 7.767500380894168, 6.783214790338892, 5.8279689652932705, 4.937940145906517, 9.816416761099548, 10.804410890749162, 11.693915968822338, 12.660766896048306, 13.61642503230786, 14.598678640399585, 15.605045193737384, 16.540569098572814, 16.561211904737558, 15.537863476040298, 14.519949659206175, 13.480988655968622, 12.5014155103267, 11.574914731804265, 10.620174076794685, 9.692724190741101, 8.79241365469653, 7.850055603711244, 6.890573796147045, 5.905980873705228, 8.864199079875961, 9.745831575377816, 10.746453477031453, 11.740529670754938, 12.683399001427198, 13.664670010005565, 14.600959133815135, 15.594956809681518, 16.584183251112876, 16.49635948446437, 15.4306499397414, 14.484659750325832, 13.544360202403352, 12.567684441068618, 11.618706230510082, 10.691079261000874, 9.764115179409313, 8.78335350525397, 7.8431283296875804, 6.899990813192144, 7.854275811519292, 8.801023405505646, 9.822125968653733, 10.800542097365698, 11.709079890285297, 12.637445356615116, 13.636795256456063, 14.538775692810198, 15.557774170631834, 16.602498299538635, 16.4185844664575, 15.449820238092085, 14.566208962535415, 13.502472850077556, 12.65539739954876, 11.760681492986725, 10.784656752004086, 9.7861687745415, 8.768498763499094, 7.8458354784556175, 6.935239475791373, 7.90963326094315, 8.849814260993284, 9.744089210123583, 10.686064396717514, 11.619207585388146, 12.63480696404303, 13.607404057335254, 14.585309137585021, 15.642848119021105, 16.56894195134386, 16.404039033598835, 15.481139067911608, 14.473146309703935, 13.694334247726593, 12.739709481091241, 11.738199786806337, 10.826541937595758, 9.807245041477916, 8.81664338258882, 5.868924425157806, 6.873434827458244, 7.881328621559101, 8.771152904143335, 9.714437566364962, 10.668979692705022, 11.617833620551695, 12.612632774335509, 13.628046624099635, 14.61944778929536, 15.5522496669556, 16.546138171112272, 16.40635719125416, 15.461631296686294, 14.657651320188192, 13.695403645128001, 12.65037308384566, 11.674265953722552, 10.739847698889458, 9.742001365000013, 4.851619460777756, 5.823183477692882, 6.896169986858407, 7.838554295371346, 8.703707374000098, 9.711654533252187, 10.672565412129515, 11.726450599642893, 12.675685703658068, 13.616457710596313, 14.666859551886837, 15.594704501304477, 16.612764348907987, 16.39487127228215, 15.613231593216893, 14.590150500665793, 13.597131456837745, 12.619312297965608, 11.720962453596417, 10.696485414148201, 3.872063078691309, 4.910199569494052, 5.9080493049145035, 6.767060660147048, 7.733972389008995, 8.772204690437786, 9.729583266516464, 10.700607101947607, 11.665360113760226, 12.706121325522304, 13.778024050970192, 14.806149557708205, 15.765095030501437, 16.722140304840014, 16.52566831148442, 15.567970650877784, 14.528352767830063, 13.551183947843036, 12.647608639120302, 11.75405698320872, 2.891796684814192, 3.837890085152953, 4.8371558793829434, 5.808396711646973, 6.835890309298563, 7.805736177449009, 8.786509178751121, 9.73551858050266, 10.80348048001497, 11.81274651267412, 12.863910452947902, 13.825774424849142, 14.860136986282757, 15.844727147703486, 16.90797334918823, 16.5010188828734, 15.542640747243707, 14.565807446013869, 13.610040771743227, 12.784275255295622, 1.9714608227148123, 2.9358927976270284, 3.903848916982749, 4.859191834593504, 5.85318045222837, 6.919016820402435, 7.922265704455029, 8.950726440655776, 9.9870504841384, 10.96422053309741, 12.029264373704251, 13.01959973197972, 13.99394446342202, 15.033588044640627, 16.043657785145147, 17.07068778428257, 16.5544962552332, 15.563171007593315, 14.673403997055363, 13.822668600190855, 0.9937627056499769, 2.0375491423609717, 3.0932068813053575, 4.104859195670614, 5.062994598448262, 6.122594241576213, 7.184146761834297, 8.193686763044193, 9.264859605632573, 10.193010788111602, 11.194052999736234, 12.20392366739351, 13.184032500720797, 14.148716315306636, 15.140834739949236, 16.08621381871901, 17.015607417041338, 16.575122147784768, 15.723481787787987, 14.836227761126837, 1.9710374018275822, 2.9940285613152415, 3.9311818745594835, 4.938001664659651, 5.992678820077373, 6.995528637241419, 7.938481814516203, 8.877377121703901, 9.814418394952837, 10.750184978360807, 11.823202903389097, 12.806124659617641, 13.793733476897925, 14.779470344278247, 15.837760816091963, 16.857185637564527, 17.81836524362485, 17.560275022333933, 16.739844420977132, 15.869374201180678, 2.907078485920649, 3.932658441852941, 4.8765612638325395, 5.855272624547761, 6.84038517294205, 7.874120023919093, 8.772018154626112, 9.76728633769491, 10.741997369556081, 11.695566010191968, 12.651429006516164, 13.550614862478707, 14.564864597848995, 15.562344675936536, 16.515964286156738, 17.50496330508174, 18.520006041665596, 18.59664115113393, 17.71168245572475, 16.82105984871753], [3.021136098283, 3.8810976350104682, 4.872180012776639, 5.817198258763437, 6.756715640361271, 7.775080793942799, 8.756156091660152, 9.722157583332057, 10.741387073580661, 11.680101826232374, 12.608841300756321, 13.566273363515428, 14.63921783966898, 15.649075311232156, 16.581896679609713, 17.573578972062045, 18.62499242674913, 18.53798310314163, 17.66007564488785, 16.754171409421417, 2.0186727711357175, 2.936541825460554, 3.909182404952892, 4.849528215214966, 5.8319104269568545, 6.83488146768887, 7.882398887973794, 8.92381994673234, 9.938657459147102, 10.943491255586421, 11.943639014856123, 12.93627847760679, 13.884472825553106, 14.889527825007535, 15.836649277732162, 16.815375490649, 17.855311958820238, 17.55753067943572, 16.632455938642188, 15.73552206868991, 1.0123191086405616, 2.003510231989284, 3.024314663242848, 4.024706073220832, 5.022098013151517, 5.993296947676274, 6.934916642709889, 7.979027787030042, 8.937846023589932, 9.978533575787674, 11.018182535999303, 12.03080109615943, 12.988409955459634, 13.920919315231918, 14.862219659944287, 15.871436573305903, 16.934893473571762, 16.6134729027494, 15.673960445567232, 14.77625428328283, 0.0, 1.0457558810950975, 2.087103299309635, 3.139505303751225, 4.068656508470848, 5.038591650152268, 5.994981597515739, 7.024615169540055, 8.008423140222948, 8.994551441559878, 9.951932512941255, 10.979573306056627, 12.00284377254087, 12.978583277471321, 13.951086705633656, 14.92174771149397, 15.97443269764399, 15.76142585439529, 14.74547636249093, 13.805510502062873, 1.0452916010881619, 2.0382018957435055, 3.0160409748293135, 4.079560412315665, 5.010255546015011, 5.93743810834129, 6.867115997914809, 7.90595528273402, 8.859810910862981, 9.83328045338873, 10.897981864002901, 11.901265057491555, 12.867781789716366, 13.808515651298832, 14.803108917652382, 15.766945776928608, 15.819509347838055, 14.829682289260113, 13.798450132672595, 12.854237082520303, 2.1074013327364884, 3.045380172061293, 4.0090910859696525, 5.011608806908086, 5.987802977588855, 6.950784011504606, 7.828831348293036, 8.861221894654346, 9.797979365844796, 10.800550185009872, 11.804425188449791, 12.74862026738161, 13.759994489573925, 14.744592025812414, 15.720952137121898, 15.791636282767747, 14.778106894993781, 13.79366785041388, 12.797320509119832, 11.796680345887374, 3.151593476215228, 4.00937638572785, 4.980570400446545, 5.999112029521761, 6.9537424533769645, 7.918030336496205, 8.80562000412236, 9.856901142676797, 10.826507464476977, 11.786723653496633, 12.800501418791823, 13.69400888143615, 14.704956603557726, 15.729248150100036, 15.568748379119716, 14.72112410912294, 13.703528722980936, 12.76070238260608, 11.75603288468586, 10.826967056161328, 4.082222108195588, 5.006456564125058, 5.969789272428688, 7.008071982643966, 7.9869686164125495, 8.926704877823347, 9.86753983895437, 10.81371409554369, 11.77199816397976, 12.781359942360188, 13.791110106162009, 14.675316887624648, 15.673471611909495, 15.519711642103502, 14.59517971315188, 13.651041733201893, 12.764137305061938, 11.803105928487229, 10.847860103441608, 9.838314137376313, 5.014640720587986, 5.960543111879237, 6.937852069307144, 7.904702996533112, 8.860361132792667, 9.842614740884391, 10.847539962546795, 11.783063867382225, 12.76333253494991, 13.772755021383563, 14.790668838217687, 15.70144175196657, 15.481929162259426, 14.555428383736992, 13.600687728727411, 12.673237842673828, 11.739224031259576, 10.854944706395562, 9.809754263933598, 8.870273409577603, 6.068382656422316, 7.0191224272505846, 7.8853145610980295, 8.879390754821515, 9.805332683676511, 10.786603692254879, 11.722892816064448, 12.737605394228986, 13.709717075420151, 14.63955491064136, 15.705264455364333, 15.611272410459158, 14.68187139962976, 13.611873686428353, 12.702286131781776, 11.774659162272568, 10.764734049217406, 9.924864686250226, 8.857199730393063, 7.876263470090688, 7.078305924778986, 7.963930597122755, 8.92215122396668, 9.91879222709708, 10.848510382793574, 11.776875849123392, 12.755662583422236, 13.714947097181494, 14.73394557500313, 15.64113300875182, 15.685843641131921, 14.646111922692905, 13.668499602802083, 12.677085277419415, 11.684713345909334, 10.734969596740553, 9.744192476622633, 8.88237757880721, 7.931829296581549, 6.930418804827214, 8.00980353505678, 8.97378315069245, 9.967511176265182, 10.975245114339195, 11.871525876361357, 12.830761754155805, 13.75765087583527, 14.646318732656436, 15.717486583782277, 15.600019681124294, 14.66050975812657, 13.691893127186155, 12.660500917016298, 11.709330483775581, 10.746783902740637, 9.792159136105285, 8.790649441820381, 7.825836667482351, 6.933946920689413, 5.959610900694012, 9.076118585690349, 10.009981584177355, 10.935996815699365, 11.870108580121743, 12.843152706713909, 13.780989646838929, 14.751123834307359, 15.64109001565618, 15.592397505730933, 14.57661935139855, 13.643817473738311, 12.699242061472688, 11.735282793673745, 10.797561402469821, 9.802065379380462, 8.839817704320271, 7.788976095474245, 6.8128689653511385, 5.916446530106716, 5.03425291828282, 10.128491266931237, 11.060232933942718, 11.92115545040006, 12.802707188893732, 13.80755102204902, 14.738314806291765, 15.696392042729538, 15.616332403700225, 14.66709729968505, 13.726325292746806, 12.675923451456281, 11.748078502038641, 10.787968665120582, 9.864321426873966, 8.910134259531493, 7.920575760522307, 6.92755671669426, 5.867822621108082, 4.913149134464735, 4.111277813178191, 11.108047649017683, 12.047845672743048, 12.951429104277, 13.87420082411803, 14.777286007040123, 15.677764649106166, 15.930479154044304, 14.900269155783297, 13.935516143970679, 12.8947549322086, 11.822852206760713, 10.776409759023675, 9.817464286230443, 8.860419011891866, 7.92462182430779, 6.966924163701153, 5.996335405701944, 4.935950971230655, 3.9865029489408506, 3.053706244117671, 12.0883140428948, 13.03440744323356, 14.02232252980856, 14.832864772618105, 15.79389513163254, 16.113663251462814, 15.1328902501607, 14.183880848409162, 13.115918948896852, 12.1066529162377, 11.055488975963918, 10.093625004062678, 9.116522136550577, 8.131931975129849, 7.078990753146158, 6.033875931705538, 5.099129381763381, 4.069561803493811, 3.036230516110694, 2.0777474050892164, 13.029114585197703, 13.99354656010992, 14.955629492208756, 15.805874841608345, 16.2925287312574, 15.226692363083332, 14.223443479030738, 13.19498274282999, 12.158658699347367, 11.181488650388356, 10.116444809781516, 9.126109451506046, 8.151764720063747, 7.112121138845141, 6.102051398340622, 5.075021399203202, 4.0635234895542505, 3.0721982419143643, 2.066832598975977, 1.039354060193984, 14.101686594211818, 15.044765747743359, 15.88543096561352, 16.823041185440708, 16.85888201309722, 15.799282369969267, 14.737729849711183, 13.728189848501287, 12.657017005912907, 11.728865823433878, 10.727823611809246, 9.71795294415197, 8.737844110824684, 7.773160296238845, 6.781041871596246, 5.83566279282647, 4.9062691945041434, 3.9766328840228375, 2.9875876496958305, 2.052913221129965, 15.078961290389424, 16.05554483660892, 16.83669514384305, 17.818033085317367, 17.45581287056038, 16.45296305339633, 15.510009876121547, 14.571114568933849, 13.634073295684914, 12.698306712276944, 11.669037490238635, 10.686115734010091, 9.698506916729807, 8.799175586387884, 7.7882691954445065, 6.768844373971945, 5.834560201962225, 4.871074660924521, 3.9220495656345546, 2.9689377780218758, 16.015002374482492, 17.002935344546252, 17.879660909732177, 18.879212565240405, 18.42425363713921, 17.39051878616217, 16.56923955846826, 15.535196152600852, 14.532173518187038, 13.553568409335302, 12.615355560990187, 11.662693828650283, 10.627209888023948, 9.67377906504298, 8.72015945482278, 7.742836003922643, 6.8575512591676455, 5.894931093642466, 4.893887600382171, 3.920623425558726], [3.8233057146991998, 2.835341753915371, 3.8264241316815415, 4.77144237766834, 5.710959759266174, 6.7293249128477015, 7.710400210565055, 8.67640170223696, 9.695631192485564, 10.634345945137277, 11.563085419661224, 12.520517482420331, 13.593461958573883, 14.60331943013706, 15.536140798514616, 16.527823090966947, 17.579236545654034, 17.82495041480181, 17.13024861868904, 17.506155297447748, 2.8208423875519175, 1.890785944365457, 2.863426523857795, 3.803772334119869, 4.786154545861757, 5.789125586593773, 6.836643006878697, 7.878064065637243, 8.892901578052005, 9.897735374491324, 10.897883133761026, 11.890522596511692, 12.838716944458008, 13.843771943912438, 14.790893396637065, 15.769619609553901, 16.80955607772514, 17.840457831068658, 17.38443982666852, 16.48750595671624, 1.9583489820895381, 0.9577543508941868, 1.9785587821477504, 2.978950192125734, 3.976342132056419, 4.947541066581176, 5.88916076161479, 6.9332719059349435, 7.892090142494833, 8.932777694692575, 9.972426654904206, 10.985045215064332, 11.942654074364537, 12.875163434136821, 13.81646377884919, 14.825680692210806, 15.889137592476665, 16.918861188785357, 16.425944333593563, 15.528238171309159, 1.0457558810950975, 0.0, 1.041347418214537, 2.093749422656127, 3.02290062737575, 3.9928357690571694, 4.94922571642064, 5.978859288444956, 6.9626672591278504, 7.94879556046478, 8.906176631846158, 9.93381742496153, 10.957087891445774, 11.932827396376224, 12.90533082453856, 13.875991830398872, 14.928676816548894, 15.942909823018386, 15.497460250517259, 14.557494390089202, 2.0416447419836787, 0.9924460146484081, 1.970285093734216, 3.033804531220568, 3.9644996649199142, 4.891682227246193, 5.8213601168197115, 6.860199401638923, 7.814055029767884, 8.787524572293632, 9.852225982907804, 10.855509176396458, 11.822025908621269, 12.762759770203735, 13.757353036557285, 14.721189895833511, 15.752983773020064, 15.581666177286444, 14.550434020698924, 13.606220970546632, 3.017699321885872, 1.9996242909661954, 2.963335204874555, 3.9658529258129884, 4.942047096493758, 5.905028130409509, 6.783075467197939, 7.815466013559249, 8.752223484749699, 9.754794303914775, 10.758669307354694, 11.702864386286512, 12.714238608478828, 13.698836144717317, 14.675196256026801, 15.61835430230169, 15.53009078302011, 14.54565173844021, 13.54930439714616, 12.548664233913703, 3.903577364241557, 2.963620504632753, 3.934814519351448, 4.953356148426664, 5.907986572281868, 6.872274455401108, 7.759864123027263, 8.8111452615817, 9.78075158338188, 10.740967772401536, 11.754745537696726, 12.648253000341052, 13.659200722462629, 14.683492269004939, 15.614800789189394, 15.47917436116413, 14.455512611007265, 13.51268627063241, 12.508016772712189, 11.578950944187657, 4.834205996221917, 3.960700683029961, 4.924033391333591, 5.962316101548869, 6.941212735317453, 7.880948996728251, 8.821783957859273, 9.767958214448592, 10.726242282884662, 11.735604061265091, 12.745354225066912, 13.629561006529551, 14.627715730814398, 15.56592036558951, 15.42848054238625, 14.484342562436263, 13.539375407068835, 12.55508981651356, 11.599843991467939, 10.590298025402642, 5.766624608614315, 4.914787230784141, 5.892096188212047, 6.858947115438015, 7.81460525169757, 8.796858859789294, 9.801784081451698, 10.737307986287128, 11.717576653854813, 12.726999140288466, 13.74491295712259, 14.655685870871473, 15.635259016513395, 15.388729212971361, 14.433988557961781, 13.506538671908197, 12.572524860493946, 11.606928594421891, 10.561738151959927, 9.622257297603932, 6.820366544448645, 5.9733665461554875, 6.839558680002932, 7.8336348737264165, 8.759576802581414, 9.740847811159782, 10.67713693496935, 11.691849513133889, 12.663961194325054, 13.593799029546263, 14.659508574269235, 15.605498763684803, 15.587503829310307, 14.517506116108901, 13.595162330996267, 12.66753536148706, 11.657610248431897, 10.676848574276555, 9.609183618419392, 8.628247358117017, 7.830289812805315, 6.918174716027658, 7.876395342871583, 8.873036346001982, 9.802754501698477, 10.731119968028295, 11.709906702327139, 12.669191216086396, 13.688189693908033, 14.595377127656723, 15.575319917222377, 15.60856667734041, 14.630954357449587, 13.582717707099963, 12.590345775589881, 11.640602026421103, 10.649824906303182, 9.701483195650283, 8.683813184607878, 7.682402692853543, 8.76178742308311, 7.928027269597353, 8.921755295170085, 9.929489233244096, 10.82576999526626, 11.785005873060708, 12.711894994740172, 13.600562851561339, 14.67173070268718, 15.580953224632362, 15.639836872324466, 14.65434788183366, 13.622955671663803, 12.61496291345613, 11.652416332421186, 10.697791565785835, 9.696281871500931, 8.7314690971629, 7.729160596208095, 6.711594788720341, 9.828102473716676, 8.964225703082258, 9.890240934604268, 10.824352699026646, 11.797396825618812, 12.735233765743832, 13.705367953212262, 14.595334134561083, 15.61074798432521, 15.555946465596445, 14.623144587936206, 13.671867621237869, 12.707908353438926, 11.753698922112266, 10.707697809061012, 9.745450134000821, 8.694608525154795, 7.718501395031688, 6.784083140198593, 5.786236806309149, 10.880475154957564, 10.01447705284762, 10.875399569304962, 11.756951307798635, 12.761795140953923, 13.692558925196668, 14.650636161634441, 15.592501603524948, 15.646424413882945, 14.7056524069447, 13.655250565654176, 12.727405616236537, 11.767295779318477, 10.83698255367619, 9.882795386333717, 8.830873749671689, 7.837854705843643, 6.7781206102574645, 5.823447123614118, 4.869302999738389, 11.86003153704401, 11.00208979164795, 11.905673223181903, 12.828444943022934, 13.731530125945026, 14.632008768011069, 15.589387344089747, 15.879596269981192, 14.914843258168574, 13.874082046406496, 12.802179320958608, 11.75573687322157, 10.796791400428338, 9.83974612608976, 8.903948938505685, 7.946251277899049, 6.906633394851327, 5.846248960380038, 4.896800938090234, 3.9640042332670546, 12.840297930921126, 12.07439927598905, 12.976566648713463, 13.787108891523008, 14.748139250537443, 15.629855287574754, 16.1786461312558, 15.229636729504259, 14.161674829991949, 13.152408797332798, 12.101244857059017, 11.139380885157777, 10.162278017645674, 9.177687856224946, 8.124746634241255, 7.079631812800635, 6.1448852628584785, 5.115317684588908, 4.070914228695719, 3.112431117674242, 13.78109847322403, 13.12467976625724, 13.909873611113658, 14.760118960513248, 15.754107578148115, 16.272448244178435, 15.269199360125839, 14.240738623925091, 13.204414580442467, 12.227244531483457, 11.162200690876615, 10.171865332601145, 9.197520601158846, 8.157877019940239, 7.147807279435719, 6.120777280298299, 5.109279370649348, 4.117954123009461, 3.112588480071074, 2.0851099412890814, 14.853670482238146, 14.175898953890677, 14.839675084518422, 15.77728530434561, 16.735420707123257, 16.777289794989727, 15.715737274731644, 14.706197273521749, 13.635024430933369, 12.70687324845434, 11.705831036829707, 10.69596036917243, 9.715851535845145, 8.751167721259305, 7.7590492966167055, 6.81367021784693, 5.884276619524603, 4.954640309043297, 3.9655950747162896, 3.0309206461504243, 15.830945178415751, 15.186678042756238, 15.790939262747953, 16.77227720422227, 17.7359417964985, 17.219279987902432, 16.276326810627648, 15.337431503439948, 14.400390230191013, 13.464623646783043, 12.502977225851676, 11.520055469623133, 10.532446652342848, 9.626895262852383, 8.617334245911312, 7.5979094244387495, 6.636729818378425, 5.673244277340721, 4.724219182050755, 3.7711073944380757, 16.76698626250882, 16.13406855069357, 16.83390502863708, 17.833456684145307, 17.468550448100668, 16.55324867121578, 15.551176108124952, 14.526729348067398, 13.486417637091941, 12.507812528240205, 11.671312906024937, 10.627952926175624, 9.603743681048707, 8.628023183947883, 7.674403573727682, 6.738599995566511, 5.811795378072548, 4.849175212547369, 3.901820167145928, 4.722793041974926], [4.844744734891995, 3.856780774108166, 3.0251841146420775, 3.8968941477926435, 4.80980215291068, 5.812214548323071, 6.764881725910362, 7.730883217582267, 8.75011270783087, 9.688827460482582, 10.61756693500653, 11.574998997765636, 12.647943473919188, 13.657800945482364, 14.590622313859921, 15.582304606312254, 16.633718060999342, 16.92528470989752, 17.771997447020713, 18.469321151251492, 3.8422814077447125, 2.912224964558252, 1.9888782939820984, 2.929224104244173, 3.880647939404081, 4.872015222069143, 5.810105351023302, 6.838494002185787, 7.853331514600549, 8.858165311039867, 9.858313070309569, 10.850952533060235, 11.799146881006552, 12.804201880460981, 13.749545978422528, 14.728272191339364, 15.768208659510602, 16.79911041285412, 17.775521720827943, 17.450671810519985, 2.9797880022823326, 1.9791933710869816, 0.9372113639332134, 1.9376027739111972, 2.9349947138418817, 3.906193648366639, 4.8478133434002535, 5.891924487720407, 6.8507427242802965, 7.891430276478038, 8.93107923668967, 9.943697796849795, 10.90130665615, 11.833816015922284, 12.775116360634653, 13.78433327399627, 14.847790174262128, 15.877513770570818, 16.817026227752987, 16.491404025112907, 2.087103299309635, 1.041347418214537, 0.0, 1.05240200444159, 1.9815532091612131, 2.9514883508426326, 3.9078782982061036, 4.937511870230419, 5.921319840913314, 6.907448142250243, 7.864829213631621, 8.892470006746994, 9.915740473231237, 10.891479978161687, 11.863983406324023, 12.834644412184335, 13.887329398334357, 14.90156240480385, 15.921760072453521, 15.520660243892952, 3.004810595787427, 1.9556118684521564, 0.9777727893663485, 2.0412922268527005, 2.96718660083842, 3.894369163164699, 4.8240470527382175, 5.862886337557429, 6.81674196568639, 7.790211508212138, 8.837491626786235, 9.828016966595309, 10.79453369882012, 11.735267560402585, 12.729860826756136, 13.693697686032362, 14.725491563218915, 15.773359418908889, 15.513599874502674, 14.569386824350381, 3.9808651756896207, 2.9627901447699436, 1.9708229005066875, 2.973340621445121, 3.944734032412264, 4.907715066328015, 5.785762403116445, 6.818152949477755, 7.754910420668205, 8.75748123983328, 9.7613562432732, 10.705551322205018, 11.716925544397334, 12.701523080635823, 13.677883191945307, 14.621041238220196, 15.679889040041296, 15.50881759224396, 14.51247025094991, 13.511830087717453, 4.866743218045306, 3.9267863584365013, 2.988141635022906, 3.981628228643945, 4.910673508200373, 5.874961391319614, 6.762551058945769, 7.813832197500206, 8.783438519300386, 9.743654708320042, 10.757432473615232, 11.650939936259558, 12.661887658381135, 13.686179204923445, 14.6174877251079, 15.670190550535585, 15.418678464811014, 14.475852124436159, 13.471182626515938, 12.542116797991406, 5.797371850025666, 4.923866536833709, 4.013593729816184, 4.99058818176615, 5.943899671235958, 6.883635932646756, 7.824470893777779, 8.770645150367098, 9.728929218803168, 10.738290997183597, 11.748041160985418, 12.632247942448057, 13.630402666732904, 14.568607301508017, 15.591056391075735, 15.447508416240012, 14.502541260872583, 13.518255670317307, 12.563009845271687, 11.553463879206392, 6.7297904624180624, 5.8779530845878885, 4.98165652669464, 5.948507453920608, 6.869723329651885, 7.8519769377436095, 8.804471017370204, 9.739994922205634, 10.72026358977332, 11.729686076206972, 12.747599893041096, 13.658372806789979, 14.6379459524319, 15.532890559874527, 15.39715441176553, 14.469704525711947, 13.535690714297695, 12.57009444822564, 11.524904005763677, 10.585423151407682, 7.783532398252393, 6.929740920139164, 5.929119018485525, 6.923195212209009, 7.814694880535728, 8.795965889114097, 9.732255012923666, 10.694536449052395, 11.66664813024356, 12.596485965464769, 13.662195510187741, 14.60818569960331, 15.61552857840996, 15.480671969912652, 14.558328184800017, 13.63070121529081, 12.620776102235647, 11.640014428080304, 10.572349472223141, 9.591413211920766, 8.793455666609063, 7.874549090011334, 6.965955681354176, 7.962596684484575, 8.857872579652792, 9.78623804598261, 10.765024780281454, 11.724309294040712, 12.720670161247222, 13.59806406357523, 14.578006853140883, 15.573346187369562, 15.594120211253337, 14.545883560903714, 13.553511629393633, 12.603767880224853, 11.612990760106932, 10.664649049454033, 9.646979038411628, 8.645568546657293, 9.724953276886858, 8.884401643581029, 8.022089590265798, 9.01904957172669, 9.880888073220575, 10.840123951015023, 11.767013072694487, 12.655680929515654, 13.726848780641495, 14.583640160550868, 15.603340736146233, 15.61751373563741, 14.586121525467552, 13.57812876725988, 12.615582186224936, 11.660957419589584, 10.65944772530468, 9.69463495096665, 8.692326450011844, 7.67476064252409, 10.791268327520424, 9.920600077065934, 8.990575229699981, 9.924686994122359, 10.852514903573127, 11.790351843698147, 12.760486031166577, 13.650452212515399, 14.665866062279525, 15.607040490276612, 15.586310441739958, 14.635033475041618, 13.671074207242675, 12.716864775916015, 11.670863662864761, 10.70861598780457, 9.657774378958544, 8.681667248835437, 7.747248994002342, 6.749402660112898, 11.843641008761312, 10.970851426831295, 9.975733864400675, 10.857285602894349, 11.862129436049637, 12.747677003150983, 13.705754239588757, 14.647619681479263, 15.596854785494438, 15.668818260748452, 14.618416419457928, 13.690571470040288, 12.730461633122228, 11.800148407479941, 10.845961240137468, 9.79403960347544, 8.801020559647393, 7.741286464061214, 6.786612977417867, 5.832468853542138, 12.823197390847758, 11.958464165631625, 11.006007518277617, 11.928779238118647, 12.83186442104074, 13.687126845965384, 14.644505422044062, 15.673463179174549, 15.878009111972325, 14.837247900210247, 13.76534517476236, 12.718902727025322, 11.75995725423209, 10.802911979893512, 9.867114792309437, 8.9094171317028, 7.8697992486550765, 6.809414814183787, 5.859966791893983, 4.927170087070803, 13.803463784724874, 13.030773649972724, 12.076900943809177, 12.887443186618722, 13.848473545633157, 14.68497336552907, 15.645605372711575, 16.270984147718796, 15.203022248206487, 14.193756215547335, 13.142592275273554, 12.180728303372314, 11.20362543586021, 10.219035274439483, 9.166094052455792, 8.120979231015172, 7.137598313098321, 6.0991411312844495, 5.034080082499467, 4.07559697147799, 14.744264327027778, 13.978164025565093, 13.010207906209372, 13.860453255608961, 14.854441873243829, 15.73866434683694, 16.310546778340374, 15.282086042139627, 14.245761998657002, 13.268591949697992, 12.203548109091152, 11.213212750815682, 10.238868019373383, 9.199224438154776, 8.189154697650256, 7.1621246985128355, 6.150626788863885, 5.159301541223999, 4.153935898285612, 3.1264573595036187, 15.816836336041893, 14.995667118558522, 13.940009379614136, 14.877619599441323, 15.83575500221897, 16.791234209481846, 16.341234538867237, 15.331694537657341, 14.416697233450442, 13.488546050971413, 12.537570474577842, 11.527699806920566, 10.54759097359328, 9.682113103719564, 8.689994679076964, 7.744615600307189, 6.905715639717397, 5.976079329236091, 4.987034094909085, 4.052359666343219, 16.794111032219497, 15.828426871087908, 14.891273557843666, 15.872611499317982, 16.836276091594215, 16.273761503247737, 15.330808325972951, 14.391913018785253, 13.454871745536318, 12.519105162128348, 11.557458741196985, 10.574536984968441, 9.586928167688157, 8.709784898327753, 7.7404051089907195, 6.811434019161715, 5.973565469805531, 5.084301324307903, 5.74565820224355, 4.792546414630871, 17.730152116312563, 16.77581737902524, 15.934239323732793, 16.933790979241017, 16.523031963445977, 15.607730186561085, 14.605657623470258, 13.581210863412704, 12.540899152437246, 11.56229404358551, 10.725794421370242, 9.682434441520929, 8.658225196394014, 7.710912819423253, 6.757293209203052, 5.8374423892110165, 4.937247148196852, 4.047935195507905, 4.923259187338723, 5.744232062167721], [5.876532892433098, 4.888568931649269, 4.007678363266997, 2.998696775893414, 3.822582443380231, 4.782749849389724, 5.712479721468773, 6.678481213140678, 7.697710703389281, 8.636425456040994, 9.565164930564942, 10.522596993324049, 11.5955414694776, 12.605398941040777, 13.538220309418334, 14.529902601870667, 15.581316056557753, 16.544044540011186, 17.603890594423376, 18.671706606131657, 4.874069565285816, 3.9440131220993555, 2.9713725426070177, 2.0310267323449436, 2.8934282298736322, 3.842550523135795, 4.757703346581712, 5.786091997744197, 6.800929510158959, 7.805763306598278, 8.80591106586798, 9.798550528618646, 10.746744876564962, 11.751799876019392, 12.697143973980939, 13.675870186897775, 14.715806655069013, 15.74670840841253, 16.723119716386353, 17.738854223856002, 4.032190006723923, 3.0315953755285716, 1.9896133683748034, 1.0105719853762671, 1.947775004311433, 2.8767289494332906, 3.7954113389586634, 4.839522483278817, 5.7983407198387065, 6.839028272036449, 7.878677232248081, 8.891295792408206, 9.848904651708411, 10.781414011480695, 11.722714356193064, 12.73193126955468, 13.795388169820539, 14.825111766129229, 15.764624223311396, 16.780067709659946, 3.1395053037512244, 2.093749422656127, 1.05240200444159, 0.0, 0.9291512047196232, 1.899086346401043, 2.855476293764514, 3.88510986578883, 4.8689178364717245, 5.855046137808654, 6.812427209190032, 7.840068002305404, 8.863338468789648, 9.839077973720098, 10.811581401882433, 11.782242407742746, 12.834927393892768, 13.84916040036226, 14.869358068011932, 15.809323928439989, 4.057212600229017, 3.0080138728937467, 2.0301747938079386, 1.0386827066380218, 1.9147845963968297, 2.841967158723109, 3.7716450482966275, 4.810484333115838, 5.764339961244799, 6.737809503770547, 7.785089622344646, 8.77561496215372, 9.74213169437853, 10.682865555960996, 11.677458822314547, 12.641295681590773, 13.673089558777326, 14.7209574144673, 15.76349194143271, 15.62178882879197, 5.033267180131212, 4.0151921492115346, 2.9906822045782344, 1.988164483639801, 2.892332027970674, 3.855313061886424, 4.733360398674856, 5.7657509450361655, 6.702508416226614, 7.705079235391689, 8.708954238831609, 9.653149317763427, 10.664523539955743, 11.649121076194232, 12.625481187503716, 13.568639233778605, 14.627487035599705, 15.692361274911224, 15.5648722553915, 14.564232092159042, 5.919145222486896, 4.979188362878092, 4.008000939094453, 2.9964520908386247, 3.8582715037587834, 4.822559386878023, 5.71014905450418, 6.761430193058617, 7.731036514858797, 8.69125270387845, 9.705030469173641, 10.598537931817967, 11.609485653939544, 12.633777200481854, 13.565085720666309, 14.617788546093994, 15.64145029625086, 15.528254128877748, 14.523584630957528, 13.594518802432995, 6.849773854467256, 5.976268541275299, 5.033453033887731, 4.00541204396083, 4.891497666794368, 5.831233928205166, 6.77206888933619, 7.718243145925509, 8.67652721436158, 9.685888992742004, 10.695639156543825, 11.579845938006466, 12.578000662291313, 13.516205297066426, 14.538654386634144, 15.55843757033132, 15.554943265314172, 14.570657674758897, 13.615411849713276, 12.605865883647981, 7.782192466859653, 6.9303550890294785, 5.96169182009943, 4.994840892873462, 5.817321325210296, 6.79957493330202, 7.752069012928616, 8.687592917764047, 9.667861585331732, 10.67728407176538, 11.695197888599504, 12.605970802348388, 13.58554394799031, 14.480488555432935, 15.435229210442515, 15.522106530153536, 14.588092718739285, 13.62249645266723, 12.577306010205266, 11.63782515584927, 8.835934402693985, 7.909776213543953, 6.909154311890315, 6.0415834314241215, 6.762292876094139, 7.743563884672507, 8.679853008482075, 9.642134444610807, 10.614246125801973, 11.544083961023182, 12.609793505746154, 13.555783695161722, 14.563126573968372, 15.473258264697288, 15.604999378331081, 14.683103219732399, 13.673178106677236, 12.692416432521894, 11.62475147666473, 10.643815216362356, 9.801331977402477, 8.854584383416123, 7.945990974758966, 7.080984903699687, 7.805470575211203, 8.733836041541021, 9.712622775839863, 10.67190728959912, 11.668268156805635, 12.545662059133642, 13.525604848699295, 14.520944182927975, 15.513465037684776, 15.455149534633131, 14.568308209292404, 13.655015817940791, 12.665392764548521, 11.717051053895622, 10.699381042853217, 9.697970551098882, 10.732829587680271, 9.864436936985818, 9.002124883670588, 8.137437790941801, 8.828486068778986, 9.787721946573434, 10.714611068252896, 11.603278925074065, 12.674446776199906, 13.53123815610928, 14.550938731704646, 15.475162978434724, 15.35893060257087, 14.484476075006752, 13.527531621533871, 12.633959115801447, 11.71184972974627, 10.74703695540824, 9.744728454453433, 8.72716264696568, 11.799144638313837, 10.900635370470724, 9.97061052310477, 9.11037409692205, 9.800112899131538, 10.737949839256558, 11.708084026724988, 12.59805020807381, 13.613464057837936, 14.554638485835024, 15.487440363495264, 15.315355104827216, 14.433712479228317, 13.495991088024393, 12.564144218114766, 11.678264951764687, 10.710176383400134, 9.734069253277026, 8.799650998443932, 7.801804664554488, 12.851517319554725, 11.950886720236085, 10.955769157805465, 10.042972705694039, 10.810843091496402, 11.695274998709394, 12.653352235147167, 13.595217677037674, 14.544452781052849, 15.485224787991093, 15.291766384437063, 14.363921435019423, 13.486398350675154, 12.562751112428538, 11.608563945086065, 10.753182894576536, 9.853422564088985, 8.793688468502806, 7.839014981859458, 6.884870857983728, 13.831073701641172, 12.938499459036414, 11.986042811682406, 11.114466340918337, 11.780578076487505, 12.634724841523795, 13.592103417602473, 14.62106117473296, 15.571969636348385, 15.4490147584196, 14.435601567473611, 13.392252692004456, 12.515893971785015, 11.558848697446438, 10.623051509862362, 9.699739355137167, 8.922201253096668, 7.861816818625378, 6.912368796335574, 5.979572091512394, 14.811340095518288, 14.010808943377514, 13.044371121682442, 12.073130289418412, 12.797187201079922, 13.63257136108748, 14.593203368269986, 15.542212770021525, 15.424836219664916, 14.424905471320415, 13.373741531046633, 12.411877559145394, 11.567258134162634, 10.66932443550934, 9.656578529459015, 8.766691123141552, 8.050925601457525, 7.15154313572604, 6.086482086941058, 5.1279989759195805, 15.752140637821192, 14.945634203438358, 13.977678084082637, 13.046140358408651, 13.834618019835967, 14.68626234239535, 15.607688194257696, 15.269042524784508, 14.432524193297185, 13.493398595562525, 12.434697364864231, 11.444362006588761, 10.55663338996782, 9.649513599224633, 8.643982638248255, 7.807836590639215, 7.015319709248394, 6.211703545665588, 5.206337902727201, 4.178859363945208, 16.82471264683531, 15.963137296431785, 14.9074795574874, 14.063306702241013, 14.876968303977241, 15.738832205040259, 15.288832534425651, 14.279292533215756, 13.364295229008857, 12.436144046529828, 11.485168470136252, 10.475297802478975, 9.49518896915169, 8.694893394189116, 7.702774969546516, 6.75739589077674, 6.0160330150069745, 6.94566932548828, 6.039436099350675, 5.104761670784809, 17.801987343012915, 16.795897048961173, 15.858743735716931, 15.058298602117672, 15.877489393352485, 15.22135949880615, 14.278406321531365, 13.339511014343667, 12.402469741094732, 11.466703157686762, 10.505056736755394, 9.52213498052685, 8.534526163246566, 7.6701723656006555, 6.710940410057372, 5.824214309631266, 5.075368097906302, 6.038853638944007, 6.777446359784653, 5.824334572171974, 18.73802842710598, 17.743287556898505, 16.90170950160606, 16.119478082040708, 15.47062995900439, 14.555328182119498, 13.55325561902867, 12.528808858971116, 11.488497147995659, 10.509892039143923, 9.673392416928655, 8.63003243707934, 7.605823191952424, 6.671300286696155, 5.727828510269704, 4.850222679680567, 4.039049776297623, 5.0193573688066655, 5.9550473448798265, 6.776020219708824], [6.7921653969840525, 5.804201436200223, 4.892494205043143, 3.832948620258443, 2.8934312386606083, 3.8535986446701, 4.783328516749149, 5.749330008421055, 6.768559498669657, 7.70727425132137, 8.636013725845318, 9.593445788604425, 10.666390264757977, 11.676247736321153, 12.60906910469871, 13.600751397151043, 14.65216485183813, 15.61489333529156, 16.67473938970375, 17.74255540141203, 5.78970206983677, 4.85964562665031, 3.887005047157972, 2.9466592368958975, 1.9642770251540091, 2.9133993184161713, 3.828552141862089, 4.856940793024575, 5.871778305439336, 6.876612101878655, 7.876759861148357, 8.869399323899025, 9.81759367184534, 10.82264867129977, 11.767992769261316, 12.746718982178152, 13.78665545034939, 14.817557203692907, 15.79396851166673, 16.80970301913638, 4.961341211443546, 3.9607465802481947, 2.9187645730944265, 1.9397231900958904, 1.01862379959181, 1.9475777447136673, 2.8662601342390404, 3.910371278559194, 4.869189515119084, 5.909877067316826, 6.949526027528457, 7.962144587688582, 8.919753446988787, 9.852262806761072, 10.79356315147344, 11.802780064835057, 12.866236965100915, 13.895960561409606, 14.835473018591772, 15.850916504940322, 4.068656508470848, 3.0229006273757504, 1.9815532091612131, 0.9291512047196232, 0.0, 0.9699351416814197, 1.9263250890448906, 2.9559586610692064, 3.939766631752101, 4.9258949330890305, 5.883276004470408, 6.910916797585781, 7.934187264070024, 8.909926769000474, 9.88243019716281, 10.853091203023123, 11.905776189173144, 12.920009195642637, 13.940206863292309, 14.880172723720365, 4.98636380494864, 3.9371650776133698, 2.9593259985275617, 1.916328525376553, 0.9856333916772066, 1.9128159540034857, 2.8424938435770044, 3.881333128396215, 4.835188756525176, 5.808658299050925, 6.855938417625023, 7.846463757434095, 8.812980489658905, 9.75371435124137, 10.748307617594921, 11.712144476871147, 12.7439383540577, 13.791806209747675, 14.834340736713084, 15.779780985243123, 5.9238349180413525, 4.905759887121675, 3.8683280233167654, 2.865810302378332, 1.9631808232510508, 2.926161857166801, 3.8042091939552325, 4.836599740316542, 5.773357211506992, 6.775928030672066, 7.779803034111986, 8.723998113043805, 9.735372335236121, 10.71996987147461, 11.696329982784095, 12.639488029058983, 13.698335830880083, 14.763210070191601, 15.75955741148565, 15.44188450183263, 6.796797632160484, 5.85684077255168, 4.885646757832984, 3.8740979095771557, 2.9291202990391607, 3.8934081821584003, 4.780997849784557, 5.832278988338993, 6.801885310139173, 7.7621014991588275, 8.77587926445402, 9.669386727098345, 10.680334449219922, 11.704625995762232, 12.635934515946687, 13.688637341374372, 14.712299091531237, 15.655125431906093, 15.401237040631116, 14.472171212106584, 7.727426264140844, 6.853920950948888, 5.911098852626262, 4.883057862699361, 3.9623464620747457, 4.9020827234855435, 5.842917684616566, 6.789091941205886, 7.747376009641956, 8.756737788022383, 9.766487951824203, 10.650694733286844, 11.648849457571691, 12.587054092346804, 13.609503181914523, 14.629286365611698, 15.576706284930566, 15.448310084432487, 14.493064259386866, 13.48351829332157, 8.65984487653324, 7.790693908662442, 6.810679183976195, 5.843828256750227, 4.888170120490672, 5.870423728582397, 6.8229178082089925, 7.758441713044423, 8.738710380612108, 9.748132867045758, 10.766046683879882, 11.676819597628766, 12.656392743270688, 13.551337350713315, 14.506078005722895, 14.793821915466792, 15.465745128412873, 14.500148862340819, 13.454958419878855, 12.51547756552286, 9.713586812367572, 8.758763577420718, 7.75814167576708, 6.776011002046776, 5.8331416713745154, 6.814412679952883, 7.750701803762452, 8.712983239891184, 9.68509492108235, 10.614932756303558, 11.68064230102653, 12.626632490442098, 13.633975369248748, 14.544107059977668, 14.675848173611458, 13.795466845207018, 14.550830516350825, 13.570068842195482, 12.50240388633832, 11.521467626035944, 10.650319341279241, 9.703571747292887, 8.79497833863573, 7.815412474322342, 6.876319370491579, 7.804684836821399, 8.78347157112024, 9.742756084879497, 10.739116952086011, 11.616510854414019, 12.596453643979672, 13.591792978208352, 14.584313832965153, 14.525998329913508, 13.63915700457278, 12.725864613221168, 13.54304517422211, 12.59470346356921, 11.577033452526805, 10.57562296077247, 11.581816951557036, 10.713424300862583, 9.851112247547352, 8.871865361564456, 7.899334864059362, 8.85857074185381, 9.785459863533273, 10.674127720354441, 11.745295571480282, 12.602086951389657, 13.621787526985022, 14.546011773715101, 14.429779397851247, 13.555324870287128, 12.598380416814248, 11.704807911081824, 12.589502139419858, 11.624689365081828, 10.62238086412702, 9.604815056639268, 12.648132002190604, 11.749622734347488, 10.778913431967082, 9.844801667544704, 8.870961694411914, 9.808798634536934, 10.778932822005364, 11.668899003354186, 12.684312853118312, 13.6254872811154, 14.55828915877564, 14.386203900107592, 13.504561274508694, 12.56683988330477, 11.634993013395142, 10.749113747045064, 11.587828793073722, 10.611721662950615, 9.67730340811752, 8.679457074228075, 13.700504683431491, 12.79987408411285, 11.764072066667776, 10.777400276316694, 9.881691886776778, 10.76612379398977, 11.724201030427544, 12.66606647231805, 13.615301576333225, 14.55607358327147, 14.362615179717439, 13.434770230299799, 12.55724714595553, 11.633599907708915, 10.679412740366441, 9.824031689856913, 10.738040161235956, 9.684256206412947, 8.7295827197696, 7.762523267657316, 14.680061065517938, 13.78748682291318, 12.794345720544715, 11.81833860062983, 10.851426871767881, 11.705573636804171, 12.66295221288285, 13.691909970013336, 14.642818431628761, 14.519863553699976, 13.506450362753988, 12.463101487284833, 11.586742767065392, 10.629697492726814, 9.693900305142739, 8.770588150417543, 9.806818850243639, 8.75238455653552, 7.802936534245715, 6.870139829422535, 15.660327459395054, 14.810257421606332, 13.748243381393934, 12.777002549129904, 11.868035996360298, 12.703420156367857, 13.664052163550362, 14.613061565301901, 14.495685014945293, 13.495754266600791, 12.44459032632701, 11.48272635442577, 10.63810692944301, 9.740173230789717, 8.727427324739391, 7.837539918421928, 8.792530870829994, 8.080694340445662, 7.015633291660681, 6.057150180639203, 15.88088976521522, 15.64950646314985, 14.681550343794129, 13.750012618120143, 12.905466815116343, 13.757111137675727, 14.678536989538072, 14.339891320064885, 13.503372988577562, 12.564247390842901, 11.505546160144608, 10.515210801869138, 9.627482185248196, 8.72036239450501, 7.714831433528633, 6.878685385919592, 7.756924978620864, 7.140854750385213, 6.135489107446825, 5.108010568664833, 16.8446792105903, 16.667009556143277, 15.611351817198893, 14.767178961952505, 13.947817099257618, 14.809681000320635, 14.359681329706028, 13.350141328496132, 12.435144024289233, 11.506992841810204, 10.556017265416628, 9.546146597759352, 8.566037764432066, 7.765742189469492, 6.773623764826893, 5.8282446860571175, 6.7576382843794445, 7.68727459486075, 6.968587304070298, 6.0339128755044324, 17.821953906767906, 17.499769308672665, 16.562615995428423, 15.762170861829164, 14.948338188632862, 14.292208294086526, 13.349255116811742, 12.410359809624044, 11.473318536375109, 10.537551952967139, 9.57590553203577, 8.592983775807227, 7.605374958526943, 6.741021160881032, 5.781789205337747, 4.895063104911643, 5.8562427109719675, 6.819728252009672, 7.693078864335607, 6.7399670767229285, 18.660609790636357, 17.635029834704063, 16.60593872145629, 15.616286992686145, 14.541478754284766, 13.626176977399874, 12.624104414309047, 11.599657654251493, 10.559345943276035, 9.580740834424299, 8.744241212209031, 7.700881232359716, 6.6766719872328, 5.742149081976532, 4.79867730555008, 3.9210714749609448, 4.873301620662652, 5.853609213171694, 6.867798147885901, 7.691652724259779], [7.722383134949247, 6.734419174165419, 5.822711943008336, 4.763166358223637, 3.823648976625803, 2.8836635029886803, 3.81339337506773, 4.7793948667396355, 5.798624356988238, 6.737339109639951, 7.666078584163899, 8.623510646923007, 9.696455123076559, 10.706312594639735, 11.639133963017292, 12.630816255469625, 13.682229710156712, 14.644958193610142, 15.70480424802233, 16.772620259730612, 6.719919807801965, 5.789863364615504, 4.817222785123167, 3.8768769748610925, 2.894494763119204, 1.9434641767347518, 2.8586170001806694, 3.887005651343155, 4.901843163757916, 5.906676960197235, 6.906824719466937, 7.899464182217604, 8.847658530163919, 9.852713529618349, 10.798057627579896, 11.776783840496732, 12.81672030866797, 13.847622062011485, 14.82403336998531, 15.839767877454957, 5.931276353124966, 4.930681721929615, 3.8886997147758464, 2.90965833177731, 1.948841537557005, 0.9776426030322476, 1.8963249925576207, 2.940436136877774, 3.8992543734376643, 4.939941925635407, 5.9795908858470375, 6.992209446007162, 7.949818305307367, 8.882327665079652, 9.82362800979202, 10.832844923153637, 11.896301823419495, 12.926025419728186, 13.865537876910352, 14.880981363258902, 5.038591650152268, 3.9928357690571703, 2.951488350842633, 1.899086346401043, 0.9699351416814197, 0.0, 0.9563899473634709, 1.9860235193877867, 2.969831490070681, 3.9559597914076106, 4.9133408627889885, 5.940981655904361, 6.964252122388604, 7.9399916273190545, 8.91249505548139, 9.883156061341703, 10.935841047491724, 11.950074053961217, 12.970271721610889, 13.910237582038945, 5.951259237605363, 4.9020605102700925, 3.9242214311842845, 2.8607019936979325, 1.9300068599985865, 1.0028242976723074, 1.931348428476596, 2.9701877132958066, 3.924043341424768, 4.897512883950516, 5.886003275943603, 6.876528615752675, 7.843045347977485, 8.78377920955995, 9.778372475913502, 10.742209335189727, 11.77400321237628, 12.821871068066255, 13.864405595031664, 14.809845843561703, 6.868208386362731, 5.850133355443054, 4.812701491638145, 3.8101837706997115, 2.9075542915724304, 2.0161702008356226, 2.893063778854824, 3.9254543252161334, 4.862211796406584, 5.864782615571658, 6.8277913682364435, 7.7719864471682625, 8.78336066936058, 9.767958205599069, 10.744318316908553, 11.68747636318344, 12.746324165004541, 13.811198404316059, 14.807545745610108, 15.821791122583395, 7.741171100481863, 6.801214240873059, 5.830020226154364, 4.818471377898535, 3.8734937673605403, 2.983416525827222, 3.869852434684148, 4.921133573238585, 5.890739895038765, 6.850956084058419, 7.823867598578476, 8.717375061222803, 9.72832278334438, 10.75261432988669, 11.683922850071145, 12.73662567549883, 13.760287425655696, 14.703113766030551, 15.707783263950772, 15.416544680427965, 8.671799732462224, 7.798294419270267, 6.855472320947642, 5.82743133102074, 4.906719930396125, 4.025153785156448, 4.931772269516157, 5.877946526105477, 6.836230594541547, 7.845592372921975, 8.855342536723795, 9.698683067411302, 10.696837791696149, 11.635042426471262, 12.65749151603898, 13.677274699736156, 14.624694619055024, 15.6089802096103, 15.437437727708247, 14.42789176164295, 9.60421834485462, 8.735067376983823, 7.755052652297575, 6.788201725071607, 5.832543588812053, 5.061724613920488, 5.911772393108584, 6.847296297944014, 7.8275649655117, 8.836987451945351, 9.854901268779475, 10.724807931753224, 11.704381077395146, 12.599325684837773, 13.554066339847353, 14.481516225900936, 15.415530037315188, 15.444522330662199, 14.399331888200235, 13.45985103384424, 10.657960280688952, 9.703137045742098, 8.70251514408846, 7.720384470368156, 6.777515139695896, 6.039966212968345, 6.915858453030833, 7.801837824790776, 8.77394950598194, 9.70378734120315, 10.769496885926122, 11.71548707534169, 12.72282995414834, 13.592095394102126, 13.72493583363066, 14.652562803139867, 15.495203984672205, 14.514442310516863, 13.4467773546597, 12.465841094357325, 11.594692809600621, 10.647945215614268, 9.73935180695711, 8.759785942643722, 7.82069283881296, 7.107835993279025, 7.9486282203886205, 8.858018941662095, 9.827971536985602, 10.70536543931361, 11.685308228879263, 12.680647563107943, 13.673168417864744, 13.57508598993271, 12.688244664591982, 13.622534321053886, 14.48741864254349, 13.539076931890591, 12.521406920848186, 11.519996429093851, 12.526190419878416, 11.657797769183963, 10.795485715868733, 9.816238829885837, 8.843708332380743, 8.161721898311438, 8.950616512801654, 9.789390577137038, 10.860558428262879, 11.690941536289248, 12.710642111884614, 13.634866358614692, 13.478867057870449, 12.60441253030633, 11.64746807683345, 12.601477618914542, 13.533875607741239, 12.569062833403208, 11.5667543324484, 10.549188524960648, 13.592505470511984, 12.693996202668869, 11.723286900288462, 10.789175135866085, 9.815335162733295, 9.111949790994561, 10.00195899772407, 10.784161860136782, 11.799575709900909, 12.714341866014992, 13.647143743675231, 13.416268758426172, 12.553648934527896, 11.615927543323972, 10.684080673414345, 11.645783454877781, 12.532202261395103, 11.556095131271995, 10.621676876438901, 9.623830542549456, 14.644878151752872, 13.744247552434231, 12.708445534989156, 11.721773744638075, 10.826065355098159, 10.069274950447397, 10.94722720614625, 11.781329329100647, 12.730564433115822, 13.671336440054066, 13.39268003803602, 12.46483508861838, 11.606334805974733, 10.682687567728117, 9.728500400385643, 10.72070139768963, 11.634709869068674, 10.628629674734325, 9.673956188090978, 8.706896735978695, 15.624434533839318, 14.731860291234561, 13.738719188866096, 12.76271206895121, 11.795800340089261, 11.008724793261798, 11.890209351759301, 12.807172826795933, 13.758081288411358, 13.549928412018556, 12.536515221072568, 11.493166345603413, 10.635830427084594, 9.678785152746016, 8.74298796516194, 9.667257858250261, 10.703488558076357, 9.696758024856898, 8.747310002567094, 7.814513297743914, 15.779625327613369, 15.754630889927713, 14.692616849715314, 13.721376017451284, 12.812409464681679, 12.006571312825484, 12.891309302426814, 13.77226134824088, 13.525749873263875, 12.525819124919371, 11.47465518464559, 10.51279121274435, 9.66817178776159, 8.771532350668876, 7.776514984758593, 8.734209626254646, 9.689200578662712, 9.045589773102385, 7.980528724317404, 7.022045613295926, 14.9109546235338, 15.875386598446017, 15.62592381211551, 14.694386086441524, 13.849840283437723, 13.060262294133354, 13.905794128414524, 13.369956178383466, 12.533437846896144, 11.594312249161483, 10.535611018463188, 9.545275660187718, 8.657547043566776, 7.751721514384169, 6.763919093547833, 7.77535509375231, 8.653594686453582, 8.110789892066633, 7.105424249128245, 6.077945710346253, 15.874744068908878, 16.918530505619874, 16.555725285520275, 15.711552430273885, 14.892190567578998, 14.112832156778262, 13.38974618802461, 12.380206186814714, 11.465208882607815, 10.537057700128786, 9.586082123735208, 8.576211456077932, 7.596102622750646, 6.797101309348651, 5.822711424846093, 6.7249143938898355, 7.654307992212162, 8.583944302693467, 7.938522445751718, 7.003848017185852, 16.852018765086484, 17.323773228331284, 16.386619915087042, 15.379800124986875, 14.325122969569154, 13.322273152405108, 12.379319975130324, 11.440424667942626, 10.50338339469369, 9.56761681128572, 8.60597039035435, 7.623048634125807, 6.6354398168455235, 5.771086019199612, 4.811854063656328, 5.791732812744361, 6.752912418804685, 7.71639795984239, 8.623296602300801, 7.670184814688123, 17.690674648954936, 16.665094693022642, 15.63600357977487, 14.646351851004727, 13.571543612603348, 12.656241835718456, 11.654169272627628, 10.629722512570074, 9.589410801594617, 8.61080569274288, 7.774306070527612, 6.730946090678297, 5.706736845551381, 4.772213940295112, 3.8287421638686605, 4.817741182793663, 5.803519358627846, 6.783826951136889, 7.798015885851096, 8.621870462224972], [8.678773082312718, 7.69080912152889, 6.779101890371807, 5.719556305587108, 4.780038923989274, 3.838078725421612, 2.8570034277042584, 3.8230049193761637, 4.8422344096247665, 5.780949162276479, 6.709688636800427, 7.6671206995595345, 8.740065175713086, 9.749922647276263, 10.68274401565382, 11.674426308106153, 12.725839762793239, 13.68856824624667, 14.748414300658858, 15.816230312367138, 7.676309755165436, 6.746253311978975, 5.7736127324866375, 4.8332669222245634, 3.850884710482675, 2.8998541240982227, 1.9022270528171983, 2.930615703979684, 3.945453216394445, 4.950287012833764, 5.950434772103466, 6.943074234854133, 7.891268582800448, 8.896323582254878, 9.841667680216425, 10.82039389313326, 11.860330361304499, 12.891232114648016, 13.86764342262184, 14.883377930091488, 6.887666300488437, 5.887071669293086, 4.845089662139317, 3.866048279140781, 2.905231484920476, 1.9340325503957185, 0.9399350451941497, 1.9840461895143031, 2.9428644260741934, 3.9835519782719357, 5.0232009384835665, 6.035819498643691, 6.9934283579438965, 7.925937717716181, 8.86723806242855, 9.876454975790168, 10.939911876056026, 11.969635472364716, 12.909147929546883, 13.924591415895433, 5.994981597515739, 4.949225716420641, 3.907878298206104, 2.855476293764514, 1.9263250890448906, 0.9563899473634709, 0.0, 1.0296335720243157, 2.01344154270721, 2.9995698440441396, 3.9569509154255176, 4.98459170854089, 6.007862175025133, 6.983601679955584, 7.95610510811792, 8.926766113978234, 9.979451100128255, 10.993684106597748, 12.01388177424742, 12.953847634675476, 6.8530713106197, 5.803872583284429, 4.826033504198621, 3.7625140667122694, 2.831818933012923, 1.9046363706866438, 0.9749584811131251, 2.0137977659323356, 2.9676533940612972, 3.9411229365870453, 4.929613328580132, 5.920138668389204, 6.886655400614014, 7.827389262196481, 8.82198252855003, 9.785819387826256, 10.81761326501281, 11.865481120702784, 12.908015647668194, 13.853455896198232, 7.7700204593770685, 6.751945428457391, 5.714513564652482, 4.711995843714049, 3.8093663645867673, 2.9044805616009977, 1.9366738314913532, 2.9690643778526624, 3.9058218490431127, 4.908392668208187, 5.871401420872973, 6.8155964998047915, 7.8269707219971085, 8.811568258235598, 9.787928369545082, 10.73108641581997, 11.78993421764107, 12.85480845695259, 13.851155798246639, 14.865401175219926, 8.642983173496201, 7.7030263138873964, 6.731832299168701, 5.720283450912873, 4.775305840374877, 3.871726886592597, 2.913462487320677, 3.964743625875114, 4.934349947675294, 5.894566136694948, 6.867477651215005, 7.7609851138593315, 8.771932835980909, 9.796224382523219, 10.727532902707674, 11.78023572813536, 12.803897478292225, 13.74672381866708, 14.7513933165873, 15.680459145111833, 9.573611805476562, 8.700106492284604, 7.757284393961979, 6.729243404035078, 5.808532003410462, 4.913464145921823, 3.975382322152687, 4.921556578742006, 5.879840647178076, 6.889202425558504, 7.8989525893603245, 8.742293120047831, 9.740447844332678, 10.678652479107791, 11.70110156867551, 12.720884752372685, 13.668304671691553, 14.652590262246829, 15.60783608729245, 15.329703834657288, 10.506030417868958, 9.636879449998158, 8.65686472531191, 7.690013798085943, 6.734355661826388, 5.950034974685863, 4.955382445745113, 5.8909063505805435, 6.871175018148229, 7.88059750458188, 8.898511321416004, 9.768417984389753, 10.747991130031675, 11.6429357374743, 12.59767639248388, 13.525126278537464, 14.459140089951715, 15.42473635602377, 15.301143961214573, 14.361663106858577, 11.55977235370329, 10.604949118756434, 9.604327217102796, 8.622196543382492, 7.679327212710231, 6.895757629476932, 5.959468505667362, 6.845447877427305, 7.817559558618471, 8.74739739383968, 9.813106938562653, 10.75909712797822, 11.76644000678487, 12.635705446738653, 13.634938721211316, 14.523481348797237, 15.433630071993885, 15.4162543835312, 14.348589427674037, 13.367653167371662, 12.496504882614957, 11.549757288628603, 10.641163879971447, 9.661598015658058, 8.722504911827295, 7.963627409787612, 6.9922382730251496, 7.901628994298624, 8.871581589622132, 9.74897549195014, 10.728918281515794, 11.724257615744474, 12.716778470501275, 12.803135679784253, 13.628946103875162, 14.563235760337067, 15.389230715557828, 14.440889004904928, 13.423218993862523, 12.421808502108188, 13.428002492892752, 12.559609842198299, 11.69729778888307, 10.718050902900172, 9.745520405395078, 9.009825944093066, 7.994226565438183, 8.833000629773569, 9.90416848089941, 10.734551588925779, 11.754252164521144, 12.678476411251223, 12.605094180589917, 11.832462220157874, 12.58816951611663, 13.542179058197723, 14.435687680755576, 13.470874906417546, 12.468566405462738, 11.451000597974986, 14.494317543526318, 13.595808275683204, 12.625098973302798, 11.69098720888042, 10.71714723574763, 9.96005383677619, 9.0455690503606, 9.827771912773313, 10.84318576253744, 11.757951918651523, 12.690753796311762, 12.459878811062701, 11.679876057247364, 10.843977233175515, 11.624782112697524, 12.586484894160963, 13.43401433440944, 12.457907204286332, 11.523488949453238, 10.525642615563793, 15.546690224767206, 14.646059625448565, 13.610257608003492, 12.62358581765241, 11.727877428112494, 10.917378996229026, 9.99083725878278, 10.824939381737178, 11.774174485752352, 12.714946492690597, 12.436290090672548, 11.508445141254908, 10.732561928694201, 9.91073725757966, 10.669201839668823, 11.661402836972812, 12.575411308351855, 11.530441747748663, 10.575768261105315, 9.608708808993034, 15.803501774127014, 15.633672364248895, 14.640531261880433, 13.664524141965545, 12.697612413103597, 11.856828839043427, 10.93381940439583, 11.850782879432463, 12.801691341047889, 12.593538464655085, 11.580125273709097, 10.536776398239942, 9.762057549804062, 8.860070618161487, 9.68368940444512, 10.607959297533442, 11.644189997359538, 10.598570097871235, 9.649122075581431, 8.716325370758252, 14.823235380249898, 15.769328780588658, 15.59442892272965, 14.62318809046562, 13.714221537696014, 12.854675358607112, 11.934919355063343, 12.81587140087741, 12.569359925900402, 11.5694291775559, 10.518265237282119, 9.55640126538088, 8.71178184039812, 7.815142403305404, 8.717216424041773, 9.674911065537827, 10.629902017945893, 9.94740184611672, 8.88234079733174, 7.923857686310263, 13.954564676170332, 14.918996651082548, 15.886952770438269, 15.59619815945586, 14.751652356452059, 13.908366339914982, 12.949404181051053, 12.413566231019994, 11.57704789953267, 10.63792230179801, 9.579221071099717, 8.588885712824247, 7.701157096203304, 6.795331567020697, 7.704620532831013, 8.716056533035491, 9.594296125736763, 9.067179839430104, 8.061814196491717, 7.034335657709724, 14.91835412154541, 15.962140558256404, 16.33904182872383, 15.327389514358574, 14.369254111580926, 13.317927643687158, 12.433356240661137, 11.423816239451241, 10.508818935244342, 9.580667752765313, 8.629692176371737, 7.619821508714461, 6.639712675387174, 5.840711361985179, 6.763412864129274, 7.665615833173017, 8.595009431495344, 9.524645741976649, 8.894912393115188, 7.960237964549323, 15.895628817723015, 16.36738328096781, 15.43022996772357, 14.423410177623403, 13.368733022205681, 12.365883205041635, 11.422930027766851, 10.484034720579153, 9.546993447330218, 8.611226863922248, 7.64958044299088, 6.666658686762335, 5.679049869482052, 4.81469607183614, 5.752555502939508, 6.732434252027542, 7.693613858087867, 8.65709939912557, 9.579686549664274, 8.626574762051595, 16.734284701591463, 15.708704745659169, 14.679613632411398, 13.689961903641255, 12.615153665239875, 11.699851888354983, 10.697779325264156, 9.673332565206602, 8.633020854231145, 7.654415745379409, 6.8179161231641405, 5.774556143314825, 4.750346898187909, 3.8158239929316404, 4.769443603151841, 5.758442622076844, 6.759909305991317, 7.74021689850036, 8.754405833214566, 9.578260409588445], [9.708406654337033, 8.720442693553204, 7.808735462396124, 6.749189877611424, 5.809672496013589, 4.867712297445928, 3.8866369997285743, 3.0175533424818295, 3.9029516059525102, 4.841666358604223, 5.770405833128171, 6.727837895887278, 7.80078237204083, 8.810639843604006, 9.743461211981563, 10.735143504433896, 11.786556959120983, 12.749285442574413, 13.809131496986602, 14.87239369879868, 8.70594332718975, 7.775886884003291, 6.803246304510953, 5.862900494248879, 4.880518282506991, 3.9294876961225382, 2.931860624841514, 1.9483501441911826, 2.9631876566059434, 3.9680214530452624, 4.968169212314964, 5.95256581865019, 6.9007601665965055, 7.905815166050934, 8.81203410819211, 9.790760321108946, 10.830696789280184, 11.8615985426237, 12.838009850597526, 13.853744358067173, 7.9172998725127535, 6.916705241317402, 5.874723234163634, 4.895681851165096, 3.9348650569447914, 2.963666122420034, 1.9695686172184654, 1.0017806297258016, 1.9590335914350214, 2.9997211436327635, 3.993567366459251, 5.006185926619375, 5.963794785919581, 6.896304145691866, 7.837604490404235, 8.846821403765853, 9.910278304031712, 10.940001900340402, 11.879514357522568, 12.894957843871119, 7.024615169540054, 5.978859288444957, 4.93751187023042, 3.8851098657888294, 2.9559586610692064, 1.9860235193877867, 1.0296335720243157, 0.0, 0.9838079706828944, 1.9699362720198241, 2.927317343401202, 3.9549581365165745, 4.978228603000818, 5.953968107931268, 6.926471536093604, 7.897132541953918, 8.94981752810394, 9.964050534573433, 10.984248202223105, 11.924214062651162, 7.882704882644014, 6.8335061553087435, 5.855667076222936, 4.7921476387365844, 3.8614525050372386, 2.9342699427109595, 2.004592053137441, 1.0392208739577038, 1.9930765020866654, 2.9665460446124134, 3.8999797565558163, 4.890505096364889, 5.8570218285896996, 6.797755690172166, 7.792348956525717, 8.756185815801944, 9.787979692988497, 10.83584754867847, 11.87838207564388, 12.82382232417392, 8.799654031401383, 7.781579000481706, 6.744147136676797, 5.741629415738363, 4.838999936611082, 3.9341141336253136, 2.966307403515669, 2.098906476946977, 2.931244957068481, 3.933815776233555, 4.841767848848657, 5.785962927780476, 6.797337149972792, 7.781934686211281, 8.758294797520765, 9.701452843795654, 10.760300645616754, 11.825174884928273, 12.821522226222323, 13.83576760319561, 9.672616745520514, 8.73265988591171, 7.761465871193016, 6.749917022937187, 5.804939412399192, 4.901360458616913, 3.943096059344993, 3.108031308528426, 3.9735235191010916, 4.919989244720316, 5.83784407919069, 6.731351541835016, 7.7422992639565935, 8.766590810498903, 9.697899330683358, 10.750602156111043, 11.774263906267908, 12.717090246642764, 13.721759744562984, 14.650825573087516, 10.603245377500874, 9.729740064308919, 8.786917965986293, 7.758876976059392, 6.838165575434777, 5.94309771794614, 5.005015894177003, 4.064844261395318, 4.926467329858717, 5.914625533583872, 6.903992178444916, 7.712659548023516, 8.710814272308362, 9.649018907083475, 10.671467996651193, 11.691251180348369, 12.638671099667237, 13.622956690222512, 14.578202515268133, 15.587748481333428, 11.535663989893271, 10.666513022022475, 9.686498297336227, 8.719647370110259, 7.763989233850705, 6.9796685467101796, 5.973729634495042, 5.038205729659612, 5.9285755795120885, 6.906020612607248, 7.9238304652690426, 8.738784412365439, 9.71835755800736, 10.613302165449984, 11.568042820459564, 12.495492706513147, 13.429506517927399, 14.395102783999453, 15.440293226461417, 15.39129667888289, 12.589405925727602, 11.63458269078075, 10.633960789127112, 9.651830115406806, 8.708960784734547, 7.9141048182268605, 6.977815694417291, 5.992747256506374, 6.8749601199823305, 7.804797955203539, 8.87050749992651, 9.74245550672265, 10.7497983855293, 11.606071874714337, 12.605305149187, 13.49384777677292, 14.403996499969569, 15.32840068554218, 15.37822299969835, 14.397286739395975, 13.526138454639273, 12.57939086065292, 11.670797451995764, 10.691231587682372, 9.75213848385161, 8.98197459853754, 8.008212887136951, 7.048928373377693, 7.928982150985991, 8.806376053314, 9.786318842879654, 10.707615994488902, 11.700136849245704, 12.540860283723275, 13.533232215233356, 14.482975964402137, 15.424538072564342, 15.470522576929241, 14.452852565886836, 13.451442074132501, 14.457636064917068, 13.589243414222615, 12.726931360907386, 11.747684474924487, 10.775153977419393, 10.025800558204867, 9.010201179549984, 7.980300008852637, 8.99501684687667, 9.791952150289639, 10.811652725885004, 11.661834789995652, 11.799642603695583, 12.790695771251373, 13.615819989708635, 14.57037442538648, 15.465321252779889, 14.500508478441859, 13.498199977487051, 12.480634169999298, 15.523951115550634, 14.62544184770752, 13.654732545327112, 12.720620780904735, 11.746780807771945, 10.940004633104625, 9.969870445636195, 8.97507129185238, 9.952279360362056, 10.815352480015383, 11.748154357675622, 11.654427234168368, 10.87442448035303, 11.802210784269015, 12.65243258628953, 13.61468026134972, 14.463647906433753, 13.487540776310645, 12.553122521477551, 11.555276187588106, 15.65705687066499, 15.675693197472881, 14.639891180027806, 13.653219389676725, 12.757511000136809, 11.89732979255746, 10.915138654058374, 9.972238760816245, 10.92147386483142, 11.81834255871443, 11.630838513778215, 10.702993564360575, 9.927110351799866, 10.86897080867316, 11.696852313260829, 12.691036408997125, 13.60504488037617, 12.560075319772977, 11.60540183312963, 10.638342381017347, 14.773868202102701, 15.812004692905445, 15.670164833904746, 14.69415771398986, 13.727245985127912, 12.815499375750104, 11.858120799671426, 10.99808225851153, 11.948990720126956, 11.773567553480296, 10.77400078577499, 9.73132482134561, 8.956605972909728, 9.818304169254986, 10.711339878037126, 11.637592869557755, 12.673823569383853, 11.62820366989555, 10.678755647605746, 9.745958942782567, 13.793601808225585, 14.739695208564346, 15.79062616081415, 15.652821662489934, 14.743855109720329, 13.81334589531379, 12.859220750338938, 11.963170779956478, 11.630077122228146, 10.749458266381112, 9.712140749348013, 8.750949688486546, 7.906330263503785, 8.773375954398904, 9.744866897633779, 10.70454463756214, 11.659535589970208, 10.977035418141035, 9.911974369356054, 8.953491258334576, 12.924931104146017, 13.889363079058233, 14.857319198413954, 15.405273054518679, 14.472321592049944, 13.42929845714653, 12.426049573093936, 11.474283427347737, 10.637765095860415, 9.698639498125754, 8.765597167634565, 7.783434135929913, 6.8957055193089705, 7.753565118114198, 8.73227100642302, 9.745690105059804, 10.623929697761078, 10.096813411454418, 9.091447768516032, 8.063969229734038, 13.888720549521096, 14.932506986232092, 15.399759025051575, 14.388106710686317, 13.42997130790867, 12.378644840014902, 11.49407343698888, 10.484533435778985, 9.569536131572086, 8.641384949093057, 7.813782836505996, 6.814369931820127, 5.83426109849284, 6.79894491307868, 7.791063337721279, 8.69524940519733, 9.624643003519658, 10.554279314000963, 9.924545965139504, 8.98987153657364, 14.865995245698702, 15.428100477295555, 14.490947164051313, 13.484127373951146, 12.429450218533425, 11.42660040136938, 10.483647224094595, 9.544751916906897, 8.607710643657962, 7.6719440602499915, 6.824951390243436, 5.861207109868001, 4.873598292587718, 5.844329643860457, 6.782189074963824, 7.762067824051857, 8.723247430112181, 9.686732971149885, 10.609320121688588, 9.65620833407591, 15.795001897919205, 14.769421941986913, 13.740330828739141, 12.750679099968998, 11.675870861567619, 10.760569084682727, 9.7584965215919, 8.734049761534346, 7.693738050558888, 6.715132941707153, 5.878633319491884, 4.835273339642569, 3.9448953212935756, 4.845457564955956, 5.799077175176157, 6.7880761941011585, 7.789542878015633, 8.769850470524675, 9.784039405238882, 10.60789398161276], [10.692214625019929, 9.7042506642361, 8.792543433079018, 7.7329978482943185, 6.793480466696484, 5.851520268128823, 4.870444970411469, 3.949816570068045, 2.937166955654394, 3.875881708306107, 4.804621182830055, 5.762053245589162, 6.834997721742713, 7.8448551933058885, 8.777676561683446, 9.76935885413578, 10.80693659431968, 11.76966507777311, 12.8295111321853, 13.888585728115785, 9.689751297872647, 8.759694854686186, 7.787054275193848, 6.8467084649317735, 5.864326253189885, 4.913295666805433, 3.9156685955244086, 2.880613371777398, 1.9974030063078272, 3.002236802747146, 4.002384562016848, 4.968757847967296, 5.916952195913611, 6.92200719536804, 7.8282261375092155, 8.806952350426052, 9.84688881859729, 10.877790571940807, 11.854201879914632, 12.869936387384278, 8.901107843195648, 7.9005132120002965, 6.858531204846528, 5.879489821847992, 4.918673027627686, 3.9474740931029286, 2.95337658790136, 1.9340438573120173, 0.975225620752127, 2.0159131729498694, 3.0097593957763564, 4.022377955936481, 4.979986815236686, 5.912496175008972, 6.853796519721341, 7.863013433082958, 8.926470333348817, 9.956193929657507, 10.895706386839674, 11.911149873188224, 8.008423140222948, 6.962667259127851, 5.9213198409133145, 4.8689178364717245, 3.939766631752101, 2.969831490070681, 2.01344154270721, 0.9838079706828944, 0.0, 0.9861283013369297, 1.9435093727183077, 2.97115016583368, 3.994420632317923, 4.9701601372483735, 5.94266356541071, 6.913324571271024, 7.966009557421046, 8.980242563890538, 10.00044023154021, 10.940406091968267, 8.866512853326908, 7.817314125991638, 6.8394750469058305, 5.775955609419479, 4.845260475720133, 3.918077913393854, 2.9884000238203354, 1.9823614207597848, 1.0285057926308232, 1.9996196566487348, 2.9161717858729217, 3.906697125681994, 4.873213857906805, 5.8139477194892715, 6.808540985842822, 7.772377845119048, 8.804171722305602, 9.852039577995576, 10.894574104960986, 11.840014353491025, 9.783462002084278, 8.7653869711646, 7.7279551073596915, 6.725437386421258, 5.822807907293977, 4.917922104308208, 3.9501153741985635, 3.0278404328941972, 1.9666742476126386, 2.9668893882698764, 3.8579598781657625, 4.8021549570975814, 5.8135291792898975, 6.798126715528387, 7.774486826837871, 8.717644873112759, 9.77649267493386, 10.841366914245377, 11.837714255539426, 12.851959632512713, 10.656424716203409, 9.716467856594605, 8.74527384187591, 7.733724993620082, 6.788747383082087, 5.885168429299807, 4.926904030027888, 3.9785591314454294, 3.0089528096452494, 3.9530628567566373, 4.854036108507795, 5.7475435711521214, 6.758491293273699, 7.782782839816009, 8.714091360000463, 9.766794185428148, 10.790455935585014, 11.73328227595987, 12.73795177388009, 13.667017602404622, 11.587053348183769, 10.713548034991813, 9.770725936669187, 8.742684946742287, 7.821973546117672, 6.926905688629034, 5.9479819708464925, 4.920180688838945, 3.9618966204028747, 4.947699145620193, 5.920184207762022, 6.728851577340621, 7.727006301625468, 8.665210936400582, 9.687660025968299, 10.707443209665474, 11.654863128984342, 12.639148719539618, 13.594394544585239, 14.603940510650535, 12.519471960576166, 11.65032099270537, 10.670306268019122, 9.703455340793154, 8.7477972045336, 7.894165768925755, 6.82906606193867, 5.89354215710324, 4.964004870056247, 5.939094224643569, 6.940022494586148, 7.754976441682543, 8.734549587324464, 9.62949419476709, 10.58423484977667, 11.511684735830254, 12.445698547244506, 13.41129481331656, 14.456485255778524, 15.49719171284236, 13.573213896410497, 12.618390661463645, 11.617768759810007, 10.635638086089703, 9.692768755417443, 8.769441245670489, 7.83315212186092, 6.848083683950001, 5.910389410526489, 6.840227245747697, 7.90593679047067, 8.758647536039753, 9.765990414846403, 10.622263904031444, 11.621497178504107, 12.510039806090028, 13.420188529286676, 14.344592714859287, 15.40903978931906, 15.38109471007887, 14.509946425322168, 13.563198831335814, 12.654605422678657, 11.675039558365269, 10.735946454534506, 9.837311025981169, 8.86354931458058, 7.904264800821322, 6.9644114415301495, 7.841805343858159, 8.821748133423812, 9.723808023806006, 10.716328878562807, 11.557052313040382, 12.549424244550464, 13.499167993719244, 14.44073010188145, 15.405077711316373, 15.43666053656973, 14.435250044815396, 15.441444035599963, 14.57305138490551, 13.710739331590279, 12.731492445607383, 11.75896194810229, 10.881136985648496, 9.865537606993612, 8.835636436296266, 8.030446137420828, 8.827381440833797, 9.847082016429162, 10.678026819312755, 11.709419029482612, 12.527725772666761, 13.490272353701705, 14.444897120337057, 15.394273136683701, 15.484316449124753, 14.482007948169947, 13.464442140682193, 15.534924789901824, 15.609249818390415, 14.638540516010009, 13.704428751587631, 12.730588778454841, 11.795341060548255, 10.825206873079825, 9.83040771929601, 8.987708650906214, 9.850781770559541, 10.78358364821978, 10.784757042199532, 11.738418609613307, 12.692628040939967, 13.584695813875745, 14.546943488935936, 15.447455877116647, 14.47134874699354, 13.536930492160446, 12.539084158271, 14.673248899982095, 15.644812916897221, 15.623699150710703, 14.637027360359621, 13.741318970819705, 12.75266622000109, 11.770475081502004, 10.827575188259875, 10.057128519955231, 10.853771849258589, 10.737491664478581, 9.833323372391739, 10.791104481060144, 11.801234036259375, 12.629115540847044, 13.636910537083976, 14.554306191684645, 13.543883290455872, 12.589209803812524, 11.622150351700242, 13.790060231419806, 14.82819672222255, 15.868833494778242, 15.675979833484472, 14.709068104622524, 13.670835803193734, 12.713457227115056, 11.85341868595516, 11.084645375250767, 10.807782903182181, 9.808216135476874, 8.861654629376773, 9.820600102170005, 10.750567396841202, 11.643603105623342, 12.583466997644607, 13.623084880692328, 12.612011640578444, 11.66256361828864, 10.729766913465461, 12.80979383754269, 13.755887237881451, 14.806818190131255, 15.412498473210803, 14.405063167099758, 13.435217298949313, 12.4544442976472, 11.505434895895661, 10.66429247193003, 9.783673616082996, 8.746356099049896, 7.88127949651771, 8.83859349109, 9.70563918198512, 10.677130125219994, 11.650418765648991, 12.632991828850148, 11.96084338882393, 10.895782340038949, 9.937299229017471, 11.941123133463122, 12.905555108375339, 13.87351122773106, 14.439488404220564, 13.506536941751829, 12.463513806848415, 11.46026492279582, 10.508498777049622, 9.6719804455623, 8.732854847827639, 7.799812517336449, 6.913763943961077, 7.827968746895186, 8.685828345700413, 9.664534234009235, 10.691564233146655, 11.597385936641018, 11.080621382137313, 10.075255739198926, 9.047777200416933, 12.9049125788382, 13.948699015549195, 14.43397437475346, 13.422322060388202, 12.464186657610554, 11.412860189716787, 10.528288786690766, 9.51874878548087, 8.60375148127397, 7.675600298794942, 6.84799818620788, 5.94469973985129, 6.766524326079056, 7.731208140664895, 8.723326565307495, 9.66870564407727, 10.598099242399599, 11.527735552880904, 10.908353935822399, 9.973679507256534, 13.882187275015806, 14.46231582699744, 13.525162513753198, 12.518342723653031, 11.46366556823531, 10.460815751071264, 9.51786257379648, 8.578967266608782, 7.641925993359846, 6.7061594099518755, 5.85916673994532, 4.939196045561152, 5.805861520173933, 6.791598387554254, 7.765997045646721, 8.745875794734754, 9.70705540079508, 10.670540941832783, 11.593128092371485, 10.640016304758806, 14.815381533117902, 13.78980157718561, 12.760710463937839, 11.784894449670881, 10.710086211269502, 9.79478443438461, 8.79271187129378, 7.768265111236228, 6.727953400260772, 5.749348291409037, 4.912848669193768, 3.869488689344453, 4.877158548879791, 5.829265535638852, 6.782885145859053, 7.771884164784055, 8.773350848698527, 9.75365844120757, 10.767847375921777, 11.591701952295656], [11.678342926356859, 10.69037896557303, 9.778671734415946, 8.719126149631247, 7.779608768033413, 6.8376485694657525, 5.856573271748399, 4.935944871404974, 3.9232952569913238, 3.020456840717942, 3.9491963152418905, 4.906628378000998, 5.9231464584748625, 6.86991410125231, 7.802735469629867, 8.785580672487736, 9.82080829298275, 10.783536776436181, 11.84338283084837, 12.902457426778856, 10.675879599209576, 9.745823156023116, 8.773182576530777, 7.832836766268703, 6.850454554526815, 5.899423968142362, 4.901796896861338, 3.8667416731143276, 2.983531307644757, 2.0936197641290435, 3.080493364054224, 3.982629546630366, 4.930823894576681, 5.93587889403111, 6.842097836172286, 7.820824049089122, 8.86076051726036, 9.891662270603877, 10.868073578577702, 11.883808086047349, 9.887236144532578, 8.886641513337226, 7.844659506183458, 6.865618123184921, 5.9048013289646155, 4.933602394439858, 3.9395048892382896, 2.920172158648947, 1.9613539220890568, 1.0449479772700185, 2.023631094439427, 3.036249654599551, 3.993858513899757, 4.926367873672042, 5.867668218384411, 6.876885131746029, 7.940342032011888, 8.970065628320578, 9.909578085502744, 10.925021571851294, 8.994551441559878, 7.948795560464781, 6.907448142250244, 5.855046137808654, 4.9258949330890305, 3.9559597914076106, 2.9995698440441396, 1.9699362720198241, 0.9861283013369297, 0.0, 0.957381071381378, 1.9850218644967503, 3.0082923309809937, 3.984031835911444, 4.95653526407378, 5.927196269934094, 6.979881256084116, 7.994114262553609, 9.01431193020328, 9.954277790631338, 9.852641154663837, 8.803442427328568, 7.82560334824276, 6.762083910756409, 5.831388777057063, 4.904206214730784, 3.974528325157265, 2.9408165259665147, 1.986960897837553, 1.013491355311805, 1.9300434845359922, 2.9205688243450645, 3.887085556569875, 4.827819418152341, 5.822412684505892, 6.786249543782118, 7.818043420968671, 8.865911276658645, 9.908445803624055, 10.853886052154094, 10.769590303421207, 9.75151527250153, 8.71408340869662, 7.7115656877581875, 6.808936208630906, 5.904050405645138, 4.9362436755354935, 3.986295538100927, 2.9251293528193685, 1.9807610869329464, 2.871831576828833, 3.8160266557606515, 4.827400877952968, 5.811998414191457, 6.788358525500941, 7.731516571775829, 8.79036437359693, 9.855238612908447, 10.851585954202497, 11.865831331175784, 11.642553017540337, 10.702596157931533, 9.731402143212838, 8.719853294957012, 7.774875684419016, 6.871296730636737, 5.913032331364818, 4.93701423665216, 3.967407914851979, 2.9669345554197077, 3.8679078071708655, 4.761415269815192, 5.772362991936769, 6.796654538479079, 7.7279630586635335, 8.780665884091219, 9.804327634248084, 10.74715397462294, 11.75182347254316, 12.680889301067692, 12.573181649520697, 11.699676336328741, 10.756854238006115, 9.728813248079218, 8.808101847454601, 7.913033989965964, 6.906437076053222, 5.878635794045675, 4.9203517256096045, 3.9615708442832633, 4.934055906425091, 5.742723276003692, 6.7408780002885385, 7.6790826350636525, 8.70153172463137, 9.721314908328544, 10.668734827647413, 11.653020418202688, 12.608266243248309, 13.617812209313605, 13.505600261913093, 12.636449294042299, 11.656434569356051, 10.689583642130083, 9.733925505870529, 8.852620874132485, 7.7875211671454, 6.851997262309969, 5.922459975262976, 4.952965923306639, 5.9538941932492175, 6.7688481403456136, 7.7484212859875345, 8.643365893430161, 9.598106548439741, 10.525556434493325, 11.459570245907576, 12.425166511979631, 13.470356954441595, 14.51106341150543, 14.559342197747425, 13.604518962800574, 12.603897061146936, 11.621766387426632, 10.678897056754373, 9.727896350877218, 8.791607227067649, 7.806538789156731, 6.868844515733218, 5.947653708193928, 7.006749144662157, 7.772519234702823, 8.779862113509473, 9.636135602694514, 10.635368877167178, 11.523911504753098, 12.434060227949747, 13.358464413522357, 14.42291148798213, 15.45354505112033, 15.496074726659097, 14.549327132672744, 13.640733724015586, 12.661167859702198, 11.722074755871436, 10.795766131187898, 9.822004419787309, 8.862719906028051, 7.922866546736879, 6.94923180630439, 7.929174595870043, 8.737679722469077, 9.730200577225878, 10.570924011703452, 11.563295943213534, 12.513039692382314, 13.45460180054452, 14.418949409979444, 15.348281921793644, 15.421378346152324, 15.567716442755057, 15.55917968624244, 14.696867632927209, 13.717620746944313, 12.745090249439219, 11.839592090855225, 10.823992712200342, 9.794091541502993, 8.988901242627557, 7.934807903280029, 8.954508478875393, 9.691898517975826, 10.723290728145683, 11.541597471329831, 12.504144052364776, 13.458768819000127, 14.408144835346771, 15.44250922229935, 15.468136249506873, 14.45057044201912, 14.548796488564895, 15.614832555305515, 15.624668817346938, 14.69055705292456, 13.71671707979177, 12.753796165754983, 11.783661978286553, 10.788862824502738, 9.946163756112943, 8.958208233005774, 9.891010110666013, 10.71638457585769, 11.648508851488236, 12.53008245831219, 13.467531455783881, 14.414462983036888, 15.409818181692907, 15.457477048330468, 14.523058793497373, 13.525212459607928, 13.687120598645166, 14.658684615560292, 15.731671124725818, 15.62315566169655, 14.727447272156635, 13.711121325207818, 12.728930186708732, 11.786030293466602, 10.901970318643066, 9.961198311704822, 9.882066796890415, 10.804839079236999, 11.762620187905403, 12.787362337596303, 13.615243842183972, 14.623038838420904, 15.540434493021573, 14.530011591792801, 13.575338105149454, 12.60827865303717, 12.803931930082875, 13.842068420885619, 14.88270519344131, 15.515737554122712, 14.56624742410401, 13.557497956805225, 12.600119380726547, 11.615098549752442, 10.784577636692894, 9.952358035594015, 8.952791267888708, 9.833170336222032, 10.792115809015264, 11.73669569817813, 12.62973140696027, 13.569595298981534, 14.609213182029256, 13.598139941915374, 12.64869191962557, 11.71589521480239, 11.823665536205759, 12.76975893654452, 13.820689888794325, 14.557073605622637, 13.549638299511592, 12.579792431361147, 11.599019430059034, 10.650010028307495, 9.808867604341865, 8.92824874849483, 7.890931231461731, 8.85279520336297, 9.824721792426928, 10.691767483322048, 11.663258426556922, 12.63654706698592, 13.619120130187076, 12.94697169016086, 11.881910641375878, 10.9234275303544, 10.954994832126193, 11.919426807038409, 12.88738292639413, 13.584063536632398, 12.651112074163663, 11.608088939260249, 10.604840055207655, 9.653073909461456, 8.816555577974134, 7.877429980239473, 6.944387649748284, 7.899892245298006, 8.814097048232114, 9.67195664703734, 10.650662535346163, 11.677692534483583, 12.583514237977946, 12.066749683474242, 11.061384040535856, 10.033905501753862, 11.91878427750127, 12.962570714212266, 13.578549507165294, 12.566897192800036, 11.608761790022388, 10.55743532212862, 9.6728639191026, 8.663323917892704, 7.748326613685805, 6.820175431206776, 5.992573318619715, 6.93082804118822, 7.752652627415984, 8.717336442001823, 9.709454866644423, 10.654833945414198, 11.584227543736526, 12.513863854217831, 11.894482237159329, 10.959807808593464, 12.896058973678876, 13.606890959409274, 12.669737646165032, 11.662917856064865, 10.608240700647144, 9.605390883483098, 8.662437706208314, 7.723542399020616, 6.7865011257716805, 5.8507345423637105, 5.003741872357155, 5.925324346898082, 6.791989821510862, 7.777726688891183, 8.75212534698365, 9.732004096071684, 10.693183702132009, 11.656669243169713, 12.579256393708414, 11.626144606095735, 13.829253231780973, 12.80367327584868, 11.77458216260091, 10.801116268022838, 9.726308029621459, 8.819843342331032, 7.8177707792402025, 6.856413847968377, 5.872528532672607, 4.893923423820872, 4.057423801605603, 4.855616990681383, 5.86328685021672, 6.815393836975781, 7.769013447195983, 8.758012466120984, 9.759479150035455, 10.739786742544497, 11.753975677258705, 12.577830253632586], [12.635723997738237, 11.64776003695441, 10.736052805797325, 9.676507221012626, 8.736989839414791, 7.79502964084713, 6.813954343129776, 5.893325942786353, 4.880676328372702, 3.9778379120993197, 3.1929971217183835, 3.96013194367554, 4.965765387093485, 5.912533029870932, 6.845354398248489, 7.828199601106358, 8.863427221601373, 9.826155705054804, 10.886001759466993, 11.945076355397477, 11.633260670590955, 10.703204227404495, 9.730563647912156, 8.790217837650081, 7.807835625908193, 6.85680503952374, 5.859177968242716, 4.824122744495706, 3.940912379026135, 3.051000835510421, 2.123112292672846, 3.025248475248988, 3.9734428231953034, 4.978497822649732, 5.884716764790908, 6.863442977707745, 7.903379445878983, 8.9342811992225, 9.910692507196323, 10.92642701466597, 10.844617215913955, 9.844022584718603, 8.802040577564835, 7.822999194566299, 6.8621824003459935, 5.890983465821236, 4.8968859606196675, 3.877553230030325, 2.9187349934704345, 2.0023290486513963, 1.0662500230580487, 2.0788685832181732, 3.036477442518379, 3.968986802290664, 4.910287147003033, 5.91950406036465, 6.982960960630509, 8.012684556939199, 8.952197014121365, 9.967640500469916, 9.951932512941257, 8.90617663184616, 7.864829213631622, 6.812427209190032, 5.883276004470408, 4.9133408627889885, 3.9569509154255176, 2.927317343401202, 1.9435093727183077, 0.957381071381378, 0.0, 1.0276407931153724, 2.0509112595996157, 3.026650764530066, 3.999154192692402, 4.969815198552715, 6.0225001847027375, 7.03673319117223, 8.056930858821902, 8.996896719249959, 10.810022226045216, 9.760823498709946, 8.782984419624139, 7.7194649821377865, 6.788769848438441, 5.861587286112162, 4.931909396538643, 3.8981975973478926, 2.944341969218931, 1.970872426693183, 0.9726624131546141, 1.9631877529636865, 2.929704485188497, 3.870438346770963, 4.865031613124514, 5.82886847240074, 6.860662349587294, 7.908530205277268, 8.951064732242678, 9.896504980772717, 11.726971374802586, 10.708896343882909, 9.671464480077999, 8.668946759139565, 7.766317280012284, 6.861431477026515, 5.8936247469168705, 4.943676609482305, 3.8825104242007464, 2.918325508887375, 1.914450505447455, 2.8586455843792735, 3.87001980657159, 4.854617342810079, 5.830977454119563, 6.7741355003944514, 7.832983302215551, 8.89785754152707, 9.89420488282112, 10.908450259794407, 12.599934088921716, 11.659977229312911, 10.688783214594217, 9.67723436633839, 8.732256755800394, 7.828677802018114, 6.870413402746195, 5.894395308033538, 4.924788986233358, 3.9044989773741365, 2.9105267357894875, 3.8040341984338135, 4.814981920555391, 5.839273467097701, 6.7705819872821555, 7.82328481270984, 8.846946562866705, 9.78977290324156, 10.794442401161781, 11.723508229686313, 13.530562720902076, 12.65705740771012, 11.714235309387494, 10.686194319460595, 9.765482918835978, 8.870415061347341, 7.863818147434601, 6.8360168654270534, 5.877732796990983, 4.899135266237693, 3.9766748350437133, 4.785342204622313, 5.78349692890716, 6.721701563682274, 7.744150653249991, 8.763933836947167, 9.711353756266035, 10.695639346821311, 11.650885171866932, 12.660431137932228, 14.462981333294472, 13.593830365423676, 12.613815640737428, 11.64696471351146, 10.691306577251906, 9.810001945513864, 8.744902238526779, 7.809378333691348, 6.879841046644355, 5.890530345261069, 4.99651312186784, 5.811467068964235, 6.791040214606156, 7.685984822048783, 8.640725477058364, 9.568175363111948, 10.5021891745262, 11.467785440598254, 12.512975883060218, 13.553682340124054, 15.516723269128804, 14.561900034181951, 13.561278132528313, 12.57914745880801, 11.63627812813575, 10.685277422258597, 9.748988298449028, 8.76391986053811, 7.815055965369567, 6.885218130148358, 6.049368073280779, 6.8151381633214445, 7.8224810421280955, 8.678754531313137, 9.6779878057858, 10.566530433371721, 11.47667915656837, 12.40108334214098, 13.465530416600753, 14.496163979738952, 15.4504489780661, 15.50670820405412, 14.598114795396963, 13.618548931083575, 12.679455827252813, 11.753147202569277, 10.779385491168687, 9.82010097740943, 8.869077996373228, 7.886796228258819, 7.037302599996879, 7.780298651087698, 8.772819505844499, 9.613542940322075, 10.605914871832157, 11.555658621000937, 12.497220729163143, 13.461568338598067, 14.390900850412267, 15.392311342166602, 14.61033537137368, 15.67863552223954, 15.654248704308586, 14.67500181832569, 13.702471320820596, 12.796973162236604, 11.78137378358172, 10.751472612884374, 9.935112692263907, 8.872372325234458, 8.06263648300223, 8.734517446594447, 9.765909656764304, 10.584216399948454, 11.546762980983399, 12.50138774761875, 13.450763763965394, 14.485128150917973, 15.429647128391089, 15.4079515134005, 13.591415417183518, 14.657451483924138, 15.703197143951542, 15.647938124305938, 14.674098151173148, 13.711177237136363, 12.741043049667933, 11.746243895884119, 10.892375205749293, 9.895772654960203, 9.07932876739049, 9.759003504476311, 10.691127780106857, 11.572701386930813, 12.510150384402504, 13.45708191165551, 14.45243711031153, 15.428544240434638, 15.480439864878752, 14.482593530989307, 12.729739527263787, 13.701303544178913, 14.774290053344437, 15.653695257691117, 14.64885142453583, 13.627388165664108, 12.67354189238408, 11.77138241349221, 10.972177813981869, 10.126118822963646, 10.047222789672519, 10.710437174284104, 11.63844190866002, 12.505941362526668, 13.460128529869142, 14.382163968843662, 15.375183012671709, 15.48739266317418, 14.532719176530833, 13.565659724418548, 11.846550858701498, 12.884687349504242, 13.925324122059934, 14.646177920167194, 13.696687790148491, 12.687938322849707, 11.730559746771029, 10.745538915796924, 9.944660958686333, 9.196158842070508, 9.910172339270087, 10.790551407603411, 11.749496880396643, 12.69407676955951, 13.58711247834165, 14.526976370362915, 15.566594253410637, 14.555521013296753, 13.606072991006949, 12.67327628618377, 10.866284464824382, 11.812377865163143, 12.863308817412946, 13.68751397166712, 12.680078665556074, 11.710232797405629, 10.729459796103516, 9.780450394351977, 8.968950926335303, 8.172049554971323, 8.848312302843109, 9.810176274744348, 10.782102863808309, 11.649148554703428, 12.620639497938303, 13.5939281383673, 14.576501201568457, 13.904352761542238, 12.839291712757257, 11.88080860173578, 9.997613760744814, 10.96204573565703, 11.930001855012751, 12.71450390267688, 11.781552440208145, 10.738529305304729, 9.735280421252135, 8.783514275505938, 7.976638899967572, 7.121230786715966, 7.901768721129662, 8.857273316679386, 9.771478119613494, 10.629337718418721, 11.608043606727543, 12.635073605864964, 13.540895309359327, 13.024130754855621, 12.018765111917235, 10.991286573135241, 10.961403206119893, 12.005189642830889, 12.708989873209775, 11.697337558844518, 10.73920215606687, 9.687875688173103, 8.80330428514708, 7.793764283937185, 6.908409935679243, 6.063976237683269, 6.949954390001093, 7.888209112569599, 8.710033698797364, 9.674717513383204, 10.666835938025804, 11.612215016795579, 12.541608615117907, 13.471244925599212, 12.851863308540706, 11.91718887997484, 11.9386779022975, 12.737331325453756, 11.800178012209514, 10.793358222109347, 9.738681066691626, 8.73583124952758, 7.792878072252795, 6.853982765065096, 5.91694149181616, 5.094535348840203, 5.961122943738533, 6.8827054182794605, 7.749370892892241, 8.735107760272562, 9.709506418365027, 10.68938516745306, 11.650564773513386, 12.61405031455109, 13.536637465089793, 12.583525677477114, 12.871872160399596, 11.846292204467304, 10.817201091219532, 9.84373519664146, 8.76892695824008, 7.862462270949654, 6.8603897078588245, 5.899032776586999, 4.989362517212916, 4.137724230297365, 5.014804872986981, 5.812998062062761, 6.8206679215980985, 7.7727749083571585, 8.72639451857736, 9.715393537502361, 10.716860221416834, 11.697167813925876, 12.711356748640084, 13.535211325013965], [13.663364790853608, 12.67540083006978, 11.763693598912697, 10.704148014127998, 9.764630632530164, 8.723683720132797, 7.742608422415444, 6.776606930743538, 5.757377440494936, 4.818662687843223, 3.8899232133192747, 2.9324911505601676, 3.938124593978112, 4.88489223675556, 5.817713605133116, 6.800558807990984, 7.835786428485999, 8.79851491193943, 9.858360966351619, 10.917435562282105, 12.660901463706326, 11.730845020519865, 10.758204441027527, 9.817858630765452, 8.835476419023564, 7.884445832639113, 6.8868187613580885, 5.8517635376110775, 4.968553172141507, 3.990394904153985, 2.990247144884283, 1.9976076821336157, 2.945802030079931, 3.95085702953436, 4.857075971675535, 5.835802184592371, 6.875738652763609, 7.906640406107125, 8.88305171408095, 9.898786221550598, 11.872258009029327, 10.871663377833976, 9.829681370680207, 8.85063998768167, 7.889823193461366, 6.9186242589366085, 5.92452675373504, 4.905194023145697, 3.946375786585807, 3.0299698417667686, 2.0884166122064496, 1.051227790102801, 2.0088366494030065, 2.941346009175291, 3.8826463538876603, 4.891863267249278, 5.955320167515136, 6.985043763823827, 7.924556221005994, 8.939999707354543, 10.979573306056627, 9.93381742496153, 8.892470006746994, 7.840068002305404, 6.910916797585781, 5.940981655904361, 4.98459170854089, 3.9549581365165745, 2.97115016583368, 1.9850218644967503, 1.0276407931153724, 0.0, 1.0232704664842431, 1.9990099714146934, 2.9715133995770295, 3.942174405437343, 4.994859391587365, 6.009092398056858, 7.02929006570653, 7.969255926134586, 11.837663019160589, 10.788464291825319, 9.810625212739511, 8.747105775253159, 7.816410641553813, 6.889228079227534, 5.959550189654015, 4.925838390463265, 3.9719827623343034, 2.9985132198085553, 1.9388301533369687, 0.9355469598483143, 1.9020636920731246, 2.8427975536555907, 3.837390820009141, 4.801227679285367, 5.833021556471921, 6.8808894121618955, 7.923423939127305, 8.868864187657344, 12.754612167917958, 11.736537136998281, 10.699105273193371, 9.696587552254938, 8.793958073127657, 7.889072270141887, 6.921265540032243, 5.971317402597677, 4.910151217316119, 3.8844932490697293, 2.8806182456298095, 1.9469697990284254, 2.8671074841261475, 3.8440111060418225, 4.8203712173513065, 5.763529263626195, 6.822377065447295, 7.887251304758814, 8.883598646052862, 9.897844023026149, 13.627574882037088, 12.687618022428284, 11.71642400770959, 10.704875159453762, 9.759897548915767, 8.856318595133487, 7.898054195861567, 6.8644842114841955, 5.8948778896840155, 4.870666717556491, 3.8587552951639, 2.8923584130829654, 3.812069598109949, 4.836361144652258, 5.7676696648367125, 6.820372490264397, 7.844034240421262, 8.786860580796118, 9.791530078716338, 10.72059590724087, 14.558203514017448, 13.684698200825492, 12.741876102502866, 11.713835112575968, 10.793123711951353, 9.873379502014002, 8.833907050885259, 7.806105768877711, 6.847821700441641, 5.859613339290904, 4.849863175489084, 3.8736664192714647, 4.79733296295402, 5.735537597729133, 6.741238330804548, 7.761021514501723, 8.70844143382059, 9.692727024375866, 10.647972849421487, 11.657518815486782, 15.490622126409844, 14.62147115853905, 13.641456433852802, 12.674605506626834, 11.71894737036728, 10.780090848964521, 9.714991141977436, 8.779467237142006, 7.849929950095013, 6.85100841831428, 5.86970146231321, 4.899791283613387, 5.834262743408247, 6.699820856095642, 7.654561511105223, 8.582011397158807, 9.516025208573058, 10.481621474645113, 11.526811917107077, 12.567518374170913, 15.436880221314443, 15.574204760337004, 14.573582858683366, 13.579506664959881, 12.636637334287622, 11.655366325709254, 10.719077201899685, 9.734008763988767, 8.775534038422778, 7.84569620320157, 6.849452567386165, 5.903462377970596, 6.8772074354849, 7.692590565359996, 8.69182383983266, 9.58036646741858, 10.490515190615229, 11.41491937618784, 12.479366450647612, 13.510000013785811, 14.46428501211296, 15.411032606099313, 15.610419521552018, 14.618908137235447, 13.651601572349753, 12.723236106019934, 11.749474394619345, 10.790189880860087, 9.82955606942644, 8.817329883667918, 7.837387094102265, 6.8686228657368495, 7.861143720493651, 8.627378974368934, 9.619750905879016, 10.569494655047794, 11.511056763210004, 12.475404372644928, 13.404736884459126, 14.406147376213461, 13.62417140542054, 14.690737594963597, 15.668770460940278, 15.675361024477562, 14.674617065917536, 13.767062065687261, 12.751462687032378, 11.72156151633503, 10.868459229927613, 9.802905980643557, 8.816370115664515, 7.822841661243599, 8.854233871413456, 9.598052433995313, 10.560599015030258, 11.51522378166561, 12.464599798012255, 13.498964184964834, 14.44348316243795, 15.376955280346664, 12.588503094738071, 13.654539161478692, 14.700284821506095, 15.558653073347733, 14.520415210061259, 13.55707253200157, 12.591169307690885, 11.7409090893407, 11.013956889915516, 10.765864277713014, 9.833062400052775, 8.847327719125463, 9.779451994756009, 10.586537420977672, 11.523986418449363, 12.47091794570237, 13.466273144358391, 14.442380274481499, 15.376798529314593, 15.51023432410468, 11.726827204818344, 12.69839122173347, 13.771377730898994, 14.626054464575743, 13.621210631420455, 12.599747372548734, 11.645901099268706, 10.743741620376836, 9.944537020866498, 10.823044914564537, 10.726606338350896, 9.798761388933256, 10.726766123309172, 11.519777396573527, 12.473964563916, 13.39600000289052, 14.389019046718566, 15.387426618724556, 15.560359969646205, 14.59330051753392, 10.818910065586126, 11.85704655638887, 12.897683328944561, 13.618537127051821, 12.669046997033117, 11.660297529734333, 10.702918953655654, 9.71789812268155, 8.917020165570962, 9.8930849336714, 10.68588078450556, 10.770430131948222, 11.697270502199311, 12.5704440359917, 13.459476999139703, 14.41717465974634, 15.320240357710883, 15.583161806412125, 14.633713784122321, 13.700917079299142, 9.83864367170901, 10.78473707204777, 11.835668024297574, 12.659873178551747, 11.6524378724407, 10.682592004290255, 9.701819002988142, 8.752809601236603, 7.9413101332199325, 8.868975646572215, 9.624020748078582, 10.585884719979822, 11.620247281413437, 12.532429542660614, 13.503920485895488, 14.477209126324485, 15.459782189525642, 14.93199355465761, 13.86693250587263, 12.908449394851152, 8.969972967629442, 9.934404942541658, 10.902361061897379, 11.686863109561507, 10.753911647092773, 9.710888512189356, 8.707639628136763, 7.755873482390566, 6.948998106852201, 7.818156878316858, 8.677477166365135, 9.667812524640604, 10.642157256082903, 11.512618706375907, 12.491324594684729, 13.51835459382215, 14.424176297316512, 14.051771547970992, 13.046405905032605, 12.018927366250612, 9.93376241300452, 10.977548849715514, 11.681349080094403, 10.669696765729146, 9.711561362951498, 8.660234895057728, 7.775663492031708, 6.766123490821813, 5.880769142563873, 6.760902329284161, 7.725662835236565, 8.725256839492689, 9.59331468675455, 10.55799850134039, 11.550116925982989, 12.495496004752765, 13.424889603075092, 14.354525913556397, 13.879504101656078, 12.944829673090213, 10.911037109182125, 11.709690532338385, 10.772537219094144, 9.765717428993977, 8.711040273576254, 7.708190456412207, 6.7652372791374225, 5.826341971949724, 4.889300698700788, 5.791461440441095, 6.7368313889740055, 7.71975314520255, 8.632651880849426, 9.618388748229748, 10.638160497650695, 11.618039246738729, 12.579218852799054, 13.542704393836758, 14.491729489126724, 13.611166470592485, 11.844231367284221, 10.81865141135193, 9.789560298104158, 8.816094403526085, 7.741286165124706, 6.834821477834281, 5.832748914743452, 4.871391983471627, 3.961721724097544, 4.834650321898256, 5.7905133182224535, 6.6896991741849945, 7.703948909555284, 8.701428987642826, 9.655048597863027, 10.64404761678803, 11.659090353371884, 12.639397945880926, 13.653586880595133, 14.562852118129335], [14.686635257337851, 13.698671296554023, 12.73931241742548, 11.679766832640782, 10.740249451042947, 9.689791293039214, 8.70871599532186, 7.742714503649955, 6.723485013401352, 5.78477026074964, 4.856030786225691, 3.898598723466584, 3.0157179919014325, 3.8905381977933438, 4.8233595661709, 5.7772883415067415, 6.812515962001758, 7.775244445455188, 8.835090499867377, 9.894165095797861, 13.684171930190569, 12.754115487004109, 11.78147490751177, 10.841129097249695, 9.858746885507808, 8.907716299123356, 7.910089227842332, 6.875034004095321, 5.96133627349972, 4.956502477060401, 3.9563547177906995, 2.9637152550400323, 2.0233954280032513, 2.956502990572144, 3.833805505191292, 4.812531718108128, 5.852468186279367, 6.883369939622884, 7.8597812475967075, 8.875515755066354, 12.895528475513572, 11.89493384431822, 10.852951837164452, 9.873910454165914, 8.91309365994561, 7.941894725420852, 6.947797220219283, 5.92846448962994, 4.96964625307005, 4.053240308251012, 3.054524185112866, 2.0173353630092175, 0.9855661829187632, 1.918075542691048, 2.8593758874034174, 3.8685928007650343, 4.932049701030893, 5.961773297339584, 6.9012857545217505, 7.9167292408703, 12.002843772540873, 10.957087891445775, 9.915740473231239, 8.863338468789648, 7.934187264070024, 6.964252122388604, 6.007862175025133, 4.978228603000818, 3.994420632317923, 3.0082923309809937, 2.0509112595996157, 1.0232704664842431, 0.0, 0.9757395049304503, 1.9482429330927862, 2.9189039389530995, 3.971588925103122, 4.985821931572614, 6.006019599222286, 6.945985459650343, 12.822377828642724, 11.773179101307454, 10.795340022221646, 9.731820584735294, 8.801125451035947, 7.873942888709667, 6.9442649991361485, 5.905425714316938, 4.951570086187977, 3.9781005436622285, 2.9133991330480575, 1.910115939559403, 0.9435992073345923, 1.8843330689170585, 2.878926335270609, 3.8427631945468352, 4.874557071733388, 5.917565496707791, 6.960100023673201, 7.897258879192914, 13.739326977400093, 12.721251946480416, 11.683820082675506, 10.681302361737073, 9.778672882609792, 8.873787079624021, 7.905980349514376, 6.950904726451352, 5.889738541169793, 4.859062228780818, 3.8551872253408983, 2.920017221579932, 1.9086429993876153, 2.8855466213032903, 3.8619067326127743, 4.805064778887663, 5.863912580708762, 6.928786820020281, 7.92513416131433, 8.939379538287616, 14.612289691519223, 13.672332831910419, 12.701138817191724, 11.689589968935897, 10.744612358397902, 9.84103340461562, 8.8827690053437, 7.839053191195284, 6.869446869395104, 5.845235697267579, 4.831802717715406, 3.865405835634472, 2.8536051133714166, 3.877896659913726, 4.80920518009818, 5.861908005525865, 6.88556975568273, 7.8283960960575865, 8.833065593977807, 9.762131422502339, 15.542918323499583, 14.669413010307627, 13.726590911985001, 12.698549922058103, 11.777838521433488, 10.847948481725092, 9.80847603059635, 8.780674748588801, 7.82239068015273, 6.822970122519773, 5.813219958717952, 4.837023202500333, 3.838868478215487, 4.777073112990601, 5.782773846066016, 6.802557029763191, 7.749976949082059, 8.734262539637335, 9.689508364682956, 10.69905433074825, 15.418264174118859, 15.606185968021185, 14.626171243334937, 13.65932031610897, 12.703662179849415, 11.75465982867561, 10.689560121688524, 9.754036216853095, 8.8244989298061, 7.814365201543149, 6.8330582455420785, 5.855371404311635, 4.875798258669714, 5.74135637135711, 6.696097026366691, 7.623546912420274, 8.557560723834525, 9.52315698990658, 10.568347432368544, 11.60905388943238, 14.478415736575908, 15.39737629123295, 15.548151838394455, 14.55407564467097, 13.61120631399871, 12.629935305420343, 11.693646181610774, 10.708577743699855, 9.738890821651646, 8.809052986430437, 7.805032688084414, 6.859042498668845, 5.918742950746367, 6.734126080621464, 7.7333593550941275, 8.621901982680047, 9.532050705876696, 10.456454891449306, 11.52090196590908, 12.551535529047278, 13.505820527374427, 14.45256812136078, 15.473670684508868, 15.593477116946536, 14.626170552060842, 13.697805085731023, 12.724043374330433, 11.764758860571176, 10.792912852655308, 9.772910004366167, 8.792967214800514, 7.824202986435099, 6.964872384945515, 7.668914489630401, 8.661286421140483, 9.611030170309263, 10.552592278471469, 11.516939887906393, 12.446272399720593, 13.447682891474928, 12.665706920682005, 13.732273110225066, 14.710305976201747, 15.60550912861753, 14.57876703352604, 13.594025417796923, 12.729236785725531, 11.822405365452672, 11.824039350625862, 10.758486101341806, 9.771950236362764, 8.778421781941848, 7.972871070731299, 8.63958794925678, 9.602134530291725, 10.556759296927076, 11.50613531327372, 12.540499700226299, 13.485018677699415, 14.41849079560813, 11.63003860999954, 12.69607467674016, 13.741820336767564, 14.645378066459962, 13.607140203173488, 12.643797525113799, 11.677894300803114, 10.827634082452928, 11.843047932217054, 11.721444398411263, 10.788642520751024, 9.802907839823712, 8.898089194073851, 9.628072936239139, 10.56552193371083, 11.512453460963837, 12.507808659619856, 13.483915789742964, 14.418334044576058, 15.343848778019323, 10.768362720079812, 11.739926736994938, 12.812913246160463, 13.712779457687972, 12.707935624532684, 11.686472365660963, 10.732626092380935, 9.830466613489063, 10.779701717504238, 11.720473724442483, 11.682186459049145, 10.754341509631505, 9.845403322627014, 10.561312911834994, 11.515500079177468, 12.437535518151988, 13.430554561980035, 14.42896213398602, 15.42163144021804, 15.578015327016056, 9.847304757121695, 10.885441247924438, 11.88329098334489, 12.643031374346307, 11.755771990145346, 10.747022522846562, 9.789643946767884, 8.804623115793778, 9.769376127606396, 10.810137339368474, 11.651988357411975, 11.726010252646471, 10.815907701517153, 11.611979551253167, 12.50101251440117, 13.458710175007807, 14.361775872972352, 15.360833783863448, 15.618428593604456, 14.685631888781277, 8.867038363244578, 9.813131763583339, 10.81239755781333, 11.684367425846233, 10.73916286555293, 9.769316997402484, 8.78854399610037, 7.839534594348831, 8.871234545353149, 9.835083219478632, 10.590128320984997, 11.551992292886236, 11.866183410923096, 12.65690776610925, 13.467485494804517, 14.391758407003422, 15.376063852385997, 15.916708364139746, 14.851647315354764, 13.893164204333287, 7.946702501145198, 8.911134476057414, 9.879090595413135, 10.711357356855993, 9.778405894387259, 8.78263747292833, 7.79436462124899, 6.842598475502793, 7.8789225189854175, 8.784264451223274, 9.64358473927155, 10.63392009754702, 11.608264828989318, 12.478726279282323, 13.457432167591145, 14.484462166728566, 15.390283870222929, 15.075042014455237, 14.06967637151685, 13.042197832734857, 8.910491946520278, 9.954278383231273, 10.705843327388889, 9.694191013023632, 8.736055610245984, 7.730067610283423, 6.862388485143935, 5.85284848393404, 6.8415766821739705, 7.727009902190577, 8.69177040814298, 9.691364412399103, 10.559422259660966, 11.524106074246806, 12.516224498889406, 13.461603577659181, 14.390997175981509, 15.320633486462814, 14.902774568140323, 13.968100139574458, 9.887766642697883, 10.73418477963287, 9.797031466388628, 8.790211676288461, 7.735534520870739, 6.7780231716379005, 5.85196227224965, 4.913066965061951, 5.850108238310886, 6.757569013347512, 7.702938961880422, 8.685860718108966, 9.598759453755843, 10.584496321136164, 11.604268070557112, 12.584146819645145, 13.54532642570547, 14.508811966743174, 15.457837062033141, 14.634436937076728, 10.82096090079998, 9.795380944867688, 8.766289831619916, 7.792823937041843, 6.718015698640463, 5.840467438872065, 4.838394875781236, 3.948985381394947, 4.92782929700396, 5.800757894804673, 6.75662089112887, 7.655806747091411, 8.670056482461701, 9.667536560549243, 10.621156170769444, 11.610155189694446, 12.6251979262783, 13.605505518787343, 14.61969445350155, 15.586122584613578], [15.662374762268302, 14.656432291411843, 13.665349913645672, 12.605804328860973, 11.666286947263139, 10.615828789259405, 9.634753491542051, 8.668751999870146, 7.649522509621544, 6.710807756969832, 5.782068282445883, 4.824636219686776, 3.924656164426069, 2.9147986928628935, 3.84762006124045, 4.801548836576291, 5.836776457071307, 6.799504940524738, 7.859350994936928, 8.918425590867411, 14.65991143512102, 13.729854991934559, 12.75721441244222, 11.816868602180145, 10.834486390438258, 9.883455804053806, 8.885828732772783, 7.850773509025771, 6.887373769719913, 5.882539973280593, 4.882392214010891, 3.8897527512602244, 2.9494329242234434, 1.9807634856416936, 2.8580660002608416, 3.836792213177678, 4.876728681348917, 5.907630434692433, 6.884041742666257, 7.899776250135904, 13.87126798044402, 12.87067334924867, 11.828691342094901, 10.849649959096364, 9.88883316487606, 8.917634230351302, 7.9235367251497335, 6.90420399456039, 5.9453857580005005, 5.028979813181462, 3.980561681333058, 2.9433728592294095, 1.9116036791389548, 0.9423360377605978, 1.8836363824729672, 2.892853295834584, 3.9563101961004428, 4.986033792409134, 5.9255462495913, 6.94098973593985, 12.978583277471321, 11.932827396376224, 10.891479978161687, 9.839077973720098, 8.909926769000474, 7.9399916273190545, 6.983601679955584, 5.953968107931268, 4.9701601372483735, 3.984031835911444, 3.026650764530066, 1.9990099714146934, 0.9757395049304503, 0.0, 0.972503428162336, 1.9431644340226497, 2.9958494201726715, 4.010082426642164, 5.030280094291836, 5.970245954719893, 13.798117333573172, 12.748918606237902, 11.771079527152095, 10.707560089665742, 9.776864955966396, 8.849682393640117, 7.920004504066599, 6.881165219247388, 5.927309591118427, 4.953840048592679, 3.889138637978508, 2.885855444489853, 1.9193387122650427, 0.9845740817188258, 1.9791673480723762, 2.9430042073486025, 3.974798084535156, 4.941825991777341, 5.984360518742751, 6.921519374262464, 14.715066482330542, 13.696991451410865, 12.659559587605955, 11.657041866667521, 10.75441238754024, 9.849526584554471, 8.881719854444826, 7.926644231381802, 6.865478046100243, 5.834801733711269, 4.830926730271349, 3.895756726510382, 2.8843825043180655, 1.9857876341050575, 2.9621477454145415, 3.90530579168943, 4.964153593510529, 5.977840430623574, 6.974187771917623, 7.979076110895393, 15.588029196449671, 14.648072336840867, 13.676878322122173, 12.665329473866345, 11.72035186332835, 10.81677290954607, 9.85850851027415, 8.814792696125735, 7.845186374325555, 6.8209752021980306, 5.807542222645856, 4.841145340564922, 3.829344618301867, 3.0420325705228173, 3.9407281042973397, 4.975817965334237, 5.999479715491102, 6.9423060558659575, 7.946975553786178, 8.87604138231071, 15.508571316429508, 15.645152515238076, 14.70233041691545, 13.674289426988551, 12.753578026363936, 11.823687986655543, 10.7842155355268, 9.756414253519251, 8.798130185083181, 7.798709627450224, 6.788959463648403, 5.812762707430784, 4.814607983145938, 4.068272099675928, 4.914296770265175, 5.9340799539623506, 6.881499873281219, 7.865785463836494, 8.821031288882116, 9.83057725494741, 14.630955902441812, 15.66864733492725, 15.601910748265386, 14.635059821039418, 13.679401684779863, 12.730399333606062, 11.665299626618976, 10.729775721783547, 9.800238434736553, 8.790104706473599, 7.80879775047253, 6.831110909242086, 5.851537763600165, 5.032555358042438, 5.9087887546896445, 6.836238640743227, 7.77025245215748, 8.735848718229533, 9.781039160691497, 10.798617982746121, 13.691107464898863, 14.610068019555904, 15.610689921209541, 15.529815149601422, 14.586945818929163, 13.605674810350795, 12.669385686541226, 11.684317248630308, 10.714630326582096, 9.784792491360887, 8.780772193014863, 7.834782003599296, 6.894482455676818, 6.025325067306792, 6.946051083417081, 7.834593711003, 8.744742434199651, 9.66914661977226, 10.733593694232033, 11.764227257370232, 12.71851225569738, 13.665259849683734, 14.686362412831821, 15.700773306634508, 14.67707503891326, 13.748709572583442, 12.83202332789267, 12.740498365501628, 11.768652357585758, 10.748649509296618, 9.768706719730964, 8.799942491365549, 7.940611889875967, 6.960113476315729, 7.95248540782581, 8.90222915699459, 9.765284006794424, 10.729631616229348, 11.658964128043547, 12.660374619797881, 11.827876584832268, 12.863796034424226, 13.841828900400907, 14.644320419392393, 13.679565283280146, 12.694823667551029, 11.830035035479638, 12.731343537977308, 12.799778855556312, 11.734225606272256, 10.747689741293215, 9.754161286872298, 8.93877969414978, 7.930786935942108, 8.893333516977053, 9.847958283612405, 10.718827041596676, 11.753191428549254, 12.69771040602237, 13.631182523931084, 10.7615615341987, 11.82759760093932, 12.873343260966724, 13.671384113412145, 12.707938452927594, 11.744595774867905, 10.77869255055722, 11.736572254977563, 12.75198610474169, 12.697183903341713, 11.764382025681474, 10.778647344754162, 9.863997817492333, 8.919271922924468, 9.856720920396159, 10.803652447649165, 11.720500387942812, 12.69660751806592, 13.631025772899013, 14.556540506342277, 9.85112163427769, 10.822685651192817, 11.895672160358341, 12.738785504640155, 11.80873387428679, 10.78727061541507, 9.833424342135041, 10.739404786013699, 11.688639890028874, 12.629411896967119, 12.657925963979595, 11.730081014561955, 10.811311946045496, 9.852511898520323, 10.806699065862796, 11.728734504837316, 12.667258760934898, 13.641653862308976, 14.634323168540995, 15.511024555490465, 8.871565252191244, 9.909701742993988, 10.90755147841444, 11.667291869415857, 10.847043942048613, 9.847820772600668, 8.89044219652199, 9.713561288318413, 10.678314300131031, 11.71907551189311, 12.578025853632166, 12.701749757576922, 11.781816324935635, 10.903178537938496, 11.792211501086499, 12.749909161693136, 13.598480071927215, 14.573525512186404, 15.522973534476208, 15.661371393711725, 7.891298858314128, 8.837392258652889, 9.83665805288288, 10.708627920915783, 9.830434817456196, 8.86058894930575, 7.889342245854477, 8.748472766873466, 9.780172717877784, 10.761120715698825, 11.516165817205188, 12.478029789106428, 12.832092034341578, 11.948106752794578, 12.758684481489846, 13.682957393688751, 14.61276805134086, 15.588149010357236, 15.827386820285213, 14.868903709263735, 6.970962996214748, 7.935394971126964, 8.903351090482685, 9.735617851925543, 8.802666389456808, 7.80689796799788, 6.8748574198667685, 7.751536648027429, 8.787860691510053, 9.710301947443467, 10.56962223549174, 11.55995759376721, 12.53430232520951, 12.967917589079285, 13.771280372700605, 14.641811926191087, 15.64837394354999, 16.050781519385687, 15.045415876447299, 14.017937337665305, 7.9347524415898265, 8.97853887830082, 9.730103822458439, 8.718451508093182, 7.760316105315534, 6.754328105352973, 5.9428812837617135, 6.761786656458676, 7.750514854698606, 8.65304739841077, 9.617807904363172, 10.617401908619296, 11.485459755881159, 12.450143570466999, 13.442261995109599, 14.387641073879374, 15.317034672201702, 16.246670982683007, 15.878514073070772, 14.943839644504907, 8.912027137767431, 9.758445274702419, 8.821291961458178, 7.814472171358011, 6.759795015940289, 5.80228366670745, 4.9218850531975, 5.822005137586586, 6.759046410835522, 7.683606509567704, 8.628976458100613, 9.611898214329157, 10.524796949976036, 11.510533817356357, 12.530305566777303, 13.510184315865336, 14.471363921925661, 15.434849462963365, 16.383874558253332, 15.610176442007178, 9.84522139586953, 8.819641439937238, 7.790550326689466, 6.817084432111392, 5.742276193710013, 4.864727933941615, 3.862655370850786, 4.8579235539195835, 5.853866793224153, 6.726795391024865, 7.682658387349062, 8.581844243311604, 9.596093978681893, 10.593574056769434, 11.547193666989635, 12.536192685914637, 13.551235422498491, 14.531543015007534, 15.545731949721741, 16.56186208954403], [16.634878190430637, 15.62893571957418, 14.63785334180801, 13.57830775702331, 12.638790375425476, 11.588332217421742, 10.607256919704389, 9.641255428032483, 8.62202593778388, 7.683311185132167, 6.754571710608219, 5.797139647849112, 4.897159592588405, 3.8873021210252294, 3.017726649593355, 3.9155332616396237, 4.914904090424324, 5.877632573877754, 6.937478628289944, 7.9459221627050765, 15.632414863283355, 14.702358420096894, 13.729717840604556, 12.78937203034248, 11.806989818600593, 10.855959232216142, 9.858332160935117, 8.823276937188107, 7.859877197882248, 6.855043401442929, 5.8548956421732266, 4.86225617942256, 3.921936352385779, 2.9532669138040295, 2.009470489562028, 2.9507766382410106, 3.9548563147019324, 4.957588140933121, 5.911538314503922, 6.927272821973569, 14.843771408606358, 13.843176777411006, 12.801194770257238, 11.8221533872587, 10.861336593038395, 9.890137658513638, 8.896040153312068, 7.876707422722726, 6.917889186162836, 6.001483241343798, 4.953065109495394, 3.915876287391745, 2.8841071073012907, 1.9148394659229337, 1.0350408717741535, 1.9203498676722481, 2.9838067679381064, 4.013530364246798, 4.953042821428965, 5.968486307777514, 13.951086705633658, 12.905330824538561, 11.863983406324024, 10.811581401882433, 9.88243019716281, 8.91249505548139, 7.956105108117919, 6.9264715360936036, 5.942663565410709, 4.956535264073779, 3.9991541926924015, 2.971513399577029, 1.9482429330927862, 0.972503428162336, 0.0, 0.9706610058603136, 2.0233459920103356, 3.0375789984798285, 4.0577766661295005, 4.997742526557557, 14.77062076173551, 13.72142203440024, 12.743582955314432, 11.68006351782808, 10.749368384128733, 9.822185821802455, 8.892507932228936, 7.853668647409725, 6.899813019280764, 5.926343476755015, 4.861642066140844, 3.858358872652189, 2.8918421404273786, 1.9570775098811617, 1.0493741969910015, 2.0132110562672274, 3.018830356676994, 3.9693225636150054, 5.011857090580415, 5.949015946100128, 15.68756991049288, 14.669494879573202, 13.632063015768292, 12.629545294829859, 11.726915815702577, 10.822030012716809, 9.854223282607164, 8.899147659544138, 7.837981474262579, 6.807305161873605, 5.8034301584336845, 4.868260154672718, 3.8568859324804015, 2.9582910622673935, 2.0697783557040417, 3.01293640197893, 4.060232809521268, 5.005337002461238, 6.001684343755287, 7.006572682733058, 15.54683055869937, 15.620575765003204, 14.64938175028451, 13.637832902028682, 12.692855291490687, 11.789276337708408, 10.831011938436488, 9.787296124288071, 8.817689802487891, 7.793478630360366, 6.7800456508081925, 5.813648768727258, 4.801848046464203, 3.979667234771294, 3.04835871458684, 4.083448575623737, 5.107110325780602, 6.0499366661554586, 7.042971968189259, 7.972037796713791, 14.61620192671901, 15.689323793033063, 15.674833845077787, 14.646792855150888, 13.726081454526273, 12.796191414817878, 11.756718963689135, 10.728917681681587, 9.770633613245517, 8.77121305561256, 7.761462891810739, 6.78526613559312, 5.787111411308273, 5.005906763924405, 4.021927380554676, 5.041710564251851, 5.989130483570719, 6.9734160741259945, 7.928661899171616, 8.938207865236912, 13.738586512731313, 14.776277945216751, 15.665783023289928, 15.607563249201755, 14.6519051129422, 13.702902761768396, 12.63780305478131, 11.70227914994588, 10.772741862898888, 9.762608134635935, 8.781301178634864, 7.803614337404421, 6.8240411917625, 5.9701900222909146, 5.016419364979145, 5.943869251032728, 6.877883062446981, 7.8434793285190345, 8.888669770980998, 9.906248593035622, 12.798738075188364, 13.717698629845405, 14.718320531499042, 15.712396725222527, 14.900974022651996, 13.997300637515794, 13.64188911470356, 12.656820676792641, 11.687133754744432, 10.757295919523223, 9.753275621177199, 8.807285431761631, 7.8669858838391535, 6.9629597315552685, 6.053681693706581, 6.942224321292501, 7.852373044489152, 8.77677723006176, 9.841224304521534, 10.871857867659733, 11.826142865986881, 12.772890459973235, 13.793993023121322, 14.81475773169784, 13.857796323534933, 12.929430857205114, 13.804526756055008, 13.713001793663961, 12.741155785748093, 11.721152937458953, 10.7412101478933, 9.772445919527884, 8.913115318038303, 7.897748140564206, 7.090372862745259, 8.011826553278352, 8.872914617083925, 9.837262226518849, 10.766594738333048, 11.768005230087383, 10.935507195121769, 11.93663200628075, 12.876813006330885, 13.758304844455726, 12.860286567901818, 11.875544952172701, 12.802538463641975, 13.703846966139645, 13.772282283718647, 12.706729034434591, 11.72019316945555, 10.726664715034634, 9.876414358398257, 8.868421600190585, 8.131149450503791, 9.032883255417696, 9.826457651886177, 10.860822038838755, 11.805341016311871, 12.738813134220585, 9.869192144488201, 10.900433572795844, 11.908327366896701, 12.785368538475478, 11.888659737549267, 10.925317059489577, 11.751195978719558, 12.7090756831399, 13.724489532904027, 13.669687331504049, 12.73688545384381, 11.751150772916498, 10.80163248174081, 9.856906587172944, 9.094536853922897, 9.988577419454456, 10.828130998232313, 11.80423812835542, 12.738656383188514, 13.664171116631778, 8.878618206115357, 9.850182223030483, 10.923168732196007, 11.852769929703488, 10.940425742859706, 9.967991900036742, 10.805927770297378, 11.711908214176036, 12.661143318191211, 13.601915325129456, 13.63042939214193, 12.70258444272429, 11.748946610293974, 10.790146562768799, 10.050117126951598, 10.913659476642607, 11.774889371224399, 12.749284472598477, 13.741953778830496, 14.618655165779966, 7.89906182402891, 8.937198314831653, 9.935048050252103, 10.78127629447919, 9.970690757868603, 9.02854205722234, 9.862945624684327, 10.68606471648075, 11.650817728293369, 12.691578940055447, 13.550529281794502, 13.674253185739257, 12.719450989184113, 11.840813202186972, 11.0356295621753, 11.967103016081976, 12.706110682216716, 13.681156122475905, 14.630604144765709, 15.563400849588888, 6.918795430151793, 7.864888830490553, 8.864154624720543, 9.822612345979115, 8.954081633276186, 8.030695537658655, 8.861845674016815, 9.720976195035803, 10.752676146040121, 11.73362414386116, 12.488669245367523, 13.450533217268763, 13.769726698590055, 12.885741417043054, 12.002102542578648, 12.900151248077592, 13.72039866163036, 14.695779620646737, 15.593036277388634, 15.841407137426073, 5.998459568052413, 6.962891542964629, 7.930847662320349, 8.849602276988875, 7.916650814520141, 6.977004556350785, 7.847360848029105, 8.724040076189766, 9.76036411967239, 10.682805375605803, 11.542125663654076, 12.532461021929546, 13.506805753371845, 13.90555225332776, 13.014698433789407, 13.859005780579928, 14.75600455383949, 15.693143182226184, 16.017919304609634, 14.990440765827643, 6.962249013427491, 8.006035450138485, 8.844088247521771, 7.832435933156514, 6.874300530378866, 5.924434693705877, 6.91538471192405, 7.734290084621013, 8.723018282860943, 9.625550826573106, 10.590311332525507, 11.58990533678163, 12.457963184043496, 13.422646998629336, 13.955906102491147, 14.901285181260922, 15.75529124808091, 16.684927558562215, 16.85101750123311, 15.916343072667244, 7.939523709605097, 8.845159581227588, 7.91164372593161, 6.928456596421343, 5.873779441003621, 4.972390255060355, 5.894388481359837, 6.794508565748924, 7.731549838997859, 8.65610993773004, 9.601479886262949, 10.584401642491493, 11.497300378138373, 12.483037245518695, 13.50280899493964, 14.482687744027674, 15.443867350087999, 16.407352891125704, 17.35637798641567, 16.582679870169514, 8.875564793698164, 7.897769073290254, 6.868677960042483, 5.921932353850844, 4.856260618773345, 4.03483452229452, 4.835158799013122, 5.83042698208192, 6.8263702213864885, 7.6992988191872005, 8.655161815511397, 9.55434767147394, 10.56859740684423, 11.566077484931771, 12.519697095151972, 13.508696114076974, 14.523738850660829, 15.504046443169871, 16.51823537788408, 17.534365517706362], [17.60553919629095, 16.59959672543449, 15.60851434766832, 14.548968762883622, 13.609451381285787, 12.558993223282053, 11.5779179255647, 10.611916433892794, 9.592686943644193, 8.65397219099248, 7.725232716468533, 6.7678006537094255, 5.8533806587149995, 4.843523187151824, 3.9365545482316437, 2.9448722557793103, 3.94424308456401, 4.906971568017441, 5.96681762242963, 6.975261156844763, 16.60307586914367, 15.673019425957209, 14.70037884646487, 13.760033036202795, 12.777650824460908, 11.826620238076456, 10.828993166795431, 9.793937943048421, 8.830538203742561, 7.825704407303243, 6.82555664803354, 5.832917185282874, 4.892597358246093, 3.909487979930624, 2.958841845297534, 1.980115632380697, 2.984195308841619, 3.9869271350728064, 4.940877308643608, 5.956611816113255, 15.814432414466673, 14.813837783271321, 13.771855776117553, 12.792814393119015, 11.83199759889871, 10.860798664373952, 9.866701159172383, 8.84736842858304, 7.88855019202315, 6.9721442472041115, 5.9237261153557075, 4.886537293252059, 3.8547681131616045, 2.8855004717832475, 1.99751483912659, 0.9496888618119346, 2.013145762077793, 3.042869358386484, 3.982381815568651, 4.997825301917201, 14.921747711493973, 13.875991830398876, 12.834644412184339, 11.782242407742748, 10.853091203023125, 9.883156061341705, 8.926766113978234, 7.897132541953917, 6.913324571271023, 5.927196269934093, 4.969815198552715, 3.942174405437343, 2.9189039389531, 1.9431644340226497, 0.9706610058603136, 0.0, 1.052684986150022, 2.0669179926195147, 3.087115660269187, 4.027081520697244, 15.741281767595824, 14.692083040260554, 13.714243961174747, 12.650724523688394, 11.720029389989048, 10.792846827662768, 9.863168938089249, 8.824329653270038, 7.8704740251410765, 6.897004482615328, 5.832303072001157, 4.8290198785125025, 3.8625031462876924, 2.9277385157414755, 2.013823924364445, 1.049987065088219, 2.0481693508166803, 2.9986615577546916, 4.041196084720101, 4.978354940239815, 15.720942514278317, 15.640155885433517, 14.602724021628607, 13.600206300690173, 12.697576821562892, 11.792691018577122, 10.824884288467477, 9.86980866540445, 8.808642480122892, 7.777966167733918, 6.774091164293997, 5.838921160533031, 4.827546938340715, 3.9289520681277073, 3.034228083077485, 2.0998115404489788, 3.089571803660954, 4.0346759966009245, 5.031023337894974, 6.035911676872745, 14.676750370799578, 15.616707230408382, 15.620042756144825, 14.608493907888997, 13.663516297351002, 12.759937343568721, 11.8016729442968, 10.757957130148382, 9.788350808348202, 8.764139636220678, 7.7507066566685054, 6.784309774587571, 5.772509052324517, 4.944116962144737, 4.012808441960283, 3.1703237140937857, 4.1641499756738, 5.087651018744434, 6.072310962328945, 7.001376790853477, 13.746121738819218, 14.810587002235316, 15.714068329432768, 15.617453861011203, 14.696742460386588, 13.76685242067819, 12.727379969549446, 11.699578687541898, 10.741294619105828, 9.741874061472874, 8.732123897671054, 7.755927141453434, 6.757772417168587, 5.970356491297848, 4.986377107928119, 4.240406090014831, 5.130863258977269, 6.115148849532544, 7.021926871976181, 7.990029709638492, 12.868506324831522, 13.856500454481136, 14.746005532554312, 15.71285645978028, 14.963286503285495, 14.673563767628707, 13.608464060641621, 12.672940155806192, 11.7434028687592, 10.73326914049625, 9.751962184495179, 8.774275343264735, 7.794702197622814, 6.934639749664358, 5.980869092352588, 5.2182099805428965, 6.152223791957149, 7.117820058029203, 8.084531702829956, 8.958070437437202, 11.916288643607935, 12.79792113910979, 13.798543040763427, 14.792619234486912, 14.018314952401653, 14.88180057911135, 14.61255012056387, 13.627481682652952, 12.657794760604746, 11.727956925383538, 10.723936627037514, 9.777946437621946, 8.837646889699467, 7.927409458928712, 7.0181314210800245, 6.21656505080267, 7.12671377399932, 8.051117959571929, 9.037086236370492, 9.952080376924117, 10.906365375251266, 11.85311296923762, 12.874215532385707, 13.844096725837526, 12.97513725328459, 13.81393079880067, 14.709981648625865, 14.683662799524273, 13.711816791608408, 12.691813943319268, 11.711871153753615, 10.743106925388199, 9.883776323898616, 8.862197867937649, 8.054822590118702, 7.28616728278852, 8.147255346594093, 9.111602956029017, 9.962456670182005, 10.897925042187591, 9.987329039523349, 10.965971000420438, 11.906152000470573, 12.787643838595411, 11.952121759716807, 12.760044893768256, 13.707993356212832, 14.646221308073974, 14.742943289578962, 13.677390040294906, 12.690854175315865, 11.697325720894948, 10.8408640857717, 9.832871327564028, 9.095599177877235, 8.307223984927864, 9.100798381396345, 10.135162768348923, 11.001202948160827, 11.868732946320794, 8.921013988889781, 9.929772566935533, 10.93766636103639, 11.814707532615163, 10.980494929364255, 11.809817001085133, 12.656650871290415, 13.65145002507423, 14.666863874838356, 14.640348337364363, 13.707546459704124, 12.721811778776813, 11.766082209114254, 10.821356314546387, 10.05898658129634, 9.262918148964625, 10.102471727742481, 11.078578857865589, 12.012997112698683, 12.794090928731986, 7.907957200255043, 8.87952121717017, 9.952507726335696, 10.882108923843173, 9.969764736999391, 10.852491841632297, 11.711382662868235, 12.656138329545504, 13.605373433560679, 14.546145440498924, 14.601090398002246, 13.673245448584606, 12.713396337667417, 11.754596290142242, 11.014566854325041, 10.188000206152775, 11.049230100734567, 12.023625202108645, 13.016294508340664, 13.748574977880175, 6.928400818168597, 7.96653730897134, 8.96438704439179, 9.810615288618875, 9.000029752008288, 9.913041998817896, 10.768400517255184, 11.630294831850218, 12.595047843662837, 13.635809055424915, 14.521190287654814, 14.642846189350788, 13.683900716557556, 12.805262929560415, 12.000079289548744, 11.241443745592145, 11.980451411726884, 12.955496851986073, 13.904944874275877, 14.806146546940694, 5.94813442429148, 6.89422782463024, 7.89349361886023, 8.8519513401188, 7.983420627415871, 8.91519547925421, 9.767300566587672, 10.66520631040527, 11.69690626140959, 12.689060743906419, 13.459330251227836, 14.421194223129076, 14.734176425963497, 13.850191144416497, 12.966552269952091, 12.17449197758776, 12.994739391140529, 13.970120350156906, 14.867377006898803, 15.82586011792028, 5.0277985621921, 5.992230537104316, 6.960186656460036, 7.878941271128561, 6.945989808659826, 7.86150449794634, 8.752815740599962, 9.668270191559234, 10.704594235041858, 11.638241975651061, 12.512786669514389, 13.503122027789859, 14.477466759232158, 14.870001980701204, 13.97914816116285, 13.133346510090096, 14.030345283349659, 14.967483911736352, 15.930740232210937, 15.961101771687957, 5.991588007567178, 7.0353744442781725, 7.873427241661457, 6.861774927296199, 5.903639524518551, 6.808934635301432, 7.820839604494907, 8.678520199990482, 9.667248398230413, 10.580987426618364, 11.56097233838582, 12.560566342641945, 13.428624189903807, 14.393308004489647, 14.92035582986459, 14.18378720995257, 15.029631977591078, 15.959268288072384, 16.948313522399392, 16.88700407852756, 6.968862703744784, 7.874498575367273, 6.940982720071297, 5.957795590561029, 4.903118435143307, 5.856890196655909, 6.799843373930694, 7.7387386811183925, 8.675779954367329, 9.611546537775299, 10.572140892123262, 11.555062648351806, 12.467961383998684, 13.453698251379006, 14.473470000799951, 15.116968791098044, 15.970296894691751, 16.933782435729455, 17.88280753101942, 17.55334087602983, 7.904903787837851, 6.92710806742994, 5.898016954182169, 4.95127134799053, 3.885599612913032, 4.919334463890074, 5.791379865139716, 6.786648048208514, 7.797031227246801, 8.669959825047513, 9.62582282137171, 10.525008677334252, 11.539258412704541, 12.536738490792082, 13.490358101012283, 14.479357119937285, 15.49439985652114, 16.47470744903018, 17.488896383744386, 18.505026523566677], [18.65822418244097, 17.652281711584514, 16.661199333818345, 15.601653749033645, 14.66213636743581, 13.611678209432077, 12.630602911714723, 11.664601420042818, 10.645371929794214, 9.706657177142501, 8.777917702618554, 7.820485639859447, 6.895065649381566, 5.885208177818391, 4.978239538898211, 3.9865572464458774, 2.941911930598417, 3.9046404140518476, 4.915812028739248, 5.92257617069474, 17.65576085529369, 16.72570441210723, 15.753063832614892, 14.812718022352817, 13.83033581061093, 12.879305224226478, 11.881678152945453, 10.846622929198444, 9.883223189892583, 8.878389393453263, 7.878241634183562, 6.885602171432895, 5.945282344396114, 4.951172970597191, 4.0005268359641, 3.0218006230472643, 1.9818641548760259, 2.9342421489227846, 3.888192322493586, 4.903926829963233, 16.867117400616692, 15.86652276942134, 14.824540762267572, 13.845499379269036, 12.884682585048731, 11.913483650523974, 10.919386145322404, 9.900053414733064, 8.941235178173173, 8.024829233354135, 6.976411101505729, 5.93922227940208, 4.907453099311626, 3.9381854579332694, 3.050199825276612, 2.0023738479619566, 1.0108146081121998, 1.9901843722364623, 2.929696829418629, 3.9451403157671785, 15.974432697643993, 14.928676816548895, 13.887329398334359, 12.83492739389277, 11.905776189173146, 10.935841047491726, 9.979451100128255, 8.949817528103939, 7.966009557421045, 6.9798812560841155, 6.0225001847027375, 4.994859391587365, 3.971588925103122, 2.9958494201726715, 2.0233459920103356, 1.052684986150022, 0.0, 1.0142330064694927, 2.0344306741191653, 2.974396534547222, 15.730367259776623, 15.744768026410574, 14.766928947324766, 13.703409509838414, 12.772714376139067, 11.845531813812789, 10.91585392423927, 9.877014639420059, 8.923159011291098, 7.949689468765349, 6.884988058151178, 5.881704864662524, 4.915188132437714, 3.9804235018914973, 2.991115101129438, 2.027278241853212, 0.9954843646666582, 1.9459765716046697, 2.988511098570079, 3.925669954089793, 14.668257528128295, 15.528018457924919, 15.655409007778626, 14.652891286840193, 13.750261807712912, 12.845376004727143, 11.877569274617498, 10.922493651554472, 9.861327466272913, 8.830651153883938, 7.826776150444019, 6.891606146683053, 5.880231924490737, 4.981637054277729, 4.011519259842478, 3.0771027172139718, 2.0368868175109323, 2.9819910104509026, 3.9783383517449513, 4.983226690722723, 13.624065384649557, 14.56402224425836, 15.535216258977055, 15.661178894039017, 14.716201283501022, 13.812622329718742, 12.854357930446822, 11.810642116298405, 10.841035794498225, 9.8168246223707, 8.803391642818527, 7.836994760737593, 6.825194038474538, 5.92140813890973, 4.990099618725276, 4.135126739680643, 3.1114649895237774, 4.0349660325944114, 5.019625976178923, 5.948691804703455, 12.693436752669196, 13.757902016085295, 14.661383343282747, 15.649600322542891, 15.749427446536608, 14.819537406828212, 13.78006495569947, 12.752263673691921, 11.793979605255851, 10.794559047622895, 9.784808883821075, 8.808612127603455, 7.810457403318608, 6.947647668062841, 5.963668284693112, 5.025598192146115, 4.078178272827246, 5.062463863382522, 5.9692418858261584, 6.9373447234884695, 11.8158213386815, 12.803815468331115, 13.69332054640429, 14.660171473630259, 15.615829609889813, 15.72624875377873, 14.661149046791644, 13.725625141956215, 12.796087854909223, 11.78595412664627, 10.8046471706452, 9.791666547901702, 8.81209340225978, 7.885592623737344, 6.930851968727763, 6.00340208267418, 5.103091546629608, 6.068687812701662, 7.031846716679933, 7.90538545128718, 10.863603657457913, 11.745236152959768, 12.745858054613405, 13.73993424833689, 14.68280357900915, 15.664074587587518, 15.665235106713894, 14.680166668802975, 13.710479746754768, 12.780641911533559, 11.74132783167448, 10.795337642258913, 9.855038094336432, 8.878362333001698, 7.92938412244316, 7.001757152933953, 6.077581528671779, 7.001985714244388, 7.984401250220468, 8.899395390774096, 9.853680389101244, 10.800427983087598, 11.821530546235685, 12.804194850692964, 13.712732643612563, 14.641098109942382, 15.640448009783329, 15.736347785674296, 14.753929276863037, 13.709205147956235, 12.729262358390582, 11.760498130025166, 10.876886854468495, 9.813150742010636, 8.966075291481838, 8.071359384919804, 7.098123101266553, 8.062470710701476, 8.909771684031982, 9.84524005603757, 8.934644053373326, 9.913286014270415, 10.85346701432055, 11.74774196345085, 12.68971715004478, 13.622860338715412, 14.638459717370296, 15.61105681066252, 15.760334494215929, 14.694781244931873, 13.708245379952832, 12.714716925531915, 11.791816959844688, 10.783824201637016, 10.00685187924037, 9.053175830353709, 8.051666136068805, 9.086030523021384, 9.948517962010804, 10.816047960170772, 7.868329002739758, 8.87708758078551, 9.884981374886367, 10.774805657470601, 11.718090319692228, 12.672632446032289, 13.62148637387896, 14.616285527662775, 15.631699377426902, 15.653495930877538, 14.720694053217299, 13.680994350986184, 12.717035083187241, 11.772309188619374, 10.970239282659476, 10.00886999439047, 9.053339482414941, 10.029446612538049, 10.963864867371143, 11.741405942581965, 6.855272214105021, 7.826836231020147, 8.899822740185673, 9.842207048698612, 10.707360127327364, 11.715307286579453, 12.676218165456781, 13.697823320212072, 14.647058424227247, 15.587830431165491, 15.560272970211617, 14.632428020793977, 13.664349211740404, 12.70554916421523, 11.925819555688177, 10.93395205157862, 10.000097855407027, 10.974492956781106, 11.967162263013124, 12.695889991730153, 5.8757158320185745, 6.9138523228213185, 7.911702058241769, 8.770713413474313, 9.737625142336261, 10.775857443765052, 11.73323601984373, 12.671979822516786, 13.636732834329404, 14.677494046091482, 15.573875273804836, 15.593799063423775, 14.634853590630543, 13.756215803633403, 12.91133199091188, 11.970937049447066, 10.931319166399344, 11.906364606658533, 12.855812628948337, 13.753461560790672, 4.8954494381414575, 5.841542838480218, 6.840808632710209, 7.812049464974238, 8.839543062625827, 9.809388930776272, 10.790161932078385, 11.706891301071838, 12.738591252076155, 13.730745734572984, 14.512015237377858, 15.473879209279097, 15.685129300036486, 14.801144018489484, 13.877804971315227, 12.903985281442681, 11.945607145812989, 12.920988104829366, 13.818244761571263, 14.77672787259274, 3.975113576042078, 4.9395455509542945, 5.9075016703100145, 6.862844587920769, 7.856833205555636, 8.903189488612908, 9.79450073126653, 10.7099551822258, 11.746279225708424, 12.679926966317627, 13.56547165566441, 14.55580701393988, 15.53015174538218, 15.820954854774191, 14.889869813082438, 13.862839813945017, 12.98121303802212, 13.918351666408814, 14.881607986883399, 15.815121217487974, 4.938903021417156, 5.982689458128151, 6.837303143714779, 6.005111573824632, 6.945324515185119, 7.850619625967999, 8.862524595161474, 9.720205190657047, 10.708933388896979, 11.62267241728493, 12.613657324535842, 13.613251328791964, 14.48130917605383, 15.44599299063967, 15.831077481784178, 14.909893330585867, 13.980499732263539, 14.910136042744844, 15.89918127707185, 16.828680378423954, 5.916177717594762, 6.859382604672053, 5.938651566105703, 5.0101196739479725, 5.944803425809875, 6.898575187322477, 7.841528364597261, 8.780423671784959, 9.717464945033894, 10.653231528441864, 11.624825878273283, 12.607747634501827, 13.520646370148707, 14.506383237529029, 15.526154986949974, 15.84307491173134, 14.921164649364211, 15.884650190401915, 16.833675285691882, 17.78678707330456, 6.852218801687829, 5.91199209673472, 4.895685800216576, 3.948940194024937, 4.927284603579599, 5.9610194545566415, 6.833064855806283, 7.828333038875081, 8.849716213396823, 9.722644811197535, 10.678507807521731, 11.577693663484274, 12.591943398854564, 13.589423476942105, 14.543043087162307, 15.532042106087308, 15.95748297097289, 16.921016319201915, 17.8055133204395, 18.738472720841408], [18.78256195267829, 18.012281157124875, 17.13479155426882, 16.589520636519467, 15.650003254921632, 14.599545096917899, 13.618469799200545, 12.65246830752864, 11.633238817280038, 10.694524064628325, 9.765784590104378, 8.80835252734527, 7.848964636692784, 6.839107165129609, 5.906285796752052, 4.914603504299719, 3.8631900496126317, 2.9004615661592013, 3.9015790222697557, 4.908343164225248, 17.780098625531007, 17.739937418576723, 16.767296839084384, 15.826951028822311, 14.844568817080424, 13.893538230695972, 12.895911159414947, 11.860855935667937, 10.871090077378406, 9.866256280939087, 8.866108521669386, 7.873469058918718, 6.925274710972403, 5.920219711517974, 4.969573576884883, 3.9908473639680464, 2.950910895796808, 1.9200091424532917, 2.8739593160240933, 3.88969382349374, 16.773744963035853, 16.880755775890837, 15.838773768737068, 14.85973238573853, 13.898915591518225, 12.927716656993468, 11.933619151791898, 10.914286421202556, 9.955468184642665, 9.039062239823627, 7.990644107975223, 6.953455285871574, 5.92168610578112, 4.952418464402763, 4.064432831746105, 3.0166068544314495, 2.0250476145816925, 0.9759513657669695, 1.9154638229491363, 2.9309073092976856, 15.761425854395291, 15.942909823018391, 14.901562404803855, 13.849160400362264, 12.92000919564264, 11.95007405396122, 10.99368410659775, 9.964050534573433, 8.980242563890538, 7.994114262553609, 7.036733191172231, 6.0090923980568585, 4.985821931572615, 4.010082426642165, 3.0375789984798285, 2.0669179926195147, 1.0142330064694927, 0.0, 1.0201976676496725, 1.9601635280777292, 14.71613425330713, 15.520963727773214, 15.762310100111003, 14.698790662624651, 13.768095528925304, 12.840912966599024, 11.911235077025506, 10.872395792206294, 9.918540164077333, 8.945070621551585, 7.880369210937413, 6.877086017448759, 5.910569285223948, 4.969835423641482, 3.975242157287931, 3.011405298011705, 1.9796114208251514, 0.931743565135177, 1.9742780921005867, 2.9114369476202997, 13.654024521658803, 14.513785451455426, 15.53830198702378, 15.64827243962643, 14.745642960499149, 13.840757157513378, 12.872950427403733, 11.917874804340707, 10.856708619059148, 9.826032306670173, 8.822157303230254, 7.886987299469288, 6.875613077276971, 5.9710489760277135, 4.995646316000971, 4.061229773372465, 3.0210138736694256, 1.9677580039814098, 2.964105345275459, 3.9689936842532294, 12.609832378180064, 13.549789237788868, 14.520983252507563, 15.539524881582778, 15.711582436287259, 14.808003482504978, 13.849739083233057, 12.806023269084639, 11.836416947284459, 10.812205775156935, 9.798772795604762, 8.832375913523828, 7.820575191260772, 6.905535195068223, 5.974226674883769, 4.98722111665664, 3.963559366499775, 3.020733026124919, 4.005392969709431, 4.934458798233963, 11.679203746199704, 12.743669009615802, 13.647150336813255, 14.635367316073399, 15.527420261836248, 15.814918559614446, 14.775446108485703, 13.747644826478155, 12.789360758042084, 11.78994020040913, 10.78019003660731, 9.80399328038969, 8.805838556104844, 7.931774724221334, 6.897475752819287, 5.877692569122112, 4.930272649803244, 4.059532951163371, 4.955008879356666, 5.923111717018977, 10.801588332212008, 11.789582461861622, 12.679087539934798, 13.645938467160766, 14.60159660342032, 15.583850211512045, 15.639776746049746, 14.704252841214316, 13.723984173646631, 12.700635744949373, 11.68272192811525, 10.643760924877697, 9.664187779235775, 8.73768700071334, 7.78294634570376, 6.855496459650177, 5.955185923605606, 5.126373764535723, 6.017613710210441, 6.8911524448176875, 9.849370650988421, 10.731003146490275, 11.731625048143913, 12.725701241867398, 13.668570572539657, 14.649841581118025, 15.586130704927594, 15.578196030026014, 14.588969588594656, 13.659131753373448, 12.593422208650475, 11.647432019234907, 10.707132471312427, 9.730456709977693, 8.781478499419158, 7.853851529909951, 6.929675905647777, 6.059671666078449, 6.970168243750976, 7.8851623843046035, 8.839447382631752, 9.786194976618106, 10.807297539766193, 11.789961844223471, 12.69849963714307, 13.62686510347289, 14.626215003313837, 15.528195439667972, 15.606023653839031, 14.56129952493223, 13.581356735366576, 12.61259250700116, 11.72898123144449, 10.66524511898663, 9.818169668457836, 8.923453761895802, 7.950217478242551, 7.120156662535536, 7.89553867756249, 8.831007049568077, 7.9204110469038325, 8.899053007800921, 9.839234007851056, 10.733508956981357, 11.675484143575288, 12.60862733224592, 13.624226710900803, 14.596823804193027, 15.574728884442795, 15.546875621907867, 14.560339756928826, 13.56681130250791, 12.643911336820683, 11.63591857861301, 10.858946256216369, 9.905270207329707, 8.903760513044803, 8.176697573860395, 8.934284955541312, 9.80181495370128, 6.8540959962702654, 7.862854574316016, 8.870748368416873, 9.760572651001109, 10.703857313222736, 11.658399439562796, 12.607253367409468, 13.602052521193283, 14.617466370957409, 15.608867536153133, 15.572788430193294, 14.533088727962179, 13.569129460163236, 12.624403565595369, 11.822333659635474, 10.860964371366467, 9.90543385939094, 9.189665275991608, 9.951785346124009, 10.727172936112472, 5.841039207635528, 6.812603224550654, 7.885589733716179, 8.827974042229119, 9.693127120857872, 10.70107428010996, 11.661985158987289, 12.715870346500665, 13.66510545051584, 14.605877457454085, 15.656279298744609, 15.484522397769972, 14.516443588716399, 13.557643541191224, 12.777913932664175, 11.786046428554618, 10.852192232383025, 10.134711620234665, 10.95508274176599, 11.68165698526066, 4.861482825549081, 5.899619316351824, 6.897469051772276, 7.756480407004821, 8.723392135866769, 9.76162443729556, 10.719003013374238, 11.69002684880538, 12.654779860617998, 13.695541072380076, 14.767443797827964, 15.795569304565978, 15.486947967606538, 14.608310180609397, 13.763426367887877, 12.823031426423064, 11.783413543375342, 11.066583270112092, 11.881728927289874, 12.73922855432118, 3.881216431671964, 4.827309832010725, 5.826575626240716, 6.797816458504745, 7.825310056156335, 8.79515592430678, 9.775928925608893, 10.724938327360432, 11.792900226872742, 12.802166259531894, 13.853330199805676, 14.815194171706915, 15.849556733140531, 15.653238395465479, 14.729899348291225, 13.75607965841868, 12.797701522788987, 12.081206768282925, 12.8441610599128, 13.769446826408082, 2.960880569572585, 3.925312544484801, 4.893268663840521, 5.848611581451276, 6.842600199086142, 7.908436567260207, 8.9116854513128, 9.940146187513548, 10.976470230996172, 11.953640279955183, 13.018684120562025, 14.009019478837494, 14.983364210279793, 16.0230077914984, 15.741964190058436, 14.714934190921015, 13.833307414998117, 13.078570329862373, 13.907524285224934, 14.807840171303315, 3.9246700149476625, 4.968456451658657, 5.823070137245285, 6.834722451610542, 7.79285785438819, 8.77866588382184, 9.790570853015316, 10.648251448510889, 11.63697964675082, 12.550718675138771, 13.551760886763404, 14.56163155442068, 15.469176063539653, 16.433859878125492, 16.683171858760176, 15.761987707561865, 14.832594109239537, 14.090521470053828, 14.957602075957558, 15.821399332239297, 4.901944711125268, 5.8451495982025605, 4.934472718213057, 5.931397792962187, 6.872849683663716, 7.826621445176318, 8.769574622451103, 9.7084699296388, 10.645511202887736, 11.581277786295706, 12.612692765759107, 13.59561452198765, 14.50851325763453, 15.494250125014851, 16.514021874435795, 16.695169288707337, 15.77325902634021, 15.075674344602993, 15.973964709146705, 16.85454577229314, 5.837985795218335, 4.897759090265228, 3.89150695232393, 4.870218313039151, 5.8553308614334405, 6.889065712410483, 7.786963843117501, 8.7822320261863, 9.837583100882647, 10.710511698683359, 11.666374695007555, 12.565560550970098, 13.579810286340386, 14.577290364427927, 15.530909974648129, 16.519908993573132, 16.80957734794889, 16.112040473402992, 16.94580274389432, 17.806231419829988], [17.76661246077393, 17.091679810385287, 17.91072853249472, 17.481565811010967, 16.542048429413132, 15.491590271409398, 14.510514973692045, 13.54451348202014, 12.525283991771538, 11.586569239119825, 10.657829764595878, 9.70039770183677, 8.741009811184286, 7.73115233962111, 6.798330971243553, 5.80664867879122, 4.7552352241041325, 3.792506740650702, 2.9145992823969227, 3.888626767786601, 16.76414913362665, 17.38824619488272, 17.787494506734056, 16.847148696471983, 15.864766484730096, 14.866911243328138, 13.819393823043214, 12.777972764284668, 11.763135251869906, 10.758301455430587, 9.758153696160885, 8.765514233410219, 7.8173198854639026, 6.812264886009474, 5.861618751376383, 4.882892538459547, 3.8429560702883085, 2.812054316944792, 1.8869795761512602, 2.8699774270550935, 15.757795471131493, 16.45521460141145, 16.85897143638674, 15.879930053388202, 14.919113259167897, 13.94791432464314, 12.95381681944157, 11.934484088852228, 10.975665852292337, 10.0592599074733, 9.010841775624895, 7.973652953521246, 6.941883773430792, 5.972616132052435, 5.042964202770437, 3.995138225455782, 2.9316813251899236, 1.8679965402584697, 0.928484083076303, 1.9107096416480132, 14.745476362490932, 15.497460250517262, 15.921760072453527, 14.869358068011936, 13.940206863292312, 12.970271721610892, 12.013881774247421, 10.984248202223105, 10.00044023154021, 9.01431193020328, 8.056930858821904, 7.029290065706531, 6.006019599222288, 5.030280094291838, 4.057776666129501, 3.0871156602691876, 2.0344306741191653, 1.0201976676496725, 0.0, 0.9399658604280567, 13.70018476140277, 14.505014235868854, 15.482853314954662, 15.718988330274323, 14.788293196574976, 13.861110634248696, 12.931432744675178, 11.892593459855966, 10.938737831727005, 9.965268289201257, 8.900566878587085, 7.897283685098431, 6.930766952873621, 5.990033091291155, 4.995439824937604, 4.031602965661378, 2.999809088474824, 1.9519412327848493, 1.0423743749831018, 1.8912392799706275, 12.638075029754443, 13.497835959551066, 14.52235249511942, 15.524870216057854, 15.76584062814882, 14.86095482516305, 13.893148095053405, 12.93807247199038, 11.87690628670882, 10.846229974319845, 9.842354970879926, 8.90718496711896, 7.895810744926644, 6.991246643677386, 6.015843983650644, 5.081427441022138, 4.041211541319098, 2.987955671631082, 2.043503998535865, 2.948796016603557, 11.593882886275704, 12.533839745884508, 13.505033760603203, 14.523575389678419, 15.486568753433762, 15.82820115015465, 14.86993675088273, 13.82622093673431, 12.85661461493413, 11.832403442806607, 10.818970463254434, 9.8525735811735, 8.840772858910444, 7.925732862717896, 6.994424342533442, 6.007418784306312, 4.983757034149447, 4.040930693774591, 3.0847916229698367, 3.9185093063296033, 10.663254254295344, 11.727719517711442, 12.631200844908895, 13.61941782416904, 14.511470769931888, 15.451207031342687, 15.795643776135375, 14.767842494127827, 13.809558425691757, 12.810137868058803, 11.800387704256982, 10.824190948039362, 9.826036223754516, 8.951972391871006, 7.917673420468959, 6.897890236771784, 5.950470317452916, 4.989653357662694, 4.034407532617072, 4.907162225114618, 9.785638840307648, 10.773632969957262, 11.663138048030438, 12.629988975256406, 13.58564711151596, 14.567900719607685, 15.574267272945484, 15.724450508863988, 14.744181841296303, 13.720833412599045, 12.702919595764921, 11.663958592527369, 10.684385446885447, 9.757884668363012, 8.803144013353432, 7.875694127299849, 6.975383591255278, 6.0564941710350455, 5.097012363470847, 5.8752029529133285, 8.833421159084063, 9.715053654585915, 10.715675556239553, 11.709751749963038, 12.652621080635297, 13.633892089213665, 14.570181213023234, 15.56417888888962, 15.609167256244328, 14.67932942102312, 13.613619876300147, 12.66762968688458, 11.727330138962099, 10.750654377627365, 9.80167616706883, 8.874049197559623, 7.949873573297449, 6.989792072577772, 6.049566897011382, 6.8692128924002445, 7.823497890727393, 8.770245484713746, 9.791348047861833, 10.7697641765738, 11.678301969493397, 12.606667435823216, 13.606017335664164, 14.5079977720183, 15.526996249839936, 15.581497192581901, 14.601554403016248, 13.632790174650832, 12.749178899094161, 11.685442786636303, 10.838367336107508, 9.943651429545474, 8.970415145892222, 7.992607341865301, 6.974937330822896, 7.815057557663718, 6.9044615549994734, 7.87885534015125, 8.819036340201384, 9.713311289331685, 10.655286475925614, 11.588429664596248, 12.604029043251131, 13.576626136543355, 14.554531216793123, 15.612070198229205, 15.580537424578498, 14.587008970157582, 13.664109004470355, 12.656116246262682, 11.87914392386604, 10.925467874979377, 9.923958180694473, 9.03298050491956, 8.013683608801719, 8.78586546179692, 5.838146504365906, 6.842656906666344, 7.850550700767201, 8.740374983351437, 9.683659645573062, 10.638201771913124, 11.587055699759796, 12.58185485354361, 13.597268703307737, 14.58866986850346, 15.5214717461637, 15.55328639561185, 14.589327127812908, 13.64460123324504, 12.842531327285146, 11.881162039016138, 10.92563152704061, 9.96560225421751, 9.031183999384416, 9.711223444208112, 4.820841539985856, 5.792405556900982, 6.865392066066507, 7.807776374579447, 8.672929453208198, 9.680876612460288, 10.641787491337617, 11.695672678850993, 12.644907782866168, 13.585679789804413, 14.636081631094937, 15.563926580512577, 15.536641256366071, 14.577841208840896, 13.798111600313847, 12.806244096204288, 11.872389900032696, 10.910648598460567, 10.034481395026397, 10.665707493356301, 3.841285157899409, 4.879421648702152, 5.877271384122604, 6.736282739355149, 7.703194468217096, 8.741426769645887, 9.698805345724566, 10.669829181155707, 11.634582192968326, 12.675343404730404, 13.747246130178292, 14.775371636916306, 15.734317109709538, 15.62850784825907, 14.78362403553755, 13.843229094072734, 12.803611211025013, 11.842520248337994, 10.961127580550281, 11.72327906241682, 2.861018764022292, 3.807112164361053, 4.806377958591044, 5.777618790855073, 6.805112388506663, 7.774958256657109, 8.755731257959221, 9.70474065971076, 10.77270255922307, 11.781968591882222, 12.833132532156004, 13.794996504057243, 14.82935906549086, 15.813949226911587, 15.750097015940897, 14.77627732606835, 13.817899190438657, 12.857143746508827, 11.923559713173207, 12.753497334503724, 1.9406829019229126, 2.9051148768351287, 3.873070996190849, 4.828413913801604, 5.82240253143647, 6.888238899610535, 7.891487783663129, 8.919948519863876, 9.9562725633465, 10.93344261230551, 11.998486452912353, 12.988821811187822, 13.963166542630121, 15.002810123848729, 16.01287986435325, 15.735131858570686, 14.84583255572816, 13.854507308088273, 12.986922938485343, 13.791890679398957, 2.90447234729799, 3.948258784008985, 4.802872469595613, 5.81452478396087, 6.772660186738518, 7.8322598298664685, 8.823463919768184, 9.83300392097808, 10.90417676356646, 11.832327946045488, 12.833370157670121, 13.843240825327397, 14.823349658654683, 15.788033473240523, 16.780151897883123, 16.72548835708336, 15.796094758761033, 14.866458448279728, 14.037000729217967, 14.805449840334939, 3.8817470434755954, 4.8581698583297275, 5.754136647825144, 6.76095643792531, 7.764894858155217, 8.71866661966782, 9.661619796942604, 10.600515104130302, 11.537556377379238, 12.473322960787208, 13.504737940250607, 14.48765969647915, 15.40055843212603, 16.38629529950635, 17.406067048927294, 17.658669938228833, 16.736759675861705, 15.851611322828893, 15.053363362407113, 15.83859628038878, 4.8177881275686625, 3.9107793503923944, 4.78355212681543, 5.762263487530652, 6.747376035924941, 7.781110886901984, 8.679009017609003, 9.674277200677802, 10.729628275374147, 11.602556873174859, 12.558419869499055, 13.457605725461598, 14.471855460831886, 15.469335538919427, 16.42295514913963, 17.411954168064632, 17.773077997470384, 16.887977451628892, 16.02520139715473, 16.79028192792563], [16.826646600345875, 17.392836144004576, 18.383918521770745, 18.421531671439023, 17.48201428984119, 16.431556131837457, 15.450480834120102, 14.484479342448196, 13.465249852199594, 12.526535099547882, 11.597795625023934, 10.640363562264827, 9.680975671612343, 8.671118200049166, 7.73829683167161, 6.7466145392192765, 5.695201084532189, 4.732472601078759, 3.8545651428249794, 2.948660907358544, 15.82418327319859, 16.44828033445466, 17.420920913947, 17.787114556900043, 16.804732345158154, 15.806877103756195, 14.75935968347127, 13.717938624712724, 12.703101112297963, 11.698267315858644, 10.698119556588942, 9.705480093838275, 8.75728574589196, 7.75223074643753, 6.80158461180444, 5.822858398887604, 4.782921930716365, 3.7520201773728488, 2.826945436579317, 1.9300115666270368, 14.817829610703434, 15.51524874098339, 16.457871607826164, 16.81989591381626, 15.859079119595954, 14.887880185071197, 13.893782679869627, 12.874449949280285, 11.915631712720394, 10.999225767901356, 9.950807636052952, 8.913618813949304, 7.881849633858849, 6.912581992480492, 5.982930063198494, 4.935104085883839, 3.8716471856179804, 2.8079624006865265, 1.8684499435043598, 0.9707437812199565, 13.805510502062873, 14.557494390089204, 15.520660243892952, 15.809323928439992, 14.880172723720369, 13.910237582038949, 12.953847634675478, 11.924214062651162, 10.940406091968267, 9.954277790631338, 8.99689671924996, 7.969255926134588, 6.945985459650345, 5.9702459547198945, 4.997742526557558, 4.027081520697244, 2.974396534547222, 1.9601635280777292, 0.9399658604280567, 0.0, 12.760218900974712, 13.565048375440796, 14.542887454526603, 15.534386132631575, 15.728259057003033, 14.801076494676753, 13.871398605103234, 12.832559320284023, 11.878703692155062, 10.905234149629313, 9.840532739015142, 8.837249545526488, 7.870732813301678, 6.929998951719211, 5.9354056853656605, 4.971568826089435, 3.9397749489028806, 2.891907093212906, 1.8967136680726102, 0.9512734195425707, 11.698109169326385, 12.557870099123008, 13.582386634691362, 14.584904355629796, 15.512542368793813, 15.800920685591107, 14.833113955481462, 13.878038332418436, 12.816872147136877, 11.786195834747902, 10.782320831307983, 9.847150827547017, 8.8357766053547, 7.931212504105443, 6.955809844078701, 6.017912674052042, 4.959064872230941, 3.8941906329194227, 2.8978432916253736, 2.0088301561755, 10.653917025847646, 11.59387388545645, 12.565067900175144, 13.58360952925036, 14.546602893005703, 15.552978430243856, 15.809902611310786, 14.766186797162367, 13.796580475362187, 12.772369303234663, 11.75893632368249, 10.792539441601557, 9.780738719338501, 8.862778208490159, 7.931469688305705, 6.87876686287802, 5.855105112721155, 4.9122787723462995, 3.9076092744260786, 2.9785434459015465, 9.723288393867286, 10.787753657283385, 11.691234984480838, 12.679451963740982, 13.571504909503831, 14.51124117091463, 15.550713622043373, 15.707808354555883, 14.749524286119813, 13.749609865395398, 12.739859701593577, 11.763662945375957, 10.76550822109111, 9.827303586315997, 8.763959702690254, 7.744176518993079, 6.796756599674211, 5.812471009118935, 4.857225184073314, 3.967196364686561, 8.845672979879591, 9.833667109529205, 10.723172187602382, 11.69002311482835, 12.645681251087904, 13.627934859179629, 14.634301412517427, 15.569825317352857, 15.5904681235176, 14.567119694820342, 13.549205877986218, 12.510244874748665, 11.530671729106743, 10.604170950584308, 9.649430295574728, 8.721980409521144, 7.821669873476573, 6.879311822491287, 5.919830014927088, 4.935237092485271, 7.893455298656005, 8.775087794157859, 9.775709695811496, 10.769785889534981, 11.71265522020724, 12.693926228785609, 13.630215352595178, 14.624213028461563, 15.61343946989292, 15.525615703244416, 14.459906158521443, 13.513915969105875, 12.573616421183395, 11.596940659848661, 10.647962449290125, 9.720335479780918, 8.793371398189356, 7.812609724034013, 6.872384548467624, 5.929247031972187, 6.883532030299335, 7.830279624285688, 8.851382187433774, 9.829798316145743, 10.73833610906534, 11.666701575395159, 12.666051475236106, 13.568031911590243, 14.58703038941188, 15.631754518318681, 15.447840685237544, 14.479076456872129, 13.595465181315458, 12.531729068857599, 11.684653618328802, 10.789937711766768, 9.81391297078413, 8.815424993321543, 7.797754982279137, 6.875091697235661, 5.964495694571417, 6.938889479723194, 7.879070479773329, 8.773345428903628, 9.715320615497557, 10.64846380416819, 11.664063182823073, 12.636660276115299, 13.614565356365066, 14.67210433780115, 15.598198170123904, 15.433295252378878, 14.51039528669165, 13.502402528483978, 12.723590466506637, 11.768965699871286, 10.767456005586382, 9.855798156375803, 8.836501260257961, 7.845899601368862, 4.89818064393785, 5.902691046238288, 6.910584840339145, 7.80040912292338, 8.743693785145005, 9.698235911485066, 10.64708983933174, 11.641888993115554, 12.65730284287968, 13.648704008075406, 14.581505885735645, 15.575394389892315, 15.435613410034204, 14.490887515466337, 13.686907538968237, 12.724659863908046, 11.6796293026257, 10.703522172502593, 9.769103917669499, 8.771257583780054, 3.8808756795577994, 4.852439696472926, 5.925426205638451, 6.86781051415139, 7.732963592780141, 8.74091075203223, 9.70182163090956, 10.755706818422938, 11.704941922438113, 12.645713929376358, 13.696115770666882, 14.623960720084522, 15.64202056768803, 15.424127491062192, 14.642487811996938, 13.619406719445834, 12.626387675617787, 11.64856851674565, 10.750218672376459, 9.725741632928242, 2.9013192974713524, 3.939455788274096, 4.937305523694548, 5.796316878927092, 6.763228607789039, 7.8014609092178295, 8.758839485296509, 9.729863320727652, 10.69461633254027, 11.735377544302349, 12.807280269750237, 13.83540577648825, 14.794351249281481, 15.751396523620059, 15.554924530264463, 14.597226869657826, 13.557608986610104, 12.580440166623077, 11.676864857900343, 10.783313201988761, 1.9210529035942354, 2.867146303932996, 3.866412098162987, 4.837652930427017, 5.865146528078606, 6.834992396229052, 7.815765397531165, 8.764774799282705, 9.832736698795015, 10.842002731454166, 11.893166671727947, 12.855030643629187, 13.889393205062802, 14.87398336648353, 15.937229567968272, 15.53027510165344, 14.571896966023749, 13.59506366479391, 12.639296990523269, 11.813531474075663, 1.0007170414948559, 1.965149016407072, 2.9331051357627924, 3.888448053373547, 4.8824366710084135, 5.948273039182478, 6.951521923235072, 7.979982659435819, 9.016306702918444, 9.993476751877454, 11.058520592484296, 12.048855950759766, 13.023200682202065, 14.062844263420672, 15.072914003925192, 16.09994400306261, 15.583752474013243, 14.592427226373356, 13.702660215835405, 12.851924818970897, 1.9645064868699333, 3.008292923580928, 3.8629066091675566, 4.874558923532813, 5.832694326310461, 6.892293969438412, 7.883498059340127, 8.893038060550023, 9.964210903138403, 10.892362085617432, 11.893404297242064, 12.90327496489934, 13.883383798226626, 14.848067612812466, 15.840186037455066, 16.78556511622484, 16.534014677046116, 15.604378366564811, 14.752738006568029, 13.865483979906879, 2.9417811830475387, 3.9647723425351975, 4.814170787397087, 5.820990577497254, 6.8332154156857055, 7.8360652328497515, 8.779018410124536, 9.717913717312234, 10.65495499056117, 11.59072157396914, 12.66373949899743, 13.646661255225974, 14.634270072506258, 15.62000693988658, 16.678297411700296, 17.697722233172858, 17.47467959414679, 16.589531241113974, 15.769100639757175, 14.89863041996072, 3.8778222671406057, 4.850745210820452, 5.723517987243487, 6.702229347958709, 7.687341896352998, 8.721076747330041, 9.61897487803706, 10.614243061105858, 11.582533965164414, 12.542522733602915, 13.498385729927111, 14.397571585889654, 15.411821321259943, 16.409301399347484, 17.362921009567685, 18.35192002849269, 18.510997915755468, 17.62589736991397, 16.74093867450479, 15.85031606749757], [4.066427699371162, 4.87698649589905, 5.868068873665221, 6.813087119652018, 7.752604501249853, 8.770969654831381, 9.710074738323959, 10.676076229995864, 11.695305720244466, 12.634020472896179, 13.562759947420126, 14.520192010179233, 15.593136486332785, 16.60299395789596, 17.535815326273518, 18.527497618725853, 18.4554199855069, 17.492691502053468, 16.61478404379969, 15.708879808333256, 3.0639643722238796, 3.932430686349136, 4.905071265841474, 5.845417076103548, 6.827799287845436, 7.830770328577453, 8.755298363436898, 9.783687014599384, 10.798524527014145, 11.803358323453464, 12.803506082723166, 13.796145545473832, 14.744339893420149, 15.749394892874578, 16.656183333834015, 17.63490954675085, 17.543140831691076, 16.51223907834756, 15.587164337554029, 14.690230467601749, 2.0576107097287233, 2.9993990928778658, 3.9420219597206403, 4.942413369698624, 5.939805309629309, 6.911004244154066, 7.79300635581385, 8.837117500134003, 9.795935736693894, 10.836623288891635, 11.876272249103264, 12.88889080926339, 13.807944011561487, 14.740453371333771, 15.68175371604614, 16.690970629407758, 16.63186608659269, 15.568181301661237, 14.628668844479071, 13.730962682194669, 1.0452916010881619, 2.0416447419836787, 3.004810595787427, 4.0572126002290165, 4.98636380494864, 5.951259237605363, 6.8530713106197, 7.882704882644015, 8.86651285332691, 9.85264115466384, 10.810022226045216, 11.837663019160589, 12.822377828642724, 13.798117333573174, 14.77062076173551, 15.741281767595822, 15.730367259776623, 14.71613425330713, 13.700184761402769, 12.760218900974712, 0.0, 1.0491987273352705, 2.0270378064210783, 3.0905572439074303, 4.021252377606777, 4.948434939933056, 5.878112829506574, 6.916952114325785, 7.870807742454746, 8.844277284980494, 9.908978695594666, 10.91226188908332, 11.87877862130813, 12.819512482890596, 13.814105749244147, 14.777942608520373, 14.774217746749894, 13.784390688171953, 12.753158531584434, 11.808945481432142, 1.0621097316483266, 2.0563770036530578, 3.0200879175614173, 4.022605638499851, 4.99879980918062, 5.961780843096371, 6.839828179884803, 7.872218726246112, 8.80897619743656, 9.811547016601637, 10.815422020041556, 11.759617098973374, 12.77099132116569, 13.75558885740418, 14.731948968713663, 14.746344681679588, 13.73281529390562, 12.74837624932572, 11.75202890803167, 10.751388744799213, 2.106301875127066, 3.0203732173196154, 3.99156723203831, 5.010108861113526, 5.96473928496873, 6.92902716808797, 7.816616835714127, 8.867897974268564, 9.837504296068744, 10.797720485088398, 11.811498250383588, 12.705005713027914, 13.71595343514949, 14.7402449816918, 14.523456778031557, 13.67583250803478, 12.658237121892775, 11.71541078151792, 10.710741283597699, 9.781675455073167, 3.0369305071074266, 4.0174533957168235, 4.980786104020453, 6.019068814235731, 6.997965448004315, 7.937701709415113, 8.878536670546136, 9.824710927135456, 10.782994995571526, 11.792356773951953, 12.802106937753774, 13.686313719216413, 14.68446844350126, 14.474420041015343, 13.549888112063721, 12.605750132113734, 11.718845703973779, 10.75781432739907, 9.802568502353449, 8.793022536288152, 3.9693491194998236, 4.971539943471003, 5.948848900898909, 6.915699828124877, 7.871357964384432, 8.853611572476156, 9.858536794138562, 10.794060698973992, 11.774329366541677, 12.783751852975328, 13.801665669809452, 14.712438583558335, 14.436637561171267, 13.510136782648832, 12.555396127639252, 11.627946241585668, 10.693932430171417, 9.8096531053074, 8.764462662845435, 7.824981808489442, 5.023091055334154, 6.030119258842349, 6.896311392689794, 7.890387586413278, 8.816329515268276, 9.797600523846643, 10.733889647656213, 11.748602225820752, 12.720713907011918, 13.650551742233127, 14.7162612869561, 14.622803134337952, 13.636579798541597, 12.56658208534019, 11.656994530693616, 10.729367561184409, 9.719442448129247, 8.879573085162063, 7.811908129304901, 6.830971869002526, 6.033014323690824, 6.97492742871452, 7.933148055558445, 8.929789058688844, 9.859507214385339, 10.787872680715157, 11.766659415014, 12.725943928773258, 13.744942406594895, 14.652129840343587, 14.708096581129247, 13.657642646571698, 12.680030326680876, 11.631793676331252, 10.63942174482117, 9.689677995652392, 8.698900875534472, 7.837085977719049, 6.886537695493387, 5.885127203739052, 6.964511933968619, 7.9847799822842145, 8.978508007856947, 9.986241945930958, 10.882522707953122, 11.84175858574757, 12.768647707427034, 13.6573155642482, 14.728483415374042, 14.623757205084646, 13.684247282086922, 12.703423851064949, 11.672031640895092, 10.66403888268742, 9.701492301652475, 8.746867535017124, 7.74535784073222, 6.78054506639419, 5.888655319601251, 4.91431929960585, 8.030826984602186, 9.02097841576912, 9.94699364729113, 10.881105411713508, 11.854149538305673, 12.791986478430694, 13.762120665899124, 14.652086847247945, 14.616135029691284, 13.600356875358901, 12.667554997698662, 11.720943590469158, 10.756984322670215, 9.802774891343555, 8.7567737782923, 7.79452610323211, 6.743684494386084, 5.767577364262977, 4.871154929018554, 3.9889613171946583, 9.083199665843074, 10.0547636827582, 10.932152281991824, 11.813704020485497, 12.818547853640785, 13.74931163788353, 14.707388874321303, 14.640069927660576, 13.690834823645401, 12.750062816707157, 11.699660975416633, 10.771816025998993, 9.811706189080933, 8.881392963438648, 7.927205796096175, 6.875284159434146, 5.882265115606099, 4.8225310200199205, 3.867857533376573, 3.0659862120900288, 10.06275604792952, 11.04237642155853, 11.962425935868765, 12.885197655709796, 13.788282838631888, 14.68876148069793, 14.954216678004656, 13.924006679743648, 12.95925366793103, 11.918492456168952, 10.846589730721064, 9.800147282984026, 8.841201810190794, 7.884156535852217, 6.948359348268141, 5.990661687661505, 4.951043804613783, 3.8906593701424934, 2.941211347852689, 2.0084146430295093, 11.043022441806636, 11.989115842145397, 13.033319361400325, 13.84386160420987, 14.804891963224305, 15.28724512944789, 14.306472128145776, 13.357462726394237, 12.289500826881927, 11.280234794222777, 10.229070853948995, 9.267206882047756, 8.23284432061414, 7.2482541591934115, 6.185007957708669, 5.139893136268049, 4.132787717310894, 3.094330535497022, 2.02926948671204, 1.070786375690563, 11.98382298410954, 12.948254959021757, 13.916211078377478, 14.81687167320011, 15.810860290834977, 16.246188218245436, 15.242939334192844, 14.214478597992096, 13.178154554509472, 12.200984505550462, 11.135940664943622, 10.145605306668152, 9.171260575225853, 8.131616994007246, 7.121547253502726, 6.0945172543653054, 5.083019344716355, 4.091694097076469, 3.0926327120241752, 2.0846456612821456, 13.056394993123655, 13.999474146655196, 14.846012551782241, 15.834038017032471, 16.79217341981012, 16.844573971057432, 15.783021450799348, 14.773481449589452, 13.702308607001072, 12.774157424522043, 11.77311521289741, 10.763244545240134, 9.783135711912848, 8.818451897327009, 7.826333472684409, 6.880954393914633, 5.951560795592306, 5.0219244851110005, 4.032879250783993, 3.0982048222181273, 14.033669689301261, 15.010253235520757, 15.797276730011772, 16.80409652011194, 17.792694509185363, 17.498254654484498, 16.555301477209714, 15.616406170022014, 14.679364896773079, 13.743598313365109, 12.7143290913268, 11.731407335098256, 10.743798517817972, 9.844467187476049, 8.83356079653267, 7.814135975060108, 6.8798518030503875, 5.916366262012683, 4.967341166722717, 4.014229379110038, 14.969710773394327, 15.95764374345809, 16.8402424959009, 17.85637200579041, 18.81021333141564, 18.435810387250335, 17.550850635883855, 16.5264038758263, 15.486092164850843, 14.507487055999107, 13.660647162078352, 12.627627453934526, 11.60341820880761, 10.668895303551341, 9.716048315711362, 8.78024473755019, 7.853440120056227, 6.8908199545310485, 5.939179201470333, 4.965915026646888], [4.815751729347608, 3.827787768563779, 4.8188701463299495, 5.763888392316748, 6.703405773914582, 7.7217709274961095, 8.660876010988687, 9.626877502660593, 10.646106992909196, 11.584821745560909, 12.513561220084856, 13.470993282843963, 14.543937758997515, 15.553795230560691, 16.486616598938248, 17.47829889139058, 17.795232883606833, 16.8325044001534, 16.137802604040637, 16.51370928279934, 3.8132884022003255, 2.883231959013865, 3.855872538506203, 4.796218348768277, 5.778600560510165, 6.781571601242181, 7.706099636101627, 8.734488287264114, 9.749325799678875, 10.754159596118194, 11.754307355387896, 12.746946818138563, 13.695141166084879, 14.700196165539309, 15.606984606498745, 16.58571081941558, 17.62564728758682, 17.317068552813645, 16.39199381202011, 15.495059942067833, 2.9507949967379465, 1.950200365542595, 2.8928232323853695, 3.893214642363353, 4.890606582294038, 5.861805516818795, 6.743807628478579, 7.787918772798732, 8.746737009358622, 9.787424561556364, 10.827073521767995, 11.83969208192812, 12.758745284226217, 13.691254643998501, 14.63255498871087, 15.641771902072486, 16.705228802338343, 16.373010776127323, 15.433498318945155, 14.535792156660753, 2.0382018957435055, 0.9924460146484081, 1.9556118684521564, 3.0080138728937467, 3.9371650776133698, 4.9020605102700925, 5.803872583284429, 6.833506155308744, 7.817314125991639, 8.80344242732857, 9.760823498709946, 10.788464291825319, 11.773179101307454, 12.748918606237904, 13.72142203440024, 14.692083040260552, 15.744768026410574, 15.520963727773212, 14.505014235868853, 13.565048375440796, 1.0491987273352705, 0.0, 0.9778390790858079, 2.04135851657216, 2.9720536502715063, 3.8992362125977853, 4.828914102171304, 5.867753386990515, 6.821609015119476, 7.795078557645224, 8.859779968259396, 9.86306316174805, 10.829579893972861, 11.770313755555327, 12.764907021908877, 13.728743881185103, 14.760537758371656, 14.589220162638036, 13.557988006050518, 12.613774955898226, 2.025253307237464, 1.0071782763177874, 1.970889190226147, 2.9734069111645804, 3.9496010818453504, 4.912582115761101, 5.790629452549531, 6.823019998910841, 7.759777470101291, 8.762348289266367, 9.766223292706286, 10.710418371638104, 11.72179259383042, 12.70639013006891, 13.682750241378393, 14.625908287653282, 14.537644768371704, 13.553205723791804, 12.556858382497754, 11.556218219265297, 2.9111313495931492, 1.971174489984345, 2.94236850470304, 3.960910133778256, 4.91554055763346, 5.8798284407527, 6.767418108378855, 7.818699246933292, 8.788305568733472, 9.748521757753128, 10.762299523048318, 11.655806985692644, 12.66675470781422, 13.69104625435653, 14.622354774540986, 14.486728346515724, 13.463066596358859, 12.520240255984003, 11.515570758063783, 10.58650492953925, 3.8417599815735097, 2.968254668381553, 3.931587376685183, 4.969870086900461, 5.948766720669045, 6.888502982079843, 7.829337943210865, 8.775512199800184, 9.733796268236254, 10.743158046616683, 11.752908210418504, 12.637114991881143, 13.63526971616599, 14.573474350941103, 14.436034527737844, 13.491896547787857, 12.546929392420427, 11.562643801865152, 10.60739797681953, 9.597852010754236, 4.774178593965907, 3.9223412161357327, 4.899650173563639, 5.866501100789607, 6.822159237049162, 7.804412845140886, 8.80933806680329, 9.74486197163872, 10.725130639206405, 11.734553125640058, 12.752466942474182, 13.663239856223065, 14.642813001864987, 14.396283198322955, 13.441542543313375, 12.514092657259791, 11.58007884584554, 10.614482579773485, 9.569292137311521, 8.629811282955526, 5.827920529800237, 4.9809205315070795, 5.8471126653545245, 6.8411888590780086, 7.767130787933005, 8.748401796511374, 9.684690920320943, 10.69940349848548, 11.671515179676646, 12.601353014897855, 13.667062559620827, 14.613052749036395, 14.595057814661903, 13.525060101460497, 12.60271631634786, 11.675089346838654, 10.665164233783491, 9.684402559628149, 8.616737603770986, 7.63580134346861, 6.837843798156907, 5.92572870137925, 6.883949328223175, 7.880590331353574, 8.810308487050069, 9.738673953379887, 10.71746068767873, 11.676745201437988, 12.695743679259625, 13.602931113008315, 14.582873902573969, 14.616120662692003, 13.638508342801181, 12.590271692451559, 11.597899760941477, 10.648156011772697, 9.657378891654776, 8.709037181001875, 7.691367169959471, 6.689956678205136, 7.769341408434702, 6.935581254948945, 7.929309280521677, 8.937043218595688, 9.833323980617852, 10.7925598584123, 11.719448980091764, 12.60811683691293, 13.679284688038772, 14.588507209983954, 14.64739085767606, 13.661901867185254, 12.630509657015397, 11.622516898807724, 10.65997031777278, 9.705345551137428, 8.703835856852525, 7.739023082514494, 6.736714581559688, 5.719148774071934, 8.835656459068268, 7.971779688433851, 8.89779491995586, 9.831906684378238, 10.804950810970404, 11.742787751095424, 12.712921938563854, 13.602888119912675, 14.618301969676802, 14.56350045094804, 13.6306985732878, 12.679421606589463, 11.71546233879052, 10.76125290746386, 9.715251794412605, 8.753004119352415, 7.702162510506389, 6.726055380383281, 5.791637125550186, 4.793790791660742, 9.888029140309156, 9.022031038199213, 9.882953554656554, 10.764505293150227, 11.769349126305515, 12.70011291054826, 13.658190146986033, 14.60005558887654, 14.65397839923454, 13.713206392296295, 12.66280455100577, 11.73495960158813, 10.774849764670071, 9.844536539027784, 8.89034937168531, 7.8384277350232825, 6.845408691195236, 5.785674595609057, 4.83100110896571, 3.8768569850899812, 10.867585522395602, 10.009643776999543, 10.913227208533495, 11.835998928374526, 12.739084111296618, 13.63956275336266, 14.59694132944134, 14.887150255332786, 13.922397243520168, 12.88163603175809, 11.809733306310202, 10.763290858573164, 9.804345385779932, 8.847300111441355, 7.911502923857279, 6.953805263250642, 5.91418738020292, 4.853802945731631, 3.904354923441826, 2.9715582186186467, 11.847851916272718, 11.081953261340642, 11.984120634065055, 12.7946628768746, 13.755693235889035, 14.637409272926346, 15.355670855481046, 14.406661453729507, 13.338699554217197, 12.329433521558046, 11.278269581284265, 10.316405609383025, 9.28204304794941, 8.297452886528681, 7.234206685043939, 6.189091863603319, 5.181986444646164, 4.143529262832293, 3.078468214047311, 2.1199851030258334, 12.788652458575623, 12.132233751608831, 12.91742759646525, 13.76767294586484, 14.761661563499707, 15.691100254234216, 16.261645374774247, 15.2331846385735, 14.196860595090875, 13.219690546131865, 12.154646705525023, 11.164311347249553, 10.189966615807254, 9.150323034588647, 8.140253294084127, 7.113223294946707, 6.1017253852977555, 5.110400137657869, 4.105034494719482, 3.0775559559374894, 13.861224467589738, 13.183452939242269, 13.847229069870014, 14.784839289697201, 15.74297469247485, 16.743670116879123, 16.708183289380052, 15.698643288170157, 14.627470445581777, 13.699319263102748, 12.698277051478115, 11.688406383820839, 10.708297550493553, 9.743613735907713, 8.751495311265113, 7.806116232495338, 6.876722634173011, 5.947086323691705, 4.9580410893646985, 4.023366660798833, 14.838499163767343, 14.19423202810783, 14.798493248099545, 15.77983118957386, 16.743495781850093, 17.695714555524646, 17.22680261105128, 16.28790730386358, 15.350866030614645, 14.415099447206675, 13.453453026275309, 12.470531270046765, 11.48292245276648, 10.61856865512057, 9.60978026055972, 8.590355439087158, 7.629175833026833, 6.6656902919891285, 5.716665196699163, 4.763553409086484, 15.77454024786041, 15.141622536045164, 15.841459013988672, 16.841010669496896, 17.76101460408037, 17.503724471639412, 16.501651908548585, 15.47720514849103, 14.436893437515574, 13.458288328663837, 12.62178870644857, 11.578428726599256, 10.55421948147234, 9.61969657621607, 8.66684958837609, 7.731046010214919, 6.804241392720956, 5.841621227195777, 4.894266181794336, 5.715239056623334], [5.793590808433415, 4.805626847649586, 4.0029569040084265, 4.874666937158992, 5.787574942277028, 6.78998733768942, 7.68303693190288, 8.649038423574785, 9.668267913823389, 10.606982666475101, 11.535722140999049, 12.493154203758156, 13.566098679911708, 14.575956151474884, 15.50877751985244, 16.500459812304776, 16.910240403984606, 15.947511920531174, 16.794224657654365, 17.491548361885148, 4.791127481286133, 3.8610710380996727, 2.966651083348447, 3.906996893610521, 4.8584207287704295, 5.849788011435492, 6.72826055701582, 7.756649208178305, 8.771486720593066, 9.776320517032385, 10.776468276302086, 11.769107739052753, 12.71730208699907, 13.7223570864535, 14.629145527412938, 15.607871740329774, 16.64780820850101, 16.927964344237083, 17.36983289110592, 16.47289902115364, 3.928634075823754, 2.9280394446284026, 1.914984153299562, 2.9153755632775455, 3.9127675032082303, 4.883966437732988, 5.765968549392771, 6.810079693712924, 7.768897930272814, 8.809585482470556, 9.849234442682187, 10.861853002842313, 11.78090620514041, 12.713415564912694, 13.654715909625063, 14.663932822986679, 15.727389723252537, 16.73826146587797, 16.411337398030962, 15.51363123574656, 3.0160409748293135, 1.970285093734216, 0.9777727893663485, 2.0301747938079386, 2.9593259985275617, 3.924221431184285, 4.826033504198621, 5.855667076222937, 6.839475046905831, 7.825603348242761, 8.782984419624139, 9.810625212739511, 10.795340022221646, 11.771079527152096, 12.743582955314432, 13.714243961174745, 14.766928947324766, 15.762310100111, 15.48285331495466, 14.542887454526603, 2.0270378064210783, 0.9778390790858079, 0.0, 1.063519437486352, 1.9942145711856982, 2.9213971335119773, 3.851075023085496, 4.889914307904707, 5.843769936033668, 6.817239478559417, 7.881940889173588, 8.885224082662242, 9.851740814887053, 10.792474676469519, 11.78706794282307, 12.750904802099296, 13.782698679285849, 14.830566534975823, 14.535827085136326, 13.591614034984033, 3.0030923863232726, 1.9850173554035955, 0.9930501111403389, 1.9955678320787724, 2.9717620027595424, 3.9347430366752927, 4.812790373463724, 5.845180919825033, 6.781938391015483, 7.784509210180558, 8.788384213620478, 9.732579292552296, 10.743953514744613, 11.728551050983102, 12.704911162292586, 13.648069208567474, 14.706917010388574, 14.531044802877611, 13.534697461583562, 12.534057298351104, 3.8889704286789573, 2.949013569070153, 2.010368845656558, 3.0038554392775962, 3.937701478547652, 4.901989361666892, 5.789579029293048, 6.8408601678474845, 7.8104664896476645, 8.770682678667319, 9.78446044396251, 10.677967906606836, 11.688915628728413, 12.713207175270723, 13.644515695455178, 14.697218520882863, 14.440905675444666, 13.49807933506981, 12.49340983714959, 11.564344008625058, 4.819599060659318, 3.946093747467361, 3.0358209404498355, 4.012815392399801, 4.970927641583237, 5.910663902994035, 6.851498864125057, 7.797673120714377, 8.755957189150447, 9.765318967530874, 10.775069131332694, 11.659275912795335, 12.657430637080182, 13.595635271855295, 14.618084361423014, 14.469735626873662, 13.524768471506235, 12.54048288095096, 11.585237055905338, 10.575691089840044, 5.752017673051714, 4.90018029522154, 4.003883737328292, 4.97073466455426, 5.896751299999163, 6.879004908090888, 7.831498987717484, 8.767022892552914, 9.7472915601206, 10.756714046554249, 11.774627863388373, 12.685400777137257, 13.664973922779179, 14.559918530221804, 14.41938162239918, 13.491931736345597, 12.557917924931346, 11.59232165885929, 10.547131216397327, 9.607650362041333, 6.805759608886045, 5.951968130772816, 4.951346229119177, 5.945422422842661, 6.841722850883007, 7.822993859461374, 8.759282983270943, 9.721564419399675, 10.69367610059084, 11.62351393581205, 12.689223480535022, 13.63521366995059, 14.64255654875724, 14.502899180546304, 13.580555395433667, 12.65292842592446, 11.643003312869297, 10.662241638713954, 9.594576682856792, 8.613640422554418, 7.815682877242715, 6.896776300644986, 5.988182891987828, 6.984823895118227, 7.88490055000007, 8.813266016329889, 9.79205275062873, 10.751337264387988, 11.747698131594502, 12.62509203392251, 13.605034823488163, 14.600374157716843, 14.616347421886989, 13.568110771537366, 12.575738840027284, 11.625995090858504, 10.635217970740584, 9.686876260087683, 8.669206249045278, 7.667795757290944, 8.74718048752051, 7.906628854214681, 7.044316800899449, 8.041276782360342, 8.907916043567853, 9.867151921362302, 10.794041043041764, 11.68270889986293, 12.753876750988772, 13.610668130898148, 14.630368706493513, 14.639740946271061, 13.608348736101204, 12.600355977893532, 11.637809396858588, 10.683184630223236, 9.681674935938332, 8.716862161600302, 7.714553660645495, 6.696987853157742, 9.813495538154076, 8.942827287699586, 8.012802440333633, 8.94691420475601, 9.879542873920405, 10.817379814045426, 11.787514001513856, 12.677480182862675, 13.692894032626802, 14.634068460623892, 14.608537652373608, 13.65726068567527, 12.693301417876327, 11.739091986549667, 10.693090873498413, 9.730843198438222, 8.680001589592196, 7.703894459469089, 6.7694762046359935, 5.771629870746549, 10.865868219394963, 9.993078637464947, 8.997961075034327, 9.879512813528, 10.884356646683289, 11.774704973498261, 12.732782209936035, 13.67464765182654, 14.623882755841715, 14.691045471382102, 13.640643630091578, 12.712798680673938, 11.752688843755879, 10.822375618113593, 9.86818845077112, 8.816266814109092, 7.823247770281045, 6.763513674694866, 5.808840188051519, 4.85469606417579, 11.84542460148141, 10.980691376265277, 10.028234728911269, 10.951006448752299, 11.854091631674391, 12.714154816312663, 13.671533392391341, 14.700491149521826, 14.900236322605975, 13.859475110843897, 12.78757238539601, 11.741129937658972, 10.78218446486574, 9.825139190527162, 8.889342002943087, 7.93164434233645, 6.892026459288728, 5.831642024817439, 4.882194002527635, 3.949397297704455, 12.825690995358526, 12.053000860606376, 11.099128154442829, 11.909670397252373, 12.870700756266809, 13.712001335876348, 14.672633343058854, 15.384500532815318, 14.316538633303008, 13.307272600643856, 12.256108660370074, 11.294244688468835, 10.259882127035219, 9.27529196561449, 8.21204576412975, 7.166930942689128, 6.159825523731973, 5.121368341918101, 4.056307293133119, 3.0978241821116415, 13.76649153766143, 13.000391236198745, 12.032435116843024, 12.882680466242613, 13.87666908387748, 14.765692317184218, 15.687118169046563, 16.211023717659305, 15.174699674176683, 14.197529625217673, 13.13248578461083, 12.14215042633536, 11.167805694893062, 10.128162113674454, 9.118092373169935, 8.091062374032514, 7.079564464383563, 6.088239216743677, 5.08287357380529, 4.055395035023297, 14.839063546675545, 14.017894329192174, 12.962236590247787, 13.899846810074974, 14.857982212852622, 15.818262179829127, 16.61909430515162, 16.24984974364986, 15.334852439442962, 14.406701256963933, 13.455725680570358, 12.445855012913082, 11.465746179585796, 10.659885893085912, 9.667767468443312, 8.722388389673537, 7.854561713258819, 6.924925402777513, 5.935880168450506, 5.00120573988464, 15.816338242853151, 14.85065408172156, 13.913500768477318, 14.894838709951634, 15.858503302227867, 16.77030661847465, 16.248963531965472, 15.310068224777773, 14.373026951528837, 13.437260368120867, 12.475613947189501, 11.492692190960957, 10.505083373680673, 9.640729576034762, 8.718177898357068, 7.789206808528063, 6.951338259171879, 6.062074113674252, 6.69450427578497, 5.741392488172291, 16.75237932694622, 15.798044589658893, 14.956466534366445, 15.95601818987467, 16.876022124458142, 16.525885392553604, 15.523812829462777, 14.499366069405223, 13.459054358429766, 12.48044924957803, 11.643949627362762, 10.600589647513448, 9.576380402386532, 8.641857497130262, 7.735065998569401, 6.815215178577365, 5.9150199375632, 5.025707984874254, 5.872105260880144, 6.693078135709142], [6.857110245919768, 5.869146285135939, 5.046361069905019, 4.037379482531436, 4.809759764037161, 5.744365496686613, 6.619517494416527, 7.585518986088433, 8.604748476337036, 9.543463228988749, 10.472202703512696, 11.429634766271803, 12.502579242425355, 13.512436713988532, 14.445258082366088, 15.436940374818422, 16.087823638829207, 16.854072181132768, 17.700784918255955, 18.48304703999012, 5.854646918772485, 4.924590475586025, 4.010055249245039, 3.069709438982965, 3.880605550530562, 4.804166170432684, 5.6647411195294675, 6.693129770691953, 7.707967283106714, 8.712801079546033, 9.712948838815734, 10.7055883015664, 11.653782649512717, 12.658837648967147, 13.565626089926585, 14.544352302843421, 15.58428877101466, 16.615190524358177, 17.57274997864874, 17.464397699258612, 4.9921535133101065, 3.991558882114755, 2.978503590785914, 2.049254692014289, 2.934952324968363, 3.83834459673018, 4.702449111906419, 5.746560256226572, 6.705378492786462, 7.746066044984204, 8.785715005195835, 9.79833356535596, 10.717386767654057, 11.649896127426342, 12.59119647213871, 13.600413385500326, 14.663870285766185, 15.674742028391616, 16.614254485573785, 16.505129913851533, 4.079560412315665, 3.033804531220568, 2.0412922268527005, 1.0386827066380218, 1.916328525376553, 2.8607019936979325, 3.762514066712269, 4.7921476387365844, 5.775955609419479, 6.762083910756409, 7.7194649821377865, 8.747105775253159, 9.731820584735294, 10.707560089665744, 11.68006351782808, 12.650724523688393, 13.703409509838414, 14.698790662624647, 15.71898833027432, 15.534386132631576, 3.0905572439074307, 2.04135851657216, 1.063519437486352, 0.0, 0.9306951336993462, 1.8578776960256254, 2.787555585599144, 3.826394870418355, 4.780250498547316, 5.7537200410730645, 6.818421451687236, 7.82170464517589, 8.788221377400701, 9.728955238983167, 10.723548505336717, 11.687385364612943, 12.719179241799496, 13.76704709748947, 14.80958162445488, 14.583112713089006, 4.007506392664799, 2.989431361745122, 1.9519994979402124, 0.949481777001779, 1.9082425652731902, 2.8712235991889408, 3.749270935977372, 4.781661482338682, 5.718418953529131, 6.720989772694206, 7.724864776134126, 8.669059855065944, 9.68043407725826, 10.66503161349675, 11.641391724806233, 12.584549771081122, 13.643397572902222, 14.708271812213741, 14.526196139688535, 13.525555976456078, 4.880469106783931, 3.940512247175126, 2.9693182324564313, 1.9577693842006028, 2.8741820410613, 3.83846992418054, 4.726059591806696, 5.777340730361133, 6.746947052161313, 7.707163241180967, 8.720941006476158, 9.614448469120484, 10.62539619124206, 11.64968773778437, 12.580996257968826, 13.633699083396511, 14.657360833553376, 14.489578013174784, 13.484908515254563, 12.555842686730031, 5.811097738764291, 4.937592425572334, 3.994770327249709, 2.966729337322808, 3.907408204096885, 4.847144465507683, 5.787979426638707, 6.734153683228025, 7.692437751664095, 8.701799530044523, 9.711549693846344, 10.595756475308983, 11.59391119959383, 12.532115834368943, 13.554564923936661, 14.574348107633837, 14.51626714961121, 13.531981559055934, 12.576735734010313, 11.567189767945017, 6.743516351156687, 5.891678973326513, 4.923009113461408, 3.9561581862354402, 4.833231862512812, 5.815485470604536, 6.767979550231133, 7.7035034550665635, 8.683772122634249, 9.693194609067898, 10.711108425902022, 11.621881339650905, 12.601454485292827, 13.496399092735452, 14.451139747745032, 14.483430414450572, 13.54941660303632, 12.583820336964266, 11.538629894502302, 10.599149040146306, 7.797258286991018, 6.871093506905931, 5.870471605252293, 5.0029007247861, 5.778203413396655, 6.759474421975023, 7.695763545784592, 8.658044981913324, 9.63015666310449, 10.559994498325699, 11.625704043048671, 12.571694232464239, 13.579037111270889, 14.489168801999805, 14.572054073538641, 13.644427104029434, 12.634501990974272, 11.65374031681893, 10.586075360961766, 9.605139100659391, 8.762649270764454, 7.815901676778101, 6.907308268120944, 6.042302197061666, 6.821381112513719, 7.7497465788435385, 8.72853331314238, 9.687817826901638, 10.684178694108152, 11.561572596436159, 12.541515386001812, 13.536854720230492, 14.529375574987293, 14.559609449642338, 13.567237518132256, 12.617493768963477, 11.626716648845557, 10.678374938192658, 9.660704927150253, 8.659294435395918, 9.694146881042249, 8.825754230347796, 7.963442177032565, 7.09875508430378, 7.844396606081501, 8.803632483875951, 9.730521605555413, 10.619189462376582, 11.690357313502423, 12.547148693411797, 13.566849269007163, 14.491073515737241, 14.599847414206177, 13.591854655998505, 12.62930807496356, 11.674683308328209, 10.673173614043305, 9.708360839705275, 8.706052338750467, 7.688486531262715, 10.760461931675817, 9.861952663832701, 8.931927816466748, 8.071691390284029, 8.816023436434053, 9.753860376559075, 10.723994564027505, 11.613960745376326, 12.629374595140453, 13.570549023137541, 14.50335090079778, 14.648759363780243, 13.6848000959813, 12.73059066465464, 11.684589551603386, 10.722341876543195, 9.67150026769717, 8.695393137574062, 7.760974882740967, 6.7631285488515225, 11.812834612916705, 10.912204013598064, 9.917086451167442, 9.004289999056018, 9.826753628798917, 10.71118553601191, 11.669262772449684, 12.61112821434019, 13.560363318355366, 14.50113532529361, 14.645057636433105, 13.717212687015465, 12.757102850097406, 11.826789624455117, 10.872602457112643, 9.820680820450615, 8.82766177662257, 7.767927681036391, 6.8132541943930445, 5.846194742280763, 12.792390995003151, 11.899816752398394, 10.947360105044382, 10.075783634280317, 10.79648861379002, 11.650635378826312, 12.60801395490499, 13.636971712035477, 14.587880173650902, 14.863889117185424, 13.791986391737536, 12.745543944000499, 11.786598471207267, 10.82955319686869, 9.893756009284614, 8.936058348677976, 7.896440465630254, 6.836056031158964, 5.88660800886916, 4.953811304045981, 13.772657388880267, 12.972126236739493, 12.005688415044421, 11.034447582780391, 11.813097738382437, 12.648481898389997, 13.609113905572503, 14.558123307324042, 15.380058070789357, 14.370792038130206, 13.319628097856425, 12.357764125955185, 11.32340156452157, 10.338811403100841, 9.2755652016161, 8.23045038017548, 7.223344961218325, 6.184887779404454, 5.119826730619471, 4.161343619597994, 14.713457931183171, 13.906951496800337, 12.938995377444616, 12.00745765177063, 12.850528557138482, 13.702172879697867, 14.623598731560213, 15.555059426170079, 15.339561966244938, 14.400436368510277, 13.341735137811986, 12.351399779536516, 11.463671162915574, 10.557845633732967, 9.624621087245766, 8.795013911296145, 8.054002415886416, 7.151758654230029, 6.146393011291642, 5.118914472509649, 15.786029940197286, 14.924454589793765, 13.86879685084938, 13.024623995602992, 13.892878841279757, 14.754742742342776, 15.555574867665268, 15.186330306163509, 14.27133300195661, 13.34318181947758, 12.392206243084006, 11.38233557542673, 10.402226742099444, 9.60322542869745, 8.683413418544026, 7.7445732114336705, 7.054715721644996, 7.984352032126302, 6.999399605936858, 6.064725177370993, 16.76330463637489, 15.757214342323152, 14.82006102907891, 14.019615895479651, 14.893399930655, 15.706787180988298, 15.185444094479118, 14.24654878729142, 13.309507514042485, 12.373740930634515, 11.412094509703149, 10.429172753474605, 9.44156393619432, 8.57721013854841, 7.67255605735426, 6.811391630288196, 6.114050804544323, 7.077536345582028, 7.758023713271323, 6.804911925658644, 17.699345720467957, 16.704604850260484, 15.863026794968038, 15.080795375402687, 15.910918752885276, 15.462365955067252, 14.460293391976425, 13.43584663191887, 12.395534920943414, 11.416929812091677, 10.58043018987641, 9.537070210027096, 8.51286096490018, 7.57833805964391, 6.6894441575665935, 5.837400000337498, 5.0777324829356445, 6.058040075444687, 6.935624698366496, 7.756597573195494], [7.777798788661259, 6.78983482787743, 5.878127596720349, 4.818582011935649, 3.8790646303378145, 4.813670362987267, 5.688822360717182, 6.654823852389088, 7.6740533426376905, 8.612768095289404, 9.541507569813351, 10.498939632572458, 11.57188410872601, 12.581741580289187, 13.514562948666743, 14.506245241119077, 15.557658695806163, 16.520387179259593, 17.580233233671784, 18.648049245380065, 6.7753354615139765, 5.845279018327516, 4.872638438835178, 3.932292628573104, 2.949910416831216, 3.8734710367333385, 4.734045985830122, 5.762434636992607, 6.777272149407368, 7.782105945846688, 8.78225370511639, 9.774893167867056, 10.723087515813372, 11.728142515267802, 12.634930956227238, 13.613657169144075, 14.653593637315312, 15.684495390658828, 16.642054844949392, 17.657789352419037, 5.922848647009452, 4.922254015814101, 3.904397964771633, 2.925356581773097, 2.0042571912690166, 2.9076494630308343, 3.771753978207073, 4.815865122527226, 5.774683359087116, 6.815370911284859, 7.85501987149649, 8.867638431656614, 9.78669163395471, 10.719200993726995, 11.660501338439364, 12.66971825180098, 13.733175152066838, 14.74404689469227, 15.683559351874436, 16.699002838222984, 5.010255546015012, 3.9644996649199142, 2.96718660083842, 1.9147845963968297, 0.9856333916772066, 1.9300068599985865, 2.831818933012923, 3.8614525050372386, 4.845260475720133, 5.831388777057063, 6.788769848438441, 7.816410641553813, 8.801125451035947, 9.776864955966397, 10.749368384128733, 11.720029389989046, 12.772714376139067, 13.7680955289253, 14.788293196574973, 15.72825905700303, 4.021252377606777, 2.9720536502715063, 1.9942145711856982, 0.9306951336993462, 0.0, 0.927182562326279, 1.8568604518997978, 2.8956997367190085, 3.84955536484797, 4.823024907373719, 5.887726317987889, 6.891009511476543, 7.857526243701354, 8.79826010528382, 9.79285337163737, 10.756690230913597, 11.78848410810015, 12.836351963790124, 13.878886490755534, 14.824326739285572, 4.938201526364145, 3.9201264954444683, 2.8826946316395587, 1.8801769107011252, 0.977547431573844, 1.9405284654895945, 2.818575802278026, 3.8509663486393353, 4.787723819829786, 5.79029463899486, 6.79416964243478, 7.738364721366599, 8.749738943558915, 9.734336479797404, 10.710696591106888, 11.653854637381777, 12.712702439202877, 13.777576678514396, 14.773924019808446, 14.456251110155423, 5.811164240483277, 4.8712073808744725, 3.900013366155777, 2.888464517899949, 1.9434869073619536, 2.9077747904811937, 3.79536445810735, 4.846645596661787, 5.816251918461967, 6.776468107481621, 7.790245872776813, 8.68375333542114, 9.694701057542716, 10.718992604085026, 11.65030112426948, 12.703003949697166, 13.726665699854031, 14.669492040228887, 14.415603648953908, 13.486537820429376, 6.741792872463637, 5.86828755927168, 4.925465460949055, 3.8974244710221546, 2.9767130703975386, 3.9164493318083364, 4.85728429293936, 5.8034585495286795, 6.7617426179647495, 7.771104396345177, 8.780854560146997, 9.665061341609638, 10.663216065894485, 11.601420700669598, 12.623869790237316, 13.643652973934492, 14.59107289325336, 14.462676692755279, 13.507430867709658, 12.497884901644362, 7.674211484856034, 6.805060516985235, 5.825045792298988, 4.85819486507302, 3.9025367288134656, 4.88479033690519, 5.837284416531786, 6.772808321367217, 7.753076988934902, 8.762499475368553, 9.780413292202677, 10.69118620595156, 11.670759351593482, 12.565703959036107, 13.520444614045687, 14.44789450009927, 14.480111736735665, 13.51451547066361, 12.469325028201647, 11.529844173845651, 8.727953420690366, 7.773130185743511, 6.772508284089873, 5.7903776103695686, 4.847508279697308, 5.828779288275676, 6.765068412085245, 7.727349848213978, 8.699461529405143, 9.629299364626352, 10.695008909349324, 11.640999098764892, 12.648341977571542, 13.55847366830046, 14.557706942773123, 14.57512223772878, 13.565197124673617, 12.584435450518274, 11.516770494661111, 10.535834234358736, 9.664685949602035, 8.717938355615681, 7.809344946958523, 6.829779082645134, 5.890685978814372, 6.819051445144192, 7.7978381794430325, 8.75712269320229, 9.753483560408805, 10.630877462736812, 11.610820252302466, 12.606159586531145, 13.598680441287947, 14.493262077309398, 14.4979326518316, 13.548188902662822, 12.557411782544902, 11.609070071892003, 10.591400060849598, 9.589989569095263, 10.59618355987983, 9.727790909185376, 8.865478855870146, 7.886231969887247, 6.913701472382154, 7.8729373501766045, 8.799826471856067, 9.688494328677233, 10.759662179803074, 11.61645355971245, 12.636154135307816, 13.560378382037895, 14.591770592207752, 14.52254978969785, 13.560003208662906, 12.605378442027554, 11.60386874774265, 10.63905597340462, 9.636747472449812, 8.61918166496206, 11.662498610513396, 10.763989342670282, 9.793280040289874, 8.859168275867496, 7.885328302734706, 8.823165242859728, 9.793299430328158, 10.683265611676978, 11.698679461441104, 12.639853889438195, 13.572655767098434, 14.584864439919759, 14.483655794526483, 13.545934403322558, 12.614087533412931, 11.65303701024254, 10.602195401396514, 9.626088271273407, 8.691670016440312, 7.693823682550868, 12.714871291754283, 11.814240692435643, 10.778438674990568, 9.791766884639486, 8.89605849509957, 9.780490402312564, 10.738567638750338, 11.680433080640842, 12.629668184656017, 13.570440191594262, 14.540549789380464, 14.340264074267832, 13.53634166597332, 12.612694427726703, 11.65850726038423, 10.751375954149964, 9.758356910321918, 8.698622814735739, 7.743949328092391, 6.776889875980109, 13.69442767384073, 12.801853431235973, 11.808712328867507, 10.832705208952621, 9.865793480090673, 10.719940245126965, 11.677318821205644, 12.706276578336128, 13.657185039951553, 14.5004001724874, 14.411944206722021, 13.368595331252866, 12.56583728708318, 11.608792012744603, 10.672994825160528, 9.75622154209475, 8.827135599329601, 7.766751164858311, 6.817303142568507, 5.884506437745328, 14.674694067717846, 13.824624029929124, 12.762609989716726, 11.791369157452696, 10.88240260468309, 11.71778676469065, 12.678418771873156, 13.627428173624695, 14.632895072302583, 14.401248110568824, 13.350084170295043, 12.388220198393803, 11.543600773411043, 10.646961336318329, 9.70652184475718, 8.823173310099135, 8.15404009491767, 7.115582913103799, 6.050521864318817, 5.09203875329734, 15.61549461002075, 14.663873071472642, 13.69591695211692, 12.764379226442935, 11.919833423439135, 12.77147774599852, 13.692903597860866, 14.624364292470734, 14.408866832545593, 13.469741234810932, 12.41104000411264, 11.420704645837171, 10.532976029216229, 9.627150500033622, 8.69392595354642, 7.864318777596798, 8.74255837029807, 8.082453787929376, 7.077088144990989, 6.049609606208996, 16.688066619034867, 15.68137616446607, 14.625718425521685, 13.781545570275297, 12.96218370758041, 13.82404760864343, 14.624879733965921, 14.255635172464164, 13.340637868257264, 12.412486685778235, 11.461511109384661, 10.451640441727385, 9.471531608400099, 8.672530294998104, 7.752718284844681, 6.813878077734324, 7.743271676056651, 8.672907986537956, 7.930094739636204, 6.995420311070339, 17.537127076483117, 16.514135916995457, 15.576982603751215, 14.776537470151956, 13.962704796955654, 14.776092047288952, 14.254748960779773, 13.315853653592075, 12.37881238034314, 11.44304579693517, 10.481399376003804, 9.49847761977526, 8.510868802494976, 7.646515004849065, 6.741860923654915, 5.8806964965888495, 6.841876102649174, 7.8053616436868785, 8.678712256012814, 7.725600468400135, 18.473168160576183, 17.46152642493279, 16.619948369640344, 15.837716950074991, 14.98022361918593, 14.531670821367907, 13.52959825827708, 12.505151498219526, 11.464839787244069, 10.486234678392332, 9.649735056177065, 8.60637507632775, 7.582165831200833, 6.647642925944565, 5.758749023867248, 4.906704866638151, 5.858935012339858, 6.8392426048489, 7.853431539563108, 8.677286115936985], [8.704981350987538, 7.71701739020371, 6.805310159046627, 5.745764574261928, 4.8062471926640935, 3.8864878006609875, 4.7616397983909025, 5.727641290062808, 6.7468707803114105, 7.685585532963123, 8.614325007487071, 9.571757070246179, 10.64470154639973, 11.654559017962907, 12.587380386340463, 13.579062678792797, 14.630476133479883, 15.593204616933313, 16.653050671345504, 17.720866683053785, 7.7025180238402555, 6.772461580653795, 5.799821001161457, 4.859475190899383, 3.877092979157495, 2.946288474407059, 3.806863423503842, 4.835252074666328, 5.850089587081089, 6.854923383520408, 7.85507114279011, 8.847710605540778, 9.795904953487094, 10.800959952941524, 11.70774839390096, 12.686474606817796, 13.726411074989034, 14.757312828332552, 15.714872282623116, 16.730606790092764, 6.850031209335732, 5.849436578140381, 4.831580527097913, 3.852539144099376, 2.9314397535952956, 1.980466900704555, 2.8445714158807935, 3.888682560200947, 4.847500796760837, 5.888188348958579, 6.927837309170211, 7.940455869330335, 8.85950907162843, 9.792018431400717, 10.733318776113085, 11.742535689474701, 12.80599258974056, 13.816864332365991, 14.756376789548158, 15.771820275896708, 5.937438108341292, 4.891682227246194, 3.894369163164699, 2.841967158723109, 1.9128159540034857, 1.0028242976723074, 1.9046363706866438, 2.9342699427109595, 3.918077913393854, 4.904206214730784, 5.861587286112162, 6.889228079227534, 7.873942888709668, 8.84968239364012, 9.822185821802455, 10.792846827662768, 11.845531813812789, 12.840912966599022, 13.861110634248694, 14.801076494676751, 4.948434939933056, 3.8992362125977853, 2.9213971335119773, 1.8578776960256254, 0.927182562326279, 0.0, 0.9296778895735187, 1.9685171743927294, 2.922372802521691, 3.895842345047439, 4.96054375566161, 5.963826949150265, 6.930343681375076, 7.871077542957543, 8.865670809311093, 9.829507668587318, 10.861301545773872, 11.909169401463846, 12.951703928429255, 13.897144176959294, 5.8653840886904245, 4.847309057770747, 3.809877193965838, 2.8073594730274043, 1.9047299939001232, 1.0133459031633154, 1.8913932399517468, 2.9237837863130562, 3.8605412575035065, 4.863112076668581, 5.866987080108501, 6.81118215904032, 7.822556381232637, 8.807153917471126, 9.78351402878061, 10.726672075055498, 11.785519876876599, 12.850394116188117, 13.846741457482166, 14.860986834455453, 6.738346802809556, 5.7983899432007515, 4.827195928482056, 3.815647080226228, 2.8706694696882327, 1.9805922281549146, 2.868181895781071, 3.9194630343355077, 4.889069356135688, 5.849285545155342, 6.863063310450533, 7.75657077309486, 8.767518495216438, 9.791810041758747, 10.723118561943203, 11.775821387370888, 12.799483137527753, 13.742309477902609, 14.74697897582283, 14.413720382755656, 7.668975434789916, 6.79547012159796, 5.852648023275334, 4.824607033348434, 3.9038956327238177, 3.022329487484141, 3.9301017306130808, 4.8762759872023995, 5.83456005563847, 6.843921834018898, 7.853671997820719, 8.73787877928336, 9.736033503568207, 10.67423813834332, 11.696687227911038, 12.716470411608213, 13.663890330927082, 14.648175921482357, 14.434613430035938, 13.425067463970642, 8.601394047182312, 7.732243079311514, 6.752228354625267, 5.785377427399299, 4.829719291139744, 4.058900316248181, 4.910101854205507, 5.845625759040937, 6.825894426608622, 7.835316913042274, 8.8532307298764, 9.764003643625282, 10.743576789267204, 11.63852139670983, 12.59326205171941, 13.520711937772994, 14.454725749187245, 14.44169803298989, 13.396507590527927, 12.457026736171931, 9.655135983016644, 8.70031274806979, 7.699690846416152, 6.717560172695848, 5.774690842023587, 5.037141915296038, 5.914187914127757, 6.8001672858876985, 7.772278967078864, 8.702116802300074, 9.767826347023046, 10.713816536438614, 11.721159415245264, 12.631291105974183, 13.630524380446847, 14.519067008032767, 14.492379686999897, 13.511618012844554, 12.443953056987391, 11.463016796685016, 10.591868511928313, 9.64512091794196, 8.736527509284802, 7.756961644971414, 6.817868541140651, 6.105011695606718, 6.946957681485544, 7.856348402759018, 8.826300998082525, 9.703694900410534, 10.683637689976187, 11.678977024204867, 12.671497878961668, 13.566079514983121, 13.69106896226429, 14.475371464989102, 13.484594344871182, 12.536252634218283, 11.518582623175877, 10.517172131421543, 11.523366122206108, 10.654973471511655, 9.792661418196424, 8.813414532213528, 7.840884034708434, 7.158897600639131, 7.948945973898577, 8.78772003823396, 9.858887889359801, 10.689270997386172, 11.708971572981538, 12.633195819711617, 13.664588029881473, 13.607236827978637, 12.650292374505756, 13.532561004353834, 12.53105131006893, 11.5662385357309, 10.563930034776092, 9.54636422728834, 12.589681172839676, 11.69117190499656, 10.720462602616154, 9.786350838193776, 8.812510865060986, 8.109125493322255, 9.000288458820993, 9.782491321233705, 10.797905170997831, 11.712671327111916, 12.645473204772156, 13.65768187759348, 13.556473232200203, 12.618751840996278, 11.686904971086651, 12.58021957256882, 11.529377963722794, 10.553270833599687, 9.618852578766592, 8.621006244877147, 13.642053854080563, 12.741423254761923, 11.705621237316848, 10.718949446965766, 9.82324105742585, 9.06645065277509, 9.945556667243173, 10.77965879019757, 11.728893894212744, 12.669665901150989, 13.613367227054185, 13.413081511941552, 12.60915910364704, 11.685511865400423, 10.73132469805795, 11.678558516476244, 10.685539472648198, 9.625805377062019, 8.671131890418671, 7.704072438306388, 14.62161023616701, 13.729035993562253, 12.735894891193787, 11.759887771278901, 10.792976042416953, 10.005900495589492, 10.888538812856224, 11.805502287892855, 12.75641074950828, 13.599625882044126, 13.484761644395741, 12.441412768926586, 11.6386547247569, 10.681609450418323, 9.745812262834248, 10.670082155922568, 9.754318161655881, 8.693933727184591, 7.744485704894787, 6.811689000071607, 14.86692366101096, 14.751806592255404, 13.689792552043006, 12.718551719778976, 11.80958516700937, 11.003747015153177, 11.889638763523736, 12.770590809337802, 13.73212078185931, 13.474065548242544, 12.422901607968763, 11.461037636067523, 10.616418211084763, 9.719778773992049, 8.7793392824309, 9.737033923926953, 9.08122265724395, 8.042765475430079, 6.977704426645096, 6.019221315623619, 15.801793536171607, 15.591055633798922, 14.6230995144432, 13.691561788769215, 12.847015985765415, 12.057437996461047, 12.904123589511446, 13.767526928183841, 13.481684270219313, 12.542558672484653, 11.48385744178636, 10.493522083510891, 9.60579346688995, 8.699967937707342, 7.766743391220141, 8.778179391424617, 9.656418984125889, 9.009636350255656, 8.00427070731727, 6.976792168535276, 16.765582981546686, 16.60855872679235, 15.552900987847964, 14.708728132601577, 13.88936626990669, 13.110007859105956, 13.836099725616501, 13.328452610137884, 12.413455305930984, 11.485304123451956, 10.534328547058381, 9.524457879401105, 8.544349046073819, 7.745347732671824, 6.825535722518401, 7.727738691562142, 8.65713228988447, 9.586768600365774, 8.857277301962483, 7.9226028733966185, 17.74285767772429, 17.441318479321737, 16.504165166077495, 15.703720032478236, 14.889887359281934, 14.062052297751478, 13.327566398453493, 12.388671091265795, 11.45162981801686, 10.51586323460889, 9.554216813677524, 8.57129505744898, 7.583686240168696, 6.719332442522785, 5.814678361328635, 6.794557110416668, 7.755736716476992, 8.719222257514696, 9.605894818339094, 8.652783030726415, 18.63892107227811, 17.613341116345815, 16.58425000309804, 15.594598274327899, 14.519790035926519, 13.604488259041627, 12.6024156959508, 11.577968935893246, 10.537657224917789, 9.559052116066052, 8.722552493850785, 7.679192514001469, 6.654983268874553, 5.720460363618285, 4.831566461540968, 5.820565480465969, 6.786117574666137, 7.766425167175179, 8.780614101889386, 9.604468678263265], [9.634659240561056, 8.646695279777228, 7.734988048620146, 6.675442463835447, 5.735925082237612, 4.813037206534737, 3.8319619088173837, 4.797963400489289, 5.817192890737892, 6.755907643389604, 7.684647117913553, 8.64207918067266, 9.715023656826212, 10.724881128389388, 11.657702496766944, 12.649384789219278, 13.700798243906364, 14.663526727359795, 15.723372781771985, 16.791188793480266, 8.632195913413774, 7.702139470227314, 6.729498890734976, 5.789153080472902, 4.806770868731014, 3.874812605211348, 2.8771855339303234, 3.905574185092809, 4.9204116975075705, 5.925245493946889, 6.925393253216591, 7.918032715967258, 8.866227063913573, 9.871282063368003, 10.778070504327442, 11.756796717244278, 12.796733185415516, 13.827634938759033, 14.785194393049599, 15.800928900519246, 7.77970909890925, 6.779114467713899, 5.761258416671431, 4.782217033672895, 3.8611176431688143, 2.908991031508844, 1.9148935263072748, 2.9590046706274284, 3.9178229071873187, 4.958510459385061, 5.998159419596692, 7.010777979756816, 7.9298311820549126, 8.862340541827198, 9.803640886539567, 10.812857799901183, 11.876314700167041, 12.887186442792474, 13.826698899974641, 14.842142386323191, 6.867115997914809, 5.8213601168197115, 4.8240470527382175, 3.7716450482966275, 2.8424938435770044, 1.931348428476596, 0.9749584811131251, 2.004592053137441, 2.9884000238203354, 3.974528325157265, 4.931909396538643, 5.959550189654015, 6.944264999136149, 7.9200045040666, 8.892507932228936, 9.863168938089249, 10.91585392423927, 11.911235077025506, 12.931432744675178, 13.871398605103234, 5.878112829506574, 4.828914102171304, 3.851075023085496, 2.787555585599144, 1.8568604518997978, 0.9296778895735187, 0.0, 1.0388392848192107, 1.9926949129481724, 2.9661644554739204, 4.030865866088091, 5.034149059576746, 6.000665791801557, 6.941399653384024, 7.935992919737575, 8.899829779013801, 9.931623656200355, 10.979491511890329, 12.022026038855739, 12.967466287385777, 6.795061978263943, 5.776986947344266, 4.739555083539356, 3.737037362600923, 2.834407883473642, 1.9295220804878728, 0.9617153503782281, 1.9941058967395375, 2.930863367929988, 3.9334341870950618, 4.9373091905349815, 5.8815042694668005, 6.892878491659117, 7.877476027897606, 8.85383613920709, 9.796994185481978, 10.855841987303078, 11.920716226614598, 12.917063567908647, 13.931308944881934, 7.668024692383074, 6.72806783277427, 5.756873818055575, 4.745324969799746, 3.8003473592617514, 2.896768405479472, 1.9385040062075523, 2.989785144761989, 3.9593914665621694, 4.919607655581823, 5.9333854208770145, 6.8268928835213405, 7.837840605642918, 8.862132152185227, 9.793440672369682, 10.846143497797367, 11.869805247954233, 12.812631588329088, 13.817301086249309, 14.74636691477384, 8.598653324363434, 7.725148011171479, 6.782325912848853, 5.7542849229219515, 4.833573522297336, 3.9385056648086985, 3.000423841039562, 3.9465980976288813, 4.904882166064951, 5.914243944445379, 6.923994108247199, 7.80820088970984, 8.806355613994686, 9.7445602487698, 10.767009338337518, 11.786792522034693, 12.734212441353561, 13.718498031908837, 14.673743856954458, 14.35474535354416, 9.531071936755831, 8.661920968885033, 7.681906244198785, 6.715055316972817, 5.759397180713263, 4.975076493572739, 3.9804239646319886, 4.915947869467418, 5.896216537035103, 6.905639023468755, 7.92355284030288, 8.834325754051763, 9.813898899693685, 10.708843507136308, 11.663584162145888, 12.591034048199472, 13.525047859613723, 14.490644125685778, 14.326185480101445, 13.38670462574545, 10.584813872590162, 9.629990637643308, 8.62936873598967, 7.647238062269366, 6.704368731597106, 5.920799148363807, 4.984510024554238, 5.87048939631418, 6.842601077505345, 7.772438912726554, 8.838148457449527, 9.784138646865095, 10.791481525671745, 11.701613216400661, 12.700846490873325, 13.589389118459245, 14.499537841655894, 14.441295902418073, 13.37363094656091, 12.392694686258535, 11.521546401501832, 10.574798807515478, 9.66620539885832, 8.686639534544932, 7.74754643071417, 6.988668928674487, 6.017279791912025, 6.926670513185499, 7.896623108509006, 8.774017010837015, 9.753959800402669, 10.749299134631348, 11.74181998938815, 12.636401625409599, 13.62877355691968, 14.578517306088461, 14.4142722344447, 13.465930523791801, 12.448260512749396, 11.446850020995061, 12.453044011779626, 11.584651361085173, 10.722339307769943, 9.743092421787047, 8.770561924281953, 8.034867462979943, 7.019268084325058, 7.858042148660442, 8.929209999786284, 9.759593107812654, 10.779293683408019, 11.703517930138098, 12.734910140307955, 12.807420701270999, 13.563127997229756, 14.462238893927353, 13.460729199642449, 12.495916425304419, 11.493607924349611, 10.476042116861858, 13.519359062413194, 12.620849794570079, 11.650140492189673, 10.716028727767295, 9.742188754634505, 8.985095355663066, 8.070610569247474, 8.852813431660186, 9.868227281424312, 10.782993437538398, 11.715795315198637, 12.728003988019962, 12.654834538360488, 11.81893571428864, 12.599740593810651, 13.509897462142339, 12.459055853296313, 11.482948723173205, 10.548530468340111, 9.550684134450666, 14.571731743654082, 13.671101144335442, 12.635299126890366, 11.648627336539285, 10.752918946999369, 9.942420515115902, 9.015878777669654, 9.84998090062405, 10.799216004639225, 11.73998801157747, 12.683689337480667, 12.483403622368034, 11.707520409807325, 10.885695738692785, 11.64416032078195, 12.608236406049762, 11.615217362221717, 10.555483266635537, 9.60080977999219, 8.633750327879907, 14.917512165314559, 14.658713883135771, 13.665572780767306, 12.68956566085242, 11.722653931990472, 10.881870357930303, 9.958860923282705, 10.875824398319336, 11.826732859934761, 12.669947992470608, 12.555083754822222, 11.511734879353067, 10.737016030917186, 9.835029099274612, 10.658647885558247, 11.582917778646566, 10.6839960512294, 9.62361161675811, 8.674163594468306, 7.741366889645126, 13.937245771437443, 14.883339171776203, 14.619470441616524, 13.648229609352494, 12.739263056582889, 11.879716877493989, 10.959960873950218, 11.840912919764284, 12.802442892285791, 12.544387658669025, 11.493223718395244, 10.531359746494005, 9.686740321511243, 8.79010088441853, 9.6921749051549, 10.649869546650951, 10.010900546817469, 8.972443365003597, 7.907382316218615, 6.948899205197137, 14.87211564659809, 15.836547621510306, 15.55277740401672, 14.621239678342734, 13.776693875338934, 12.933407858801859, 11.974445699937927, 12.837849038610322, 12.552006380645794, 11.612880782911134, 10.554179552212842, 9.563844193937372, 8.676115577316429, 7.770290048133823, 8.67957901394414, 9.691015014148615, 10.569254606849888, 9.939314239829173, 8.933948596890787, 7.906470058108793, 15.835905091973167, 16.879691528684162, 16.482578877421485, 15.638406022175095, 14.819044159480208, 13.967974356301067, 12.906421836042982, 12.398774720564365, 11.483777416357466, 10.555626233878437, 9.604650657484862, 8.594779989827586, 7.614671156500299, 6.815669843098306, 7.738371345242401, 8.640574314286141, 9.569967912608469, 10.499604223089774, 9.786955191536, 8.852280762970135, 16.813179788150773, 17.342341762080935, 16.405188448836693, 15.398368658736526, 14.343691503318805, 13.340841686154759, 12.397888508879975, 11.458993201692277, 10.521951928443341, 9.586185345035371, 8.624538924104005, 7.64161716787546, 6.654008350595177, 5.7896545529492665, 6.727513984052635, 7.707392733140668, 8.668572339200992, 9.632057880238696, 10.535572707912612, 9.582460920299933, 17.70924318270459, 16.683663226772296, 15.654572113524523, 14.66492038475438, 13.590112146353, 12.674810369468108, 11.672737806377281, 10.648291046319727, 9.60797933534427, 8.629374226492533, 7.792874604277266, 6.749514624427951, 5.725305379301035, 4.790782474044766, 5.7444020842649675, 6.733401103189969, 7.715795464239656, 8.696103056748697, 9.710291991462904, 10.534146567836784], [10.673498525380268, 9.68553456459644, 8.773827333439357, 7.714281748654658, 6.774764367056823, 5.8518764913539485, 4.870801193636595, 4.056774216439533, 4.919528376414179, 5.858243129065891, 6.7869826035898395, 7.744414666348947, 8.817359142502498, 9.795963912110283, 10.72878528048784, 11.68271405582368, 12.717941676318695, 13.680670159772125, 14.740516214184314, 15.780738956431541, 9.671035198232985, 8.740978755046525, 7.768338175554187, 6.827992365292113, 5.845610153550225, 4.913651890030558, 3.916024818749534, 2.987571018148886, 3.979764427067612, 4.98459822350693, 5.984745982776633, 6.923446072596881, 7.871640420543196, 8.861928704889083, 9.73923121950823, 10.717957432425067, 11.757893900596304, 12.788795653939822, 13.746355108230388, 14.762089615700035, 8.81854838372846, 7.81795375253311, 6.8000977014906425, 5.821056318492106, 4.8999569279880255, 3.947830316328054, 2.9537328111264856, 2.041001503683505, 2.957587041511912, 3.985764503236533, 4.964447620405942, 5.977066180566066, 6.890991897235701, 7.823501257007987, 8.764801601720356, 9.774018515081972, 10.83747541534783, 11.848347157973263, 12.78785961515543, 13.80330310150398, 7.90595528273402, 6.860199401638923, 5.862886337557429, 4.810484333115839, 3.881333128396215, 2.9701877132958066, 2.0137977659323356, 1.0392208739577038, 1.9823614207597848, 2.9408165259665147, 3.8981975973478926, 4.925838390463265, 5.905425714316938, 6.881165219247388, 7.853668647409725, 8.824329653270038, 9.877014639420059, 10.872395792206294, 11.892593459855966, 12.832559320284023, 6.9169521143257855, 5.867753386990515, 4.889914307904707, 3.826394870418355, 2.8956997367190085, 1.9685171743927294, 1.0388392848192107, 0.0, 0.9538556281289615, 1.9273251706547097, 2.9920265812688807, 3.9953097747575352, 4.961826506982346, 5.902560368564813, 6.8971536349183635, 7.860990494194589, 8.892784371381143, 9.940652227071118, 10.983186754036527, 11.928627002566566, 7.833901263083154, 6.815826232163477, 5.778394368358567, 4.775876647420134, 3.8732471682928526, 2.9683613653070835, 2.000554635197439, 1.0596856029892732, 1.892024083110777, 2.894594902275851, 3.8984699057157712, 4.84266498464759, 5.854039206839907, 6.838636743078396, 7.81499685438788, 8.758154900662769, 9.817002702483869, 10.881876941795387, 11.878224283089436, 12.892469660062723, 8.706863977202286, 7.766907117593481, 6.795713102874786, 5.784164254618958, 4.8391866440809626, 3.9356076902986827, 2.977343291026763, 2.068810434570722, 2.934302645143388, 3.8807683707626124, 4.894546136057803, 5.78805359870213, 6.799001320823709, 7.8232928673660185, 8.754601387550473, 9.807304212978158, 10.830965963135023, 11.773792303509879, 12.7784618014301, 13.707527629954631, 9.637492609182646, 8.76398729599069, 7.821165197668064, 6.793124207741163, 5.872412807116548, 4.977344949627909, 4.039263125858772, 3.0256233874376144, 3.887246455901013, 4.875404659626168, 5.885154823427989, 6.76936160489063, 7.767516329175477, 8.70572096395059, 9.728170053518308, 10.747953237215484, 11.695373156534352, 12.679658747089627, 13.634904572135248, 14.644450538200545, 10.569911221575042, 9.700760253704244, 8.720745529017996, 7.7538946017920285, 6.798236465532474, 5.999608467524424, 4.934508760537339, 3.998984855701909, 4.889354705554385, 5.8667997386495445, 6.884713555483669, 7.795486469232552, 8.775059614874474, 9.6700042223171, 10.62474487732668, 11.552194763380264, 12.486208574794516, 13.45180484086657, 14.496995283328534, 14.425543910564661, 11.623653157409374, 10.66882992246252, 9.668208020808882, 8.686077347088577, 7.743208016416317, 6.874883944269158, 5.938594820459588, 4.95352638254867, 5.835739246024627, 6.765577081245835, 7.831286625968808, 8.777276815384376, 9.784619694191026, 10.662773931581453, 11.662007206054117, 12.550549833640037, 13.460698556836686, 14.385102742409297, 14.412470231380121, 13.431533971077746, 12.560385686321043, 11.61363809233469, 10.705044683677531, 9.725478819364143, 8.786385715533381, 7.942753724579838, 6.968992013179247, 6.00970749941999, 6.889761277028288, 7.767155179356297, 8.74709796892195, 9.742437303150629, 10.73495815790743, 11.597562340590391, 12.589934272100473, 13.539678021269253, 14.481240129431459, 14.504769808611012, 13.487099797568607, 12.485689305814272, 13.491883296598838, 12.623490645904385, 11.761178592589154, 10.781931706606258, 9.809401209101164, 8.986579684247165, 7.97098030559228, 6.941079134894934, 7.955795972918966, 8.752731276331936, 9.772431851927301, 10.696656098657378, 11.728048308827235, 12.56823580021677, 13.530782381251715, 14.485407147887067, 14.49956848446166, 13.53475571012363, 12.532447209168822, 11.51488140168107, 14.558198347232405, 13.65968907938929, 12.688979777008884, 11.754868012586506, 10.781028039453716, 9.900783759146922, 8.930649571678492, 7.935850417894678, 8.913058486404351, 9.77613160605768, 10.708933483717919, 11.721142156539242, 11.913645354310733, 12.841431658226718, 13.638579878629862, 14.54873674696155, 13.497895138115524, 12.521788007992416, 11.587369753159322, 10.589523419269877, 14.713758927532105, 14.709940429154653, 13.674138411709578, 12.687466621358496, 11.79175823181858, 10.858108918599758, 9.875917780100671, 8.933017886858542, 9.882252990873717, 10.779121684756728, 11.676827505999949, 11.742214438318278, 10.96633122575757, 11.908191682630862, 12.682999605601161, 13.647075690868974, 12.654056647040928, 11.594322551454749, 10.639649064811401, 9.672589612699118, 13.878672880495348, 14.916809371298092, 14.704412065586517, 13.728404945671631, 12.761493216809683, 11.776278501792401, 10.818899925713723, 9.958861384553828, 10.909769846169253, 11.709081665649865, 11.790577556236657, 10.770545695303312, 9.99582684686743, 10.85752504321269, 11.697487170377459, 12.62175706346578, 11.722835336048611, 10.662450901577321, 9.713002879287517, 8.780206174464338, 12.898406486618232, 13.844499886956992, 14.90651392716939, 14.687068894171706, 13.743970889506532, 12.774125021356086, 11.819999876381235, 10.923949905998775, 11.885479878520282, 11.76603503684278, 10.72871751980968, 9.79017056244425, 8.945551137461488, 9.812596828356607, 10.731014189974111, 11.688708831470166, 11.049739831636678, 10.011282649822807, 8.946221601037825, 7.987738490016349, 13.833276361778879, 14.797708336691095, 15.765664456046816, 15.660078963161945, 14.781401708262576, 13.827816002663956, 12.834484702368945, 11.920886024844812, 11.654341866322083, 10.715216268587422, 9.782173938096232, 8.822655009887617, 7.934926393266673, 8.7927859920719, 9.718418298763352, 10.72985429896783, 11.608093891669101, 10.978153524648384, 9.972787881709998, 8.945309342928004, 14.797065807153956, 15.840852243864951, 16.41633579551324, 15.404683481147986, 14.446548078370338, 13.39522161047657, 12.51065020745055, 11.501110206240654, 10.586112902033754, 9.657961719554725, 8.830359606967663, 7.85359080577783, 6.873481972450543, 7.838165787036383, 8.777210630061612, 9.679413599105354, 10.608807197427682, 11.538443507908987, 10.825794476355211, 9.891120047789347, 15.774340503331562, 16.444677247757223, 15.507523934512982, 14.500704144412815, 13.446026988995094, 12.443177171831048, 11.500223994556263, 10.561328687368565, 9.62428741411963, 8.68852083071166, 7.841528160705105, 6.900427983825704, 5.912819166545421, 6.828493837768478, 7.766353268871846, 8.74623201795988, 9.707411624020205, 10.670897165057909, 11.574411992731823, 10.621300205119145, 16.710381587424628, 15.700806659184625, 14.671715545936854, 13.698249651358783, 12.623441412957403, 11.745893153189003, 10.743820590098176, 9.750626531996014, 8.710314821020557, 7.731709712168821, 6.895210089953553, 5.8518501101042375, 4.9841161952512785, 5.829621758863977, 6.783241369084179, 7.77224038800918, 8.754634749058866, 9.734942341567908, 10.749131276282116, 11.572985852655995], [11.62735415350923, 10.639390192725402, 9.727682961568318, 8.66813737678362, 7.728619995185785, 6.80573211948291, 5.824656821765556, 4.978322362698869, 3.9656727482852174, 4.90438750093693, 5.833126975460878, 6.790559038219985, 7.863503514373537, 8.84210828398132, 9.774929652358876, 10.728858427694718, 11.764086048189732, 12.726814531643162, 13.786660586055351, 14.826883328302578, 10.624890826361948, 9.694834383175488, 8.72219380368315, 7.781847993421074, 6.799465781679186, 5.86750751815952, 4.869880446878496, 3.9091191644082213, 3.0259087989386506, 4.030742595377969, 5.0308903546476715, 5.9695904444679195, 6.917784792414235, 7.90807307676012, 8.785375591379267, 9.764101804296104, 10.804038272467341, 11.834940025810859, 12.792499480101425, 13.808233987571072, 9.772404011857422, 8.77180938066207, 7.753953329619604, 6.774911946621068, 5.853812556116987, 4.901685944457016, 3.9075884392554476, 2.9625496499428405, 2.0037314133829502, 3.031908875107572, 4.0105919922769795, 5.023210552437105, 5.937136269106739, 6.869645628879024, 7.810945973591393, 8.82016288695301, 9.88361978721887, 10.8944915298443, 11.834003987026467, 12.849447473375017, 8.859810910862981, 7.814055029767884, 6.816741965686391, 5.764339961244801, 4.835188756525177, 3.9240433414247686, 2.9676533940612977, 1.9930765020866654, 1.0285057926308232, 1.986960897837553, 2.944341969218931, 3.9719827623343034, 4.951570086187976, 5.927309591118426, 6.899813019280763, 7.8704740251410765, 8.923159011291098, 9.918540164077331, 10.938737831727003, 11.87870369215506, 7.870807742454747, 6.821609015119476, 5.843769936033668, 4.780250498547316, 3.84955536484797, 2.922372802521691, 1.9926949129481724, 0.9538556281289615, 0.0, 0.9734695425257481, 2.038170953139919, 3.0414541466285736, 4.007970878853384, 4.948704740435851, 5.9432980067894015, 6.907134866065627, 7.9389287432521805, 8.986796598942155, 10.029331125907564, 10.974771374437603, 8.787756891212116, 7.7696818602924385, 6.732249996487528, 5.729732275549095, 4.827102796421814, 3.922216993436045, 2.9544102633264004, 1.999334640263374, 0.9381684549818154, 1.9407392741468896, 2.9446142775868096, 3.888809356518628, 4.900183578710944, 5.884781114949433, 6.861141226258917, 7.804299272533806, 8.863147074354906, 9.928021313666424, 10.924368654960473, 11.93861403193376, 9.660719605331247, 8.720762745722443, 7.749568731003747, 6.738019882747919, 5.793042272209924, 4.889463318427644, 3.9311989191557246, 2.950053338814606, 1.9804470170144262, 2.9269127426336508, 3.940690507928842, 4.834197970573168, 5.845145692694746, 6.8694372392370555, 7.80074575942151, 8.853448584849195, 9.87711033500606, 10.819936675380916, 11.824606173301136, 12.753672001825668, 10.591348237311607, 9.717842924119651, 8.775020825797025, 7.746979835870124, 6.826268435245509, 5.93120057775687, 4.919476178215669, 3.8916748962081216, 2.9333908277720515, 3.9215490314972064, 4.931299195299027, 5.815505976761668, 6.813660701046515, 7.751865335821629, 8.774314425389345, 9.79409760908652, 10.741517528405389, 11.725803118960664, 12.681048944006285, 13.690594910071582, 11.523766849704003, 10.654615881833205, 9.674601157146958, 8.70775022992099, 7.752092093661435, 6.865659976294931, 5.800560269307846, 4.865036364472417, 3.935499077425423, 4.912944110520582, 5.930857927354707, 6.84163084110359, 7.821203986745511, 8.716148594188137, 9.670889249197717, 10.598339135251301, 11.532352946665553, 12.497949212737607, 13.543139655199571, 14.583846112263407, 12.577508785538335, 11.62268555059148, 10.622063648937843, 9.639932975217537, 8.697063644545278, 7.740935453039665, 6.804646329230096, 5.819577891319178, 4.881883617895665, 5.811721453116873, 6.877430997839846, 7.8234211872554145, 8.830764066062065, 9.70891830345249, 10.708151577925154, 11.596694205511074, 12.506842928707723, 13.431247114280334, 14.495694188740107, 14.385389599206707, 13.514241314450004, 12.56749372046365, 11.658900311806494, 10.679334447493103, 9.737170699680163, 8.808805233350345, 7.835043521949754, 6.875759008190498, 5.935905648899325, 6.813299551227335, 7.793242340792988, 8.788581675021668, 9.781102529778469, 10.643706712461428, 11.63607864397151, 12.58582239314029, 13.527384501302496, 14.49173211073742, 14.440955425697569, 13.439544933943234, 14.445738924727799, 13.577346274033346, 12.715034220718117, 11.735787334735218, 10.760186193247947, 9.852631193017672, 8.837031814362788, 7.807130643665441, 7.001940344790003, 7.798875648202974, 8.818576223798338, 9.742800470528417, 10.774192680698274, 11.614380172087808, 12.576926753122752, 13.531551519758104, 14.480927536104748, 14.488611338252591, 13.486302837297785, 12.46873702981003, 14.62157918932287, 14.613544707518251, 13.642835405137843, 12.708723640715466, 11.730177945977118, 10.766835267917429, 9.796701080449, 8.801901926665185, 7.959202858275389, 8.822275977928719, 9.755077855588958, 10.767286528410281, 11.699410804040827, 12.602865159070166, 13.540314156541857, 14.487245683794864, 14.451750766244485, 13.475643636121378, 12.541225381288283, 11.543379047398838, 13.759903299403142, 14.731467316318268, 14.627994039838537, 13.641322249487455, 12.740908138341982, 11.724160427370265, 10.741969288871179, 9.799069395629049, 9.028622727324407, 9.825266056627767, 10.722971877870988, 10.861829165022563, 11.819610273690968, 12.829739828890197, 13.636855233730122, 14.600931318997937, 13.60791227516989, 12.54817817958371, 11.593504692940362, 10.62644524082808, 12.924817252366385, 13.962953743169129, 15.00359051572482, 14.647474040853647, 13.680562311991698, 12.642330010562908, 11.68495143448423, 10.824912893324335, 10.056139582619943, 10.755226037520904, 10.836721928107698, 9.890160422007597, 10.849105894800829, 11.779073189472024, 12.65134279850642, 13.57561269159474, 12.676690964177572, 11.616306529706282, 10.666858507416478, 9.734061802593299, 11.944550858489269, 12.89064425882803, 13.952658299040428, 14.923899131304458, 14.610022398277039, 13.640176530126594, 12.686051385151742, 11.790001414769282, 11.031849614970973, 10.812179408713819, 9.77486189168072, 8.909785289148534, 9.867099283720822, 10.734144974615942, 11.684869818103072, 12.642564459599125, 12.00359545976564, 10.965138277951768, 9.900077229166786, 8.941594118145309, 12.879420733649916, 13.843852708562132, 14.811808827917853, 15.467994196851386, 14.535042734382651, 13.492019599479237, 12.488770715426643, 11.537004569680445, 10.700486238193122, 9.761360640458461, 8.828318309967273, 7.942269736591901, 8.856474539526008, 9.714334138331235, 10.672273926892313, 11.683709927096789, 12.561949519798063, 11.932009152777345, 10.926643509838959, 9.899164971056965, 13.843210179024993, 14.886996615735988, 15.462480167384282, 14.450827853019025, 13.492692450241377, 12.441365982347609, 11.556794579321588, 10.547254578111692, 9.632257273904793, 8.704106091425764, 7.876503978838703, 6.9732055324821145, 7.795030118709879, 8.759713933295718, 9.731066258190573, 10.633269227234315, 11.562662825556643, 12.492299136037948, 11.779650104484173, 10.844975675918308, 14.820484875202599, 15.490821619628264, 14.553668306384022, 13.546848516283855, 12.492171360866132, 11.489321543702086, 10.546368366427302, 9.607473059239604, 8.670431785990669, 7.734665202582699, 6.887672532576143, 5.967701838191976, 6.834367312804757, 7.782349465897439, 8.720208897000807, 9.700087646088841, 10.661267252149166, 11.62475279318687, 12.528267620860786, 11.575155833248107, 15.756525959295665, 14.746951031055662, 13.71785991780789, 12.74439402322982, 11.66958578482844, 10.79203752506004, 9.789964961969213, 8.796770903867053, 7.756459192891596, 6.77785408403986, 5.9413544618245915, 4.897994481975276, 5.905664341510614, 6.783477386992939, 7.73709699721314, 8.726096016138142, 9.708490377187827, 10.68879796969687, 11.702986904411077, 12.526841480784958], [12.600823696034977, 11.61285973525115, 10.701152504094065, 9.641606919309366, 8.702089537711531, 7.779201662008658, 6.798126364291305, 5.94943622671678, 4.936786612303129, 4.033948196029747, 4.962687670553695, 5.920119733312802, 6.9366378137866676, 7.868638741455573, 8.80146010983313, 9.755388885168971, 10.790616505663985, 11.753344989117416, 12.813191043529606, 13.85341378577683, 11.598360368887695, 10.668303925701235, 9.695663346208896, 8.755317535946821, 7.772935324204933, 6.840977060685268, 5.843349989404244, 4.880233028426133, 3.997022662956562, 3.107111119440848, 4.093984719366029, 4.996120901942171, 5.944315249888486, 6.934603534234373, 7.811906048853521, 8.790632261770357, 9.830568729941595, 10.86147048328511, 11.819029937575676, 12.834764445045323, 10.745873554383168, 9.745278923187817, 8.72742287214535, 7.748381489146815, 6.827282098642733, 5.875155486982764, 4.881057981781195, 3.933663513960752, 2.9748452774008616, 2.0584393325818233, 3.037122449751232, 4.049741009911356, 4.963666726580992, 5.896176086353277, 6.837476431065646, 7.846693344427264, 8.910150244693122, 9.921021987318552, 10.860534444500718, 11.875977930849269, 9.833280453388728, 8.78752457229363, 7.7902115082121375, 6.737809503770547, 5.808658299050924, 4.897512883950516, 3.9411229365870453, 2.9665460446124134, 1.9996196566487348, 1.013491355311805, 1.970872426693183, 2.9985132198085553, 3.9781005436622285, 4.953840048592679, 5.926343476755015, 6.897004482615329, 7.949689468765351, 8.945070621551583, 9.965268289201255, 10.905234149629312, 8.844277284980492, 7.795078557645223, 6.817239478559415, 5.753720041073064, 4.823024907373718, 3.895842345047439, 2.9661644554739204, 1.9273251706547097, 0.9734695425257481, 0.0, 1.064701410614171, 2.0679846041028256, 3.034501336327636, 3.975235197910102, 4.969828464263653, 5.933665323539879, 6.965459200726432, 8.013327056416406, 9.055861583381816, 10.001301831911855, 9.761226433737862, 8.743151402818185, 7.705719539013276, 6.7032018180748425, 5.800572338947561, 4.895686535961793, 3.9278798058521485, 2.972804182789122, 1.9116379975075635, 0.9672697316211415, 1.9711447350610616, 2.91533981399288, 3.9267140361851967, 4.911311572423686, 5.88767168373317, 6.830829730008058, 7.889677531829157, 8.954551771140675, 9.950899112434724, 10.965144489408011, 10.634189147856993, 9.69423228824819, 8.723038273529495, 7.711489425273666, 6.766511814735671, 5.862932860953392, 4.904668461681473, 3.9235228813403547, 2.953916559540174, 1.9534432001079027, 2.967220965403094, 3.86072842804742, 4.871676150168998, 5.895967696711308, 6.827276216895762, 7.879979042323447, 8.903640792480312, 9.846467132855167, 10.851136630775388, 11.78020245929992, 11.564817779837353, 10.691312466645398, 9.748490368322772, 8.720449378395871, 7.799737977771256, 6.904670120282619, 5.892945720741417, 4.86514443873387, 3.9068603702977995, 2.9480794889714583, 3.9578296527732784, 4.8420364342359195, 5.840191158520766, 6.77839579329588, 7.800844882863598, 8.820628066560774, 9.768047985879642, 10.752333576434918, 11.707579401480539, 12.717125367545833, 12.49723639222975, 11.628085424358954, 10.648070699672706, 9.681219772446738, 8.725561636187184, 7.8391295188206795, 6.774029811833595, 5.838505906998164, 4.908968619951171, 3.939474567994834, 4.957388384828959, 5.868161298577841, 6.847734444219762, 7.74267905166239, 8.69741970667197, 9.624869592725554, 10.558883404139806, 11.52447967021186, 12.569670112673824, 13.61037656973766, 13.550978328064081, 12.596155093117229, 11.595533191463591, 10.613402517743285, 9.670533187071026, 8.714404995565413, 7.778115871755844, 6.793047433844926, 5.855353160421413, 4.934162352882123, 5.999871897605096, 6.871832392935051, 7.879175271741702, 8.735448760926744, 9.734682035399407, 10.623224662985328, 11.533373386181976, 12.457777571754587, 13.52222464621436, 14.552858209352559, 14.487710856975752, 13.540963262989399, 12.632369854332243, 11.652803990018851, 10.710640242205912, 9.782274775876093, 8.808513064475504, 7.849228550716246, 6.909375191425074, 5.935740450992585, 6.915683240558238, 7.836992880701304, 8.829513735458105, 9.670237169935682, 10.662609101445764, 11.612352850614542, 12.553914958776751, 13.518262568211675, 14.447595080025874, 14.41301447646898, 14.667029600987288, 14.550815816559094, 13.688503763243865, 12.709256877260966, 11.733655735773695, 10.82610073554342, 9.810501356888537, 8.78060018619119, 7.9754098873157515, 6.921316547968224, 7.941017123563589, 8.791211676208054, 9.82260388637791, 10.640910629562061, 11.603457210597005, 12.558081977232357, 13.507457993579003, 14.541822380531581, 14.45977237982353, 13.442206572335778, 13.648109646797122, 14.714145713537743, 14.616304947663592, 13.682193183241214, 12.703647488502869, 11.74030481044318, 10.77017062297475, 9.775371469190935, 8.932672400801136, 7.944716877693968, 8.877518755354206, 9.815697734089918, 10.747822009720464, 11.62939561654442, 12.56684461401611, 13.513776141269117, 14.509131339925139, 14.449113178647124, 13.51469492381403, 12.516848589924585, 12.786433756877393, 13.75799777379252, 14.830984282958045, 14.614791792013204, 13.714377680867733, 12.697629969896015, 11.715438831396929, 10.7725389381548, 9.888478963331261, 8.947706956393016, 9.845412777636236, 10.76713140389771, 11.695136138273627, 12.562635592140275, 13.516822759482748, 14.438858198457268, 14.581381817695636, 13.521647722109456, 12.566974235466109, 11.599914783353826, 11.951347709840636, 12.98948420064338, 14.030120973199072, 14.909093537278784, 14.654031854517449, 13.615799553088658, 12.65842097700998, 11.798382435850085, 10.915995818626797, 9.877666937286154, 9.966282623200515, 10.84666169153384, 11.805607164327071, 12.750187053489936, 13.624812341032168, 14.549082234120489, 13.650160506703319, 12.589776072232029, 11.640328049942225, 10.707531345119046, 10.97108131596352, 11.91717471630228, 12.979188756514679, 13.950429588778709, 14.563129654823395, 13.59328378667295, 12.612510785370837, 11.663501383619298, 10.82235895965367, 9.941740103806636, 8.904422586773537, 9.866286558674776, 10.838213147738735, 11.705258838633855, 12.65833936062882, 13.616034002124874, 12.977065002291386, 11.938607820477515, 10.873546771692533, 9.915063660671056, 11.905951191124167, 12.870383166036383, 13.838339285392104, 14.597554891944203, 13.664603429475468, 12.621580294572054, 11.61833141051946, 10.666565264773261, 9.830046933285939, 8.890921335551278, 7.957879005060089, 8.913383600609812, 9.82758840354392, 10.685448002349148, 11.645743469418061, 12.657179469622537, 13.535419062323811, 12.905478695303092, 11.900113052364706, 10.872634513582712, 12.869740636499245, 13.91352707321024, 14.592040862477099, 13.580388548111841, 12.622253145334193, 11.570926677440426, 10.686355274414405, 9.67681527320451, 8.76181796899761, 7.833666786518581, 7.00606467393152, 7.944319396500025, 8.76614398272779, 9.73082779731363, 10.704535800716322, 11.606738769760064, 12.536132368082392, 13.465768678563697, 12.75311964700992, 11.818445218444054, 13.84701533267685, 14.62038231472108, 13.683229001476839, 12.676409211376672, 11.62173205595895, 10.618882238794903, 9.675929061520119, 8.73703375433242, 7.7999924810834855, 6.8642258976755155, 6.01723322766896, 6.938815702209887, 7.805481176822668, 8.755819008423186, 9.693678439526556, 10.67355718861459, 11.634736794674915, 12.598222335712618, 13.501737163386533, 12.548625375773854, 14.783056416769917, 13.773481488529915, 12.744390375282144, 11.770924480704073, 10.696116242302693, 9.818567982534294, 8.816495419443466, 7.869905203280182, 6.886019887984412, 5.907414779132677, 5.070915156917408, 5.869108345993188, 6.876778205528526, 7.756946929518687, 8.710566539738888, 9.69956555866389, 10.681959919713574, 11.662267512222616, 12.676456446936823, 13.500311023310704], [13.60838641089285, 12.620422450109022, 11.708715218951939, 10.64916963416724, 9.709652252569406, 8.767692054001744, 7.78661675628439, 6.865988355940966, 5.853338741527316, 4.950500325253934, 4.165659534872997, 4.871321303897137, 5.876954747315081, 6.803937330841402, 7.736758699218958, 8.6906874745548, 9.725915095049814, 10.688643578503244, 11.748489632915433, 12.78871237516266, 12.605923083745568, 11.675866640559107, 10.703226061066768, 9.762880250804693, 8.780498039062806, 7.8294674526783545, 6.83184038139733, 5.796785157650319, 4.913574792180749, 4.023663248665035, 3.09577470582746, 3.936437835470585, 4.8846321834169, 5.869902123620202, 6.747204638239349, 7.7259308511561855, 8.765867319327423, 9.79676907267094, 10.754328526961507, 11.770063034431153, 11.81057496499734, 10.809980333801988, 9.77470299071945, 8.795661607720913, 7.834844813500608, 6.86364587897585, 5.869548373774282, 4.850215643184939, 3.8913974066250487, 2.9749914618060105, 2.0389124362126627, 2.99005794343977, 3.8989653159668207, 4.831474675739106, 5.7727750204514745, 6.781991933813092, 7.845448834078951, 8.856320576704382, 9.795833033886549, 10.811276520235099, 10.8979818640029, 9.852225982907802, 8.837491626786235, 7.785089622344646, 6.855938417625023, 5.886003275943603, 4.929613328580132, 3.8999797565558163, 2.9161717858729217, 1.9300434845359922, 0.9726624131546141, 1.9388301533369687, 2.9133991330480575, 3.889138637978508, 4.861642066140844, 5.8323030720011575, 6.88498805815118, 7.880369210937413, 8.900566878587085, 9.840532739015142, 9.908978695594664, 8.859779968259394, 7.8819408891735865, 6.818421451687235, 5.887726317987889, 4.96054375566161, 4.030865866088091, 2.9920265812688807, 2.038170953139919, 1.064701410614171, 0.0, 1.0032831934886546, 1.969799925713465, 2.9105337872959316, 3.905127053649482, 4.868963912925708, 5.900757790112262, 6.948625645802236, 7.991160172767646, 8.936600421297685, 10.825927844352034, 9.807852813432357, 8.770420949627447, 7.767903228689014, 6.865273749561733, 5.960387946575964, 4.99258121646632, 4.037505593403293, 2.9763394081217345, 1.945663095732761, 0.9417880922928409, 1.8859831712246595, 2.897357393416976, 3.8819549296554645, 4.858315040964949, 5.801473087239837, 6.860320889060937, 7.925195128372455, 8.921542469666504, 9.93578784663979, 11.698890558471163, 10.758933698862359, 9.787739684143665, 8.776190835887839, 7.831213225349843, 6.927634271567563, 5.969369872295644, 4.925654058147227, 3.956047736347047, 2.9318365642195223, 1.9378643226348733, 2.8313717852791997, 3.842319507400777, 4.866611053943087, 5.797919574127541, 6.850622399555226, 7.874284149712091, 8.817110490086947, 9.821779988007167, 10.7508458165317, 12.629519190451523, 11.756013877259567, 10.813191778936941, 9.785150789010045, 8.864439388385428, 7.9345493486770335, 6.89507689754829, 5.867275615540743, 4.908991547104673, 3.926472853083078, 3.004012421889099, 3.8126797914676995, 4.810834515752546, 5.7490391505276595, 6.771488240095377, 7.791271423792552, 8.73869134311142, 9.722976933666695, 10.678222758712316, 11.687768724777612, 13.56193780284392, 12.692786834973125, 11.712772110286878, 10.74592118306091, 9.790263046801355, 8.841260695627554, 7.776160988640468, 6.840637083805038, 5.9110997967580445, 4.917867932106454, 4.023850708713225, 4.838804655809621, 5.818377801451542, 6.713322408894169, 7.66806306390375, 8.595512949957334, 9.529526761371585, 10.49512302744364, 11.540313469905604, 12.58101992696944, 14.615679738678251, 13.635374607000037, 12.634752705346399, 11.640676511622914, 10.697807180950655, 9.716536172372287, 8.780247048562718, 7.795178610651799, 6.8423935522149515, 5.912555716993743, 5.076705660126165, 5.842475750166832, 6.849818628973483, 7.706092118158523, 8.705325392631186, 9.593868020217107, 10.504016743413755, 11.428420928986366, 12.492868003446139, 13.523501566584338, 14.477786564911487, 14.580182776872206, 13.671589368215049, 12.68007798389848, 11.712771419012785, 10.784405952682967, 9.810644241282377, 8.85135972752312, 7.896415583218612, 6.914133815104204, 6.064640186842265, 6.807636237933085, 7.800157092689886, 8.640880527167461, 9.633252458677543, 10.582996207846321, 11.52455831600853, 12.488905925443454, 13.418238437257653, 14.419648929011988, 13.637672958219067, 14.705973109084928, 14.727723277126671, 13.736530871140594, 12.735786912580568, 11.828231912350294, 10.81263253369541, 9.782731362998064, 8.96245027910929, 7.899709912079843, 7.089974069847616, 7.761855033439835, 8.793247243609692, 9.61155398679384, 10.574100567828784, 11.528725334464136, 12.478101350810782, 13.51246573776336, 14.456984715236477, 14.506907982949947, 12.618753004028902, 13.684789070769522, 14.730534730796926, 14.709467177120843, 13.705778665309742, 12.742435987250053, 11.772301799781623, 10.777502645997808, 9.919712792594677, 8.923110241805588, 8.106666354235877, 8.786341091321699, 9.718465366952245, 10.600038973776199, 11.53748797124789, 12.484419498500896, 13.479774697156918, 14.455881827280026, 14.5793963344282, 13.581550000538755, 11.757077114109173, 12.728641131024299, 13.801627640189825, 14.875083756200429, 14.716508857674606, 13.699761146702889, 12.717570008203802, 11.774670114961673, 10.86687232744288, 9.926100320504636, 9.074560376517907, 9.737774761129492, 10.665779495505408, 11.533278949372054, 12.487466116714527, 13.409501555689047, 14.402520599517093, 14.586349132723628, 13.63167564608028, 12.664616193967996, 10.886646299226467, 11.92478279002921, 12.965419562584902, 13.844392126664614, 14.607877150370086, 13.599127683071302, 12.641749106992624, 11.65672827601852, 10.85585031890793, 10.168821255225122, 10.003835905519614, 10.709443504144458, 11.636283874395547, 12.583945588790227, 13.47297855193823, 14.430676212544867, 14.71486191731749, 13.6544774828462, 12.705029460556396, 11.772232755733217, 9.90637990534935, 10.852473305688111, 11.91448734590051, 12.88572817816454, 13.59126802577767, 12.621422157627224, 11.64064915632511, 10.691639754573572, 9.8801402865569, 9.144711968125938, 9.820974715997723, 10.782838687898963, 11.754765276962921, 12.62181096785804, 13.593301911092915, 14.566590551521912, 14.041766412905558, 13.003309231091686, 11.938248182306705, 10.979765071285227, 10.841249780509997, 11.805681755422214, 12.773637874777934, 13.624756489904051, 12.691805027435317, 11.649718665526326, 10.646469781473732, 9.694703635727533, 8.887828260189169, 8.09389319987058, 8.874431134284276, 9.829935729834, 10.744140532768107, 11.602000131573334, 12.580706019882156, 13.607736019019576, 14.513557722513939, 13.970180105917263, 12.964814462978877, 11.937335924196883, 11.805039225885075, 12.84882566259607, 13.619242460436947, 12.60759014607169, 11.649454743294042, 10.599065048394698, 9.714493645368677, 8.704953644158781, 7.81959929590084, 7.036638650837883, 7.922616803155707, 8.860871525724214, 9.682696111951977, 10.647379926537816, 11.639498351180416, 12.584877429950192, 13.51427102827252, 14.443907338753824, 13.81782105762409, 12.883146629058226, 12.78231392206268, 13.647583912680929, 12.710430599436688, 11.70361080933652, 10.648933653918798, 9.647020609749175, 8.70406743247439, 7.765172125286693, 6.828130852037757, 6.067197761994818, 6.933785356893147, 7.855367831434075, 8.722033306046853, 9.707770173427175, 10.682168831519641, 11.662047580607675, 12.623227186668, 13.586712727705704, 14.509299878244406, 13.556188090631727, 13.718355006155747, 12.708780077915744, 11.679688964667973, 10.706223070089901, 9.631414831688522, 8.753866571920122, 7.751794008829294, 6.810222136808596, 5.900551877434513, 5.110386643451979, 5.987467286141595, 6.785660475217375, 7.793330334752712, 8.745437321511773, 9.699056931731974, 10.688055950656976, 11.689522634571448, 12.66983022708049, 13.684019161794698, 14.507873738168577], [14.598911750701923, 13.610947789918095, 12.699240558761012, 11.639694973976313, 10.700177592378479, 9.659230679981112, 8.678155382263759, 7.712153890591853, 6.692924400343251, 5.754209647691538, 4.82547017316759, 3.868038110408482, 4.873671553826426, 5.800654137352747, 6.733475505730303, 7.6874042810661445, 8.72263190156116, 9.68536038501459, 10.74520643942678, 11.785429181674006, 13.59644842355464, 12.66639198036818, 11.693751400875842, 10.753405590613767, 9.77102337887188, 8.819992792487426, 7.822365721206403, 6.787310497459392, 5.904100131989821, 4.9259418640023, 3.9257941047325975, 2.9331546419819303, 3.8813489899282456, 4.866618930131547, 5.743921444750695, 6.722647657667531, 7.762584125838769, 8.793485879182285, 9.751045333472852, 10.7667798409425, 12.80780496887764, 11.807210337682289, 10.76522833052852, 9.786186947529984, 8.82537015330968, 7.854171218784923, 6.860073713583354, 5.840740982994011, 4.881922746434121, 3.965516801615083, 3.0239635720547637, 1.9867747499511155, 2.895682122478166, 3.828191482250451, 4.76949182696282, 5.778708740324437, 6.842165640590296, 7.853037383215727, 8.792549840397895, 9.807993326746443, 11.901265057491555, 10.855509176396458, 9.828016966595307, 8.775614962153718, 7.846463757434095, 6.876528615752675, 5.920138668389204, 4.890505096364889, 3.906697125681994, 2.9205688243450645, 1.9631877529636865, 0.9355469598483143, 1.910115939559403, 2.885855444489853, 3.858358872652189, 4.8290198785125025, 5.881704864662525, 6.877086017448757, 7.897283685098429, 8.837249545526486, 10.91226188908332, 9.86306316174805, 8.885224082662242, 7.82170464517589, 6.891009511476544, 5.963826949150265, 5.034149059576746, 3.9953097747575352, 3.0414541466285736, 2.0679846041028256, 1.0032831934886546, 0.0, 0.9665167322248105, 1.9072505938072768, 2.9018438601608274, 3.8656807194370533, 4.897474596623606, 5.9453424523135805, 6.98787697927899, 7.93331722780903, 11.82921103784069, 10.811136006921013, 9.773704143116102, 8.771186422177669, 7.868556943050388, 6.963671140064618, 5.995864409954974, 5.040788786891948, 3.979622601610389, 2.948946289221415, 1.9450712857814954, 1.0114228391801112, 1.9315605242778333, 2.9084641461935083, 3.8848242575029923, 4.827982303777881, 5.88683010559898, 6.951704344910499, 7.948051686204548, 8.962297063177834, 12.702173751959819, 11.762216892351015, 10.79102287763232, 9.779474029376493, 8.834496418838498, 7.9309174650562175, 6.972653065784298, 5.928937251635881, 4.959330929835701, 3.9351197577081765, 2.9232083353155858, 1.9568114532346512, 2.8765226382616347, 3.900814184803944, 4.832122704988398, 5.884825530416083, 6.908487280572948, 7.8513136209478045, 8.855983118868025, 9.785048947392557, 13.632802383940179, 12.759297070748223, 11.816474972425597, 10.788433982498699, 9.867722581874084, 8.937832542165687, 7.8983600910369445, 6.870558809029397, 5.912274740593327, 4.92406637944259, 3.91431621564077, 2.9381194594231506, 3.861786003105705, 4.799990637880819, 5.805691370956234, 6.825474554653409, 7.772894473972277, 8.757180064527553, 9.712425889573174, 10.721971855638468, 14.565220996332576, 13.696070028461781, 12.716055303775534, 11.749204376549566, 10.793546240290011, 9.844543889116208, 8.779444182129122, 7.843920277293692, 6.914382990246699, 5.915461458465966, 4.934154502464896, 3.9642443237650724, 4.898715783559932, 5.764273896247328, 6.719014551256909, 7.646464437310492, 8.580478248724743, 9.546074514796798, 10.591264957258762, 11.631971414322598, 14.501333261466126, 14.63865780048869, 13.638035898835053, 12.643959705111568, 11.701090374439309, 10.71981936586094, 9.783530242051372, 8.798461804140453, 7.839987078574464, 6.910149243353255, 5.913905607537852, 4.967915418122283, 5.941660475636585, 6.757043605511682, 7.756276879984346, 8.644819507570265, 9.554968230766914, 10.479372416339524, 11.543819490799297, 12.574453053937496, 13.528738052264645, 14.475485646250998, 14.674872561703705, 13.683361177387134, 12.71605461250144, 11.787689146171621, 10.813927434771031, 9.854642921011774, 8.894009109578125, 7.881782923819605, 6.901840134253952, 5.933075905888536, 6.9255967606453375, 7.691832014520619, 8.684203946030701, 9.633947695199481, 10.575509803361687, 11.53985741279661, 12.469189924610811, 13.470600416365146, 12.688624445572223, 13.755190635115284, 14.733223501091965, 14.739814064629249, 13.739070106069223, 12.831515105838948, 11.815915727184064, 10.786014556486716, 9.9329122700793, 8.867359020795243, 7.880823155816202, 6.887294701395286, 7.918686911565143, 8.662505474146998, 9.625052055181943, 10.579676821817294, 11.529052838163938, 12.563417225116517, 13.507936202589633, 14.441408320498349, 11.652956134889758, 12.718992201630378, 13.764737861657782, 14.69884962608016, 14.709061858798394, 13.745719180738705, 12.775584993270275, 11.78078583948646, 10.846095472197083, 9.8303173178647, 8.897515440204462, 7.91178075927715, 8.843905034907696, 9.650990461129357, 10.588439458601048, 11.535370985854055, 12.530726184510074, 13.506833314633182, 14.441251569466276, 14.58483319402741, 10.79128024497003, 11.762844261885157, 12.83583077105068, 13.909286887061285, 14.556757591268772, 13.53529433239705, 12.581448059117022, 11.679288580225153, 10.880083980714812, 10.833307396563749, 9.791059378502583, 8.863214429084943, 9.791219163460859, 10.584230436725212, 11.538417604067686, 12.460453043042206, 13.453472086870253, 14.451879658876239, 14.634958839568936, 13.667899387456652, 9.88336310573781, 10.921499596540555, 11.962136369096246, 12.841108933175958, 13.604593956881434, 12.59584448958265, 11.638465913503971, 10.653445082529867, 9.852567125419275, 10.828631893519715, 10.72033490750429, 9.834883172099909, 10.761723542350998, 11.634897076143385, 12.523930039291388, 13.481627699898025, 14.38469339786257, 14.657760676334856, 13.708312654045052, 12.775515949221873, 8.903096711860695, 9.849190112199455, 10.911204152411853, 11.882444984675884, 12.587984832289017, 11.618138964138572, 10.637365962836459, 9.68835656108492, 8.876857093068246, 9.80452260642053, 10.559567707926895, 10.815258304958972, 11.81199925175694, 12.679825290999467, 13.490403019694735, 14.41467593189364, 15.045049606394214, 14.006592424580342, 12.94153137579536, 11.983048264773883, 9.837966587021342, 10.802398561933558, 11.770354681289279, 12.621473296415395, 11.68852183394666, 10.646435472037671, 9.643186587985078, 8.691420442238881, 7.884545066700515, 8.753703838165173, 9.613024126213448, 10.603359484488918, 11.577704215931217, 12.448165666224224, 13.426871554533045, 14.453901553670466, 15.359723257164829, 14.97346329940592, 13.968097656467533, 12.94061911768554, 10.801756032396419, 11.845542469107414, 12.615959266948291, 11.604306952583034, 10.646171549805386, 9.595781854906045, 8.711210451880023, 7.701670450670128, 6.816316102412186, 7.696449289132476, 8.66120979508488, 9.660803799341004, 10.528861646602866, 11.493545461188706, 12.485663885831306, 13.431042964601081, 14.36043656292341, 15.290072873404714, 14.815051061504391, 13.880376632938527, 11.779030728574025, 12.644300719192273, 11.707147405948032, 10.700327615847865, 9.645650460430142, 8.643737416260523, 7.7007842389857375, 6.761888931798039, 5.8248476585491025, 6.72700840028941, 7.6723783488223205, 8.655300105050864, 9.568198840697743, 10.553935708078065, 11.57370745749901, 12.553586206587044, 13.514765812647369, 14.478251353685073, 15.42727644897504, 14.5467134304408, 12.715071812667091, 11.70549688442709, 10.676405771179319, 9.702939876601246, 8.628131638199866, 7.750583378431468, 6.748510815340639, 5.806938943319941, 4.897268683945859, 5.770197281746571, 6.726060278070769, 7.6252461340333095, 8.6394958694036, 9.636975947491141, 10.590595557711342, 11.579594576636344, 12.594637313220199, 13.574944905729241, 14.589133840443449, 15.49839907797765], [15.565428482926734, 14.577464522142906, 13.665757290985823, 12.606211706201124, 11.66669432460329, 10.625747412205923, 9.64467211448857, 8.678670622816664, 7.659441132568061, 6.720726379916348, 5.7919869053924, 4.834554842633293, 3.9593171992360254, 4.834137405127936, 5.766958773505492, 6.7208875488413335, 7.756115169336349, 8.71884365278978, 9.77868970720197, 10.818912449449195, 14.562965155779452, 13.632908712592991, 12.660268133100653, 11.719922322838578, 10.73754011109669, 9.786509524712239, 8.788882453431214, 7.753827229684203, 6.870616864214632, 5.89245859622711, 4.8923108369574075, 3.899671374206741, 2.9669946353378442, 3.9001021979067363, 4.777404712525884, 5.75613092544272, 6.796067393613958, 7.826969146957475, 8.784528601248041, 9.800263108717688, 13.774321701102451, 12.7737270699071, 11.731745062753332, 10.752703679754795, 9.791886885534492, 8.820687951009734, 7.826590445808165, 6.807257715218822, 5.848439478658932, 4.932033533839894, 3.9904803042795747, 2.953291482175926, 1.9291653902533556, 2.8616747500256405, 3.80297509473801, 4.812192008099627, 5.875648908365486, 6.886520650990918, 7.8260331081730845, 8.841476594521634, 12.867781789716364, 11.822025908621267, 10.794533698820118, 9.742131694378529, 8.812980489658905, 7.843045347977486, 6.886655400614015, 5.8570218285896996, 4.873213857906805, 3.887085556569875, 2.929704485188497, 1.9020636920731246, 0.9435992073345923, 1.9193387122650427, 2.8918421404273786, 3.8625031462876924, 4.915188132437715, 5.910569285223948, 6.93076695287362, 7.870732813301677, 11.878778621308129, 10.82957989397286, 9.851740814887052, 8.7882213774007, 7.857526243701353, 6.930343681375074, 6.000665791801556, 4.961826506982345, 4.007970878853384, 3.034501336327636, 1.969799925713465, 0.9665167322248105, 0.0, 0.9407338615824663, 1.935327127936017, 2.899163987212243, 3.930957864398797, 4.978825720088771, 6.021360247054181, 6.966800495584221, 12.795727770065499, 11.777652739145822, 10.740220875340912, 9.737703154402478, 8.835073675275197, 7.9301878722894275, 6.962381142179783, 6.007305519116759, 4.9461393338352, 3.915463021446226, 2.911588018006306, 1.9764180142453394, 0.9650437920530229, 1.941947413968698, 2.9183075252781823, 3.8614655715530706, 4.920313373374171, 5.9851876126856896, 6.981534953979739, 7.995780330953025, 13.668690484184628, 12.728733624575824, 11.75753960985713, 10.745990761601302, 9.801013151063307, 8.897434197281026, 7.939169798009107, 6.895453983860692, 5.925847662060512, 4.901636489932987, 3.888203510380814, 2.9218066282998794, 1.9100059060368242, 2.934297452579134, 3.8656059727635883, 4.918308798191273, 5.941970548348138, 6.884796888722994, 7.889466386643214, 8.818532215167746, 14.599319116164988, 13.725813802973033, 12.782991704650406, 11.754950714723508, 10.834239314098891, 9.9043492743905, 8.864876823261756, 7.837075541254208, 6.878791472818138, 5.879370915185181, 4.86962075138336, 3.8934239951657412, 2.8952692708808945, 3.833473905656008, 4.839174638731424, 5.858957822428599, 6.806377741747467, 7.790663332302743, 8.745909157348365, 9.755455123413661, 14.474664966784266, 14.662586760686589, 13.68257203600034, 12.715721108774373, 11.760062972514818, 10.811060621341017, 9.745960914353931, 8.810437009518502, 7.88089972247151, 6.870765994208557, 5.8894590382074865, 4.911772196977043, 3.9321990513351217, 4.797757164022517, 5.752497819032098, 6.679947705085681, 7.613961516499933, 8.579557782571987, 9.62474822503395, 10.665454682097787, 13.534816529241315, 14.453777083898357, 14.604552631059862, 13.610476437336377, 12.667607106664118, 11.68633609808575, 10.75004697427618, 9.764978536365263, 8.795291614317055, 7.865453779095846, 6.861433480749821, 5.9154432913342525, 4.975143743411775, 5.790526873286871, 6.789760147759535, 7.678302775345454, 8.588451498542105, 9.512855684114713, 10.577302758574486, 11.607936321712685, 12.562221320039834, 13.508968914026187, 14.530071477174275, 14.649877909611943, 13.682571344726249, 12.75420587839643, 11.78044416699584, 10.821159653236583, 9.849313645320716, 8.829310797031575, 7.849368007465921, 6.880603779100506, 6.021273177610924, 6.725315282295808, 7.71768721380589, 8.66743096297467, 9.60899307113688, 10.5733406805718, 11.502673192386, 12.504083684140335, 11.722107713347413, 12.788673902890476, 13.766706768867158, 14.7052691998356, 14.705586838294032, 13.798031838063757, 12.782432459408874, 11.752531288711527, 10.880440143291269, 9.814886894007213, 8.828351029028171, 7.834822574607255, 7.0292718633967075, 7.6959887419221875, 8.658535322957132, 9.613160089592483, 10.562536105939131, 11.59690049289171, 12.541419470364822, 13.474891588273538, 10.68643940266495, 11.75247546940557, 12.798221129432974, 13.732332893855352, 14.55073941050808, 13.58739673244839, 12.621493508137705, 11.77123328978752, 11.793623345409053, 10.77784519107667, 9.845043313416431, 8.85930863248912, 7.954489986739261, 8.684473728904546, 9.621922726376237, 10.568854253629244, 11.564209452285267, 12.540316582408375, 13.474734837241469, 14.40024957068473, 9.82476351274522, 10.796327529660346, 11.86931403882587, 12.942770154836474, 13.651534831867275, 12.630071572995554, 11.676225299715526, 10.774065820823656, 11.723300924838831, 11.780835269775718, 10.738587251714552, 9.810742302296912, 8.901804115292423, 9.617713704500401, 10.571900871842875, 11.493936310817395, 12.486955354645442, 13.485362926651431, 14.47803223288345, 14.634416119681461, 8.916846373513001, 9.954982864315745, 10.995619636871437, 11.874592200951149, 12.699371197479937, 11.690621730181153, 10.733243154102475, 9.74822232312837, 10.712975334940989, 11.753736546703067, 11.66786278071626, 10.782411045311878, 9.872308494182562, 10.668380343918574, 11.557413307066577, 12.515110967673214, 13.418176665637759, 14.417234576528859, 14.674829386269861, 13.742032681446682, 7.936579979635885, 8.882673379974646, 9.944687420187044, 10.915928252451074, 11.68276207288752, 10.712916204737075, 9.732143203434962, 8.783133801683423, 9.814833752687742, 10.771039338645341, 11.526084440151704, 11.762786178170941, 10.922584203588503, 11.713308558774656, 12.523886287469924, 13.44815919966883, 14.432464645051404, 14.973109156805151, 13.90804810802017, 12.949564996998692, 8.871449854796532, 9.835881829708748, 10.80383794906447, 11.654956564190584, 10.72200510172185, 9.726236680262923, 8.737963828583583, 7.786197682837386, 8.82252172632001, 9.720220570389984, 10.579540858438257, 11.569876216713727, 11.933208947783317, 12.733119395059363, 13.536482178680684, 14.407013732171166, 15.418511641820116, 15.939980031630729, 14.934614388692342, 13.907135849910349, 9.835239300171612, 10.879025736882607, 11.64944253472348, 10.637790220358223, 9.679654817580575, 8.673666817618015, 7.805987692478528, 6.796447691268633, 7.782832834636997, 8.662966021357287, 9.627726527309688, 10.627320531565811, 11.495378378827677, 12.460062193413517, 13.452180618056117, 14.397559696825892, 15.32695329514822, 16.256589605629525, 15.781567793729202, 14.846893365163337, 10.812513996349217, 11.677783986967462, 10.74063067372322, 9.733810883623054, 8.679133728205331, 7.7216223789724925, 6.795561479584243, 5.856666172396544, 6.791364390773913, 7.69352513251422, 8.63889508104713, 9.621816837275674, 10.534715572922554, 11.520452440302876, 12.540224189723821, 13.520102938811855, 14.48128254487218, 15.444768085909883, 16.39379318119985, 15.51323016266561, 11.748555080442284, 10.738980152202279, 9.709889038954508, 8.736423144376435, 7.661614905975055, 6.784066646206657, 5.781994083115828, 4.89258458872954, 5.8637854161706695, 6.7367140139713815, 7.692577010295579, 8.59176286625812, 9.60601260162841, 10.603492679715952, 11.557112289936153, 12.546111308861155, 13.56115404544501, 14.541461637954052, 15.55565057266826, 16.46491581020246], [16.5061623445092, 15.518198383725371, 14.606491152568289, 13.54694556778359, 12.607428186185755, 11.566481273788389, 10.585405976071035, 9.61940448439913, 8.600174994150528, 7.661460241498815, 6.732720766974866, 5.775288704215759, 4.900051060818491, 3.8993727745817193, 4.832194142959276, 5.786122918295117, 6.821350538790133, 7.784079022243564, 8.843925076655754, 9.878178587866728, 15.503699017361917, 14.573642574175457, 13.601001994683118, 12.660656184421043, 11.678273972679156, 10.727243386294704, 9.72961631501368, 8.694561091266669, 7.811350725797098, 6.833192457809576, 5.833044698539874, 4.840405235789207, 3.90772849692031, 2.9653375673605193, 3.8426400819796673, 4.821366294896504, 5.861302763067743, 6.889844566094774, 7.843794739665575, 8.859529247135221, 14.71505556268492, 13.714460931489569, 12.6724789243358, 11.693437541337262, 10.732620747116957, 9.7614218125922, 8.76732430739063, 7.7479915768012875, 6.789173340241398, 5.872767395422359, 4.931214165862041, 3.8940253437583925, 2.8698992518358217, 1.9269101194794236, 2.868210464191793, 3.87742737755341, 4.9408842778192685, 5.9457867894084515, 6.885299246590618, 7.900742732939168, 13.808515651298832, 12.762759770203735, 11.735267560402587, 10.682865555960996, 9.753714351241372, 8.783779209559953, 7.827389262196481, 6.797755690172165, 5.813947719489271, 4.827819418152341, 3.8704383467709635, 2.842797553655591, 1.8843330689170585, 0.9845740817188258, 1.9570775098811617, 2.927738515741475, 3.9804235018914973, 4.969835423641482, 5.990033091291155, 6.929998951719211, 12.819512482890596, 11.770313755555327, 10.792474676469519, 9.728955238983167, 8.79826010528382, 7.871077542957542, 6.941399653384023, 5.902560368564812, 4.948704740435851, 3.9752351979101026, 2.9105337872959316, 1.9072505938072768, 0.9407338615824663, 0.0, 0.9945932663535505, 1.9584301256297767, 2.9902240028163303, 4.038091858506305, 5.080626385471715, 6.026066634001754, 13.736461631647966, 12.718386600728289, 11.680954736923379, 10.678437015984946, 9.775807536857664, 8.870921733871896, 7.903115003762251, 6.948039380699225, 5.886873195417666, 4.856196883028693, 3.8523218795887724, 2.917151875827806, 1.9057776536354893, 1.0012135523862318, 1.977573663695716, 2.9207317099706045, 3.9795795117917043, 5.044453751103223, 6.040801092397272, 7.055046469370558, 14.609424345767096, 13.669467486158291, 12.698273471439597, 11.68672462318377, 10.741747012645774, 9.838168058863495, 8.879903659591575, 7.836187845443159, 6.866581523642979, 5.842370351515454, 4.82893737196328, 3.862540489882346, 2.8507397676192907, 2.0574584888039915, 2.9561540225785143, 3.9912438836154114, 5.014905633772276, 5.957731974147132, 6.962401472067352, 7.891467300591884, 14.523997234710684, 14.6665476645555, 13.723725566232874, 12.695684576305975, 11.77497317568136, 10.845083135972965, 9.805610684844222, 8.777809402836674, 7.819525334400605, 6.820104776767647, 5.810354612965827, 4.834157856748208, 3.836003132463361, 3.0836980179571025, 3.92972268854635, 4.949505872243526, 5.896925791562394, 6.8812113821176695, 7.836457207163291, 8.846003173228587, 13.646381820722988, 14.684073253208426, 14.62330589758281, 13.656454970356842, 12.700796834097288, 11.751794482923483, 10.686694775936397, 9.751170871100967, 8.821633584053977, 7.811499855791023, 6.830192899789953, 5.852506058559509, 4.872932912917588, 4.047981276323612, 4.92421467297082, 5.851664559024403, 6.785678370438656, 7.7512746365107095, 8.796465078972673, 9.814043901027297, 12.706533383180037, 13.62549393783708, 14.626115839490717, 14.551210298918843, 13.608340968246583, 12.627069959668216, 11.690780835858646, 10.705712397947728, 9.73602547589952, 8.806187640678312, 7.802167342332289, 6.85617715291672, 5.915877604994241, 5.040750985587966, 5.961477001698256, 6.850019629284176, 7.760168352480827, 8.684572538053436, 9.749019612513209, 10.779653175651408, 11.733938173978556, 12.68068576796491, 13.701788331112997, 14.731865457573917, 14.623305206308714, 13.694939739978896, 12.721178028578306, 11.761893514819048, 10.790047506903182, 9.770044658614042, 8.790101869048389, 7.821337640682973, 6.96200703919339, 5.975539394596903, 6.967911326106984, 7.917655075275763, 8.780709925075602, 9.745057534510522, 10.674390046324723, 11.675800538079057, 10.843302503113442, 11.879221952705402, 12.857254818682085, 13.795817249650527, 14.664139364998972, 13.679397749269855, 12.814609117198463, 12.693265150293993, 11.821174004873736, 10.75562075558968, 9.769084890610639, 8.775556436189722, 7.954205612430954, 6.946212854223282, 7.908759435258227, 8.863384201893577, 9.734252959877853, 10.768617346830432, 11.713136324303544, 12.64660844221226, 9.776987452479876, 10.843023519220496, 11.888769179247902, 12.82288094367028, 13.69251253464642, 12.729169856586731, 11.763266632276046, 12.711967151369986, 12.73435720699152, 11.718579052659138, 10.785777174998898, 9.800042494071587, 8.879423735773507, 7.934697841205641, 8.872146838677331, 9.819078365930338, 10.73592630622399, 11.712033436347097, 12.646451691180191, 13.571966424623453, 8.897698598169358, 9.869262615084484, 10.942249124250008, 12.00535197459298, 12.793307956005616, 11.771844697133895, 10.817998423853867, 11.714799682406122, 12.664034786421297, 12.721569131358185, 11.67932111329702, 10.75147616387938, 9.82673786432667, 8.867937816801495, 9.822124984143969, 10.744160423118489, 11.682684679216075, 12.657079780590154, 13.649749086822172, 14.526450473771641, 7.976112511930536, 9.01424900273328, 10.054885775288971, 10.933858339368681, 11.831618023767438, 10.832394854319494, 9.875016278240816, 10.688956184710836, 11.653709196523454, 12.694470408285532, 12.608596642298727, 11.723144906894346, 10.79724224321681, 9.918604456219668, 10.807637419367671, 11.765335079974308, 12.613905990208393, 13.588951430467581, 14.538399452757385, 14.68276654302915, 6.995846118053419, 7.9419395183921795, 9.003953558604577, 9.975194390868607, 10.815008899175021, 9.845163031024576, 8.873916327573303, 9.723867663265889, 10.755567614270207, 11.711773200227807, 12.466818301734172, 12.703520039753409, 11.847517952622752, 10.96353267107575, 11.774110399771018, 12.698383311969923, 13.628193969622037, 14.603574928638414, 14.848781969602637, 13.89029885858116, 7.930715993214067, 8.895147968126283, 9.863104087482004, 10.720191933644369, 9.787240471175634, 8.791472049716706, 7.859431501585594, 8.726931544419852, 9.763255587902476, 10.66095443197245, 11.520274720020725, 12.510610078296194, 12.858142696817566, 11.983343507360457, 12.786706290981778, 13.65723784447226, 14.663799861831167, 15.60093849021786, 15.87534825027481, 14.847869711492816, 8.894505438589146, 9.938291875300141, 10.714677904177265, 9.703025589812007, 8.74489018703436, 7.7389021870717984, 6.927455365480539, 7.737181552851099, 8.723566696219462, 9.603699882939752, 10.568460388892156, 11.56805439314828, 12.436112240410143, 12.937963712395975, 13.727913959683518, 14.673293038453293, 15.602686636775621, 16.532322947256926, 16.72230165531167, 15.787627226745807, 9.871780134766752, 10.743019356421245, 9.805866043177003, 8.799046253076837, 7.744369097659114, 6.786857748426276, 5.906459134916326, 6.7974000339790095, 7.732098252356379, 8.634258994096687, 9.579628942629597, 10.562550698858141, 11.47544943450502, 12.461186301885341, 13.480958051306287, 14.46083680039432, 15.422016406454645, 16.38550194749235, 17.334527042782316, 16.453964024248076, 10.807821218859818, 9.804215521656063, 8.775124408408292, 7.801658513830218, 6.726850275428839, 5.849302015660441, 4.847229452569612, 5.833318450312006, 6.804519277753135, 7.677447875553848, 8.633310871878045, 9.532496727840588, 10.546746463210876, 11.544226541298418, 12.497846151518619, 13.48684517044362, 14.501887907027475, 15.482195499536518, 16.496384434250725, 17.405649671784925], [17.50075561086275, 16.51279165007892, 15.60108441892184, 14.54153883413714, 13.602021452539306, 12.56107454014194, 11.579999242424586, 10.61399775075268, 9.594768260504077, 8.656053507852365, 7.727314033328416, 6.769881970569309, 5.894644327172042, 4.893966040935269, 4.067100846584356, 4.958696180143756, 5.933027031727855, 6.875703723447133, 7.876821179557687, 8.883585321513179, 16.498292283715468, 15.568235840529008, 14.595595261036669, 13.655249450774594, 12.672867239032707, 11.721836652648255, 10.72420958136723, 9.68915435762022, 8.805943992150649, 7.827785724163126, 6.827637964893424, 5.834998502142757, 4.902321763273861, 3.9599308337140697, 3.0588446865530297, 3.993939556745142, 4.9729792560054635, 5.895251299741223, 6.849201473312024, 7.864935980781671, 15.709648829038471, 14.70905419784312, 13.667072190689352, 12.688030807690813, 11.727214013470508, 10.756015078945751, 9.761917573744181, 8.74258484315484, 7.7837666065949485, 6.86736066177591, 5.925807432215591, 4.888618610111942, 3.8644925181893726, 2.921503385832974, 2.0844150687651553, 2.9635127861763797, 4.0019297092416375, 4.951193523054901, 5.890705980237067, 6.906149466585617, 14.803108917652382, 13.757353036557285, 12.729860826756138, 11.677458822314547, 10.748307617594923, 9.778372475913503, 8.821982528550032, 7.792348956525716, 6.808540985842821, 5.822412684505892, 4.865031613124514, 3.8373908200091416, 2.8789263352706094, 1.9791673480723762, 1.0493741969910015, 2.013823924364445, 2.991115101129438, 3.975242157287931, 4.995439824937604, 5.9354056853656605, 13.814105749244147, 12.764907021908877, 11.78706794282307, 10.723548505336717, 9.79285337163737, 8.865670809311093, 7.935992919737574, 6.897153634918363, 5.9432980067894015, 4.969828464263653, 3.905127053649482, 2.9018438601608274, 1.935327127936017, 0.9945932663535505, 0.0, 0.9638368592762261, 1.9956307364627797, 3.043498592152754, 4.086033119118164, 5.0314733676482035, 14.731054898001517, 13.71297986708184, 12.67554800327693, 11.673030282338496, 10.770400803211215, 9.865515000225447, 8.897708270115801, 7.9426326470527755, 6.8814664617712165, 5.850790149382243, 4.846915145942323, 3.9117451421813563, 2.9003709199890397, 1.9958068187397822, 1.0204041587130401, 1.9635622049879287, 3.0224100068090287, 4.079513030998987, 5.075860372293036, 6.089030104281133, 14.497456361708368, 14.664060752511842, 13.692866737793148, 12.68131788953732, 11.736340278999325, 10.832761325217046, 9.874496925945126, 8.83078111179671, 7.86117478999653, 6.836963617869005, 5.82353063831683, 4.857133756235896, 3.845333033972841, 2.9302930377802925, 1.9989845175958383, 3.0340743786327353, 4.0577361287896005, 5.000562469164457, 6.005231967084677, 6.93429779560921, 13.566827729728008, 14.639949596042062, 14.718318832586425, 13.690277842659526, 12.769566442034911, 11.839676402326516, 10.800203951197773, 9.772402669190225, 8.814118600754155, 7.814698043121198, 6.804947879319378, 5.828751123101759, 4.830596398816912, 3.9565325669334035, 2.972553183563674, 3.992336367260849, 4.939756286579717, 5.924041877134993, 6.879287702180615, 7.88883366824591, 12.689212315740312, 13.72690374822575, 14.616408826298926, 14.651048236710393, 13.695390100450838, 12.746387749277034, 11.681288042289948, 10.745764137454518, 9.816226850407526, 8.806093122144574, 7.824786166143504, 6.826889749464269, 5.847316603822348, 4.920815825299913, 3.9670451679881436, 4.894495054041727, 5.828508865455979, 6.794105131528033, 7.839295573989996, 8.85687439604462, 11.74936387819736, 12.668324432854403, 13.66894633450804, 14.663022528231526, 14.602934234600134, 13.621663226021766, 12.685374102212197, 11.700305664301279, 10.730618742253071, 9.800780907031863, 8.776551033237046, 7.830560843821479, 6.890261295899001, 5.913585534564267, 5.00430749671558, 5.8928501243015, 6.80299884749815, 7.727403033070759, 8.791850107530532, 9.822483670668731, 10.77676866899588, 11.723516262982233, 12.74461882613032, 13.774695952591241, 14.80073579055805, 13.978805054196116, 13.715771294931857, 12.7564867811726, 11.784640773256733, 10.7444283495188, 9.764485559953147, 8.795721331587732, 7.912110056031063, 6.848373943573204, 6.040998665754257, 6.962452356287351, 7.823540420092924, 8.787888029527846, 9.717220541342046, 10.718631033096381, 9.886132998130766, 10.922052447722725, 11.900085313699408, 12.83864774466785, 13.858268809585597, 12.924919149163703, 13.809202383552014, 13.687858416647543, 12.795557695778495, 11.730004446494439, 10.743468581515398, 9.749940127094481, 8.827040161407256, 7.819047403199583, 7.08177525351279, 7.983509058426694, 8.777083454895177, 9.811447841847755, 10.755966819320868, 11.689438937229584, 8.8198179474972, 9.88585401423782, 10.931599674265225, 11.865711438687603, 12.886641979233046, 11.974691256480579, 12.757859898629597, 13.706560417723537, 13.704497286772488, 12.688719132440106, 11.755917254779867, 10.716217552548752, 9.752258284749809, 8.807532390181942, 8.045162656931895, 8.939203222463455, 9.778756801241313, 10.75486393136442, 11.689282186197515, 12.614796919640776, 7.940529093186683, 8.912093110101809, 9.985079619267335, 11.010758708239429, 11.875911786868182, 11.017366097027743, 11.812591690207418, 12.709392948759673, 13.658628052774848, 13.64589801306471, 12.595496171774185, 11.667651222356545, 10.699572413302972, 9.740772365777797, 9.000742929960596, 9.864285279651606, 10.725515174233399, 11.699910275607477, 12.692579581839496, 13.569280968788965, 6.981519245576985, 8.019655736379729, 9.06029250893542, 9.93926507301513, 10.906176801877079, 10.077916254213342, 10.869609544594367, 11.683549451064387, 12.648302462877005, 13.689063674639083, 13.524771700775892, 12.629022264986343, 11.670076792193111, 10.79143900519597, 9.986255365184299, 10.917728819090975, 11.656736485225716, 12.631781925484905, 13.581229947774709, 14.514026652597888, 6.001252851699868, 6.947346252038629, 8.009360292251026, 8.980601124515056, 9.997244551780318, 9.080069734649657, 9.868509593926854, 10.71846092961944, 11.750160880623756, 12.706366466581358, 13.46141156808772, 13.609397397845406, 12.720352501599052, 11.836367220052052, 10.952728345587646, 11.85077705108659, 12.67102446463936, 13.646405423655738, 14.543662080397635, 14.88489212493471, 6.936122726860516, 7.900554701772732, 8.868510821128453, 9.823853738739208, 8.959813733024273, 8.026378753341787, 8.854024767939144, 9.721524810773401, 10.757848854256025, 11.655547698326, 12.514867986374274, 13.505203344649743, 13.730977245793866, 12.85617805633676, 11.965324236798406, 12.809631583588926, 13.70663035684849, 14.643768985235184, 15.607025305709769, 15.842462977846367, 7.899912172235594, 8.943698608946589, 9.798312294533217, 8.875598851660646, 7.917463448882998, 6.973808890696879, 7.922048631834089, 8.731774819204649, 9.718159962573015, 10.598293149293303, 11.563053655245705, 12.562647659501827, 13.430705506763694, 13.810798261372277, 12.906531905500145, 13.85191098426992, 14.70591705108991, 15.635553361571215, 16.624598595898224, 16.78222049309936, 8.8771868684132, 9.820391755490492, 8.909714875500988, 7.971619514925475, 6.916942359507753, 6.0217644520513565, 6.901052401269876, 7.79199330033256, 8.72669151870993, 9.628852260450238, 10.574222208983146, 11.55714396521169, 12.47004270085857, 13.455779568238892, 13.917389266689911, 14.785092565415395, 15.646581968190583, 16.610067509228287, 17.559092604518252, 17.448557290601627, 9.813227952506265, 8.873001247553159, 7.866749109611861, 6.940055295154375, 5.899423537277477, 5.084208719285521, 5.8418227189231615, 6.8279117166655565, 7.799112544106686, 8.672041141907398, 9.627904138231594, 10.527089994194137, 11.541339729564427, 12.538819807651969, 13.49243941787217, 14.481438436797172, 15.496481173381026, 16.476788765890067, 17.490977700604272, 18.400242938138476], [18.464592470138975, 17.476628509355148, 16.564921278198067, 15.505375693413367, 14.565858311815532, 13.524911399418164, 12.54383610170081, 11.577834610028905, 10.558605119780303, 9.61989036712859, 8.691150892604643, 7.733718829845536, 6.858481186448268, 5.857802900211496, 4.986541613319862, 3.994859320867529, 4.969190172451629, 5.911866864170906, 6.912984320281461, 7.919748462236953, 17.462129142991692, 16.532072699805234, 15.559432120312895, 14.61908631005082, 13.636704098308932, 12.685673511924481, 11.688046440643456, 10.652991216896448, 9.769780851426876, 8.791622583439352, 7.791474824169651, 6.798835361418984, 5.866158622550087, 4.923767692990296, 4.008828910385752, 3.030102697468916, 4.009142396729238, 4.931414440464996, 5.885364614035798, 6.901099121505445, 16.673485688314695, 15.672891057119344, 14.630909049965576, 13.65186766696704, 12.691050872746734, 11.719851938221977, 10.725754433020407, 9.706421702431067, 8.747603465871176, 7.831197521052137, 6.889644291491818, 5.852455469388169, 4.828329377465598, 3.8853402451092003, 3.0475019042148093, 1.9996759269001536, 3.0380928499654116, 3.9873566637786744, 4.926869120960841, 5.9423126073093915, 15.76694577692861, 14.721189895833513, 13.693697686032362, 12.641295681590773, 11.71214447687115, 10.74220933518973, 9.785819387826258, 8.756185815801942, 7.772377845119048, 6.786249543782119, 5.828868472400741, 4.801227679285368, 3.8427631945468357, 2.9430042073486025, 2.0132110562672274, 1.049987065088219, 2.027278241853212, 3.011405298011705, 4.031602965661378, 4.971568826089435, 14.777942608520375, 13.728743881185105, 12.750904802099297, 11.687385364612945, 10.756690230913598, 9.829507668587318, 8.8998297790138, 7.8609904941945885, 6.907134866065627, 5.933665323539879, 4.868963912925708, 3.8656807194370537, 2.899163987212243, 1.9584301256297767, 0.9638368592762261, 0.0, 1.0317938771865536, 2.079661732876528, 3.122196259841938, 4.067636508371978, 14.734059425392022, 14.676816726358068, 13.639384862553158, 12.636867141614724, 11.734237662487443, 10.829351859501672, 9.861545129392027, 8.906469506329001, 7.845303321047442, 6.814627008658469, 5.810752005218549, 4.875582001457582, 3.864207779265266, 2.9596436780160085, 1.9842410179892662, 1.0498244753607595, 2.073196330030828, 3.115676171722761, 4.11202351301681, 5.125193245004907, 13.695933645928141, 14.635890505536945, 14.656703597069376, 13.645154748813548, 12.700177138275553, 11.796598184493272, 10.838333785221351, 9.794617971072936, 8.825011649272756, 7.800800477145231, 6.787367497593056, 5.820970615512122, 4.809169893249067, 3.894129897056519, 2.9628213768720646, 2.1203366490055666, 3.143998399162432, 4.086824739537288, 5.091494237457509, 6.020560065982041, 12.765305013947781, 13.82977027736388, 14.733251604561332, 14.654114701935754, 13.733403301311139, 12.803513261602744, 11.764040810474, 10.736239528466452, 9.777955460030382, 8.778534902397423, 7.7687847385956035, 6.7925879823779844, 5.794433258093138, 4.92036942620963, 3.9363900428399003, 3.1904190249266127, 4.110711682465901, 5.0949972730211766, 6.041110147104744, 7.009212984767055, 11.887689599960085, 12.8756837296097, 13.765188807682875, 14.732039734908843, 14.659226959727066, 13.710224608553261, 12.645124901566176, 11.709600996730746, 10.780063709683754, 9.769929981420798, 8.78862302541973, 7.790726608740496, 6.811153463098575, 5.88465268457614, 4.93088202726437, 4.168222915454678, 5.102236726868931, 6.067832992940985, 7.103714977958519, 7.977253712565766, 10.935471918736498, 11.817104414238353, 12.81772631589199, 13.811802509615475, 14.754671840287735, 14.585500085297994, 13.649210961488425, 12.664142523577507, 11.694455601529295, 10.764617766308087, 9.740387892513274, 8.794397703097706, 7.854098155175228, 6.877422393840494, 5.968144355991806, 5.1665779857144525, 6.076726708911101, 7.001130894483711, 8.056269511499053, 8.97126365205268, 9.92554865037983, 10.872296244366183, 11.89339880751427, 12.92347593397519, 13.917447443877155, 14.845812910206973, 14.679608154208085, 13.720323640448827, 12.748477632532957, 11.708265208795028, 10.728322419229375, 9.75955819086396, 8.875946915307289, 7.812210802849431, 7.004835525030483, 6.236180217700303, 7.097268281505875, 8.061615890940798, 8.981639945310567, 9.917108317316154, 9.00651231465191, 10.042431764243869, 10.995433568602735, 11.933995999571177, 12.894431950309372, 13.810031958856475, 14.75798042130105, 14.651695275923771, 13.759394555054723, 12.693841305770666, 11.707305440791625, 10.713776986370709, 9.790877020683482, 8.78288426247581, 8.045612112789016, 7.257236919839647, 8.050811316308128, 9.085175703260706, 10.020386223289389, 10.887916221449357, 7.940197264018344, 9.006233330758963, 10.026947929168552, 10.96105969359093, 11.92280511995682, 12.859804066173352, 13.706637936378634, 14.670397276999761, 14.668334146048714, 13.652555991716332, 12.719754114056093, 11.680054411824978, 10.716095144026035, 9.771369249458168, 9.008999516208121, 8.212931083876407, 9.052484662654264, 10.028591792777371, 10.963010047610465, 11.81327420386055, 6.997238768387206, 7.968802785302332, 9.041789294467858, 10.046921848963203, 10.912074927591956, 11.902478906720516, 12.761369727956454, 13.673229808035897, 14.622464912051072, 14.609734872340935, 13.55933303105041, 12.63148808163277, 11.663409272579198, 10.704609225054023, 9.964579789236822, 9.138013141064558, 9.99924303564635, 10.973638137020428, 11.966307443252447, 12.767758253008738, 6.017682386300759, 7.055818877103503, 8.096455649659195, 8.975428213738905, 9.942339942600853, 10.963029063906115, 11.818387582343403, 12.647386310340611, 13.61213932215323, 14.652900533915307, 14.488608560052118, 13.592859124262569, 12.633913651469337, 11.755275864472196, 10.950092224460525, 10.191456680503928, 10.930464346638667, 11.905509786897856, 12.85495780918766, 13.787754514010839, 5.037415992423642, 5.983509392762403, 7.045523432974801, 8.01676426523883, 9.03340769250409, 9.96518254434243, 10.81728763167589, 11.682297788895664, 12.713997739899982, 13.670203325857582, 14.425248427363947, 14.573234257121632, 13.68418936087528, 12.800204079328278, 11.916565204863872, 11.124504912499543, 11.944752326052312, 12.920133285068689, 13.817389941810585, 14.775873052832063, 5.97228586758429, 6.936717842496506, 7.904673961852226, 8.86001687946298, 7.995976873748045, 8.91149156303456, 9.80280280568818, 10.685361670049627, 11.721685713532251, 12.619384557602224, 13.4787048456505, 14.46904020392597, 14.694814105070094, 13.820014915612985, 12.929161096074631, 12.083359445001879, 12.980358218261442, 13.917496846648135, 14.88075316712272, 15.814266397727295, 6.936075312959368, 7.979861749670363, 8.83447543525699, 7.9117619923844185, 6.95362658960677, 7.858921700389651, 8.870826669583126, 9.695611678480875, 10.681996821849241, 11.562130008569527, 12.52689051452193, 13.526484518778055, 14.394542366039918, 14.774635120648503, 13.870368764776371, 13.133800144864352, 13.979644912502861, 14.909281222984166, 15.898326457311173, 16.827825558663275, 7.913350009136974, 8.856554896214266, 7.945878016224762, 7.007782655649248, 5.953105500231526, 6.906877261744128, 7.849830439018913, 8.755830159608786, 9.690528377986157, 10.592689119726462, 11.538059068259372, 12.520980824487916, 13.433879560134795, 14.419616427515116, 14.881226125966137, 14.066981726009827, 14.920309829603534, 15.883795370641238, 16.832820465931203, 17.78593225354388, 8.849391093230041, 7.909164388276933, 6.902912250335635, 5.976218435878149, 4.9355866780012505, 5.969321528978293, 6.805659578199388, 7.791748575941782, 8.762949403382912, 9.635878001183624, 10.59174099750782, 11.490926853470363, 12.505176588840651, 13.502656666928193, 14.456276277148394, 15.040973355960526, 15.956628151212213, 16.920161499441235, 17.80465850067882, 18.73761790108073], [18.744031042671345, 17.8765073690034, 16.948283035401086, 16.00235160671044, 15.597652189002085, 14.556705276604719, 13.575629978887365, 12.60962848721546, 11.590398996966856, 10.651684244315144, 9.722944769791196, 8.765512707032089, 7.890275063634821, 6.88069254248505, 5.973723903564869, 4.982041611112535, 3.937396295265075, 4.880072986984353, 5.881190443094908, 6.8879545850504, 17.741567715524063, 17.563866576991785, 16.591225997499446, 15.650880187237373, 14.668497975495486, 13.717467389111034, 12.719840317830009, 11.684785094082999, 10.801574728613428, 9.823416460625905, 8.823268701356204, 7.830629238605536, 6.89795249973664, 5.94665733526385, 4.996011200630759, 4.017284987713922, 2.977348519542684, 3.899620563278443, 4.853570736849245, 5.869305244318892, 16.83182845647862, 16.7046849343059, 15.66270292715213, 14.683661544153592, 13.722844749933287, 12.75164581540853, 11.75754831020696, 10.738215579617618, 9.779397343057727, 8.86299139823869, 7.92143816867837, 6.884249346574721, 5.860123254652152, 4.917134122295754, 4.0456841899432705, 2.997858212628615, 2.006298972778858, 2.955562786592121, 3.8950752437742877, 4.9105187301228375, 15.819509347838057, 15.752983773020064, 14.725491563218917, 13.673089558777326, 12.743938354057702, 11.774003212376282, 10.817613265012811, 9.787979692988495, 8.8041717223056, 7.818043420968671, 6.860662349587293, 5.8330215564719206, 4.874557071733388, 3.974798084535156, 3.018830356676994, 2.0481693508166803, 0.9954843646666582, 1.9796114208251514, 2.999809088474824, 3.9397749489028806, 14.774217746749896, 14.760537758371656, 13.782698679285849, 12.719179241799496, 11.78848410810015, 10.861301545773872, 9.931623656200353, 8.892784371381142, 7.9389287432521805, 6.965459200726432, 5.9007577901122605, 4.897474596623606, 3.9309578643987964, 2.9902240028163303, 1.9956307364627797, 1.0317938771865536, 0.0, 1.0478678556899745, 2.090402382655384, 3.0358426311854236, 13.712108015101569, 14.571868944898192, 14.671178739739709, 13.668661018801275, 12.766031539673994, 11.861145736688226, 10.89333900657858, 9.938263383515554, 8.877097198233995, 7.8464208858450215, 6.842545882405101, 5.907375878644135, 4.896001656451819, 3.991437555202562, 3.01603489517582, 2.081618352547313, 1.041402452844274, 2.0838822945362074, 3.080229635830256, 4.093399367818353, 12.66791587162283, 13.607872731231634, 14.579066745950328, 14.6769486260001, 13.731971015462104, 12.828392061679825, 11.870127662407905, 10.826411848259488, 9.856805526459308, 8.832594354331782, 7.819161374779609, 6.852764492698675, 5.8409637704356205, 4.925923774243072, 3.994615254058618, 3.1396423750139846, 2.1159806248571194, 3.0588069652319754, 4.063476463152195, 4.9925422916767275, 11.73728723964247, 12.801752503058566, 13.705233830256018, 14.693450809516163, 14.76519717849769, 13.835307138789295, 12.795834687660552, 11.768033405653004, 10.809749337216934, 9.810328779583978, 8.800578615782157, 7.824381859564538, 6.826227135279691, 5.952163303396183, 4.968183920026454, 4.030113827479457, 3.0826939081605884, 4.066979498715864, 5.013092372799431, 5.981195210461742, 10.859671825654774, 11.847665955304386, 12.737171033377562, 13.70402196060353, 14.659680096863084, 14.742018485739813, 13.676918778752727, 12.741394873917297, 11.811857586870305, 10.801723858607353, 9.820416902606283, 8.796182183235041, 7.81660903759312, 6.8901082590706855, 5.9353676040611045, 5.007917718007522, 4.107607181962951, 5.073203448035005, 6.075697203653205, 6.949235938260452, 9.907454144431185, 10.78908663993304, 11.789708541586677, 12.783784735310162, 13.726654065982421, 14.707925074560789, 14.681004838674976, 13.695936400764058, 12.72624947871585, 11.796411643494642, 10.74584346700782, 9.799853277592252, 8.859553729669774, 7.882877968335039, 6.933899757776503, 6.006272788267296, 5.082097164005122, 6.006501349577731, 7.028251737193741, 7.943245877747368, 8.897530876074516, 9.84427847006087, 10.865381033208957, 11.895458159669877, 12.885653566690602, 13.81401903302042, 14.813368932861367, 14.752117517635378, 13.758444912196376, 12.713720783289574, 11.73377799372392, 10.765013765358505, 9.881402489801836, 8.817666377343977, 7.970590926815181, 7.075875020253147, 6.1026387365998955, 7.066986346034819, 7.953622171005255, 8.889090543010843, 7.978494540346597, 9.014413989938557, 9.96363969141618, 10.902202122384622, 11.862638073122818, 12.79578126179345, 13.811380640448334, 14.783977733740558, 14.764850129549268, 13.699296880265212, 12.712761015286171, 11.719232560865255, 10.79633259517803, 9.788339836970357, 9.011367514573713, 8.057691465687052, 7.056181771402148, 8.090546158354726, 8.992368448984077, 9.859898447144046, 6.91217948971303, 7.978215556453651, 8.995154051981997, 9.929265816404374, 10.891011242770267, 11.845553369110327, 12.794407296956999, 13.789206450740814, 14.80462030050494, 14.65801156621088, 13.72520968855064, 12.685509986319525, 11.721550718520582, 10.776824823952715, 9.974754917992819, 9.013385629723812, 8.057855117748284, 9.033962247871392, 9.968380502704486, 10.785256429555238, 5.965444891200652, 6.937008908115778, 8.009995417281303, 9.01512797177665, 9.880281050405403, 10.888228209657491, 11.84913908853482, 12.903024276048196, 13.852259380063371, 14.793031387001616, 14.564788605544958, 13.636943656127318, 12.668864847073745, 11.71006479954857, 10.93033519102152, 9.938467686911963, 9.00461349074037, 9.979008592114448, 10.971677898346467, 11.739740478703427, 4.985888509114205, 6.024024999916948, 7.06466177247264, 7.943634336552352, 8.9105460654143, 9.94877836684309, 10.906156942921768, 11.87718077835291, 12.841933790165529, 13.882695001927607, 14.954597727375495, 14.598314698757116, 13.639369225963884, 12.760731438966744, 11.915847626245222, 10.975452684780409, 9.935834801732687, 10.910880241991876, 11.86032826428168, 12.79312496910486, 4.005622115237088, 4.951715515575849, 6.013729555788247, 6.984970388052276, 8.012463985703866, 8.98230985385431, 9.963082855156424, 10.912092256907963, 11.980054156420273, 12.989320189079425, 14.040484129353207, 15.002348101254446, 14.689644935369827, 13.805659653822826, 12.88232060664857, 11.908500916776024, 10.950122781146332, 11.925503740162709, 12.822760396904606, 13.781243507926083, 4.940491990397737, 5.904923965309953, 6.872880084665673, 7.828223002276427, 8.822211619911293, 9.888047988085358, 10.789985095933188, 11.705439546892459, 12.741763590375083, 13.651178434788779, 14.510498722837053, 15.500834081112522, 15.700269679564641, 14.825470490107532, 13.89438544841578, 12.86735544927836, 11.985728673355462, 12.922867301742155, 13.88612362221674, 14.819636852821315, 5.904281435772814, 6.94806787248381, 7.802681558070438, 7.00059593849129, 7.940808879851778, 8.846103990634656, 9.858008959828133, 10.715689555323706, 11.704417753563638, 12.593923885756082, 13.558684391708484, 14.558278395964606, 15.426336243226473, 15.78009069514305, 14.83559311711752, 13.91440896591921, 12.985015367596882, 13.914651678078187, 14.903696912405193, 15.833196013757297, 6.88155613195042, 7.824761019027712, 6.914084139038209, 6.0056040386146305, 6.940287790476533, 7.894059551989135, 8.83701272926392, 9.775908036451618, 10.712949309700553, 11.624482996913017, 12.569852945445925, 13.552774701674469, 14.46567343732135, 15.451410304701671, 15.846450478307286, 14.847590547064684, 13.925680284697554, 14.889165825735258, 15.838190921025225, 16.791302708637904, 7.817597216043487, 6.87737051109038, 5.8711183731490815, 4.944424558691595, 5.922768968246257, 6.9565038192232995, 7.828549220472942, 8.823542453128336, 9.794743280569465, 10.667671878370177, 11.623534874694373, 12.522720730656916, 13.536970466027206, 14.534450544114748, 15.488070154334949, 15.821582177015383, 14.961998606306233, 15.925531954535257, 16.810028955772843, 17.742988356174752], [17.850818387543114, 17.080537591989703, 16.20304798913364, 16.91818678321792, 16.58174682005681, 15.531288662053077, 14.550213364335724, 13.584211872663818, 12.564982382415215, 11.626267629763502, 10.697528155239555, 9.740096092480448, 8.780708201827961, 7.770850730264786, 6.838029361887229, 5.846347069434896, 4.7949336147478085, 3.832205131294378, 4.833322587404933, 5.840086729360425, 16.848355060395832, 17.4724521216519, 17.23935380979362, 16.69874804292735, 15.716365831185461, 14.76533524480101, 13.767708173519985, 12.732652949772975, 11.802833642513583, 10.797999846074264, 9.797852086804562, 8.805212624053896, 7.8570182761075795, 6.851963276653151, 5.90131714202006, 4.922590929103223, 3.882654460931985, 2.8517527075884685, 3.80570288115927, 4.821437388628917, 15.842001397900676, 16.53942052818063, 16.710570782842105, 15.731529399843568, 14.770712605623263, 13.799513671098506, 12.805416165896936, 11.786083435307594, 10.827265198747703, 9.910859253928665, 8.9223876731104, 7.885198851006751, 6.853429670916297, 5.88416202953794, 4.996176396881282, 3.9483504195666264, 2.9567911797168698, 1.9076949309021465, 2.847207388084313, 3.8626508744328625, 14.829682289260115, 15.581666177286445, 15.773359418908893, 14.720957414467302, 13.791806209747678, 12.821871068066258, 11.865481120702787, 10.83584754867847, 9.852039577995576, 8.865911276658647, 7.908530205277269, 6.880889412161896, 5.917565496707792, 4.941825991777342, 3.9693225636150054, 2.9986615577546916, 1.9459765716046697, 0.931743565135177, 1.9519412327848493, 2.891907093212906, 13.784390688171953, 14.589220162638037, 14.830566534975825, 13.767047097489472, 12.836351963790126, 11.909169401463847, 10.979491511890329, 9.940652227071118, 8.986796598942156, 8.013327056416408, 6.948625645802236, 5.945342452313582, 4.978825720088771, 4.038091858506305, 3.043498592152754, 2.079661732876528, 1.0478678556899745, 0.0, 1.0425345269654096, 1.987974775495449, 12.722280956523626, 13.58204188632025, 14.606558421888604, 14.716528874491251, 13.81389939536397, 12.909013592378201, 11.941206862268556, 10.98613123920553, 9.924965053923971, 8.894288741534996, 7.890413738095077, 6.955243734334111, 5.943869512141794, 5.039305410892537, 4.063902750865794, 3.129486208237288, 2.0892703085342488, 1.036014438846233, 2.032361780140282, 3.0455315121283784, 11.678088813044887, 12.618045672653691, 13.589239687372386, 14.607781316447602, 14.77983887115208, 13.8762599173698, 12.91799551809788, 11.874279703949464, 10.904673382149284, 9.880462210021758, 8.867029230469585, 7.900632348388651, 6.8888316261255955, 5.9737916299330465, 5.042483109748592, 4.055477551521463, 3.031815801364598, 2.088989460989742, 3.0736494045742537, 4.002715233098786, 10.747460181064527, 11.811925444480625, 12.715406771678078, 13.703623750938222, 14.595676696701071, 14.88317499447927, 13.843702543350528, 12.81590126134298, 11.85761719290691, 10.858196635273952, 9.848446471472132, 8.872249715254512, 7.874094990969666, 7.0000311590861575, 5.96573218768411, 4.945949003986935, 3.998529084668067, 3.1277893860281942, 4.023265314221489, 4.9913681518838, 9.869844767076831, 10.857838896726445, 11.747343974799621, 12.71419490202559, 13.669853038285144, 14.652106646376868, 14.70803318091457, 13.772509276079141, 12.792240608511456, 11.768892179814198, 10.750978362980074, 9.712017359742521, 8.7324442141006, 7.805943435578164, 6.851202780568583, 5.923752894515, 5.0234423584704295, 4.194630199400546, 5.085870145075264, 5.959408879682511, 8.917627085853244, 9.799259581355098, 10.799881483008736, 11.793957676732221, 12.73682700740448, 13.718098015982848, 14.654387139792417, 14.646452464890839, 13.657226023459481, 12.727388188238272, 11.6616786435153, 10.715688454099732, 9.775388906177252, 8.798713144842518, 7.8497349342839815, 6.922107964774774, 5.9979323405126, 5.127928100943272, 6.038424678615799, 6.953418819169427, 7.907703817496575, 8.854451411482929, 9.875553974631016, 10.905631101091936, 11.837785711000626, 12.766151177330444, 13.765501077171391, 14.667481513525527, 14.674280088703856, 13.629555959797054, 12.649613170231401, 11.680848941865985, 10.797237666309314, 9.733501553851456, 8.886426103322659, 7.991710196760625, 7.018473913107374, 6.1884130974003595, 6.963795112427313, 7.8992634844329, 6.988667481768656, 7.975590835676072, 8.915771835726206, 9.854334266694648, 10.814770217432843, 11.747913406103475, 12.763512784758358, 13.736109878050582, 14.71401495830035, 14.615132056772692, 13.628596191793651, 12.635067737372735, 11.712167771685507, 10.704175013477835, 9.927202691081192, 8.97352664219453, 7.972016947909626, 7.244954008725219, 8.002541390406137, 8.870071388566103, 5.922352431135089, 6.9393924021911655, 7.947286196292023, 8.8813979607144, 9.843143387080291, 10.797685513420351, 11.746539441267023, 12.741338595050838, 13.756752444814964, 14.74815361001069, 14.641044865058118, 13.601345162827004, 12.63738589502806, 11.692660000460194, 10.890590094500297, 9.92922080623129, 8.973690294255762, 8.257921710856431, 9.020041780988834, 9.795429370977295, 4.917577035510678, 5.889141052425804, 6.962127561591329, 7.967260116086676, 8.832413194715427, 9.840360353967515, 10.801271232844844, 11.855156420358222, 12.804391524373397, 13.745163531311642, 14.795565372602166, 14.552778832634797, 13.584700023581224, 12.625899976056049, 11.846170367528998, 10.854302863419441, 9.920448667247848, 9.202968055099488, 10.023339176630815, 10.749913420125484, 3.9380206534242306, 4.976157144226974, 6.016793916782666, 6.8957664808623775, 7.862678209724325, 8.900910511153114, 9.858289087231793, 10.829312922662936, 11.794065934475555, 12.834827146237632, 13.90672987168552, 14.934855378423533, 14.555204402471363, 13.676566615474222, 12.8316828027527, 11.891287861287887, 10.851669978240166, 10.134839704976915, 10.949985362154699, 11.807484989186003, 2.9577542595471136, 3.9038476598858747, 4.965861700098273, 5.937102532362302, 6.964596130013891, 7.9344419981643375, 8.91521499946645, 9.864224401217989, 10.932186300730299, 11.94145233338945, 12.99261627366323, 13.95448024556447, 14.988842806998086, 14.721494830330304, 13.798155783156048, 12.824336093283502, 11.86595795765381, 11.149463203147748, 11.912417494777625, 12.837703261272907, 3.892624134707762, 4.857056109619978, 5.825012228975698, 6.780355146586452, 7.774343764221319, 8.840180132395384, 9.843429016447978, 10.861160520064026, 11.89748456354665, 12.87465461250566, 13.939159855376678, 14.921995798121102, 15.896340529563401, 15.74130566661501, 14.810220624923259, 13.783190625785839, 12.90156384986294, 12.146826764727194, 12.975780720089759, 13.87609660616814, 4.856413580082839, 5.900200016793834, 6.754813702380462, 7.766466016745719, 8.724601419523367, 9.710409448957018, 10.722314418150493, 11.579995013646066, 12.568723211885997, 13.482462240273948, 14.48350445189858, 15.493375119555857, 16.40091962867483, 16.69592587165053, 15.751428293624999, 14.830244142426688, 13.90085054410436, 13.158777904918649, 14.025858510822383, 14.889655767104122, 5.833688276260445, 6.776893163337737, 5.866216283348233, 6.863141358097364, 7.804593248798893, 8.758365010311495, 9.70131818758628, 10.640213494773977, 11.577254768022913, 12.513021351430883, 13.544436330894284, 14.527358087122828, 15.440256822769708, 16.42599369015003, 16.762285654814765, 15.763425723572162, 14.841515461205033, 14.143930779467814, 15.04222114401153, 15.922802207157963, 6.769729360353512, 5.829502655400405, 4.8232505174591065, 5.801961878174328, 6.787074426568617, 7.82080927754566, 8.718707408252678, 9.713975591321477, 10.769326666017824, 11.642255263818535, 12.598118260142732, 13.497304116105274, 14.511553851475565, 15.509033929563106, 16.462653539783307, 16.73741735352286, 15.877833782813711, 15.180296908267813, 16.014059178759148, 16.874487854694813], [16.819586230955593, 16.049305435402186, 16.868354157511618, 17.771056622891493, 17.584422804396233, 16.5339646463925, 15.552889348675146, 14.58688785700324, 13.567658366754639, 12.628943614102926, 11.700204139578979, 10.742772076819872, 9.783384186167389, 8.773526714604213, 7.840705346226655, 6.849023053774322, 5.7976095990872345, 4.834881115633804, 3.9569736573800243, 4.845374575431155, 15.817122903808311, 16.44121996506438, 17.41386054455672, 17.74128256989276, 16.75890035815087, 15.807869771766418, 14.810242700485393, 13.775187476738383, 12.805509626853008, 11.800675830413688, 10.800528071143987, 9.80788860839332, 8.859694260447004, 7.854639260992575, 6.9039931263594845, 5.925266913442648, 4.885330445271411, 3.854428691927894, 2.929353951134362, 3.826725234699647, 14.810769241313155, 15.50818837159311, 16.450811238435886, 16.774063926808978, 15.813247132588671, 14.842048198063914, 13.847950692862344, 12.828617962273002, 11.869799725713111, 10.953393780894073, 9.96492220007581, 8.927733377972162, 7.895964197881707, 6.92669655650335, 6.038710923846692, 4.990884946532036, 3.9740557001730257, 2.9103709152415718, 1.9708584580594048, 2.8674574492925666, 13.798450132672594, 14.550434020698924, 15.513599874502672, 15.76349194143271, 14.834340736713086, 13.864405595031666, 12.908015647668195, 11.878382075643879, 10.894574104960984, 9.908445803624055, 8.951064732242678, 7.923423939127306, 6.960100023673202, 5.9843605187427515, 5.011857090580415, 4.041196084720101, 2.988511098570079, 1.9742780921005867, 1.0423743749831018, 1.8967136680726102, 12.753158531584432, 13.557988006050516, 14.535827085136324, 14.809581624454884, 13.878886490755537, 12.951703928429257, 12.022026038855739, 10.983186754036527, 10.029331125907566, 9.055861583381818, 7.991160172767646, 6.987876979278992, 6.021360247054181, 5.080626385471715, 4.086033119118164, 3.1221962598419375, 2.090402382655384, 1.0425345269654096, 0.0, 0.9454402485300395, 11.691048799936105, 12.550809729732729, 13.575326265301083, 14.577843986239516, 14.856433922329382, 13.951548119343611, 12.983741389233966, 12.02866576617094, 10.967499580889381, 9.936823268500406, 8.932948265060487, 7.997778261299521, 6.986404039107204, 6.040717163563803, 5.064357052254319, 4.121199005979431, 3.0623512041583307, 1.997476964846812, 1.0011296235527631, 2.002996985162969, 10.646856656457366, 11.58681351606617, 12.558007530784865, 13.57654915986008, 14.539542523615424, 14.91879444433521, 13.96053004506329, 12.916814230914872, 11.947207909114692, 10.922996736987168, 9.909563757434995, 8.943166875354061, 7.931366153091005, 6.974245931321572, 6.0429374111371175, 5.013574836438677, 3.9899130862818115, 3.0470867459069555, 2.042417247986735, 2.971483076511267, 9.716228024477006, 10.780693287893106, 11.684174615090559, 12.672391594350703, 13.564444540113552, 14.50418080152435, 14.886237070315936, 13.858435788308388, 12.900151719872317, 11.884417838956054, 10.874667675154233, 9.898470918936614, 8.900316194651767, 7.962111559876653, 6.89876767625091, 5.878984492553735, 4.9315645732348665, 3.9472789826795913, 2.99203315763397, 3.9601359952962816, 8.838612610489312, 9.826606740138926, 10.716111818212102, 11.68296274543807, 12.638620881697625, 13.62087448978935, 14.627241043127148, 14.70554476464594, 13.725276097078254, 12.701927668380996, 11.684013851546872, 10.64505284830932, 9.665479702667398, 8.738978924144963, 7.784238269135383, 6.8567883830818, 5.956477847037229, 5.014119796051943, 4.054637988487745, 4.9281767230949916, 7.886394929265726, 8.76802742476758, 9.768649326421217, 10.762725520144702, 11.705594850816961, 12.68686585939533, 13.623154983204898, 14.654256432010984, 14.590261512026279, 13.66042367680507, 12.594714132082098, 11.64872394266653, 10.70842439474405, 9.731748633409316, 8.782770422850781, 7.855143453341574, 6.92817937175001, 5.947417697594669, 5.00719252202828, 5.9221866625819075, 6.876471660909056, 7.823219254895409, 8.844321818043497, 9.868252626971355, 10.795251184035216, 11.723616650365035, 12.722966550205982, 13.624946986560118, 14.643945464381755, 14.562591448363852, 13.582648658798199, 12.613884430432783, 11.730273154876112, 10.666537042418254, 9.819461591889459, 8.924745685327425, 7.948720944344784, 6.950232966882199, 5.932562955839794, 6.868031327845381, 5.957435325181137, 6.933056308710663, 7.873237308760798, 8.81179973972924, 9.772235690467433, 10.705378879138065, 11.720978257792948, 12.693575351085174, 13.671480431334942, 14.729019412771025, 14.561631680360449, 13.568103225939533, 12.645203260252305, 11.637210502044633, 10.858398440067292, 9.90377367343194, 8.902263979147037, 7.990606129936459, 6.971309233818617, 7.838839231978583, 4.89112027454757, 5.8968578752257566, 6.904751669326614, 7.838863433748992, 8.800608860114881, 9.755150986454941, 10.704004914301615, 11.69880406808543, 12.714217917849556, 13.705619083045281, 14.63842096070552, 14.534380651393802, 13.570421383594859, 12.625695489026992, 11.821715512528892, 10.859467837468701, 9.899335009357516, 8.923227879234409, 7.988809624401314, 8.764197214389775, 3.875042508545268, 4.846606525460395, 5.91959303462592, 6.924725589121266, 7.789878667750017, 8.797825827002105, 9.758736705879436, 10.812621893392814, 11.761856997407989, 12.702629004346234, 13.753030845636758, 14.680875795054398, 14.517735512148022, 13.558935464622847, 12.777295785557593, 11.784549894656852, 10.846093382349602, 9.868274223477465, 8.992107020043296, 9.718681263537963, 2.895486126458821, 3.9336226172615647, 4.974259389817256, 5.853231953896968, 6.820143682758915, 7.858375984187705, 8.815754560266384, 9.786778395697528, 10.751531407510146, 11.792292619272224, 12.864195344720113, 13.892320851458125, 14.851266324251357, 14.60960210404102, 13.762808220781295, 12.816932576389641, 11.77731469334192, 10.800145873354893, 9.91875320556718, 10.776252832598482, 1.9152197325817042, 2.861313132920465, 3.923327173132863, 4.894568005396892, 5.922061603048482, 6.891907471198928, 7.872680472501041, 8.82168987425258, 9.889651773764891, 10.898917806424041, 11.950081746697823, 12.911945718599062, 13.946308280032678, 14.930898441453406, 14.729281201184643, 13.749980808385256, 12.791602672755564, 11.814769371525726, 10.881185338190106, 11.806471104685386, 2.8560202748846084, 3.8204522497968245, 4.7884083691525445, 5.743751286763299, 6.737739904398166, 7.80357627257223, 8.806825156624825, 9.818625993098617, 10.854950036581242, 11.832120085540252, 12.89662532841127, 13.879461271155694, 14.853806002597993, 15.8934495838166, 15.735865340025013, 14.708835340887592, 13.803458180745059, 12.812132933105172, 11.944548563502241, 12.84486444958062, 3.8612201549425436, 4.871671437430263, 5.718209842557309, 6.729862156922566, 7.687997559700214, 8.747597202828164, 9.73880129272988, 10.748341293939776, 11.819514136528156, 12.747665319007185, 13.748707530631817, 14.758578198289094, 15.73868703161638, 16.70337084620222, 16.628493060870035, 15.68311398210026, 14.753720383777932, 13.824084073296627, 12.994626354234866, 13.858423610516601, 4.838494851120149, 5.861486010607808, 6.66947402078684, 7.676293810887007, 8.688518649075458, 9.691368466239505, 10.634321643514289, 11.573216950701987, 12.510258223950922, 13.446024807358892, 14.519042732387183, 15.501964488615727, 16.44293280710913, 17.428669674489452, 17.635720384718294, 16.616295563245732, 15.694385300878604, 14.809236947845791, 14.010988987424012, 14.891570050570442, 5.774535935213216, 4.953153725375496, 5.825926501798532, 6.804637862513754, 7.789750410908043, 8.823485261885086, 9.721383392592106, 10.716651575660904, 11.772002650357248, 12.64493124815796, 13.600794244482156, 14.499980100444699, 15.514229835814987, 16.51170991390253, 17.46532952412273, 17.59028719319643, 16.730703622487283, 15.84560307664579, 14.982827022171628, 15.843255698107292], [15.875373180803303, 16.441562724462003, 17.43264510222817, 18.37766334821497, 18.433287709383762, 17.38282955138003, 16.401754253662677, 15.43575276199077, 14.416523271742166, 13.477808519090454, 12.549069044566506, 11.5916369818074, 10.632249091154915, 9.622391619591738, 8.689570251214182, 7.697887958761847, 6.64647450407476, 5.68374602062133, 4.8058385623675495, 3.899934326901115, 14.87290985365602, 15.49700691491209, 16.469647494404427, 17.4099933046665, 17.704340606680912, 16.753310020296457, 15.710633103013842, 14.669212044255296, 13.654374531840535, 12.649540735401215, 11.649392976131514, 10.656753513380847, 9.708559165434531, 8.703504165980101, 7.75285803134701, 6.774131818430174, 5.734195350258936, 4.70329359691542, 3.7782188561218875, 2.8812849861696077, 13.866556191160864, 14.56397532144082, 15.506598188283595, 16.50698959826158, 16.758687381118712, 15.787488446593954, 14.793390941392385, 13.774058210803043, 12.815239974243152, 11.898834029424114, 10.902081055595522, 9.864892233491874, 8.833123053401419, 7.863855412023062, 6.934203482741065, 5.88637750542641, 4.822920605160551, 3.7592358202290974, 2.8197233630469305, 1.9220172007625274, 12.854237082520303, 13.606220970546634, 14.569386824350381, 15.62178882879197, 15.779780985243127, 14.809845843561707, 13.853455896198236, 12.82382232417392, 11.840014353491025, 10.853886052154095, 9.896504980772718, 8.868864187657346, 7.897258879192915, 6.9215193742624646, 5.949015946100128, 4.978354940239814, 3.925669954089792, 2.9114369476202997, 1.8912392799706275, 0.9512734195425707, 11.808945481432142, 12.613774955898226, 13.591614034984033, 14.583112713089005, 14.824326739285574, 13.897144176959296, 12.967466287385777, 11.928627002566566, 10.974771374437605, 10.001301831911857, 8.936600421297685, 7.933317227809031, 6.966800495584221, 6.026066634001754, 5.0314733676482035, 4.067636508371978, 3.0358426311854236, 1.987974775495449, 0.9454402485300395, 0.0, 10.746835749783815, 11.606596679580438, 12.631113215148792, 13.633630936087226, 14.561268949251243, 14.89698836787365, 13.929181637764005, 12.974106014700979, 11.91293982941942, 10.882263517030445, 9.878388513590526, 8.94321850982956, 7.931844287637244, 6.986157412093842, 6.009797300784358, 5.06663925450947, 4.0077914526883704, 2.9429172133768517, 1.9465698720828026, 1.0575567366329295, 9.702643606305076, 10.64260046591388, 11.613794480632574, 12.63233610970779, 13.595329473463133, 14.601705010701286, 14.90597029359333, 13.862254479444912, 12.892648157644732, 11.868436985517206, 10.855004005965034, 9.8886071238841, 8.876806401621044, 7.911504788947588, 6.980196268763134, 5.927493443335449, 4.903831693178584, 3.961005352803728, 2.9563358548835077, 2.0272700263589756, 8.772014974324716, 9.836480237740815, 10.739961564938268, 11.728178544198412, 12.620231489961261, 13.55996775137206, 14.599440202500803, 14.803876036838428, 13.845591968402358, 12.798336445852827, 11.788586282051007, 10.812389525833387, 9.81423480154854, 8.876030166773427, 7.812686283147683, 6.792903099450508, 5.84548318013164, 4.861197589576364, 3.9059517645307427, 3.01592294514399, 7.894399560337019, 8.882393689986635, 9.771898768059812, 10.73874969528578, 11.694407831545334, 12.676661439637058, 13.683027992974857, 14.618551897810287, 14.63919470397503, 13.61584627527777, 12.597932458443646, 11.558971455206093, 10.579398309564171, 9.652897531041736, 8.698156876032156, 7.7707069899785735, 6.870396453934003, 5.928038402948716, 4.968556595384517, 3.9839636729427, 6.942181879113434, 7.823814374615288, 8.824436276268926, 9.818512469992411, 10.76138180066467, 11.742652809243038, 12.678941933052608, 13.710043381858693, 14.69926982329005, 14.574342283701844, 13.508632738978871, 12.562642549563304, 11.622343001640823, 10.64566724030609, 9.696689029747555, 8.769062060238348, 7.842097978646784, 6.861336304491442, 5.921111128925053, 4.977973612429616, 5.932258610756764, 6.879006204743117, 7.900108767891204, 8.922812378441316, 9.849810935505177, 10.778176401834996, 11.777526301675943, 12.679506738030078, 13.698505215851714, 14.743229344758516, 14.496567265694972, 13.527803037329557, 12.644191761772886, 11.580455649315027, 10.733380198786232, 9.838664292224198, 8.862639551241557, 7.864151573778972, 6.8464815627365665, 5.92381827769309, 5.013222275028845, 5.987616060180623, 6.927797060230757, 7.866359491199201, 8.826795441937394, 9.759938630608026, 10.77553800926291, 11.748135102555134, 12.726040182804901, 13.783579164240985, 14.70967299656374, 14.482021832836306, 13.559121867149079, 12.551129108941407, 11.772317046964064, 10.817692280328712, 9.816182586043809, 8.904524736833231, 7.885227840715389, 6.8946261818262915, 3.9469072243952783, 4.951417626695717, 5.959311420796574, 6.8934231852189525, 7.855168611584841, 8.809710737924902, 9.758564665771575, 10.75336381955539, 11.768777669319515, 12.76017883451524, 13.69298071217548, 14.68686921633215, 14.484339990491632, 13.539614095923765, 12.735634119425663, 11.773386444365473, 10.72835588308313, 9.752248752960023, 8.817830498126929, 7.819984164237484, 2.9296022600152285, 3.901166276930355, 4.97415278609588, 5.979285340591226, 6.844438419219977, 7.852385578472067, 8.813296457349395, 9.867181644862773, 10.816416748877948, 11.757188755816193, 12.807590597106717, 13.735435546524357, 14.753495394127865, 14.47285407151962, 13.691214392454365, 12.668133299903264, 11.675114256075217, 10.69729509720308, 9.798945252833889, 8.774468213385672, 1.9500458779287815, 2.9881823687315254, 4.028819141287217, 4.907791705366928, 5.874703434228875, 6.9129357356576655, 7.870314311736344, 8.841338147167487, 9.806091158980106, 10.846852370742184, 11.918755096190072, 12.946880602928085, 13.905826075721317, 14.862871350059894, 14.603651110721893, 13.645953450115256, 12.606335567067534, 11.629166747080507, 10.725591438357773, 9.832039782446191, 0.9697794840516646, 1.9158728843904256, 2.9778869246028234, 3.9491277568668526, 4.976621354518443, 5.946467222668889, 6.927240223971002, 7.876249625722541, 8.94421152523485, 9.953477557894, 11.004641498167782, 11.966505470069022, 13.000868031502637, 13.985458192923366, 15.048704394408107, 14.57900168211087, 13.620623546481179, 12.64379024525134, 11.688023570980699, 10.862258054533093, 1.9105800263545691, 2.8750120012667852, 3.8429681206225057, 4.79831103823326, 5.792299655868127, 6.858136024042191, 7.861384908094785, 8.873185744568579, 9.909509788051203, 10.886679837010213, 11.95118507988123, 12.934021022625654, 13.908365754067953, 14.94800933528656, 15.95807907579108, 15.537856214613207, 14.632479054470673, 13.641153806830786, 12.751386796292834, 11.900651399428327, 2.9157799064125043, 3.9262311889002235, 4.77276959402727, 5.7844219083925275, 6.7425573111701755, 7.802156954298126, 8.793361044199841, 9.802901045409737, 10.874073887998117, 11.802225070477146, 12.803267282101778, 13.813137949759055, 14.79324678308634, 15.75793059767218, 16.75004902231478, 16.512134855825874, 15.582741257503546, 14.653104947022241, 13.801464587025459, 12.914210560364308, 3.8930546025901096, 4.916045762077768, 5.724033772256801, 6.730853562356968, 7.74307840054542, 8.745928217709466, 9.68888139498425, 10.627776702171948, 11.564817975420883, 12.500584558828853, 13.573602483857144, 14.556524240085688, 15.544133057365972, 16.529869924746293, 17.58816039656001, 17.445316436971346, 16.52340617460422, 15.638257821571406, 14.817827220214605, 13.94735700041815, 4.829095686683177, 5.802018630363022, 6.674791406786058, 7.65350276750128, 8.638615315895569, 9.672350166872612, 10.570248297579631, 11.56551648064843, 12.492396950024128, 13.457395677371693, 14.41325867369589, 15.348845005432226, 16.363094740802516, 17.360574818890058, 18.31419442911026, 18.419308066922046, 17.559724496212898, 16.674623950371405, 15.789665254962221, 14.899042647955], [5.128537431019488, 5.853041075801244, 6.8441234535674145, 7.789141699554212, 8.728659081152045, 9.747024234733574, 10.627023887081327, 11.593025378753232, 12.612254869001834, 13.550969621653547, 14.479709096177494, 15.437141158936601, 16.510085635090153, 17.51994310665333, 18.452764475030886, 18.444723708545663, 17.393310253858576, 16.430581770405144, 15.552674312151366, 14.64677007668493, 4.126074103872206, 4.908485266251329, 5.881125845743667, 6.821471656005741, 7.8038538677476295, 8.806824908479646, 9.672247512194266, 10.700636163356751, 11.715473675771513, 12.720307472210832, 13.720455231480534, 14.7130946942312, 15.661289042177517, 16.666344041631945, 17.573132482591383, 17.520967568213987, 16.48103110004275, 15.450129346699233, 14.525054605905703, 13.628120735953424, 3.11972044137705, 3.975453672780059, 4.9180765396228345, 5.918467949600818, 6.915859889531503, 7.845850989394979, 8.709955504571218, 9.75406664889137, 10.712884885451261, 11.753572437649003, 12.793221397860632, 13.805839958020758, 14.724893160318855, 15.65740252009114, 16.59870286480351, 16.633213255210222, 15.569756354944365, 14.506071570012912, 13.566559112830745, 12.668852950546343, 2.1074013327364884, 3.017699321885872, 3.9808651756896207, 5.033267180131211, 5.923834918041351, 6.868208386362731, 7.770020459377068, 8.799654031401383, 9.783462002084278, 10.769590303421207, 11.726971374802584, 12.754612167917957, 13.739326977400092, 14.715066482330542, 15.687569910492877, 15.720942514278317, 14.668257528128295, 13.654024521658803, 12.638075029754443, 11.698109169326386, 1.0621097316483266, 2.025253307237464, 3.003092386323272, 4.007506392664799, 4.9382015263641446, 5.865384088690424, 6.795061978263942, 7.833901263083153, 8.787756891212114, 9.761226433737862, 10.825927844352034, 11.829211037840688, 12.795727770065499, 13.736461631647964, 14.731054898001515, 14.73405942539202, 13.712108015101569, 12.722280956523626, 11.691048799936109, 10.746835749783816, 0.0, 1.0180750309196769, 2.0555068947245863, 3.0580246156630198, 4.1301793834218765, 5.167571311838496, 6.13537804194814, 7.16776858830945, 8.228934773591009, 9.298389958673072, 10.302264962112991, 11.24646004104481, 12.257834263237125, 13.242431799475614, 14.218791910785098, 13.68423495003126, 12.670705562257295, 11.686266517677394, 10.689919176383345, 9.689279013150887, 1.0441921434787393, 1.9820712445862343, 2.953265259304929, 3.9718068883801454, 4.934800252135489, 5.983486035867048, 6.965399355459791, 8.016680494014228, 8.986286815814408, 10.010497987941932, 11.082161802937817, 12.048558685018751, 13.070211798470154, 14.094503345012464, 13.46134704638323, 12.613722776386453, 11.59612739024445, 10.653301049869594, 9.648631551949373, 8.719565723424841, 1.9748207754590998, 2.9791514229834424, 3.942484131287072, 4.9807668415023505, 5.968026415171074, 6.907762676581871, 7.947235127710615, 8.97349344688112, 9.93177751531719, 10.992001255782784, 12.001751419584604, 12.977948175802224, 13.97610290008707, 13.412310309367015, 12.487778380415394, 11.543640400465407, 10.656735972325452, 9.695704595750742, 8.740458770705121, 7.730912804639826, 2.907239387851497, 3.933237970737622, 4.9105469281655285, 5.8773978553914965, 6.833055991651051, 7.8153095997427755, 8.880409306729861, 9.81593321156529, 10.796201879132976, 11.819550307830234, 12.837464124664358, 13.87642512790191, 13.37452782952294, 12.448027051000505, 11.493286395990925, 10.565836509937341, 9.63182269852309, 8.747543373659074, 7.70235293119711, 6.7628720768411155, 3.960981323685828, 4.991817286108969, 5.858009419956414, 6.852085613679898, 7.778027542534894, 8.759298551113263, 9.695587674922832, 10.726689123728917, 11.715915565160275, 12.645753400381484, 13.711462945104456, 13.560693402689624, 12.57447006689327, 11.504472353691863, 10.594884799045289, 9.667257829536082, 8.65733271648092, 7.8174633535137374, 6.7497983976565745, 5.7688621373541995, 4.970904592042498, 5.9176521860288505, 6.894846082825064, 7.891487085955463, 8.821205241651958, 9.749570707981777, 10.72835744228062, 11.687641956039878, 12.706640433861514, 13.647331498491944, 13.64598684948092, 12.595532914923371, 11.61792059503255, 10.569683944682925, 9.577312013172843, 8.627568264004065, 7.636791143886145, 6.774976246070722, 5.824427963845061, 4.823017472090726, 5.9024022023202924, 6.927504739598545, 7.921232765171277, 8.94033737992408, 9.844220735219741, 10.80345661301419, 11.730345734693653, 12.619013591514822, 13.690181442640663, 13.561647473436317, 12.622137550438593, 11.641314119416622, 10.609921909246765, 9.601929151039093, 8.639382570004148, 7.684757803368797, 6.683248109083893, 5.7184353347458625, 4.826545587952925, 3.8522095679575235, 6.9687172529538595, 7.963703173083451, 8.88971840460546, 9.823830169027838, 10.815847565572293, 11.753684505697313, 12.723818693165743, 13.613784874514566, 13.554025298042955, 12.538247143710572, 11.605445266050333, 10.658833858820831, 9.694874591021888, 8.740665159695228, 7.6946640466439735, 6.732416371583783, 5.681574762737757, 4.70546763261465, 3.809045197370228, 2.9268515855463315, 8.021089934194748, 8.992653951109874, 9.874877039306154, 10.756428777799828, 11.761272610955116, 12.711009665150149, 13.669086901587923, 13.577960196012247, 12.628725091997072, 11.687953085058828, 10.637551243768304, 9.709706294350664, 8.749596457432606, 7.819283231790321, 6.865096064447847, 5.813174427785818, 4.820155383957772, 3.7604212883715933, 2.8057478017282462, 2.003876480441702, 9.000646316281195, 9.980266689910206, 10.905150693183096, 11.827922413024126, 12.731007595946219, 13.65045950796455, 13.892106946356327, 12.86189694809532, 11.897143936282701, 10.856382724520623, 9.784479999072735, 8.738037551335697, 7.779092078542466, 6.8220468042038895, 5.886249616619814, 4.928551956013178, 3.888934072965456, 2.8285496384941666, 1.8791016162043621, 0.9463049113811827, 9.98091271015831, 10.927006110497071, 11.976044118714656, 12.7865863615242, 13.747616720538636, 14.648306027528236, 14.75767793029278, 13.808668528541242, 12.740706629028931, 11.731440596369781, 10.680276656096, 9.71841268419476, 8.829367787948408, 7.866975019059971, 6.8527225970231616, 5.861600188008793, 4.88163031847887, 3.843173136664999, 2.841533748827288, 1.9765231834680854, 10.921713252461215, 11.886145227373431, 12.854101346729152, 13.75959643051444, 14.753585048149308, 15.701997008836106, 15.73381890705867, 14.705358170857922, 13.669034127375298, 12.691864078416287, 11.626820237809447, 10.685928236751392, 9.839992532143222, 8.85755446015307, 7.84748471964855, 6.82045472051113, 5.831861945884332, 4.8405366982444455, 3.904896974139423, 3.014916528363318, 11.99428526147533, 12.937364415006869, 13.783902820133916, 14.776762774346802, 15.73489817712445, 16.754566871481014, 16.58854080683995, 15.579000805630058, 14.507827963041677, 13.579676780562648, 12.578634568938016, 11.593807898565034, 10.613699065237748, 9.649015250651908, 8.656896826009309, 7.711517747239533, 6.782124148917205, 5.852487838435899, 4.9549747648720475, 4.0284756892993, 12.971559957652936, 13.94814350387243, 14.735166998363447, 15.741986788463613, 16.735419266499694, 17.706611310126537, 17.36082083325032, 16.42192552606262, 15.484884252813684, 14.549117669405714, 13.5448924446517, 12.561970688423155, 11.574361871142871, 10.675030540800948, 9.66412414985757, 8.644699328385007, 7.722789066017878, 6.837640712985064, 5.971337398061193, 5.061622129353141, 13.907601041746002, 14.895534011809763, 15.778132764252573, 16.794262274142085, 17.75293808872997, 18.644167042892374, 18.420050515597033, 17.386007109729622, 16.40304131360821, 15.424436204756475, 14.491210515403251, 13.538548783063348, 12.503064842437013, 11.56130958748091, 10.607689977260709, 9.618690958335707, 8.759107387626557, 7.866874534433242, 6.919519489031801, 6.013307776889992], [5.822930005665395, 4.834966044881567, 5.826048422647737, 6.771066668634535, 7.710584050232369, 8.728949203813897, 9.60894885616165, 10.574950347833555, 11.594179838082159, 12.532894590733871, 13.461634065257819, 14.419066128016926, 15.492010604170478, 16.501868075733654, 17.43468944411121, 17.694563684896302, 16.788054607289045, 15.825326123835612, 15.130624327722847, 15.506531006481552, 4.8204666785181125, 3.890410235331652, 4.86305081482399, 5.803396625086064, 6.785778836827952, 7.788749877559969, 8.654172481274589, 9.682561132437076, 10.697398644851837, 11.702232441291157, 12.702380200560858, 13.695019663311525, 14.643214011257841, 15.648269010712271, 16.555057451671708, 17.533783664588544, 17.340792029839374, 16.309890276495857, 15.384815535702325, 14.487881665750045, 3.9579732730557335, 2.957378641860382, 3.9000015087031574, 4.900392918681141, 5.897784858611826, 6.827775958475303, 7.691880473651541, 8.735991617971695, 9.694809854531586, 10.735497406729328, 11.775146366940957, 12.787764927101083, 13.70681812939918, 14.639327489171464, 15.580627833883833, 16.58984474724545, 16.42951728474099, 15.365832499809533, 14.426320042627367, 13.528613880342965, 3.045380172061293, 1.9996242909661954, 2.962790144769944, 4.0151921492115346, 4.905759887121675, 5.850133355443055, 6.751945428457391, 7.781579000481707, 8.7653869711646, 9.75151527250153, 10.708896343882909, 11.736537136998281, 12.721251946480416, 13.696991451410867, 14.669494879573202, 15.640155885433515, 15.528018457924917, 14.513785451455425, 13.497835959551065, 12.557870099123008, 2.0563770036530578, 1.0071782763177874, 1.9850173554035955, 2.989431361745122, 3.9201264954444683, 4.847309057770747, 5.776986947344266, 6.815826232163477, 7.7696818602924385, 8.743151402818187, 9.807852813432358, 10.811136006921013, 11.777652739145823, 12.718386600728289, 13.71297986708184, 14.676816726358066, 14.57186894489819, 13.582041886320248, 12.55080972973273, 11.606596679580438, 1.0180750309196769, 0.0, 1.0374318638049096, 2.039949584743343, 3.1121043525021994, 4.149496280918819, 5.117303011028463, 6.149693557389773, 7.210859742671332, 8.280314927753395, 9.284189931193314, 10.228385010125132, 11.239759232317448, 12.224356768555937, 13.200716879865421, 14.14387492614031, 13.530466492053916, 12.546027447474016, 11.549680106179967, 10.549039942947509, 1.9039530732753618, 0.9639962136665575, 1.9351902283852525, 2.9537318574604687, 3.9167252212158123, 4.965411004947372, 5.947324324540114, 6.998605463094551, 7.968211784894731, 8.992422957022256, 10.064086772018142, 11.030483654099076, 12.05213676755048, 13.076428314092789, 14.007736834277244, 13.479550070197936, 12.45588832004107, 11.513061979666215, 10.508392481745995, 9.579326653221463, 2.8345817052557223, 1.9610763920637657, 2.9244091003673955, 3.9626918105826743, 4.949951384251397, 5.889687645662195, 6.929160096790938, 7.955418415961443, 8.913702484397513, 9.973926224863106, 10.983676388664927, 11.959873144882547, 12.958027869167394, 13.896232503942507, 13.428856251420056, 12.484718271470069, 11.53975111610264, 10.555465525547364, 9.600219700501743, 8.590673734436448, 3.7670003176481193, 2.915162939817945, 3.892471897245852, 4.859322824471819, 5.814980960731374, 6.797234568823098, 7.862334275810183, 8.797858180645614, 9.778126848213299, 10.801475276910558, 11.819389093744682, 12.858350096982235, 13.837923242624157, 13.389104922005167, 12.434364266995587, 11.506914380942003, 10.572900569527752, 9.607304303455697, 8.562113860993733, 7.622633006637738, 4.82074225348245, 3.973742255189292, 4.8399343890367374, 5.8340105827602216, 6.759952511615217, 7.741223520193585, 8.677512644003153, 9.708614092809238, 10.697840534240596, 11.627678369461805, 12.693387914184777, 13.639378103600345, 13.587879538344115, 12.517881825142709, 11.595538040030071, 10.667911070520864, 9.657985957465701, 8.677224283310359, 7.609559327453197, 6.628623067150822, 5.83066552183912, 4.918550425061462, 5.876771051905388, 6.873412055035788, 7.803130210732281, 8.7314956770621, 9.710282411360941, 10.669566925120199, 11.688565402941835, 12.629256467572265, 13.609199257137918, 13.608942386374215, 12.631330066483393, 11.58309341613377, 10.590721484623689, 9.640977735454909, 8.650200615336988, 7.701858904684088, 6.684188893641683, 5.682778401887348, 6.762163132116915, 5.928402978631157, 6.922131004203889, 7.929864942277901, 8.826145704300064, 9.785381582094512, 10.712270703773974, 11.600938560595143, 12.672106411720984, 13.614832564547903, 13.640212581358272, 12.654723590867466, 11.623331380697609, 10.615338622489936, 9.652792041454992, 8.69816727481964, 7.696657580534737, 6.731844806196706, 5.7295363052419, 4.711970497754146, 7.828478182750482, 6.964601412116063, 7.890616643638072, 8.82472840806045, 9.797772534652616, 10.735609474777636, 11.705743662246066, 12.595709843594888, 13.611123693359014, 13.556322174630251, 12.623520296970012, 11.672243330271675, 10.708284062472732, 9.754074631146072, 8.708073518094817, 7.745825843034627, 6.694984234188601, 5.718877104065493, 4.784458849232398, 3.786612515342954, 8.88085086399137, 8.014852761881425, 8.875775278338766, 9.75732701683244, 10.762170849987728, 11.692934634230472, 12.651011870668246, 13.592877312558752, 13.646800122916751, 12.706028115978507, 11.655626274687982, 10.727781325270342, 9.767671488352283, 8.837358262709998, 7.8831710953675245, 6.8312494587054955, 5.838230414877449, 4.77849631929127, 3.8238228326479233, 2.8696787087721938, 9.860407246077816, 9.002465500681755, 9.906048932215707, 10.828820652056738, 11.73190583497883, 12.632384477044873, 13.589763053123551, 13.879971979014998, 12.91521896720238, 11.874457755440302, 10.802555029992414, 9.756112582255376, 8.797167109462144, 7.840121835123567, 6.904324647539491, 5.946626986932855, 4.907009103885133, 3.8466246694138437, 2.897176647124039, 1.9643799423008597, 10.840673639954932, 10.074774985022854, 10.976942357747268, 11.787484600556812, 12.748514959571247, 13.630230996608558, 14.590863003791064, 14.82674355946092, 13.75878165994861, 12.74951562728946, 11.698351687015679, 10.73648771511444, 9.847442818868085, 8.885050049979649, 7.870797627942839, 6.87967521892847, 5.899705349398548, 4.861248167584677, 3.859608779746965, 2.9945982143877625, 11.781474182257837, 11.125055475291044, 11.910249320147463, 12.760494669547052, 13.75448328718192, 14.683921977916429, 15.605347829778774, 15.7234332017776, 14.687109158294977, 13.709939109335966, 12.644895268729126, 11.704003267671071, 10.8580675630629, 9.875629491072747, 8.865559750568227, 7.838529751430807, 6.84993697680401, 5.8586117291641235, 4.9229720050590995, 4.032991559282995, 12.854046191271951, 12.176274662924481, 12.840050793552226, 13.777661013379413, 14.735796416157061, 15.736491840561337, 16.53732396588383, 16.597075836549735, 15.525902993961356, 14.597751811482327, 13.596709599857695, 12.611882929484711, 11.631774096157425, 10.667090281571586, 9.674971856928986, 8.72959277815921, 7.800199179836883, 6.870562869355577, 5.9652193656824855, 5.03054493711662, 13.831320887449557, 13.187053751790042, 13.791314971781757, 14.772652913256072, 15.736317505532305, 16.688536279206858, 17.55832019644804, 17.235980149036543, 16.298938875787606, 15.363172292379637, 14.401525871448271, 13.418604115219727, 12.430995297939443, 11.566641500293532, 10.616958536877506, 9.597533715404944, 8.63635410934462, 7.6728685683069155, 6.72384347301695, 5.770731685404271, 14.767361971542623, 14.134444259727376, 14.834280737670884, 15.833832393179108, 16.75383632776258, 17.626092011972695, 17.449724753721547, 16.425277993663993, 15.384966282688536, 14.4063611738368, 13.569861551621532, 12.526501571772219, 11.502292326645302, 10.567769421389032, 9.674027864693878, 8.738224286532706, 7.811419669038743, 6.848799503513565, 5.901444458112124, 6.722417332941121], [6.786640919573754, 5.798676958789926, 4.996007015148765, 5.867717048299331, 6.761759261977373, 7.696364994626825, 8.57151699235674, 9.537518484028645, 10.556747974277247, 11.49546272692896, 12.424202201452907, 13.381634264212014, 14.454578740365566, 15.464436211928742, 16.3972575803063, 16.823699370451525, 15.917190292844262, 14.954461809390832, 15.801174546514023, 16.531047542049908, 5.784177592426472, 4.854121149240012, 3.959701194488786, 4.90004700475086, 5.832605048470774, 6.756165668372897, 7.61674061746968, 8.645129268632166, 9.659966781046927, 10.664800577486247, 11.664948336755948, 12.657587799506615, 13.605782147452931, 14.610837146907361, 15.517625587866798, 16.496351800783636, 16.877238068566655, 15.934914233096741, 16.40933207127068, 15.512398201318401, 4.921684186964093, 3.9210895557687415, 2.908034264439901, 3.9084256744178845, 4.886951822908575, 5.790344094670393, 6.654448609846631, 7.6985597541667845, 8.657377990726674, 9.698065542924416, 10.737714503136049, 11.750333063296175, 12.66938626559427, 13.601895625366554, 14.543195970078923, 15.552412883440539, 16.615869783706398, 16.39034903537789, 15.450836578195723, 14.55313041591132, 4.0090910859696525, 2.963335204874555, 1.9708229005066875, 2.990682204578234, 3.8683280233167654, 4.812701491638145, 5.714513564652481, 6.744147136676797, 7.7279551073596915, 8.714083408696622, 9.671464480078, 10.699105273193373, 11.683820082675506, 12.659559587605957, 13.632063015768292, 14.602724021628605, 15.655409007778626, 15.53830198702378, 14.52235249511942, 13.582386634691364, 3.0200879175614173, 1.970889190226147, 0.9930501111403389, 1.9519994979402124, 2.8826946316395587, 3.809877193965838, 4.739555083539356, 5.778394368358567, 6.732249996487528, 7.705719539013277, 8.770420949627448, 9.773704143116102, 10.740220875340913, 11.680954736923379, 12.67554800327693, 13.639384862553156, 14.671178739739709, 14.606558421888604, 13.575326265301086, 12.631113215148794, 2.0555068947245863, 1.0374318638049096, 0.0, 1.0025177209384335, 2.0746724886972903, 3.11206441711391, 4.079871147223554, 5.1122616935848635, 6.173427878866422, 7.242883063948485, 8.246758067388404, 9.190953146320222, 10.202327368512538, 11.186924904751027, 12.163285016060511, 13.1064430623354, 14.1652908641565, 13.570543983042372, 12.574196641748323, 11.573556478515865, 2.928469608843718, 1.9885127492349137, 1.0173187345162187, 2.0108053281372573, 2.973798691892601, 4.022484475624161, 5.004397795216903, 6.05567893377134, 7.02528525557152, 8.049496427699044, 9.121160242694929, 10.087557124775863, 11.109210238227266, 12.133501784769576, 13.064810304954031, 14.117513130381717, 13.480404855609427, 12.537578515234571, 11.532909017314351, 10.603843188789819, 3.8590982408240784, 2.985592927632122, 2.042770829309496, 3.0197652812594624, 4.007024854928186, 4.946761116338984, 5.986233567467727, 7.012491886638232, 7.970775955074302, 9.030999695539895, 10.040749859341716, 11.016946615559336, 12.015101339844183, 12.953305974619296, 14.016649858245039, 13.509234807038425, 12.564267651670995, 11.57998206111572, 10.624736236070099, 9.615190270004804, 4.791516853216475, 3.939679475386301, 3.0108336261879525, 3.97768455341392, 4.932848513344114, 5.915102121435838, 6.966233691060154, 7.9017575958955835, 8.882026263463269, 9.905374692160528, 10.923288508994652, 11.962249512232205, 12.941822657874127, 13.868323436396562, 13.458880802563943, 12.53143091651036, 11.597417105096108, 10.631820839024053, 9.58663039656209, 8.647149542206094, 5.845258789050805, 4.958918019632476, 3.958296117978838, 4.952372311702322, 5.877820064227957, 6.859091072806325, 7.795380196615894, 8.82648164542198, 9.815708086853338, 10.745545922074546, 11.811255466797519, 12.757245656213087, 13.764588535019737, 13.542398360711065, 12.620054575598429, 11.692427606089222, 10.68250249303406, 9.701740818878717, 8.634075863021554, 7.653139602719178, 6.850473783490999, 5.9037261895046464, 4.995132780847489, 5.991773783977887, 6.920997763345021, 7.84936322967484, 8.828149963973681, 9.787434477732939, 10.806432955554575, 11.747124020185007, 12.72706680975066, 13.72240614397934, 13.65584660205175, 12.607609951702127, 11.615238020192045, 10.665494271023265, 9.674717150905344, 8.726375440252443, 7.708705429210039, 6.707294937455704, 7.781971393768794, 6.913578743074341, 6.05126668975911, 7.048226671220001, 7.944013256912804, 8.903249134707252, 9.830138256386714, 10.718806113207883, 11.789973964333724, 12.732700117160645, 13.75240069275601, 13.679240126435822, 12.647847916265965, 11.639855158058293, 10.677308577023348, 9.722683810387997, 8.721174116103093, 7.7563613417650625, 6.754052840810256, 5.736487033322502, 8.848286444402362, 7.949777176559247, 7.0197523291932935, 7.953864093615672, 8.915640087265356, 9.853477027390376, 10.823611214858806, 11.713577396207628, 12.728991245971754, 13.744769400304136, 13.660952160774922, 12.696759865840031, 11.732800598041088, 10.778591166714428, 9.732590053663174, 8.770342378602983, 7.719500769756957, 6.743393639633849, 5.808975384800754, 4.81112905091131, 9.90065912564325, 9.00002852632461, 8.004910963893987, 8.88646270238766, 9.891306535542949, 10.810802186843212, 11.768879423280985, 12.710744865171492, 13.659979969186667, 13.743459979783417, 12.693058138492892, 11.765213189075252, 10.805103352157193, 9.874790126514906, 8.920602959172433, 7.868681322510405, 6.875662278682358, 5.8159281830961795, 4.861254696452832, 3.89419524434055, 10.880215507729696, 9.987641265124939, 9.035184617770927, 9.957956337611959, 10.861041520534052, 11.750252029657613, 12.707630605736291, 13.736588362866778, 13.95265083100729, 12.911889619245212, 11.839986893797324, 10.793544446060286, 9.834598973267054, 8.877553698928477, 7.941756511344401, 6.984058850737764, 5.944440967690042, 4.884056533218753, 3.9346085109289484, 3.001811806105769, 11.860481901606812, 11.059950749466038, 10.106078043302487, 10.916620286112034, 11.877650645126469, 12.748098549221298, 13.708730556403804, 14.657739958155343, 14.796213523753522, 13.78694749109437, 12.735783550820589, 11.77391957891935, 10.884874682672997, 9.922481913784559, 8.908229491747749, 7.917107082733379, 6.9371372132034566, 5.898680031389585, 4.897040643551874, 4.032030078192672, 12.801282443909717, 12.007341125058403, 11.039385005702682, 11.889630355102273, 12.883618972737139, 13.801789530529168, 14.723215382391514, 15.65467607700138, 15.724541022099888, 14.747370973140878, 13.682327132534036, 12.741435131475981, 11.895499426867811, 10.913061354877655, 9.902991614373136, 8.875961615235715, 7.887368840608918, 6.896043592969032, 5.960403868864009, 5.048445146163637, 13.873854452923831, 13.024844218051832, 11.969186479107446, 12.906796698934635, 13.864932101712283, 14.854359393174077, 15.655191518496569, 16.644426068570134, 16.22333249989682, 15.295181317417791, 14.34420574102422, 13.334335073366944, 12.354226240039658, 11.555224926637662, 10.635412916484238, 9.696572709373882, 8.83763104364179, 7.907994733160486, 6.928930279590845, 5.994255851024979, 14.851129149101437, 13.857603970581218, 12.920450657336977, 13.901788598811294, 14.865453191087527, 15.8064038318196, 16.67618774906078, 16.19854828523163, 15.261507011982696, 14.325740428574726, 13.364094007643363, 12.381172251414819, 11.393563434134535, 10.529209636488622, 9.624555555294473, 8.763391128228408, 7.944388370312218, 7.055124224814591, 7.687554386925309, 6.73444259931263, 15.787170233194503, 14.804994478518552, 13.963416423226104, 14.96296807873433, 15.882972013317803, 16.743959564585435, 16.412292889916635, 15.387846129859081, 14.347534418883624, 13.368929310031888, 12.53242968781662, 11.489069707967307, 10.464860462840392, 9.530337557584122, 8.641443655506805, 7.789399498277709, 6.908070048703539, 6.018758096014593, 6.865155372020483, 7.6861282468494805], [7.789158640512188, 6.80119467972836, 5.995842846906798, 4.986861259533215, 5.759241541038939, 6.693847273688392, 7.568999271418306, 8.535000763090212, 9.554230253338815, 10.492945005990528, 11.421684480514475, 12.379116543273582, 13.452061019427134, 14.46191849099031, 15.394739859367867, 15.948745039911866, 15.138341861827428, 15.904590404130987, 16.75130314125418, 17.53356526298834, 6.7866953133649055, 5.856638870178445, 4.959537026246818, 4.019191215984744, 4.830087327532341, 5.753647947434463, 6.614222896531246, 7.642611547693732, 8.657449060108492, 9.662282856547812, 10.662430615817513, 11.65507007856818, 12.603264426514496, 13.608319425968926, 14.515107866928364, 15.4938340798452, 16.09838963754982, 16.885042827836898, 17.411849792209114, 16.514915922256833, 5.9242019079025265, 4.923607276707175, 3.9105519853783344, 2.998736469016068, 3.884434101970142, 4.787826373731959, 5.651930888908198, 6.696042033228351, 7.654860269788241, 8.695547821985983, 9.735196782197614, 10.74781534235774, 11.666868544655836, 12.59937790442812, 13.54067824914049, 14.549895162502105, 15.613352062767964, 16.624223805393395, 16.45335429913416, 15.555648136849754, 5.011608806908086, 3.9658529258129884, 2.973340621445121, 1.988164483639801, 2.865810302378332, 3.8101837706997115, 4.711995843714048, 5.741629415738363, 6.725437386421258, 7.7115656877581875, 8.668946759139565, 9.696587552254938, 10.681302361737073, 11.657041866667523, 12.629545294829859, 13.600206300690171, 14.652891286840193, 15.648272439626426, 15.524870216057854, 14.584904355629797, 4.022605638499851, 2.9734069111645804, 1.9955678320787724, 0.949481777001779, 1.8801769107011252, 2.8073594730274043, 3.737037362600923, 4.775876647420134, 5.729732275549095, 6.703201818074843, 7.767903228689015, 8.771186422177669, 9.73770315440248, 10.678437015984946, 11.673030282338496, 12.636867141614722, 13.668661018801275, 14.71652887449125, 14.57784398623952, 13.633630936087227, 3.0580246156630198, 2.039949584743343, 1.0025177209384335, 0.0, 1.0721547677588565, 2.1095466961754763, 3.077353426285121, 4.109743972646431, 5.17091015792799, 6.240365343010053, 7.244240346449973, 8.188435425381792, 9.199809647574108, 10.184407183812597, 11.160767295122081, 12.10392534139697, 13.16277314321807, 14.22764738252959, 13.576714362686756, 12.576074199454299, 3.9309873297821514, 2.9910304701733472, 2.0198364554546524, 1.0082876071988238, 1.9712809709541674, 3.0199667546857274, 4.0018800742784695, 5.053161212832906, 6.022767534633086, 7.046978706760611, 8.118642521756495, 9.08503940383743, 10.106692517288833, 11.130984063831143, 12.062292584015598, 13.114995409443283, 14.138657159600148, 13.540096236173005, 12.535426738252784, 11.606360909728252, 4.861615961762512, 3.9881106485705553, 3.04528855024793, 2.017247560321029, 3.0045071339897524, 3.9442433954005502, 4.983715846529293, 6.0099741656997985, 6.9682582341358685, 8.028481974601462, 9.038232138403282, 10.014428894620902, 11.012583618905749, 11.950788253680862, 13.014132137306605, 14.03391532100378, 13.56678537260943, 12.582499782054155, 11.627253957008534, 10.617707990943238, 5.794034574154908, 4.942197196324734, 3.973527336459629, 3.0066764092336613, 3.9303307924056794, 4.912584400497403, 5.9637159701217195, 6.89923987495715, 7.879508542524835, 8.902856971222093, 9.920770788056217, 10.95973179129377, 11.939304936935692, 12.865805715458126, 13.820546370467707, 13.533948637448793, 12.599934826034541, 11.634338559962487, 10.589148117500523, 9.649667263144527, 6.847776509989239, 5.921611729904152, 4.920989828250514, 4.053418947784321, 4.875302343289523, 5.85657335186789, 6.79286247567746, 7.823963924483546, 8.813190365914904, 9.743028201136113, 10.808737745859085, 11.754727935274653, 12.762070814081303, 13.832068527282708, 13.622572296536863, 12.694945327027655, 11.685020213972493, 10.70425853981715, 9.636593583959987, 8.655657323657612, 7.813167493762675, 6.866419899776322, 5.957826491119165, 5.092820420059887, 5.918480042406586, 6.846845508736406, 7.825632243035247, 8.784916756794503, 9.80391523461614, 10.744606299246573, 11.724549088812227, 12.719888423040906, 13.712409277797708, 13.610127672640559, 12.617755741130477, 11.668011991961698, 10.677234871843778, 9.728893161190879, 8.711223150148474, 7.709812658394138, 8.74466510404047, 7.876272453346017, 7.013960400030786, 6.149273307302001, 6.941495535974369, 7.900731413768819, 8.82762053544828, 9.716288392269448, 10.787456243395289, 11.730182396222212, 12.749882971817577, 13.674107218547656, 13.650365637204398, 12.642372878996726, 11.679826297961782, 10.72520153132643, 9.723691837041526, 8.758879062703496, 7.756570561748689, 6.739004754260936, 9.810980154674038, 8.912470886830922, 7.9824460394649694, 7.12220961328225, 7.91312236632692, 8.850959306451943, 9.821093493920372, 10.711059675269192, 11.726473525033319, 12.742251679365701, 13.67505355702594, 13.699277586778464, 12.735318318979521, 11.781108887652861, 10.735107774601607, 9.772860099541417, 8.72201849069539, 7.745911360572283, 6.811493105739188, 5.8136467718497435, 10.863352835914926, 9.962722236596285, 8.967604674165663, 8.05480822205424, 8.923852558691785, 9.808284465904778, 10.766361702342552, 11.708227144233057, 12.657462248248232, 13.598234255186476, 13.695575859431324, 12.767730910013684, 11.807621073095625, 10.877307847453338, 9.923120680110864, 8.871199043448836, 7.878179999620791, 6.818445904034612, 5.8637724173912655, 4.896712965278984, 11.842909218001372, 10.950334975396615, 9.997878328042603, 9.126301857278538, 9.893587543682887, 10.74773430871918, 11.705112884797858, 12.734070641928342, 13.684979103543768, 13.914407340183644, 12.842504614735756, 11.796062166998718, 10.837116694205486, 9.880071419866908, 8.944274232282833, 7.9865765716761965, 6.946958688628475, 5.8865742541571855, 4.937126231867381, 4.004329527044202, 12.823175611878488, 12.022644459737714, 11.056206638042642, 10.084965805778612, 10.910196668275304, 11.745580828282865, 12.70621283546537, 13.65522223721691, 14.660689135894797, 14.789465212032802, 13.73830127175902, 12.77643729985778, 11.887392403611429, 10.92499963472299, 9.91074721268618, 8.91962480367181, 7.93965493414189, 6.901197752328018, 5.899558364490307, 5.034547799131105, 13.763976154181393, 12.957469719798558, 11.989513600442837, 11.057975874768852, 11.94762748703135, 12.799271809590735, 13.72069766145308, 14.652158356062948, 15.653001162262528, 15.349918145512056, 14.291216914813765, 13.300881556538295, 12.413152939917353, 11.507327410734746, 10.574102864247545, 9.744495688297924, 8.889886561547351, 7.898561313907465, 6.962921589802442, 6.05096286710207, 14.836548163195507, 13.974972812791986, 12.919315073847601, 12.075142218601213, 12.989977771172624, 13.851841672235643, 14.652673797558135, 15.6419083476317, 15.220814778958388, 14.29266359647936, 13.341688020085785, 12.331817352428509, 11.351708519101223, 10.552707205699228, 9.632895195545805, 8.694054988435449, 8.004197498646775, 8.91051245409892, 7.9314480005292785, 6.996773571963413, 15.813822859373113, 14.807732565321373, 13.870579252077132, 13.070134118477872, 13.990498860547868, 14.803886110881166, 15.673670028122348, 15.1960305642932, 14.258989291044264, 13.323222707636294, 12.361576286704928, 11.378654530476384, 10.3910457131961, 9.526691915550188, 8.622037834356039, 7.760873407289974, 7.063532581546102, 8.027018122583806, 8.690072107863742, 7.736960320251064, 16.74986394346618, 15.755123073258707, 14.913545017966259, 14.131313598400908, 15.008017682778144, 15.741441843647001, 15.409775168978204, 14.38532840892065, 13.345016697945193, 12.366411589093456, 11.529911966878188, 10.486551987028875, 9.462342741901958, 8.527819836645689, 7.638925934568372, 6.786881777339276, 6.027214259937423, 7.007521852446466, 7.867673092958917, 8.688645967787913], [8.755346220235102, 7.767382259451274, 6.855675028294193, 5.796129443509494, 4.856612061911659, 5.791217794561111, 6.666369792291025, 7.6323712839629305, 8.651600774211534, 9.590315526863247, 10.519055001387194, 11.476487064146301, 12.549431540299853, 13.55928901186303, 14.492110380240586, 14.94340354474581, 15.867197781927668, 16.63344632423123, 17.480159061354417, 18.43425469464786, 7.75288289308782, 6.82282644990136, 5.850185870409022, 4.909840060146948, 3.92745784840506, 4.851018468307182, 5.711593417403965, 6.739982068566451, 7.754819580981212, 8.75965337742053, 9.759801136690232, 10.752440599440899, 11.700634947387215, 12.705689946841645, 13.612478387801083, 14.59120460071792, 15.631141068889157, 16.662042822232674, 17.61960227652324, 17.442553935420854, 6.900396078583297, 5.899801447387945, 4.881945396345477, 3.902904013346941, 2.9818046228428607, 3.885196894604678, 4.749301409780917, 5.79341255410107, 6.75223079066096, 7.792918342858702, 8.832567303070332, 9.845185863230459, 10.764239065528555, 11.69674842530084, 12.638048770013208, 13.647265683374824, 14.710722583640683, 15.721594326266114, 16.661106783448282, 16.48328615001377, 5.987802977588856, 4.942047096493758, 3.944734032412264, 2.892332027970674, 1.9631808232510508, 2.9075542915724304, 3.809366364586767, 4.838999936611082, 5.822807907293977, 6.808936208630906, 7.766317280012284, 8.793958073127657, 9.778672882609792, 10.754412387540242, 11.726915815702577, 12.69757682156289, 13.750261807712912, 14.745642960499145, 15.765840628148817, 15.512542368793815, 4.99879980918062, 3.94960108184535, 2.971762002759542, 1.9082425652731902, 0.977547431573844, 1.9047299939001232, 2.834407883473642, 3.8732471682928526, 4.827102796421814, 5.800572338947562, 6.865273749561734, 7.868556943050388, 8.835073675275199, 9.775807536857664, 10.770400803211215, 11.734237662487441, 12.766031539673994, 13.813899395363968, 14.856433922329378, 14.561268949251245, 4.1301793834218765, 3.1121043525022, 2.0746724886972903, 1.0721547677588565, 0.0, 1.0373919284166198, 2.005198658526264, 3.0375892048875737, 4.098755390169132, 5.168210575251195, 6.1720855786911155, 7.1162806576229345, 8.127654879815251, 9.11225241605374, 10.088612527363225, 11.031770573638113, 12.090618375459213, 13.155492614770733, 14.151839956064782, 13.503712212618316, 4.858625342946169, 3.9186684833373646, 2.94747446861867, 1.9289328395434533, 0.9659394757881097, 2.0046382534082188, 2.9819873143555884, 4.033268452910026, 5.002874774710206, 6.0270859468377305, 7.0987497618336155, 8.061669271677475, 9.072616993799052, 10.096908540341362, 11.028217060525817, 12.080919885953502, 13.104581636110368, 14.047407976485223, 13.463064751416802, 12.53399892289227, 5.789253974926529, 4.915748661734573, 3.9729265634119475, 2.9378927926656586, 1.9991656388236947, 2.9389019002344927, 3.978374351363236, 4.990081405776918, 5.948365474212988, 7.008589214678581, 8.018339378480402, 8.994536134698022, 9.992690858982868, 10.930895493757982, 11.994239377383725, 13.0140225610809, 13.961442480399768, 13.510137795218172, 12.554891970172552, 11.545346004107255, 6.721672587318926, 5.8275130854113915, 4.847498360725144, 3.880647433499176, 2.9249892972396214, 3.9072429053313456, 4.958374474955662, 5.893898379791093, 6.874167047358778, 7.897515476056037, 8.915429292890162, 9.954390296127714, 10.933963441769636, 11.860464220292071, 12.815204875301651, 13.742654761355235, 13.527572839198559, 12.561976573126504, 11.51678613066454, 10.577305276308545, 7.775414523153256, 6.795582754169667, 5.794960852516029, 4.812830178795725, 3.8699608481234646, 4.851231856701832, 5.787520980511402, 6.818622429317488, 7.807848870748846, 8.737686705970056, 9.803396250693028, 10.749386440108596, 11.756729318915246, 12.82672703211665, 13.828147370245944, 13.622583340191673, 12.61265822713651, 11.631896552981168, 10.564231597124005, 9.58329533682163, 8.68713851802819, 7.740390924041837, 6.83179751538468, 5.852231651071291, 4.9131385472405285, 5.841504013570348, 6.820290747869189, 7.7795752616284455, 8.798573739450081, 9.739264804080516, 10.71920759364617, 11.71454692787485, 12.70706778263165, 13.761515441125589, 13.545393754294494, 12.595650005125716, 11.604872885007795, 10.656531174354896, 9.638861163312491, 8.637450671558156, 9.618636128305985, 8.750243477611532, 7.887931424296301, 6.908684538313405, 5.9361540408083115, 6.89538991860276, 7.822279040282222, 8.710946897103389, 9.78211474822923, 10.724840901056155, 11.74454147665152, 12.668765723381599, 13.700157933551456, 13.570010892160743, 12.6074643111258, 11.652839544490448, 10.651329850205544, 9.686517075867513, 8.684208574912706, 7.666642767424953, 10.684951178939553, 9.786441911096437, 8.815732608716031, 7.8816208442936535, 6.907780871160863, 7.845617811285884, 8.815751998754314, 9.705718180103133, 10.72113202986726, 11.736910184199642, 12.669712061859881, 13.693251781263463, 13.662956332143539, 12.708746900816879, 11.662745787765624, 10.700498112705434, 9.649656503859408, 8.6735493737363, 7.739131118903205, 6.741284785013761, 11.73732386018044, 10.8366932608618, 9.800891243416725, 8.814219453065643, 7.918511063525727, 8.80294297073872, 9.761020207176493, 10.702885649066998, 11.652120753082173, 12.592892760020417, 13.637606084141911, 13.839885677772543, 12.879775840854483, 11.949462615212198, 10.995275447869725, 9.943353811207697, 8.95033476737965, 7.890600671793469, 6.8488280178912175, 5.824350978443001, 12.716880242266887, 11.82430599966213, 10.831164897293664, 9.855157777378778, 8.88824604851683, 9.74239281355312, 10.699771389631799, 11.728729146762284, 12.679637608377709, 13.522852740913555, 13.914659382494614, 12.868216934757577, 11.909271461964344, 10.952226187625767, 10.016429000041692, 9.058731339435054, 8.019113456387332, 6.958729021916042, 6.009280999626238, 5.076484294803059, 13.697146636144003, 12.847076598355281, 11.785062558142883, 10.813821725878853, 9.904855173109247, 10.740239333116806, 11.700871340299312, 12.64988074205085, 13.655347640728738, 14.54696202801274, 14.327631601868886, 13.365767629967646, 12.521148204984886, 11.624508767892172, 10.684069276331023, 9.80072074167298, 9.011809701900747, 7.973352520086875, 6.971713132249164, 6.069586184871183, 14.637947178446908, 13.686325639898799, 12.718369520543078, 11.786831794869093, 10.942285991865292, 11.793930314424676, 12.715356166287021, 13.646816860896887, 14.64765966709647, 14.447288666384775, 13.388587435686484, 12.398252077411014, 11.510523460790072, 10.604697931607465, 9.671473385120263, 8.841866209170643, 9.720105801871915, 8.970716081666321, 8.035076357561298, 7.027157037782841, 15.710519187461022, 14.703828732892227, 13.648170993947842, 12.803998138701454, 11.984636276006567, 12.846500177069585, 13.647332302392076, 14.63656685246564, 14.318185299831107, 13.390034117352078, 12.439058540958504, 11.429187873301228, 10.449079039973942, 9.650077726571947, 8.730265716418524, 7.791425509308168, 8.720819107630495, 9.6504554181118, 8.907642171210048, 7.972967742644183, 16.559579644909274, 15.536588485421614, 14.599435172177373, 13.798990038578113, 12.985157365381811, 13.798544615715107, 14.66832853295629, 14.293401085165918, 13.356359811916983, 12.420593228509013, 11.458946807577647, 10.476025051349103, 9.488416234068819, 8.624062436422907, 7.719408355228758, 6.858243928162694, 7.819423534223018, 8.782909075260722, 9.656259687586658, 8.70314789997398, 17.49562072900234, 16.483978993358946, 15.6424009380665, 14.860169518501149, 14.002676187612087, 14.736100348480942, 14.507145689850923, 13.482698929793369, 12.442387218817911, 11.463782109966175, 10.627282487750907, 9.583922507901594, 8.559713262774677, 7.625190357518408, 6.736296455441091, 5.884252298211996, 6.836482443913702, 7.816790036422745, 8.830978971136952, 9.65483354751083], [9.718327254150852, 8.730363293367024, 7.818656062209943, 6.759110477425243, 5.8195930958274085, 4.899833703824303, 5.7614839893052565, 6.727485480977162, 7.746714971225765, 8.685429723877478, 9.614169198401425, 10.571601261160533, 11.644545737314084, 12.65440320887726, 13.587224577254817, 14.57890686970715, 15.630320324394237, 16.59304880784767, 17.65289486225986, 18.72071087396814, 8.71586392700357, 7.78580748381711, 6.813166904324772, 5.872821094062698, 4.89043888232081, 3.9596343775703744, 4.806707614418197, 5.835096265580682, 6.849933777995443, 7.854767574434762, 8.854915333704463, 9.84755479645513, 10.795749144401446, 11.800804143855876, 12.707592584815314, 13.68631879773215, 14.726255265903388, 15.757157019246904, 16.714716473537468, 17.730450981007117, 7.863377112499047, 6.862782481303696, 5.8449264302612285, 4.865885047262691, 3.944785656758611, 2.99381280386787, 3.844415606795148, 4.888526751115301, 5.847344987675191, 6.888032539872933, 7.927681500084565, 8.94030006024469, 9.859353262542786, 10.79186262231507, 11.73316296702744, 12.742379880389056, 13.805836780654914, 14.816708523280345, 15.756220980462512, 16.77166446681106, 6.950784011504606, 5.905028130409509, 4.907715066328015, 3.855313061886424, 2.926161857166801, 2.0161702008356226, 2.904480561600998, 3.9341141336253136, 4.917922104308208, 5.904050405645138, 6.861431477026516, 7.889072270141888, 8.873787079624023, 9.849526584554473, 10.822030012716809, 11.792691018577122, 12.845376004727143, 13.840757157513377, 14.860954825163049, 15.800920685591105, 5.9617808430963715, 4.912582115761101, 3.9347430366752927, 2.8712235991889408, 1.9405284654895945, 1.0133459031633154, 1.9295220804878728, 2.9683613653070835, 3.922216993436045, 4.895686535961794, 5.960387946575965, 6.963671140064619, 7.93018787228943, 8.870921733871896, 9.865515000225447, 10.829351859501672, 11.861145736688226, 12.9090135923782, 13.95154811934361, 14.896988367873648, 5.167571311838497, 4.14949628091882, 3.11206441711391, 2.1095466961754763, 1.0373919284166198, 0.0, 0.9678067301096446, 2.000197276470954, 3.0613634617525127, 4.130818646834576, 5.134693650274496, 6.078888729206315, 7.090262951398632, 8.074860487637121, 9.051220598946605, 9.994378645221493, 11.053226447042594, 12.118100686354111, 13.11444802764816, 14.128693404621448, 5.896017271362789, 4.956060411753985, 3.9848663970352893, 2.966324767960073, 2.0033314042047294, 0.9672463249915992, 1.9445953859389689, 2.9958765244934056, 3.965482846293586, 4.989694018421111, 6.061357833416996, 7.024277343260855, 8.035225065382432, 9.059516611924742, 9.990825132109197, 11.043527957536883, 12.067189707693748, 13.010016048068604, 14.014685545988824, 13.541681309333908, 6.826645903343149, 5.953140590151193, 4.998672246709862, 3.946667128921341, 2.9487198457316235, 2.0089835843208257, 3.0065152207709787, 3.952689477360298, 4.910973545796368, 5.971197286261962, 6.980947450063782, 7.957144206281401, 8.955298930566247, 9.89350356534136, 10.956847448967103, 11.976630632664278, 12.924050551983147, 13.908336142538422, 13.562574356614189, 12.553028390548894, 7.759064515735545, 6.7770672923193205, 5.797052567633073, 4.830201640407105, 3.8745435041475504, 3.045554413084866, 3.986515344363405, 4.922039249198836, 5.902307916766521, 6.925656345463779, 7.943570162297904, 8.982531165535457, 9.962104311177379, 10.857786823707869, 11.812527478717449, 12.739977364771033, 13.673991176185284, 13.599368501543124, 12.55417805908116, 11.584987662750184, 8.801212950941348, 7.745136961077597, 6.744515059423958, 5.762384385703654, 4.819515055031394, 4.023796012132724, 4.960085135942293, 5.876580776045597, 6.848692457236763, 7.778530292457972, 8.844239837180943, 9.790230026596511, 10.797572905403161, 11.850556532972222, 12.849789807444886, 13.738332435030806, 13.65005015555313, 12.669288481397787, 11.601623525540624, 10.590977723263268, 9.63669272493612, 8.689945130949766, 7.781351722292609, 6.801785857979219, 5.8626927541484575, 5.091665792443404, 5.99285490330008, 6.932761892916917, 7.902714488240424, 8.780108390568433, 9.760051180134086, 10.755390514362764, 11.747911369119565, 12.78534494198116, 13.777716873491242, 13.633041933542335, 12.642264813424415, 11.693923102771516, 10.67625309172911, 9.674842599974776, 10.568190335213915, 9.699797684519462, 8.837485631204231, 7.858238745221333, 6.88570824771624, 6.145551697475817, 6.994843195713114, 7.86413352839186, 8.9353013795177, 9.765684487544071, 10.785385063139437, 11.709609309869514, 12.74100152003937, 13.748994278247043, 13.644856239542419, 12.690231472907067, 11.688721778622163, 10.723909004284133, 9.721600503329327, 8.704034695841573, 11.634505385847483, 10.735996118004367, 9.76528681562396, 8.831175051201582, 7.857335078068791, 7.095779590158941, 8.04618568063553, 8.858904811391604, 9.87431866115573, 10.789084817269815, 11.721886694930054, 12.734095367751378, 13.666219643381924, 13.632097744159594, 12.700137716182244, 11.737890041122053, 10.687048432276027, 9.71094130215292, 8.776523047319825, 7.7786767134303805, 12.68687806708837, 11.78624746776973, 10.750445450324653, 9.763773659973571, 8.868065270433656, 8.053104749611776, 8.99145388905771, 9.856072280355468, 10.805307384370643, 11.746079391308887, 12.689780717212084, 13.617625666629724, 13.622505006810355, 12.69885776856374, 11.744670601221266, 10.980745739624318, 9.98772669579627, 8.927992600210091, 7.886219946307837, 6.861742906859621, 13.666434449174817, 12.77386020657006, 11.780719104201594, 10.804711984286707, 9.837800255424758, 8.992554592426178, 9.93443603467076, 10.881915778050754, 11.832824239666179, 12.676039372202025, 13.619056246213791, 13.44125695984094, 12.652000627920216, 11.694955353581639, 10.759158165997563, 10.096123267851675, 9.056505384803954, 7.996120950332664, 7.0466729280428595, 6.1138762232196795, 14.646700843051933, 13.79663080526321, 12.734616765050811, 11.763375932786781, 10.854409380017175, 9.990401111989863, 10.935535985338273, 11.847004299495701, 12.808534272017209, 13.70014865930121, 13.422745798883117, 12.460881826981877, 11.616262401999117, 10.719622964906403, 9.792685185594216, 10.750379827090267, 10.049201630317368, 9.010744448503496, 7.991050329808412, 7.032567218786935, 15.587501385354837, 14.635879846806727, 13.667923727451006, 12.73638600177702, 11.89184019877322, 11.044092093297733, 11.950020811325983, 12.843940418341738, 13.80084629838494, 13.542402863399008, 12.483701632700715, 11.493366274425245, 10.605637657804303, 9.699812128621696, 8.780089294383457, 9.791525294587931, 10.669764887289205, 10.008108010082942, 9.017616610480584, 7.99013807169859, 16.660073394368954, 15.653382939800156, 14.59772520085577, 13.753552345609382, 12.934190482914495, 12.096661955942642, 12.881996947431038, 13.83369040991049, 13.41329949684534, 12.485148314366311, 11.534172737972735, 10.524302070315459, 9.544193236988173, 8.745191923586178, 7.838881625681717, 8.741084594725457, 9.670478193047785, 10.60011450352909, 9.870623205125797, 8.935948776559933, 17.509133851817204, 16.486142692329544, 15.5489893790853, 14.748544245486041, 13.93471157228974, 13.048706394588164, 13.902993177995251, 13.388515282180151, 12.451474008931216, 11.515707425523246, 10.554061004591878, 9.571139248363334, 8.58353043108305, 7.719176633437139, 6.828024264491951, 7.807903013579984, 8.769082619640308, 9.732568160678012, 10.619240721502408, 9.666128933889729, 18.44517493591027, 17.433533200266876, 16.591955144974428, 15.809723725409077, 14.952230394520015, 13.986262127354, 13.602259886865154, 12.5778131268076, 11.537501415832143, 10.558896306980406, 9.722396684765139, 8.679036704915823, 7.654827459788907, 6.720304554532639, 5.8449123647042835, 6.833911383629285, 7.799463477829452, 8.779771070338494, 9.793960005052702, 10.617814581426579], [10.596374590939284, 9.608410630155456, 8.696703398998373, 7.6371578142136745, 6.69764043261584, 5.774752556912965, 4.793677259195611, 5.759678750867517, 6.7789082411161194, 7.717622993767832, 8.64636246829178, 9.603794531050887, 10.67673900720444, 11.686596478767616, 12.619417847145172, 13.611100139597506, 14.662513594284592, 15.625242077738022, 16.685088132150213, 17.752904143858494, 9.593911263792002, 8.663854820605541, 7.691214241113204, 6.7508684308511295, 5.768486219109241, 4.836527955589576, 3.8389008843085515, 4.867289535471037, 5.882127047885798, 6.886960844325117, 7.887108603594819, 8.879748066345487, 9.827942414291803, 10.832997413746233, 11.73978585470567, 12.718512067622505, 13.758448535793743, 14.78935028913726, 15.746909743427825, 16.762644250897473, 8.741424449287477, 7.740829818092126, 6.722973767049659, 5.743932384051123, 4.822832993547042, 3.8707063818870715, 2.876608876685503, 3.920720021005656, 4.879538257565546, 5.920225809763288, 6.9598747699749195, 7.972493330135044, 8.89154653243314, 9.824055892205426, 10.765356236917794, 11.77457315027941, 12.83803005054527, 13.8489017931707, 14.788414250352867, 15.803857736701417, 7.828831348293036, 6.783075467197939, 5.785762403116446, 4.733360398674856, 3.8042091939552325, 2.893063778854824, 1.9366738314913532, 2.966307403515669, 3.950115374198563, 4.936243675535493, 5.8936247469168705, 6.921265540032243, 7.905980349514377, 8.881719854444828, 9.854223282607164, 10.824884288467477, 11.877569274617498, 12.872950427403731, 13.893148095053403, 14.83311395548146, 6.839828179884802, 5.790629452549531, 4.812790373463724, 3.749270935977372, 2.818575802278026, 1.8913932399517468, 0.9617153503782281, 2.000554635197439, 2.9544102633264004, 3.9278798058521485, 4.99258121646632, 5.995864409954974, 6.962381142179785, 7.9031150037622515, 8.897708270115801, 9.861545129392027, 10.89333900657858, 11.941206862268555, 12.983741389233964, 13.929181637764003, 6.13537804194814, 5.117303011028463, 4.079871147223554, 3.0773534262851205, 2.005198658526264, 0.9678067301096446, 0.0, 1.0323905463613094, 2.093556731642868, 3.1630119167249315, 4.166886920164852, 5.111081999096671, 6.122456221288987, 7.107053757527476, 8.08341386883696, 9.026571915111848, 10.085419716932948, 11.150293956244468, 12.146641297538517, 13.160886674511804, 6.863824001472433, 5.923867141863629, 4.952673127144934, 3.9341314980697173, 2.9711381343143737, 1.935053055101244, 0.9767886558293242, 2.028069794383761, 2.997676116183941, 4.021887288311466, 5.093551103307351, 6.056470613151211, 7.067418335272788, 8.091709881815097, 9.023018401999552, 10.075721227427238, 11.099382977584103, 12.042209317958958, 13.046878815879179, 13.975944644403711, 7.794452633452793, 6.9209473202608365, 5.9664789768195075, 4.914473859030986, 3.916526575841268, 2.9767903144304704, 2.038708490661334, 2.984882747250653, 3.9431668156867232, 5.003390556152317, 6.013140719954137, 6.989337476171756, 7.987492200456603, 8.925696835231717, 9.98904071885746, 11.008823902554635, 11.956243821873503, 12.940529412428779, 13.8957752374744, 13.520835120658537, 8.72687124584519, 7.744874022428965, 6.764859297742717, 5.798008370516749, 4.842350234257195, 4.01336114319451, 3.0187086142537605, 3.9542325190891905, 4.934501186656876, 5.957849615354134, 6.975763432188259, 8.014724435425812, 8.994297581067734, 9.889980093598226, 10.844720748607806, 11.77217063466139, 12.70618444607564, 13.671780712147696, 13.521984789190805, 12.552794392859827, 9.769019681050992, 8.71294369118724, 7.712321789533602, 6.730191115813298, 5.787321785141038, 4.9590837979855795, 4.02279467417601, 4.908774045935952, 5.880885727127118, 6.810723562348326, 7.876433107071299, 8.822423296486868, 9.829766175293518, 10.882749802862579, 11.881983077335242, 12.770525704921162, 13.680674428117811, 13.637095211507432, 12.56943025565027, 11.558784453372912, 10.604499455045763, 9.65775186105941, 8.749158452402252, 7.769592588088864, 6.830499484258102, 6.0269535782962596, 5.0555644415337975, 5.9649551628072714, 6.9349077581307785, 7.812301660458788, 8.792244450024441, 9.78758378425312, 10.780104639009922, 11.817538211871517, 12.809910143381599, 13.759653892550379, 13.61007154353406, 12.66172983288116, 11.644059821838756, 10.64264933008442, 11.535997065323558, 10.667604414629105, 9.805292361313874, 8.826045475330979, 7.853514977825885, 7.073152112601714, 6.057552733946831, 6.896326798282215, 7.967494649408056, 8.797877757434426, 9.817578333029791, 10.74180257975987, 11.773194789929727, 12.7811875481374, 13.743734129172344, 13.658038203016712, 12.656528508731808, 11.691715734393778, 10.68940723343897, 9.671841425951218, 12.602312115957126, 11.70380284811401, 10.733093545733604, 9.798981781311227, 8.825141808178437, 8.023380005284839, 7.108895218869247, 7.891098081281959, 8.906511931046087, 9.82127808716017, 10.75407996482041, 11.766288637641734, 12.69841291327228, 12.780651064666868, 13.561455944188879, 12.705696771231699, 11.654855162385672, 10.678748032262565, 9.74432977742947, 8.746483443540026, 13.654684797198014, 12.754054197879373, 11.718252180434298, 10.731580390083217, 9.8358720005433, 8.980705164737675, 8.054163427291426, 8.888265550245823, 9.837500654260998, 10.778272661199242, 11.721973987102439, 12.649818936520079, 12.669235760185552, 11.847411089071013, 12.605875671160177, 11.948552469733961, 10.955533425905914, 9.895799330319734, 8.854026676417481, 7.829549636969265, 14.16676740432851, 13.741666936679703, 12.748525834311238, 11.772518714396352, 10.805606985534403, 9.920155007552076, 8.997145572904477, 9.914109047941109, 10.865017509556534, 11.70823264209238, 12.651249516104146, 12.473450229731295, 11.698731381295413, 10.79674444965284, 11.620363235936475, 11.063929997961319, 10.024312114913597, 8.963927680442307, 8.014479658152503, 7.081682953329323, 14.898961121815669, 14.764437535372855, 13.702423495160456, 12.731182662896426, 11.82221611012682, 10.918001527115761, 9.99824552357199, 10.879197569386056, 11.840727541907563, 12.732341929191564, 12.454939068773472, 11.493075096872232, 10.648455671889472, 9.751816234796758, 10.653890255533128, 11.611584897029182, 10.972615897195695, 9.934158715381823, 8.869097666596842, 7.910614555575365, 15.833830996976316, 15.603686576916372, 14.635730457560651, 13.704192731886666, 12.859646928882865, 11.971692508423631, 11.0127303495597, 11.876133688232095, 12.833039568275295, 12.574596133289361, 11.51589490259107, 10.5255595443156, 9.637830927694658, 8.732005398512051, 9.641294364322368, 10.652730364526846, 11.530969957228118, 10.9010295902074, 9.895663947269014, 8.86818540848702, 16.797620442351395, 16.6211896699098, 15.565531930965415, 14.721359075719027, 13.90199721302414, 13.00625900592284, 11.944706485664755, 12.865883679800847, 12.445492766735693, 11.517341584256664, 10.56636600786309, 9.556495340205814, 8.576386506878528, 7.777385193476533, 8.700086695620628, 9.60228966466437, 10.531683262986698, 11.461319573468003, 10.748670541914228, 9.813996113348363, 17.774895138529, 17.453949422439187, 16.516796109194946, 15.716350975595686, 14.902518302399384, 13.908655893503752, 12.965702716228968, 12.420708552070504, 11.483667278821569, 10.547900695413599, 9.586254274482233, 8.603332518253689, 7.615723700973405, 6.751369903327494, 7.689229334430863, 8.669108083518896, 9.630287689579221, 10.593773230616925, 11.49728805829084, 10.544176270678161, 18.670958533082818, 17.645378577150524, 16.61628746390275, 15.626635735132608, 14.551827496731228, 13.636525719846336, 12.634453156755509, 11.610006396697955, 10.569694685722498, 9.591089576870761, 8.754589954655494, 7.711229974806178, 6.687020729679262, 5.752497824422994, 6.706117434643195, 7.695116453568197, 8.677510814617882, 9.657818407126925, 10.672007341841132, 11.495861918215011], [11.628765137300595, 10.640801176516767, 9.729093945359683, 8.669548360574984, 7.730030978977149, 6.807143103274274, 5.826067805556921, 5.1164598194288065, 5.9650073885485915, 6.903722141200304, 7.832461615724252, 8.78989367848336, 9.862838154636911, 10.841442924244696, 11.774264292622252, 12.728193067958093, 13.763420688453108, 14.726149171906538, 15.785995226318729, 16.826217968565956, 10.626301810153313, 9.696245366966853, 8.723604787474514, 7.783258977212439, 6.800876765470551, 5.868918501950885, 4.871291430669861, 4.0472566211381595, 5.025243439202025, 6.030077235641343, 7.030224994911046, 7.968925084731293, 8.917119432677609, 9.907407717023496, 10.784710231642643, 11.76343644455948, 12.803372912730717, 13.834274666074233, 14.7918341203648, 15.807568627834447, 9.773814995648786, 8.773220364453435, 7.755364313410968, 6.776322930412433, 5.855223539908351, 4.903096928248381, 3.9089994230468124, 3.100687106672779, 4.003066053646324, 5.031243515370946, 6.0099266325403535, 7.022545192700478, 7.936470909370114, 8.8689802691424, 9.810280613854768, 10.819497527216384, 11.882954427482243, 12.893826170107676, 13.833338627289843, 14.848782113638393, 8.861221894654346, 7.815466013559249, 6.8181529494777555, 5.7657509450361655, 4.836599740316542, 3.9254543252161334, 2.9690643778526624, 2.098906476946977, 3.0278404328941972, 3.986295538100927, 4.943676609482305, 5.971317402597677, 6.950904726451351, 7.926644231381801, 8.899147659544138, 9.86980866540445, 10.922493651554472, 11.917874804340707, 12.93807247199038, 13.878038332418436, 7.872218726246111, 6.823019998910841, 5.845180919825033, 4.781661482338682, 3.8509663486393353, 2.9237837863130562, 1.9941058967395375, 1.0596856029892732, 1.999334640263374, 2.972804182789122, 4.037505593403293, 5.040788786891948, 6.007305519116759, 6.9480393806992256, 7.942632647052776, 8.906469506329003, 9.938263383515556, 10.98613123920553, 12.02866576617094, 12.974106014700979, 7.1677685883094515, 6.149693557389774, 5.112261693584864, 4.109743972646431, 3.037589204887574, 2.000197276470954, 1.0323905463613094, 0.0, 1.0611661852815586, 2.130621370363622, 3.1344963738035423, 4.078691452735361, 5.090065674927677, 6.0746632111661665, 7.0510233224756504, 7.994181368750539, 9.053029170571639, 10.117903409883159, 11.114250751177208, 12.128496128150495, 7.896214547833742, 6.956257688224938, 5.985063673506243, 4.966522044431027, 4.003528680675684, 2.9674436014625534, 2.0091792021906336, 1.009124831581449, 1.9787311533816292, 3.002942325509154, 4.074606140505039, 5.024080066789901, 6.035027788911479, 7.059319335453789, 7.990627855638243, 9.043330681065928, 10.066992431222793, 11.009818771597649, 12.01448826951787, 12.943554098042402, 8.826843179814103, 7.953337866622146, 6.998869523180817, 5.946864405392295, 4.948917122202578, 4.00918086079178, 2.9937390664558885, 1.9659377844483412, 2.9242218528844113, 3.9844455933500047, 4.994195757151825, 5.970392513369444, 6.968547237654291, 7.906751872429405, 8.964196521606079, 9.983979705303254, 10.931399624622122, 11.915685215177398, 12.870931040223018, 13.880477006288313, 9.7592617922065, 8.777264568790274, 7.7972498441040266, 6.830398916878059, 5.874740780618504, 4.939922864535151, 3.874823157548066, 2.939299252712636, 3.919567920280321, 4.94291634897758, 5.960830165811704, 6.996517377711366, 7.976090523353287, 8.871035130795914, 9.825775785805494, 10.753225671859077, 11.687239483273329, 12.652835749345384, 13.698026191807347, 13.573887477580222, 10.790112765771386, 9.734036775907635, 8.733414874253997, 7.739338680530513, 6.796469349858253, 5.815198341279885, 4.878909217470316, 3.8938407795593974, 4.865952460750563, 5.795790295971772, 6.861499840694744, 7.807490030110313, 8.814832908916964, 9.863804840060267, 10.86303811453293, 11.75158074211885, 12.6617294653155, 13.58613365088811, 13.601820802011579, 12.579877538093307, 11.625592539766158, 10.678844945779804, 9.770251537122647, 8.778740152806078, 7.8114335879203844, 6.883068121590565, 5.909306410189974, 4.950021896430718, 5.919974491754225, 6.797368394082233, 7.777311183647887, 8.772650517876567, 9.765171372633368, 10.798593249069205, 11.790965180579287, 12.740708929748067, 13.682271037910272, 13.69412037924247, 12.676450368200065, 11.67503987644573, 12.557090150043953, 11.6886974993495, 10.82638544603427, 9.835193040048193, 8.834449081488167, 7.926894081257891, 6.911294702603008, 5.881393531905661, 6.952561383031502, 7.782944491057872, 8.802645066653238, 9.726869313383316, 10.758261523553173, 11.766254281760846, 12.72880086279579, 13.683425629431142, 13.688919055093118, 12.724106280755088, 11.72179777980028, 10.704231972312527, 13.62340520067752, 12.724895932834405, 11.742241110450818, 10.80812934602844, 9.804440834217338, 8.84109815615765, 7.870963968689219, 6.8761648149054055, 7.891578664669533, 8.806344820783616, 9.739146698443855, 10.75135537126518, 11.683479646895726, 12.637689078222387, 13.68369019127364, 13.738087317593008, 12.687245708746982, 11.711138578623874, 10.77672032379078, 9.778873989901335, 13.949785395619875, 13.775147282599768, 12.727399745151512, 11.74072795480043, 10.815171026582203, 9.798423315610485, 8.816232177111399, 7.87333228386927, 8.822567387884446, 9.76333939482269, 10.707040720725885, 11.634885670143525, 12.026016828746842, 12.879801635432322, 13.638266217521487, 12.98094301609527, 11.987923972267225, 10.928189876681046, 9.88641722277879, 8.861940183330574, 13.134376857967201, 14.179281758015698, 13.757673399028452, 12.721736929093867, 11.754825200231918, 10.716592898803128, 9.75921432272445, 8.899175781564555, 9.850084243179982, 10.693299375715828, 11.636316249727592, 11.830231298292585, 11.055512449856703, 11.82913499601415, 12.652753782297784, 12.09632054432263, 11.056702661274908, 9.996318226803618, 9.046870204513814, 8.114073499690635, 13.943885498752644, 14.889978899091405, 14.651641709857971, 13.680400877593941, 12.684285286517259, 11.714439418366814, 10.760314273391963, 9.864264303009502, 10.825794275531011, 11.717408662815012, 11.774196531944092, 10.849856165433522, 10.00523674045076, 10.784206781158067, 11.686280801894437, 12.643975443390492, 12.005006443557004, 10.966549261743133, 9.901488212958151, 8.943005101936674, 14.878755373913291, 15.843187348825507, 15.584948672258166, 14.65341094658418, 13.721716105273304, 12.768130399674684, 11.774799099379672, 10.86120042185554, 11.818106301898743, 11.760695280721833, 10.827652950230645, 9.88234061287689, 8.994611996255946, 9.76439594487336, 10.673684910683678, 11.685120910888156, 12.563360503589427, 11.93342013656871, 10.928054493630324, 9.90057595484833, 15.84254481928837, 16.886331255999366, 16.51475014566293, 15.670577290416542, 14.764066389414578, 13.768327755742812, 12.706775235484727, 11.850950413424291, 11.631591914168165, 10.703440731689136, 9.875838619102076, 8.913276408767103, 7.933167575439817, 8.809775739837843, 9.732477241981938, 10.63468021102568, 11.564073809348008, 12.493710119829313, 11.781061088275537, 10.846386659709673, 16.819819515465976, 17.490156259891634, 16.553002946647393, 15.546183156547226, 14.491506001129505, 13.488656183965459, 12.545703006690674, 11.606807699502976, 10.669766426254041, 9.733999842846071, 8.887007172839517, 7.960113586814978, 6.9725047695346944, 7.7837604496888035, 8.721619880792172, 9.701498629880206, 10.66267823594053, 11.626163776978235, 12.529678604652151, 11.576566817039472, 17.755860599559043, 16.746285671319036, 15.717194558071267, 14.743728663493195, 13.668920425091816, 12.791372165323416, 11.789299602232589, 10.796105544130427, 9.75579383315497, 8.777188724303233, 7.9406891020879655, 6.89732912223865, 6.043801798240552, 6.784888370784303, 7.7385079810045045, 8.727506999929506, 9.709901360979192, 10.690208953488234, 11.704397888202442, 12.528252464576322], [12.565522608491046, 11.577558647707217, 10.665851416550133, 9.606305831765434, 8.6667884501676, 7.743900574464725, 6.762825276747371, 5.916490817680684, 4.903841203267032, 5.842555955918745, 6.771295430442693, 7.7287274932018, 8.801671969355352, 9.780276738963137, 10.713098107340693, 11.667026882676534, 12.702254503171549, 13.66498298662498, 14.724829041037168, 15.765051783284395, 11.563059281343763, 10.633002838157303, 9.660362258664964, 8.72001644840289, 7.737634236661001, 6.805675973141335, 5.808048901860311, 4.847287619390037, 3.9640772539204656, 4.968911050359784, 5.9690588096294865, 6.9077588994497345, 7.85595324739605, 8.846241531741937, 9.723544046361084, 10.70227025927792, 11.742206727449158, 12.773108480792676, 13.730667935083241, 14.746402442552888, 10.710572466839237, 9.709977835643885, 8.692121784601419, 7.713080401602883, 6.791981011098802, 5.839854399438831, 4.845756894237263, 3.900718104924656, 2.9418998683647657, 3.970077330089387, 4.948760447258795, 5.96137900741892, 6.875304724088555, 7.8078140838608405, 8.74911442857321, 9.758331341934825, 10.821788242200684, 11.832659984826117, 12.772172442008284, 13.787615928356834, 9.797979365844796, 8.752223484749699, 7.754910420668206, 6.702508416226616, 5.773357211506992, 4.862211796406584, 3.9058218490431127, 2.931244957068481, 1.9666742476126386, 2.9251293528193685, 3.8825104242007464, 4.910151217316119, 5.889738541169792, 6.865478046100242, 7.837981474262579, 8.808642480122892, 9.861327466272913, 10.856708619059148, 11.87690628670882, 12.816872147136877, 8.80897619743656, 7.759777470101291, 6.781938391015483, 5.718418953529132, 4.787723819829786, 3.8605412575035065, 2.930863367929988, 1.892024083110777, 0.9381684549818154, 1.9116379975075635, 2.9763394081217345, 3.979622601610389, 4.9461393338352, 5.8868731954176665, 6.881466461771217, 7.845303321047443, 8.877097198233997, 9.924965053923971, 10.967499580889381, 11.91293982941942, 8.228934773591009, 7.210859742671332, 6.1734278788664225, 5.170910157927989, 4.098755390169132, 3.0613634617525127, 2.093556731642868, 1.0611661852815586, 0.0, 1.0694551850820633, 2.0733301885219833, 3.017525267453802, 4.028899489646118, 5.013497025884607, 5.989857137194091, 6.93301518346898, 7.99186298529008, 9.056737224601598, 10.053084565895647, 11.067329942868934, 8.9573807331153, 8.017423873506496, 7.046229858787802, 6.027688229712586, 5.064694865957242, 4.028609786744112, 3.063166022387228, 2.011884883832791, 1.0422785620326107, 2.0556286535688244, 3.0694064188640158, 3.962913881508342, 4.97386160362992, 5.99815315017223, 6.929461670356684, 7.982164495784368, 9.005826245941233, 9.948652586316088, 10.953322084236309, 11.88238791276084, 9.88800936509566, 8.973801545055265, 8.010468836751635, 6.958463718963112, 5.960516435773394, 5.020780174362597, 3.9813077232338534, 2.953506441226306, 1.995222372790236, 3.05026494243238, 4.0600151062342, 4.944221887696841, 5.942376611981688, 6.880581246756801, 7.90303033632452, 8.922813520021695, 9.870233439340563, 10.854519029895839, 11.80976485494146, 12.819310821006756, 10.820427977488057, 9.788863882361092, 8.808849157674844, 7.841998230448876, 6.886340094189322, 5.927491521313116, 4.862391814326031, 3.9268679094906007, 2.9973306224436076, 4.020679051140866, 5.038592867974991, 5.970346752038763, 6.949919897680684, 7.844864505123311, 8.799605160132892, 9.727055046186475, 10.661068857600727, 11.626665123672781, 12.671855566134745, 13.712562023198581, 11.777681422549351, 10.7216054326856, 9.720983531031962, 8.726907337308477, 7.784038006636218, 6.80276699805785, 5.866477874248281, 4.881409436337362, 3.9437151629138496, 4.873552998135058, 5.939262542858031, 6.8852527322735995, 7.89259561108025, 8.837634214387664, 9.836867488860328, 10.725410116446248, 11.635558839642897, 12.559963025215508, 13.62441009967528, 13.567446194871271, 12.613161196544123, 11.66641360255777, 10.757820193900614, 9.766308809584043, 8.799002244698348, 7.87063677836853, 6.896875066967939, 5.937590553208683, 4.99773719391751, 5.87513109624552, 6.855073885811173, 7.850413220039853, 8.842934074796654, 9.772422623396603, 10.764794554906684, 11.714538304075464, 12.65610041223767, 13.620448021672594, 13.737616553481622, 12.736206061727287, 13.544658806821918, 12.676266156127465, 11.813954102812236, 10.822761696826158, 9.822017738266132, 8.914462738035855, 7.8988633593809725, 6.868962188683626, 6.063771889808188, 6.860707193221159, 7.880407768816524, 8.804632015546602, 9.836024225716459, 10.743096083022982, 11.705642664057926, 12.660267430693278, 13.609643447039922, 13.785272466036645, 12.782963965081837, 11.765398157594085, 13.750295100258045, 13.71246458961237, 12.729809767228783, 11.795698002806406, 10.792009490995303, 9.828666812935614, 8.858532625467184, 7.8637334716833704, 7.021034403293574, 7.884107522946903, 8.816909400607141, 9.829118073428466, 10.761242349059012, 11.715451780385672, 12.669030067477031, 13.615961594730038, 13.74841189402854, 12.772304763905431, 11.837886509072337, 10.840040175182892, 12.888619210338314, 13.86018322725344, 13.714968401929477, 12.728296611578395, 11.802739683360167, 10.78599197238845, 9.803800833889364, 8.860900940647234, 8.090454272342592, 8.887097601645952, 9.784803422889171, 10.71264837230681, 11.708556477612175, 12.648691755981528, 13.602878923324, 14.042109201376828, 13.049090157548783, 11.989356061962603, 10.94758340806035, 9.923106368612133, 12.07321067268564, 13.118115572734137, 14.158752345289829, 13.709305585871832, 12.742393857009883, 11.704161555581093, 10.746782979502415, 9.88674443834252, 9.117971127638128, 9.817057582539089, 10.714078951890878, 10.828328876989412, 11.787274349782644, 12.717241644453841, 13.589511253488235, 13.157486729604187, 12.117868846556465, 11.057484412085175, 10.108036389795371, 9.175239684972192, 12.882719313471085, 13.828812713809846, 14.890826754022244, 14.667969534371906, 13.671853943295224, 12.702008075144779, 11.747882930169927, 10.851832959787467, 10.093681159989158, 10.841166869638274, 10.713030346662533, 9.847953744130349, 10.80526773870264, 11.672313429597759, 12.623038273084887, 13.580732914580942, 12.941763914747455, 11.903306732933583, 10.838245684148601, 9.879762573127124, 13.817589188631732, 14.782021163543948, 15.74997728289967, 15.640979603362146, 14.709284762051269, 13.755699056452649, 12.762367756157637, 11.848769078633506, 11.08599318635689, 10.699529095440276, 9.766486764949086, 8.880438191573717, 9.794642994507825, 10.652502593313052, 11.610442381874128, 12.621878382078606, 13.500117974779878, 12.87017760775916, 11.864811964820774, 10.83733342603878, 14.78137863400681, 15.825165070717805, 16.400648622366095, 15.38899630800084, 14.430860905223192, 13.379534437329424, 12.494963034303403, 11.485423033093507, 10.570425728886608, 9.64227454640758, 8.814672433820517, 7.9113739874639295, 8.733198573691695, 9.697882388277534, 10.669234713172388, 11.57143768221613, 12.500831280538458, 13.430467591019763, 12.717818559465988, 11.783144130900123, 15.758653330184416, 16.428990074610077, 15.491836761365835, 14.485016971265669, 13.430339815847947, 12.427489998683901, 11.484536821409117, 10.545641514221419, 9.608600240972484, 8.672833657564514, 7.825840987557958, 6.905870293173791, 7.772535767786572, 8.720517920879253, 9.658377351982622, 10.638256101070656, 11.599435707130981, 12.562921248168685, 13.466436075842601, 12.513324288229922, 16.694694414277482, 15.685119486037479, 14.656028372789708, 13.682562478211636, 12.607754239810257, 11.730205980041857, 10.72813341695103, 9.734939358848868, 8.69462764787341, 7.716022539021675, 6.8795229168064065, 5.836162936957091, 6.843832796492429, 7.721645841974754, 8.675265452194955, 9.664264471119957, 10.646658832169642, 11.626966424678685, 12.641155359392892, 13.465009935766773], [13.568093427656118, 12.58012946687229, 11.668422235715207, 10.608876650930508, 9.669359269332674, 8.746471393629799, 7.765396095912445, 6.9167059583379205, 5.90405634392427, 5.001217927650888, 5.9299574021748365, 6.816984399629898, 7.822617843047842, 8.749600426574162, 9.682421794951718, 10.63635057028756, 11.671578190782574, 12.634306674236004, 13.694152728648195, 14.73437547089542, 12.565630100508836, 11.635573657322375, 10.662933077830036, 9.722587267567961, 8.740205055826074, 7.808246792306409, 6.810619721025385, 5.8475027600472735, 4.964292394577703, 4.074380851061989, 5.041437801560221, 5.882100931203346, 6.830295279149661, 7.815565219352962, 8.69286773397211, 9.671593946888946, 10.711530415060183, 11.742432168403699, 12.699991622694267, 13.715726130163914, 11.71314328600431, 10.712548654808959, 9.694692603766493, 8.715651220767956, 7.794551830263876, 6.842425218603905, 5.848327713402337, 4.900933245581893, 3.942115009022003, 3.0257090642029647, 3.984575531945424, 4.935721039172531, 5.844628411699581, 6.777137771471866, 7.718438116184235, 8.727655029545852, 9.791111929811711, 10.801983672437142, 11.741496129619309, 12.756939615967859, 10.80055018500987, 9.754794303914773, 8.757481239833279, 7.70507923539169, 6.775928030672066, 5.864782615571658, 4.908392668208187, 3.933815776233555, 2.966889388269876, 1.9807610869329464, 2.918325508887375, 3.8844932490697297, 4.859062228780818, 5.834801733711268, 6.807305161873605, 7.7779661677339185, 8.83065115388394, 9.826032306670173, 10.846229974319845, 11.786195834747902, 9.811547016601635, 8.762348289266365, 7.784509210180557, 6.720989772694205, 5.790294638994859, 4.86311207666858, 3.9334341870950618, 2.894594902275851, 1.9407392741468896, 0.9672697316211415, 1.945663095732761, 2.9489462892214156, 3.915463021446226, 4.856196883028693, 5.850790149382243, 6.814627008658469, 7.846420885845022, 8.894288741534996, 9.936823268500406, 10.882263517030445, 9.298389958673072, 8.280314927753395, 7.242883063948486, 6.240365343010052, 5.168210575251195, 4.130818646834576, 3.1630119167249315, 2.130621370363622, 1.0694551850820633, 0.0, 1.00387500343992, 1.9480700823717387, 2.9594443045640553, 3.944041840802544, 4.920401952112028, 5.863559998386917, 6.922407800208017, 7.987282039519536, 8.983629380813584, 9.997874757786871, 9.954557071451264, 9.01460021184246, 8.043406197123765, 7.0248645680485495, 6.0618712042932055, 5.013185420561646, 4.031272100968903, 2.9799909624144663, 2.0103846406142862, 0.9861734684867611, 1.9999512337819525, 2.8934586964262787, 3.9044064185478566, 4.9286979650901666, 5.860006485274621, 6.912709310702305, 7.93637106085917, 8.879197401234027, 9.883866899154247, 10.81293272767878, 10.885185703431624, 9.94190762363694, 8.97857491533331, 7.926569797544788, 6.92862251435507, 5.988886252944273, 4.949413801815529, 3.9216125198079816, 2.9633284513719116, 1.980809757350317, 2.990559921152137, 3.874766702614778, 4.872921426899625, 5.811126061674738, 6.8335751512424565, 7.853358334939632, 8.8007782542585, 9.785063844813775, 10.740309669859396, 11.749855635924693, 11.813275527981961, 10.756969960942767, 9.77695523625652, 8.810104309030551, 7.854446172770997, 6.895597599894791, 5.830497892907706, 4.894973988072277, 3.965436701025283, 2.9722048363736926, 3.9901186532078174, 4.9008915669567, 5.880464712598621, 6.7754093200412475, 7.7301499750508285, 8.657599861104412, 9.591613672518664, 10.557209938590718, 11.602400381052682, 12.643106838116518, 12.745787501131026, 11.689711511267275, 10.689089609613637, 9.695013415890152, 8.752144085217893, 7.770873076639525, 6.834583952829956, 5.849515514919038, 4.8967304564821905, 3.966892621260982, 5.032602165983954, 5.904562661313911, 6.911905540120562, 7.7681790293056014, 8.767412303778265, 9.655954931364185, 10.566103654560834, 11.490507840133445, 12.554954914593218, 13.585588477731417, 13.581267275125798, 12.634519681139444, 11.725926272482287, 10.734414888165718, 9.767108323280024, 8.838742856950205, 7.864981145549614, 6.905696631790358, 5.950752487485852, 4.968470719371443, 5.948413508937097, 6.869723149080164, 7.862244003836965, 8.70296743831454, 9.695339369824621, 10.645083118993401, 11.586645227155607, 12.550992836590531, 13.480325348404731, 13.73338240006325, 13.699759869366144, 13.64437223470914, 12.78206018139391, 11.790867775407833, 10.790123816847807, 9.882568816617532, 8.866969437962648, 7.837068267265301, 7.01678718337653, 5.954046816347082, 6.973747391942449, 7.823941944586913, 8.85533415475677, 9.673640897940919, 10.636187478975863, 11.590812245611215, 12.540188261957859, 13.574552648910437, 13.780140303417802, 12.762574495930048, 12.680839915175982, 13.746875981916602, 13.697915845810458, 12.76380408138808, 11.760115569576978, 10.79677289151729, 9.82663870404886, 8.831839550265045, 7.974049696861916, 6.9774471460728265, 7.910249023733065, 8.848428002468777, 9.780552278099323, 10.662125884923277, 11.599574882394968, 12.546506409647975, 13.541861608303995, 13.769481102241395, 12.8350628474083, 11.837216513518856, 11.819164025256253, 12.790728042171379, 13.863714551336905, 13.69640269016007, 12.770845761941843, 11.754098050970125, 10.771906912471039, 9.829007019228909, 8.921209231710119, 7.980437224771875, 8.878143046015094, 9.79986167227657, 10.727866406652486, 11.595365860519133, 12.549553027861606, 13.471588466836126, 14.061797596807784, 12.997717348271062, 11.944759746396313, 10.920282706948097, 11.003755487603577, 12.048660387652074, 13.089297160207765, 14.162744404671141, 13.710499935591558, 12.672267634162768, 11.71488905808409, 10.854850516924195, 9.948726087005655, 8.910397205665014, 9.8074185750168, 10.771530415291537, 11.698370785542625, 12.646032499937306, 13.535065463085308, 14.22694191468625, 13.187324031638529, 12.126939597167238, 11.177491574877434, 10.244694870054255, 11.85204300108211, 12.798136401420871, 13.86015044163327, 14.8313912738973, 14.639960021876899, 13.670114153726454, 12.715989008751603, 11.819939038369142, 10.924436119356685, 9.934506492764198, 9.871692318394677, 10.833556290295917, 11.805482879359875, 12.672528570254995, 13.625609092249961, 14.583303733746014, 13.944334733912529, 12.905877552098657, 11.840816503313675, 10.882333392292198, 12.786912876242758, 13.751344851154974, 14.719300970510695, 15.564824623565343, 14.631873161096609, 13.588850026193194, 12.5856011421406, 11.633834996394402, 10.79731666490708, 9.85819106717242, 8.92514873668123, 9.880653332230954, 10.794858135165061, 11.652717733970288, 12.613013201039202, 13.624449201243678, 14.502688793944952, 13.872748426924234, 12.867382783985848, 11.839904245203854, 13.750702321617837, 14.794488758328832, 15.559310594098239, 14.547658279732982, 13.589522876955334, 12.538196409061566, 11.653625006035545, 10.64408500482565, 9.729087700618752, 8.800936518139723, 7.973334405552661, 8.911589128121168, 9.73341371434893, 10.69809752893477, 11.671805532337462, 12.574008501381204, 13.503402099703532, 14.433038410184837, 13.720389378631062, 12.785714950065197, 14.727977017795443, 15.587652046342221, 14.65049873309798, 13.643678942997813, 12.58900178758009, 11.586151970416044, 10.64319879314126, 9.704303485953561, 8.767262212704626, 7.831495629296657, 6.984502959290102, 7.906085433831029, 8.772750908443808, 9.723088740044327, 10.660948171147696, 11.64082692023573, 12.602006526296055, 13.565492067333759, 14.469006895007674, 13.515895107394995, 15.664018101888509, 14.654443173648504, 13.625352060400733, 12.651886165822662, 11.577077927421282, 10.699529667652882, 9.697457104562055, 8.755885232541358, 7.846214973167275, 6.874684510753818, 6.03818488853855, 6.836378077614329, 7.844047937149666, 8.724216661139828, 9.677836271360029, 10.66683529028503, 11.649229651334716, 12.629537243843759, 13.643726178557966, 14.467580754931845], [14.55017450318569, 13.562210542401862, 12.65050331124478, 11.590957726460081, 10.651440344862246, 9.709480146294585, 8.728404848577231, 7.807776448233807, 6.795126833820157, 5.892288417546775, 5.107447627165838, 5.813109396189978, 6.818742839607922, 7.7457254231342425, 8.678546791511799, 9.63247556684764, 10.667703187342655, 11.630431670796085, 12.690277725208276, 13.730500467455501, 13.547711176038408, 12.617654732851948, 11.64501415335961, 10.704668343097534, 9.722286131355647, 8.771255544971195, 7.773628473690171, 6.73857324994316, 5.85536288447359, 4.965451340957876, 4.037562798120301, 4.878225927763426, 5.826420275709741, 6.811690215913043, 7.68899273053219, 8.667718943449026, 9.707655411620264, 10.73855716496378, 11.696116619254347, 12.711851126723994, 12.717018289444232, 11.71642365824888, 10.698567607206416, 9.719526224207877, 8.776632905793448, 7.805433971268691, 6.8113364660671225, 5.792003735477779, 4.8331854989178895, 3.9167795540988513, 2.980700528505504, 3.931846035732611, 4.840753408259662, 5.773262768031946, 6.714563112744315, 7.723780026105934, 8.787236926371792, 9.798108668997223, 10.73762112617939, 11.75306461252794, 11.804425188449791, 10.758669307354694, 9.761356243273202, 8.70895423883161, 7.779803034111987, 6.8277913682364435, 5.871401420872973, 4.841767848848657, 3.8579598781657625, 2.871831576828833, 1.914450505447455, 2.8806182456298095, 3.8551872253408983, 4.830926730271349, 5.803430158433685, 6.774091164293999, 7.826776150444021, 8.822157303230254, 9.842354970879926, 10.782320831307983, 10.815422020041556, 9.766223292706286, 8.788384213620478, 7.724864776134126, 6.79416964243478, 5.866987080108501, 4.937309190534982, 3.8984699057157712, 2.9446142775868096, 1.9711447350610616, 0.9417880922928409, 1.9450712857814954, 2.911588018006306, 3.8523218795887724, 4.846915145942323, 5.810752005218549, 6.842545882405103, 7.890413738095077, 8.932948265060487, 9.878388513590526, 10.302264962112993, 9.284189931193316, 8.246758067388406, 7.244240346449971, 6.172085578691115, 5.134693650274495, 4.166886920164851, 3.134496373803542, 2.0733301885219833, 1.00387500343992, 0.0, 0.9441950789318186, 1.955569301124135, 2.9401668373626237, 3.916526948672108, 4.8596849949469965, 5.918532796768096, 6.9834070360796145, 7.979754377373664, 8.99399975434695, 10.958432074891183, 10.018475215282379, 9.047281200563685, 8.028739571488469, 7.065746207733125, 6.017060424001565, 5.035147104408823, 3.9838659658543865, 3.014259644054206, 1.990048471926681, 0.9960762303420325, 1.8895836929863588, 2.9005314151079364, 3.9248229616502464, 4.856131481834701, 5.908834307262385, 6.93249605741925, 7.875322397794106, 8.879991895714326, 9.809057724238858, 11.889060706871543, 10.94578262707686, 9.982449918773229, 8.930444800984707, 7.93249751779499, 6.992761256384192, 5.953288805255449, 4.925487523247901, 3.9672034548118313, 2.9846847607902367, 2.0622243295962583, 2.8708916991748583, 3.869046423459705, 4.807251058234819, 5.829700147802536, 6.8494833314997114, 7.79690325081858, 8.781188841373854, 9.736434666419475, 10.74598063248477, 12.81715053142188, 11.760844964382686, 10.780830239696439, 9.81397931247047, 8.858321176210916, 7.8994726033347105, 6.834372896347626, 5.898848991512196, 4.969311704465203, 3.9760798398136123, 3.0820626164203846, 3.8970165635167806, 4.876589709158702, 5.771534316601328, 6.726274971610909, 7.653724857664493, 8.587738669078744, 9.553334935150799, 10.598525377612763, 11.639231834676599, 13.749662504570946, 12.693586514707194, 11.692964613053556, 10.698888419330071, 9.756019088657812, 8.774748080079444, 7.838458956269875, 6.853390518358958, 5.90060545992211, 4.970767624700901, 4.134917567833324, 4.900687657873991, 5.908030536680642, 6.764304025865682, 7.763537300338346, 8.652079927924266, 9.562228651120915, 10.486632836693525, 11.551079911153298, 12.581713474291497, 13.535998472618646, 13.638394684579364, 12.729801275922206, 11.738289891605637, 10.770983326719943, 9.842617860390124, 8.868856148989535, 7.909571635230277, 6.9546274909257715, 5.972345722811363, 5.122852094549424, 5.8658481456402445, 6.858369000397046, 7.699092434874619, 8.6914643663847, 9.641208115553479, 10.582770223715688, 11.547117833150612, 12.476450344964812, 13.477860836719147, 12.695884865926224, 13.764185016792085, 13.785935184833829, 12.794742778847752, 11.793998820287726, 10.886443820057451, 9.870844441402568, 8.840943270705221, 8.02066218681645, 6.957921819787002, 6.148185977554776, 6.820066941146994, 7.851459151316851, 8.669765894500998, 9.632312475535942, 10.586937242171294, 11.53631325851794, 12.570677645470518, 13.515196622943634, 13.766449499369967, 11.676964911736059, 12.74300097847668, 13.788746638504083, 13.767679084828, 12.7639905730169, 11.80064789495721, 10.83051370748878, 9.835714553704966, 8.977924700301836, 7.981322149512746, 7.164878261943036, 7.844552999028858, 8.776677274659404, 9.658250881483356, 10.595699878955047, 11.542631406208054, 12.537986604864075, 13.514093734987183, 13.83893785084822, 12.841091516958775, 10.815289021816332, 11.786853038731458, 12.859839547896982, 13.933295663907586, 13.774720765381764, 12.757973054410046, 11.77578191591096, 10.83288202266883, 9.925084235150038, 8.984312228211794, 8.132772284225066, 8.795986668836651, 9.723991403212567, 10.591490857079211, 11.545678024421685, 12.467713463396205, 13.46073250722425, 14.00159235171098, 12.948634749836232, 11.924157710388016, 9.999880484163654, 11.044785384212151, 12.085422156767843, 13.158869401231218, 14.125781130093166, 13.67614263760269, 12.718764061524011, 11.858725520364116, 10.952601090445574, 9.914272209104931, 9.062047813226773, 9.767655411851617, 10.694495782102706, 11.642157496497385, 12.531190459645387, 13.488888120252025, 14.19119903507845, 13.13081460060716, 12.181366578317355, 11.248569873494176, 10.848167997642191, 11.794261397980952, 12.85627543819335, 13.82751627045738, 14.533056118070508, 13.563210249920063, 12.58243724861795, 11.633427846866411, 10.82192837884974, 10.086500060418778, 10.123907849653751, 10.74803054471068, 11.744771491508647, 12.687085711353467, 13.497663440048735, 14.42193635224764, 14.94820973735245, 13.909752555538578, 12.844691506753596, 11.886208395732119, 11.783037872802838, 12.747469847715054, 13.715425967070775, 14.566544582196892, 13.633593119728157, 12.591506757819166, 11.588257873766572, 10.636491728020374, 9.82961635248201, 9.03568129216342, 9.816219226577116, 10.77172382212684, 11.68592862506095, 12.543788223866176, 13.522494112174998, 14.549524111312419, 15.455345814806781, 14.876623430364155, 13.871257787425769, 12.843779248643775, 12.746827318177917, 13.790613754888913, 14.561030552729788, 13.54937823836453, 12.591242835586883, 11.540853140687538, 10.656281737661518, 9.646741736451622, 8.76138738819368, 7.978426743130724, 8.864404895448548, 9.802659618017053, 10.624484204244819, 11.589168018830659, 12.581286443473259, 13.526665522243034, 14.456059120565362, 15.385695431046667, 14.724264382070983, 13.789589953505118, 13.724102014355523, 14.589372004973768, 13.652218691729527, 12.64539890162936, 11.590721746211639, 10.588808702042016, 9.645855524767232, 8.706960217579534, 7.769918944330597, 7.008985854287658, 7.875573449185988, 8.797155923726915, 9.663821398339696, 10.649558265720017, 11.623956923812482, 12.603835672900516, 13.565015278960841, 14.528500819998545, 15.451087970537246, 14.497976182924567, 14.66014309844859, 13.650568170208585, 12.621477056960813, 11.648011162382742, 10.573202923981363, 9.695654664212963, 8.693582101122136, 7.752010229101437, 6.8423399697273535, 6.05217473574482, 6.929255378434436, 7.727448567510216, 8.735118427045553, 9.687225413804613, 10.640845024024815, 11.629844042949816, 12.631310726864289, 13.611618319373331, 14.625807254087539, 15.449661830461418], [15.49436958211751, 14.506405621333682, 13.5946983901766, 12.5351528053919, 11.595635423794066, 10.653675225226404, 9.67259992750905, 8.723576729771963, 7.704347239523361, 6.765632486871649, 5.8368930123477005, 4.879460949588593, 5.885094393006538, 6.8105554193732765, 7.743376787750833, 8.697305563086674, 9.732533183581689, 10.695261667035119, 11.75510772144731, 12.795330463694533, 14.491906254970228, 13.561849811783768, 12.589209232291429, 11.648863422029354, 10.666481210287467, 9.715450623903015, 8.71782355262199, 7.682768328874979, 6.799557963405409, 5.909646419889695, 4.937216943912708, 3.9445774811620415, 4.892771829108357, 5.8765202121520765, 6.753822726771224, 7.73254893968806, 8.772485407859298, 9.803387161202814, 10.76094661549338, 11.776681122963026, 13.66121336837605, 12.660618737180698, 11.642762686138232, 10.663721303139695, 9.720827984725268, 8.749629050200511, 7.7555315449989415, 6.736198814409598, 5.7773805778497085, 4.86097463303067, 3.924895607437322, 2.9981975891312267, 3.905583404498695, 4.83809276427098, 5.779393108983349, 6.788610022344967, 7.852066922610826, 8.862938665236255, 9.802451122418422, 10.817894608766972, 12.74862026738161, 11.702864386286512, 10.705551322205018, 9.653149317763429, 8.723998113043805, 7.7719864471682625, 6.8155964998047915, 5.785962927780476, 4.8021549570975814, 3.8160266557606515, 2.8586455843792735, 1.9469697990284254, 2.920017221579932, 3.895756726510382, 4.868260154672718, 5.838921160533032, 6.8916061466830545, 7.886987299469286, 8.907184967118958, 9.847150827547015, 11.759617098973374, 10.710418371638104, 9.732579292552296, 8.669059855065944, 7.738364721366598, 6.811182159040319, 5.8815042694668005, 4.842664984647589, 3.888809356518628, 2.91533981399288, 1.8859831712246595, 1.0114228391801112, 1.9764180142453394, 2.9171518758278054, 3.911745142181356, 4.875582001457582, 5.907375878644135, 6.955243734334109, 7.997778261299519, 8.943218509829558, 11.246460041044811, 10.228385010125134, 9.190953146320224, 8.18843542538179, 7.1162806576229345, 6.078888729206315, 5.111081999096671, 4.078691452735361, 3.0175252674538022, 1.9480700823717387, 0.9441950789318186, 0.0, 1.0113742221923165, 1.9959717584308052, 2.972331869740289, 3.9154899160151775, 4.974337717836278, 6.0392119571477965, 7.035559298441846, 8.049804675415132, 11.902627153823001, 10.962670294214197, 9.991476279495503, 8.972934650420287, 8.009941286664944, 6.961255502933383, 5.979342183340641, 4.9280610447862045, 3.9584547229860245, 2.9342435508584996, 1.9117854961354745, 0.9453886140545401, 1.956336336176118, 2.9806278827184274, 3.9119364029028816, 4.964639228330566, 5.988300978487431, 6.931127318862288, 7.935796816782508, 8.86486264530704, 12.833255785803361, 11.889977706008677, 10.926644997705047, 9.874639879916526, 8.876692596726809, 7.936956335316011, 6.897483884187268, 5.86968260217972, 4.91139853374365, 3.9126435402624793, 2.9028933764606593, 1.9266966202430398, 2.9248513445278865, 3.863055979303, 4.885505068870717, 5.9052882525678925, 6.852708171886761, 7.836993762442036, 8.792239587487657, 9.801785553552953, 13.7613456103537, 12.705040043314506, 11.725025318628258, 10.75817439140229, 9.802516255142736, 8.843667682266531, 7.778567975279445, 6.843044070444015, 5.913506783397022, 4.904038619285855, 3.922731663284785, 2.9528214845849616, 3.9323946302268826, 4.827339237669509, 5.78207989267909, 6.709529778732673, 7.643543590146925, 8.60913985621898, 9.654330298680943, 10.695036755744779, 13.564398602888307, 13.637781593639014, 12.637159691985376, 11.643083498261891, 10.700214167589632, 9.718943159011264, 8.782654035201695, 7.797585597290777, 6.828564239394353, 5.898726404173145, 4.90248276835774, 3.956492578942172, 4.963835457748822, 5.820108946933863, 6.819342221406527, 7.707884848992446, 8.618033572189097, 9.542437757761705, 10.606884832221478, 11.637518395359677, 12.591803393686826, 13.53855098767318, 13.673996354854026, 12.682484970537457, 11.715178405651763, 10.786812939321944, 9.813051227921354, 8.853766714162097, 7.882586270398015, 6.870360084639493, 5.89041729507384, 4.9216530667084255, 5.914173921465227, 6.7548973559428, 7.747269287452882, 8.697013036621662, 9.638575144783871, 10.602922754218792, 11.532255266032992, 12.533665757787327, 11.751689786994405, 12.819989937860266, 13.81303719900645, 13.738937857779572, 12.738193899219546, 11.830638898989271, 10.815039520334388, 9.785138349637041, 8.92148943089919, 7.8559361816151325, 6.869400316636091, 5.875871862215175, 6.907264072385032, 7.72557081556918, 8.688117396604124, 9.642742163239475, 10.592118179586123, 11.626482566538701, 12.571001544011814, 13.50447366192053, 10.732769832804243, 11.798805899544863, 12.844551559572267, 13.778663323994644, 13.70818565194872, 12.74484297388903, 11.7747087864206, 10.779909632636786, 9.834672633016973, 8.81889447868459, 7.886092601024352, 6.900357920097038, 7.832482195727585, 8.714055802551538, 9.651504800023229, 10.598436327276236, 11.593791525932259, 12.569898656055367, 13.50431691088846, 13.785286595890593, 9.871093942884514, 10.84265795979964, 11.915644468965166, 12.98910058497577, 13.993944418131058, 13.702168133341866, 12.71997699484278, 11.711891668337058, 10.762656564321883, 9.821884557383639, 8.779636539322471, 7.851791589904832, 8.779796324280747, 9.647295778147393, 10.601482945489867, 11.523518384464387, 12.516537428292434, 13.514945000298423, 13.89282982876805, 12.868352789319834, 9.055685405231838, 10.100590305280335, 11.141227077836026, 12.214674322299402, 13.18158605116135, 13.60726732876276, 12.649888752684081, 11.664867921709977, 10.863989964599387, 10.751844538276776, 9.708912068324178, 8.8234603329198, 9.750300703170886, 10.697962417565567, 11.586995380713569, 12.544693041320206, 13.447758739284751, 14.075009679538978, 13.125561657249174, 12.192764952425994, 9.912997993881223, 10.859091394219984, 11.921105434432382, 12.892346266696412, 13.599407671469127, 12.629561803318682, 11.648788802016568, 10.69977940026503, 9.888279932248357, 10.815945445600642, 10.765699437680102, 9.803835465778862, 10.800576412576827, 11.742890632421648, 12.553468361116916, 13.477741273315822, 14.462046718698396, 14.853947634470396, 13.788886585685415, 12.830403474663937, 10.84786786904187, 11.812299843954086, 12.780255963309807, 13.631374578435926, 12.698423115967191, 11.657858311217783, 10.65460942716519, 9.70284328141899, 8.895967905880626, 9.765126677345284, 10.624446965393558, 10.771351018335494, 11.745695749777793, 12.762701468706355, 13.566064252327676, 14.436595805818158, 15.448093715467108, 15.820818509295973, 14.815452866357587, 13.787974327575593, 11.811657314416948, 12.855443751127943, 13.625860548968822, 12.614208234603565, 11.656072831825917, 10.607204694086155, 9.722633291060134, 8.713093289850239, 7.8277389415922976, 8.707872128312587, 9.672632634264989, 10.672226638521114, 11.540284485782976, 12.504968300368816, 13.497086725011416, 14.442465803781191, 15.371859402103519, 16.301495712584824, 15.6684594610028, 14.733785032436936, 12.788932010594554, 13.654202001212802, 12.71704868796856, 11.710228897868394, 10.655551742450672, 9.655160255440633, 8.712207078165848, 7.77331177097815, 6.836270497729214, 7.738431239469521, 8.68380118800243, 9.666722944230974, 10.579621679877853, 11.565358547258175, 12.568152002744302, 13.548030751832336, 14.50921035789266, 15.472695898930365, 16.395283049469064, 15.442171261856387, 13.72497309468762, 12.715398166447619, 11.686307053199847, 10.712841158621776, 9.638032920220397, 8.760484660451997, 7.758412097361169, 6.818361782500053, 5.90869152312597, 6.781620120926682, 7.737483117250879, 8.636668973213421, 9.65091870858371, 10.631420492736433, 11.585040102956635, 12.574039121881636, 13.575505805796109, 14.555813398305151, 15.570002333019358, 16.393856909393236], [16.505743804309827, 15.517779843525998, 14.606072612368916, 13.546527027584217, 12.607009645986382, 11.590791204258947, 10.609715906541593, 9.643714414869688, 8.624484924621084, 7.685770171969371, 6.757030697445423, 5.7995986346863155, 4.924360991289048, 5.799181197180959, 6.732002565558515, 7.685931340894357, 8.721158961389373, 9.683887444842803, 10.743733499254994, 11.783956241502219, 15.503280477162544, 14.573224033976084, 13.600583454483745, 12.66023764422167, 11.677855432479783, 10.726824846095331, 9.729197774814306, 8.694142551067296, 7.810932185597725, 6.857502388280133, 5.85735462901043, 4.864715166259764, 3.932038427390867, 4.865145989959759, 5.742448504578907, 6.721174717495744, 7.761111185666982, 8.792012939010498, 9.749572393301065, 10.765306900770712, 14.672587590568366, 13.671992959373014, 12.654136908330548, 11.67509552533201, 10.732202206917584, 9.761003272392827, 8.766905767191258, 7.747573036601914, 6.788754800042025, 5.872348855222986, 4.936269829629639, 3.918335274228949, 2.8942091823063785, 3.8267185420786634, 4.768018886791032, 5.77723580015265, 6.840692700418509, 7.85156444304394, 8.791076900226107, 9.806520386574656, 13.759994489573925, 12.714238608478828, 11.716925544397334, 10.664523539955743, 9.73537233523612, 8.78336066936058, 7.826970721997108, 6.797337149972792, 5.8135291792898975, 4.827400877952968, 3.87001980657159, 2.8671074841261475, 1.9086429993876153, 2.8843825043180655, 3.8568859324804015, 4.827546938340715, 5.8802319244907375, 6.87561307727697, 7.895810744926642, 8.835776605354699, 12.77099132116569, 11.72179259383042, 10.743953514744613, 9.68043407725826, 8.749738943558913, 7.822556381232635, 6.892878491659117, 5.854039206839906, 4.900183578710945, 3.9267140361851967, 2.897357393416976, 1.9315605242778333, 0.9650437920530229, 1.9057776536354893, 2.9003709199890397, 3.864207779265266, 4.896001656451819, 5.943869512141793, 6.986404039107203, 7.931844287637243, 12.257834263237129, 11.239759232317452, 10.202327368512542, 9.199809647574108, 8.127654879815251, 7.090262951398631, 6.122456221288987, 5.090065674927677, 4.028899489646118, 2.9594443045640553, 1.955569301124135, 1.0113742221923165, 0.0, 0.9845975362384888, 1.960957647547973, 2.9041156938228614, 3.962963495643961, 5.0278377349554795, 6.024185076249529, 7.038430453222815, 12.91400137601532, 11.974044516406515, 11.00285050168782, 9.984308872612605, 9.021315508857262, 7.972629725125701, 6.990716405532958, 5.9394352669785215, 4.9698289451783415, 3.9456177730508166, 2.923159718327791, 1.9567628362468565, 0.9449621139838013, 1.9692536605261108, 2.900562180710565, 3.95326500613825, 4.976926756295115, 5.919753096669972, 6.924422594590192, 7.853488423114724, 13.84463000799568, 12.901351928200995, 11.938019219897365, 10.886014102108843, 9.888066818919127, 8.948330557508328, 7.908858106379585, 6.881056824372037, 5.922772755935967, 4.914327123132158, 3.904576959330338, 2.9283802031127184, 1.9302254788278717, 2.8684301136029853, 3.874130846678401, 4.893914030375576, 5.8413339496944445, 6.82561954024972, 7.780865365295342, 8.790411331360637, 13.509621174731244, 13.716414265506824, 12.736399540820576, 11.769548613594608, 10.813890477335054, 9.855041904458847, 8.789942197471762, 7.854418292636332, 6.924881005589339, 5.905722202155534, 4.924415246154464, 3.94672840492402, 2.967155259282099, 3.832713371969495, 4.787454026979075, 5.714903913032659, 6.648917724446911, 7.614513990518965, 8.659704432980929, 9.700410890044765, 12.569772737188295, 13.488733291845335, 13.648533914177692, 12.654457720454207, 11.711588389781948, 10.73031738120358, 9.794028257394011, 8.808959819483093, 7.830247822264032, 6.900409987042823, 5.896389688696799, 4.950399499281231, 4.010099951358752, 4.825483081233848, 5.824716355706512, 6.713258983292432, 7.623407706489083, 8.547811892061691, 9.612258966521464, 10.642892529659663, 11.597177527986812, 12.543925121973166, 13.565027685121253, 13.693859192729773, 12.726552627844079, 11.79818716151426, 10.82442545011367, 9.865140936354413, 8.884269853267693, 7.864267004978553, 6.884324215412899, 5.915559987047484, 5.0562293855579, 5.760271490242785, 6.752643421752866, 7.702387170921646, 8.643949279083856, 9.60829688851878, 10.537629400332978, 11.539039892087313, 10.757063921294392, 11.823630110837453, 12.801662976814134, 13.740225407782576, 13.749568121411862, 12.842013121181587, 11.826413742526704, 10.796512571829357, 9.915396351238247, 8.84984310195419, 7.8633072369751496, 6.869778782554233, 6.064228071343684, 6.730944949869165, 7.693491530904109, 8.64811629753946, 9.597492313886107, 10.631856700838686, 11.576375678311802, 12.509847796220516, 9.721395610611927, 10.787431677352547, 11.83317733737995, 12.767289101802328, 13.822930940732952, 13.756217196081346, 12.786083008612916, 11.791283854829102, 10.82857955335603, 9.812801399023648, 8.879999521363409, 7.894264840436097, 6.989446194686237, 7.719429936851523, 8.656878934323213, 9.60381046157622, 10.599165660232243, 11.575272790355351, 12.509691045188445, 13.435205778631708, 8.859719720692198, 9.831283737607324, 10.90427024677285, 11.977726362783454, 12.982570195938742, 13.595115365048578, 12.64126909176855, 11.73910961287668, 11.75656348466094, 10.815791477722696, 9.77354345966153, 8.84569851024389, 7.9367603232394, 8.652669912447378, 9.606857079789851, 10.528892518764371, 11.521911562592418, 12.520319134598408, 13.512988440830426, 13.879727011512152, 8.04431118303952, 9.089216083088015, 10.129852855643707, 11.203300100107082, 12.17021182896903, 12.655665522234177, 11.698286946155498, 10.713266115181394, 11.678019126994013, 11.745751458615834, 10.702818988663237, 9.817367253258857, 8.90726470212954, 9.70333655186555, 10.592369515013553, 11.55006717562019, 12.453132873584735, 13.452190784475835, 14.136935879441491, 13.204139174618312, 8.901623771688907, 9.847717172027668, 10.909731212240066, 11.880972044504096, 12.647805864940544, 11.677959996790099, 10.697186995487986, 9.748177593736447, 10.779877544740764, 11.736083130698363, 11.759606358019159, 10.79774238611792, 9.957540411535483, 10.748264766721633, 11.5588424954169, 12.483115407615806, 13.46742085299838, 14.466814282646668, 14.80026080787773, 13.841777696856253, 9.836493646849554, 10.80092562176177, 11.768881741117491, 12.620000356243608, 11.687048893774874, 10.691280472315947, 9.703007620636605, 8.751241474890408, 9.787565518373032, 10.685264362443005, 11.54458465049128, 11.765257938674551, 10.968165155730297, 11.76807560300634, 12.57143838662766, 13.441969940118142, 14.453467849767092, 15.44479309740698, 15.826827088549903, 14.79934854976791, 10.800283092224632, 11.844069528935627, 12.614486326776504, 11.602834012411247, 10.644698609633599, 9.638710609671039, 8.77103148453155, 7.761491483321655, 8.747876626690019, 9.628009813410308, 10.592770319362712, 11.592364323618835, 12.029609576546427, 12.722695808041857, 13.5126460553294, 14.458025134099175, 15.387418732421503, 16.31705504290281, 16.679833683195117, 15.745159254629252, 11.777557788402238, 12.642827779020486, 11.705674465776244, 10.698854675676078, 9.644177520258355, 8.686666171025516, 7.760605271637265, 6.821709964449566, 7.756408182826935, 8.658568924567243, 9.603938873100153, 10.586860629328697, 11.499759364975578, 12.4854962323559, 13.505267981776845, 14.485146730864878, 15.446326336925203, 16.40981187796291, 17.358836973252874, 16.453545484048703, 12.713598872495304, 11.704023944255303, 10.674932831007531, 9.701466936429458, 8.626658698028079, 7.74911043825968, 6.747037875168851, 5.857628380782563, 6.828829208223691, 7.701757806024404, 8.657620802348601, 9.556806658311144, 10.571056393681435, 11.568536471768976, 12.522156081989177, 13.511155100914179, 14.526197837498033, 15.506505430007076, 16.520694364721283, 17.405231131585552], [17.490341340548312, 16.502377379764486, 15.590670148607403, 14.531124563822704, 13.59160718222487, 12.567694826174618, 11.586619528457264, 10.620618036785359, 9.601388546536757, 8.662673793885045, 7.733934319361097, 6.77650225660199, 5.901264613204723, 4.900586326967951, 5.833407695345508, 6.787336470681349, 7.822564091176364, 8.785292574629795, 9.845138629041983, 10.87939214025296, 16.48787801340103, 15.557821570214571, 14.585180990722233, 13.644835180460158, 12.66245296871827, 11.711422382333819, 10.713795311052793, 9.678740087305783, 8.795529721836212, 7.834406010195807, 6.834258250926105, 5.841618788175438, 4.908942049306542, 3.966551119746751, 4.8438536343658996, 5.822579847282736, 6.8625163154539734, 7.891058118481006, 8.845008292051807, 9.860742799521454, 15.657185126806855, 14.656590495611503, 13.638734444569037, 12.659693061570499, 11.716799743156072, 10.745600808631314, 9.751503303429745, 8.732170572840403, 7.773352336280513, 6.8569463914614746, 5.920867365868127, 4.895238896144623, 3.8711128042220535, 2.9281236718656554, 3.8694240165780247, 4.878640929939642, 5.9420978302055, 6.947000341794683, 7.88651279897685, 8.901956285325399, 14.744592025812414, 13.698836144717317, 12.701523080635823, 11.649121076194232, 10.719969871474609, 9.767958205599067, 8.811568258235596, 7.78193468621128, 6.798126715528386, 5.811998414191456, 4.854617342810078, 3.8440111060418225, 2.8855466213032903, 1.9857876341050575, 2.9582910622673935, 3.928952068127707, 4.981637054277729, 5.9710489760277135, 6.9912466436773855, 7.931212504105442, 13.75558885740418, 12.70639013006891, 11.728551050983102, 10.66503161349675, 9.734336479797403, 8.807153917471124, 7.877476027897606, 6.8386367430783945, 5.884781114949433, 4.911311572423685, 3.8819549296554645, 2.9084641461935083, 1.941947413968698, 1.0012135523862318, 1.9958068187397822, 2.9596436780160085, 3.991437555202562, 5.039305410892537, 6.040717163563803, 6.986157412093843, 13.242431799475616, 12.22435676855594, 11.186924904751029, 10.184407183812596, 9.112252416053739, 8.07486048763712, 7.107053757527474, 6.074663211166165, 5.0134970258846066, 3.9440418408025435, 2.9401668373626237, 1.9959717584308052, 0.9845975362384888, 0.0, 0.9763601113094842, 1.9195181575843727, 2.9783659594054726, 4.043240198716991, 5.03958754001104, 6.053832916984327, 13.898598912253807, 12.958642052645002, 11.987448037926308, 10.968906408851092, 10.005913045095749, 8.957227261364189, 7.9753139417714465, 6.92403280321701, 5.95442648141683, 4.930215309289305, 3.9077572545662793, 2.941360372485345, 1.92955965022229, 1.0562449364177597, 1.9549404701922826, 2.9900303312291796, 4.013692081386045, 4.956518421760901, 5.961187919681121, 6.890253748205653, 13.522783682324452, 13.885949464439484, 12.922616756135854, 11.870611638347333, 10.872664355157616, 9.932928093746817, 8.893455642618074, 7.865654360610526, 6.9073702921744555, 5.898924659370647, 4.8891744955688266, 3.912977739351207, 2.9148230150663603, 2.0824844655708707, 2.9285091361601183, 3.948292319857294, 4.895712239176162, 5.879997829731438, 6.835243654777059, 7.844789620842355, 12.645168268336755, 13.682859700822194, 13.720997077059065, 12.754146149833097, 11.798488013573543, 10.839639440697336, 9.77453973371025, 8.839015828874821, 7.909478541827827, 6.890319738394023, 5.909012782392953, 4.931325941162508, 3.951752795520587, 3.0467677239373803, 3.923001120584588, 4.8504510066381705, 5.784464818052423, 6.750061084124477, 7.79525152658644, 8.812830348641064, 11.705319830793805, 12.624280385450847, 13.624902287104485, 13.639055256692696, 12.696185926020437, 11.71491491744207, 10.7786257936325, 9.793557355721582, 8.814845358502522, 7.885007523281312, 6.880987224935287, 5.934997035519718, 4.99469748759724, 4.039537433201734, 4.960263449312024, 5.848806076897944, 6.758954800094594, 7.683358985667203, 8.747806060126976, 9.778439623265175, 10.732724621592324, 11.679472215578677, 12.700574778726764, 13.730651905187685, 13.711150164082568, 12.78278469775275, 11.80902298635216, 10.849738472592902, 9.868867389506184, 8.84886454121704, 7.868921751651387, 6.900157523285971, 6.03806195466853, 4.974325842210671, 5.966697773720753, 6.916441522889532, 7.779496372689368, 8.74384398212429, 9.67317649393849, 10.674586985692825, 9.84208895072721, 10.87800840031917, 11.856041266295852, 12.794603697264295, 13.821345792355785, 13.826610657420076, 12.811011278765193, 11.781110108067846, 10.899993887476734, 9.834440638192678, 8.847904773213637, 7.8543763187927205, 6.952992060044722, 5.944999301837051, 6.907545882871995, 7.8621706495073465, 8.73303940749162, 9.7674037944442, 10.711922771917312, 11.645394889826028, 8.775773900093643, 9.841809966834264, 10.887555626861669, 11.821667391284047, 12.87730923021467, 13.730383408972964, 12.764480184662279, 12.77588139106759, 11.813177089594518, 10.797398935262136, 9.864597057601896, 8.84216945118622, 7.878210183387275, 6.933484288819409, 7.8709332862911, 8.817864813544107, 9.734712753837757, 10.710819883960864, 11.645238138793959, 12.57075287223722, 7.896485045783127, 8.868049062698253, 9.941035571863779, 11.014491687874383, 12.01933552102967, 12.773058249520128, 11.8192119762401, 12.716013234792351, 12.712621918640421, 11.771849911702176, 10.721448070411652, 9.793603120994012, 8.825524311940438, 7.866724264415264, 8.820911431757738, 9.742946870732258, 10.681471126829843, 11.655866228203921, 12.64853553443594, 13.525236921385408, 7.059713646801032, 8.104618546849528, 9.14525531940522, 10.218702563868593, 11.185614292730541, 11.833608406705727, 10.876229830627048, 11.690169737097065, 12.654922748909684, 12.701809892595314, 11.650723599413359, 10.754974163623809, 9.796028690830576, 8.917390903833438, 9.80642386698144, 10.764121527588077, 11.61269243782216, 12.587737878081349, 13.537185900371153, 14.1887367108568, 7.9559368961455075, 8.902030296484268, 9.964044336696666, 10.935285168960696, 11.816222451561254, 10.846376583410809, 9.875129879959536, 10.725081215652118, 11.756781166656436, 12.712986752614036, 12.697213268384111, 11.735349296482871, 10.84630440023652, 9.96231911868952, 10.772896847384787, 11.697169759583693, 12.626980417235805, 13.602361376252182, 14.499618032994078, 14.826375233094742, 8.896737438448412, 9.861169413360628, 10.829125532716349, 11.7214054860306, 10.788454023561865, 9.792685602102939, 8.860645053971826, 9.728145096806081, 10.764469140288705, 11.662167984358678, 12.521488272406954, 12.702864849039504, 11.856929144431334, 10.982129954974226, 11.785492738595547, 12.656024292086029, 13.662586309444935, 14.599724937831628, 15.562981258306213, 15.783946086006399, 9.895718990975375, 10.912388600994067, 11.715891456563496, 10.704239142198238, 9.74610373942059, 8.74011573945803, 7.928668917866771, 8.738395105237329, 9.724780248605695, 10.604913435325981, 11.569673941278385, 12.56926794553451, 12.901433974595584, 11.936750160009744, 12.726700407297287, 13.672079486067062, 14.60147308438939, 15.531109394870695, 16.5201546291977, 16.72975679086774, 10.87299368715298, 11.744232908807476, 10.807079595563234, 9.800259805463067, 8.745582650045346, 7.788071300812508, 6.907672687302558, 7.79861358636524, 8.73331180474261, 9.635472546482916, 10.580842495015826, 11.56376425124437, 12.476662986891249, 12.962765450158784, 13.737557768487052, 14.605261067212536, 15.542138001490063, 16.50562354252777, 17.454648637817733, 17.43814302028719, 11.809034771246047, 10.805429074042294, 9.776337960794523, 8.80287206621645, 7.72806382781507, 6.8505155680466725, 5.848443004955843, 6.8345320026982375, 7.805732830139366, 8.678661427940078, 9.634524424264274, 10.533710280226817, 11.547960015597106, 12.545440093684647, 13.499059703904848, 14.48805872282985, 15.503101459413704, 16.483409051922745, 17.49759798663695, 18.389828667824037], [18.466701451857798, 17.47873749107397, 16.56703025991689, 15.50748467513219, 14.567967293534355, 13.544054937484104, 12.56297963976675, 11.596978148094845, 10.577748657846243, 9.63903390519453, 8.710294430670583, 7.752862367911475, 6.877624724514208, 5.876946438277435, 5.0875050052973965, 5.979100338856795, 6.953431190440895, 7.896107882160174, 8.897225338270728, 9.903989480226219, 17.464238124710516, 16.534181681524057, 15.561541102031718, 14.621195291769643, 13.638813080027756, 12.687782493643304, 11.69015542236228, 10.65510019861527, 9.771889833145698, 8.810766121505292, 7.81061836223559, 6.817978899484923, 5.8853021606160265, 4.942911231056235, 4.07924884526607, 5.014343715458182, 5.993383414718504, 6.915655458454264, 7.869605632025065, 8.885340139494712, 16.63354523811634, 15.63295060692099, 14.615094555878523, 13.636053172879985, 12.693159854465558, 11.7219609199408, 10.72786341473923, 9.708530684149888, 8.749712447589998, 7.833306502770959, 6.897227477177612, 5.871599007454108, 4.847472915531538, 3.9044837831751393, 3.1048192274781954, 3.98391694488942, 5.022333867954678, 5.971597681767942, 6.911110138950108, 7.9265536252986575, 15.7209521371219, 14.675196256026803, 13.677883191945309, 12.625481187503718, 11.696329982784095, 10.744318316908553, 9.787928369545082, 8.758294797520765, 7.774486826837871, 6.788358525500941, 5.830977454119563, 4.820371217351307, 3.8619067326127747, 2.9621477454145415, 2.0697783557040417, 3.034228083077485, 4.011519259842478, 4.995646316000972, 6.015843983650644, 6.955809844078701, 14.731948968713665, 13.682750241378395, 12.704911162292587, 11.641391724806235, 10.710696591106888, 9.783514028780608, 8.85383613920709, 7.814996854387879, 6.861141226258918, 5.88767168373317, 4.858315040964949, 3.8848242575029928, 2.9183075252781823, 1.977573663695716, 1.0204041587130401, 1.9842410179892662, 3.01603489517582, 4.063902750865795, 5.064357052254319, 6.009797300784359, 14.218791910785102, 13.200716879865425, 12.163285016060515, 11.160767295122081, 10.088612527363225, 9.051220598946605, 8.08341386883696, 7.0510233224756504, 5.989857137194091, 4.920401952112028, 3.916526948672108, 2.9723318697402896, 1.960957647547973, 0.9763601113094842, 0.0, 0.9431580462748885, 2.0020058480959886, 3.0668800874075073, 4.063227428701556, 5.077472805674843, 13.477052202995328, 13.935002163954488, 12.963808149235794, 11.945266520160578, 10.982273156405235, 9.933587372673674, 8.951674053080932, 7.900392914526495, 6.930786592726315, 5.90657542059879, 4.884117365875764, 3.9177204837948296, 2.9059197615317744, 1.9098888790672526, 0.9785803588827983, 2.013670219919695, 3.0373319700765604, 3.9801583104514164, 4.984827808371637, 5.913893636896169, 12.546423571014968, 13.619545437329021, 13.898976867445338, 12.846971749656817, 11.8490244664671, 10.909288205056301, 9.869815753927558, 8.84201447192001, 7.88373040348394, 6.858434687299763, 5.848684523497942, 4.872487767280323, 3.874333042995477, 2.9361284082203634, 1.952149024850634, 2.971932208547809, 3.919352127866677, 4.903637718421953, 5.858883543467575, 6.86842950953287, 11.668808157027271, 12.706499589512708, 13.596004667585884, 13.730506261142581, 12.774848124883027, 11.815999552006819, 10.750899845019733, 9.815375940184303, 8.873178195020397, 7.849829766323139, 6.845446593988781, 5.806485590751229, 4.826912445109308, 3.900411666586873, 2.9466410092751034, 3.8740908953286866, 4.808104706742939, 5.773700972814993, 6.818891415276956, 7.83647023733158, 10.728959719484322, 11.647920274141361, 12.648542175794999, 13.642618369518484, 13.67254603732992, 12.691275028751551, 11.754985904941982, 10.740920695899547, 9.75169425446819, 8.82185641924698, 7.756146874524007, 6.8101566851084385, 5.869857137185961, 4.893181375851227, 3.9839033380025395, 4.87244596558846, 5.78259468878511, 6.706998874357719, 7.771445948817491, 8.80207951195569, 9.756364510282838, 10.703112104269191, 11.724214667417279, 12.754291793878199, 13.780331631845009, 13.759144809062231, 12.747031311293457, 11.787746797534199, 10.768748319712563, 9.72402419080576, 8.744081401240107, 7.775317172874692, 6.8917058973180225, 5.827969784860164, 5.020594507041217, 5.9420481975743105, 6.803136261379884, 7.767483870814806, 8.696816382629006, 9.69822687438334, 8.865728839417725, 9.901648289009685, 10.879681154986367, 11.818243585954809, 12.8449856810463, 13.814519689647998, 13.74901960370649, 12.719118433009143, 11.775153537065455, 10.709600287781399, 9.723064422802357, 8.729535968381441, 7.806636002694215, 6.798643244486543, 6.06137109479975, 6.963104899713654, 7.756679296182137, 8.791043683134715, 9.73556266060783, 10.669034778516544, 7.799413788784158, 8.86544985552478, 9.911195515552183, 10.845307279974561, 11.900949118905185, 12.864291796964874, 13.740840295971763, 13.699506977823573, 12.684093128059446, 11.668314973727064, 10.735513096066825, 9.69581339383571, 8.731854126036767, 7.787128231468902, 7.024758498218855, 7.918799063750414, 8.758352642528273, 9.73445977265138, 10.668878027484475, 11.594392760927736, 6.920124934473643, 7.891688951388769, 8.964675460554293, 10.038131576564897, 11.042975409720185, 12.037770255740783, 12.795572087549584, 13.692373346101837, 13.566265861289912, 12.625493854351667, 11.575092013061143, 10.647247063643503, 9.67916825458993, 8.720368207064757, 7.980338771247556, 8.843881120938565, 9.705111015520359, 10.679506116894437, 11.672175423126456, 12.548876810075924, 6.083353535491548, 7.128258435540044, 8.168895208095735, 9.242342452559111, 10.20925418142106, 11.098320412926382, 11.852589941936532, 12.666529848406551, 13.63128286021917, 13.555453835244805, 12.50436754206285, 11.608618106273301, 10.649672633480069, 9.77103484648293, 8.965851206471259, 9.897324660377935, 10.636332326512676, 11.611377766771865, 12.560825789061669, 13.493622493884848, 6.9795767848360235, 7.925670185174784, 8.987684225387182, 9.958925057651212, 10.986418655302803, 10.100473893362697, 10.85148999126902, 11.701441326961604, 12.733141277965922, 13.689346863923522, 13.550857211033604, 12.588993239132364, 11.69994834288601, 10.815963061339012, 9.932324186874606, 10.83037289237355, 11.65062030592632, 12.626001264942698, 13.523257921684595, 14.481741032706072, 7.920377327138928, 8.884809302051144, 9.852765421406865, 10.80810833901762, 9.980217891737311, 9.046782912054827, 9.83700516528131, 10.704505208115567, 11.740829251598191, 12.638528095668164, 13.49784838371644, 13.556508791688996, 12.710573087080824, 11.835773897623719, 10.944920078085365, 11.789227424875886, 12.68622619813545, 13.623364826522145, 14.58662114699673, 15.520134377601305, 8.920316330948634, 9.936028489684581, 10.782566894811628, 9.896003010373684, 8.937867607596036, 7.994213049409919, 8.905029029176255, 9.714755216546815, 10.70114035991518, 11.581273546635467, 12.54603405258787, 13.545628056843995, 13.755077917245076, 12.790394102659237, 11.886127746787105, 12.83150682555688, 13.68551289237687, 14.615149202858175, 15.604194437185182, 16.533693538537285, 9.89759102712624, 10.840795914203532, 9.93011903421403, 8.992023673638514, 7.937346518220792, 7.042168610764397, 7.884032798612042, 8.774973697674726, 9.709671916052097, 10.611832657792402, 11.557202606325312, 12.540124362553856, 13.453023098200735, 13.816409392808277, 12.896985107976871, 13.764688406702355, 14.626177809477543, 15.589663350515247, 16.538688445805214, 17.49180023341789, 10.833632111219305, 9.893405406266199, 8.887153268324903, 7.960459453867415, 6.9198276959905165, 6.104612877998561, 6.824803116265327, 7.810892114007722, 8.782092941448852, 9.655021539249564, 10.61088453557376, 11.510070391536303, 12.524320126906591, 13.521800204994133, 13.880097007764538, 14.738680036653054, 15.662496131086222, 16.626029479315246, 17.51052648055283, 18.44348588095474], [18.688836112216563, 17.821312438548617, 16.893088104946305, 15.947156676255661, 15.018789116900106, 14.487212983758992, 13.506137686041638, 12.540136194369733, 11.520906704121131, 10.582191951469419, 9.653452476945471, 8.696020414186364, 7.820782770789095, 6.820104484552324, 6.030663051572285, 5.044683796228289, 6.019014647812387, 6.961691339531667, 7.96280879564222, 8.966573581410586, 17.68637278506928, 17.477339727798945, 16.504699148306607, 15.564353338044532, 14.581971126302644, 13.630940539918193, 12.633313468637168, 11.598258244890157, 10.715047879420586, 9.75392416778018, 8.753776408510479, 7.761136945759811, 6.828460206890914, 5.886069277331124, 5.0224068915409585, 4.0799271728296755, 5.0589668720899965, 5.981238915825757, 6.935189089396558, 7.947924240679078, 16.803955391408312, 16.576108653195877, 15.558252602153411, 14.579211219154873, 13.636317900740446, 12.665118966215688, 11.671021461014119, 10.651688730424777, 9.692870493864886, 8.776464549045848, 7.8403855234525, 6.8147570537289965, 5.790630961806426, 4.847641829450028, 4.047977273753084, 3.0495004022609136, 4.0879173253261705, 5.0371811391394345, 5.976693596321601, 6.988656455271998, 15.791636282767751, 15.618354302301691, 14.621041238220197, 13.568639233778606, 12.639488029058983, 11.68747636318344, 10.73108641581997, 9.701452843795654, 8.717644873112759, 7.731516571775829, 6.7741355003944514, 5.763529263626196, 4.805064778887663, 3.9053057916894303, 3.01293640197893, 2.0998115404489788, 3.077102717213971, 4.061229773372465, 5.081427441022138, 6.017912674052041, 14.74634468167959, 14.625908287653283, 13.648069208567476, 12.584549771081123, 11.653854637381777, 10.726672075055498, 9.79699418548198, 8.758154900662769, 7.8042992725338065, 6.830829730008058, 5.801473087239837, 4.8279823037778815, 3.8614655715530706, 2.9207317099706045, 1.9635622049879287, 1.0498244753607595, 2.081618352547313, 3.1294862082372874, 4.12119900597943, 5.06663925450947, 13.684234950031263, 14.143874926140313, 13.106443062335403, 12.10392534139697, 11.031770573638113, 9.994378645221493, 9.026571915111848, 7.994181368750539, 6.93301518346898, 5.863559998386917, 4.8596849949469965, 3.915489916015178, 2.9041156938228614, 1.9195181575843727, 0.9431580462748885, 0.0, 1.0588478018210998, 2.1237220411326185, 3.120069382426667, 4.134314759399953, 12.646109170567383, 13.586066030176188, 13.906966195510682, 12.888424566435466, 11.925431202680123, 10.876745418948563, 9.89483209935582, 8.843550960801384, 7.873944639001203, 6.849733466873678, 5.8272754121506525, 4.860878530069718, 3.8490778078066628, 2.853046925342141, 1.921738405157687, 1.0705121736448069, 2.094173923801672, 3.037000264176528, 4.041669762096749, 4.970735590621281, 11.715480538587023, 12.77994580200312, 13.683427129200572, 13.790129795931705, 12.792182512741988, 11.85244625133119, 10.812973800202446, 9.785172518194898, 8.826888449758828, 7.801592733574652, 6.7918425697728315, 5.8156458135552125, 4.817491089270366, 3.879286454495252, 2.8953070711255227, 2.140594549565853, 3.060887207105141, 4.045172797660417, 4.991285671743984, 5.9593885094062955, 10.837865124599327, 11.82585925424894, 12.715364332322116, 13.682215259548084, 13.718006171157915, 12.759157598281707, 11.694057891294621, 10.758533986459192, 9.816336241295286, 8.792987812598028, 7.788604640263669, 6.749643637026117, 5.770070491384196, 4.843569712861761, 3.889799055549992, 3.1183984400939186, 4.052412251508171, 5.018008517580225, 6.053890502597759, 6.927429237205006, 9.885647443375738, 10.767279938877593, 11.76790184053123, 12.761978034254716, 13.704847364926975, 13.63443307502644, 12.69814395121687, 11.684078742174433, 10.694852300743076, 9.765014465521867, 8.699304920798895, 7.753314731383327, 6.813015183460849, 5.836339422126115, 4.927061384277429, 4.116753510353693, 5.0269022335503415, 5.951306419122951, 7.006445036138294, 7.921439176691922, 8.87572417501907, 9.822471769005423, 10.84357433215351, 11.87365145861443, 12.89969129658124, 13.828056762911059, 13.690189357568345, 12.730904843809087, 11.711906365987451, 10.667182237080649, 9.687239447514996, 8.71847521914958, 7.834863943592911, 6.771127831135052, 5.963752553316105, 5.186355742339543, 6.0474438061451155, 7.0117914155800385, 7.931815469949808, 8.867283841955397, 7.956687839291151, 8.99260728888311, 9.970640154859792, 10.909202585828234, 11.935944680919725, 12.905478689521424, 13.921078068176307, 13.662276479284031, 12.718311583340343, 11.652758334056287, 10.666222469077246, 9.67269401465633, 8.749794048969104, 7.7418012907614315, 7.004529141074638, 6.207412444478887, 7.000986840947368, 8.035351227899946, 8.970561747928631, 9.8380917460886, 6.890372788657584, 7.956408855398204, 9.002154515425609, 9.936266279847986, 10.99190811877861, 11.9552507968383, 12.92538498430673, 13.920184138090544, 13.627251174334337, 12.611473020001954, 11.678671142341715, 10.6389714401106, 9.675012172311657, 8.73028627774379, 7.967916544493743, 7.163106608515647, 8.002660187293504, 8.978767317416612, 9.913185572249706, 10.763449728499792, 5.9769668881987545, 6.948530905113881, 8.021517414279405, 9.094973530290009, 10.099817363445297, 11.121280622317018, 12.190242935390248, 13.258563903539915, 14.20779900755509, 13.568651900626557, 12.518250059336033, 11.590405109918393, 10.62232630086482, 9.663526253339645, 8.923496817522445, 8.088188665703798, 8.94941856028559, 9.923813661659668, 10.916482967891687, 11.71793377764798, 5.140195489216659, 6.185100389265155, 7.225737161820846, 8.29918440628422, 9.266096135146169, 10.30432843657496, 11.261707012653638, 12.291917010914645, 13.256670022727263, 14.297431234489341, 13.44752558833774, 12.551776152548191, 11.59283067975496, 10.714192892757818, 9.909009252746147, 9.141632205143168, 9.880639871277907, 10.855685311537096, 11.8051333338269, 12.73793003865008, 6.036418738561134, 6.982512138899895, 8.044526179112292, 9.015767011376322, 10.043260609027913, 11.013106477178358, 11.79464803754391, 12.644599373236492, 13.676299324240809, 14.63250491019841, 14.494015257308494, 13.532151285407254, 12.643106389160902, 11.7591211076139, 10.875482233149494, 10.074680437138783, 10.894927850691552, 11.870308809707929, 12.767565466449826, 13.726048577471303, 6.9772192808640385, 7.941651255776255, 8.909607375131975, 9.86495029274273, 9.045801349108805, 9.961316038395319, 10.7801632115562, 11.647663254390453, 12.683987297873077, 13.581686141943052, 14.441006429991328, 14.499666837963886, 13.653731133355716, 12.778931943898607, 11.888078124360254, 11.033534969641119, 11.930533742900682, 12.867672371287377, 13.830928691761962, 14.764441922366537, 7.982419160921975, 8.992870443409693, 9.839408848536738, 8.961586467745178, 8.00345106496753, 8.90874617575041, 9.848187075451145, 10.657913262821701, 11.64429840619007, 12.524431592910355, 13.489192098862759, 14.488786103118883, 14.698235963519965, 13.733552148934125, 12.829285793061993, 12.083975669503594, 12.929820437142101, 13.859456747623407, 14.848501981950413, 15.778001083302518, 8.95969385709958, 9.906379371575026, 8.995702491585522, 8.057607131010009, 7.002929975592286, 7.956701737104888, 8.827190844886932, 9.718131743949613, 10.652829962326985, 11.55499070406729, 12.5003606526002, 13.483282408828744, 14.396181144475623, 14.759567439083165, 13.84014315425176, 13.017157250649069, 13.870485354242774, 14.833970895280478, 15.782995990570445, 16.736107778183122, 9.895734941192647, 8.958988863637693, 7.952736725696395, 7.026042911238907, 5.98541115336201, 7.019146004339053, 7.7679611625402165, 8.75405016028261, 9.72525098772374, 10.598179585524452, 11.554042581848648, 12.453228437811191, 13.46747817318148, 14.464958251269021, 14.823255054039427, 13.991148880599768, 14.906803675851453, 15.870337024080477, 16.75483402531806, 17.68779342571997], [17.70262858982707, 16.835104916159125, 15.906880582556811, 14.960949153866167, 15.807819960471445, 15.54606078558009, 14.564985487862737, 13.598983996190832, 12.57975450594223, 11.641039753290517, 10.71230027876657, 9.754868216007463, 8.879630572610195, 7.8789522863734245, 7.0151263564091435, 6.02344406395681, 4.97879874810935, 5.921475439828627, 6.922592895939181, 7.907725779589486, 16.70016526267979, 17.42087672738557, 16.86896500767671, 15.928619197414637, 15.640818928123744, 14.689788341739293, 13.692161270458268, 12.657106046711258, 11.773895681241687, 10.812771969601279, 9.812624210331578, 8.81998474758091, 7.887308008712014, 6.944917079152225, 6.037413653475033, 5.058687440558197, 4.018750972386958, 4.941023016122717, 5.894973189693519, 6.889076438857979, 15.790426003634343, 16.4878451339143, 16.617100403974508, 15.638059020975971, 14.695165702561546, 13.723966768036789, 12.72986926283522, 11.710536532245877, 10.751718295685986, 9.835312350866948, 8.8992333252736, 7.873604855550097, 6.849478763627526, 5.906489631271128, 5.087086642787544, 4.039260665472889, 3.0477014256231323, 3.996965239436395, 4.936477696618562, 5.929808653450898, 14.778106894993781, 15.530090783020112, 15.679889040041296, 14.627487035599705, 13.698335830880081, 12.746324165004541, 11.78993421764107, 10.760300645616754, 9.77649267493386, 8.79036437359693, 7.832983302215552, 6.822377065447296, 5.863912580708763, 4.96415359351053, 4.060232809521268, 3.089571803660954, 2.0368868175109323, 3.0210138736694256, 4.0412115413190985, 4.959064872230941, 13.73281529390562, 14.537644768371704, 14.706917010388574, 13.643397572902222, 12.712702439202875, 11.785519876876597, 10.855841987303078, 9.817002702483867, 8.863147074354906, 7.889677531829158, 6.8603208890609375, 5.886830105598982, 4.920313373374171, 3.9795795117917043, 3.0224100068090287, 2.073196330030828, 1.041402452844274, 2.0892703085342488, 3.0623512041583307, 4.0077914526883704, 12.670705562257293, 13.530466492053916, 14.165290864156503, 13.16277314321807, 12.090618375459213, 11.053226447042594, 10.085419716932948, 9.053029170571639, 7.99186298529008, 6.922407800208017, 5.918532796768097, 4.974337717836278, 3.962963495643961, 2.9783659594054726, 2.0020058480959886, 1.0588478018210998, 0.0, 1.0648742393115187, 2.061221580605568, 3.075466957578854, 11.626513418778554, 12.566470278387358, 13.537664293106053, 13.947272368256566, 12.984279004501223, 11.935593220769663, 10.95367990117692, 9.902398762622484, 8.932792440822304, 7.908581268694778, 6.886123213971752, 5.919726331890818, 4.907925609627762, 3.911894727163241, 2.9805862069787867, 2.0982399221697103, 1.0745781720128451, 2.017404512387701, 3.0220740103079216, 3.9511398388324537, 10.695884786798194, 11.760350050214292, 12.663831377411745, 13.652048356671889, 13.85103031456309, 12.911294053152291, 11.871821602023548, 10.844020320016, 9.88573625157993, 8.860440535395751, 7.850690371593932, 6.874493615376313, 5.876338891091466, 4.938134256316352, 3.9541548729466225, 2.988711374635182, 2.0412914553163137, 3.0255770458715894, 3.971689919955157, 4.939792757617468, 9.818269372810498, 10.806263502460112, 11.695768580533288, 12.662619507759256, 13.61827764401881, 13.815895258549904, 12.750795551562819, 11.815271646727389, 10.835002979159704, 9.811654550462444, 8.79374073362832, 7.7547797303907675, 6.7752065847488465, 5.848705806226412, 4.893965151216831, 3.9665152651632476, 3.066204729118676, 4.03180099519073, 5.0342947508089315, 5.9078334854161785, 8.866051691586913, 9.747684187088765, 10.748306088742403, 11.742382282465888, 12.685251613138147, 13.666522621716515, 13.72031628434517, 12.689214835539085, 11.699988394107727, 10.770150558886519, 9.704441014163546, 8.758450824747978, 7.8181512768255, 6.841475515490766, 5.8924973049322285, 4.964870335423021, 4.040694711160847, 4.965098896733457, 5.986849284349467, 6.901843424903094, 7.856128423230243, 8.802876017216596, 9.823978580364683, 10.854055706825603, 11.880095544792413, 12.808461011122231, 13.883287308866077, 13.736040937173739, 12.717042459352102, 11.6723183304453, 10.692375540879647, 9.723611312514231, 8.840000036957562, 7.776263924499703, 6.929188473970905, 6.034472567408872, 5.061236283755621, 6.025583893190544, 6.912219718160981, 7.847688090166568, 6.937092087502323, 7.973011537094283, 8.951044403070965, 9.889606834039407, 10.916348929130898, 11.885882937732596, 12.90148231638748, 13.895359669301461, 13.723447676704994, 12.657894427420938, 11.671358562441897, 10.67783010802098, 9.754930142333754, 8.746937384126081, 7.969965061729438, 7.016289012842777, 6.014779318557873, 7.049143705510453, 7.950965996139804, 8.81849599429977, 5.870777036868756, 6.936813103609377, 7.982558763636781, 8.916670528059159, 9.972312366989783, 10.935655045049472, 11.905789232517902, 12.900588386301717, 13.916002236065843, 13.616609113366604, 12.683807235706364, 11.64410753347525, 10.680148265676307, 9.73542237110844, 8.933352465148543, 7.971983176879537, 7.01645266490401, 7.992559795027118, 8.926978049860212, 9.743853976710962, 4.957371136409927, 5.928935153325053, 7.001921662490578, 8.075377778501181, 9.08022161165647, 10.10168487052819, 11.145841356445588, 12.214162324595256, 13.16339742861043, 14.104169435548675, 13.523386152700683, 12.595541203283043, 11.62746239422947, 10.668662346704295, 9.888932738177244, 8.897065234067687, 7.963211037896096, 8.937606139270175, 9.930275445502193, 10.698338025859151, 4.081347687395559, 5.126252587444055, 6.166889359999747, 7.240336604463121, 8.207248333325069, 9.245480634753859, 10.202859210832537, 11.233069209093545, 12.197822220906163, 13.238583432668241, 14.31048615811613, 13.55691224591284, 12.597966773119609, 11.719328986122468, 10.874445173400947, 9.934050231936135, 8.894432348888413, 9.869477789147602, 10.818925811437406, 11.751722516260585, 4.977570936740035, 5.923664337078796, 6.985678377291194, 7.956919209555223, 8.984412807206812, 9.954258675357258, 10.93503167665937, 11.88404107841091, 12.95200297792322, 13.96126901058237, 15.012432950856152, 14.537287378771904, 13.64824248252555, 12.76425720097855, 11.840918153804294, 10.86709846393175, 9.908720328302058, 10.884101287318435, 11.781357944060332, 12.73984105508181, 5.918371479042939, 6.882803453955155, 7.850759573310875, 8.80610249092163, 9.800091108556497, 10.865927476730562, 11.831387548777462, 12.706511056211554, 13.742835099694178, 14.64053394376415, 15.499854231812426, 15.504802931328536, 14.658867226720364, 13.784068037263257, 12.852982995571507, 11.825952996434086, 10.944326220511188, 11.881464848897881, 12.844721169372466, 13.778234399977041, 6.923571359100875, 7.9340226415885935, 8.78056104671564, 8.041998391335564, 8.982211332696052, 9.887506443478932, 10.899411412672407, 11.716761064642801, 12.703146208011168, 13.583279394731454, 14.548039900683857, 15.547633904939982, 15.703372056884614, 14.738688242298775, 13.794190664273247, 12.873006513074936, 11.943612914752608, 12.873249225233913, 13.86229445956092, 14.791793560913023, 7.900846055278481, 8.866163471871987, 7.955486591882483, 7.047006491458905, 7.9816902433208075, 8.93546200483341, 9.878415182108194, 10.776979545770713, 11.711677764148083, 12.613838505888388, 13.559208454421299, 14.542130210649843, 15.455028946296721, 15.764703532447815, 14.805048025463012, 13.80618809422041, 12.88427783185328, 13.847763372890984, 14.796788468180951, 15.74990025579363, 8.836887139371548, 7.918772963934654, 6.912520825993355, 5.98582701153587, 6.964171421090532, 7.997906272067574, 8.826808964361318, 9.81289796210371, 10.784098789544839, 11.65702738734555, 12.612890383669747, 13.51207623963229, 14.526325975002578, 15.52380605309012, 15.769178743096111, 14.78017972417111, 13.92059615346196, 14.884129501690984, 15.768626502928567, 16.70158590333048], [16.81480394869688, 16.04452315314347, 15.16703355028741, 15.882172344371687, 16.729043150976967, 16.56730310089931, 15.586227803181954, 14.620226311510049, 13.600996821261447, 12.662282068609734, 11.733542594085787, 10.77611053132668, 9.816722640674195, 8.806865169111019, 7.874043800733462, 6.882361508281129, 5.8309480535940414, 4.868219570140611, 5.8693370262511655, 6.842851540277968, 15.812340621549598, 16.436437682805668, 16.20333937094739, 16.84984238792016, 16.705693167435264, 15.75466258105081, 14.757035509769786, 13.721980286022776, 12.838769920553204, 11.834014284920496, 10.833866525650794, 9.841227062900128, 8.893032714953812, 7.887977715499383, 6.937331580866292, 5.958605367949456, 4.918668899778218, 3.8877671464347014, 4.841717320005503, 5.82420219954646, 14.805986959054442, 15.503406089334398, 16.446028956177173, 16.702933260287494, 15.760039941873064, 14.788841007348307, 13.794743502146737, 12.775410771557395, 11.816592534997504, 10.900186590178466, 9.958402111956632, 8.921213289852984, 7.889444109762529, 6.920176468384172, 6.032190835727515, 4.984364858412859, 3.992805618563102, 2.943709369748379, 3.883221826930546, 4.8649344141393795, 13.79366785041388, 14.545651738440212, 15.50881759224396, 15.692361274911226, 14.763210070191603, 13.811198404316059, 12.854808456952588, 11.825174884928272, 10.841366914245377, 9.855238612908447, 8.89785754152707, 7.887251304758814, 6.928786820020282, 5.977840430623575, 5.005337002461238, 4.0346759966009245, 2.981991010450902, 1.9677580039814098, 2.987955671631082, 3.8941906329194227, 12.74837624932572, 13.553205723791804, 14.531044802877611, 14.708271812213743, 13.777576678514396, 12.850394116188118, 11.9207162266146, 10.881876941795388, 9.928021313666427, 8.954551771140679, 7.925195128372457, 6.9517043449105, 5.9851876126856896, 5.044453751103223, 4.079513030998987, 3.115676171722761, 2.0838822945362074, 1.036014438846233, 1.997476964846812, 2.9429172133768517, 11.686266517677392, 12.546027447474016, 13.57054398304237, 14.22764738252959, 13.155492614770733, 12.118100686354113, 11.150293956244468, 10.117903409883159, 9.0567372246016, 7.9872820395195365, 6.983407036079616, 6.039211957147797, 5.02783773495548, 4.043240198716991, 3.0668800874075073, 2.1237220411326185, 1.0648742393115187, 0.0, 0.9963473412940489, 2.0105927182673353, 10.642074374198653, 11.582031233807458, 12.553225248526152, 13.571766877601368, 14.049153243812741, 13.00046746008118, 12.018554140488439, 10.967273001934002, 9.997666680133822, 8.973455508006298, 7.9509974532832715, 6.984600571202337, 5.972799848939282, 4.97676896647476, 4.045460446290305, 3.0194631126752305, 1.9958013625183653, 1.0529750221435092, 2.037634965728021, 2.966700794252553, 9.711445742218293, 10.775911005634391, 11.679392332831844, 12.667609312091988, 13.559662257854837, 13.976168292463809, 12.936695841335066, 11.908894559327518, 10.950610490891448, 9.91536791154302, 8.9056177477412, 7.92942099152358, 6.931266267238733, 5.99306163246362, 4.929717748837877, 3.909934565140702, 2.962514645821834, 2.0917749471819613, 2.9872508753752562, 3.9553537130375673, 8.833830328230597, 9.821824457880211, 10.711329535953388, 11.678180463179356, 12.63383859943891, 13.616092207530635, 13.672018742068337, 12.736494837232907, 11.756226169665222, 10.732877740967965, 9.71496392413384, 8.676002920896288, 7.696429775254367, 6.769928996731932, 5.815188341722351, 4.887738455668767, 3.987427919624196, 3.158615760554313, 4.049855706229031, 4.923394440836278, 7.881612647007012, 8.763245142508865, 9.763867044162502, 10.757943237885987, 11.700812568558247, 12.682083577136614, 13.618372700946184, 13.610438026044605, 12.621211584613247, 11.691373749392039, 10.625664204669066, 9.679674015253498, 8.73937446733102, 7.762698705996286, 6.813720495437748, 5.8860935259285405, 4.961917901666367, 4.091913662097039, 5.002410239769566, 5.917404380323194, 6.871689378650342, 7.818436972636695, 8.839539535784782, 9.869616662245702, 10.895656500212512, 11.82402196654233, 12.898848264286176, 13.842292260196505, 13.638265649857622, 12.59354152095082, 11.613598731385167, 10.644834503019752, 9.761223227463082, 8.697487115005224, 7.850411664476425, 6.955695757914391, 5.982459474261141, 5.152398658554127, 5.92778067358108, 6.8632490455866675, 5.952653042922423, 6.988572492514383, 7.966605358491064, 8.905167789459508, 9.931909884550999, 10.901443893152697, 11.91704327180758, 12.910920624721562, 13.88882570497133, 13.579117617926459, 12.592581752947417, 11.599053298526501, 10.676153332839275, 9.668160574631603, 8.891188252234958, 7.937512203348297, 6.936002509063393, 6.208939569878986, 6.966526951559903, 7.834056949719869, 4.886337992288856, 5.952374059029476, 6.998119719056881, 7.932231483479259, 8.987873322409884, 9.951216000469573, 10.921350187938003, 11.916149341721818, 12.931563191485944, 13.947341345818327, 13.605030426211886, 12.565330723980772, 11.601371456181829, 10.656645561613962, 9.854575655654063, 8.893206367385057, 7.93767585540953, 7.221907272010199, 7.9840273421426, 8.759414932131062, 3.9729320918300264, 4.944496108745152, 6.0174826179106775, 7.090938733921281, 8.095782567076569, 9.11724582594829, 10.080967117134069, 11.149288085283736, 12.098523189298911, 13.039295196237155, 14.08969703752768, 13.516764393788565, 12.548685584734992, 11.589885537209817, 10.810155928682764, 9.818288424573208, 8.884434228401616, 8.166953616253256, 8.987324737784581, 9.71389898127925, 3.0164734480840405, 4.0613783481325365, 5.102015120688228, 6.175462365151603, 7.14237409401355, 8.18060639544234, 9.137984971521018, 10.168194969782025, 11.132947981594643, 12.173709193356721, 13.24561191880461, 14.292054366541647, 13.51918996362513, 12.64055217662799, 11.795668363906467, 10.855273422441655, 9.815655539393934, 9.098825266130683, 9.913970923308465, 10.77147055033977, 3.9126966974285162, 4.858790097767277, 5.920804137979675, 6.892044970243704, 7.9195385678952945, 8.88938443604574, 9.870157437347853, 10.819166839099392, 11.887128738611702, 12.896394771270852, 13.947558711544634, 14.909422683445873, 14.569465673031072, 13.685480391484072, 12.762141344309814, 11.78832165443727, 10.829943518807578, 10.113448764301516, 10.876403055931391, 11.801688822426673, 4.85349723973142, 5.8179292146436365, 6.785885333999357, 7.741228251610111, 8.735216869244978, 9.801053237419042, 10.804302121471636, 11.816102957945429, 12.852427001428053, 13.829597050387063, 14.894102293258081, 15.876938236002506, 15.580090417225886, 14.705291227768779, 13.774206186077027, 12.747176186939607, 11.865549411016708, 11.110812325880964, 11.939766281243525, 12.840082167321906, 5.8586971197893565, 6.869148402277075, 7.71568680740412, 8.727339121769377, 9.685474524547026, 10.745074167674975, 11.736278257576691, 12.6160094524923, 13.60473765073223, 14.518476679120182, 15.519518890744814, 16.52938955840209, 16.624595247390136, 15.659911432804297, 14.715413854778767, 13.794229703580456, 12.864836105258128, 12.122763466072419, 12.98984407197615, 13.853641328257888, 6.835971815966962, 7.81290760218397, 6.902230722194467, 7.899155796943597, 8.840607687645125, 9.794379449157729, 10.737332626432513, 11.676227933620211, 12.613269206869147, 13.549035790277117, 14.580450769740516, 15.56337252596906, 16.47627126161594, 16.685926722953337, 15.726271215968533, 14.72741128472593, 13.8055010223588, 13.107916340621584, 14.006206705165296, 14.886787768311729, 7.772012900060029, 6.865517094246638, 5.859264956305339, 6.837976317020561, 7.82308886541485, 8.856823716391894, 9.754721847098912, 10.74999003016771, 11.805341104864056, 12.678269702664767, 13.634132698988964, 14.533318554951506, 15.547568290321795, 16.545048368409336, 16.69040193360163, 15.70140291467663, 14.84181934396748, 14.144282469421583, 14.978044739912912, 15.83847341584858], [15.818456607402831, 15.048175811849422, 15.867224533958858, 16.769926999338733, 17.616797805944007, 17.53509426994527, 16.554018972227915, 15.588017480556008, 14.568787990307404, 13.630073237655692, 12.701333763131744, 11.743901700372637, 10.784513809720151, 9.774656338156975, 8.841834969779418, 7.850152677327085, 6.798739222639997, 5.836010739186567, 4.958103280932788, 5.846504198983918, 14.81599328025555, 15.440090341511619, 16.412730921003956, 17.35307673126603, 17.702040508729315, 16.75100992234486, 15.753382851063837, 14.718327627316826, 13.806639250405773, 12.801805453966454, 11.801657694696752, 10.809018231946085, 9.86082388399977, 8.85576888454534, 7.905122749912248, 6.926396536995412, 5.8864600688241735, 4.855558315480657, 3.930483574687125, 4.82785485825241, 13.809639617760393, 14.507058748040349, 15.449681614883124, 16.45007302486111, 16.756387283167115, 15.785188348642357, 14.791090843440788, 13.771758112851446, 12.812939876291555, 11.896533931472517, 10.954749453250681, 9.917560631147033, 8.885791451056578, 7.916523809678221, 7.028538177021564, 5.980712199706908, 4.975185323725789, 3.911500538794335, 2.971988081612168, 3.86858707284533, 12.797320509119832, 13.549304397146162, 14.51247025094991, 15.5648722553915, 15.759557411485654, 14.80754574561011, 13.851155798246639, 12.821522226222323, 11.837714255539428, 10.851585954202498, 9.894204882821121, 8.883598646052864, 7.925134161314331, 6.974187771917624, 6.001684343755287, 5.031023337894974, 3.9783383517449513, 2.964105345275459, 2.043503998535865, 2.8978432916253736, 11.75202890803167, 12.556858382497754, 13.534697461583562, 14.526196139688533, 14.773924019808447, 13.846741457482167, 12.917063567908649, 11.878224283089438, 10.924368654960476, 9.950899112434728, 8.921542469666507, 7.948051686204549, 6.981534953979739, 6.040801092397272, 5.075860372293036, 4.11202351301681, 3.0802296358302566, 2.032361780140282, 1.0011296235527631, 1.9465698720828026, 10.689919176383343, 11.549680106179967, 12.57419664174832, 13.576714362686754, 14.151839956064782, 13.114448027648162, 12.146641297538517, 11.114250751177208, 10.053084565895649, 8.983629380813586, 7.979754377373665, 7.0355592984418465, 6.0241850762495295, 5.03958754001104, 4.063227428701556, 3.1200693824266676, 2.061221580605568, 0.9963473412940489, 0.0, 1.0142453769732862, 9.645727032904604, 10.585683892513408, 11.556877907232103, 12.575419536307319, 13.538412900062662, 13.996814801375232, 13.01490148178249, 11.963620343228053, 10.994014021427873, 9.969802849300347, 8.94734479457732, 7.9809479124963865, 6.969147190233331, 5.973116307768809, 5.0418077875843545, 4.012445212885913, 2.988783462729048, 2.045957122354192, 1.041287624433972, 1.9703534529585038, 8.715098400924244, 9.779563664340342, 10.683044991537795, 11.67126197079794, 12.563314916560788, 13.503051177971587, 13.929597306312502, 12.901796024304954, 11.943511955868884, 10.88328821540329, 9.87353805160147, 8.89734129538385, 7.899186571099003, 6.96098193632389, 5.897638052698147, 4.877854869000972, 3.930434949682104, 2.9461493591268284, 1.9909035340812071, 2.959006371743518, 7.837482986936548, 8.825477116586162, 9.714982194659338, 10.681833121885306, 11.63749125814486, 12.619744866236585, 13.626111419574384, 13.704415141093179, 12.724146473525494, 11.700798044828236, 10.682884227994112, 9.64392322475656, 8.664350079114637, 7.7378493005922016, 6.783108645582621, 5.855658759529037, 4.955348223484466, 4.01299017249918, 3.0535083649349817, 3.927047099542228, 6.885265305712962, 7.7668978012148155, 8.767519702868453, 9.761595896591938, 10.704465227264198, 11.685736235842565, 12.622025359652135, 13.65312680845822, 13.589131888473519, 12.65929405325231, 11.593584508529338, 10.64759431911377, 9.70729477119129, 8.730619009856555, 7.781640799298017, 6.85401382978881, 5.927049748197248, 4.946288074041906, 4.006062898475517, 4.921057039029144, 5.875342037356292, 6.822089631342645, 7.843192194490732, 8.873269320951653, 9.899309158918463, 10.827674625248282, 11.902500922992127, 12.845944918902457, 13.864943396724094, 13.561461824811092, 12.581519035245439, 11.612754806880023, 10.729143531323352, 9.665407418865493, 8.818331968336695, 7.923616061774661, 6.947591320792022, 5.949103343329436, 4.931433332287031, 5.8669017042926175, 4.956305701628374, 5.9922251512203335, 6.970258017197015, 7.908820448165459, 8.93556254325695, 9.905096551858648, 10.920695930513531, 11.914573283427513, 12.89247836367728, 13.958031612961337, 13.560502056807689, 12.566973602386772, 11.644073636699545, 10.636080878491873, 9.85726881651453, 8.902644049879179, 7.901134355594275, 6.989476506383696, 5.970179610265854, 6.837709608425819, 3.8899906509948066, 4.956026717735427, 6.001772377762832, 6.93588414218521, 7.991525981115834, 8.954868659175524, 9.925002846643954, 10.919802000427769, 11.935215850191895, 12.950994004524278, 13.883795882184517, 13.533251027841041, 12.569291760042098, 11.624565865474231, 10.82058588897613, 9.858338213915939, 8.898205385804753, 7.922098255681646, 6.987680000848551, 7.763067590837012, 2.9765847505359773, 3.9481487674511038, 5.021135276616629, 6.094591392627232, 7.0994352257825195, 8.12089848465424, 9.084619775840022, 10.152940743989689, 11.102175848004864, 12.042947854943108, 13.093349696233632, 14.021194645651272, 13.516605888595262, 12.557805841070087, 11.77616616200483, 10.78342027110409, 9.844963758796839, 8.867144599924703, 7.990977396490532, 8.717551639985201, 2.0201261067899914, 3.0650310068384874, 4.105667779394179, 5.179115023857554, 6.146026752719501, 7.184259054148291, 8.14163763022697, 9.171847628487978, 10.136600640300596, 11.177361852062674, 12.249264577510562, 13.2957070252476, 14.254652498040832, 13.60847248048826, 12.761678597228533, 11.815802952836878, 10.776185069789156, 9.799016249802131, 8.917623582014416, 9.77512320904572, 2.916349356134467, 3.8624427564732278, 4.924456796685626, 5.895697628949655, 6.923191226601245, 7.8930370947516915, 8.873810096053804, 9.822819497805343, 10.890781397317653, 11.900047429976805, 12.951211370250586, 13.913075342151826, 14.947437903585442, 14.653400695344342, 13.72815157763188, 12.748851184832493, 11.7904730492028, 10.813639747972964, 9.880055714637342, 10.805341481132622, 3.8571498984373713, 4.821581873349587, 5.7895379927053074, 6.744880910316062, 7.7388695279509285, 8.804705896124993, 9.807954780177587, 10.819755616651381, 11.856079660134005, 12.833249709093016, 13.897754951964034, 14.880590894708458, 15.854935626150757, 15.673211531629049, 14.73473571647225, 13.707705717334829, 12.802328557192299, 11.811003309552412, 10.943418939949478, 11.843734826027855, 4.862349778495307, 5.872801060983026, 6.719339466110071, 7.730991780475328, 8.689127183252976, 9.748726826380928, 10.739930916282642, 11.749470917492538, 12.820643760080918, 13.748794942559947, 14.74983715418458, 15.759707821841856, 16.739816655169143, 16.619481861959873, 15.627363437317275, 14.6819843585475, 13.752590760225171, 12.822954449743866, 11.993496730682102, 12.857293986963837, 5.839624474672913, 6.862615634160572, 7.670603644339602, 8.677423434439769, 9.68964827262822, 10.692498089792267, 11.635451267067051, 12.574346574254749, 13.511387847503684, 14.447154430911654, 15.520172355939945, 16.50309411216849, 17.444062430661898, 17.645497152108913, 16.634590761165533, 15.615165939692973, 14.693255677325844, 13.808107324293031, 13.009859363871248, 13.890440427017678, 6.77566555876598, 5.95428334892826, 6.827056125351295, 7.805767486066517, 8.790880034460807, 9.82461488543785, 10.722513016144868, 11.717781199213666, 12.773132273910013, 13.646060871710725, 14.601923868034921, 15.501109723997464, 16.515359459367755, 17.512839537455296, 17.578156588568675, 16.58915756964367, 15.729573998934523, 14.84447345309303, 13.981697398618865, 14.842126074554528], [14.817816444170374, 15.384005987829076, 16.375088365595246, 17.320106611582045, 18.25962399317988, 18.44038628801296, 17.459310990295606, 16.4933094986237, 15.474080008375095, 14.535365255723383, 13.606625781199435, 12.649193718440328, 11.689805827787842, 10.679948356224665, 9.747126987847109, 8.755444695394775, 7.704031240707689, 6.7413027572542585, 5.863395299000479, 4.957491063534045, 13.815353117023092, 14.439450178279161, 15.4120907577715, 16.352436568033575, 17.334818779775464, 17.765255299318145, 16.767628228037122, 15.726768780888225, 14.711931268473464, 13.707097472034144, 12.706949712764443, 11.714310250013776, 10.76611590206746, 9.76106090261303, 8.810414767979939, 7.831688555063103, 6.791752086891865, 5.7608503335483485, 4.835775592754817, 3.938841722802537, 12.808999454527935, 13.506418584807891, 14.449041451650666, 15.449432861628651, 16.446824801559334, 16.799433725615643, 15.805336220414073, 14.786003489824731, 13.82718525326484, 12.910779308445802, 11.959637792228452, 10.922448970124805, 9.89067979003435, 8.921412148655993, 7.991760219373994, 6.943934242059338, 5.88047734179348, 4.816792556862026, 3.8772800996798598, 2.9795739373954566, 11.796680345887374, 12.548664233913705, 13.511830087717453, 14.564232092159042, 15.441884501832629, 15.821791122583395, 14.865401175219924, 13.835767603195608, 12.851959632512713, 11.865831331175784, 10.908450259794405, 9.89784402302615, 8.939379538287618, 7.979076110895394, 7.006572682733058, 6.035911676872744, 4.983226690722722, 3.9689936842532294, 2.948796016603557, 2.0088301561755, 10.751388744799213, 11.556218219265297, 12.534057298351104, 13.525555976456076, 14.456251110155423, 14.860986834455451, 13.931308944881932, 12.892469660062721, 11.93861403193376, 10.965144489408011, 9.93578784663979, 8.962297063177836, 7.995780330953025, 7.055046469370558, 6.089030104281132, 5.1251932450049065, 4.093399367818353, 3.0455315121283784, 2.002996985162969, 1.0575567366329295, 9.689279013150886, 10.549039942947509, 11.573556478515863, 12.576074199454297, 13.503712212618314, 14.128693404621446, 13.1608866745118, 12.128496128150491, 11.067329942868932, 9.99787475778687, 8.99399975434695, 8.049804675415132, 7.038430453222816, 6.053832916984327, 5.077472805674843, 4.134314759399954, 3.075466957578854, 2.0105927182673353, 1.0142453769732862, 0.0, 8.645086869672147, 9.585043729280951, 10.556237743999645, 11.574779373074861, 12.537772736830204, 13.544148274068355, 13.983052041867333, 12.931770903312897, 11.962164581512717, 10.937953409385191, 9.866289594389306, 8.899892712308372, 7.878239598856968, 6.853948052314658, 5.922639532130204, 4.86993670670252, 3.846274956545655, 2.903448616170799, 1.8987791182505782, 0.9697132897260462, 7.714458237691786, 8.778923501107885, 9.682404828305337, 10.670621807565482, 11.56267475332833, 12.50241101473913, 13.541883465867873, 13.75928751812156, 12.80100344968549, 11.740779709219897, 10.731029545418076, 9.754832789200456, 8.75667806491561, 7.818473430140497, 6.755129546514754, 5.7353463628175785, 4.78792644349871, 3.8036408529434347, 2.8483950278978134, 1.9583662085110607, 6.836842823704091, 7.824836953353705, 8.714342031426881, 9.681192958652849, 10.636851094912403, 11.619104703004128, 12.625471256341926, 13.560995161177356, 13.5816379673421, 12.558289538644841, 11.540375721810717, 10.501414718573164, 9.521841572931242, 8.595340794408807, 7.640600139399227, 6.713150253345644, 5.812839717301072, 4.870481666315786, 3.910999858751588, 2.9264069363097707, 5.8846251424805045, 6.766257637982358, 7.766879539635996, 8.76095573335948, 9.70382506403174, 10.685096072610108, 11.621385196419677, 12.652486645225762, 13.64171308665712, 13.516785547068915, 12.451076002345943, 11.505085812930375, 10.564786265007895, 9.58811050367316, 8.639132293114624, 7.711505323605417, 6.784541242013855, 5.803779567858513, 4.863554392292123, 3.920416875796686, 4.874701874123835, 5.821449468110187, 6.842552031258275, 7.872629157719196, 8.898668995686005, 9.827034462015824, 10.90186075975967, 11.845304755669996, 12.864303233491633, 13.909027362398435, 13.439010529062044, 12.470246300696628, 11.586635025139957, 10.522898912682098, 9.675823462153302, 8.781107555591268, 7.805082814608629, 6.806594837146042, 5.788924826103637, 4.86626154106016, 3.955665538395916, 4.991584987987876, 5.969617853964557, 6.908180284933001, 7.934922380024492, 8.90445638862619, 9.920055767281074, 10.913933120195054, 11.891838200444822, 12.957391449728878, 13.899848003340317, 13.424465096203377, 12.50156513051615, 11.493572372308478, 10.714760310331137, 9.760135543695785, 8.758625849410882, 7.8469680002003015, 6.82767110408246, 5.837069445193362, 2.889350487762349, 3.9553865545029696, 5.001132214530374, 5.9352439789527525, 6.990885817883377, 7.954228495943066, 8.924362683411495, 9.91916183719531, 10.934575686959436, 11.950353841291818, 12.883155718952057, 13.922855421183172, 13.426783253858703, 12.482057359290836, 11.678077382792736, 10.715829707732546, 9.6707991464502, 8.694692016327092, 7.760273761493998, 6.762427427604554, 1.9759445873035197, 2.9475086042186462, 4.020495113384172, 5.093951229394775, 6.098795062550062, 7.109463519989406, 8.070374398866734, 9.138695367016402, 10.087930471031576, 11.028702477969821, 12.079104319260345, 13.006949268677985, 14.025009116281494, 13.415297334886692, 12.633657655821438, 11.610576563270332, 10.617557519442286, 9.63973836057015, 8.74138851620096, 7.716911476752744, 1.0058807298167052, 2.050785629865201, 3.0914224024208927, 4.164869646884267, 5.131781375746215, 6.170013677175005, 7.127392253253683, 8.15760225151469, 9.122355263327309, 10.163116475089387, 11.235019200537275, 12.281461648274313, 13.240407121067545, 14.197452395406122, 13.546094374088963, 12.588396713482325, 11.548778830434603, 10.571610010447577, 9.668034701724844, 8.774483045813263, 1.9861471236938222, 2.932240524032583, 3.994254564244981, 4.96549539650901, 5.9929889941606, 6.962834862311046, 7.943607863613159, 8.892617265364699, 9.960579164877009, 10.96984519753616, 12.02100913780994, 12.98287310971118, 14.017235671144796, 15.001825832565524, 14.51256735449231, 13.52144494547794, 12.563066809848248, 11.58623350861841, 10.63046683434777, 9.804701317900165, 2.9269476659967264, 3.8913796409089425, 4.8593357602646625, 5.814678677875417, 6.808667295510284, 7.874503663684348, 8.877752547736943, 9.889553384210735, 10.92587742769336, 11.90304747665237, 12.967552719523388, 13.950388662267812, 14.924733393710111, 15.964376974928719, 15.507329477117697, 14.480299477980276, 13.574922317837745, 12.583597070197857, 11.693830059659906, 10.843094662795398, 3.9733366430454335, 4.942598828542381, 5.789137233669427, 6.800789548034684, 7.758924950812332, 8.818524593940282, 9.809728683841998, 10.819268685051894, 11.890441527640274, 12.818592710119303, 13.819634921743935, 14.829505589401212, 15.809614422728497, 16.774298237314337, 16.39995719796272, 15.454578119192945, 14.525184520870617, 13.595548210389312, 12.74390785039253, 11.85665382373138, 4.950611339223039, 5.953377917407941, 6.740401411898958, 7.747221201999125, 8.759446040187576, 9.762295857351623, 10.705249034626407, 11.644144341814105, 12.58118561506304, 13.51695219847101, 14.5899701234993, 15.572891879727845, 16.560500697008127, 17.54623756438845, 17.40718452181098, 16.387759700338417, 15.46584943797129, 14.580701084938477, 13.760270483581676, 12.88980026378522, 5.886652423316106, 6.859575366995951, 7.732348143418987, 8.711059504134209, 9.696172052528498, 10.699851590117458, 11.627805034212559, 12.608225925481108, 13.508764589666285, 14.473763317013848, 15.429626313338044, 16.406401742065153, 17.420651477435445, 18.418131555522987, 18.35075034921412, 17.361751330289117, 16.50216775957997, 15.617067213738476, 14.732108518329293, 13.84148591132207], [6.172729574498229, 6.738919118156929, 7.7300014959231, 8.675019741909896, 9.61453712350773, 10.624834603470545, 11.499986601200458, 12.465988092872363, 13.485217583120967, 14.42393233577268, 15.352671810296627, 16.310103873055734, 17.383048349209286, 18.392905820772462, 18.392213857519252, 17.40053156506692, 16.349118110379834, 15.386389626926402, 14.508482168672625, 13.60257793320619, 5.170266247350947, 5.794363308607014, 6.767003888099352, 7.707349698361426, 8.689731910103314, 9.684635277216616, 10.545210226313397, 11.573598877475883, 12.588436389890644, 13.593270186329963, 14.593417945599665, 15.586057408350332, 16.534251756296648, 17.539306755751078, 17.455501637652084, 16.476775424735248, 15.43683895656401, 14.405937203220493, 13.480862462426963, 12.583928592474683, 4.16391258485579, 4.861331715135744, 5.80395458197852, 6.804345991956503, 7.801737931887188, 8.718813703514112, 9.582918218690349, 10.627029363010502, 11.585847599570393, 12.626535151768135, 13.666184111979765, 14.678802672139891, 15.597855874437988, 16.530365234210272, 16.58187143047352, 15.589021111731483, 14.525564211465625, 13.461879426534171, 12.522366969352005, 11.624660807067603, 3.1515934762152282, 3.903577364241557, 4.866743218045306, 5.919145222486896, 6.796797632160484, 7.741171100481863, 8.6429831734962, 9.672616745520516, 10.65642471620341, 11.64255301754034, 12.599934088921717, 13.62757488203709, 14.612289691519225, 15.588029196449675, 15.546830558699368, 14.676750370799578, 13.624065384649557, 12.609832378180064, 11.593882886275702, 10.653917025847646, 2.106301875127066, 2.9111313495931492, 3.8889704286789573, 4.880469106783931, 5.811164240483277, 6.738346802809556, 7.668024692383074, 8.706863977202286, 9.660719605331247, 10.634189147856995, 11.698890558471167, 12.70217375195982, 13.668690484184632, 14.609424345767097, 14.497456361708366, 13.695933645928141, 12.667915871622828, 11.678088813044887, 10.646856656457368, 9.702643606305076, 1.0441921434787393, 1.9039530732753618, 2.928469608843718, 3.9309873297821514, 4.858625342946168, 5.896017271362788, 6.863824001472432, 7.8962145478337415, 8.9573807331153, 9.954557071451266, 10.958432074891185, 11.902627153823003, 12.91400137601532, 13.898598912253808, 13.477052202995326, 12.646109170567382, 11.626513418778554, 10.642074374198653, 9.645727032904604, 8.645086869672147, 0.0, 0.9399568596088043, 1.9111508743274992, 2.9296925034027153, 3.892685867158059, 4.941371650889619, 5.923284970482362, 6.9745661090367985, 7.9441724308369785, 8.968383602964504, 10.04004741796039, 11.006444300041323, 12.028097413492727, 13.052388960035037, 12.498471844112528, 11.575596996922574, 10.551935246765709, 9.609108906390853, 8.604439408470633, 7.6753735799461005, 0.9306286319803604, 1.9370370380060122, 2.900369746309642, 3.9386524565249204, 4.925912030193643, 5.865648291604441, 6.905120742733184, 7.931379061903691, 8.88966313033976, 9.949886870805354, 10.959637034607175, 11.935833790824795, 12.933988515109641, 12.449435107096313, 11.524903178144692, 10.580765198194705, 9.635798042827279, 8.651512452272003, 7.6962666272263816, 6.686720661161086, 1.8630472443727575, 2.891123585760192, 3.8684325431880984, 4.835283470414066, 5.790941606673621, 6.7731952147653445, 7.838294921752429, 8.77381882658786, 9.754087494155545, 10.777435922852803, 11.795349739686927, 12.83431074292448, 12.411652627252238, 11.485151848729803, 10.530411193720223, 9.60296130766664, 8.668947496252388, 7.703351230180333, 6.65816078771837, 5.718679933362376, 2.916789180207088, 3.949702901131539, 4.8158950349789835, 5.809971228702468, 6.735913157557464, 7.717184166135832, 8.653473289945401, 9.684574738751486, 10.673801180182844, 11.603639015404053, 12.669348560127025, 12.670149800865106, 11.683926465068751, 10.613928751867345, 9.691584966754709, 8.763957997245502, 7.754032884190339, 6.773271210034998, 5.705606254177835, 4.72466999387546, 3.926712448563758, 4.873460042550111, 5.852731697847634, 6.849372700978034, 7.779090856674528, 8.707456323004347, 9.686243057303189, 10.645527571062447, 11.664526048884083, 12.605217113514513, 12.755443247656402, 11.704989313098853, 10.727376993208031, 9.679140342858407, 8.686768411348325, 7.737024662179547, 6.746247542061627, 5.797905831408726, 4.780235820366321, 3.778825328611986, 4.858210058841553, 5.883312596119805, 6.8770406216925375, 7.896145236445339, 8.80210635024231, 9.76134222803676, 10.688231349716222, 11.57689920653739, 12.648067057663232, 12.76419216661341, 11.74429897201302, 10.750770517592104, 9.719378307422247, 8.711385549214574, 7.74883896817963, 6.794214201544278, 5.792704507259375, 4.827891732921344, 3.8255832319665375, 2.808017424478784, 5.92452510947512, 6.9195110296047115, 7.845526261126722, 8.779638025549099, 9.773733180594862, 10.711570120719884, 11.681704308188314, 12.571670489537135, 12.756569991220049, 11.740791836887666, 10.807989959227427, 9.768290256996313, 8.80433098919737, 7.850121557870709, 6.804120444819455, 5.841872769759265, 4.7910311609132386, 3.814924030790131, 2.8805057759570363, 1.8826594420675922, 6.9768977907160075, 7.9484618076311335, 8.830684895827416, 9.712236634321089, 10.717080467476377, 11.66889528017272, 12.626972516610493, 13.046009809389334, 12.096774705374159, 11.156002698435914, 10.10560085714539, 9.17775590772775, 8.159696060124242, 7.106368373189068, 6.152181205846595, 5.100259569184566, 4.107240525356519, 3.0431602768197967, 1.9902026749450483, 0.9657256354968321, 7.956454172802454, 8.936074546431463, 9.860958549704357, 10.783730269545387, 11.68681545246748, 12.60834512298712, 13.5657236990658, 13.899644192359892, 12.934891180547273, 11.894129968785196, 10.822227243337307, 9.77578479560027, 8.816839322807038, 7.85979404846846, 6.923996860884385, 5.966299200277748, 4.926681317230027, 3.866296882758737, 2.9168488604689324, 1.990497054859922, 8.93672056667957, 9.88281396701833, 10.931851975235917, 11.742394218045462, 12.703424577059897, 13.606191642550806, 14.566823649733312, 14.846415772805814, 13.778453873293504, 12.769187840634354, 11.718023900360572, 10.756159928459333, 9.867115032212979, 8.904722263324542, 7.890469841287732, 6.8993474322733634, 5.91937756274344, 4.880920380929569, 3.879280993091858, 3.0207153269468248, 9.877521108982474, 10.84195308389469, 11.809909203250411, 12.715404287035701, 13.709392904670569, 14.659882623858676, 15.581308475721022, 15.743105415122495, 14.70678137163987, 13.72961132268086, 12.66456748207402, 11.723675481015965, 10.877739776407793, 9.89530170441764, 8.885231963913121, 7.8582019647757, 6.8696091901489025, 5.878283942509016, 4.942644218403993, 4.059108671842058, 10.95009311799659, 11.89317227152813, 12.739710676655175, 13.732570630868063, 14.69070603364571, 15.712452486503585, 16.513284611826077, 16.61674804989463, 15.54557520730625, 14.617424024827221, 13.616381813202588, 12.631555142829605, 11.651446309502319, 10.68676249491648, 9.69464407027388, 8.749264991504104, 7.819871393181776, 6.89023508270047, 5.992722009136617, 5.0726678327780395, 11.927367814174195, 12.903951360393691, 13.690974854884706, 14.697794644984873, 15.691227123020955, 16.664496925149106, 17.534280842390288, 17.459672770327195, 16.522631497078258, 15.586864913670286, 14.58263968891627, 13.599717932687726, 12.612109115407442, 11.71277778506552, 10.70187139412214, 9.682446572649578, 8.760536310282449, 7.875387957249635, 7.009084642325764, 6.105814272831881, 12.863408898267261, 13.851341868331025, 14.733940620773833, 15.750070130663344, 16.70874594525123, 17.602052657914943, 18.593510524737002, 18.3163157387028, 17.276004027727343, 16.297398918875608, 15.46089929666034, 14.417539316811027, 13.39333007168411, 12.45880716642784, 11.569913264350525, 10.642177359808066, 9.715372742314104, 8.752752576788927, 7.805397531387486, 7.057499920368731], [6.786926219331953, 5.798962258548125, 6.7900446363142954, 7.735062882301093, 8.674580263898928, 9.684877743861739, 10.560029741591654, 11.52603123326356, 12.545260723512161, 13.483975476163874, 14.412714950687821, 15.370147013446928, 16.44309148960048, 17.452948961163656, 17.679203671007304, 16.730567471229747, 15.824058393622485, 14.861329910169054, 14.166628114056293, 14.542534792814994, 5.784462892184671, 4.85440644899821, 5.827047028490548, 6.767392838752622, 7.74977505049451, 8.74467841760781, 9.605253366704593, 10.633642017867079, 11.64847953028184, 12.65331332672116, 13.65346108599086, 14.646100548741527, 15.594294896687844, 16.59934989614227, 17.50613833710171, 17.41673228434405, 16.376795816172812, 15.345894062829297, 14.420819322035767, 13.523885452083487, 4.921969486722292, 3.92137485552694, 4.8639977223697155, 5.864389132347699, 6.861781072278384, 7.778856843905307, 8.642961359081545, 9.687072503401698, 10.645890739961589, 11.68657829215933, 12.726227252370963, 13.738845812531089, 14.657899014829184, 15.590408374601468, 16.531708719313837, 16.528977971340286, 15.465521071074429, 14.401836286142975, 13.462323828960809, 12.564617666676407, 4.009376385727851, 2.963620504632753, 3.9267863584365017, 4.979188362878092, 5.85684077255168, 6.801214240873059, 7.703026313887396, 8.732659885911712, 9.716467856594607, 10.702596157931536, 11.659977229312915, 12.687618022428287, 13.67233283191042, 14.64807233684087, 15.620575765003206, 15.61670723040838, 14.564022244258359, 13.549789237788866, 12.533839745884507, 11.59387388545645, 3.020373217319616, 1.971174489984345, 2.949013569070153, 3.940512247175126, 4.8712073808744725, 5.7983899432007515, 6.72806783277427, 7.766907117593481, 8.720762745722443, 9.694232288248191, 10.758933698862363, 11.762216892351017, 12.728733624575828, 13.669467486158293, 14.664060752511844, 14.635890505536944, 13.607872731231632, 12.61804567265369, 11.586813516066172, 10.64260046591388, 1.9820712445862343, 0.9639962136665575, 1.9885127492349137, 2.9910304701733472, 3.918668483337364, 4.956060411753984, 5.923867141863628, 6.956257688224937, 8.017423873506496, 9.01460021184246, 10.018475215282379, 10.962670294214197, 11.974044516406513, 12.958642052645002, 13.935002163954486, 13.586066030176184, 12.566470278387358, 11.582031233807458, 10.585683892513408, 9.585043729280951, 0.9399568596088043, 0.0, 0.9711940147186949, 1.989735643793911, 2.9527290075492547, 4.001414791280815, 4.983328110873558, 6.034609249427994, 7.004215571228174, 8.028426743355698, 9.100090558351583, 10.066487440432518, 11.088140553883921, 12.112432100426231, 13.043740620610686, 12.515553856531378, 11.491892106374513, 10.549065765999657, 9.544396268079437, 8.615330439554905, 1.8705854915891647, 0.9970801783972081, 1.960412886700838, 2.998695596916116, 3.9859551705848397, 4.925691431995638, 5.965163883124381, 6.991422202294887, 7.949706270730957, 9.00993001119655, 10.01968017499837, 10.99587693121599, 11.994031655500837, 12.93223629027595, 12.464860037753496, 11.520722057803509, 10.575754902436081, 9.591469311880806, 8.636223486835185, 7.62667752076989, 2.8030041039815616, 1.9511667261513874, 2.928475683579294, 3.895326610805262, 4.850984747064817, 5.83323835515654, 6.898338062143625, 7.833861966979056, 8.814130634546741, 9.837479063244, 10.855392880078124, 11.894353883315677, 12.873927028957599, 12.425108708338607, 11.470368053329027, 10.542918167275444, 9.608904355861192, 8.643308089789137, 7.598117647327174, 6.65863679297118, 3.856746039815892, 3.0097460415227344, 3.87593817537018, 4.870014369093664, 5.79595629794866, 6.777227306527028, 7.713516430336597, 8.744617879142682, 9.73384432057404, 10.663682155795248, 11.72939170051822, 12.675381889933789, 12.623883324677557, 11.55388561147615, 10.631541826363513, 9.703914856854306, 8.693989743799143, 7.713228069643802, 6.645563113786639, 5.664626853484264, 4.866669308172562, 3.9545542113949046, 4.91277483823883, 5.9094158413692295, 6.839133997065724, 7.767499463395543, 8.746286197694385, 9.705570711453642, 10.724569189275279, 11.665260253905709, 12.645203043471362, 12.644946172707657, 11.667333852816835, 10.619097202467213, 9.626725270957131, 8.67698152178835, 7.686204401670431, 6.73786269101753, 5.720192679975125, 4.71878218822079, 5.798166918450357, 4.9644067649645995, 5.958134790537332, 6.965868728611343, 7.862149490633506, 8.821385368427956, 9.748274490107418, 10.636942346928585, 11.708110198054426, 12.650836350881347, 12.684255831621824, 11.690727377200908, 10.65933516703105, 9.651342408823378, 8.688795827788434, 7.7341710611530825, 6.732661366868179, 5.767848592530148, 4.765540091575342, 3.7479742840875883, 6.864481969083924, 6.000605198449506, 6.926620429971516, 7.860732194393894, 8.833776320986058, 9.77161326111108, 10.74174744857951, 11.63171362992833, 12.647127479692456, 12.68074869649647, 11.747946818836231, 10.708247116605117, 9.744287848806174, 8.790078417479513, 7.744077304428259, 6.781829629368069, 5.730988020522043, 4.754880890398935, 3.8204626355658404, 2.8226163016763963, 7.916854650324812, 7.050856548214868, 7.91177906467221, 8.793330803165883, 9.798174636321171, 10.728938420563916, 11.68701565700169, 12.628881098892194, 13.036731564982965, 12.09595955804472, 11.045557716754196, 10.117712767336556, 9.099652919733048, 8.046325232797873, 7.092138065455399, 6.04021642879337, 5.047197384965323, 3.983117136428601, 2.9301595345538525, 1.9056824951056364, 8.896411032411258, 8.038469287015198, 8.94205271854915, 9.864824438390182, 10.767909621312274, 11.668388263378317, 12.625766839456995, 13.65472459658748, 13.874848040156078, 12.834086828394, 11.762184102946112, 10.715741655209074, 9.756796182415842, 8.799750908077264, 7.863953720493189, 6.906256059886553, 5.866638176838831, 4.8062537423675415, 3.8568057200777366, 2.928376155967417, 9.876677426288374, 9.110778771356298, 10.01294614408071, 10.823488386890256, 11.784518745904691, 12.666234782942002, 13.626866790124508, 14.575876191876047, 14.71841073290231, 13.709144700243158, 12.657980759969377, 11.696116788068137, 10.807071891821785, 9.844679122933346, 8.830426700896536, 7.839304291882168, 6.859334422352246, 5.820877240538374, 4.819237852700662, 3.9585944280543197, 10.817477968591279, 10.161059261624487, 10.946253106480905, 11.796498455880496, 12.790487073515362, 13.719925764249872, 14.641351616112217, 15.572812310722085, 15.646738231248676, 14.669568182289666, 13.604524341682824, 12.663632340624769, 11.8176966360166, 10.835258564026445, 9.825188823521925, 8.798158824384505, 7.8095660497577075, 6.818240802117821, 5.882601078012797, 4.996987772949552, 11.890049977605393, 11.212278449257926, 11.876054579885668, 12.813664799712857, 13.771800202490505, 14.77249562689478, 15.573327752217272, 16.56256230229084, 16.485532066915056, 15.557380884436025, 14.556338672811393, 13.571512002438409, 12.591403169111123, 11.626719354525283, 10.634600929882684, 9.689221851112908, 8.75982825279058, 7.830191942309275, 6.9292155793490435, 5.994541150783178, 12.867324673783, 12.223057538123488, 12.827318758115199, 13.808656699589516, 14.77232129186575, 15.724540065540303, 16.594323982781486, 17.502343821162928, 17.250019761217608, 16.31425317780964, 15.352606756878277, 14.369685000649733, 13.382076183369449, 12.517722385723536, 11.580954750544064, 10.561529929071503, 9.600350323011178, 8.636864781973474, 7.687839686683508, 6.734727899070829, 13.803365757876065, 13.170448046060821, 13.870284524004326, 14.869836179512552, 15.789840114096025, 16.66209579830614, 17.6535536651282, 17.376358879093996, 16.336047168118537, 15.357442059266802, 14.520942437051534, 13.477582457202221, 12.453373212075306, 11.518850306819036, 10.62995640474172, 9.702220500199264, 8.775415882705301, 7.812795717180123, 6.865440671778682, 7.686413546607679], [7.758120234050647, 6.770156273266819, 6.013325749664984, 6.8850357828155495, 7.7790779964935926, 8.713683729143046, 9.588835726872961, 10.554837218544867, 11.57406670879347, 12.512781461445183, 13.44152093596913, 14.398952998728237, 15.47189747488179, 16.481754946444966, 16.744242879099744, 15.806380635935307, 14.899871558328046, 13.937143074874616, 14.783855811997807, 15.513728807533688, 6.755656906903365, 5.8256004637169045, 4.977019929005005, 5.917365739267079, 6.849923782986994, 7.773484402889117, 8.6340593519859, 9.662448003148386, 10.677285515563147, 11.682119312002467, 12.682267071272168, 13.674906534022835, 14.623100881969151, 15.62815588142358, 16.534944322383016, 16.77113725933392, 15.859919334050437, 14.917595498580525, 15.392013336754461, 14.495079466802181, 5.893163501440986, 4.8925688702456345, 3.9253529989561198, 4.925744408934103, 5.904270557424795, 6.807662829186612, 7.671767344362851, 8.715878488683005, 9.674696725242896, 10.715384277440638, 11.755033237652265, 12.767651797812391, 13.68670500011049, 14.619214359882774, 15.560514704595143, 16.56973161795676, 16.436715085793125, 15.37303030086167, 14.433517843679503, 13.535811681395101, 4.980570400446545, 3.934814519351448, 2.9881416350229064, 4.008000939094453, 4.885646757832984, 5.830020226154365, 6.731832299168701, 7.761465871193017, 8.74527384187591, 9.73140214321284, 10.688783214594217, 11.71642400770959, 12.701138817191726, 13.676878322122176, 14.649381750284512, 15.620042756144825, 15.535216258977053, 14.52098325250756, 13.505033760603201, 12.565067900175144, 3.99156723203831, 2.94236850470304, 2.010368845656558, 2.9693182324564313, 3.9000133661557776, 4.827195928482057, 5.756873818055576, 6.795713102874787, 7.749568731003748, 8.723038273529497, 9.787739684143668, 10.791022877632322, 11.757539609857133, 12.698273471439599, 13.69286673779315, 14.656703597069376, 14.579066745950326, 13.589239687372384, 12.558007530784867, 11.613794480632574, 2.9532652593049296, 1.9351902283852525, 1.0173187345162187, 2.0198364554546524, 2.94747446861867, 3.9848663970352893, 4.952673127144934, 5.985063673506243, 7.046229858787802, 8.043406197123764, 9.047281200563683, 9.991476279495501, 11.002850501687817, 11.987448037926306, 12.96380814923579, 13.906966195510678, 13.537664293106053, 12.553225248526152, 11.556877907232103, 10.556237743999645, 1.9111508743274992, 0.9711940147186949, 0.0, 1.0185416290752163, 1.98153499283056, 3.0302207765621194, 4.0121340961548615, 5.063415234709298, 6.033021556509478, 7.057232728637003, 8.128896543632887, 9.095293425713821, 10.116946539165225, 11.141238085707535, 12.07254660589199, 13.125249431319675, 12.463086121093207, 11.520259780718352, 10.515590282798131, 9.586524454273599, 2.8417795063078595, 1.968274193115903, 1.0254520947932775, 2.027501582197422, 3.014761155866145, 3.9544974172769427, 4.993969868405686, 6.0202281875761905, 6.9785122560122606, 8.038735996477854, 9.048486160279674, 10.024682916497294, 11.022837640782141, 11.961042275557254, 13.024386159182997, 12.491916072522205, 11.546948917154776, 10.5626633265995, 9.60741750155388, 8.597871535488585, 3.7741981187002565, 2.922360740870082, 1.9935148916717338, 2.9603658188977016, 3.916023955157256, 4.89827756324898, 5.963377270236065, 6.8989011750714955, 7.879169842639181, 8.90251827133644, 9.920432088170564, 10.959393091408117, 11.938966237050039, 12.865467015572474, 12.441562068047723, 11.51411218199414, 10.580098370579888, 9.614502104507833, 8.56931166204587, 7.629830807689875, 4.827940054534587, 3.9415992851162573, 2.940977383462619, 3.9350535771861037, 4.8609955060411, 5.842266514619467, 6.778555638429037, 7.809657087235123, 8.798883528666481, 9.72872136388769, 10.794430908610662, 11.74042109802623, 12.74776397683288, 12.525079626194845, 11.60273584108221, 10.675108871573002, 9.66518375851784, 8.684422084362497, 7.616757128505334, 6.635820868202959, 5.83315504897478, 4.8864074549884275, 3.97781404633127, 4.974455049461669, 5.9041732051581635, 6.832538671487983, 7.811325405786824, 8.77060991954608, 9.789608397367717, 10.73029946199815, 11.710242251563804, 12.705581585792483, 12.63852786753553, 11.590291217185907, 10.597919285675825, 9.648175536507045, 8.657398416389125, 7.709056705736225, 6.69138669469382, 5.689976202939485, 6.764652659252575, 5.896260008558122, 5.033947955242891, 6.030907936703783, 6.927188698725946, 7.886424576520396, 8.813313698199858, 9.701981555021025, 10.773149406146866, 11.715875558973789, 12.735576134569154, 12.661921391919602, 11.630529181749745, 10.622536423542073, 9.659989842507128, 8.705365075871777, 7.703855381586873, 6.739042607248843, 5.736734106294037, 4.7191682988062835, 7.830967709886142, 6.932458442043028, 6.0024335946770755, 6.936545359099454, 7.898815529078497, 8.83665246920352, 9.80678665667195, 10.69675283802077, 11.712166687784896, 12.727944842117278, 12.719140833554926, 11.679441131323811, 10.715481863524868, 9.761272432198208, 8.715271319146954, 7.753023644086763, 6.702182035240737, 5.72607490511763, 4.791656650284535, 3.793810316395091, 8.88334039112703, 7.98270979180839, 6.9875922293777695, 7.869143967871443, 8.87398780102673, 9.793977628656355, 10.752054865094129, 11.693920306984634, 12.643155410999809, 13.067153572763415, 12.01675173147289, 11.08890678205525, 10.070846934451742, 9.017519247516567, 8.063332080174094, 7.011410443512065, 6.018391399684019, 4.954311151147296, 3.9013535492725477, 2.8768765098243314, 9.862896773213476, 8.97032253060872, 8.01786588325471, 8.940637603095741, 9.843722786017834, 10.733427471470756, 11.690806047549435, 12.71976380467992, 13.670672266295345, 13.805280843112694, 12.733378117664806, 11.686935669927768, 10.727990197134536, 9.770944922795959, 8.835147735211883, 7.877450074605247, 6.837832191557525, 5.777447757086236, 4.827999734796432, 3.899570170686112, 10.843163167090593, 10.04263201494982, 9.08875930878627, 9.899301551595816, 10.86033191061025, 11.731273991034442, 12.691905998216948, 13.640915399968486, 14.646382298646374, 14.680338714961852, 13.629174774688071, 12.667310802786831, 11.77826590654048, 10.81587313765204, 9.80162071561523, 8.810498306600861, 7.8305284370709405, 6.792071255257069, 5.790431867419358, 4.929788442773015, 11.783963709393497, 10.990022390542187, 10.022066271186466, 10.872311620586055, 11.866300238220923, 12.784964972342312, 13.706390824204657, 14.637851518814525, 15.638694325014106, 15.64076219700836, 14.575718356401518, 13.634826355343463, 12.788890650735294, 11.806452578745137, 10.796382838240618, 9.769352839103197, 8.780760064476402, 7.789434816836516, 6.853795092731493, 5.9681817876682475, 12.856535718407612, 12.007525483535616, 10.95186774459123, 11.889477964418417, 12.847613367196065, 13.83753483498722, 14.638366960309712, 15.627601510383277, 16.698774352971657, 16.312500051934016, 15.36152447554044, 14.351653807883164, 13.371544974555878, 12.572543661153883, 11.605794944601378, 10.660415865831602, 9.731022267509275, 8.80138595702797, 7.900409594067738, 6.965735165501872, 13.833810414585217, 12.840285236065002, 11.90313192282076, 12.884469864295076, 13.848134456571309, 14.789579273632743, 15.659363190873925, 16.567383029255367, 16.278825746498917, 15.343059163090949, 14.381412742159583, 13.398490985931039, 12.410882168650755, 11.546528371004843, 10.641874289810694, 9.78070986274463, 8.961707104828438, 8.072442959330811, 8.659033701402201, 7.705921913789523, 14.769851498678284, 13.787675744002335, 12.946097688709887, 13.945649344218111, 14.865653278801584, 15.727135006398578, 16.71859287322064, 16.405164864375305, 15.364853153399848, 14.386248044548111, 13.549748422332843, 12.50638844248353, 11.482179197356613, 10.547656292100344, 9.658762390023027, 8.80671823279393, 7.925388783219758, 7.036076830530812, 7.836634686497376, 8.657607561326373], [8.776661863125863, 7.788697902342035, 7.0041304541056215, 5.9951488667320385, 6.767529148237763, 7.702134880887216, 8.57728687861713, 9.543288370289035, 10.562517860537639, 11.501232613189352, 12.429972087713299, 13.387404150472406, 14.460348626625958, 15.470206098189134, 15.750262109149341, 14.940457432713043, 14.130054254628604, 14.896302796932163, 15.743015534055354, 16.532270436608908, 7.774198535978582, 6.844142092792121, 5.967824633445642, 5.027478823183568, 5.838374934731164, 6.761935554633287, 7.62251050373007, 8.650899154892556, 9.665736667307318, 10.670570463746637, 11.670718223016339, 12.663357685767005, 13.611552033713322, 14.616607033167751, 15.523395474127188, 15.905214056111657, 15.090102030350995, 15.876755220638072, 16.41055496582968, 15.513621095877399, 6.911705130516203, 5.911110499320851, 4.918839592577158, 4.007024076214892, 4.892721709168965, 5.796113980930783, 6.660218496107022, 7.704329640427175, 8.663147876987065, 9.703835429184807, 10.743484389396437, 11.756102949556563, 12.67515615185466, 13.607665511626944, 14.548965856339313, 15.55818276970093, 16.06115157711482, 16.391571929936887, 15.452059472754721, 14.554353310470319, 5.999112029521761, 4.953356148426664, 3.981628228643945, 2.9964520908386243, 3.8740979095771557, 4.818471377898535, 5.720283450912872, 6.749917022937187, 7.733724993620082, 8.719853294957012, 9.67723436633839, 10.704875159453762, 11.689589968935897, 12.665329473866347, 13.637832902028682, 14.608493907888995, 15.661178894039017, 15.53952488158278, 14.523575389678419, 13.583609529250362, 5.010108861113527, 3.960910133778256, 3.0038554392775962, 1.9577693842006028, 2.888464517899949, 3.815647080226228, 4.745324969799746, 5.784164254618958, 6.738019882747919, 7.711489425273667, 8.776190835887839, 9.779474029376493, 10.745990761601304, 11.68672462318377, 12.68131788953732, 13.645154748813546, 14.6769486260001, 14.607781316447603, 13.576549159860084, 12.632336109707792, 3.9718068883801454, 2.9537318574604687, 2.0108053281372573, 1.0082876071988238, 1.9289328395434533, 2.966324767960073, 3.9341314980697177, 4.966522044431027, 6.027688229712586, 7.024864568048549, 8.028739571488469, 8.972934650420287, 9.984308872612603, 10.968906408851092, 11.945266520160576, 12.888424566435464, 13.947272368256565, 13.57176687760137, 12.57541953630732, 11.574779373074863, 2.9296925034027153, 1.989735643793911, 1.0185416290752163, 0.0, 0.9629933637553436, 2.0116791474869036, 2.993592467079646, 4.044873605634082, 5.014479927434262, 6.038691099561787, 7.110354914557672, 8.076751796638607, 9.09840491009001, 10.12269645663232, 11.054004976816776, 12.106707802244461, 13.130369552401326, 12.53880140979357, 11.534131911873349, 10.605066083348817, 3.8603211353830758, 2.986815822191119, 2.0439937238684935, 1.0089599531222053, 1.9962195267909286, 2.9359557882017264, 3.9754282393304696, 5.001686558500975, 5.959970626937045, 7.020194367402638, 8.029944531204459, 9.006141287422079, 10.004296011706925, 10.942500646482038, 12.005844530107781, 13.025627713804957, 12.565490546229995, 11.58120495567472, 10.625959130629099, 9.616413164563802, 4.792739747775473, 3.9409023699452987, 2.965239729260805, 1.9983888020348375, 2.9220431852068556, 3.9042967932985797, 4.955428362922896, 5.890952267758326, 6.871220935326011, 7.89456936402327, 8.912483180857395, 9.951444184094948, 10.93101732973687, 11.857518108259304, 12.812258763268884, 12.532653811069357, 11.598639999655106, 10.633043733583051, 9.587853291121087, 8.648372436765092, 5.846481683609803, 4.913324122705329, 3.9127022210516906, 3.045131340585497, 3.867014736090699, 4.848285744669067, 5.784574868478636, 6.815676317284722, 7.80490275871608, 8.734740593937289, 9.800450138660262, 10.74644032807583, 11.75378320688248, 12.823780920083884, 12.621277470157427, 11.69365050064822, 10.683725387593057, 9.702963713437715, 8.635298757580552, 7.654362497278176, 6.804879886563852, 5.8581322925774995, 4.949538883920342, 4.084532812861063, 4.910192435207763, 5.838557901537582, 6.817344635836423, 7.77662914959568, 8.795627627417316, 9.73631869204775, 10.716261481613403, 11.711600815842083, 12.704121670598884, 12.608832846261123, 11.616460914751041, 10.666717165582263, 9.675940045464342, 8.727598334811443, 7.709928323769037, 6.708517832014702, 7.736377496841647, 6.867984846147194, 6.005672792831963, 5.140985700103177, 5.933207928775545, 6.892443806569995, 7.819332928249456, 8.708000785070624, 9.779168636196465, 10.721894789023388, 11.741595364618753, 12.665819611348832, 12.649070810824963, 11.64107805261729, 10.678531471582346, 9.723906704946994, 8.72239701066209, 7.75758423632406, 6.755275735369254, 5.7377099278815, 8.802692547475214, 7.9041832796321, 6.974158432266147, 6.113922006083426, 6.9048347591280965, 7.842671699253119, 8.812805886721549, 9.702772068070368, 10.718185917834495, 11.733964072166877, 12.666765949827116, 12.697982760399029, 11.734023492600086, 10.779814061273425, 9.733812948222171, 8.77156527316198, 7.720723664315955, 6.744616534192847, 5.810198279359752, 4.812351945470308, 9.855065228716102, 8.954434629397461, 7.959317066966841, 7.046520614855416, 7.915564951492961, 8.799996858705954, 9.758074095143728, 10.699939537034233, 11.649174641049408, 12.589946647987652, 13.035293360548106, 12.107448411130466, 11.089388563526958, 10.036060876591783, 9.08187370924931, 8.029952072587282, 7.036933028759234, 5.972852780222512, 4.919895178347764, 3.8954181388995472, 10.834621610802548, 9.942047368197791, 8.989590720843783, 8.118014250079714, 8.885299936484063, 9.739446701520356, 10.696825277599034, 11.725783034729519, 12.676691496344944, 13.51990662888079, 13.751919746740024, 12.705477299002986, 11.746531826209754, 10.789486551871176, 9.853689364287101, 8.895991703680464, 7.856373820632741, 6.795989386161452, 5.846541363871648, 4.918111799761328, 11.814888004679664, 11.01435685253889, 10.047919030843818, 9.076678198579788, 9.90190906107648, 10.737293221084041, 11.697925228266547, 12.646934630018086, 13.652401528695973, 14.544015915979974, 14.647716403763289, 13.685852431862049, 12.796807535615695, 11.834414766727258, 10.820162344690448, 9.829039935676079, 8.849070066146156, 7.810612884332285, 6.808973496494573, 5.948330071848231, 12.755688546982569, 11.949182112599734, 10.981225993244013, 10.049688267570028, 10.939339879832525, 11.790984202391911, 12.712410054254256, 13.643870748864124, 14.644713555063705, 15.594834684235332, 15.299504522012588, 14.309169163737119, 13.421440547116177, 12.51561501793357, 11.582390471446368, 10.752783295496748, 9.799301693551618, 8.80797644591173, 7.872336721806708, 6.986723416743463, 13.828260555996684, 12.966685205593162, 11.911027466648777, 11.06685461140239, 11.9816901639738, 12.84355406503682, 13.644386190359311, 14.633620740432876, 15.704793583021257, 15.300951203678183, 14.349975627284609, 13.340104959627332, 12.359996126300047, 11.560994812898052, 10.641182802744629, 9.702342595634272, 9.012485105845599, 9.819927586103185, 8.918951223142955, 7.984276794577089, 14.80553525217429, 13.79944495812255, 12.862291644878308, 12.061846511279048, 12.982211253349044, 13.795598503682342, 14.665382420923525, 15.573402259304965, 15.267276898243088, 14.331510314835118, 13.369863893903752, 12.386942137675208, 11.399333320394923, 10.534979522749012, 9.630325441554863, 8.769161014488798, 8.071820188744926, 9.03530572978263, 9.677575330477419, 8.72446354286474, 15.741576336267356, 14.746835466059883, 13.905257410767435, 13.123025991202084, 13.99973007557932, 14.733154236448177, 15.724612103270239, 15.393616016119473, 14.353304305144016, 13.37469919629228, 12.538199574077012, 11.494839594227699, 10.470630349100782, 9.536107443844513, 8.647213541767195, 7.7951693845381, 7.035501867136247, 8.01580945964529, 8.855176315572592, 9.67614919040159], [9.721285696023212, 8.733321735239384, 7.8216145040823015, 6.762068919297603, 5.822551537699768, 6.757157270349221, 7.632309268079135, 8.59831075975104, 9.617540249999642, 10.556255002651355, 11.484994477175302, 12.44242653993441, 13.515371016087961, 14.525228487651137, 14.787268745393996, 13.9774640689577, 14.901258306139557, 15.667506848443116, 16.51421958556631, 17.468315218859747, 8.71882236887593, 7.78876592568947, 6.816125346197132, 5.875779535935058, 4.893397324193169, 5.816957944095292, 6.677532893192075, 7.705921544354561, 8.720759056769321, 9.72559285320864, 10.725740612478342, 11.718380075229009, 12.666574423175325, 13.671629422629755, 14.578417863589193, 14.942220692356313, 15.861306081861947, 16.647959272149027, 17.37354832958502, 16.476614459632742, 7.866335554371406, 6.8657409231760544, 5.847884872133587, 4.868843489135051, 3.94774409863097, 4.851136370392788, 5.715240885569027, 6.75935202988918, 7.71817026644907, 8.758857818646812, 9.798506778858442, 10.811125339018568, 11.730178541316665, 12.66268790108895, 13.603988245801318, 14.613205159162934, 15.676662059428793, 16.687533802054226, 16.415052836510064, 15.517346674225662, 6.9537424533769645, 5.907986572281867, 4.910673508200373, 3.8582715037587834, 2.9291202990391603, 3.8734937673605403, 4.775305840374877, 5.804939412399192, 6.788747383082087, 7.774875684419016, 8.732256755800394, 9.759897548915767, 10.744612358397902, 11.720351863328352, 12.692855291490687, 13.663516297351, 14.716201283501022, 15.711582436287255, 15.486568753433762, 14.546602893005705, 5.96473928496873, 4.915540557633459, 3.937701478547652, 2.8741820410613, 1.9434869073619536, 2.8706694696882327, 3.8003473592617514, 4.8391866440809626, 5.793042272209924, 6.766511814735672, 7.831213225349844, 8.834496418838498, 9.801013151063309, 10.741747012645774, 11.736340278999325, 12.700177138275551, 13.731971015462104, 14.779838871152078, 14.539542523615427, 13.595329473463135, 4.9348002521354895, 3.9167252212158123, 2.973798691892601, 1.9712809709541674, 0.9659394757881097, 2.0033314042047294, 2.971138134314374, 4.003528680675684, 5.064694865957243, 6.0618712042932055, 7.065746207733126, 8.009941286664944, 9.02131550885726, 10.005913045095749, 10.982273156405233, 11.925431202680121, 12.984279004501222, 14.04915324381274, 13.538412900062664, 12.537772736830206, 3.892685867158059, 2.9527290075492547, 1.98153499283056, 0.9629933637553436, 0.0, 1.0486857837315597, 2.0305991033243025, 3.081880241878739, 4.051486563678919, 5.075697735806444, 6.147361550802329, 7.113758432883263, 8.135411546334668, 9.159703092876978, 10.091011613061433, 11.143714438489118, 12.167376188645983, 13.110202529020839, 12.497125275628692, 11.56805944710416, 4.823314499138419, 3.949809185946463, 3.0069870876238376, 1.971953316877549, 1.033226163035585, 1.9729624244463828, 3.012434875575126, 4.0386931947456315, 4.9969772631817015, 6.057201003647295, 7.0669511674491154, 8.043147923666735, 9.041302647951582, 9.979507282726695, 11.042851166352438, 12.062634350049613, 13.010054269368482, 12.54419831943006, 11.58895249438444, 10.579406528319145, 5.755733111530816, 4.8615736096232816, 3.881558884937034, 2.9147079577110664, 1.959049821451512, 2.941303429543236, 3.9924349991675525, 4.927958904002983, 5.908227571570668, 6.931576000267927, 7.949489817102052, 8.988450820339605, 9.968023965981526, 10.894524744503961, 11.849265399513541, 12.776715285567125, 12.561633363410447, 11.596037097338392, 10.550846654876429, 9.611365800520435, 6.809475047365146, 5.829643278381557, 4.829021376727919, 3.846890703007615, 2.904021372335355, 3.8852923809137234, 4.821581504723293, 5.852682953529379, 6.841909394960737, 7.771747230181946, 8.837456774904918, 9.783446964320486, 10.790789843127136, 11.860787556328543, 12.862207894457836, 12.656643864403561, 11.646718751348399, 10.665957077193056, 9.598292121335893, 8.61735586103352, 7.72119904224008, 6.7744514482537275, 5.86585803959657, 4.886292175283181, 3.9471990714524186, 4.875564537782238, 5.85435127208108, 6.8136357858403365, 7.832634263661972, 8.773325328292406, 9.75326811785806, 10.74860745208674, 11.74112830684354, 12.79557596533748, 12.579454278506386, 11.629710529337606, 10.638933409219685, 9.690591698566784, 8.67292168752438, 7.671511195770045, 8.652696652517875, 7.784304001823422, 6.921991948508191, 5.942745062525295, 4.970214565020202, 5.92945044281465, 6.856339564494113, 7.74500742131528, 8.816175272441122, 9.758901425268045, 10.77860200086341, 11.702826247593489, 12.734218457763346, 12.604071416372634, 11.64152483533769, 10.686900068702338, 9.685390374417434, 8.720577600079404, 7.718269099124597, 6.700703291636843, 9.719011703151441, 8.820502435308327, 7.849793132927922, 6.915681368505544, 5.941841395372753, 6.879678335497774, 7.849812522966204, 8.739778704315023, 9.75519255407915, 10.770970708411532, 11.703772586071771, 12.727312305475353, 12.697016856355429, 11.742807425028769, 10.696806311977515, 9.734558636917324, 8.683717028071298, 7.70760989794819, 6.773191643115095, 5.775345309225651, 10.771384384392329, 9.870753785073688, 8.834951767628617, 7.848279977277533, 6.9525715877376175, 7.8370034949506096, 8.795080731388383, 9.736946173278888, 10.686181277294063, 11.626953284232307, 12.671666608353801, 13.07044177488581, 12.052381927282301, 10.999054240347126, 10.044867073004653, 8.992945436342625, 7.9999263925145785, 6.935846143977856, 5.882888542103108, 4.858411502654891, 11.750940766478776, 10.858366523874018, 9.865225421505556, 8.889218301590667, 7.922306572728719, 8.77645333776501, 9.733831913843689, 10.762789670974174, 11.713698132589599, 12.556913265125445, 13.600942137355508, 13.668470662758331, 12.709525189965099, 11.752479915626521, 10.816682728042446, 9.858985067435809, 8.819367184388087, 7.758982749916797, 6.809534727626992, 5.881105163516672, 12.731207160355892, 11.88113712256717, 10.819123082354771, 9.847882250090741, 8.938915697321137, 9.774299857328696, 10.734931864511202, 11.68394126626274, 12.689408164940629, 13.58102255222463, 14.63218649249841, 14.331707105755758, 13.487087680772998, 12.590448243680282, 11.650008752119133, 10.766660217461087, 9.812063429901501, 8.77360624808763, 7.7719668602499175, 6.911323435603575, 13.672007702658796, 12.720386164110687, 11.752430044754966, 10.820892319080981, 9.976346516077182, 10.827990838636566, 11.749416690498911, 12.68087738510878, 13.68172019130836, 14.631841320479987, 14.354526911474595, 13.364191553199126, 12.476462936578184, 11.570637407395575, 10.637412860908373, 9.807805684958751, 10.686045277660025, 9.770969809667076, 8.835330085562052, 7.949716780498807, 14.74457971167291, 13.737889257104115, 12.68223151815973, 11.838058662913342, 11.018696800218457, 11.880560701281475, 12.681392826603966, 13.670627376677531, 14.741800219265912, 14.355973593140186, 13.404998016746616, 12.39512734908934, 11.415018515762053, 10.616017202360057, 9.696205192206634, 8.757364985096277, 9.686758583418605, 10.61639489389991, 9.873581646998156, 8.938907218432291, 15.593640169121162, 14.570649009633502, 13.63349569638926, 12.833050562790001, 12.019217889593701, 12.832605139926997, 13.70238905716818, 14.61040889554962, 14.322299287705091, 13.386532704297121, 12.424886283365758, 11.441964527137214, 10.45435570985693, 9.590001912211017, 8.685347831016868, 7.824183403950803, 8.785363010011128, 9.748848551048832, 10.622199163374768, 9.66908737576209, 16.52968125321423, 15.518039517570836, 14.676461462278388, 13.894230042713037, 13.036736711823977, 13.770160872692832, 14.761618739514894, 14.448638405581477, 13.40832669460602, 12.429721585754283, 11.593221963539015, 10.549861983689702, 9.525652738562787, 8.591129833306518, 7.702235931229201, 6.850191774000105, 7.802421919701811, 8.782729512210853, 9.79691844692506, 10.62077302329894], [10.685573579142453, 9.697609618358625, 8.785902387201542, 7.726356802416843, 6.786839420819009, 5.867080028815902, 6.728730314296856, 7.694731805968761, 8.713961296217363, 9.652676048869075, 10.581415523393023, 11.53884758615213, 12.611792062305682, 13.621649533868858, 14.036123675063564, 14.925711426662138, 15.849505663843997, 16.615754206147557, 17.462466943270748, 18.416562576564186, 9.68311025199517, 8.75305380880871, 7.780413229316372, 6.840067419054298, 5.85768520731241, 4.926880702561974, 5.773953939409796, 6.802342590572281, 7.8171801029870425, 8.822013899426361, 9.822161658696063, 10.81480112144673, 11.762995469393045, 12.768050468847475, 13.674838909806914, 14.65356512272375, 15.693501590894988, 16.724403344238503, 17.681962798529067, 17.48298999687089, 8.830623437490646, 7.830028806295295, 6.812172755252828, 5.833131372254291, 4.912031981750211, 3.9610591288594694, 4.811661931786747, 5.8557730761069005, 6.81459131266679, 7.855278864864532, 8.894927825076163, 9.907546385236289, 10.826599587534385, 11.75910894730667, 12.700409292019039, 13.709626205380655, 14.773083105646514, 15.783954848271945, 16.72346730545411, 16.52372221146381, 7.918030336496205, 6.872274455401108, 5.874961391319614, 4.822559386878024, 3.8934081821584003, 2.983416525827222, 3.8717268865925973, 4.901360458616913, 5.885168429299807, 6.871296730636737, 7.828677802018115, 8.856318595133487, 9.841033404615622, 10.816772909546073, 11.789276337708408, 12.759937343568721, 13.812622329718742, 14.808003482504976, 15.828201150154648, 15.552978430243854, 6.929027168087971, 5.8798284407527, 4.901989361666892, 3.83846992418054, 2.9077747904811937, 1.9805922281549146, 2.896768405479472, 3.9356076902986827, 4.889463318427644, 5.862932860953393, 6.927634271567564, 7.930917465056218, 8.89743419728103, 9.838168058863495, 10.832761325217046, 11.796598184493272, 12.828392061679825, 13.876259917369799, 14.918794444335209, 14.601705010701284, 5.983486035867049, 4.965411004947372, 4.022484475624161, 3.0199667546857274, 2.0046382534082188, 0.9672463249915992, 1.935053055101244, 2.9674436014625534, 4.028609786744112, 5.013185420561646, 6.017060424001566, 6.961255502933385, 7.972629725125701, 8.95722726136419, 9.933587372673674, 10.876745418948563, 11.935593220769663, 13.000467460081182, 13.996814801375232, 13.544148274068355, 4.941371650889619, 4.001414791280815, 3.03022077656212, 2.0116791474869036, 1.0486857837315597, 0.0, 0.9819133195927425, 2.0331944581471793, 3.0028007799473597, 4.027011952074885, 5.09867576707077, 6.065072649151704, 7.086725762603108, 8.111017309145417, 9.042325829329872, 10.095028654757558, 11.118690404914423, 12.061516745289278, 13.066186243209499, 12.574434984342309, 5.872000282869979, 4.994758630021893, 4.031425921718263, 2.9794208039297416, 1.9814735207400243, 1.0417372593292265, 2.0438331544247523, 2.9900074110140715, 3.9482914794501416, 5.008515219915735, 6.018265383717555, 6.994462139935174, 7.992616864220021, 8.930821498995135, 9.994165382620878, 11.013948566318053, 11.961368485636921, 12.945654076192197, 12.59532803162259, 11.585782065557295, 6.804418895262376, 5.809820967327721, 4.829806242641474, 3.8629553154155056, 2.907297179155951, 2.0783080880932667, 3.023833278017179, 3.959357182852609, 4.939625850420294, 5.962974279117552, 6.980888095951677, 8.01984909918923, 8.999422244831152, 9.895104757361644, 10.849845412371224, 11.777295298424807, 12.711309109839059, 12.644722881069953, 11.599532438607989, 10.617741337758584, 7.833966625949749, 6.777890636085997, 5.777268734432359, 4.795138060712055, 3.8522687300397944, 3.0565496871411244, 3.992838810950693, 4.91389870969937, 5.886010390890536, 6.815848226111744, 7.881557770834717, 8.827547960250286, 9.834890839056936, 10.887874466625997, 11.88710774109866, 12.77565036868458, 12.695404535079959, 11.714642860924616, 10.646977905067454, 9.62373139827167, 8.66944639994452, 7.722698805958168, 6.8141053973010095, 5.83453953298762, 4.895446429156858, 4.124419467451805, 5.02560857830848, 5.970079826570689, 6.9400324218941964, 7.817426324222206, 8.797369113787859, 9.792708448016539, 10.78522930277334, 11.822662875634935, 12.815034807145016, 12.678396313069165, 11.687619192951244, 10.739277482298345, 9.72160747125594, 8.720196979501605, 9.600944010222316, 8.732551359527863, 7.870239306212631, 6.8909924202297335, 5.9184619227246404, 5.178305372484218, 6.0275968707215135, 6.901451462045633, 7.9726193131714735, 8.803002421197844, 9.82270299679321, 10.746927243523288, 11.778319453693145, 12.786312211900817, 12.690210619069248, 11.735585852433896, 10.734076158148993, 9.769263383810962, 8.766954882856156, 7.749389075368403, 10.667259060855883, 9.768749793012768, 8.79804049063236, 7.863928726209982, 6.890088753077192, 6.128533265167341, 7.0789393556439295, 7.896222745045377, 8.911636594809504, 9.826402750923588, 10.759204628583827, 11.771413301405152, 12.703537577035698, 12.791493208760327, 11.745492095709073, 10.783244420648883, 9.732402811802856, 8.756295681679749, 7.821877426846655, 6.8240310929572106, 11.719631742096771, 10.81900114277813, 9.783199125333054, 8.796527334981972, 7.900818945442056, 7.085858424620177, 8.024207564066108, 8.89339021400924, 9.842625318024416, 10.78339732496266, 11.727098650865857, 12.654943600283497, 13.10106771101386, 12.047740024078685, 11.093552856736212, 10.041631220074184, 9.048612176246138, 7.9845319277094156, 6.931574325834667, 5.907097286386451, 12.699188124183218, 11.80661388157846, 10.813472779209995, 9.837465659295107, 8.870553930433159, 8.025308267434578, 8.96718970967916, 9.919233711704527, 10.870142173319952, 11.713357305855798, 12.656374179867564, 13.626612343298463, 13.619246952911816, 12.662201678573238, 11.726404490989163, 10.907670851167367, 9.868052968119645, 8.807668533648355, 7.858220511358551, 6.9297909472482315, 13.679454518060334, 12.82938448027161, 11.767370440059212, 10.796129607795182, 9.887163055025576, 9.023154786998264, 9.968289660346672, 10.884322233149474, 11.845852205670981, 12.737466592954982, 13.718234216294542, 13.428128151973478, 12.583508726990718, 11.686869289898002, 10.759931510585815, 11.71762615208187, 10.86074921363306, 9.822292031819188, 8.820652643981477, 7.960009219335134, 14.620255060363238, 13.668633521815128, 12.700677402459407, 11.769139676785421, 10.924593873781621, 10.076845768306134, 10.982774486334382, 11.881258351995513, 12.838164232038713, 13.78828536121034, 13.450947957692316, 12.460612599416846, 11.572883982795904, 10.667058453613295, 9.747335619375056, 10.758771619579534, 11.637011212280806, 10.819655593398636, 9.884015869293613, 8.95738439669019, 15.692827069377353, 14.686136614808557, 13.63047887586417, 12.786306020617783, 11.966944157922896, 11.129415630951042, 11.914750622439437, 12.871008343564265, 13.906393196327041, 13.452394639357907, 12.501419062964336, 11.49154839530706, 10.511439561979774, 9.712438248577778, 8.806127950673316, 9.708330919717058, 10.637724518039386, 11.567360828520691, 10.837869530117397, 9.903195101551532, 16.5418875268256, 15.518896367337943, 14.581743054093701, 13.781297920494442, 12.96746524729814, 12.081460069596565, 12.93574685300365, 13.810789862436353, 13.418720333922812, 12.482953750514842, 11.521307329583479, 10.538385573354935, 9.55077675607465, 8.686422958428738, 7.79527058948355, 8.775149338571584, 9.736328944631909, 10.699814485669613, 11.586487046494009, 10.63337525888133, 17.477928610918667, 16.466286875275276, 15.624708819982828, 14.842477400417478, 13.984984069528416, 13.0190158023624, 13.994976535350364, 13.545059451799197, 12.50474774082374, 11.526142631972004, 10.689643009756736, 9.646283029907423, 8.622073784780508, 7.687550879524238, 6.812158689695883, 7.8011577086208845, 8.766709802821051, 9.747017395330094, 10.7612063300443, 11.58506090641818], [11.57316324676861, 10.585199285984782, 9.673492054827697, 8.613946470042999, 7.674429088445164, 6.751541212742289, 5.7704659150249356, 6.736467406696841, 7.755696896945444, 8.694411649597157, 9.623151124121105, 10.580583186880212, 11.653527663033763, 12.66338513459694, 13.596206502974496, 14.58788879542683, 15.639302250113916, 16.602030733567346, 17.661876787979537, 18.729692799687818, 10.570699919621328, 9.640643476434867, 8.668002896942529, 7.727657086680454, 6.745274874938565, 5.8133166114189, 4.815689540137876, 5.844078191300361, 6.858915703715122, 7.863749500154441, 8.863897259424142, 9.856536722174809, 10.804731070121125, 11.809786069575555, 12.716574510534993, 13.69530072345183, 14.735237191623067, 15.766138944966585, 16.72369839925715, 17.739432906726798, 9.718213105116801, 8.71761847392145, 7.699762422878983, 6.720721039880448, 5.799621649376366, 4.847495037716396, 3.853397532514827, 4.89750867683498, 5.85632691339487, 6.897014465592612, 7.936663425804244, 8.949281985964369, 9.868335188262465, 10.80084454803475, 11.742144892747119, 12.751361806108735, 13.814818706374593, 14.825690449000025, 15.765202906182191, 16.78064639253074, 8.80562000412236, 7.759864123027263, 6.76255105894577, 5.71014905450418, 4.780997849784557, 3.869852434684148, 2.913462487320677, 3.9430960593449926, 4.926904030027887, 5.913032331364817, 6.870413402746195, 7.898054195861567, 8.882769005343702, 9.858508510274152, 10.831011938436488, 11.8016729442968, 12.854357930446822, 13.849739083233056, 14.869936750882728, 15.809902611310784, 7.816616835714126, 6.767418108378855, 5.789579029293048, 4.726059591806696, 3.79536445810735, 2.868181895781071, 1.9385040062075523, 2.977343291026763, 3.9311989191557246, 4.904668461681473, 5.969369872295644, 6.972653065784298, 7.939169798009109, 8.879903659591575, 9.874496925945126, 10.838333785221351, 11.870127662407905, 12.917995518097879, 13.960530045063289, 14.905970293593327, 6.965399355459792, 5.947324324540115, 5.004397795216903, 4.0018800742784695, 2.981987314355589, 1.9445953859389689, 0.9767886558293242, 2.0091792021906336, 3.0631660223872275, 4.031272100968903, 5.035147104408823, 5.979342183340642, 6.990716405532959, 7.975313941771448, 8.951674053080932, 9.89483209935582, 10.95367990117692, 12.01855414048844, 13.01490148178249, 13.983052041867335, 5.923284970482362, 4.983328110873558, 4.012134096154862, 2.993592467079646, 2.0305991033243025, 0.9819133195927425, 0.0, 1.0512811385544367, 2.0208874603546167, 3.0450986324821416, 4.116762447478027, 5.083159329558961, 6.104812443010365, 7.129103989552675, 8.06041250973713, 9.113115335164816, 10.13677708532168, 11.079603425696536, 12.084272923616757, 13.013338752141289, 6.853913602462722, 5.976671949614635, 5.013339241311005, 3.961334123522484, 2.963386840332767, 2.023650578921969, 1.0619198348320098, 2.008094091421329, 2.966378159857399, 4.0266019003229925, 5.036352064124813, 6.012548820342432, 7.010703544627279, 7.948908179402393, 9.012252063028136, 10.03203524672531, 10.979455166044179, 11.963740756599455, 12.918986581645076, 12.567695385150037, 7.786332214855118, 6.791734286920463, 5.811719562234216, 4.844868635008248, 3.8892104987486937, 3.060221407686009, 2.0419199584244363, 2.9774438632598663, 3.9577125308275516, 4.98106095952481, 5.998974776358935, 7.037935779596487, 8.017508925238408, 8.913191437768901, 9.867932092778481, 10.795381978832065, 11.729395790246317, 12.694992056318371, 12.581445758200733, 11.599654657351326, 8.815879945542491, 7.7598039556787395, 6.759182054025101, 5.777051380304797, 4.8341820496325365, 3.982295142156255, 3.046006018346686, 3.931985390106628, 4.904097071297794, 5.833934906519002, 6.899644451241975, 7.8456346406575435, 8.852977519464194, 9.905961147033254, 10.905194421505918, 11.793737049091838, 12.703885772288487, 12.69655618051736, 11.628891224660197, 10.605644717864411, 9.651359719537263, 8.70461212555091, 7.796018716893752, 6.816452852580362, 5.8773597487496, 5.050164922466935, 4.078775785704473, 4.988166506977947, 5.958119102301454, 6.835513004629464, 7.815455794195117, 8.810795128423797, 9.803315983180598, 10.840749556042192, 11.833121487552274, 12.782865236721054, 12.669532512543988, 11.721190801891089, 10.703520790848684, 9.702110299094349, 10.582857329815058, 9.714464679120605, 8.852152625805374, 7.8729057398224755, 6.9003752423173825, 6.09636345677239, 5.0807640781175065, 5.919538142452891, 6.9907059935787315, 7.821089101605103, 8.840789677200467, 9.765013923930546, 10.796406134100403, 11.804398892308075, 12.76694547334302, 12.71749917202664, 11.715989477741736, 10.751176703403706, 9.7488682024489, 8.731302394961146, 11.649172380448626, 10.75066311260551, 9.779953810225102, 8.845842045802724, 7.872002072669934, 7.046591349455514, 6.1321065630399225, 6.914309425452635, 7.929723275216762, 8.844489431330846, 9.777291308991085, 10.78949998181241, 11.721624257442956, 12.675833688769616, 12.727405415301817, 11.765157740241627, 10.7143161313956, 9.738209001272493, 8.803790746439399, 7.8059444125499535, 12.701545061689513, 11.800914462370873, 10.765112444925796, 9.778440654574714, 8.882732265034798, 8.003916508908349, 7.077374771462101, 7.9114768944164995, 8.860711998431675, 9.80148400536992, 10.745185331273115, 11.673030280690755, 12.66893838599612, 12.824199744900337, 12.075466176328954, 11.023544539666926, 10.03052549583888, 8.966445247302158, 7.91348764542741, 6.889010605979194, 13.68110144377596, 12.788527201171203, 11.795386098802737, 10.81937897888785, 9.852467250025901, 8.94336635172275, 8.020356917075151, 8.937320392111785, 9.888228853727211, 10.731443986263058, 11.674460860274822, 12.644699023705721, 12.675520037124738, 11.773533105482164, 12.5971518917658, 11.889584170760111, 10.84996628771239, 9.7895818532411, 8.840133830951295, 7.9117042668409745, 14.661367837653076, 13.811297799864352, 12.749283759651954, 11.778042927387924, 10.869076374618318, 9.941212871286435, 9.021456867742664, 9.902408913556732, 10.863938886078241, 11.755553273362242, 12.7363208967018, 12.469863752701556, 11.625244327718796, 10.728604890626082, 11.630678911362452, 12.588373552858506, 11.842662533225804, 10.804205351411932, 9.80256596357422, 8.887403211404688, 15.60216837995598, 14.65054684140787, 13.682590722052149, 12.751052996378164, 11.906507193374363, 10.994903852594305, 10.035941693730374, 10.89934503240277, 11.856250912445972, 12.8063720416176, 12.492683558420394, 11.502348200144924, 10.614619583523982, 9.708794054341375, 10.618083020151692, 11.62951902035617, 12.507758613057442, 11.801568912991378, 10.865929188886355, 9.844974064316345, 16.674740388970097, 15.6680499344013, 14.612392195456913, 13.768219340210525, 12.948857477515638, 12.029470350093513, 10.967917829835429, 11.889095023971523, 12.924479876734301, 12.494130240085989, 11.543154663692414, 10.533283996035138, 9.553175162707852, 8.754173849305857, 9.676875351449953, 10.579078320493695, 11.508471918816022, 12.438108229297328, 11.725459197743552, 10.790784769177687, 17.523800846418347, 16.500809686930687, 15.563656373686444, 14.763211240087184, 13.934717054838472, 12.931867237674426, 11.988914060399642, 12.828876542843611, 12.460455934650893, 11.524689351242923, 10.563042930311557, 9.580121174083013, 8.592512356802729, 7.728158559156818, 8.666017990260187, 9.64589673934822, 10.607076345408545, 11.57056188644625, 12.474076714120166, 11.520964926507487, 18.459841930511413, 17.44820019486802, 16.60662213957557, 15.82439072001022, 14.903157821417304, 13.869422970440262, 13.048143742746356, 12.586795052527279, 11.546483341551822, 10.567878232700085, 9.731378610484818, 8.688018630635503, 7.6638093855085865, 6.729286480252318, 7.682906090472519, 8.671905109397521, 9.654299470447206, 10.634607062956249, 11.648795997670456, 12.472650574044337], [12.624444385323047, 11.636480424539219, 10.724773193382134, 9.665227608597435, 8.7257102269996, 7.802822351296726, 6.821747053579372, 6.125584651010255, 6.915726087099824, 7.854440839751536, 8.783180314275484, 9.74061237703459, 10.802608805462308, 11.729591388988629, 12.662412757366186, 13.616341532702027, 14.651569153197041, 15.614297636650472, 16.67414369106266, 17.714366433309884, 11.621981058175765, 10.691924614989304, 9.719284035496965, 8.77893822523489, 7.796556013493002, 6.864597749973337, 5.866970678692312, 5.0563814527196085, 5.975962137753257, 6.980795934192576, 7.980943693462279, 8.86209189361781, 9.810286241564127, 10.795556181767429, 11.672858696386577, 12.651584909303413, 13.69152137747465, 14.722423130818168, 15.679982585108732, 16.695717092578377, 10.769494243671238, 9.768899612475886, 8.75104356143342, 7.772002178434884, 6.850902787930803, 5.898776176270832, 4.904678671069264, 4.109811938254228, 4.953784752197556, 5.981962213922178, 6.960645331091587, 7.915712001586996, 8.824619374114047, 9.757128733886333, 10.698429078598702, 11.707645991960318, 12.771102892226176, 13.781974634851608, 14.721487092033774, 15.736930578382324, 9.856901142676797, 8.8111452615817, 7.813832197500207, 6.761430193058617, 5.832278988338993, 4.921133573238585, 3.964743625875114, 3.108031308528426, 3.97855913144543, 4.93701423665216, 5.894395308033538, 6.8644842114841955, 7.839053191195284, 8.814792696125735, 9.787296124288071, 10.757957130148384, 11.810642116298405, 12.806023269084639, 13.82622093673431, 14.766186797162367, 8.867897974268562, 7.818699246933292, 6.8408601678474845, 5.777340730361133, 4.846645596661787, 3.9194630343355077, 2.989785144761989, 2.068810434570722, 2.9500533388146066, 3.9235228813403547, 4.925654058147227, 5.928937251635881, 6.895453983860692, 7.836187845443159, 8.830781111796709, 9.794617971072935, 10.826411848259488, 11.874279703949462, 12.916814230914872, 13.86225447944491, 8.016680494014228, 6.998605463094551, 6.05567893377134, 5.053161212832906, 4.033268452910026, 2.9958765244934056, 2.028069794383761, 1.009124831581449, 2.011884883832791, 2.9799909624144663, 3.9838659658543865, 4.928061044786205, 5.939435266978522, 6.9240328032170115, 7.9003929145264955, 8.843550960801384, 9.902398762622484, 10.967273001934004, 11.963620343228053, 12.931770903312897, 6.974566109036798, 6.0346092494279935, 5.063415234709298, 4.044873605634082, 3.081880241878739, 2.0331944581471793, 1.0512811385544367, 0.0, 0.9696063218001802, 1.9938174939277051, 3.06548130892359, 4.031878191004524, 5.0535313044559285, 6.077822850998238, 7.009131371182693, 8.061834196610377, 9.085495946767242, 10.028322287142098, 11.032991785062318, 11.96205761358685, 7.905194741017158, 6.977108056695849, 6.01377534839222, 4.961770230603698, 3.9638229474139806, 3.0240866860031828, 1.9846142348744396, 0.9568129528668922, 1.9150970213029623, 2.9753207617685558, 3.9850709255703762, 4.961267681787995, 5.959422406072842, 6.897627040847956, 7.960970924473699, 8.980754108170874, 9.928174027489742, 10.912459618045018, 11.867705443090639, 12.877251409155935, 8.837613353409555, 7.792170394001678, 6.81215566931543, 5.845304742089462, 4.889646605829908, 3.9307980329537022, 2.865698325966617, 1.9301744211311869, 2.910443088698872, 3.9337915173961306, 4.9517053342302555, 5.987392546129917, 6.966965691771838, 7.861910299214466, 8.816650954224047, 9.74410084027763, 10.678114651691882, 11.643710917763936, 12.6889013602259, 12.564762645998773, 9.780987934189938, 8.724911944326186, 7.724290042672548, 6.730213848949064, 5.787344518276804, 4.806073509698436, 3.8697843858888668, 2.8847159479779485, 3.856827629169114, 4.786665464390323, 5.852375009113295, 6.798365198528864, 7.805708077335515, 8.85468000847882, 9.853913282951483, 10.742455910537403, 11.652604633734052, 12.577008819306663, 12.601386269650057, 11.570752706511858, 10.61646770818471, 9.669720114198356, 8.761126705541198, 7.769615321224629, 6.8023087563389355, 5.873943290009116, 4.900181578608525, 3.9408970648492683, 4.910849660172776, 5.788243562500784, 6.768186352066438, 7.763525686295118, 8.75604654105192, 9.789468417487758, 10.78184034899784, 11.731584098166618, 12.673146206328827, 12.772471940445524, 11.754801929403119, 10.753391437648784, 11.547965318462504, 10.679572667768051, 9.81726061445282, 8.826068208466744, 7.825324249906718, 6.917769249676442, 5.902169871021559, 4.872268700324211, 5.943436551450052, 6.773819659476423, 7.79352023507179, 8.717744481801867, 9.749136691971724, 10.757129450179397, 11.719676031214341, 12.674300797849693, 12.767270616296171, 11.802457841958141, 10.800149341003333, 9.78258353351558, 12.614280369096072, 11.715771101252956, 10.73311627886937, 9.799004514446992, 8.79531600263589, 7.8319733245762, 6.86183913710777, 5.867039983323956, 6.882453833088082, 7.797219989202167, 8.730021866862407, 9.742230539683732, 10.674354815314278, 11.628564246640938, 12.674565359692192, 12.816438878796061, 11.765597269950035, 10.789490139826928, 9.855071884993833, 8.857225551104388, 12.968288911164324, 12.76602245101832, 11.718274913570063, 10.731603123218981, 9.806046195000754, 8.789298484029036, 7.807107345529949, 6.86420745228782, 7.813442556302995, 8.75421456324124, 9.697915889144436, 10.625760838562076, 11.62166894386744, 12.561804222236793, 13.12674731488339, 12.074825678221362, 11.081806634393317, 10.017726385856594, 8.964768783981846, 7.94029174453363, 13.937651633129601, 13.753635189818649, 12.748548567447003, 11.712612097512416, 10.745700368650468, 9.707468067221678, 8.750089491143, 7.890050949983106, 8.840959411598531, 9.684174544134377, 10.627191418146143, 11.597429581577043, 12.064637281438152, 12.8248142440366, 13.648433030320236, 12.940865309314546, 11.901247426266824, 10.840862991795534, 9.89141496950573, 8.962985405395411, 14.832033963496576, 14.704530918488919, 13.64251687827652, 12.67127604601249, 11.675160454935808, 10.705314586785363, 9.751189441810512, 8.855139471428053, 9.81666944394956, 10.708283831233562, 11.689051454573121, 11.85898099701497, 11.014361572032211, 11.779886029180519, 12.681960049916889, 13.639654691412943, 12.893943671780239, 11.855486489966367, 10.853847102128656, 9.938684349959125, 15.766903838657223, 15.543779960032436, 14.575823840676716, 13.64428611500273, 12.712591273691853, 11.759005568093233, 10.765674267798222, 9.85207559027409, 10.808981470317292, 11.75910259948892, 11.778371648781876, 10.891465444458339, 10.003736827837397, 10.760075192895812, 11.669364158706129, 12.680800158910607, 13.559039751611879, 12.852850051545815, 11.917210327440792, 10.896255202870782, 16.730693284032302, 16.561283053025864, 15.50562531408148, 14.661452458835091, 13.754941557833128, 12.759202924161361, 11.697650403903276, 10.841825581842842, 11.87721043460562, 11.654159430240368, 10.826557317653307, 9.922401240348552, 8.942292407021267, 9.805454987860294, 10.72815649000439, 11.630359459048131, 12.55975305737046, 13.489389367851764, 12.776740336297989, 11.842065907732124, 17.707967980209908, 17.39404280555525, 16.45688949231101, 15.65644435871175, 14.66444962890632, 13.661599811742274, 12.71864663446749, 11.78160710071493, 11.620485124805272, 10.684718541397302, 9.837725871390749, 8.917755177006581, 7.981629601116143, 8.779439697711254, 9.717299128814624, 10.697177877902657, 11.658357483962982, 12.621843025000686, 13.525357852674603, 12.572246065061924, 18.644009064302974, 17.63443413606297, 16.6053430228152, 15.631877128237129, 14.55706888983575, 13.67952063006735, 12.677448066976522, 11.735876194955823, 10.7065125317062, 9.727907422854464, 8.891407800639197, 7.8480478207898825, 7.052926629822001, 7.780567618806755, 8.734187229026956, 9.723186247951958, 10.705580609001643, 11.685888201510686, 12.700077136224893, 13.523931712598774], [13.594050707123225, 12.606086746339397, 11.694379515182314, 10.634833930397615, 9.69531654879978, 8.772428673096906, 7.791353375379552, 6.958769379713294, 5.946119765299644, 6.884834517951356, 7.8135739924753045, 8.771006055234412, 9.833002483662128, 10.759985067188449, 11.692806435566006, 12.646735210901847, 13.681962831396861, 14.644691314850292, 15.704537369262482, 16.74476011150971, 12.591587379975943, 11.661530936789482, 10.688890357297144, 9.748544547035069, 8.766162335293181, 7.834204071773517, 6.836577000492492, 5.889566181422647, 5.006355815953077, 6.011189612392396, 7.011337371662099, 7.892485571817631, 8.840679919763947, 9.825949859967249, 10.703252374586397, 11.681978587503233, 12.72191505567447, 13.752816809017986, 14.710376263308554, 15.7261107707782, 11.739100565471418, 10.738505934276066, 9.7206498832336, 8.741608500235063, 7.820509109730983, 6.868382498071012, 5.874284992869444, 4.942996666957266, 3.9841784303973764, 5.012355892121998, 5.9910390092914065, 6.946105679786816, 7.8550130523138675, 8.787522412086153, 9.728822756798522, 10.738039670160138, 11.801496570425996, 12.81236831305143, 13.751880770233596, 14.767324256582146, 10.826507464476977, 9.78075158338188, 8.783438519300386, 7.731036514858797, 6.801885310139173, 5.890739895038765, 4.934349947675294, 3.9735235191010916, 3.0089528096452494, 3.967407914851979, 4.924788986233358, 5.8948778896840155, 6.869446869395104, 7.8451863743255545, 8.817689802487891, 9.788350808348204, 10.841035794498225, 11.83641694728446, 12.856614614934132, 13.79658047536219, 9.837504296068742, 8.788305568733472, 7.8104664896476645, 6.746947052161312, 5.816251918461966, 4.889069356135687, 3.959391466562169, 2.934302645143388, 1.9804470170144262, 2.953916559540174, 3.956047736347047, 4.959330929835701, 5.925847662060512, 6.866581523642979, 7.86117478999653, 8.825011649272756, 9.85680552645931, 10.904673382149284, 11.947207909114693, 12.892648157644732, 8.986286815814408, 7.968211784894731, 7.02528525557152, 6.022767534633086, 5.002874774710206, 3.9654828462935856, 2.997676116183941, 1.9787311533816292, 1.0422785620326107, 2.0103846406142862, 3.0142596440542064, 3.958454722986025, 4.9698289451783415, 5.954426481416831, 6.930786592726315, 7.873944639001203, 8.932792440822302, 9.997666680133822, 10.994014021427871, 11.962164581512717, 7.944172430836978, 7.0042155712281735, 6.033021556509478, 5.014479927434262, 4.051486563678919, 3.0028007799473593, 2.0208874603546167, 0.9696063218001802, 0.0, 1.0242111721275249, 2.09587498712341, 3.062271869204344, 4.083924982655748, 5.108216529198058, 6.039525049382513, 7.092227874810197, 8.115889624967062, 9.058715965341918, 10.063385463262138, 10.99245129178667, 8.874801062817339, 7.931522983022653, 6.968190274719023, 5.916185156930502, 4.918237873740784, 3.9785016123299863, 2.939029161201243, 1.9112278791936954, 0.9529438107576255, 2.0131675512232188, 3.022917715025039, 3.9991144712426583, 4.997269195527505, 5.935473830302618, 6.998817713928361, 8.018600897625536, 8.966020816944404, 9.95030640749968, 10.9055522325453, 11.915098198610597, 9.802890887367676, 8.746585320328482, 7.766570595642234, 6.799719668416266, 5.8440615321567115, 4.885212959280505, 3.82011325229342, 2.88458934745799, 1.9550520604109969, 2.9784004891082554, 3.99631430594238, 5.025239335584581, 6.004812481226502, 6.899757088669127, 7.854497743678708, 8.781947629732292, 9.715961441146543, 10.681557707218598, 11.726748149680562, 12.767454606744398, 10.735402860516741, 9.67932687065299, 8.678704968999352, 7.684628775275867, 6.741759444603606, 5.760488436025239, 4.824199312215669, 3.8391308743047516, 2.901436600881239, 3.8312744361024476, 4.89698398082542, 5.842974170240988, 6.850317049047639, 7.892526797933481, 8.891760072406145, 9.780302699992065, 10.690451423188714, 11.614855608761324, 12.679302683221097, 12.525167632838661, 11.570882634511513, 10.62413504052516, 9.715541631868003, 8.724030247551433, 7.756723682665738, 6.828358216335919, 5.854596504935328, 4.895311991176071, 3.9554586318849, 4.8328525342129085, 5.812795323778563, 6.808134658007242, 7.800655512764044, 8.82731520694242, 9.819687138452501, 10.76943088762128, 11.710992995783489, 12.675340605218413, 12.7244082512033, 11.722997759448965, 12.502380244789308, 11.633987594094855, 10.771675540779626, 9.780483134793547, 8.779739176233521, 7.872184176003245, 6.856584797348361, 5.826683626651015, 5.021493327775578, 5.818428631188548, 6.838129206783914, 7.762353453513992, 8.793745663683849, 9.797988666568799, 10.760535247603743, 11.715160014239094, 12.66453603058574, 12.772064163758323, 11.769755662803515, 10.752189855315763, 12.846082477861886, 12.67018602757976, 11.687531205196173, 10.753419440773795, 9.749730928962693, 8.786388250903004, 7.816254063434574, 6.821454909650759, 5.978755841260964, 6.841828960914292, 7.77463083857453, 8.786839511395856, 9.718963787026402, 10.673173218353062, 11.719174331404316, 12.670854178275855, 12.735203591750217, 11.75909646162711, 10.824678206794015, 9.82683187290457, 11.998682589364144, 12.97024660627927, 12.672689839896867, 11.686018049545785, 10.760461121327557, 9.74371341035584, 8.761522271856753, 7.818622378614624, 7.048175710309982, 7.84481903961334, 8.742524860856559, 9.670369810274199, 10.666277915579565, 11.606413193948917, 12.56060036129139, 13.044432000021544, 12.051412956193497, 10.987332707656774, 9.934375105782026, 8.90989806633381, 12.968045311329423, 13.957859345079601, 13.702963493773808, 12.667027023839221, 11.700115294977273, 10.661882993548483, 9.704504417469805, 8.84446587630991, 8.075692565605518, 8.774779020506479, 9.671800389858266, 10.642038553289165, 11.600984026082397, 12.558029300420975, 13.49382648800505, 13.910471631114726, 12.870853748067004, 11.810469313595714, 10.86102129130591, 9.932591727195591, 13.862427641696398, 14.808521042035158, 14.596931804603326, 13.625690972339296, 12.629575381262613, 11.659729513112168, 10.705604368137317, 9.809554397754857, 9.051402597956548, 9.798888307605663, 10.733660426285244, 10.890232306162957, 11.84754630073525, 12.71459199163037, 13.651566371717069, 14.609261013213121, 13.863549993580419, 12.825092811766547, 11.823453423928836, 10.908290671759305, 14.797297516857045, 15.76172949176926, 15.530238767003521, 14.598701041329535, 13.667006200018658, 12.713420494420038, 11.720089194125027, 10.806490516600896, 10.043714624324279, 10.849707075861021, 10.808765326981696, 9.922716753606325, 10.836921556540435, 11.694781155345662, 12.638970480506309, 13.650406480710785, 14.528646073412059, 13.822456373345993, 12.88681664924097, 11.865861524670962, 15.761086962232124, 16.80487339894312, 16.460040240408286, 15.615867385161897, 14.709356484159933, 13.713617850488166, 12.652065330230082, 11.796240508169648, 11.111943588612608, 10.68455310844019, 9.856950995853127, 8.953652549496539, 9.775477135724305, 10.740160950310145, 11.69776281180457, 12.599965780848311, 13.52935937917064, 14.458995689651944, 13.746346658098169, 12.811672229532304, 16.73836165840973, 17.471268636642687, 16.534115323398446, 15.527295533298279, 14.472618377880558, 13.469768560716512, 12.526815383441727, 11.58792007625403, 10.650878803005094, 9.715112219597124, 8.868119549590569, 7.9481488552064015, 8.814814329819182, 9.749046019511434, 10.686905450614804, 11.666784199702837, 12.627963805763162, 13.591449346800866, 14.49496417447478, 13.541852386862102, 17.674402742502796, 16.664827814262793, 15.63573670101502, 14.662270806436949, 13.58746256803557, 12.70991430826717, 11.707841745176342, 10.766269873155643, 9.736906209906023, 8.758301101054286, 7.921801478839018, 6.8784414989897025, 7.8861113585250395, 8.750173940606935, 9.703793550827136, 10.692792569752138, 11.675186930801823, 12.655494523310866, 13.669683458025073, 14.493538034398952], [14.55426689614288, 13.566302935359051, 12.654595704201968, 11.59505011941727, 10.655532737819435, 9.73264486211656, 8.751569564399206, 7.902879426824682, 6.8902298124110315, 5.9873913961376495, 6.916130870661598, 7.803157868116658, 8.808791311534602, 9.735773895060923, 10.66859526343848, 11.622524038774321, 12.657751659269335, 13.620480142722766, 14.680326197134956, 15.720548939382182, 13.551803568995597, 12.621747125809136, 11.649106546316798, 10.708760736054723, 9.726378524312835, 8.79442026079317, 7.7967931895121465, 6.833676228534035, 5.950465863064465, 5.060554319548751, 6.0276112700469815, 6.868274399690106, 7.816468747636422, 8.801738687839723, 9.67904120245887, 10.657767415375707, 11.697703883546945, 12.72860563689046, 13.686165091181028, 14.701899598650675, 12.699316754491072, 11.69872212329572, 10.680866072253254, 9.701824689254718, 8.780725298750637, 7.8285986870906665, 6.834501181889098, 5.887106714068654, 4.928288477508764, 4.011882532689726, 4.970749000432185, 5.9218945076592915, 6.830801880186342, 7.763311239958627, 8.704611584670996, 9.713828498032612, 10.77728539829847, 11.788157140923904, 12.72766959810607, 13.74311308445462, 11.786723653496631, 10.740967772401534, 9.74365470832004, 8.691252703878451, 7.7621014991588275, 6.850956084058419, 5.894566136694948, 4.919989244720316, 3.9530628567566373, 2.9669345554197077, 3.904498977374136, 4.870666717556491, 5.8452356972675785, 6.820975202198029, 7.793478630360365, 8.764139636220678, 9.8168246223707, 10.812205775156935, 11.832403442806607, 12.772369303234663, 10.797720485088396, 9.748521757753126, 8.770682678667319, 7.707163241180966, 6.77646810748162, 5.849285545155341, 4.919607655581823, 3.8807683707626124, 2.9269127426336508, 1.9534432001079027, 2.931836564219522, 3.9351197577081765, 4.9016364899329865, 5.842370351515453, 6.836963617869004, 7.80080047714523, 8.832594354331784, 9.880462210021758, 10.922996736987168, 11.868436985517206, 10.010497987941934, 8.992422957022256, 8.049496427699045, 7.046978706760612, 6.02708594683773, 4.98969401842111, 4.021887288311466, 3.002942325509154, 2.0556286535688244, 0.9861734684867611, 1.990048471926681, 2.9342435508584996, 3.945617773050816, 4.930215309289305, 5.906575420598789, 6.849733466873677, 7.9085812686947765, 8.973455508006296, 9.969802849300345, 10.937953409385193, 8.968383602964503, 8.028426743355698, 7.057232728637004, 6.038691099561788, 5.075697735806444, 4.027011952074885, 3.0450986324821416, 1.9938174939277051, 1.0242111721275249, 0.0, 1.0716638149958848, 2.038060697076819, 3.0597138105282236, 4.0840053570705335, 5.015313877254988, 6.068016702682672, 7.091678452839537, 8.034504793214394, 9.039174291134614, 9.968240119659146, 9.899012234944863, 8.955734155150179, 7.992401446846548, 6.940396329058027, 5.942449045868309, 5.002712784457511, 3.963240333328768, 2.9354390513212203, 1.9771549828851502, 0.9946362888635557, 2.004386452665376, 2.9805832088829955, 3.9787379331678423, 4.9169425679429555, 5.980286451568698, 7.000069635265874, 7.947489554584742, 8.931775145140017, 9.887020970185638, 10.896566936250935, 10.8271020594952, 9.770796492456006, 8.790781767769758, 7.82393084054379, 6.8682727042842355, 5.90942413140803, 4.844324424420945, 3.908800519585515, 2.9792632325385218, 1.9860313678869315, 3.003945184721056, 4.006708073224917, 4.986281218866838, 5.881225826309465, 6.835966481319046, 7.7634163673726295, 8.697430178786881, 9.663026444858936, 10.7082168873209, 11.748923344384735, 11.759614032644265, 10.703538042780513, 9.702916141126876, 8.70883994740339, 7.765970616731131, 6.7846996081527635, 5.848410484343194, 4.863342046432276, 3.910556987995429, 2.9807191527742205, 4.046428697497193, 4.992418886912762, 5.999761765719413, 6.873995535573819, 7.8732288100464825, 8.761771437632403, 9.671920160829051, 10.596324346401662, 11.660771420861435, 12.691404983999634, 12.595093806639037, 11.648346212652683, 10.739752803995525, 9.748241419678957, 8.780934854793262, 7.8525693884634435, 6.878807677062853, 5.919523163303596, 4.964579018999091, 3.982297250884682, 4.962240040450336, 5.957579374679016, 6.950100229435817, 7.808783944582756, 8.801155876092837, 9.750899625261617, 10.692461733423826, 11.65680934285875, 12.586141854672949, 12.74720893157649, 12.805576375634363, 12.658198766222378, 11.795886712907148, 10.804694306921071, 9.803950348361045, 8.89639534813077, 7.880795969475886, 6.85089479877854, 6.0306137148897685, 4.967873347860321, 5.987573923455687, 6.911798170185765, 7.943190380355622, 8.779457404209134, 9.742003985244079, 10.69662875187943, 11.646004768226078, 12.680369155178656, 12.793966834931041, 11.776401027443287, 11.827551215502224, 12.893587282242844, 12.711742377323697, 11.77763061290132, 10.773942101090217, 9.810599423030528, 8.840465235562098, 7.845666081778284, 6.987876228375154, 5.991273677586065, 6.924075555246303, 7.936284228067629, 8.868408503698175, 9.767942391191493, 10.705391388663184, 11.65232291591619, 12.647678114572214, 12.783307633754633, 11.84888937892154, 10.851043045032094, 10.97447141723662, 11.946035434151746, 13.01902194331727, 12.710229221673309, 11.784672293455081, 10.767924582483364, 9.785733443984277, 8.842833550742148, 7.9350357632233575, 6.994263756285114, 7.891969577528332, 8.819814526945972, 9.815722632251338, 10.701182366787348, 11.655369534129822, 12.577404973104342, 13.075624128321023, 12.0115438797843, 10.958586277909552, 9.934109238461335, 11.943834139201897, 12.933648172952076, 13.974284945507767, 13.691238195966745, 12.724326467104797, 11.686094165676007, 10.728715589597329, 9.868677048437434, 8.962552618518894, 7.924223737178251, 8.82124510653004, 9.791483269960938, 10.75042874275417, 11.707474017092748, 12.640881969353524, 13.598579629960161, 13.89506492019453, 12.83468048572324, 11.885232463433436, 10.956802899323117, 12.838216469568872, 13.784309869907633, 14.84632391012003, 14.64990214446682, 13.653786553390137, 12.683940685239692, 11.729815540264841, 10.833765569882381, 9.938262650869923, 8.948333024277435, 9.883105142957017, 10.771858402820001, 11.800704452160112, 12.75240223194883, 13.607354949756871, 14.531627861955776, 14.887761165707944, 13.849303983894073, 12.826989971800437, 11.86850686077896, 13.773086344729519, 14.737518319641735, 15.705474438997456, 15.62291221345706, 14.691217372146182, 13.737631666547562, 12.744300366252551, 11.830701688728418, 10.930574677237654, 9.999151792532793, 9.911322205167991, 10.866826800717716, 11.781031603651822, 12.63889120245705, 13.599186669525963, 14.61062266973044, 15.488862262431713, 14.846667545473519, 13.85355625247261, 12.826077713690616, 14.736875790104598, 15.780662226815593, 16.545484062585, 15.533831748219745, 14.575696345442097, 13.52436987754833, 12.639798474522308, 11.630258473312413, 10.715261169105514, 9.787109986626485, 8.959507874039423, 9.89776259660793, 10.719587182835692, 11.684270997421532, 12.657979000824223, 13.560181969867966, 14.489575568190293, 15.419211878671598, 14.706562847117823, 13.771888418551958, 15.714150486282204, 16.573825514828982, 15.63667220158474, 14.629852411484574, 13.575175256066853, 12.572325438902807, 11.629372261628022, 10.690476954440324, 9.75343568119139, 8.81766909778342, 7.970676427776863, 8.89225890231779, 9.758924376930569, 10.709262208531088, 11.647121639634458, 12.627000388722491, 13.588179994782816, 14.55166553582052, 15.455180363494435, 14.502068575881756, 16.65019157037527, 15.640616642135265, 14.611525528887494, 13.638059634309423, 12.563251395908043, 11.685703136139644, 10.683630573048816, 9.742058701028117, 8.832388441654034, 7.8608579792405795, 7.024358357025311, 7.82255154610109, 8.830221405636427, 9.710390129626589, 10.66400973984679, 11.653008758771792, 12.635403119821477, 13.61571071233052, 14.629899647044727, 15.453754223418606], [15.546250733527724, 14.558286772743896, 13.646579541586814, 12.587033956802115, 11.64751657520428, 10.705556376636618, 9.724481078919265, 8.80385267857584, 7.79120306416219, 6.888364647888808, 6.10352385750787, 6.7912464457240675, 7.796879889142012, 8.72234091550875, 9.655162283886307, 10.609091059222148, 11.644318679717163, 12.607047163170593, 13.666893217582782, 14.70711595983001, 14.543787406380442, 13.613730963193982, 12.641090383701643, 11.700744573439568, 10.71836236169768, 9.76733177531323, 8.769704704032204, 7.734649480285193, 6.851439114815623, 5.961527571299909, 5.033639028462333, 5.856362977297516, 6.804557325243831, 7.788305708287551, 8.665608222906698, 9.644334435823534, 10.684270903994772, 11.71517265733829, 12.672732111628855, 13.688466619098502, 13.713094519786264, 12.712499888590912, 11.694643837548446, 10.71560245454991, 9.772709136135482, 8.801510201610725, 7.8074126964091555, 6.788079965819812, 5.8292617292599225, 4.912855784440884, 3.976776758847536, 4.909983085266701, 5.817368900634169, 6.7498782604064544, 7.691178605118823, 8.700395518480441, 9.7638524187463, 10.774724161371731, 11.714236618553898, 12.729680104902448, 12.800501418791823, 11.754745537696726, 10.757432473615232, 9.705030469173643, 8.77587926445402, 7.8238675985784765, 6.8674776512150055, 5.83784407919069, 4.854036108507795, 3.8679078071708655, 2.9105267357894875, 3.8587552951639, 4.831802717715406, 5.807542222645856, 6.7800456508081925, 7.750706656668506, 8.803391642818529, 9.798772795604762, 10.818970463254434, 11.75893632368249, 11.811498250383588, 10.762299523048318, 9.78446044396251, 8.720941006476158, 7.790245872776812, 6.863063310450533, 5.9333854208770145, 4.894546136057803, 3.940690507928842, 2.967220965403094, 1.9378643226348733, 2.9232083353155858, 3.888203510380814, 4.82893737196328, 5.823530638316831, 6.787367497593057, 7.819161374779611, 8.867029230469585, 9.909563757434995, 10.855004005965034, 11.082161802937819, 10.064086772018142, 9.12116024269493, 8.118642521756497, 7.098749761833615, 6.061357833416995, 5.093551103307351, 4.074606140505039, 3.0694064188640158, 1.9999512337819525, 0.9960762303420325, 1.9117854961354745, 2.923159718327791, 3.9077572545662798, 4.884117365875764, 5.8272754121506525, 6.886123213971752, 7.950997453283271, 8.947344794577319, 9.866289594389308, 10.040047417960388, 9.100090558351583, 8.128896543632889, 7.110354914557673, 6.147361550802329, 5.09867576707077, 4.116762447478027, 3.06548130892359, 2.09587498712341, 1.0716638149958848, 0.0, 0.9663968820809343, 1.9880499955323385, 3.0123415420746484, 3.9436500622591026, 4.996352887686787, 6.020014637843652, 6.962840978218509, 7.967510476138729, 8.896576304663261, 10.970676049940748, 10.027397970146062, 9.064065261842432, 8.01206014405391, 7.014112860864193, 6.074376599453395, 5.034904148324652, 4.007102866317105, 3.0488187978810353, 2.0663001038594406, 1.066148099254226, 1.9477048882694339, 2.9458596125542806, 3.8840642473293943, 4.917218728226938, 5.9370019119241135, 6.884421831242982, 7.868707421798257, 8.823953246843878, 9.833499212909175, 11.898765874491085, 10.84246030745189, 9.862445582765643, 8.895594655539675, 7.939936519280121, 6.981087946403915, 5.91598823941683, 4.9804643345813995, 4.050927047534406, 3.0576951828828163, 2.085986386078352, 2.9738297526113557, 3.9534028982532767, 4.848347505695903, 5.803088160705484, 6.730538046759067, 7.664551858173319, 8.630148124245373, 9.675338566707337, 10.716045023771173, 12.83127784764015, 11.775201857776398, 10.77457995612276, 9.780503762399276, 8.837634431727016, 7.8563634231486486, 6.920074299339079, 5.935005861428161, 4.982220802991314, 4.0523829677701055, 3.138841337491292, 3.977500846968566, 4.9848437257752165, 5.841117214960257, 6.840350489432921, 7.72889311701884, 8.63904184021549, 9.5634460257881, 10.627893100247872, 11.658526663386072, 12.61281166171322, 12.720010027648568, 11.811416618991412, 10.819905234674842, 9.852598669789147, 8.924233203459329, 7.950471492058738, 6.991186978299481, 6.036242833994976, 5.053961065880567, 4.126775864207392, 4.94266133473482, 5.935182189491621, 6.775905623969194, 7.768277555479276, 8.718021304648055, 9.659583412810264, 10.623931022245188, 11.553263534059386, 12.554674025813721, 11.7726980550208, 12.840998205886661, 12.867550527903035, 11.876358121916956, 10.87561416335693, 9.968059163126656, 8.952459784471772, 7.922558613774425, 7.1022775298856535, 6.039537162856206, 5.1521097472127435, 5.896880130241569, 6.928272340411426, 7.746579083595574, 8.709125664630518, 9.66375043126587, 10.613126447612515, 11.647490834565094, 12.59200981203821, 12.848064842439172, 10.764483492160464, 11.830519558901084, 12.876265218928488, 12.849294427897204, 11.845605916086102, 10.882263238026413, 9.912129050557983, 8.917329896774168, 8.059540043371038, 7.06293749258195, 6.168802031601004, 6.921366188123432, 7.853490463753979, 8.735064070577932, 9.672513068049623, 10.61944459530263, 11.614799793958651, 12.590906924081759, 12.920553193917424, 11.92270686002798, 9.902807602240735, 10.87437161915586, 11.947358128321387, 13.02081424433199, 12.856336108450966, 11.839588397479249, 10.857397258980162, 9.914497365738033, 9.006699578219242, 8.065927571280998, 7.136696053883033, 7.872799857931226, 8.800804592307141, 9.668304046173787, 10.62249121351626, 11.54452665249078, 12.537545696318826, 13.083207694780185, 12.030250092905437, 11.00577305345722, 10.872170324206014, 11.861984357956192, 12.902621130511884, 13.97606837497526, 13.795990282100682, 12.757757980671892, 11.800379404593214, 10.940340863433319, 10.034216433514779, 8.995887552174135, 8.06597158288474, 8.844468600946193, 9.77130897119728, 10.71897068559196, 11.608003648739963, 12.5657013093466, 13.468767007311143, 13.906344300719125, 12.956896278429321, 12.028466714319002, 11.8247834900167, 12.77087689035546, 13.832890930567858, 14.804131762831888, 14.725450368386023, 13.755604500235577, 12.801479355260726, 11.905429384878266, 11.009926465865808, 10.01999683927332, 9.127831619311719, 9.824843733805256, 10.821584680603223, 11.763898900448043, 12.57447662914331, 13.498749541342216, 14.483054986724788, 14.90582878588061, 13.840767737095629, 12.882284626074151, 12.759653365177346, 13.724085340089562, 14.692041459445283, 15.5431600745714, 14.610208612102666, 13.569643807353257, 12.566394923300663, 11.614628777554465, 10.807753402016102, 10.031757522505453, 10.074375201025166, 10.792359286361888, 11.766704017804187, 12.78370973673275, 13.58707252035407, 14.457604073844552, 15.469101983493502, 15.872699660706187, 14.867334017767801, 13.839855478985807, 13.723442810552424, 14.767229247263419, 15.537646045104296, 14.525993730739039, 13.56785832796139, 12.51899019022163, 11.634418787195608, 10.624878785985713, 9.739524437727773, 8.974502973472756, 9.86048112579058, 10.798735848359087, 11.620560434586853, 12.585244249172693, 13.577362673815292, 14.522741752585068, 15.452135350907396, 16.3817716613887, 15.720340612413015, 14.78566618384715, 14.70071750673003, 15.565987497348278, 14.628834184104036, 13.62201439400387, 12.567337238586147, 11.566945751576107, 10.623992574301322, 9.685097267113624, 8.74805599386469, 8.00506208462969, 8.871649679528021, 9.79323215406895, 10.65989762868173, 11.645634496062051, 12.620033154154516, 13.59991190324255, 14.561091509302875, 15.524577050340579, 16.44716420087928, 15.494052413266601, 15.636758590823096, 14.627183662583093, 13.598092549335322, 12.62462665475725, 11.54981841635587, 10.672270156587471, 9.670197593496644, 8.730147278635528, 7.820477019261444, 7.048250966086852, 7.925331608776469, 8.72352479785225, 9.731194657387586, 10.683301644146647, 11.636921254366849, 12.62592027329185, 13.627386957206323, 14.607694549715365, 15.621883484429572, 16.44573806080345], [16.43975819617205, 15.451794235388222, 14.54008700423114, 13.48054141944644, 12.541024037848606, 11.599063839280944, 10.61798854156359, 9.668965343826503, 8.649735853577901, 7.711021100926189, 6.7822816264022405, 5.824849563643133, 6.830483007061078, 7.7559440334278165, 8.688765401805373, 9.642694177141214, 10.677921797636229, 11.640650281089659, 12.70049633550185, 13.740719077749073, 15.437294869024768, 14.507238425838308, 13.534597846345969, 12.594252036083894, 11.611869824342007, 10.660839237957555, 9.66321216667653, 8.62815694292952, 7.744946577459949, 6.855035033944235, 5.882605557967248, 4.8899660952165815, 5.838160443162897, 6.8219088262066165, 7.699211340825764, 8.6779375537426, 9.717874021913838, 10.748775775257354, 11.70633522954792, 12.722069737017566, 14.60660198243059, 13.606007351235238, 12.588151300192772, 11.609109917194234, 10.666216598779808, 9.695017664255051, 8.700920159053481, 7.681587428464138, 6.7227691919042485, 5.80636324708521, 4.870284221491863, 3.9435862031857667, 4.850972018553235, 5.78348137832552, 6.724781723037889, 7.733998636399507, 8.797455536665366, 9.808327279290795, 10.747839736472962, 11.763283222821512, 13.69400888143615, 12.648253000341052, 11.650939936259558, 10.598537931817967, 9.669386727098344, 8.717375061222803, 7.7609851138593315, 6.731351541835016, 5.7475435711521214, 4.761415269815192, 3.804034198433814, 2.8923584130829654, 3.865405835634472, 4.841145340564922, 5.813648768727258, 6.784309774587572, 7.8369947607375945, 8.832375913523826, 9.852573581173498, 10.792539441601555, 12.705005713027914, 11.655806985692644, 10.677967906606836, 9.614448469120484, 8.683753335421137, 7.756570773094859, 6.8268928835213405, 5.788053598702129, 4.834197970573168, 3.86072842804742, 2.8313717852791997, 1.9568114532346512, 2.9218066282998794, 3.8625404898823454, 4.857133756235896, 5.820970615512122, 6.852764492698675, 7.900632348388649, 8.94316687535406, 9.888607123884098, 12.048558685018753, 11.030483654099076, 10.087557124775865, 9.085039403837431, 8.061669271677475, 7.024277343260855, 6.056470613151211, 5.024080066789901, 3.9629138815083422, 2.8934586964262787, 1.8895836929863588, 0.9453886140545401, 1.9567628362468565, 2.941360372485345, 3.917720483794829, 4.8608785300697175, 5.919726331890818, 6.9846005712023365, 7.980947912496386, 8.899892712308374, 11.006444300041322, 10.066487440432518, 9.095293425713823, 8.076751796638607, 7.113758432883263, 6.065072649151704, 5.083159329558961, 4.031878191004524, 3.062271869204344, 2.038060697076819, 0.9663968820809343, 0.0, 1.0216531134514042, 2.045944659993714, 2.977253180178168, 4.029956005605853, 5.053617755762718, 5.996444096137575, 7.001113594057795, 7.930179422582327, 11.937072932021682, 10.993794852226998, 10.030462143923367, 8.978457026134846, 7.980509742945128, 7.04077348153433, 6.001301030405587, 4.97349974839804, 4.01521567996197, 2.9672549262079393, 1.9575047624061188, 0.9813080061884996, 1.979462730473346, 2.9176673652484597, 3.950821846146004, 4.970605029843179, 5.918024949162048, 6.902310539717323, 7.857556364762945, 8.86710233082824, 12.865162756572019, 11.808857189532825, 10.828842464846577, 9.861991537620609, 8.906333401361055, 7.947484828484849, 6.882385121497764, 5.9468612166623345, 4.981998433928574, 3.958650005231315, 2.977343049230245, 2.0074328705304216, 2.9870060161723426, 3.8819506236149692, 4.83669127862455, 5.764141164678133, 6.698154976092385, 7.663751242164439, 8.708941684626403, 9.749648141690239, 12.619009988833767, 12.741598739857332, 11.740976838203695, 10.74690064448021, 9.80403131380795, 8.822760305229583, 7.8864711814200135, 6.872402066771171, 5.883175625339812, 4.953337790118604, 3.9570941543032, 3.011103964887632, 4.018446843694282, 4.874720332879323, 5.873953607351987, 6.762496234937906, 7.672644958134557, 8.597049143707165, 9.661496218166938, 10.692129781305137, 11.646414779632286, 12.59316237361864, 12.777813501072345, 11.786302116755776, 10.818995551870081, 9.890630085540263, 8.887867697401749, 7.928583183642491, 6.937197656343473, 5.924971470584953, 4.9450286810193, 3.9762644526538855, 4.968785307410687, 5.80950874188826, 6.801880673398342, 7.751624422567121, 8.693186530729331, 9.657534140164252, 10.586866651978452, 11.588277143732787, 10.806301172939865, 11.874601323805726, 12.868329349378458, 12.84275500399789, 11.842011045437864, 10.905455368469665, 9.889855989814782, 8.859954819117434, 7.976100816844649, 6.9105475675605925, 5.924011702581551, 4.930483248160635, 5.961875458330492, 6.78018220151464, 7.742728782549584, 8.697353549184935, 9.646729565531583, 10.681093952484161, 11.625612929957274, 12.55908504786599, 9.79808661007953, 10.86412267682015, 11.909868336847556, 12.843980101269933, 12.783002121429112, 11.819659443369423, 10.849525255900993, 9.854726102117178, 8.889284018962432, 7.87350586463005, 6.940703986969812, 5.954969306042498, 6.887093581673045, 7.768667188496998, 8.706116185968689, 9.653047713221696, 10.648402911877719, 11.624510042000827, 12.55892829683392, 12.889103742108913, 8.9364107201598, 9.907974737074927, 10.980961246240451, 12.054417362251055, 13.059261195406343, 12.776984602822258, 11.794793464323172, 10.766503054282518, 9.817267950267343, 8.876495943329099, 7.834247925267932, 6.906402975850292, 7.834407710226208, 8.701907164092853, 9.656094331435327, 10.578129770409847, 11.571148814237894, 12.569556386243883, 12.996646974986371, 11.972169935538155, 9.905773442125078, 10.895587475875256, 11.936224248430948, 13.009671492894324, 13.976583221756272, 13.695154186014902, 12.737775609936223, 11.792346551977804, 10.84478480556288, 9.806455924222236, 8.76352345426964, 7.878071718865259, 8.804912089116348, 9.752573803511027, 10.641606766659029, 11.599304427265666, 12.502370125230211, 13.501428036121311, 13.923293160510255, 12.994863596399936, 10.858386607935763, 11.804480008274524, 12.866494048486922, 13.837734880750952, 14.544796285523667, 13.574950417373222, 12.594177416071108, 11.64516801431957, 10.833668546302897, 10.83056521132142, 9.820310823625562, 8.858446851724322, 9.85518779852229, 10.797502018367108, 11.608079747062376, 12.532352659261282, 13.516658104643856, 14.516051534292144, 14.734275199739955, 13.775792088718477, 11.79325648309641, 12.757688458008626, 13.725644577364347, 14.576763192490466, 13.643811730021731, 12.603246925272323, 11.59999804121973, 10.64823189547353, 9.841356519935166, 10.710515291399823, 10.766854405339009, 9.825962404280954, 10.800307135723253, 11.817312854651815, 12.620675638273136, 13.491207191763618, 14.502705101412568, 15.494030349052455, 15.760841480412127, 14.733362941630133, 12.757045928471488, 13.800832365182483, 14.571249163023362, 13.559596848658105, 12.601461445880457, 11.552593308140695, 10.668021905114674, 9.658481903904779, 8.773127555646838, 9.653260742367126, 10.618021248319529, 10.79502660839074, 11.775135441718026, 12.739819256303866, 13.561883306974876, 14.507262385744651, 15.436655984066979, 16.366292294548284, 16.61384807505734, 15.679173646491476, 13.734320624649094, 14.599590615267342, 13.6624373020231, 12.655617511922934, 11.600940356505212, 10.600548869495173, 9.657595692220388, 8.71870038503269, 7.781659111783754, 8.68381985352406, 9.62918980205697, 10.612111558285514, 11.525010293932393, 12.510747161312715, 13.513540616798842, 14.493419365886876, 15.4545989719472, 16.418084512984905, 17.340671663523604, 16.387559875910927, 14.67036170874216, 13.660786780502159, 12.631695667254387, 11.658229772676316, 10.583421534274937, 9.705873274506537, 8.70380071141571, 7.763750396554593, 6.85408013718051, 7.727008734981222, 8.682871731305418, 9.582057587267961, 10.59630732263825, 11.576809106790973, 12.530428717011175, 13.519427735936176, 14.520894419850649, 15.501202012359691, 16.515390947073897, 17.339245523447776], [17.450705918293625, 16.4627419575098, 15.551034726352716, 14.491489141568017, 13.551971759970183, 12.535753318242746, 11.554678020525392, 10.588676528853487, 9.569447038604885, 8.630732285953172, 7.701992811429224, 6.744560748670117, 5.86932310527285, 6.744143311164761, 7.676964679542317, 8.630893454878159, 9.666121075373173, 10.628849558826603, 11.688695613238792, 12.72891835548602, 16.448242591146343, 15.518186147959884, 14.545545568467546, 13.60519975820547, 12.622817546463583, 11.671786960079132, 10.674159888798107, 9.639104665051097, 8.755894299581525, 7.802464502263934, 6.802316742994232, 5.809677280243565, 4.877000541374668, 5.810108103943561, 6.6874106185627085, 7.666136831479545, 8.706073299650782, 9.7369750529943, 10.694534507284866, 11.710269014754513, 15.617549704552168, 14.616955073356817, 13.59909902231435, 12.620057639315812, 11.677164320901385, 10.705965386376628, 9.711867881175058, 8.692535150585716, 7.733716914025826, 6.817310969206788, 5.88123194361344, 4.86329738821275, 3.83917129629018, 4.771680656062465, 5.712981000774834, 6.722197914136451, 7.78565481440231, 8.796526557027741, 9.736039014209908, 10.751482500558458, 14.704956603557727, 13.65920072246263, 12.661887658381136, 11.609485653939545, 10.680334449219922, 9.72832278334438, 8.771932835980909, 7.7422992639565935, 6.758491293273699, 5.772362991936769, 4.814981920555391, 3.812069598109949, 2.8536051133714166, 3.829344618301867, 4.801848046464203, 5.772509052324517, 6.825194038474539, 7.820575191260772, 8.840772858910444, 9.780738719338501, 13.715953435149492, 12.666754707814222, 11.688915628728415, 10.625396191242062, 9.694701057542716, 8.767518495216438, 7.837840605642919, 6.799001320823708, 5.8451456926947465, 4.871676150168998, 3.842319507400777, 2.8765226382616347, 1.9100059060368242, 2.8507397676192907, 3.845333033972841, 4.809169893249067, 5.840963770435621, 6.8888316261255955, 7.931366153091005, 8.876806401621044, 13.070211798470156, 12.05213676755048, 11.109210238227268, 10.106692517288835, 9.072616993799052, 8.035225065382432, 7.067418335272787, 6.035027788911478, 4.97386160362992, 3.9044064185478566, 2.9005314151079364, 1.956336336176118, 0.9449621139838013, 1.92955965022229, 2.9059197615317744, 3.8490778078066628, 4.907925609627762, 5.972799848939281, 6.96914719023333, 7.878239598856968, 12.028097413492725, 11.088140553883921, 10.116946539165227, 9.09840491009001, 8.135411546334668, 7.086725762603107, 6.104812443010365, 5.0535313044559285, 4.083924982655748, 3.0597138105282236, 1.9880499955323385, 1.0216531134514042, 0.0, 1.0242915465423097, 1.9556000667267641, 3.0083028921544486, 4.031964642311314, 4.974790982686169, 5.97946048060639, 6.908526309130922, 12.958726045473085, 12.008167921878979, 11.044835213575348, 9.992830095786827, 8.99488281259711, 8.055146551186311, 7.015674100057567, 5.98787281805002, 5.02958874961395, 3.9693650091483565, 2.9596148453465365, 1.983418089128917, 0.9852633648440704, 1.923467999619184, 2.9291687326946, 3.948951916391775, 4.896371835710643, 5.880657426265919, 6.8359032513115405, 7.845449217376836, 12.56465906074744, 12.823230259184808, 11.84321553449856, 10.876364607272592, 9.920706471013037, 8.96185789813683, 7.896758191149745, 6.961234286314315, 5.984108516868991, 4.960760088171733, 3.9794531321706623, 3.0017662909402185, 2.0221931452982975, 2.8877512579856934, 3.842491912995274, 4.769941799048857, 5.703955610463109, 6.669551876535163, 7.714742318997126, 8.755448776060963, 11.624810623204489, 12.543771177861531, 12.755349907855676, 11.76127371413219, 10.818404383459931, 9.837133374881564, 8.900844251071995, 7.874512149711589, 6.885285708280231, 5.955447873059022, 4.951427574712997, 4.005437385297428, 3.0651378373749507, 3.880520967250047, 4.87975424172271, 5.76829686930863, 6.67844559250528, 7.602849778077889, 8.66729685253766, 9.69793041567586, 10.652215414003008, 11.598963007989362, 12.620065571137449, 12.800675186407757, 11.833368621522062, 10.905003155192244, 9.889977780342166, 8.930693266582908, 7.939307739283892, 6.91930489099475, 5.939362101429097, 4.9705978730636815, 4.1112672715741, 4.815309376258984, 5.807681307769066, 6.757425056937845, 7.698987165100054, 8.663334774534977, 9.592667286349174, 10.59407777810351, 9.81210180731059, 10.87866799685365, 11.856700862830332, 12.795263293798774, 12.856384115089845, 11.907565451410083, 10.8919660727552, 9.862064902057853, 8.970434237254446, 7.904880987970389, 6.918345122991347, 5.924816668570431, 5.119265957359883, 5.785982835885363, 6.748529416920308, 7.703154183555659, 8.652530199902307, 9.686894586854885, 10.631413564327996, 11.564885682236712, 8.776433496628124, 9.842469563368745, 10.888215223396148, 11.822326987818526, 12.87796882674915, 12.821769526309842, 11.851635338841412, 10.856836185057597, 9.883617439372228, 8.867839285039846, 7.935037407379608, 6.949302726452295, 6.0444840807024365, 6.774467822867722, 7.711916820339413, 8.65884834759242, 9.654203546248443, 10.63031067637155, 11.564728931204645, 12.490243664647904, 7.914757606708395, 8.886321623623521, 9.959308132789047, 11.032764248799651, 12.03760808195494, 13.05907134082666, 12.796903547263591, 11.760836474692313, 10.811601370677138, 9.870829363738894, 8.828581345677728, 7.900736396260089, 6.9917982092556, 7.707707798463577, 8.66189496580605, 9.58393040478057, 10.576949448608616, 11.575357020614607, 12.568026326846626, 12.993823048989558, 8.884120328673674, 9.873934362423853, 10.914571134979544, 11.98801837944292, 12.954930108304868, 13.600627636217975, 12.643249060139297, 11.658228229165193, 11.839118225972674, 10.800789344632031, 9.757856874679435, 8.872405139275056, 7.962302588145739, 8.75837443788175, 9.647407401029753, 10.60510506163639, 11.508170759600933, 12.507228670492035, 13.456676692781839, 14.01651670985134, 9.84658588567271, 10.79267928601147, 11.854693326223869, 12.825934158487899, 13.592767978924343, 12.622922110773898, 11.642149109471784, 10.693139707720245, 11.724839658724564, 11.824898631731216, 10.814644244035359, 9.852780272134119, 9.01257829755168, 9.803302652737832, 10.6138803814331, 11.538153293632005, 12.522458739014578, 13.521852168662868, 14.419108825404765, 14.786739810840055, 10.781455760833357, 11.745887735745573, 12.713843855101294, 13.56496247022741, 12.632011007758676, 11.636242586299748, 10.647969734620407, 9.696203588874209, 10.732527632356833, 11.630226476426806, 11.761187825748806, 10.820295824690751, 10.023203041746495, 10.82311348902254, 11.62647627264386, 12.497007826134341, 13.508505735783292, 14.499830983423179, 15.4824720507169, 15.744310663751712, 11.745245206208434, 12.78903164291943, 13.559448440760306, 12.547796126395049, 11.589660723617401, 10.58367272365484, 9.715993598515352, 8.706453597305456, 9.692838740673823, 10.572971927394109, 11.537732433346513, 11.789360028800537, 11.084647462562625, 11.777733694058057, 12.5676839413456, 13.513063020115375, 14.442456618437703, 15.372092928919008, 16.361138163246014, 16.690121368613056, 12.72251990238604, 13.587789893004288, 12.650636579760047, 11.64381678965988, 10.589139634242157, 9.631628285009317, 8.705567385621066, 7.766672078433368, 8.701370296810738, 9.603531038551044, 10.548900987083954, 11.531822743312498, 12.045310268467748, 12.803748984207097, 13.578541302535365, 14.44624460126085, 15.383121535538375, 16.34660707657608, 17.295632171866046, 17.398507598032502, 13.658560986479106, 12.648986058239103, 11.619894944991332, 10.64642905041326, 9.571620812011881, 8.694072552243481, 7.691999989152653, 6.802590494766364, 7.773791322207494, 8.646719920008206, 9.602582916332402, 10.501768772294945, 11.516018507665233, 12.513498585752775, 13.467118195972976, 14.456117214897978, 15.471159951481832, 16.451467543990873, 17.46565647870508, 18.35019324556935], [18.474997464835933, 17.487033504052107, 16.575326272895026, 15.515780688110327, 14.576263306512493, 13.560044864785054, 12.5789695670677, 11.612968075395795, 10.593738585147193, 9.65502383249548, 8.726284357971533, 7.768852295212426, 6.893614651815159, 5.956831263385711, 6.889652631763267, 7.8435814070991094, 8.863320069508147, 9.805996761227425, 10.80711421733798, 11.811439115848703, 17.47253413768865, 16.542477694502193, 15.569837115009856, 14.62949130474778, 13.647109093005893, 12.696078506621442, 11.698451435340417, 10.663396211593406, 9.780185846123835, 8.826756048806242, 7.826608289536541, 6.833968826785874, 5.9012920879169775, 5.022796056164511, 5.900098570783659, 6.878824783700496, 7.903272293785756, 8.825544337521515, 9.779494511092318, 10.792789775117196, 16.641841251094476, 15.641246619899125, 14.623390568856658, 13.64434918585812, 12.701455867443695, 11.730256932918937, 10.736159427717368, 9.716826697128026, 8.758008460568135, 7.841602515749098, 6.90552349015575, 5.887588934755059, 4.863462842832489, 3.984368608283415, 4.9256689529957844, 5.893805823956672, 6.93222274702193, 7.881486560835193, 8.82099901801736, 9.833521989710116, 15.729248150100036, 14.683492269004939, 13.686179204923445, 12.633777200481854, 11.70462599576223, 10.75261432988669, 9.796224382523219, 8.766590810498903, 7.782782839816009, 6.796654538479079, 5.839273467097701, 4.836361144652258, 3.877896659913726, 3.0420325705228173, 3.979667234771294, 4.944116962144737, 5.92140813890973, 6.905535195068223, 7.925732862717895, 8.862778208490159, 14.7402449816918, 13.69104625435653, 12.713207175270723, 11.64968773778437, 10.718992604085024, 9.791810041758746, 8.862132152185227, 7.823292867366017, 6.8694372392370555, 5.895967696711307, 4.866611053943087, 3.900814184803944, 2.9342974525791337, 2.0574584888039915, 2.9302930377802925, 3.8941298970565184, 4.925923774243072, 5.9737916299330465, 6.974245931321572, 7.911504788947589, 14.094503345012466, 13.076428314092789, 12.133501784769578, 11.130984063831145, 10.096908540341362, 9.059516611924742, 8.091709881815097, 7.059319335453788, 5.998153150172229, 4.928697965090166, 3.924822961650246, 2.9806278827184274, 1.9692536605261108, 1.0562449364177597, 1.9098888790672526, 2.853046925342141, 3.911894727163241, 4.97676896647476, 5.973116307768809, 6.853948052314659, 13.052388960035035, 12.112432100426231, 11.141238085707537, 10.12269645663232, 9.159703092876978, 8.111017309145417, 7.129103989552675, 6.077822850998238, 5.108216529198058, 4.0840053570705335, 3.0123415420746484, 2.045944659993714, 1.0242915465423097, 0.0, 0.9313085201844543, 1.984011345612139, 3.0076730957690043, 3.9504994361438603, 4.955168934064081, 5.884234762588613, 12.499151732316623, 12.987348720963134, 12.024016012659503, 10.972010894870982, 9.974063611681265, 9.034327350270466, 7.994854899141722, 6.967053617134175, 6.008769548698105, 4.948545808232511, 3.938795644430691, 2.9625988882130714, 1.9644441639282246, 1.026239529153111, 1.90487718615229, 2.924660369849465, 3.8720802891683332, 4.856365879723609, 5.811611704769231, 6.821157670834526, 11.621536318328927, 12.659227750814365, 12.822396333582715, 11.855545406356747, 10.899887270097192, 9.941038697220986, 8.8759389902339, 7.940415085398469, 6.963289315953146, 5.939940887255887, 4.935557714921528, 3.8965967116839764, 2.9170235660420554, 1.9905227875196205, 2.8993691705767595, 3.8268190566303426, 4.760832868044595, 5.726429134116649, 6.771619576578612, 7.7891983986332365, 10.681687880785976, 11.600648435443018, 12.601270337096656, 12.722562728698577, 11.779693398026318, 10.79842238944795, 9.86213326563838, 8.831031816832295, 7.841805375400937, 6.911967540179728, 5.846257995456756, 4.900267806041187, 3.9599682581187086, 2.9832924967839745, 3.9366314993041955, 4.825174126890117, 5.7353228500867655, 6.659727035659375, 7.724174110119147, 8.754807673257346, 9.709092671584495, 10.655840265570848, 11.676942828718936, 12.707019955179856, 12.794657636088449, 11.86629216975863, 10.837142432226205, 9.877857918466947, 8.858859440645311, 7.814135311738509, 6.834192522172856, 5.86542829380744, 4.98181701825077, 3.9180809057929116, 4.9104528373029925, 5.860196586471772, 6.755864422681539, 7.7202120321164625, 8.649544543930661, 9.650955035684996, 8.81845700071938, 9.85437645031134, 10.832409316288024, 11.770971747256466, 12.797713842347957, 12.854730103294122, 11.839130724639238, 10.80922955394189, 9.865264657998203, 8.799711408714147, 7.813175543735106, 6.81964708931419, 5.896747123626962, 4.888754365419291, 5.851300946454235, 6.805925713089587, 7.709407457483792, 8.74377184443637, 9.688290821909483, 10.621762939818199, 7.752141950085814, 8.818178016826435, 9.86392367685384, 10.798035441276218, 11.853677280206842, 12.817019958266531, 12.784417252540136, 11.789618098756321, 10.774204248992195, 9.758426094659812, 8.825624216999573, 7.785924514768459, 6.821965246969516, 5.8772393524016495, 6.81468834987334, 7.761619877126346, 8.711080803829928, 9.687187933953036, 10.62160618878613, 11.547120922229391, 6.890466060166086, 7.862030077081212, 8.935016586246737, 10.00847270225734, 11.013316535412628, 12.034779794284349, 12.875456912657858, 12.605612086237835, 11.65637698222266, 10.715604975284416, 9.665203133993892, 8.737358184576252, 7.769279375522679, 6.810479327997504, 7.764666495339977, 8.686701934314497, 9.657839176822014, 10.632234278196092, 11.624903584428111, 12.50160497137758, 7.859828782131364, 8.849642815881543, 9.890279588437235, 10.963726832900608, 11.930638561762557, 12.889853343123486, 11.932474767044807, 12.682519775707501, 12.683893837518196, 11.645564956177553, 10.594478662995598, 9.69872922720605, 8.739783754412818, 7.861145967415676, 8.75017893056368, 9.707876591170317, 10.589060487814331, 11.56410592807352, 12.513553950363324, 13.446350655186503, 8.84009517600848, 9.786188576347241, 10.84820261655964, 11.81944344882367, 12.84693704647526, 11.90262151982857, 10.931374816377295, 11.717431254262554, 12.749131205266872, 12.669674243276738, 11.640968331966352, 10.679104360065113, 9.79005946381876, 8.906074182271759, 9.716651910967027, 10.640924823165932, 11.603348467227976, 12.578729426244353, 13.47598608298625, 14.434469194007727, 9.780895718311385, 10.7453276932236, 11.713283812579322, 12.668626730190077, 11.844698959979626, 10.8489305385207, 9.916889990389585, 10.720495135416517, 11.756819178899141, 12.654518022969114, 12.5875119136798, 11.646619912621745, 10.800684208013575, 9.925885018556466, 10.729247802177786, 11.599779355668268, 12.611277265317218, 13.576092987823799, 14.539349308298384, 15.472862538902959, 10.827284695360092, 11.79654688085704, 12.643085285984085, 11.760484078615999, 10.802348675838351, 9.79636067587579, 8.98491385428453, 9.730745143847765, 10.717130287216131, 11.597263473936417, 12.56202397988882, 12.615684116731531, 11.845189038177823, 10.880505223591983, 11.670455470879526, 12.615834549649302, 13.54522814797163, 14.474864458452934, 15.463909692779941, 16.398584121345806, 11.804559391537698, 12.750684793270786, 11.84000791328128, 10.85650474188083, 9.801827586463107, 8.844316237230268, 7.9639176237203175, 8.790963624975676, 9.725661843353047, 10.627822585093352, 11.573192533626262, 12.556114289854806, 12.805851844082946, 11.906520513741023, 12.681312832069292, 13.549016130794776, 14.485893065072302, 15.449378606110006, 16.39840370139997, 17.351515489012648, 12.740600475630764, 11.803294285333452, 10.797042147392153, 9.85911700263421, 8.784308764232831, 7.906760504464432, 6.904687941373603, 7.826882041308673, 8.798082868749802, 9.671011466550514, 10.62687446287471, 11.526060318837253, 12.540310054207541, 12.905392592645523, 13.66442473185696, 14.523007760745475, 15.522211386680981, 16.485744734910003, 17.370241736147587, 18.303201136549497], [18.465948208568534, 17.598424534900587, 16.670200201298275, 15.724268772607632, 14.787739914070592, 13.846595309761721, 13.510278087252155, 12.54427659558025, 11.525047105331648, 10.586332352679936, 9.657592878155988, 8.700160815396881, 7.824923171999613, 6.855526797160234, 6.066085364180195, 6.957680697739593, 7.932011549323693, 8.874688241042971, 9.875805697153526, 10.88013059566425, 17.46348488142125, 17.473786214686648, 16.50114563519431, 15.560799824932236, 14.578417613190348, 13.627387026805897, 12.629759955524872, 11.594704731777862, 10.71149436630829, 9.758064568990697, 8.757916809720996, 7.765277346970328, 6.832600608101432, 5.921491589939034, 5.057829204148868, 5.99292407434098, 6.971963773601302, 7.894235817337061, 8.848185990907863, 9.861481254932743, 16.581067487760283, 16.572555140083583, 15.554699089041117, 14.575657706042579, 13.63276438762815, 12.661565453103393, 11.667467947901823, 10.64813521731248, 9.68931698075259, 8.772911035933552, 7.8368320103402045, 6.818897454939513, 5.7947713630169435, 4.883064142057938, 4.0833995863609935, 4.962497303772218, 6.000914226837476, 6.950178040650739, 7.889690497832905, 8.902213469525663, 15.568748379119722, 15.614800789189397, 14.617487725107903, 13.565085720666312, 12.635934515946689, 11.683922850071145, 10.727532902707674, 9.697899330683358, 8.714091360000463, 7.7279630586635335, 6.7705819872821555, 5.7676696648367125, 4.80920518009818, 3.94072810429734, 3.04835871458684, 4.012808441960283, 4.990099618725276, 5.974226674883769, 6.994424342533442, 7.931469688305706, 14.52345677803156, 14.62235477454099, 13.644515695455182, 12.58099625796883, 11.650301124269483, 10.723118561943203, 9.793440672369684, 8.754601387550473, 7.800745759421511, 6.827276216895762, 5.797919574127541, 4.832122704988398, 3.8656059727635883, 2.9561540225785143, 1.9989845175958383, 2.962821376872064, 3.9946152540586177, 5.042483109748592, 6.0429374111371175, 6.980196268763135, 13.461347046383233, 14.007736834277244, 13.064810304954033, 12.0622925840156, 11.028217060525817, 9.990825132109197, 9.023018401999552, 7.990627855638243, 6.929461670356684, 5.860006485274621, 4.856131481834701, 3.911936402902882, 2.9005621807105655, 1.9549404701922826, 0.9785803588827983, 1.921738405157687, 2.9805862069787867, 4.045460446290305, 5.0418077875843545, 5.922639532130205, 12.49847184411253, 13.043740620610686, 12.072546605891992, 11.054004976816776, 10.091011613061433, 9.042325829329872, 8.06041250973713, 7.009131371182693, 6.039525049382513, 5.015313877254988, 3.9436500622591026, 2.9772531801781685, 1.9556000667267641, 0.9313085201844543, 0.0, 1.0527028254276847, 2.0763645755845497, 3.0191909159594057, 4.023860413879627, 4.952926242404159, 11.56784321213217, 12.640965078446223, 12.955324532843957, 11.903319415055435, 10.905372131865718, 9.96563587045492, 8.926163419326176, 7.898362137318629, 6.940078068882559, 5.8798543284169655, 4.870104164615145, 3.8939074083975256, 2.895752684112679, 1.9575480493375652, 0.9735686659678358, 1.993351849665011, 2.940771768983879, 3.9250573595391547, 4.880303184584776, 5.889849150650072, 10.690227798144473, 11.72791923062991, 12.617424308703086, 12.7868539265412, 11.831195790281646, 10.872347217405439, 9.807247510418353, 8.871723605582924, 7.8945978361376, 6.871249407440342, 5.866866235105983, 4.827905231868431, 3.8483320862265096, 2.9218313077040747, 1.9680606503923053, 2.8955105364458884, 3.829524347860141, 4.795120613932195, 5.840311056394158, 6.857889878448782, 9.750379360601524, 10.669339915258563, 11.6699618169122, 12.664038010635686, 12.711001918210771, 11.729730909632403, 10.793441785822834, 9.762340337016749, 8.773113895585391, 7.843276060364182, 6.777566515641209, 5.83157632622564, 4.891276778303163, 3.9146010169684287, 3.0053229791197413, 3.893865606705662, 4.804014329902312, 5.728418515474921, 6.792865589934693, 7.823499153072891, 8.77778415140004, 9.724531745386393, 10.74563430853448, 11.7757114349954, 12.80175127296221, 12.797600689943083, 11.768450952410658, 10.8091664386514, 9.790167960829764, 8.745443831922962, 7.765501042357309, 6.7967368139918936, 5.913125538435224, 4.849389425977366, 4.042014148158419, 4.963467838691513, 5.824555902497086, 6.788903511932008, 7.718236023746207, 8.719646515500543, 7.887148480534927, 8.923067930126887, 9.901100796103568, 10.83966322707201, 11.866405322163502, 12.8359393307652, 12.770439244823692, 11.740538074126345, 10.796573178182657, 9.7310199288986, 8.74448406391956, 7.750955609498643, 6.828055643811417, 5.820062885603745, 5.0827907359169515, 5.984524540830856, 6.7780989372993385, 7.812463324251917, 8.75698230172503, 9.690454419633745, 6.82083342990136, 7.886869496641981, 8.932615156669385, 9.866726921091763, 10.922368760022387, 11.885711438082076, 12.855845625550506, 12.720926618940776, 11.70551276917665, 10.689734614844268, 9.756932737184028, 8.717233034952914, 7.75327376715397, 6.808547872586104, 6.046178139336057, 6.940218704867616, 7.779772283645475, 8.755879413768582, 9.690297668601676, 10.615812402044938, 5.959157539981632, 6.930721556896758, 8.003708066062284, 9.077164182072888, 10.082008015228176, 11.103471274099897, 12.172433587173128, 13.240754555322795, 12.587685502407115, 11.646913495468871, 10.596511654178347, 9.668666704760707, 8.700587895707132, 7.741787848181959, 7.001758412364758, 7.8653007620557664, 8.72653065663756, 9.700925758011639, 10.693595064243658, 11.570296451193126, 6.92852026194691, 7.918334295697089, 8.95897106825278, 10.032418312716153, 10.999330041578101, 12.037562343006892, 12.831170300819332, 13.613828295891956, 13.615202357702652, 12.576873476362008, 11.525787183180054, 10.630037747390503, 9.671092274597271, 8.792454487600132, 7.98727084758846, 8.918744301495135, 9.657751967629878, 10.632797407889067, 11.58224543017887, 12.51504213500205, 7.908786655824027, 8.854880056162788, 9.916894096375186, 10.888134928639216, 11.915628526290806, 11.079054252245497, 11.83007035015182, 12.648739774447009, 13.680439725451327, 13.600982763461193, 12.572276852150805, 11.610412880249566, 10.721367984003212, 9.837382702456214, 8.953743827991808, 9.85179253349075, 10.672039947043523, 11.6474209060599, 12.544677562801796, 13.503160673823274, 8.849587198126931, 9.814019173039148, 10.781975292394868, 11.737318210005624, 10.95879825062011, 10.025363270937627, 10.81558552416411, 11.651803655600972, 12.688127699083596, 13.58582654315357, 13.518820433864253, 12.577928432806198, 11.731992728198026, 10.85719353874092, 9.966339719202567, 10.810647065993086, 11.707645839252653, 12.644784467639347, 13.608040788113932, 14.541554018718507, 9.89597617517564, 10.865238360672585, 11.711776765799632, 10.874583369256483, 9.916447966478835, 8.972793408292718, 9.883609388059055, 10.66205366403222, 11.648438807400586, 12.528571994120872, 13.493332500073276, 13.546992636915984, 12.776497558362278, 11.811813743776439, 10.907547387904307, 11.852926466674083, 12.706932533494072, 13.636568843975377, 14.625614078302384, 15.555113179654489, 10.873250871353246, 11.81937627308633, 10.908699393096827, 9.970604032521312, 8.91592687710359, 8.020748969647196, 8.862613157494842, 9.722272145160131, 10.656970363537502, 11.559131105277807, 12.504501053810717, 13.487422810039261, 13.737160364267401, 12.837829033925479, 11.918404749094073, 12.786108047819557, 13.647597450594745, 14.611082991632449, 15.560108086922416, 16.513219874535093, 11.809291955446312, 10.871985765148997, 9.8657336272077, 8.939039812750213, 7.898408054873315, 7.0831932368813595, 7.803383475148126, 8.758190561493128, 9.729391388934257, 10.602319986734969, 11.558182983059165, 12.457368839021708, 13.471618574391997, 13.836701112829978, 12.90151664888174, 13.760099677770256, 14.683915772203424, 15.647449120432448, 16.531946121670032, 17.46490552207194], [17.61832393857176, 16.750800264903813, 15.822575931301499, 14.876644502610855, 13.948276943255298, 14.815140636860072, 14.562980912679839, 13.596979421007934, 12.577749930759332, 11.63903517810762, 10.710295703583672, 9.752863640824565, 8.877625997427296, 7.89061665819713, 7.101175225217092, 6.115195969873096, 7.077038670279059, 7.887682682815842, 8.888800138926396, 9.827427770236564, 16.615860611424477, 17.36996030552959, 16.784660356421398, 15.844314546159325, 14.877431156761897, 14.680089852233582, 13.682462780952557, 12.647407557205547, 11.764197191735976, 10.81076739441838, 9.81061963514868, 8.817980172398013, 7.885303433529116, 6.95658145097593, 6.092919065185765, 5.150439346474483, 6.116990894556668, 6.907230259109932, 7.861180432680733, 8.808778429505058, 15.733443217763506, 16.43692871205832, 16.6074019144688, 15.628360531470262, 14.685467213055835, 13.714268278531078, 12.720170773329508, 11.700838042740166, 10.742019806180275, 9.825613861361237, 8.88953483576789, 7.871600280367199, 6.847474188444628, 5.918154003094834, 5.118489447397891, 4.1200125759057205, 5.145941347792842, 5.96317248242361, 6.902684939605776, 7.849510644097977, 14.721124109122945, 15.479174361164134, 15.670190550535587, 14.617788546093996, 13.688637341374372, 12.73662567549883, 11.78023572813536, 10.750602156111043, 9.766794185428148, 8.780665884091219, 7.823284812709841, 6.820372490264398, 5.861908005525865, 4.975817965334237, 4.083448575623737, 3.1703237140937857, 4.135126739680643, 4.98722111665664, 6.007418784306312, 6.87876686287802, 13.675832508034784, 14.486728346515726, 14.697218520882865, 13.633699083396513, 12.703003949697166, 11.775821387370886, 10.846143497797367, 9.807304212978156, 8.853448584849195, 7.8799790423234475, 6.850622399555227, 5.884825530416084, 4.918308798191273, 3.991243883615411, 3.0340743786327353, 2.1203366490055666, 3.1396423750139846, 4.055477551521463, 5.013574836438677, 5.927493443335449, 12.613722776386457, 13.479550070197938, 14.117513130381717, 13.114995409443283, 12.080919885953502, 11.043527957536883, 10.075721227427238, 9.043330681065928, 7.982164495784369, 6.912709310702306, 5.908834307262386, 4.964639228330567, 3.95326500613825, 2.990030331229179, 2.013670219919695, 1.0705121736448069, 2.0982399221697103, 3.0194631126752305, 4.012445212885914, 4.86993670670252, 11.575596996922576, 12.51555385653138, 13.125249431319675, 12.10670780224446, 11.143714438489116, 10.095028654757556, 9.113115335164814, 8.061834196610377, 7.092227874810197, 6.068016702682672, 4.996352887686787, 4.029956005605853, 3.0083028921544486, 1.984011345612139, 1.0527028254276847, 0.0, 1.0236617501568652, 1.9664880905317212, 2.9711575884519417, 3.900223416976474, 10.644968364942216, 11.709433628358314, 12.612914955555766, 12.95602224048312, 11.958074957293404, 11.018338695882605, 9.978866244753862, 8.951064962746313, 7.992780894310243, 6.93255715384465, 5.9228069900428295, 4.9466102338252105, 3.9484555095403637, 3.01025087476525, 2.02627149139552, 1.070082375921046, 1.990375033460334, 2.9746606240156095, 3.9207734980991766, 4.888876335761489, 9.76735295095452, 10.755347080604134, 11.64485215867731, 12.611703085903278, 12.879519867927492, 11.897266259835767, 10.832166552848681, 9.896642648013252, 8.916373980445567, 7.893025551748308, 6.875111734914183, 5.836150731676631, 4.85657758603471, 3.9300768075122754, 2.975336152502695, 2.0478862664491118, 2.981900077863364, 3.947496343935418, 4.983378328952951, 5.856917063560199, 8.815135269730932, 9.696767765232787, 10.697389666886425, 11.69146586060991, 12.634335191282169, 12.737976409440604, 11.801687285631035, 10.77058583682495, 9.781359395393592, 8.851521560172383, 7.78581201544941, 6.839821826033841, 5.899522278111363, 4.922846516776629, 3.9738683062180926, 3.0462413367088854, 3.956390059905535, 4.880794245478144, 5.935932862493487, 6.850927003047115, 7.805212001374263, 8.751959595360617, 9.773062158508704, 10.803139284969625, 11.829179122936434, 12.757544589266253, 12.776696452218859, 11.817411938459601, 10.798413460637965, 9.753689331731163, 8.77374654216551, 7.804982313800094, 6.921371038243425, 5.857634925785566, 5.01055947525677, 4.1158435686947366, 4.976931632500309, 5.941279241935232, 6.8613032963050005, 7.796771668310589, 6.886175665646344, 7.922095115238304, 8.900127981214986, 9.838690412183428, 10.86543250727492, 11.834966515876618, 12.8505658945315, 12.748783573934546, 11.804818677990857, 10.739265428706801, 9.75272956372776, 8.759201109306844, 7.836301143619617, 6.828308385411946, 6.051336063015302, 5.136900270834079, 5.930474667302561, 6.96483905425514, 7.900049574283823, 8.767579572443791, 5.819860615012777, 6.8858966817533975, 7.931642341780802, 8.86575410620318, 9.921395945133805, 10.884738623193494, 11.854872810661924, 12.849671964445738, 12.713758268984849, 11.697980114652466, 10.765178236992227, 9.725478534761113, 8.76151926696217, 7.816793372394304, 7.014723466434408, 6.092594434870839, 6.932148013648698, 7.908255143771806, 8.8426733986049, 9.692937554854984, 4.906454714553947, 5.878018731469073, 6.951005240634598, 8.024461356645201, 9.029305189800489, 10.05076844867221, 11.11973076174544, 12.188051729895108, 13.137286833910283, 12.65515899527707, 11.604757153986546, 10.676912204568906, 9.708833395515333, 8.75003334799016, 7.970303739463109, 7.01767649205899, 7.878906386640784, 8.853301488014862, 9.845970794246881, 10.647421604003172, 5.875817436519225, 6.8656314702694035, 7.906268242825095, 8.97971548728847, 9.946627216150418, 10.984859517579208, 11.942238093657886, 12.972448091918894, 13.937201103731512, 13.585118976170207, 12.534032682988252, 11.638283247198704, 10.679337774405472, 9.800699987408333, 8.955816174686811, 8.07112003149836, 8.810127697633101, 9.78517313789229, 10.734621160182094, 11.667417865005273, 6.856083830396342, 7.8021772307351025, 8.8641912709475, 9.83543210321153, 10.862925700863121, 11.832771569013566, 12.81354457031568, 13.701442599874692, 14.73314255087901, 14.609228263269392, 13.580522351959006, 12.618658380057767, 11.729613483811413, 10.845628202264415, 9.922289155090159, 9.004168263493975, 9.824415677046746, 10.799796636063123, 11.69705329280502, 12.655536403826497, 7.796884372699246, 8.761316347611462, 9.729272466967183, 10.684615384577938, 10.116313522753613, 11.031828212040127, 11.850675385201006, 12.704506481028655, 13.74083052451128, 14.638529368581253, 14.527065933672453, 13.586173932614399, 12.740238228006227, 11.865439038549122, 10.934885046300918, 9.963022795996311, 10.860021569255876, 11.797160197642569, 12.760416518117154, 13.693929748721729, 8.843273349747953, 9.812535535244901, 10.659073940371947, 10.032098641389986, 9.073963238612338, 9.979258349395218, 10.918699249095951, 11.714756489459903, 12.70114163282827, 13.581274819548556, 14.54603532550096, 14.555238136724185, 13.784743058170479, 12.82005924358464, 11.876092715002658, 11.013463495858787, 11.859308263497295, 12.7889445739786, 13.777989808305607, 14.70748890965771, 9.820548045925559, 10.823314624110463, 9.921693834869698, 9.128119304654817, 8.073442149237094, 9.027213910749696, 9.897703018531738, 10.774974970587815, 11.709673188965185, 12.61183393070549, 13.5572038792384, 14.540125635466945, 14.745405864075602, 13.84607453373368, 12.886950076192424, 11.946645077004261, 12.799973180597968, 13.763458721635672, 14.712483816925639, 15.665595604538318, 10.756589130018625, 9.884980206921867, 8.878728068980571, 8.084066933705579, 7.055923327006818, 8.08965817798386, 8.838473336185023, 9.810893386920812, 10.78209421436194, 11.655022812162652, 12.610885808486849, 13.510071664449391, 14.52432139981968, 14.823681586200292, 13.870061975980091, 12.92063670695496, 13.836291502206647, 14.799824850435671, 15.684321851673255, 16.617281252075166], [16.628050417814222, 15.760526744146278, 14.832302410543964, 13.88637098185332, 14.7332417884586, 15.639679231963244, 15.586642662836704, 14.620641171164799, 13.601411680916197, 12.662696928264484, 11.733957453740537, 10.77652539098143, 9.901287747584163, 8.914278408353995, 8.089704528421986, 7.098022235969654, 6.053376920122194, 6.864020932658977, 7.86513838876953, 8.8037660200797, 15.625587090666942, 16.346298555372723, 15.794386835663866, 14.854041025401791, 15.662396001965199, 15.703751602390446, 14.70612453110942, 13.67106930736241, 12.78785894189284, 11.834429144575246, 10.834281385305545, 9.841641922554878, 8.908965183685982, 7.9802432011327955, 7.111991825487877, 6.133265612571041, 5.093329144399803, 5.883568508953067, 6.837518682523868, 7.785116679348192, 14.715847831621497, 15.413266961901453, 16.35588982874423, 15.874495772370468, 15.709128963212699, 14.737930028687941, 13.743832523486372, 12.72449979289703, 11.765681556337139, 10.8492756115181, 9.913196585924753, 8.895262030524064, 7.871135938601493, 6.941815753251699, 6.142151197554756, 5.113838837485734, 4.122279597635977, 4.939510732266744, 5.879023189448911, 6.825848893941112, 13.703528722980936, 14.455512611007267, 15.418678464811014, 15.641450296250861, 14.712299091531237, 13.760287425655694, 12.803897478292223, 11.774263906267906, 10.790455935585012, 9.804327634248082, 8.846946562866705, 7.844034240421263, 6.88556975568273, 5.999479715491102, 5.107110325780602, 4.1641499756738, 3.1114649895237774, 3.963559366499775, 4.9837570341494475, 5.855105112721155, 12.658237121892775, 13.463066596358859, 14.440905675444666, 14.657360833553378, 13.726665699854031, 12.799483137527753, 11.869805247954234, 10.830965963135023, 9.877110335006062, 8.903640792480314, 7.874284149712092, 6.908487280572949, 5.941970548348138, 5.014905633772276, 4.0577361287896005, 3.143998399162432, 2.1159806248571194, 3.031815801364598, 3.9899130862818115, 4.903831693178584, 11.596127390244447, 12.45588832004107, 13.480404855609425, 14.138657159600148, 13.104581636110368, 12.067189707693748, 11.099382977584103, 10.066992431222793, 9.005826245941234, 7.936371060859171, 6.932496057419251, 5.988300978487432, 4.976926756295115, 4.013692081386044, 3.0373319700765604, 2.094173923801672, 1.0745781720128451, 1.9958013625183653, 2.9887834627290486, 3.846274956545655, 10.551935246765709, 11.491892106374513, 12.463086121093207, 13.130369552401325, 12.167376188645981, 11.118690404914421, 10.136777085321679, 9.085495946767242, 8.115889624967062, 7.091678452839537, 6.020014637843652, 5.053617755762718, 4.031964642311314, 3.007673095769004, 2.0763645755845497, 1.0236617501568652, 0.0, 0.942826340374856, 1.9474958382950764, 2.8765616668196086, 9.621306614785349, 10.685771878201447, 11.589253205398899, 12.577470184659044, 12.945084352473408, 12.00534809106261, 10.965875639933866, 9.938074357926318, 8.979790289490248, 7.919566549024656, 6.909816385222835, 5.933619629005216, 4.935464904720369, 3.9972602699452553, 2.9339163863195123, 1.9141332026223368, 0.9667132833034688, 1.9509988738587443, 2.8971117479423114, 3.865214585604623, 8.743691200797652, 9.731685330447267, 10.621190408520443, 11.58804133574641, 12.543699472005965, 12.741317086537059, 11.676217379549973, 10.740693474714543, 9.760424807146858, 8.737076378449599, 7.719162561615474, 6.680201558377922, 5.700628412736001, 4.774127634213566, 3.8193869792039856, 2.8919370931504025, 1.9916265571058311, 2.957222823177885, 3.959716578796086, 4.833255313403333, 7.791473519574067, 8.67310601507592, 9.673727916729558, 10.667804110453043, 11.610673441125302, 12.59194444970367, 12.645738112332324, 11.61463666352624, 10.625410222094882, 9.695572386873673, 8.6298628421507, 7.683872652735133, 6.743573104812654, 5.76689734347792, 4.817919132919384, 3.890292163410176, 2.966116539148002, 3.890520724720612, 4.912271112336621, 5.827265252890249, 6.781550251217397, 7.72829784520375, 8.749400408351837, 9.779477534812758, 10.805517372779567, 11.733882839109386, 12.808709136853231, 12.661462765160893, 11.642464287339257, 10.597740158432455, 9.617797368866801, 8.649033140501386, 7.765421864944716, 6.701685752486857, 5.854610301958061, 4.959894395396027, 3.986658111742776, 4.951005721177699, 5.837641546148135, 6.773109918153723, 5.862513915489479, 6.898433365081439, 7.876466231058121, 8.815028662026563, 9.841770757118054, 10.811304765719752, 11.826904144374636, 12.820781497288618, 12.648869504692149, 11.583316255408093, 10.596780390429052, 9.603251936008135, 8.680351970320908, 7.6723592121132365, 6.895386889716594, 5.941710840829932, 4.940201146545029, 5.974565533497607, 6.876387824126958, 7.7439178222869245, 4.796198864855912, 5.862234931596532, 6.907980591623937, 7.842092356046315, 8.89773419497694, 9.861076873036628, 10.831211060505058, 11.826010214288873, 12.841424064053, 12.542030941353758, 11.609229063693519, 10.569529361462404, 9.605570093663461, 8.660844199095596, 7.858774293135699, 6.897405004866692, 5.941874492891165, 6.917981623014272, 7.852399877847367, 8.669275804698117, 3.882792964397082, 4.8543569813122085, 5.927343490477734, 7.000799606488337, 8.005643439643624, 9.027106698515345, 10.096069011588575, 11.164389979738242, 12.113625083753417, 13.054397090691662, 12.448807980687837, 11.520963031270197, 10.552884222216624, 9.594084174691451, 8.8143545661644, 7.822487062054843, 6.888632865883251, 7.863027967257329, 8.85569727348935, 9.623759853846305, 4.8521556863623605, 5.841969720112539, 6.882606492668231, 7.956053737131605, 8.922965465993553, 9.961197767422343, 10.918576343501021, 11.948786341762029, 12.913539353574647, 13.954300565336725, 13.378083509689544, 12.482334073899995, 11.523388601106763, 10.644750814109624, 9.799867001388103, 8.85947205992329, 7.819854176875567, 8.794899617134757, 9.74434763942456, 10.67714434424774, 5.8324220802394775, 6.778515480578238, 7.8405295207906365, 8.811770353054666, 9.839263950706256, 10.809109818856701, 11.789882820158814, 12.738892221910353, 13.806854121422663, 14.816120154081815, 14.424573178660298, 13.462709206759058, 12.573664310512704, 11.689679028965706, 10.76633998179145, 9.792520291918905, 8.83414215628921, 9.80952311530559, 10.706779772047486, 11.665262883068964, 6.773222622542382, 7.737654597454598, 8.705610716810318, 9.660953634421073, 10.654942252055939, 11.720778620230003, 12.724027504282597, 13.728168231185522, 14.764492274668147, 15.662191118738118, 15.371116760373745, 14.43022475931569, 13.584289054707519, 12.709489865250413, 11.778404823558661, 10.75137482442124, 9.86974804849834, 10.806886676885036, 11.77014299735962, 12.703656227964196, 7.819611599591089, 8.788873785088036, 9.635412190215082, 9.116576563348408, 10.056789504708895, 10.962084615491776, 11.942360999252816, 12.73841823961677, 13.724803382985135, 14.604936569705421, 15.569697075657825, 15.399288963425477, 14.62879388487177, 13.66411007028593, 12.719612492260401, 11.798428341062088, 10.86903474273976, 11.798671053221065, 12.787716287548072, 13.717215388900177, 8.796886295768694, 9.799652873953598, 8.898032084712833, 8.121584663471749, 9.056268415333651, 10.010040176846253, 10.921364768688603, 11.798636720744682, 12.73333493912205, 13.635495680862356, 14.580865629395266, 15.56378738562381, 15.589456690776894, 14.69012536043497, 13.730469853450167, 12.731609922207562, 11.809699659840433, 12.773185200878137, 13.722210296168104, 14.675322083780783, 9.73292737986176, 8.861318456765002, 7.855066318823705, 7.060405183548713, 8.038749593103375, 9.072484444080418, 9.862135086341889, 10.834555137077679, 11.805755964518806, 12.678684562319518, 13.634547558643714, 14.533733414606257, 15.547983149976545, 15.648220181303465, 14.694600571083264, 13.705601552158262, 12.846017981449112, 13.809551329678136, 14.69404833091572, 15.627007731317633], [15.78183848088908, 15.01155768533567, 14.1140585281439, 14.829197322228179, 15.676068128833457, 16.582505572338103, 16.529469003211563, 15.563467511539656, 14.544238021291054, 13.605523268639342, 12.676783794115394, 11.719351731356287, 10.844114087959019, 9.857104748728853, 8.92701882287697, 7.935336530424638, 6.883923075737551, 5.92119459228412, 6.922312048394675, 7.8609396797048445, 14.779375153741798, 15.403472214997867, 15.15036434880388, 15.796867365776649, 16.605222342340056, 16.6465779427653, 15.648950871484278, 14.613895647737268, 13.730685282267697, 12.777255484950103, 11.777107725680402, 10.784468262929735, 9.851791524060838, 8.923069541507653, 7.990306603009801, 7.0115803900929645, 5.971643921921727, 4.94074216857821, 5.894692342149012, 6.842290338973337, 13.773021491246642, 14.470440621526597, 15.413063488369373, 16.413454898347357, 16.651955303587556, 15.680756369062799, 14.68665886386123, 13.667326133271887, 12.708507896711996, 11.792101951892958, 10.85602292629961, 9.838088370898921, 8.81396227897635, 7.884642093626557, 7.084977537929612, 6.0373398805563685, 5.045780640706611, 3.9966843918918884, 4.936196849074055, 5.883022553566256, 12.76070238260608, 13.512686270632411, 14.475852124436159, 15.528254128877748, 15.655125431906095, 14.703113766030551, 13.74672381866708, 12.717090246642764, 11.73328227595987, 10.74715397462294, 9.789772903241563, 8.78686058079612, 7.8283960960575865, 6.942306055865958, 6.0499366661554586, 5.087651018744434, 4.0349660325944114, 3.020733026124919, 4.040930693774591, 4.9122787723462995, 11.71541078151792, 12.520240255984003, 13.49807933506981, 14.489578013174782, 14.669492040228889, 13.742309477902609, 12.81263158832909, 11.773792303509879, 10.819936675380918, 9.84646713285517, 8.817110490086948, 7.8513136209478045, 6.8847968887229944, 5.957731974147133, 5.000562469164457, 4.086824739537287, 3.058806965231975, 2.088989460989742, 3.047086745906955, 3.9610053528037286, 10.653301049869592, 11.513061979666215, 12.53757851523457, 13.540096236173003, 14.047407976485223, 13.010016048068604, 12.042209317958958, 11.009818771597649, 9.94865258631609, 8.879197401234027, 7.875322397794107, 6.931127318862288, 5.919753096669972, 4.956518421760901, 3.980158310451417, 3.037000264176528, 2.017404512387701, 1.0529750221435092, 2.045957122354192, 2.903448616170799, 9.609108906390853, 10.549065765999657, 11.520259780718352, 12.538801409793567, 13.110202529020837, 12.061516745289277, 11.079603425696535, 10.028322287142098, 9.058715965341918, 8.034504793214394, 6.962840978218509, 5.996444096137575, 4.97479098268617, 3.9504994361438603, 3.019190915959406, 1.9664880905317212, 0.942826340374856, 0.0, 1.0046694979202204, 1.9337353264447525, 8.678480274410493, 9.742945537826591, 10.646426865024043, 11.634643844284188, 12.526696790047037, 12.948174431437465, 11.908701980308722, 10.880900698301174, 9.922616629865104, 8.86239288939951, 7.852642725597691, 6.876445969380072, 5.878291245095225, 4.940086610320111, 3.876742726694368, 2.856959542997193, 1.9095396236783249, 1.0387999250384519, 1.9542854075674556, 2.922388245229767, 7.800864860422797, 8.788858990072411, 9.678364068145587, 10.645214995371555, 11.60087313163111, 12.583126739722834, 12.619043719924827, 11.683519815089397, 10.703251147521712, 9.679902718824454, 8.66198890199033, 7.623027898752778, 6.643454753110857, 5.716953974588423, 4.762213319578842, 3.8347634335252585, 2.9344528974806874, 2.1056407384108033, 3.0168902384212304, 3.890428973028477, 6.848647179199211, 7.730279674701064, 8.730901576354702, 9.724977770078187, 10.667847100750446, 11.649118109328814, 12.585407233138383, 12.557463003901095, 11.568236562469737, 10.638398727248529, 9.572689182525556, 8.626698993109988, 7.686399445187511, 6.7097236838527765, 5.760745473294239, 4.833118503785032, 3.9089428795228582, 3.03893863995353, 3.969444771961766, 4.884438912515392, 5.838723910842541, 6.785471504828894, 7.806574067976981, 8.836651194437902, 9.862691032404712, 10.79105649873453, 11.865882796478376, 12.809326792388706, 12.585290627714112, 11.54056649880731, 10.560623709241657, 9.591859480876241, 8.708248205319572, 7.644512092861714, 6.797436642332917, 5.902720735770883, 4.929484452117633, 4.099423636410617, 4.89481520577328, 5.830283577778866, 4.919687575114622, 5.955607024706582, 6.9336398906832635, 7.872202321651708, 8.898944416743198, 9.868478425344897, 10.88407780399978, 11.877955156913762, 12.85586023716353, 12.526142595782948, 11.539606730803907, 10.54607827638299, 9.623178310695765, 8.615185552488093, 7.8382132300914495, 6.884537181204789, 5.883027486919885, 5.1559645477354765, 5.9335614837521025, 6.801091481912068, 3.8533725244810553, 4.919408591221676, 5.96515425124908, 6.899266015671459, 7.954907854602083, 8.918250532661773, 9.888384720130203, 10.883183873914017, 11.898597723678144, 12.914375878010526, 12.552055404068376, 11.512355701837262, 10.548396434038319, 9.603670539470452, 8.801600633510555, 7.840231345241548, 6.884700833266022, 6.168932249866689, 6.951061874334799, 7.72644946432326, 2.939966624022226, 3.9115306409373525, 4.984517150102878, 6.057973266113481, 7.062817099268768, 8.08428035814049, 9.15324267121372, 10.221563639363387, 11.170798743378562, 12.111570750316806, 13.16197259160733, 12.463789371645055, 11.495710562591482, 10.536910515066307, 9.757180906539256, 8.7653134024297, 7.831459206258108, 7.113978594109746, 7.954359269976781, 8.68093351347145, 3.909329345987504, 4.8991433797376835, 5.939780152293375, 7.01322739675675, 7.980139125618697, 9.018371427047487, 9.975750003126166, 11.005960001387173, 11.970713013199791, 13.01147422496187, 14.083376950409757, 13.425160414274853, 12.46621494148162, 11.58757715448448, 10.742693341762958, 9.802298400298147, 8.762680517250425, 8.045850243987173, 8.881005455500665, 9.738505082531969, 4.889595739864621, 5.835689140203382, 6.89770318041578, 7.868944012679809, 8.896437610331398, 9.866283478481844, 10.847056479783957, 11.796065881535496, 12.864027781047806, 13.873293813706958, 14.92445775398074, 14.405535547133915, 13.516490650887562, 12.632505369340562, 11.709166322166306, 10.735346632293762, 9.77696849666407, 9.060473742158006, 9.84343758812359, 10.76872335461887, 5.830396282167525, 6.794828257079741, 7.762784376435461, 8.718127294046216, 9.712115911681082, 10.777952279855146, 11.78120116390774, 12.793002000381534, 13.829326043864159, 14.806496092823169, 15.871001335694187, 15.373051099690548, 14.527115395082376, 13.652316205625269, 12.721231163933519, 11.694201164796098, 10.8125743888732, 10.057837303737454, 10.906800813435726, 11.807116699514104, 6.876785259216233, 7.84604744471318, 8.692585849840226, 9.704238164205483, 10.662373566983131, 11.72197321011108, 12.713177300012795, 13.668984474635808, 14.65771267287574, 15.547762910080278, 16.512523416032682, 16.342115303800334, 15.571620225246626, 14.606936410660786, 13.662438832635258, 12.741254681436947, 11.81186108311462, 11.069788443928909, 11.95687860416835, 12.820675860450086, 7.854059955393839, 8.85682653357874, 7.955205744337976, 8.952130819087106, 9.893582709788635, 10.847354471301237, 11.790307648576022, 12.72920295576372, 13.666244229012655, 14.578322021237213, 15.523691969770123, 16.50661372599867, 16.53228303115175, 15.632951700809826, 14.673296193825024, 13.674436262582422, 12.752526000215292, 12.054941318478074, 12.973241237357497, 13.853822300503927, 8.790101039486906, 7.918492116390147, 6.912239978448849, 7.89095133916407, 8.87606388755836, 9.909798738535402, 10.804961426716746, 11.777381477452534, 12.748582304893663, 13.621510902694375, 14.577373899018571, 15.476559754981114, 16.490809490351403, 16.591046521678322, 15.637426911458123, 14.648427892533121, 13.788844321823971, 13.091307447278073, 13.945079272105113, 14.805507948040777], [14.77716898296886, 14.006888187415448, 14.825936909524884, 15.728639374904757, 16.575510181510037, 17.48194762501468, 17.534138501131785, 16.56813700945988, 15.548907519211275, 14.610192766559562, 13.681453292035615, 12.724021229276508, 11.825801434154123, 10.815943962590946, 9.88312259421339, 8.891440301761056, 7.840026847073969, 6.877298363620539, 5.999390905366759, 6.856270181784623, 13.774705655821577, 14.398802717077647, 15.371443296569986, 16.31178910683206, 17.294171318573948, 17.65124744068552, 16.653620369404496, 15.618565145657486, 14.735354780187915, 13.781924982870324, 12.781777223600622, 11.789137760849956, 10.856461021981058, 9.897056508979311, 8.94641037434622, 7.967684161429384, 6.927747693258145, 5.896845939914629, 4.971771199121097, 5.837620841053115, 12.768351993326421, 13.465771123606377, 14.408393990449152, 15.408785400427137, 16.40617734035782, 16.685425866983017, 15.691328361781448, 14.671995631192106, 13.713177394632215, 12.796771449813177, 11.86069242421983, 10.842757868819142, 9.81863177689657, 8.889311591546777, 8.069825801455536, 7.02199982414088, 6.016472948159761, 4.952788163228306, 4.01327570604614, 4.878353055646035, 11.75603288468586, 12.50801677271219, 13.471182626515938, 14.52358463095753, 15.401237040631115, 15.70778326395077, 14.751393316587299, 13.721759744562982, 12.737951773880088, 11.751823472543158, 10.794442401161781, 9.79153007871634, 8.833065593977807, 7.946975553786179, 7.042971968189259, 6.072310962328945, 5.019625976178923, 4.005392969709431, 3.0847916229698367, 3.907609274426078, 10.710741283597699, 11.515570758063783, 12.49340983714959, 13.484908515254562, 14.415603648953908, 14.746978975822827, 13.817301086249309, 12.778461801430097, 11.824606173301136, 10.851136630775388, 9.821779988007167, 8.855983118868025, 7.889466386643215, 6.962401472067353, 6.005231967084677, 5.091494237457509, 4.063476463152195, 3.0736494045742537, 2.042417247986735, 2.9563358548835077, 9.648631551949371, 10.508392481745995, 11.53290901731435, 12.535426738252783, 13.4630647514168, 14.014685545988822, 13.046878815879177, 12.014488269517868, 10.953322084236309, 9.883866899154246, 8.879991895714326, 7.935796816782508, 6.924422594590192, 5.961187919681121, 4.984827808371637, 4.041669762096749, 3.0220740103079216, 2.037634965728021, 1.041287624433972, 1.8987791182505782, 8.604439408470633, 9.544396268079437, 10.515590282798131, 11.534131911873347, 12.49712527562869, 13.066186243209499, 12.084272923616757, 11.03299178506232, 10.06338546326214, 9.039174291134614, 7.967510476138729, 7.001113594057795, 5.979460480606391, 4.955168934064081, 4.023860413879627, 2.9711575884519417, 1.9474958382950764, 1.0046694979202204, 0.0, 0.929065828524532, 7.673810776490272, 8.73827603990637, 9.641757367103823, 10.629974346363968, 11.522027292126817, 12.461763553537615, 12.888309681878532, 11.860508399870984, 10.902224331434914, 9.84200059096932, 8.8322504271675, 7.85605367094988, 6.857898946665033, 5.919694311889919, 4.856350428264176, 3.8365672445670005, 2.8891473252481323, 1.9048617346928567, 0.9496159096472352, 1.9177187473095465, 6.796195362502576, 7.784189492152191, 8.673694570225367, 9.640545497451335, 10.59620363371089, 11.578457241802614, 12.584823795140412, 12.663127516659205, 11.68285884909152, 10.659510420394263, 9.641596603560139, 8.602635600322586, 7.623062454680665, 6.69656167615823, 5.741821021148649, 4.814371135095066, 3.9140605990504946, 2.971702548065208, 2.01222074050101, 2.8857594751082565, 5.84397768127899, 6.725610176780844, 7.726232078434482, 8.720308272157967, 9.663177602830226, 10.644448611408594, 11.580737735218163, 12.611839184024248, 12.547844264039545, 11.618006428818337, 10.552296884095364, 9.606306694679796, 8.666007146757318, 7.689331385422584, 6.7403531748640475, 5.81272620535484, 4.885762123763277, 3.9050004496079347, 2.9647752740415454, 3.879769414595172, 4.83405441292232, 5.780802006908673, 6.80190457005676, 7.831981696517682, 8.858021534484491, 9.78638700081431, 10.861213298558155, 11.804657294468484, 12.82365577229012, 12.520174200377118, 11.540231410811465, 10.57146718244605, 9.68785590688938, 8.624119794431522, 7.777044343902725, 6.882328437340691, 5.906303696358051, 4.907815718895464, 3.8901457078530592, 4.825614079858646, 3.915018077194402, 4.950937526786362, 5.928970392763043, 6.867532823731487, 7.894274918822978, 8.863808927424676, 9.87940830607956, 10.87328565899354, 11.851190739243307, 12.916743988527363, 12.519214432373715, 11.525685977952799, 10.602786012265573, 9.594793254057901, 8.815981192080558, 7.861356425445207, 6.859846731160303, 5.948188881949724, 4.928891985831882, 5.796421983991848, 2.848703026560835, 3.9147390933014554, 4.96048475332886, 5.894596517751238, 6.950238356681862, 7.913581034741552, 8.88371522220998, 9.878514375993795, 10.893928225757922, 11.909706380090304, 12.842508257750543, 12.49196340340707, 11.528004135608127, 10.58327824104026, 9.779298264542158, 8.817050589481967, 7.856917761370781, 6.880810631247674, 5.946392376414579, 6.72177996640304, 1.9352971261020055, 2.906861143017132, 3.979847652182657, 5.05330376819326, 6.058147601348547, 7.079610860220267, 8.148573173293498, 9.216894141443165, 10.16612924545834, 11.106901252396584, 12.157303093687108, 13.085148043104748, 12.47531826416129, 11.516518216636115, 10.734878537570859, 9.742132646670118, 8.803676134362867, 7.825856975490731, 6.94968977205656, 7.676264015551229, 2.9046598480672836, 3.8944738818174627, 4.935110654373155, 6.008557898836529, 6.975469627698477, 8.013701929127267, 8.971080505205945, 10.001290503466953, 10.966043515279571, 12.006804727041649, 13.078707452489537, 14.056816786119715, 13.445822643051429, 12.567184856054288, 11.720390972794561, 10.774515328402906, 9.734897445355184, 8.757728625368157, 7.876335957580444, 8.733835584611748, 3.8849262419444006, 4.831019642283161, 5.89303368249556, 6.864274514759589, 7.891768112411178, 8.861613980561623, 9.842386981863736, 10.791396383615275, 11.859358283127586, 12.868624315786736, 13.919788256060517, 14.881652227961757, 14.49609835245737, 13.61211307091037, 12.686863953197909, 11.70756356039852, 10.749185424768829, 9.77235212353899, 8.83876809020337, 9.764053856698652, 4.825726784247305, 5.790158759159521, 6.758114878515241, 7.713457796125995, 8.707446413760863, 9.773282781934927, 10.776531665987521, 11.788332502461312, 12.824656545943936, 13.801826594902947, 14.866331837773965, 15.849167780518389, 15.506723096652184, 14.631923907195077, 13.693448092038278, 12.666418092900857, 11.761040932758325, 10.769715685118438, 9.902131315515504, 10.802447201593885, 5.872115761296012, 6.841377946792959, 7.6879163519200056, 8.699568666285263, 9.65770406906291, 10.717303712190862, 11.708507802092576, 12.718047803302472, 13.789220645890852, 14.717371828369881, 15.718414039994514, 16.728284707651788, 16.54287805211174, 15.578194237525901, 14.586075812883301, 13.640696734113526, 12.711303135791198, 11.781666825309893, 10.952209106248128, 11.816006362529867, 6.849390457473618, 7.85215703565852, 8.639180530149536, 9.646000320249703, 10.658225158438155, 11.661074975602201, 12.604028152876985, 13.542923460064683, 14.479964733313619, 15.415731316721589, 16.48874924174988, 17.471670997978425, 17.503540858016862, 16.60420952767494, 15.593303136731562, 14.573878315259, 13.65196805289187, 12.766819699859058, 11.968571739437275, 12.849152802583708, 7.785431541566685, 6.9955709733622315, 7.868343749785267, 8.84705511050049, 9.832167658894779, 10.865902509871821, 11.76380064057884, 12.759068823647638, 13.753251802813883, 14.626180400614595, 15.582043396938792, 16.481229252901333, 17.495478988271625, 17.490488574354902, 16.5368689641347, 15.5478699452097, 14.68828637450055, 13.803185828659057, 12.940409774184891, 13.800838450120558], [13.848103154444328, 14.41429269810303, 15.4053750758692, 16.350393321856, 17.289910703453835, 18.300208183416643, 18.42902428002165, 17.463022788349743, 16.44379329810114, 15.505078545449429, 14.576339070925481, 13.618907008166374, 12.659519117513888, 11.649661645950712, 10.716840277573155, 9.725157985120822, 8.673744530433735, 7.711016046980305, 6.8331085887265255, 5.92720435326009, 12.845639827297045, 13.469736888553115, 14.442377468045454, 15.382723278307529, 16.365105490049416, 17.360008857162715, 17.58268619792903, 16.54763097418202, 15.664420608712447, 14.67681076176019, 13.67666300249049, 12.684023539739822, 11.735829191793506, 10.730774192339076, 9.780128057705985, 8.801401844789149, 7.761465376617911, 6.730563623274395, 5.805488882480863, 4.908555012528582, 11.839286164801889, 12.536705295081845, 13.47932816192462, 14.479719571902605, 15.47711151183329, 16.394187283460212, 16.62039419030598, 15.601061459716638, 14.642243223156747, 13.725837278337709, 12.789758252744361, 11.771823697343676, 10.747697605421104, 9.818377420071307, 8.96147350910004, 7.913647531785385, 6.850190631519526, 5.7865058465880725, 4.846993389405906, 3.9492872271215025, 10.826967056161328, 11.578950944187659, 12.542116797991406, 13.594518802432997, 14.472171212106582, 15.416544680427963, 15.680459145111831, 14.650825573087515, 13.66701760240462, 12.68088930106769, 11.723508229686313, 10.720595907240874, 9.76213142250234, 8.87604138231071, 7.972037796713791, 7.001376790853477, 5.948691804703455, 4.934458798233963, 3.918509306329603, 2.978543445901546, 9.781675455073167, 10.58650492953925, 11.564344008625058, 12.55584268673003, 13.486537820429376, 14.413720382755656, 14.74636691477384, 13.70752762995463, 12.753672001825668, 11.78020245929992, 10.7508458165317, 9.785048947392559, 8.818532215167748, 7.891467300591885, 6.93429779560921, 6.020560065982041, 4.9925422916767275, 4.002715233098786, 2.9714830765112668, 2.0272700263589756, 8.71956572342484, 9.579326653221463, 10.603843188789817, 11.60636090972825, 12.533998922892268, 13.541681309333908, 13.97594464440371, 12.9435540980424, 11.88238791276084, 10.812932727678778, 9.809057724238858, 8.86486264530704, 7.853488423114724, 6.890253748205653, 5.913893636896169, 4.970735590621281, 3.9511398388324537, 2.966700794252553, 1.9703534529585038, 0.9697132897260462, 7.6753735799461005, 8.615330439554905, 9.586524454273599, 10.605066083348815, 11.568059447104158, 12.574434984342309, 13.013338752141289, 11.962057613586852, 10.992451291786672, 9.968240119659146, 8.896576304663261, 7.930179422582327, 6.908526309130923, 5.884234762588613, 4.952926242404159, 3.900223416976474, 2.8765616668196086, 1.9337353264447525, 0.929065828524532, 0.0, 6.74474494796574, 7.809210211381838, 8.712691538579291, 9.700908517839435, 10.592961463602284, 11.532697725013083, 12.572170176141826, 12.789574228395514, 11.831290159959444, 10.77106641949385, 9.76131625569203, 8.78511949947441, 7.786964775189563, 6.84876014041445, 5.785416256788707, 4.765633073091532, 3.818213153772664, 2.8339275632173884, 1.878681738171767, 0.9886529187850145, 5.867129533978044, 6.8551236636276585, 7.744628741700835, 8.711479668926803, 9.667137805186357, 10.649391413278082, 11.65575796661588, 12.59128187145131, 12.611924677616056, 11.588576248918796, 10.570662432084672, 9.53170142884712, 8.552128283205198, 7.625627504682762, 6.670886849673181, 5.743436963619597, 4.843126427575026, 3.90076837658974, 2.9412865690255416, 1.9566936465837246, 4.914911852754458, 5.796544348256312, 6.797166249909949, 7.7912424436334335, 8.734111774305694, 9.715382782884062, 10.65167190669363, 11.682773355499716, 12.671999796931074, 12.54707225734287, 11.481362712619898, 10.53537252320433, 9.59507297528185, 8.618397213947116, 7.669419003388578, 6.741792033879371, 5.814827952287809, 4.834066278132466, 3.893841102566077, 2.9507035860706403, 3.9049885843977883, 4.851736178384141, 5.872838741532228, 6.9029158679931495, 7.928955705959959, 8.857321172289778, 9.932147470033623, 10.875591465943952, 11.894589943765588, 12.93931407267239, 12.469297239335999, 11.500533010970583, 10.616921735413912, 9.553185622956054, 8.706110172427255, 7.811394265865221, 6.835369524882583, 5.836881547419996, 4.819211536377591, 3.8965482513341145, 2.9859522486698697, 4.02187169826183, 4.999904564238511, 5.938466995206955, 6.965209090298446, 7.934743098900143, 8.950342477555026, 9.944219830469008, 10.922124910718775, 11.987678160002831, 12.93013471361427, 12.454751806477333, 11.531851840790106, 10.523859082582433, 9.74504702060509, 8.790422253969739, 7.788912559684835, 6.877254710474256, 5.857957814356414, 4.867356155467316, 1.919637198036303, 2.9856732647769233, 4.031418924804328, 4.965530689226706, 6.02117252815733, 6.9845152062170195, 7.954649393685449, 8.949448547469263, 9.96486239723339, 10.980640551565772, 11.913442429226011, 12.953142131457126, 12.457069964132659, 11.512344069564792, 10.70836409306669, 9.7461164180065, 8.701085856724156, 7.724978726601048, 6.790560471767953, 5.792714137878509, 1.0062312975774734, 1.9777953144926, 3.050781823658125, 4.124237939668728, 5.129081772824015, 6.150545031695735, 7.219507344768965, 8.28782831291863, 9.237063416933806, 10.17783542387205, 11.228237265162575, 12.156082214580215, 13.174142062183723, 12.445584045160647, 11.663944366095391, 10.640863273544287, 9.647844229716242, 8.670025070844105, 7.7716752264749145, 6.747198187026698, 1.9755940195427515, 2.9654080532929306, 4.0060448258486225, 5.079492070311997, 6.0464037991739445, 7.084636100602735, 8.042014676681413, 9.07222467494242, 10.036977686755039, 11.077738898517117, 12.149641623965005, 13.12775095759518, 14.086696430388413, 13.49625068457882, 12.576381084362918, 11.61868342375628, 10.579065540708559, 9.601896720721532, 8.698321411998798, 7.804769756087218, 2.9558604134198685, 3.901953813758629, 4.9639678539710275, 5.935208686235057, 6.962702283886646, 7.932548152037092, 8.913321153339204, 9.862330555090743, 10.930292454603054, 11.939558487262204, 12.990722427535985, 13.952586399437225, 14.98694896087084, 14.541178899434902, 13.542854064766265, 12.551731655751896, 11.593353520122204, 10.616520218892365, 9.660753544621723, 8.83498802817412, 3.8966609557227727, 4.861092930634989, 5.829049049990709, 6.784391967601463, 7.77838058523633, 8.844216953410395, 9.84746583746299, 10.85926667393678, 11.895590717419404, 12.872760766378414, 13.937266009249432, 14.920101951993857, 15.894446683436156, 15.547685927896172, 14.537616187391652, 13.510586188254232, 12.6052090281117, 11.613883780471813, 10.724116769933858, 9.873381373069353, 4.94304993277148, 5.912312118268427, 6.758850523395473, 7.770502837760731, 8.728638240538379, 9.78823788366633, 10.779441973568044, 11.78898197477794, 12.86015481736632, 13.788305999845349, 14.789348211469981, 15.799218879127258, 16.779327712454545, 16.422362332879274, 15.430243908236676, 14.4848648294669, 13.555471231144573, 12.625834920663268, 11.774194560666482, 10.886940534005335, 5.920324628949086, 6.923091207133988, 7.710114701625004, 8.716934491725171, 9.729159329913623, 10.732009147077669, 11.674962324352453, 12.613857631540151, 13.550898904789086, 14.486665488197056, 15.559683413225347, 16.542605169453893, 17.530213986734175, 17.448377623028314, 16.43747123208494, 15.418046410612375, 14.496136148245245, 13.610987795212433, 12.790557193855628, 11.920086974059176, 6.856365713042153, 7.829288656721998, 8.702061433145033, 9.680772793860255, 10.665885342254544, 11.669564879843504, 12.597518323938605, 13.577939215207154, 14.478477879392331, 15.443476606739896, 16.399339603064092, 17.3761150317912, 18.39036476716149, 18.334656669708277, 17.381037059488076, 16.392038040563072, 15.532454469853924, 14.647353924012432, 13.762395228603244, 12.871772621596026], [7.103358206478589, 7.669547750137289, 8.66063012790346, 9.605648373890258, 10.545165755488092, 11.555463235450903, 12.430615233180818, 13.396616724852723, 14.415846215101325, 15.354560967753038, 16.283300442276985, 17.240732505036092, 18.313676981189644, 18.394406593916447, 17.46158522553889, 16.46990293308656, 15.418489478399472, 14.455760994946042, 13.577853536692265, 12.67194930122583, 6.100894879331307, 6.724991940587375, 7.697632520079713, 8.637978330341788, 9.620360542083676, 10.615263909196974, 11.475838858293757, 12.504227509456243, 13.519065021871004, 14.523898818310323, 15.524046577580025, 16.516686040330693, 17.46488038827701, 17.47551914030481, 16.524873005671722, 15.546146792754886, 14.506210324583648, 13.475308571240133, 12.550233830446603, 11.653299960494323, 5.09454121683615, 5.791960347116105, 6.73458321395888, 7.734974623936863, 8.732366563867547, 9.64944233549447, 10.513546850670709, 11.557657994990862, 12.516476231550753, 13.557163783748495, 14.596812743960127, 15.609431304120253, 16.528484506418348, 16.450907354190104, 15.651242798493161, 14.658392479751123, 13.594935579485265, 12.531250794553811, 11.591738337371645, 10.694032175087242, 4.082222108195588, 4.834205996221918, 5.797371850025666, 6.849773854467256, 7.727426264140844, 8.671799732462222, 9.57361180547656, 10.603245377500876, 11.58705334818377, 12.5731816495207, 13.53056272090208, 14.558203514017451, 15.542918323499585, 15.508571316429506, 14.616201926719008, 13.746121738819216, 12.693436752669195, 11.679203746199702, 10.663254254295342, 9.723288393867286, 3.036930507107426, 3.8417599815735097, 4.819599060659318, 5.811097738764291, 6.741792872463637, 7.668975434789916, 8.598653324363434, 9.637492609182646, 10.591348237311607, 11.564817779837355, 12.629519190451527, 13.63280238394018, 14.599319116164992, 14.52399723471068, 13.566827729728006, 12.76530501394778, 11.737287239642468, 10.747460181064525, 9.716228024477008, 8.772014974324716, 1.9748207754590998, 2.8345817052557223, 3.8590982408240784, 4.861615961762512, 5.789253974926529, 6.826645903343149, 7.794452633452793, 8.826843179814102, 9.88800936509566, 10.885185703431624, 11.889060706871543, 12.833255785803361, 13.844630007995677, 13.52278368232445, 12.546423571014966, 11.71548053858702, 10.695884786798194, 9.711445742218293, 8.715098400924244, 7.714458237691787, 0.9306286319803604, 1.8705854915891647, 2.8417795063078595, 3.8603211353830758, 4.823314499138419, 5.872000282869979, 6.853913602462722, 7.905194741017159, 8.874801062817339, 9.899012234944863, 10.970676049940748, 11.937072932021682, 12.958726045473085, 12.499151732316623, 11.567843212132168, 10.644968364942214, 9.621306614785349, 8.678480274410493, 7.6738107764902725, 6.74474494796574, 0.0, 1.073121866314054, 2.036454574617684, 3.0884596924062055, 4.086406975595923, 5.026143237006721, 6.065615688135464, 7.093416970143012, 8.051701038579083, 9.111924779044676, 10.121674942846496, 11.097871699064116, 12.096026423348963, 11.518806475115952, 10.594274546164332, 9.650136566214345, 8.705169410846919, 7.720883820291643, 6.7656379952460215, 5.756092029180726, 0.932418612392397, 1.9887241794315915, 2.968738904117839, 3.9355898313438065, 4.891247967603361, 5.8735015756950855, 6.93860128268217, 7.874125187517601, 8.854393855085286, 9.877742283782545, 10.89565610061667, 11.934617103854222, 11.481023995271878, 10.554523216749443, 9.599782561739863, 8.67233267568628, 7.738318864272027, 6.772722598199973, 5.72753215573801, 4.788051301382016, 1.9861605482267277, 3.042236538090479, 3.9162013959087245, 4.910277589632209, 5.836219518487204, 6.817490527065572, 7.753779650875141, 8.784881099681227, 9.774107541112585, 10.703945376333794, 11.769654921056766, 11.739521168884746, 10.75329783308839, 9.683300119886985, 8.760956334774349, 7.833329365265142, 6.823404252209979, 5.842642578054638, 4.774977622197475, 3.7940413618950997, 2.9960838165833974, 3.94283141056975, 4.953038058777375, 5.949679061907775, 6.879397217604268, 7.8077626839340875, 8.786549418232928, 9.745833931992186, 10.764832409813822, 11.705523474444254, 11.824814615676042, 10.774360681118493, 9.796748361227671, 8.748511710878047, 7.756139779367966, 6.806396030199187, 5.815618910081267, 4.867277199428365, 3.8496071883859604, 2.8481966966316254, 3.9275814268611926, 4.952683964139445, 5.946411989712177, 6.965516604464979, 7.902412711172051, 8.8616485889665, 9.788537710645961, 10.67720556746713, 11.748373418592971, 11.833563534633049, 10.81367034003266, 9.820141885611744, 8.788749675441887, 7.780756917234214, 6.81821033619927, 5.863585569563918, 4.8620758752790145, 3.8972631009409833, 2.894954599986177, 1.8773887924984236, 4.99389647749476, 5.9888823976243515, 6.9148976291463615, 7.84900939356874, 8.874039541524603, 9.811876481649623, 10.782010669118053, 11.671976850466875, 11.825941359239687, 10.810163204907305, 9.877361327247066, 8.83766162501595, 7.873702357217008, 6.919492925890348, 5.873491812839094, 4.911244137778904, 3.8604025289328776, 2.8842953988097704, 1.9498771439766758, 0.9520308100872317, 6.046269158735647, 7.0178331756507735, 7.9000562638470555, 8.781608002340729, 9.786451835496017, 10.769201641102459, 11.727278877540233, 12.669144319430739, 12.708114092470153, 11.767342085531908, 10.716940244241384, 9.789095294823744, 8.821016485770171, 7.783259253210269, 6.829072085867796, 5.800179945753011, 4.807160901924965, 3.829341743052827, 2.920831306925409, 1.8963542674771925, 7.025825540822094, 8.005445914451105, 8.930329917723995, 9.853101637565027, 10.75618682048712, 11.70865148391686, 12.666030059995538, 13.694987817126025, 13.735630947765689, 12.697302066425046, 11.633928139024562, 10.587485691287524, 9.628540218494292, 8.671494944155715, 7.735697756571639, 6.778000095965003, 5.738382212917281, 4.761213392930254, 3.847477492449293, 2.9211256868402824, 8.00609193469921, 8.95218533503797, 10.001223343255555, 10.811765586065102, 11.772795945079537, 12.706498003480545, 13.667130010663051, 14.61613941241459, 14.59015476898076, 13.580888736321608, 12.529724796047827, 11.567860824146587, 10.678815927900235, 9.716423159011796, 8.702170736974987, 7.711048327960618, 6.752670192330925, 5.775836891101086, 4.809909625072219, 3.9513439589271853, 8.946892477002114, 9.91132445191433, 10.879280571270051, 11.784775655055341, 12.778764272690207, 13.760188984788416, 14.68161483665076, 15.613075531260627, 15.518482267327126, 14.541312218368116, 13.476268377761274, 12.53537637670322, 11.68944067209505, 10.707002600104895, 9.696932859600375, 8.669902860462955, 7.764525700320419, 6.773200452680533, 5.873272850384354, 4.989737303822418, 10.01946448601623, 10.962543639547768, 11.809082044674815, 12.801941998887703, 13.76007740166535, 14.812758847433324, 15.613590972755816, 16.60282552282938, 16.357276102993506, 15.429124920514475, 14.428082708889843, 13.504440580813005, 12.546362819673835, 11.581679005087995, 10.589560580445395, 9.64418150167562, 8.714787903353292, 7.785151592871987, 6.923350641116978, 6.0032964647583995, 10.996739182193835, 11.97332272841333, 12.760346222904346, 13.767166013004513, 14.760598491040595, 15.76344830820464, 16.634587203320027, 17.54260704170147, 17.33433239276551, 16.398565809357542, 15.416914155152401, 14.494634442859242, 13.507025625578958, 12.607694295237035, 11.596787904293656, 10.577363082821094, 9.655452820453965, 8.770304467421152, 7.939713274306124, 7.036442904812241, 11.932780266286901, 12.920713236350663, 13.803311988793473, 14.819441498682984, 15.77811731327087, 16.701004040970478, 17.69381688566674, 18.506688625368472, 18.2066326597077, 17.228027550855966, 16.363232225903953, 15.348167948791385, 14.32395870366447, 13.3894357984082, 12.500541896330883, 11.551354712771793, 10.646001374294466, 9.683381208769287, 8.736026163367846, 7.9881285523490915], [7.7840063977291605, 6.796042436945331, 7.787124814711502, 8.7321430606983, 9.671660442296135, 10.681957922258947, 11.55710991998886, 12.523111411660766, 13.54234090190937, 14.481055654561082, 15.40979512908503, 16.367227191844137, 17.44017166799769, 17.604330164718885, 16.682123492610096, 15.733487292832539, 14.826978215225278, 13.864249731771848, 13.169547935659084, 13.736414564641928, 6.781543070581878, 5.851486627395418, 6.824127206887756, 7.76447301714983, 8.746855228891718, 9.741758596005019, 10.6023335451018, 11.630722196264285, 12.645559708679047, 13.650393505118366, 14.650541264388067, 15.643180727138734, 16.59137507508505, 17.59643007453948, 17.589338269087822, 16.610612056170986, 15.570675587999748, 14.53977383465623, 13.6146990938627, 12.71776522391042, 5.919049665119499, 4.918455033924148, 5.861077900766922, 6.861469310744906, 7.858861250675591, 8.775937022302514, 9.640041537478751, 10.684152681798905, 11.642970918358795, 12.683658470556537, 13.723307430768168, 14.735925990928294, 15.65497919322639, 16.587488552998675, 16.72436466480721, 15.722857743167221, 14.659400842901363, 13.59571605796991, 12.656203600787743, 11.75849743850334, 5.006456564125059, 3.960700683029961, 4.923866536833709, 5.976268541275299, 6.853920950948886, 7.798294419270267, 8.700106492284602, 9.729740064308919, 10.713548034991813, 11.699676336328743, 12.65705740771012, 13.684698200825492, 14.669413010307627, 15.645152515238077, 15.68932379303306, 14.810587002235316, 13.757902016085295, 12.743669009615802, 11.72771951771144, 10.787753657283384, 4.0174533957168235, 2.968254668381553, 3.946093747467361, 4.937592425572334, 5.86828755927168, 6.795470121597959, 7.725148011171478, 8.763987295990688, 9.71784292411965, 10.691312466645398, 11.75601387725957, 12.759297070748223, 13.725813802973034, 14.6665476645555, 14.639949596042058, 13.82977027736388, 12.801752503058566, 11.811925444480625, 10.780693287893106, 9.836480237740814, 2.979151422983443, 1.9610763920637657, 2.985592927632122, 3.9881106485705553, 4.915748661734573, 5.953140590151192, 6.9209473202608365, 7.953337866622146, 8.973801545055263, 9.94190762363694, 10.94578262707686, 11.889977706008677, 12.901351928200993, 13.885949464439483, 13.619545437329018, 12.77994580200312, 11.760350050214292, 10.775911005634391, 9.779563664340342, 8.778923501107885, 1.9370370380060122, 0.9970801783972081, 1.968274193115903, 2.986815822191119, 3.949809185946463, 4.994758630021893, 5.976671949614635, 6.977108056695849, 7.931522983022653, 8.955734155150179, 10.027397970146064, 10.993794852226998, 12.008167921878979, 12.987348720963132, 12.64096507844622, 11.709433628358312, 10.685771878201447, 9.742945537826591, 8.73827603990637, 7.8092102113818385, 1.073121866314054, 0.0, 0.9633327083036298, 2.0153378260921513, 3.0132851092818687, 3.9530213706926665, 4.99249382182141, 6.020295103828957, 6.978579172265027, 8.03880291273062, 9.048553076532441, 10.02474983275006, 11.022904557034908, 11.96110919181002, 11.667396412478384, 10.717054593581885, 9.769634674263017, 8.785349083707741, 7.8301032586621195, 6.820557292596824, 2.0055404787064512, 0.9540865477541793, 1.9313955051820861, 2.8982464324080537, 3.853904568667608, 4.836158176759332, 5.901257883746417, 6.836781788581847, 7.817050456149532, 8.840398884846792, 9.858312701680916, 10.897273704918469, 11.87684685056039, 11.627645083063495, 10.672904428053915, 9.745454542000331, 8.81144073058608, 7.845844464514026, 6.800654022052063, 5.852516564798114, 3.0592824145407818, 2.0126658631255268, 2.8788579969729717, 3.8729341906964563, 4.798876119551451, 5.780147128129819, 6.716436251939388, 7.747537700745474, 8.736764142176833, 9.666601977398042, 10.732311522121014, 11.678301711536582, 11.826419699402447, 10.75642198620104, 9.834078201088403, 8.906451231579195, 7.896526118524033, 6.9157644443686905, 5.848099488511528, 4.858506625311198, 3.9042216269840497, 2.957474032997697, 3.9156946598416225, 4.912335662972022, 5.842053818668515, 6.770419284998335, 7.7492060192971755, 8.708490533056432, 9.727489010878068, 10.668180075508502, 11.648122865074155, 11.847482547432547, 10.869870227541725, 9.821633577192102, 8.82926164568202, 7.87951789651324, 6.888740776395321, 5.940399065742419, 4.922729054700014, 3.9213185629456793, 4.835719237261845, 3.967326586567392, 4.961054612140124, 5.968788550214136, 6.865069312236297, 7.824305190030747, 8.75119431171021, 9.639862168531376, 10.711030019657217, 11.65375617248414, 11.886792206346714, 10.893263751925797, 9.86187154175594, 8.853878783548268, 7.891332202513324, 6.936707435877972, 5.935197741593068, 4.970384967255037, 3.968076466300231, 2.9505106588124774, 5.902034287895412, 5.003525020052298, 5.929540251574307, 6.863652015996686, 7.836696142588849, 8.774533082713871, 9.744667270182301, 10.634633451531121, 11.650047301295247, 11.883285071221358, 10.95048319356112, 9.910783491330005, 8.946824223531062, 7.992614792204402, 6.946613679153148, 5.984366004092958, 4.933524395246931, 3.957417265123824, 3.0229990102907296, 2.0251526764012855, 6.9544069691363, 6.05377636981766, 6.914698886275001, 7.796250624768675, 8.801094457923963, 9.731858242166707, 10.68993547860448, 11.631800920494985, 12.58103602451016, 12.840463951845962, 11.790062110555438, 10.862217161137798, 9.894138352084225, 8.856381119524324, 7.902193952181849, 6.873301812067065, 5.880282768239018, 4.902463609366881, 3.9272397129510606, 2.9027626735028442, 7.933963351222746, 7.041389108617991, 7.944972540151942, 8.867744259992973, 9.770829442915065, 10.671308084981108, 11.628686661059787, 12.657644418190271, 13.608552879805696, 13.7704239327391, 12.707050005338616, 11.660607557601578, 10.701662084808346, 9.744616810469768, 8.808819622885693, 7.8511219622790565, 6.811504079231335, 5.803333920764748, 4.853885898474944, 3.9254563343646254, 8.914229745099863, 8.113698592959091, 9.015865965683503, 9.826408208493048, 10.787438567507483, 11.669154604544794, 12.6297866117273, 13.578796013478838, 14.584262912156726, 14.654010602635662, 13.60284666236188, 12.64098269046064, 11.751937794214289, 10.78954502532585, 9.77529260328904, 8.78417019427467, 7.8257920586449785, 6.817957418935581, 5.81631803109787, 4.955674606451528, 9.855030287402768, 9.16397908322728, 9.949172928083698, 10.799418277483287, 11.793406895118153, 12.722845585852664, 13.644271437715009, 14.575732132324877, 15.576574938524457, 15.61443408468217, 14.549390244075328, 13.608498243017273, 12.762562538409103, 11.780124466418947, 10.770054725914427, 9.743024726777007, 8.806646228154914, 7.815320980515028, 6.879681256410005, 5.994067951346761, 10.927602296416882, 10.215198270860718, 10.878974401488462, 11.816584621315648, 12.774720024093297, 13.775415448497572, 14.576247573820064, 15.565482123893629, 16.63665496648201, 16.50224678682853, 15.501204575203896, 14.568592180835616, 13.58848334750833, 12.62379953292249, 11.63168110827989, 10.686302029510115, 9.756908431187787, 8.827272120706482, 7.926295757746251, 6.9916213291803855, 11.904876992594488, 11.22597735972628, 11.830238579717992, 12.811576521192308, 13.77524111346854, 14.727459887143095, 15.597243804384277, 16.50526364276572, 17.442304916014656, 17.31133335620685, 16.349686935275482, 15.366765179046938, 14.379156361766654, 13.514802564120743, 12.578034928941273, 11.558610107468711, 10.597430501408386, 9.633944960370682, 8.684919865080715, 7.7318080774680364, 12.840918076687554, 12.173367867663613, 12.87320434560712, 13.872756001115343, 14.792759935698816, 15.66501561990893, 16.65647348673099, 17.469345226432722, 17.333127346515745, 16.35452223766401, 15.518022615448743, 14.47466263559943, 13.450453390472513, 12.515930485216243, 11.627036583138928, 10.699300678596472, 9.772496061102508, 8.80987589557733, 7.862520850175889, 8.683493725004887], [8.74733910603279, 7.759375145248962, 7.038777844458261, 7.910487877608826, 8.80453009128687, 9.739135823936321, 10.614287821666236, 11.580289313338142, 12.599518803586744, 13.538233556238456, 14.466973030762404, 15.42440509352151, 16.497349569675062, 16.640997456415253, 15.718790784306464, 14.78092854114203, 13.874419463534768, 12.911690980081337, 13.758403717204528, 14.639895891839382, 7.7448757788855085, 6.814819335699048, 6.002472023798282, 6.942817834060356, 7.875375877780271, 8.798936497682392, 9.659511446779176, 10.687900097941661, 11.702737610356422, 12.707571406795742, 13.707719166065443, 14.70035862881611, 15.648552976762426, 16.653607976216854, 16.724411377457482, 15.745685164540644, 14.834467239257158, 13.892143403787246, 14.518180421060155, 13.621246551107875, 6.8823823734231295, 5.881787742227778, 4.950805093749397, 5.95119650372738, 6.9297226522180715, 7.833114923979889, 8.697219439156127, 9.74133058347628, 10.700148820036171, 11.740836372233913, 12.780485332445545, 13.793103892605671, 14.712157094903766, 15.64466645467605, 16.58596679938842, 16.626339070364676, 15.562882170098817, 14.499197385167363, 13.559684927985197, 12.661978765700795, 5.969789272428688, 4.924033391333591, 4.013593729816184, 5.033453033887731, 5.911098852626262, 6.855472320947642, 7.757284393961978, 8.786917965986294, 9.770725936669189, 10.756854238006119, 11.714235309387497, 12.74187610250287, 13.726590911985003, 14.702330416915453, 15.674833845077789, 15.71406832943277, 14.661383343282749, 13.647150336813256, 12.631200844908895, 11.691234984480838, 4.980786104020454, 3.931587376685183, 3.035820940449835, 3.9947703272497086, 4.925465460949055, 5.852648023275334, 6.782325912848853, 7.821165197668064, 8.775020825797025, 9.748490368322773, 10.813191778936945, 11.816474972425599, 12.78299170465041, 13.723725566232876, 14.718318832586426, 14.733251604561334, 13.70523383025602, 12.71540677167808, 11.68417461509056, 10.739961564938268, 3.942484131287072, 2.9244091003673955, 2.042770829309496, 3.0452885502479297, 3.9729265634119466, 4.998672246709862, 5.966478976819507, 6.998869523180816, 8.010468836751635, 8.97857491533331, 9.982449918773229, 10.926644997705047, 11.938019219897363, 12.922616756135852, 13.898976867445336, 13.683427129200574, 12.663831377411746, 11.679392332831846, 10.683044991537797, 9.682404828305339, 2.900369746309642, 1.960412886700838, 1.0254520947932775, 2.0439937238684935, 3.006987087623837, 4.031425921718263, 5.013339241311005, 6.01377534839222, 6.968190274719023, 7.992401446846548, 9.064065261842433, 10.030462143923367, 11.044835213575348, 12.024016012659501, 12.955324532843957, 12.612914955555766, 11.5892532053989, 10.646426865024045, 9.641757367103825, 8.712691538579293, 2.036454574617684, 0.9633327083036298, 0.0, 1.0520051177885215, 2.049952400978239, 2.9896886623890366, 4.02916111351778, 5.056962395525328, 6.015246463961398, 7.075470204426991, 8.08522036822881, 9.06141712444643, 10.059571848731277, 10.99777648350639, 12.061120367132133, 11.62053592077934, 10.673116001460471, 9.688830410905195, 8.733584585859575, 7.724038619794278, 2.968873187010081, 1.9174192560578092, 0.9680627968784563, 1.934913724104424, 2.8905718603639783, 3.8728254684557024, 4.937925175442787, 5.873449080278217, 6.853717747845902, 7.877066176543161, 8.894979993377286, 9.933940996614838, 10.91351414225676, 11.840014920779195, 11.61742645518924, 10.689976569135656, 9.755962757721404, 8.79036649164935, 7.745176049187386, 6.755997891995568, 3.9722231801867314, 2.91614719032298, 1.915525288669342, 2.9096014823928265, 3.8355434112478215, 4.81681441982619, 5.753103543635759, 6.784204992441845, 7.773431433873204, 8.703269269094413, 9.768978813817386, 10.714969003232953, 11.722311882039604, 11.719754694504669, 10.778600228223725, 9.850973258714518, 8.841048145659355, 7.860286471504013, 6.79262151564685, 5.761987952508652, 4.8077029541815035, 3.8609553601951503, 2.9523619515379926, 3.949002954668392, 4.878721110364885, 5.807086576694704, 6.785873310993546, 7.745157824752803, 8.764156302574438, 9.704847367204874, 10.684790156770527, 11.680129490999207, 11.833202935845355, 10.78496628549573, 9.792594353985649, 8.84285060481687, 7.852073484698951, 6.90373177404605, 5.886061763003645, 4.88465127124931, 5.739200564459298, 4.870807913764845, 4.008495860449615, 5.005455841910506, 5.901736603932667, 6.860972481727117, 7.787861603406579, 8.676529460227746, 9.747697311353587, 10.690423464180512, 11.710124039775877, 11.856596460229428, 10.82520425005957, 9.817211491851898, 8.854664910816954, 7.900040144181602, 6.898530449896699, 5.933717675558668, 4.931409174603861, 3.9138433671161077, 6.805515615092865, 5.907006347249752, 4.976981499883799, 5.911093264306177, 6.873363434285219, 7.811200374410241, 8.781334561878671, 9.67130074322749, 10.686714592991617, 11.702492747324, 11.913815901864751, 10.874116199633637, 9.910156931834694, 8.955947500508033, 7.909946387456779, 6.947698712396589, 5.896857103550563, 4.920749973427455, 3.98633171859436, 2.9884853847049158, 7.857888296333753, 6.957257697015113, 5.962140134584493, 6.843691873078166, 7.848535706233453, 8.768525533863077, 9.72660277030085, 10.668468212191355, 11.61770331620653, 12.558475323144775, 12.75339481885907, 11.82554986944143, 10.857471060387857, 9.819713827827954, 8.86552666048548, 7.836634520370695, 6.843615476542649, 5.865796317670512, 4.89057242125469, 3.866095381806474, 8.8374446784202, 7.944870435815444, 6.992413788461433, 7.915185508302464, 8.818270691224555, 9.707975376677478, 10.665353952756156, 11.694311709886641, 12.645220171502066, 13.488435304037912, 13.670382713642248, 12.62394026590521, 11.664994793111978, 10.7079495187734, 9.772152331189325, 8.814454670582688, 7.774836787534965, 6.766666629068379, 5.8172186067785745, 4.888789042668255, 9.817711072297316, 9.017179920156543, 8.063307213992992, 8.873849456802539, 9.834879815816972, 10.705821896241163, 11.666453903423669, 12.615463305175208, 13.620930203853096, 14.512544591137097, 14.566179370665512, 13.604315398764273, 12.715270502517921, 11.752877733629482, 10.738625311592672, 9.747502902578303, 8.789124766948609, 7.781290127239211, 6.7796507394015, 5.919007314755158, 10.75851161460022, 9.964570295748908, 8.996614176393187, 9.846859525792778, 10.840848143427646, 11.759512877549033, 12.680938729411379, 13.612399424021245, 14.613242230220827, 15.563363359392454, 15.51272295237896, 14.571830951320905, 13.725895246712735, 12.743457174722579, 11.73338743421806, 10.706357435080639, 9.769978936458545, 8.778653688818657, 7.843013964713635, 6.95740065965039, 11.831083623614335, 10.982073388742336, 9.926415649797951, 10.86402586962514, 11.822161272402788, 12.812082740193942, 13.612914865516434, 14.602149415589997, 15.673322258178377, 16.601473440657408, 16.386976570333715, 15.37710590267644, 14.396997069349155, 13.58713224122612, 12.59501381658352, 11.649634737813745, 10.720241139491417, 9.790604829010112, 8.889628466049881, 7.954954037484016, 12.80835831979194, 11.814833141271723, 10.877679828027482, 11.859017769501799, 12.822682361778032, 13.764127178839464, 14.633911096080647, 15.541930934462085, 16.47897220771102, 16.368511257884222, 15.40686483695286, 14.423943080724316, 13.436334263444031, 12.571980465798118, 11.66732638460397, 10.806161957537906, 9.987159199621713, 9.097895054124088, 9.648252573384346, 8.695140785771667, 13.744399403885007, 12.762223649209057, 11.920645593916609, 12.920197249424834, 13.840201184008308, 14.7016829116053, 15.693140778427361, 16.50601251812909, 16.39030524819312, 15.411700139341384, 14.575200517126117, 13.531840537276803, 12.507631292149888, 11.573108386893619, 10.684214484816302, 9.832170327587207, 8.950840878013034, 8.061528925324088, 8.825853558479519, 9.646826433308517], [9.785621816248069, 8.79765785546424, 8.013090407227827, 7.004108819854244, 7.776489101359969, 8.711094834009423, 9.586246831739338, 10.552248323411243, 11.571477813659847, 12.51019256631156, 13.438932040835507, 14.396364103594614, 15.469308579748166, 15.67419653765692, 14.75198986554813, 13.942185189111832, 13.121094301506398, 13.887342843809957, 14.734055580933148, 15.628112871099525, 8.783158489100787, 7.853102045914327, 6.976784586567847, 6.036438776305773, 6.84733488785337, 7.770895507755493, 8.631470456852277, 9.659859108014762, 10.674696620429524, 11.679530416868843, 12.679678176138545, 13.672317638889211, 14.620511986835528, 15.625566986289957, 15.760246025579455, 14.906941812510446, 14.081142077228789, 14.867795267515866, 15.506397400320298, 14.609463530368018, 7.920665083638409, 6.920070452443057, 5.927799545699363, 5.015984029337097, 5.901681662291171, 6.805073934052989, 7.669178449229228, 8.713289593549382, 9.672107830109272, 10.712795382307014, 11.752444342518642, 12.765062902678768, 13.684116104976866, 14.61662546474915, 15.55792580946152, 15.93736858307921, 15.052191623992615, 15.487414364427506, 14.54790190724534, 13.650195744960937, 7.008071982643967, 5.96231610154887, 4.9905881817661495, 4.005412043960829, 4.883057862699361, 5.827431331020741, 6.729243404035078, 7.758876976059393, 8.742684946742287, 9.728813248079216, 10.686194319460594, 11.713835112575966, 12.698549922058103, 13.674289426988553, 14.646792855150888, 15.617453861011201, 15.64960032254289, 14.635367316073397, 13.619417824169037, 12.67945196374098, 6.019068814235733, 4.969870086900462, 4.012815392399801, 2.966729337322808, 3.897424471022154, 4.824607033348434, 5.754284922921952, 6.7931242077411635, 7.746979835870125, 8.720449378395873, 9.785150789010045, 10.788433982498699, 11.75495071472351, 12.695684576305975, 13.690277842659526, 14.654114701935752, 14.693450809516163, 13.70362375093822, 12.672391594350703, 11.72817854419841, 4.980766841502351, 3.9626918105826743, 3.0197652812594624, 2.017247560321029, 2.9378927926656586, 3.946667128921341, 4.914473859030985, 5.9468644053922946, 6.958463718963113, 7.926569797544788, 8.930444800984707, 9.874639879916526, 10.886014102108842, 11.87061163834733, 12.846971749656815, 13.790129795931703, 13.652048356671889, 12.667609312091988, 11.67126197079794, 10.670621807565482, 3.938652456524921, 2.9986955969161166, 2.027501582197422, 1.0089599531222053, 1.971953316877549, 2.9794208039297416, 3.961334123522484, 4.961770230603698, 5.916185156930502, 6.940396329058027, 8.012060144053912, 8.978457026134846, 9.992830095786827, 10.97201089487098, 11.903319415055435, 12.95602224048312, 12.577470184659044, 11.634643844284188, 10.629974346363968, 9.700908517839435, 3.0884596924062055, 2.0153378260921513, 1.0520051177885215, 0.0, 0.9979472831897175, 1.9376835446005154, 2.977155995729259, 4.004957277736806, 4.963241346172876, 6.02346508663847, 7.03321525044029, 8.009412006657909, 9.007566730942756, 9.945771365717869, 11.009115249343612, 12.028898433040787, 11.661332980720612, 10.677047390165336, 9.721801565119716, 8.712255599054421, 3.992600067864042, 2.9362945008248476, 1.9562797761386, 0.9894288489126323, 1.9237709416056443, 2.9060245496973685, 3.9571561193216853, 4.892680024157116, 5.872948691724801, 6.89629712042206, 7.914210937256184, 8.953171940493737, 9.93274508613566, 10.859245864658094, 11.813986519667674, 11.6781935483958, 10.744179736981549, 9.778583470909494, 8.73339302844753, 7.7442148712557115, 4.960440159446875, 3.9043641695831237, 2.9037422679294855, 2.0361713874632916, 2.8687424924894875, 3.850013501067856, 4.7863026248774245, 5.817404073683511, 6.806630515114869, 7.736468350336078, 8.80217789505905, 9.748168084474617, 10.755510963281267, 11.825508676482674, 11.766817207483868, 10.83919023797466, 9.829265124919498, 8.848503450764156, 7.780838494906994, 6.7502049317687955, 5.795919933441647, 4.849172339455294, 3.9405789307981363, 3.075572859738857, 3.9119201916065514, 4.840285657936371, 5.819072392235212, 6.778356905994468, 7.797355383816104, 8.73804644844654, 9.717989238012192, 10.71332857224087, 11.705849426997672, 11.836971403284252, 10.84459947177417, 9.894855722605392, 8.904078602487472, 7.9557368918345714, 6.938066880792166, 5.936656389037831, 6.727417543719442, 5.859024893024989, 4.996712839709758, 4.132025746980971, 4.9349356851743345, 5.894171562968783, 6.821060684648245, 7.709728541469412, 8.780896392595253, 9.723622545422177, 10.743323121017543, 11.66754736774762, 11.877209367848092, 10.86921660964042, 9.906670028605475, 8.952045261970124, 7.95053556768522, 6.98572279334719, 5.983414292392383, 4.96584848490463, 7.793732594353009, 6.895223326509895, 5.965198479143941, 5.10496205296122, 5.906562515526886, 6.8443994556519065, 7.8145336431203365, 8.704499824469156, 9.719913674233283, 10.735691828565665, 11.668493706225904, 11.926121317422158, 10.962162049623215, 10.007952618296555, 8.9619515052453, 7.99970383018511, 6.948862221339084, 5.972755091215976, 5.038336836382881, 4.040490502493437, 8.846105275593896, 7.945474676275257, 6.950357113844635, 6.03756066173321, 6.91729270789175, 7.801724615104742, 8.759801851542516, 9.70166729343302, 10.650902397448196, 11.59167440438644, 12.636387728507934, 12.877554987229951, 11.909476178176378, 10.871718945616475, 9.917531778274002, 8.888639638159216, 7.89562059433117, 6.917801435459033, 5.92885513146997, 4.904378092021753, 9.825661657680342, 8.933087415075587, 7.980630767721576, 7.109054296957508, 7.887027692882852, 8.741174457919143, 9.698553033997822, 10.727510791128307, 11.678419252743732, 12.521634385279578, 13.565663257509641, 13.675945383693731, 12.7169999109005, 11.759954636561922, 10.824157448977846, 9.866459788371209, 8.826841905323487, 7.804949339283658, 6.855501316993854, 5.927071752883534, 10.805928051557459, 10.005396899416686, 9.038959077721612, 8.067718245457582, 8.90363681747527, 9.739020977482829, 10.699652984665335, 11.648662386416873, 12.654129285094761, 13.545743672378762, 14.596907612652544, 14.656320516552794, 13.767275620306442, 12.804882851418004, 11.790630429381194, 10.799508020366824, 9.841129884737132, 8.81957283745449, 7.817933449616779, 6.957290024970437, 11.746728593860363, 10.940222159477528, 9.972266040121808, 9.040728314447822, 9.941067636231315, 10.792711958790699, 11.714137810653044, 12.64559850526291, 13.646441311462493, 14.59656244063412, 15.543451194365991, 15.318129116859327, 14.430400500238385, 13.524574971055777, 12.591350424568576, 11.75836255286916, 10.808261646673825, 9.816936399033938, 8.881296674928915, 7.995683369865669, 12.819300602874478, 11.957725252470958, 10.902067513526571, 10.057894658280183, 10.98341792037259, 11.845281821435607, 12.6461139467581, 13.635348496831663, 14.706521339420043, 15.634672521899072, 15.358935580406817, 14.34906491274954, 13.368956079422254, 12.56995476602026, 11.650142755866836, 10.71130254875648, 10.021445058967803, 10.828887539225393, 9.92791117626516, 8.993236747699296, 13.796575299052083, 12.790485005000344, 11.853331691756102, 11.052886558156843, 11.983939009747834, 12.79732626008113, 13.667110177322312, 14.57513001570375, 15.512171288952686, 15.340470267957325, 14.37882384702596, 13.395902090797415, 12.408293273517131, 11.54393947587122, 10.63928539467707, 9.778120967611006, 9.08078014186713, 10.044265682904834, 10.686535283599625, 9.733423495986946, 14.73261638314515, 13.737875512937677, 12.896297457645229, 12.114066038079878, 13.00145783197811, 13.734881992846965, 14.726339859669027, 15.539211599370754, 15.362264258266224, 14.383659149414488, 13.54715952719922, 12.503799547349907, 11.47959030222299, 10.54506739696672, 9.656173494889403, 8.804129337660306, 8.044461820258451, 9.024769412767494, 9.864136268694798, 10.685109143523796], [10.754511859058798, 9.76654789827497, 8.854840667117887, 7.795295082333188, 6.855777700735353, 7.790383433384806, 8.665535431114721, 9.631536922786626, 10.650766413035228, 11.58948116568694, 12.518220640210888, 13.475652702969995, 14.548597179123547, 14.676249254467203, 13.754042582358412, 12.944237905922114, 13.868032143103973, 14.634280685407532, 15.480993422530723, 16.43508905582416, 9.752048531911516, 8.821992088725056, 7.849351509232717, 6.909005698970643, 5.926623487228754, 6.850184107130877, 7.71075905622766, 8.739147707390146, 9.753985219804907, 10.758819016244226, 11.758966775513928, 12.751606238264594, 13.69980058621091, 14.70485558566534, 14.762298742389738, 13.908994529320728, 14.828079918826363, 15.614733109113441, 16.398450346083145, 15.501516476130867, 8.899561717406991, 7.8989670862116395, 6.881111035169171, 5.902069652170636, 4.980970261666555, 5.884362533428373, 6.748467048604612, 7.792578192924765, 8.751396429484656, 9.792083981682397, 10.831732941894026, 11.844351502054153, 12.763404704352249, 13.695914064124533, 14.637214408836902, 14.93942129988949, 15.79912946559019, 16.379467310190357, 15.439954853008189, 14.542248690723786, 7.98696861641255, 6.941212735317452, 5.943899671235958, 4.891497666794368, 3.9623464620747453, 4.906719930396125, 5.808532003410462, 6.838165575434777, 7.821973546117672, 8.808101847454601, 9.765482918835978, 10.79312371195135, 11.777838521433486, 12.753578026363936, 13.726081454526271, 14.696742460386584, 15.749427446536606, 15.527420261836246, 14.511470769931886, 13.57150490950383, 6.997965448004315, 5.948766720669044, 4.970927641583237, 3.907408204096885, 2.9767130703975386, 3.9038956327238177, 4.833573522297336, 5.872412807116547, 6.826268435245508, 7.799737977771256, 8.864439388385428, 9.867722581874082, 10.834239314098893, 11.774973175681358, 12.76956644203491, 13.733403301311135, 14.765197178497688, 14.59567669670107, 13.564444540113552, 12.62023148996126, 5.9680264151710745, 4.949951384251397, 4.007024854928186, 3.0045071339897524, 1.9991656388236947, 2.9487198457316235, 3.916526575841268, 4.948917122202578, 5.960516435773394, 6.92862251435507, 7.932497517794991, 8.876692596726809, 9.888066818919125, 10.872664355157614, 11.849024466467098, 12.792182512741986, 13.851030314563086, 13.559662257854837, 12.563314916560788, 11.56267475332833, 4.925912030193644, 3.9859551705848397, 3.014761155866145, 1.9962195267909286, 1.033226163035585, 1.9814735207400243, 2.963386840332767, 3.9638229474139806, 4.918237873740784, 5.942449045868309, 7.014112860864194, 7.980509742945128, 8.994882812597108, 9.974063611681261, 10.905372131865716, 11.958074957293402, 12.945084352473405, 12.526696790047037, 11.522027292126817, 10.592961463602284, 4.0864069755959225, 3.0132851092818687, 2.049952400978239, 0.9979472831897175, 0.0, 0.9397362614107979, 1.979208712539541, 3.0070099945470883, 3.9652940629831583, 5.025517803448752, 6.035267967250572, 7.011464723468191, 8.009619447753037, 8.94782408252815, 10.011167966153893, 11.030951149851068, 11.978371069169937, 11.569100335928185, 10.613854510882565, 9.60430854481727, 4.884653013626891, 3.8283474465876965, 2.848332721901449, 1.8814817946754814, 0.925823658415927, 1.908077266507651, 2.9592088361319675, 3.8947327409673975, 4.875001408535082, 5.898349837232341, 6.916263654066466, 7.955224657304018, 8.934797802945939, 9.861298581468374, 10.816039236477954, 11.743489122531537, 11.636232682744398, 10.670636416672343, 9.625445974210379, 8.63626781701856, 5.852493105209724, 4.796417115345973, 3.7957952136923345, 2.81366453997203, 1.8707952092997702, 2.8520662178781384, 3.788355341687707, 4.819456790493793, 5.808683231925151, 6.73852106714636, 7.8042306118693325, 8.7502208012849, 9.75756368009155, 10.827561393292957, 11.82898173142225, 11.731243183737512, 10.721318070682349, 9.740556396527007, 8.672891440669844, 7.6422578775316445, 6.687972879204496, 5.741225285218143, 4.832631876560985, 3.8530660122475955, 2.9139729084168335, 3.842338374746653, 4.821125109045495, 5.7804096228047515, 6.799408100626387, 7.740099165256821, 8.720041954822475, 9.715381289051154, 10.707902143807955, 11.762349802301895, 11.842546754963887, 10.892803005795109, 9.902025885677189, 8.874314799067562, 7.856644788025156, 6.8552342962708215, 7.619470489482291, 6.751077838787838, 5.888765785472606, 4.90951889948971, 3.936988401984616, 4.896224279779066, 5.823113401458528, 6.711781258279695, 7.782949109405536, 8.72567526223246, 9.745375837827826, 10.669600084557903, 11.70099229472776, 11.867163892830137, 10.904617311795192, 9.94999254515984, 8.948482850874937, 7.921289095743215, 6.901992199625373, 5.88442639213762, 8.685785540115859, 7.787276272272744, 6.816566969892337, 5.882455205469959, 4.908615232337168, 5.84645217246219, 6.81658635993062, 7.706552541279439, 8.721966391043566, 9.737744545375948, 10.670546423036187, 11.694086142439767, 11.960109332812932, 11.005899901486272, 9.959898788435018, 8.997651113374827, 7.946809504528801, 6.970702374405693, 6.036284119572598, 5.038437785683154, 9.738158221356747, 8.837527622038106, 7.801725604593031, 6.8150538142419474, 5.9193454247020325, 6.803777331915025, 7.761854568352798, 8.703720010243304, 9.652955114258479, 10.593727121196723, 11.638440445318217, 12.566285394735857, 12.907423461366095, 11.869666228806192, 10.915479061463719, 9.886586921348933, 8.893567877520887, 7.91574871864875, 6.916114705138693, 5.891637665690476, 10.717714603443193, 9.825140360838436, 8.83199925846997, 7.855992138555082, 6.889080409693134, 7.743227174729427, 8.700605750808105, 9.72956350793859, 10.680471969554015, 11.52368710208986, 12.567715974319924, 13.537954137750823, 13.714947194090216, 12.757901919751639, 11.822104732167563, 10.864407071560926, 9.824789188513204, 8.79220891295238, 7.842760890662577, 6.914331326552257, 11.69798099732031, 10.847910959531585, 9.785896919319187, 8.814656087055157, 7.905689534285552, 8.741073694293112, 9.701705701475618, 10.650715103227157, 11.656182001905044, 12.547796389189045, 13.598960329462827, 14.518329270609886, 14.520313843808584, 13.623674406715867, 12.683234915154719, 11.797455303556541, 10.839077167926849, 9.806832411123214, 8.805193023285502, 7.94454959863916, 12.638781539623213, 11.687160001075103, 10.719203881719382, 9.787666156045397, 8.943120353041596, 9.794764675600982, 10.716190527463327, 11.647651222073193, 12.648494028272776, 13.598615157444403, 14.545503911176274, 14.397417716234711, 13.50968909961377, 12.60386357043116, 11.67063902394396, 10.841031847994337, 11.71927144069561, 10.804195972702662, 9.868556248597638, 8.982942943534393, 13.711353548637328, 12.704663094068533, 11.649005355124146, 10.804832499877758, 9.985470637182871, 10.84733453824589, 11.648166663568382, 12.637401213641946, 13.708574056230326, 14.636725238709355, 14.438224179782202, 13.428353512124925, 12.44824467879764, 11.649243365395643, 10.72943135524222, 9.790591148131863, 10.719984746454191, 11.649621056935496, 10.906807810033742, 9.972133381467877, 14.560414006085578, 13.537422846597918, 12.600269533353677, 11.799824399754417, 10.985991726558115, 11.799378976891413, 12.669162894132596, 13.577182732514034, 14.51422400576297, 14.419758867332707, 13.458112446401344, 12.4751906901728, 11.487581872892516, 10.623228075246603, 9.718573994052454, 8.857409566986389, 9.818589173046714, 10.782074714084418, 11.655425326410354, 10.702313538797675, 15.496455090178644, 14.484813354535252, 13.643235299242804, 12.861003879677453, 12.003510548788391, 12.736934709657248, 13.72839257647931, 14.541264316181037, 14.441552857641605, 13.462947748789869, 12.626448126574601, 11.583088146725288, 10.558878901598373, 9.624355996342103, 8.735462094264786, 7.88341793703569, 8.835648082737396, 9.815955675246439, 10.830144609960646, 11.653999186334525], [11.694248120469597, 10.706284159685769, 9.794576928528684, 8.735031343743985, 7.795513962146151, 6.908817288145129, 7.770467573626082, 8.736469065297987, 9.75569855554659, 10.694413308198303, 11.62315278272225, 12.580584845481358, 13.65352932163491, 13.901095954009032, 12.994386415734336, 13.883974167332912, 14.80776840451477, 15.574016946818329, 16.42072968394152, 17.37482531723496, 10.691784793322315, 9.761728350135854, 8.789087770643516, 7.848741960381441, 6.866359748639552, 5.9686179618912005, 6.815691198739022, 7.844079849901507, 8.858917362316268, 9.863751158755587, 10.863898918025289, 11.856538380775955, 12.804732728722271, 13.804451472297236, 14.002642575765663, 14.848730790731526, 15.76781618023716, 16.554469370524238, 17.33818660749394, 16.441252737541664, 9.839297978817788, 8.838703347622436, 7.82084729657997, 6.841805913581434, 5.920706523077353, 5.002796388188696, 5.853399191115973, 6.8975103354361265, 7.856328571996016, 8.897016124193758, 9.936665084405389, 10.924607292116805, 11.833514664643856, 12.76602402441614, 13.707324369128509, 14.716541282490125, 15.779998182755984, 16.790869925381415, 16.379691114418986, 15.481984952134583, 8.926704877823347, 7.88094899672825, 6.883635932646757, 5.831233928205167, 4.9020827234855435, 4.025153785156449, 4.913464145921823, 5.943097717946139, 6.926905688629033, 7.913033989965963, 8.870415061347341, 9.873379502014004, 10.847948481725092, 11.823687986655543, 12.796191414817878, 13.766852420678191, 14.819537406828212, 15.814918559614446, 15.451207031342683, 14.511241170914627, 7.937701709415113, 6.888502982079842, 5.910663902994035, 4.847144465507683, 3.916449331808337, 3.022329487484141, 3.9385056648086985, 4.977344949627909, 5.93120057775687, 6.904670120282619, 7.9345493486770335, 8.937832542165689, 9.9043492743905, 10.845083135972965, 11.839676402326516, 12.803513261602742, 13.835307138789295, 14.883174994479269, 14.504180801524349, 13.559967751372056, 6.907762676581872, 5.889687645662195, 4.946761116338983, 3.9442433954005502, 2.9389019002344927, 2.0089835843208257, 2.9767903144304704, 4.00918086079178, 5.020780174362597, 5.988886252944273, 6.992761256384193, 7.936956335316012, 8.948330557508328, 9.932928093746817, 10.909288205056301, 11.85244625133119, 12.91129405315229, 13.976168292463807, 13.503051177971585, 12.502411014739128, 5.865648291604442, 4.925691431995638, 3.9544974172769427, 2.9359557882017264, 1.9729624244463828, 1.0417372593292265, 2.023650578921969, 3.0240866860031828, 3.978501612329986, 5.002712784457511, 6.074376599453396, 7.04077348153433, 8.055146551186311, 9.034327350270464, 9.96563587045492, 11.018338695882605, 12.005348091062608, 12.948174431437463, 12.461763553537613, 11.532697725013081, 5.026143237006721, 3.953021370692667, 2.989688662389037, 1.9376835446005154, 0.9397362614107979, 0.0, 1.0394724511287432, 2.0672737331362905, 3.0255578015723605, 4.085781542037954, 5.095531705839774, 6.0717284620573935, 7.06988318634224, 8.008087821117353, 9.071431704743096, 10.091214888440271, 11.03863480775914, 12.022920398314415, 11.553590772293362, 10.544044806228067, 5.824389275037689, 4.768083707998494, 3.7880689833122467, 2.821218056086279, 1.8655599198267248, 1.03657082876404, 2.0194725747211697, 2.9549964795565997, 3.935265147124285, 4.958613575821543, 5.976527392655668, 7.01548839589322, 7.995061541535141, 8.921562320057577, 9.876302975067157, 10.80375286112074, 11.737766672534992, 11.61037267808314, 10.565182235621176, 9.576004078429357, 6.792229366620521, 5.73615337675677, 4.735531475103132, 3.7534008013828277, 2.810531470710568, 2.014812427811898, 2.9511015516214667, 3.9095380064033614, 4.8816496875945266, 5.811487522815735, 6.877197067538708, 7.823187256954276, 8.830530135760927, 9.900527848962334, 10.901948187091627, 11.802107931380514, 11.661054332093146, 10.680292657937803, 9.61262770208064, 8.581994138942441, 7.627709140615293, 6.68096154662894, 5.772368137971783, 4.792802273658394, 3.8537091698276313, 3.082682208122578, 3.9838713189792543, 4.943155832738511, 5.935671718598188, 6.813065620926197, 7.793008410491851, 8.78834774472053, 9.780868599477332, 10.835316257971272, 11.827688189481353, 11.832539267205908, 10.841762147087987, 9.81405106047836, 8.796381049435954, 7.794970557681618, 8.559206750893088, 7.690814100198635, 6.828502046883404, 5.8492551609005075, 4.876724663395414, 4.13656811315499, 4.9858596113922875, 5.874527468213454, 6.945695319339295, 7.798641717901836, 8.818342293497201, 9.74256654022728, 10.773958750397137, 11.78195150860481, 11.844353573205991, 10.88972880657064, 9.888219112285736, 8.861025357154013, 7.84172846103617, 6.824162653548417, 9.625521801526656, 8.72701253368354, 7.756303231303135, 6.822191466880756, 5.848351493747966, 5.086796005838114, 6.0372020963147035, 6.869298751213199, 7.884712600977325, 8.82204204762758, 9.754843925287819, 10.767052598109144, 11.69917687373969, 11.94563616289707, 10.899635049845816, 9.937387374785626, 8.8865457659396, 7.910438635816492, 6.976020380983397, 5.978174047093953, 10.677894482767543, 9.777263883448903, 8.74146186600383, 7.754790075652746, 6.85908168611283, 6.0441211652909494, 6.982470304736882, 7.866466220177063, 8.815701324192238, 9.756473331130483, 10.722737947569849, 11.650582896987489, 12.646491002292853, 12.809402490216991, 11.855215322874518, 10.826323182759733, 9.833304138931686, 8.855484980059549, 7.85585096654949, 6.831373927101274, 11.65745086485399, 10.764876622249233, 9.771735519880771, 8.79572839996588, 7.828816671103932, 6.983571008105351, 7.925452450349933, 8.89230971787235, 9.843218179487774, 10.68643331202362, 11.652013476571556, 12.622251640002455, 13.581197112795687, 13.697638181162437, 12.761840993578362, 11.804143332971725, 10.764525449924003, 9.73194517436318, 8.782497152073375, 7.854067587963055, 12.637717258731106, 11.787647220942382, 10.725633180729984, 9.754392348465954, 8.84542579569635, 7.981417527669036, 8.926552401017446, 9.857398239317297, 10.818928211838804, 11.710542599122805, 12.713873512998534, 13.602626772861518, 13.625245986319943, 12.728606549227228, 11.801668769915041, 12.73719156496734, 11.778813429337648, 10.746568672534012, 9.744929284696301, 8.884285860049957, 13.57851780103401, 12.6268962624859, 11.65894014313018, 10.727402417456194, 9.882856614452395, 9.035108508976906, 9.941037227005156, 10.854334358163335, 11.811240238206535, 12.761361367378163, 13.660417094711981, 13.50234985874607, 12.614621242125128, 11.708795712942521, 10.789072878704282, 11.780768109405138, 12.65900770210641, 11.743932234113458, 10.808292510008435, 9.92267920494519, 14.651089810048125, 13.64439935547933, 12.588741616534943, 11.744568761288555, 10.92520689859367, 10.087678371621815, 10.87301336311021, 11.844084349732087, 12.879469202494864, 13.807620384973893, 13.54315632229356, 12.533285654636284, 11.553176821308998, 10.754175507907004, 9.847865210002542, 10.730327409542662, 11.65972100786499, 12.589357318346295, 11.846544071444539, 10.911869642878674, 15.500150267496375, 14.477159108008715, 13.540005794764474, 12.739560661165214, 11.925727987968914, 11.039722810267337, 11.894009593674424, 12.783865868604176, 13.720907141853111, 13.52469100984407, 12.563044588912703, 11.58012283268416, 10.592514015403875, 9.728160217757964, 8.837007848812776, 9.797145828397188, 10.758325434457513, 11.721810975495217, 12.595161587821153, 11.642049800208474, 16.436191351589443, 15.424549615946049, 14.5829715606536, 13.80074014108825, 12.94324681019919, 11.977278543033172, 12.953239276021138, 13.747947452271179, 13.546485000152968, 12.567879891301232, 11.731380269085964, 10.68802028923665, 9.663811044109734, 8.729288138853464, 7.85389594902511, 8.823154198446488, 9.775384344148193, 10.755691936657236, 11.769880871371443, 12.593735447745324], [12.63508308160062, 11.647119120816791, 10.735411889659707, 9.675866304875008, 8.736348923277173, 7.8134610475743, 6.832385749856947, 7.798387241528852, 8.817616731777456, 9.756331484429168, 10.685070958953116, 11.642503021712223, 12.715447497865775, 12.93408058590224, 13.824611008309416, 14.781965343719017, 15.833378798406104, 16.613489397947074, 17.460202135070265, 18.414297768363703, 11.632619754453337, 10.702563311266877, 9.729922731774538, 8.789576921512463, 7.807194709770575, 6.87523644625091, 5.877609374969886, 6.905998026132371, 7.9208355385471325, 8.925669334986452, 9.925817094256153, 10.831514733018876, 11.779709080965192, 12.764979021168493, 13.64228153578764, 14.621007748704477, 15.660944216875714, 16.69184597021923, 17.649405424509794, 17.480725188670405, 10.78013293994881, 9.779538308753459, 8.761682257710993, 7.782640874712457, 6.8615414842083755, 5.909414872548406, 4.915317367346837, 5.9594285116669905, 6.91824674822688, 7.951385053323241, 8.93006817049265, 9.885134840988062, 10.794042213515112, 11.726551573287397, 12.667851917999766, 13.677068831361382, 14.74052573162724, 15.751397474252672, 16.690909931434838, 16.521457403263327, 9.86753983895437, 8.821783957859273, 7.82447089377778, 6.77206888933619, 5.842917684616566, 4.931772269516158, 3.9753823221526874, 5.005015894177003, 5.9479819708464925, 6.906437076053223, 7.863818147434601, 8.83390705088526, 9.80847603059635, 10.7842155355268, 11.756718963689135, 12.727379969549448, 13.78006495569947, 14.775446108485703, 15.795643776135375, 15.55071362204337, 8.878536670546135, 7.829337943210865, 6.851498864125057, 5.787979426638706, 4.85728429293936, 3.9301017306130808, 3.000423841039562, 4.039263125858772, 4.919476178215669, 5.892945720741418, 6.89507689754829, 7.898360091036945, 8.864876823261756, 9.805610684844222, 10.800203951197773, 11.764040810473999, 12.795834687660552, 13.843702543350526, 14.886237070315936, 14.5994402025008, 7.9472351277106155, 6.929160096790938, 5.9862335674677265, 4.983715846529293, 3.978374351363236, 3.0065152207709787, 2.038708490661334, 2.9937390664558885, 3.981307723233854, 4.949413801815529, 5.95328880525545, 6.8974838841872685, 7.908858106379585, 8.893455642618074, 9.869815753927558, 10.812973800202446, 11.871821602023546, 12.936695841335066, 13.9295973063125, 13.54188346586787, 6.905120742733185, 5.965163883124381, 4.993969868405686, 3.9754282393304696, 3.012434875575126, 2.0438331544247523, 1.0619198348320098, 1.9846142348744396, 2.939029161201243, 3.963240333328768, 5.034904148324653, 6.001301030405587, 7.015674100057567, 7.994854899141721, 8.926163419326176, 9.978866244753862, 10.965875639933865, 11.90870198030872, 12.888309681878528, 12.572170176141825, 6.065615688135464, 4.9924938218214105, 4.02916111351778, 2.9771559957292584, 1.979208712539541, 1.0394724511287432, 0.0, 1.0278012820075475, 1.9860853504436176, 3.0463090909092108, 4.056059254711031, 5.03225601092865, 6.030410735213497, 6.96861536998861, 8.031959253614353, 9.051742437311528, 9.999162356630396, 10.983447947185672, 11.938693772231293, 11.58351725735681, 6.863861726166432, 5.8075561591272375, 4.82754143444099, 3.8606905072150224, 2.905032370955468, 2.0450998305795114, 0.9800001235924264, 1.9155240284278565, 2.895792695995542, 3.9191411246928003, 4.937054941526925, 5.976015944764477, 6.955589090406398, 7.882089868928833, 8.836830523938414, 9.764280409991997, 10.698294221406249, 11.663890487478303, 11.60465468674992, 10.6154765295581, 7.8317018177492645, 6.775625827885513, 5.775003926231875, 4.792873252511571, 3.850003921839311, 2.9203753073242447, 1.984086183514676, 2.870065555274618, 3.842177236465784, 4.772015071686993, 5.837724616409965, 6.783714805825534, 7.791057684632185, 8.86105539783359, 9.862475735962882, 10.76263548025177, 11.672784203448419, 11.719765109066547, 10.652100153209384, 9.621466590071185, 8.667181591744036, 7.7204339977576835, 6.811840589100526, 5.832274724787137, 4.8931816209563745, 3.9882450876349247, 3.016855950872463, 3.926246672145938, 4.896199267469445, 5.773593169797454, 6.7535359593631075, 7.748875293591787, 8.741396148348588, 9.795843806842528, 10.78821573835261, 11.73795948752139, 11.88123459821673, 10.853523511607102, 9.835853500564697, 8.834443008810362, 9.598679202021831, 8.730286551327378, 7.867974498012147, 6.888727612029251, 5.916197114524158, 5.03444362194038, 4.018844243285496, 4.857618307620881, 5.928786158746722, 6.759169266773093, 7.778869842368459, 8.703094089098537, 9.734486299268394, 10.742479057476066, 11.70502563851101, 11.929201257699383, 10.927691563414479, 9.900497808282756, 8.881200912164914, 7.86363510467716, 10.664994252655397, 9.766484984812283, 8.795775682431877, 7.8616639180095, 6.887823944876709, 5.984671514623503, 5.070186728207912, 5.852389590620626, 6.867803440384753, 7.7825695964988375, 8.715371474159076, 9.7275801469804, 10.659704422610947, 11.613913853937607, 11.93910750097456, 10.976859825914369, 9.926018217068343, 8.949911086945235, 8.015492832112141, 7.017646498222696, 11.717366933896285, 10.816736334577644, 9.780934317132571, 8.79426252678149, 7.8985541372415735, 6.941996674076339, 6.015454936630091, 6.84955705958449, 7.798792163599666, 8.73956417053791, 9.683265496441106, 10.611110445858746, 11.60701855116411, 12.547153829533462, 12.89468777400326, 11.865795633888474, 10.872776590060429, 9.894957431188292, 8.895323417678235, 7.870846378230017, 12.696923315982731, 11.804349073377974, 10.811207971009512, 9.835200851094624, 8.868289122232676, 7.88144651689074, 6.958437082243142, 7.875400557279775, 8.826309018895202, 9.669524151431048, 10.612541025442813, 11.582779188873712, 12.541724661666944, 12.835452940314175, 13.65907172659781, 12.843615784100468, 11.803997901052746, 10.771417625491923, 9.821969603202119, 8.893540039091798, 13.677189709859848, 12.827119672071127, 11.765105631858729, 10.793864799594699, 9.849138904604871, 8.879293036454426, 7.959537032910656, 8.840489078724723, 9.802019051246232, 10.693633438530233, 11.67440106186979, 12.563154321732775, 12.687164162550808, 11.790524725458093, 12.692598746194463, 13.650293387690517, 12.81828588046639, 11.786041123662756, 10.784401735825044, 9.923758311178702, 14.617990252162752, 13.666368713614645, 12.698412594258924, 11.766874868584939, 10.886569723360916, 9.932984017762296, 8.974021858898364, 9.83742519757076, 10.794331077613963, 11.74445220678559, 12.620944643583238, 12.564268034976935, 11.676539418355993, 10.770713889173386, 11.680002854983703, 12.691438855188181, 13.569678447889453, 12.783404685242203, 11.84776496113718, 10.906893899148354, 15.690562261176867, 14.683871806608074, 13.628214067663688, 12.7840412124173, 11.92892000750219, 10.967550515261504, 9.90599799500342, 10.827175189139512, 11.862560041902292, 12.79071122438132, 12.605074498524425, 11.595203830867149, 10.615094997539863, 9.816093684137869, 10.738795186281964, 11.640998155325706, 12.570391753648034, 13.500028064129339, 12.787379032575561, 11.852704604009697, 16.539622718625118, 15.51663155913746, 14.579478245893219, 13.779033112293959, 12.872797220006463, 11.869947402842417, 10.926994225567633, 11.7669567080116, 12.703997981260535, 12.586609186074934, 11.624962765143568, 10.642041008915024, 9.65443219163474, 8.790078393988829, 9.727937825092198, 10.707816574180232, 11.668996180240557, 12.63248172127826, 13.535996548952175, 12.582884761339496, 17.475663802718184, 16.464022067074794, 15.622444011782346, 14.840212592216995, 13.841237986585295, 12.807503135608252, 11.986223907914347, 12.731038291678603, 12.608403176383833, 11.629798067532096, 10.793298445316829, 9.749938465467515, 8.725729220340599, 7.791206315084329, 8.74482592530453, 9.733824944229532, 10.716219305279216, 11.696526897788258, 12.710715832502466, 13.534570408876347], [13.581257338189937, 12.593293377406109, 11.681586146249026, 10.622040561464328, 9.682523179866493, 8.759635304163618, 7.7785600064462646, 7.082397603877148, 7.8573476444933394, 8.796062397145052, 9.724801871669, 10.682233934428107, 11.744230362855824, 12.671212946382145, 13.604034314759701, 14.557963090095543, 15.593190710590557, 16.555919194043987, 17.615765248456178, 18.6559879907034, 12.578794011042655, 11.648737567856195, 10.676096988363856, 9.735751178101781, 8.753368966359893, 7.821410702840229, 6.823783631559205, 6.013194405586501, 6.917583695146773, 7.922417491586092, 8.922565250855794, 9.803713451011326, 10.751907798957642, 11.737177739160945, 12.614480253780092, 13.593206466696929, 14.633142934868166, 15.664044688211682, 16.621604142502246, 17.637338649971895, 11.72630719653813, 10.725712565342779, 9.707856514300312, 8.728815131301776, 7.807715740797695, 6.855589129137725, 5.861491623936156, 5.06662489112112, 5.895406309591072, 6.923583771315693, 7.9022668884851015, 8.857333558980512, 9.766240931507564, 10.698750291279849, 11.640050635992218, 12.649267549353834, 13.712724449619692, 14.723596192245124, 15.66310864942729, 16.67855213577584, 10.81371409554369, 9.767958214448592, 8.770645150367098, 7.718243145925509, 6.789091941205886, 5.877946526105477, 4.921556578742006, 4.064844261395319, 4.920180688838945, 5.878635794045675, 6.836016865427053, 7.806105768877711, 8.780674748588801, 9.756414253519251, 10.728917681681587, 11.6995786875419, 12.752263673691921, 13.747644826478155, 14.767842494127827, 15.707808354555883, 9.824710927135454, 8.775512199800184, 7.797673120714377, 6.734153683228024, 5.803458549528679, 4.8762759872023995, 3.9465980976288813, 3.0256233874376144, 3.8916748962081216, 4.86514443873387, 5.867275615540742, 6.870558809029397, 7.837075541254208, 8.777809402836674, 9.772402669190225, 10.73623952846645, 11.768033405653004, 12.815901261342978, 13.858435788308388, 14.803876036838426, 8.97349344688112, 7.955418415961443, 7.012491886638232, 6.0099741656997985, 4.990081405776918, 3.952689477360298, 2.984882747250653, 1.9659377844483412, 2.953506441226306, 3.921612519807981, 4.925487523247901, 5.86968260217972, 6.8810568243720365, 7.865654360610526, 8.84201447192001, 9.785172518194898, 10.844020320015998, 11.908894559327518, 12.901796024304954, 13.75928751812156, 7.93137906190369, 6.991422202294886, 6.0202281875761905, 5.001686558500975, 4.0386931947456315, 2.9900074110140715, 2.008094091421329, 0.9568129528668922, 1.9112278791936954, 2.9354390513212203, 4.007102866317105, 4.973499748398039, 5.98787281805002, 6.967053617134175, 7.898362137318629, 8.951064962746313, 9.938074357926318, 10.880900698301174, 11.860508399870982, 12.789574228395514, 7.093416970143011, 6.020295103828957, 5.056962395525328, 4.004957277736806, 3.0070099945470883, 2.0672737331362905, 1.0278012820075475, 0.0, 0.9582840684360701, 2.0185078089016635, 3.028257972703484, 4.004454728921103, 5.00260945320595, 5.940814087981064, 7.004157971606807, 8.023941155303982, 8.97136107462285, 9.955646665178126, 10.910892490223747, 11.920438456289041, 7.891663008173979, 6.835357441134785, 5.855342716448537, 4.888491789222569, 3.9328336529630152, 2.97398508008681, 1.9088853730997246, 0.9733614682642946, 1.9536301358319799, 2.9769785645292384, 3.994892381363363, 5.030579593263025, 6.010152738904946, 6.905097346347573, 7.859838001357154, 8.787287887410738, 9.72130169882499, 10.686897964897044, 11.732088407359008, 11.60794969313188, 8.824174981323045, 7.7680989914592935, 6.767477089805656, 5.773400896082172, 4.8305315654099115, 3.8492605568315432, 2.9129714330219745, 1.9279029951110562, 2.900014676302222, 3.8298525115234305, 4.895562056246403, 5.841552245661972, 6.848895124468623, 7.897867055611927, 8.89710033008459, 9.785642957670511, 10.69579168086716, 11.62019586643977, 11.644573316783164, 10.613939753644965, 9.659654755317817, 8.712907161331463, 7.8043137526743065, 6.812802368357737, 5.845495803472043, 4.917130337142224, 3.943368625741633, 2.984084111982376, 3.954036707305883, 4.831430609633892, 5.811373399199546, 6.806712733428226, 7.799233588185027, 8.832655464620865, 9.825027396130947, 10.774771145299727, 11.716333253461933, 11.873988329220765, 10.85631831817836, 9.854907826424025, 10.591152365595612, 9.722759714901159, 8.860447661585928, 7.8692552555998505, 6.868511297039825, 5.96095629680955, 4.945356918154666, 3.9154557474573193, 4.98662359858316, 5.817006706609531, 6.836707282204897, 7.760931528934975, 8.792323739104832, 9.800316497312505, 10.762863078347449, 11.7174878449828, 11.955492845422025, 10.928299090290304, 9.909002194172462, 8.891436386684708, 11.657467416229178, 10.758958148386064, 9.776303326002477, 8.8421915615801, 7.838503049768997, 6.875160371709308, 5.905026184240878, 4.910227030457063, 5.92564088022119, 6.840407036335275, 7.773208913995513, 8.78541758681684, 9.717541862447385, 10.671751293774046, 11.7177524068253, 12.004661107921915, 10.95381949907589, 9.977712368952782, 9.043294114119687, 8.045447780230242, 12.709840097470066, 11.809209498151425, 10.761461960703171, 9.77479017035209, 8.849233242133861, 7.832485531162144, 6.850294392663057, 5.907394499420928, 6.856629603436103, 7.797401610374346, 8.741102936277542, 9.668947885695182, 10.664855991000548, 11.6049912693699, 12.559178436712374, 12.893596915896023, 11.900577872067975, 10.922758713195838, 9.921581736848738, 8.897104697400522, 13.689396479556512, 12.796822236951755, 11.791735614580112, 10.755799144645525, 9.788887415783577, 8.750655114354787, 7.793276538276108, 6.933237997116214, 7.88414645873164, 8.727361591267485, 9.67037846527925, 10.640616628710148, 11.59956210150338, 12.556607375841958, 13.492404563426033, 13.871417066108014, 12.831799183060292, 11.797675944662426, 10.848227922372622, 9.919798358262303, 14.669662873433628, 13.747717965622028, 12.68570392540963, 11.7144630931456, 10.718347502068918, 9.748501633918472, 8.794376488943621, 7.89832651856116, 8.85985649108267, 9.75147087836667, 10.732238501706227, 11.620991761569211, 11.971174524899105, 12.736698982047411, 13.63877300278378, 14.596467644279834, 13.846087162473937, 12.81229944283326, 11.810660054995548, 10.895497302826017, 15.551398982077762, 14.586967007165546, 13.619010887809825, 12.68747316213584, 11.755778320824962, 10.802192615226343, 9.808861314931331, 8.895262637407198, 9.852168517450401, 10.802289646622027, 11.678782083419675, 11.833944632800025, 10.96054978070429, 11.716888145762704, 12.626177111573021, 13.637613111777497, 14.515852704478771, 13.809663004412705, 12.874023280307682, 11.853068155737674, 16.623970991091877, 15.604470100158974, 14.548812361214589, 13.704639505968201, 12.798128604966237, 11.80238997129447, 10.740837451036386, 9.88501262897595, 10.92039748173873, 11.848548664217759, 11.768178875046823, 10.864880428690238, 9.89910535988816, 10.762267940727186, 11.684969442871282, 12.587172411915024, 13.516566010237351, 14.446202320718657, 13.733553289164881, 12.798878860599016, 17.46022101217602, 16.43722985268836, 15.50007653944412, 14.69963140584486, 13.70763667603943, 12.704786858875384, 11.7618336816006, 10.824794147848039, 11.761835421096974, 11.62634009879082, 10.779347428784265, 9.859376734400099, 8.938442553983037, 9.736252650578146, 10.674112081681516, 11.65399083076955, 12.615170436829874, 13.578655977867578, 14.482170805541493, 13.529059017928814, 18.396262096269087, 17.384620360625693, 16.54304230533325, 15.750885681019641, 14.676077442618261, 13.642342591641219, 12.821063363947314, 11.788875731515041, 11.648134089099717, 10.66952898024798, 9.833029358032713, 8.7896693781834, 8.009739582688894, 8.737380571673647, 9.691000181893848, 10.67999920081885, 11.662393561868535, 12.642701154377578, 13.656890089091785, 14.480744665465664], [14.539541406626007, 13.55157744584218, 12.639870214685097, 11.580324629900398, 10.640807248302563, 9.717919372599688, 8.736844074882335, 7.91171319047092, 6.899063576057269, 7.837778328708982, 8.76651780323293, 9.723949865992036, 10.785946294419753, 11.712928877946075, 12.645750246323631, 13.599679021659473, 14.634906642154487, 15.597635125607917, 16.657481180020106, 17.69770392226733, 13.537078079478725, 12.607021636292265, 11.634381056799926, 10.694035246537851, 9.711653034795964, 8.779694771276299, 7.782067699995275, 6.842509992180273, 5.959299626710703, 6.964133423150022, 7.964281182419724, 8.845429382575256, 9.793623730521572, 10.778893670724875, 11.656196185344022, 12.634922398260859, 13.674858866432096, 14.705760619775614, 15.663320074066178, 16.679054581535823, 12.6845912649742, 11.683996633778849, 10.666140582736384, 9.687099199737846, 8.765999809233765, 7.813873197573795, 6.819775692372226, 5.895940477714892, 4.937122241155002, 5.965299702879623, 6.9439828200490314, 7.899049490544442, 8.807956863071492, 9.740466222843779, 10.681766567556148, 11.690983480917764, 12.754440381183622, 13.765312123809053, 14.70482458099122, 15.72026806733977, 11.77199816397976, 10.726242282884662, 9.72892921880317, 8.67652721436158, 7.747376009641956, 6.836230594541547, 5.879840647178076, 4.926467329858717, 3.9618966204028747, 4.9203517256096045, 5.8777327969909825, 6.847821700441641, 7.82239068015273, 8.798130185083181, 9.770633613245517, 10.74129461910583, 11.793979605255851, 12.789360758042084, 13.809558425691757, 14.749524286119813, 10.782994995571524, 9.733796268236254, 8.755957189150447, 7.6924377516640945, 6.761742617964749, 5.83456005563847, 4.904882166064951, 3.887246455901013, 2.9333908277720515, 3.9068603702977995, 4.908991547104672, 5.912274740593327, 6.878791472818138, 7.819525334400605, 8.814118600754155, 9.77795546003038, 10.809749337216934, 11.857617192906908, 12.900151719872317, 13.845591968402356, 9.93177751531719, 8.913702484397513, 7.970775955074302, 6.9682582341358685, 5.948365474212987, 4.9109735457963675, 3.9431668156867232, 2.9242218528844113, 1.995222372790236, 2.963328451371911, 3.9672034548118313, 4.91139853374365, 5.922772755935966, 6.9073702921744555, 7.8837304034839395, 8.826888449758828, 9.885736251579928, 10.950610490891446, 11.943511955868884, 12.80100344968549, 8.88966313033976, 7.949706270730956, 6.9785122560122606, 5.959970626937045, 4.9969772631817015, 3.9482914794501416, 2.966378159857399, 1.9150970213029623, 0.9529438107576255, 1.9771549828851502, 3.048818797881035, 4.015215679961969, 5.02958874961395, 6.008769548698105, 6.940078068882559, 7.992780894310243, 8.979790289490248, 9.922616629865104, 10.902224331434912, 11.831290159959444, 8.05170103857908, 6.978579172265027, 6.015246463961398, 4.963241346172876, 3.9652940629831583, 3.0255578015723605, 1.9860853504436176, 0.9582840684360701, 0.0, 1.0602237404655932, 2.0699739042674135, 3.046170660485033, 4.04432538476988, 4.982530019544994, 6.045873903170737, 7.065657086867912, 8.01307700618678, 8.997362596742056, 9.952608421787676, 10.962154387852973, 8.84994707661005, 7.793641509570856, 6.813626784884608, 5.84677585765864, 4.891117721399086, 3.93226914852288, 2.8671694415357947, 1.9316455367003647, 1.0021082496533715, 2.02545667835063, 3.043370495184755, 4.072295524826955, 5.051868670468876, 5.946813277911503, 6.901553932921084, 7.829003818974668, 8.76301763038892, 9.728613896460974, 10.773804338922938, 11.814510795986774, 9.782459049759115, 8.726383059895364, 7.725761158241726, 6.731684964518242, 5.7888156338459815, 4.807544625267614, 3.8712555014580445, 2.8861870635471263, 1.9484927901236135, 2.878330625344822, 3.9440401700677947, 4.890030359483363, 5.897373238290014, 6.939582987175857, 7.938816261648521, 8.827358889234441, 9.73750761243109, 10.6619117980037, 11.726358872463473, 11.572223822081035, 10.617938823753887, 9.671191229767533, 8.762597821110376, 7.771086436793807, 6.803779871908113, 5.875414405578294, 4.901652694177703, 3.942368180418446, 3.0025148211272747, 3.8799087234552836, 4.859851513020937, 5.855190847249617, 6.847711702006418, 7.874371396184794, 8.866743327694875, 9.816487076863655, 10.758049185025865, 11.722396794460789, 11.814602386614432, 10.813191894860097, 11.549436434031682, 10.681043783337229, 9.818731730021998, 8.827539324035921, 7.8267953654758955, 6.91924036524562, 5.903640986590736, 4.873739815893389, 4.068549517017953, 4.865484820430923, 5.885185396026288, 6.809409642756366, 7.840801852926223, 8.845044855811173, 9.807591436846117, 10.762216203481469, 11.711592219828116, 11.886583158726372, 10.86728626260853, 9.849720455120778, 11.893138667104262, 11.717242216822134, 10.734587394438547, 9.80047563001617, 8.796787118205067, 7.833444440145378, 6.863310252676948, 5.8685110988931335, 5.025812030503339, 5.888885150156667, 6.821687027816905, 7.83389570063823, 8.766019976268776, 9.720229407595436, 10.76623052064669, 11.717910367518229, 11.91210356751196, 10.935996437388852, 10.001578182555757, 9.003731848666312, 12.837521457536917, 12.767493566587497, 11.719746029139241, 10.73307423878816, 9.807517310569931, 8.790769599598214, 7.808578461099127, 6.865678567856998, 6.095231899552357, 6.8918752288557155, 7.789581050098934, 8.717425999516573, 9.71333410482194, 10.653469383191291, 11.607656550533765, 12.64299242470638, 12.858861940504045, 11.881042781631908, 10.87986580528481, 9.855388765836594, 13.806884179502195, 13.755106305387827, 12.75001968301618, 11.714083213081594, 10.747171484219646, 9.708939182790855, 8.751560606712177, 7.891522065552284, 7.122748754847894, 7.821835209748853, 8.718856579100642, 9.68909474253154, 10.648040215324771, 11.605085489663349, 12.540882677247424, 13.498580337854062, 13.790083251496362, 12.755960013098498, 11.806511990808694, 10.878082426698374, 14.78715057337931, 14.706002034058097, 13.643987993845698, 12.672747161581668, 11.676631570504986, 10.70678570235454, 9.75266055737969, 8.856610586997231, 8.098458787198924, 8.845944496848038, 9.78071661552762, 10.669469875390602, 11.698315924730714, 12.65001370451943, 13.507355657650772, 14.431628569849677, 14.804371230910007, 13.770583511269331, 12.76894412343162, 11.853781371262087, 15.727951115682215, 15.545251075601614, 14.577294956245893, 13.645757230571908, 12.71406238926103, 11.76047668366241, 10.7671453833674, 9.853546705843268, 9.090770813566655, 9.896763265103395, 10.727260197241067, 10.875660564363953, 11.789865367298063, 12.64772496610329, 13.584461180009091, 14.59589718021357, 15.474136772914841, 14.767947072848777, 13.832307348743754, 12.811352224173744, 16.714030772989748, 16.562754168595042, 15.507096429650657, 14.66292357440427, 13.756412673402306, 12.760674039730539, 11.699121519472454, 10.84329669741202, 10.158999777854984, 10.954017814136092, 10.809894806610753, 9.906596360254166, 10.728420946481933, 11.693104761067772, 12.643253511307352, 13.545456480351094, 14.474850078673422, 15.404486389154727, 14.691837357600951, 13.757162929035086, 17.691305469167354, 17.39551392112443, 16.458360607880188, 15.657915474280928, 14.665920744475498, 13.663070927311452, 12.720117750036668, 11.783078216284109, 11.150468221718068, 10.668056030354748, 9.821063360348194, 8.901092665964027, 9.76775814057681, 10.694536719014216, 11.632396150117586, 12.61227489920562, 13.573454505265945, 14.536940046303648, 15.440454873977563, 14.487343086364884, 18.62734655326042, 17.617771625020417, 16.588680511772647, 15.615214617194574, 14.540406378793195, 13.662858119024795, 12.660785555933968, 11.719213683913269, 10.689850020663647, 9.71124491181191, 8.874745289596643, 7.831385309747328, 8.839055169282666, 9.695664640109717, 10.649284250329918, 11.63828326925492, 12.620677630304606, 13.600985222813648, 14.615174157527855, 15.439028733901734], [15.548903185006434, 14.560939224222606, 13.649231993065523, 12.589686408280825, 11.65016902668299, 10.727281150980115, 9.746205853262762, 8.897515715688238, 7.8848661012745875, 6.9820276850012055, 7.910767159525154, 8.792104489851074, 9.797737933269017, 10.713508320313117, 11.646329688690674, 12.600258464026515, 13.63548608452153, 14.59821456797496, 15.65806062238715, 16.69827077275394, 14.546439857859152, 13.616383414672692, 12.643742835180353, 11.703397024918278, 10.72101481317639, 9.789056549656726, 8.7914294783757, 7.828312517397591, 6.945102151928021, 6.055190608412307, 7.0222475589105375, 7.857221021424521, 8.805415369370836, 9.779473113091917, 10.656775627711065, 11.635501840627901, 12.675438308799139, 13.706340062142655, 14.663899516433222, 15.679621432022433, 13.693953043354627, 12.693358412159276, 11.675502361116811, 10.696460978118273, 9.775361587614192, 8.823234975954222, 7.829137470752653, 6.88174300293221, 5.92292476637232, 5.006518821553282, 5.965385289295741, 6.910841129393706, 7.808536305438536, 8.741045665210821, 9.68234600992319, 10.691562923284806, 11.755019823550665, 12.765891566176098, 13.705404023358264, 14.720353646615353, 12.781359942360186, 11.73560406126509, 10.738290997183597, 9.685888992742006, 8.756737788022383, 7.845592372921974, 6.889202425558503, 5.914625533583871, 4.947699145620193, 3.9615708442832633, 4.899135266237692, 5.859613339290905, 6.822970122519773, 7.798709627450223, 8.77121305561256, 9.741874061472872, 10.794559047622894, 11.789940200409129, 12.810137868058801, 13.749609865395396, 11.792356773951951, 10.743158046616681, 9.765318967530874, 8.701799530044521, 7.771104396345176, 6.8439218340188965, 5.914243944445378, 4.8754046596261675, 3.9215490314972064, 2.9480794889714583, 3.9264728530830775, 4.924066379442591, 5.879370915185181, 6.820104776767647, 7.814698043121198, 8.778534902397425, 9.810328779583978, 10.858196635273952, 11.884417838956054, 12.798336445852826, 10.992001255782784, 9.973926224863106, 9.030999695539895, 8.028481974601462, 7.00858921467858, 5.971197286261961, 5.003390556152317, 3.9844455933500047, 3.0502649424323804, 1.980809757350317, 2.9846847607902367, 3.9126435402624793, 4.914327123132158, 5.898924659370647, 6.858434687299764, 7.801592733574652, 8.860440535395751, 9.915367911543022, 10.88328821540329, 11.740779709219897, 9.949886870805353, 9.009930011196548, 8.038735996477854, 7.020194367402638, 6.057201003647294, 5.008515219915735, 4.0266019003229925, 2.9753207617685558, 2.0131675512232188, 0.9946362888635557, 2.0663001038594406, 2.9672549262079393, 3.9693650091483565, 4.948545808232511, 5.8798543284169655, 6.93255715384465, 7.919566549024656, 8.862392889399512, 9.842000590969318, 10.77106641949385, 9.111924779044674, 8.03880291273062, 7.075470204426991, 6.02346508663847, 5.025517803448752, 4.085781542037954, 3.0463090909092108, 2.0185078089016635, 1.0602237404655932, 0.0, 1.0097501638018203, 1.9859469200194395, 2.9841016443042863, 3.9223062790794, 4.985650162705143, 6.005433346402318, 6.952853265721187, 7.937138856276462, 8.892384681322083, 9.901930647387378, 9.910170817075644, 8.85386525003645, 7.873850525350202, 6.906999598124234, 5.951341461864679, 4.992492888988473, 3.927393182001388, 2.991869277165958, 2.014743507720634, 0.9913950790233758, 2.0093088958575005, 3.0120717843613614, 3.9916449300032824, 4.886589537445909, 5.84133019245549, 6.768780078509073, 7.702793889923325, 8.668390155995379, 9.713580598457343, 10.754287055521178, 10.842682790224709, 9.786606800360957, 8.78598489870732, 7.791908704983835, 6.849039374311575, 5.867768365733207, 4.931479241923638, 3.9051471405632316, 2.9159206991318736, 1.986082863910665, 3.0517924086336374, 3.9977825980492057, 5.005125476855857, 5.879359246710263, 6.878592521182926, 7.767135148768846, 8.677283871965496, 9.601688057538105, 10.666135131997878, 11.696768695136077, 11.67816256421948, 10.731414970233127, 9.82282156157597, 8.8313101772594, 7.864003612373707, 6.935638146043887, 5.920612771193809, 4.961328257434552, 3.969942730135535, 2.987660962021126, 3.9676037515867795, 4.962943085815459, 5.95546394057226, 6.8141476557192, 7.806519587229282, 8.75626333639806, 9.69782544456027, 10.662173053995193, 11.591505565809392, 11.873415635325689, 11.810940086770806, 11.741267523802822, 10.878955470487593, 9.887763064501515, 8.887019105941489, 7.938200442261725, 6.922601063606842, 5.892699892909495, 5.0359774260262125, 3.973237058996765, 4.99293763459213, 5.917161881322208, 6.948554091492065, 7.784821115345579, 8.747367696380524, 9.701992463015875, 10.651368479362521, 11.6857328663151, 11.927510003074126, 10.909944195586371, 10.832914926638667, 11.898950993379287, 11.79481113490414, 10.860699370481763, 9.815747195221173, 8.852404517161483, 7.882270329693053, 6.88747117590924, 5.993239939511598, 4.996637388722509, 5.929439266382747, 6.941647939204072, 7.873772214834618, 8.773306102327938, 9.710755099799629, 10.657686627052636, 11.653041825708657, 11.996220177854445, 11.061801923021351, 10.063955589131906, 11.777297717071324, 12.74886173398645, 12.779969769604834, 11.793297979253753, 10.826477387586037, 9.80972967661432, 8.827538538115233, 7.884638644873104, 6.940399474359801, 5.999627467421558, 6.897333288664776, 7.825178238082416, 8.821086343387782, 9.706546077923793, 10.660733245266266, 11.582768684240786, 12.575787728068832, 12.941266522097502, 11.940089545750402, 10.915612506302185, 12.746660439036603, 13.736474472786782, 13.806490534561075, 12.7330432900977, 11.766131561235753, 10.727899259806962, 9.770520683728284, 8.910482142568389, 7.967916329655338, 6.929587448314695, 7.826608817666484, 8.796846981097383, 9.755792453890615, 10.712837728229193, 11.646245680489969, 12.603943341096606, 13.507009039061149, 13.81618375356409, 12.866735731274286, 11.938306167163967, 13.726926832913719, 14.67302023325248, 14.662948070861805, 13.691707238597775, 12.695591647521093, 11.725745779370648, 10.771620634395797, 9.875570664013336, 8.943626362006368, 7.95369673541388, 8.888468854093462, 9.777222113956446, 10.806068163296558, 11.757765943085275, 12.612718660893316, 13.536991573092221, 14.521297018474794, 14.830807251734923, 13.821626260663992, 12.863143149642514, 14.667727375216623, 15.63215935012884, 15.596255033262, 14.664717307588015, 13.733022466277138, 12.779436760678518, 11.786105460383506, 10.872506782859375, 9.9359383883741, 9.004515503669237, 9.83501243580691, 10.744737666513078, 11.719082397955377, 12.758725979173985, 13.625314552104076, 14.495846105594557, 15.507344015243508, 15.828170813314369, 14.848192541336164, 13.82071400255417, 15.714116352265329, 16.683378537762277, 16.526056506666766, 15.681883651420376, 14.775372750418413, 13.779634116746646, 12.718081596488561, 11.862256774428127, 10.989921235180963, 10.061770052701934, 9.954144162902978, 10.892398885471486, 11.714223471699249, 12.678907286285089, 13.652615289687779, 14.55481825873152, 15.484211857053849, 16.413848167535154, 15.701199135981378, 14.766524707415513, 16.691391048442934, 17.557154902152643, 16.6200015889084, 15.613181798808235, 14.558504643390513, 13.56696172776636, 12.624008550491576, 11.685113243303878, 10.748071970054943, 9.812305386646972, 8.965312716640419, 9.886895191181347, 10.753560665794126, 11.703898497394643, 12.641757928498013, 13.621636677586046, 14.582816283646372, 15.546301824684075, 16.44981665235799, 15.496704864745311, 17.627432132536, 16.618351067387458, 15.589259954139688, 14.615794059561617, 13.540985821160238, 12.663437561391838, 11.66136499830101, 10.731005322762533, 9.82133506338845, 8.855494268104135, 8.018994645888867, 8.817187834964647, 9.824857694499984, 10.705026418490144, 11.658646028710345, 12.647645047635347, 13.630039408685032, 14.610347001194075, 15.624535935908282, 16.44839051228216], [16.558653348808253, 15.570689388024425, 14.658982156867342, 13.599436572082643, 12.659919190484809, 11.737031314781936, 10.755956017064582, 9.870000777830064, 8.857351163416414, 7.954512747143033, 7.169671956762096, 7.782354326049252, 8.787987769467197, 9.703758156511297, 10.636579524888853, 11.590508300224695, 12.625735920719709, 13.58846440417314, 14.648310458585328, 15.68852060895212, 15.55619002166097, 14.62613357847451, 13.653492998982172, 12.713147188720097, 11.73076497697821, 10.798806713458546, 9.801179642177521, 8.800797579539418, 7.917587214069848, 7.027675670554134, 6.099787127716559, 6.8474708576227, 7.795665205569016, 8.769722949290097, 9.647025463909245, 10.62575167682608, 11.665688144997318, 12.696589898340836, 13.654149352631402, 14.669871268220612, 14.703703207156448, 13.703108575961096, 12.68525252491863, 11.706211141920091, 10.78511175141601, 9.832985139756042, 8.838887634554473, 7.854228065074038, 6.895409828514148, 5.97900388369511, 5.042924858101762, 5.9010909655918855, 6.798786141636716, 7.731295501409001, 8.67259584612137, 9.681812759482987, 10.745269659748846, 11.756141402374277, 12.695653859556444, 13.710603482813532, 13.791110106162007, 12.74535422506691, 11.748041160985416, 10.695639156543825, 9.766487951824201, 8.855342536723795, 7.898952589360324, 6.903992178444915, 5.920184207762021, 4.934055906425091, 3.9766748350437133, 4.849863175489085, 5.813219958717953, 6.788959463648403, 7.76146289181074, 8.732123897671054, 9.784808883821075, 10.780190036607308, 11.80038770425698, 12.739859701593575, 12.802106937753772, 11.752908210418502, 10.775069131332694, 9.711549693846342, 8.780854560146995, 7.853671997820717, 6.923994108247198, 5.885154823427988, 4.931299195299027, 3.9578296527732784, 3.004012421889099, 3.91431621564077, 4.869620751383361, 5.810354612965828, 6.8049478793193785, 7.768784738595604, 8.800578615782157, 9.848446471472132, 10.874667675154233, 11.788586282051005, 12.001751419584604, 10.983676388664927, 10.040749859341716, 9.038232138403282, 8.018339378480402, 6.980947450063781, 6.013140719954137, 4.994195757151825, 4.0600151062342, 2.990559921152137, 2.0622243295962583, 2.902893376460659, 3.904576959330338, 4.8891744955688266, 5.848684523497943, 6.7918425697728315, 7.850690371593931, 8.9056177477412, 9.87353805160147, 10.731029545418076, 10.959637034607173, 10.019680174998369, 9.048486160279674, 8.029944531204459, 7.066951167449115, 6.018265383717555, 5.036352064124813, 3.985070925570376, 3.022917715025039, 2.004386452665376, 1.066148099254226, 1.9575047624061188, 2.9596148453465365, 3.938795644430691, 4.870104164615145, 5.9228069900428295, 6.909816385222835, 7.852642725597692, 8.832250427167498, 9.76131625569203, 10.121674942846495, 9.048553076532441, 8.08522036822881, 7.03321525044029, 6.035267967250572, 5.095531705839774, 4.056059254711031, 3.0282579727034835, 2.0699739042674135, 1.0097501638018203, 0.0, 0.9761967562176194, 1.974351480502466, 2.91255611527758, 3.975899998903323, 4.995683182600498, 5.943103101919366, 6.927388692474642, 7.8826345175202635, 8.892180483585559, 10.919920980877464, 9.86361541383827, 8.883600689152022, 7.916749761926054, 6.9610916256665, 6.002243052790292, 4.937143345803207, 4.001619440967778, 3.0244936715224546, 2.001145242825196, 1.019838286824126, 2.0023216205595413, 2.9818947662014628, 3.8768393736440894, 4.83158002865367, 5.759029914707254, 6.693043726121506, 7.65863999219356, 8.703830434655524, 9.74453689171936, 11.852432954026527, 10.796356964162776, 9.795735062509138, 8.801658868785653, 7.858789538113394, 6.877518529535026, 5.941229405725457, 4.914897304365052, 3.925670862933694, 2.9958330277124854, 2.0726932382370657, 3.0059927149167516, 4.0133355937234025, 4.869609082908443, 5.868842357381107, 6.757384984967027, 7.667533708163678, 8.591937893736286, 9.65638496819606, 10.687018531334258, 11.641303529661407, 11.741165134034945, 10.83257172537779, 9.841060341061219, 8.873753776175525, 7.945388309845706, 6.930362934995629, 5.971078421236372, 4.979692893937355, 3.9974111258229463, 3.060627764953166, 3.971153202683005, 4.963674057439806, 5.80439749191738, 6.796769423427461, 7.746513172596241, 8.68807528075845, 9.652422890193375, 10.581755402007573, 11.583165893761908, 10.801189922968987, 11.869490073834848, 11.888705634289412, 10.897513228303334, 9.896769269743308, 8.947950606063547, 7.932351227408662, 6.902450056711316, 6.045727589828033, 4.982987222798585, 4.085961647958517, 4.925371998189754, 5.956764208359611, 6.77507095154376, 7.737617532578704, 8.692242299214055, 9.641618315560702, 10.67598270251328, 11.620501679986397, 11.919694359388192, 9.823164762836848, 10.889200829577469, 11.934946489604872, 11.870449534283582, 10.825497359022993, 9.862154680963304, 8.892020493494874, 7.89722133971106, 7.002990103313419, 6.0063875525243295, 5.102653932346778, 5.949858056071617, 6.881982331702164, 7.763555938526118, 8.701004935997808, 9.647936463250815, 10.643291661906838, 11.619398792029946, 12.071552086823171, 11.073705752933726, 10.767547553269504, 11.73911157018463, 12.812098079350154, 12.803048143055571, 11.836227551387857, 10.81947984041614, 9.837288701917053, 8.894388808674924, 7.950149638161622, 7.009377631223378, 6.070547954628807, 6.901291725879411, 7.829296460255327, 8.696795914121973, 9.650983081464446, 10.573018520438966, 11.566037564267013, 12.564445136273003, 12.949839709552222, 11.925362670104006, 11.73691027523478, 12.72672430898496, 13.76736108154065, 13.742793453899521, 12.775881725037573, 11.737649423608783, 10.780270847530105, 9.92023230637021, 8.977666493457159, 7.939337612116516, 6.999823483630514, 7.872960468894378, 8.799800839145467, 9.747462553540146, 10.636495516688148, 11.594193177294786, 12.49725887525933, 13.49631678615043, 13.876485895076106, 12.948056330965787, 12.717176669111897, 13.663270069450657, 14.725284109663056, 14.701457402399596, 13.705341811322914, 12.735495943172468, 11.781370798197617, 10.885320827815157, 9.953376525808189, 8.9634468992157, 8.061683520057493, 8.853335601753441, 9.85007654855141, 10.792390768396228, 11.602968497091496, 12.5272414092904, 13.511546854672975, 14.510940284321263, 14.831376424465812, 13.872893313444335, 13.657977211414801, 14.622409186327017, 15.590365305682738, 15.674467471389836, 14.742772630078958, 13.789186924480338, 12.795855624185327, 11.882256946661194, 10.94568855217592, 10.014265667471058, 9.00822710177094, 9.820851154310073, 10.795195885752372, 11.812201604680935, 12.615564388302255, 13.486095941792737, 14.497593851441687, 15.488919099081574, 15.857942705137985, 14.830464166355991, 14.70436618846351, 15.673628373960454, 16.519063286106842, 15.507410971741585, 14.549275568963937, 13.510098070546814, 12.625526667520793, 11.615986666310897, 10.730632318052958, 10.040651072726982, 9.960041432899509, 10.78991535841986, 11.770024191747146, 12.734708006332985, 13.556772057003995, 14.50215113577377, 15.431544734096098, 16.361181044577403, 16.7109492997832, 15.776274871217334, 15.681640884641116, 16.547404738350824, 15.610251425106583, 14.603431635006416, 13.548754479588693, 12.558053631901291, 11.615100454626507, 10.676205147438809, 9.739163874189874, 9.071210183883917, 9.937797778782246, 10.859380253323174, 11.726045727935954, 12.711782595316276, 13.651508092299833, 14.631386841387867, 15.592566447448192, 16.556051988485898, 17.459566816159807, 16.50645502854713, 16.617681968734182, 15.60860090358564, 14.579509790337868, 13.606043895759797, 12.531235657358417, 11.653687397590017, 10.65161483449919, 9.721255158960712, 8.811584899586629, 8.114399065341077, 8.991479708030694, 9.789672897106474, 10.797342756641811, 11.714776582291965, 12.668396192512166, 13.657395211437168, 14.639789572486851, 15.620097164995894, 16.6342860997101, 17.45814067608398], [17.42106620236055, 16.43310224157672, 15.521395010419639, 14.46184942563494, 13.522332044037105, 12.580371845469443, 11.59929654775209, 10.650273350015002, 9.6310438597664, 8.692329107114688, 7.76358963259074, 6.806157569831633, 7.811791013249578, 8.727561400293677, 9.660382768671234, 10.614311544007075, 11.64953916450209, 12.61226764795552, 13.67211370236771, 14.712323852734501, 16.418602875213267, 15.488546432026807, 14.515905852534468, 13.575560042272393, 12.593177830530506, 11.642147244146054, 10.644520172865029, 9.609464949118019, 8.726254583648448, 7.836343040132734, 6.863913564155748, 5.871274101405081, 6.819468449351397, 7.793526193072477, 8.670828707691625, 9.64955492060846, 10.689491388779699, 11.720393142123214, 12.677952596413782, 13.693674512002994, 15.587909988619089, 14.587315357423737, 13.56945930638127, 12.590417923382732, 11.647524604968307, 10.67632567044355, 9.68222816524198, 8.662895434652638, 7.704077198092747, 6.787671253273709, 5.851592227680362, 4.9248942093742665, 5.822589385419096, 6.755098745191381, 7.69639908990375, 8.705616003265368, 9.769072903531226, 10.779944646156657, 11.719457103338824, 12.734406726595914, 14.675316887624648, 13.629561006529551, 12.632247942448057, 11.579845938006466, 10.650694733286842, 9.698683067411302, 8.742293120047831, 7.712659548023515, 6.72885157734062, 5.742723276003691, 4.785342204622313, 3.873666419271465, 4.837023202500333, 5.8127627074307835, 6.78526613559312, 7.755927141453434, 8.808612127603455, 9.803993280389689, 10.82419094803936, 11.763662945375957, 13.686313719216413, 12.637114991881143, 11.659275912795335, 10.595756475308983, 9.665061341609636, 8.737878779283358, 7.808200889709839, 6.769361604890629, 5.815505976761668, 4.8420364342359195, 3.812679791467699, 2.938119459423151, 3.8934239951657412, 4.834157856748208, 5.828751123101759, 6.7925879823779844, 7.824381859564538, 8.872249715254512, 9.898470918936615, 10.812389525833387, 12.977948175802224, 11.959873144882547, 11.016946615559336, 10.014428894620902, 8.99453613469802, 7.9571442062814, 6.989337476171756, 5.970392513369444, 4.944221887696841, 3.874766702614778, 2.8708916991748583, 1.9266966202430398, 2.9283802031127184, 3.912977739351207, 4.872487767280324, 5.8156458135552125, 6.874493615376313, 7.929420991523581, 8.897341295383852, 9.754832789200458, 11.935833790824793, 10.995876931215989, 10.024682916497294, 9.006141287422079, 8.043147923666735, 6.994462139935175, 6.012548820342432, 4.961267681787995, 3.9991144712426583, 2.980583208882995, 1.9477048882694339, 0.9813080061884996, 1.983418089128917, 2.9625988882130714, 3.8939074083975256, 4.9466102338252105, 5.933619629005216, 6.876445969380072, 7.85605367094988, 8.785119499474412, 11.097871699064115, 10.02474983275006, 9.06141712444643, 8.009412006657909, 7.011464723468191, 6.0717284620573935, 5.03225601092865, 4.004454728921103, 3.046170660485033, 1.9859469200194395, 0.9761967562176194, 0.0, 0.9981547242848466, 1.9363593590599604, 2.9997032426857038, 4.019486426382879, 4.966906345701747, 5.951191936257023, 6.906437761302644, 7.91598372736794, 11.896117737095082, 10.839812170055888, 9.85979744536964, 8.892946518143672, 7.937288381884118, 6.978439809007912, 5.913340102020827, 4.977816197185398, 4.000690427740073, 2.977341999042815, 1.9960350430417453, 1.026124864341922, 2.0056980099838433, 2.90064261742647, 3.8553832724360504, 4.782833158489634, 5.716846969903886, 6.68244323597594, 7.727633678437903, 8.76834013550174, 11.637701982645268, 11.772553720380396, 10.771931818726758, 9.777855625003273, 8.834986294331014, 7.853715285752646, 6.917426161943077, 5.891094060582672, 4.9018676191513135, 3.9720297839301044, 2.975786148114701, 2.0297959586991325, 3.0371388375057835, 3.8934123266908234, 4.892645601163487, 5.781188228749407, 6.691336951946058, 7.6157411375186665, 8.68018821197844, 9.710821775116639, 10.665106773443787, 11.61185436743014, 11.808768481595408, 10.817257097278839, 9.849950532393144, 8.921585066063326, 7.906559691213249, 6.947275177453992, 5.955889650154974, 4.9436634643964545, 3.9637206748308014, 2.994956446465386, 3.987477301222187, 4.8282007356997605, 5.8205726672098415, 6.770316416378621, 7.711878524540832, 8.676226133975753, 9.605558645789953, 10.606969137544288, 9.824993166751366, 10.893293317617227, 11.887021343189959, 11.873709984520953, 10.872966025960928, 9.924147362281166, 8.908547983626283, 7.8786468129289355, 6.9947928106561506, 5.929239561372094, 4.9427036963930515, 3.949175241972135, 4.980567452141992, 5.79887419532614, 6.761420776361084, 7.716045542996436, 8.665421559343084, 9.699785946295663, 10.644304923768775, 11.577777041677491, 8.846968006619228, 9.913004073359849, 10.958749733387254, 11.892861497809632, 11.801694115240613, 10.838351437180924, 9.868217249712494, 8.87341809592868, 7.907976012773932, 6.89219785844155, 5.959395980781312, 4.973661299853999, 5.905785575484545, 6.787359182308498, 7.724808179780189, 8.671739707033195, 9.66709490568922, 10.643202035812328, 11.577620290645422, 12.049902509151346, 9.791350797051885, 10.762914813967011, 11.835901323132536, 12.825460106581621, 12.812424307605477, 11.79567659663376, 10.813485458134673, 9.785195048094018, 8.835959944078843, 7.895187937140599, 6.852939919079433, 5.925094969661793, 6.853099704037708, 7.720599157904353, 8.674786325246826, 9.596821764221346, 10.589840808049392, 11.588248380055385, 12.580917686287403, 12.901559426321626, 10.760713519017163, 11.750527552767341, 12.791164325323033, 13.864611569786408, 13.752078481255193, 12.713846179826403, 11.756467603747724, 10.811038545789303, 9.863476799374379, 8.825147918033737, 7.782215448081141, 6.89676371267676, 7.823604082927847, 8.771265797322526, 9.660298760470528, 10.617996421077166, 11.521062119041709, 12.520120029932812, 13.469568052222616, 13.924253087183407, 11.740979912894279, 12.68707331323304, 13.749087353445438, 14.720328185709468, 14.675755338438348, 13.705909470287903, 12.72513646898579, 11.77612706723425, 10.839186831725408, 9.849257205132922, 8.839002817437063, 7.877138845535824, 8.873879792333788, 9.816194012178608, 10.626771740873876, 11.55104465307278, 12.535350098455353, 13.534743528103645, 14.432000184845542, 14.757100094906976, 12.681780455197183, 13.646212430109399, 14.61416854946512, 15.548380559356326, 14.615429096887592, 13.584554931460822, 12.581306047408228, 11.62953990166203, 10.822664526123667, 10.850590239757352, 9.78554639915051, 8.844654398092457, 9.818999129534756, 10.836004848463315, 11.639367632084635, 12.509899185575117, 13.521397095224067, 14.512722342863954, 15.495363410157676, 15.714670947818632, 13.728169432245892, 14.697431617742836, 15.542866529889222, 14.531214215523965, 13.573078812746317, 12.533901314329194, 11.649329911303173, 10.639789910093278, 9.754435561835338, 10.634568748555624, 10.737360730279079, 9.813718602202243, 10.79382743552953, 11.758511250115369, 12.580575300786375, 13.52595437955615, 14.455347977878478, 15.384984288359783, 16.37402952268679, 16.660481652679977, 14.705444128423498, 15.571207982133203, 14.634054668888961, 13.627234878788794, 12.572557723371073, 11.581856875683672, 10.638903698408887, 9.70000839122119, 8.762967117972254, 9.665127859712559, 10.61049780824547, 10.81922229649238, 11.754490241434652, 12.740227108814974, 13.59143266197614, 14.459135960701625, 15.396012894979151, 16.359498436016857, 17.30852353130682, 17.368867882099426, 15.641485212516564, 14.63240414736802, 13.603313034120248, 12.629847139542177, 11.555038901140797, 10.677490641372398, 9.67541807828157, 8.745058402743092, 7.835388143369009, 8.708316741169721, 9.664179737493917, 10.56336559345646, 11.577615328826749, 12.558117112979472, 13.511736723199673, 14.500735742124675, 15.502202426039148, 16.48251001854819, 17.496698953262396, 18.320553529636275], [18.419220926645394, 17.431256965861568, 16.519549734704487, 15.460004149919786, 14.520486768321952, 13.521016683086815, 12.539941385369461, 11.573939893697556, 10.554710403448954, 9.615995650797242, 8.687256176273294, 7.729824113514187, 6.854586470116919, 7.72940667600883, 8.662228044386387, 9.616156819722228, 10.651384440217242, 11.614112923670673, 12.673958978082862, 13.714169128449655, 17.416757599498112, 16.486701156311653, 15.514060576819315, 14.57371476655724, 13.591332554815352, 12.6403019684309, 11.642674897149876, 10.607619673402866, 9.724409307933294, 8.787727867108003, 7.787580107838302, 6.794940645087635, 5.862263906218738, 6.79537146878763, 7.672673983406778, 8.651400196323614, 9.691336664494852, 10.72223841783837, 11.679797872128935, 12.695519787718148, 16.586064712903937, 15.585470081708586, 14.56761403066612, 13.588572647667581, 12.645679329253154, 11.674480394728397, 10.680382889526827, 9.661050158937485, 8.702231922377594, 7.785825977558556, 6.8497469519652086, 5.84856075305682, 4.82443466113425, 5.756944020906534, 6.698244365618903, 7.707461278980522, 8.77091817924638, 9.78178992187181, 10.721302379053977, 11.736252002311067, 15.673471611909497, 14.6277157308144, 13.630402666732905, 12.578000662291315, 11.648849457571691, 10.696837791696149, 9.740447844332678, 8.710814272308362, 7.727006301625467, 6.740878000288538, 5.78349692890716, 4.79733296295402, 3.838868478215487, 4.814607983145937, 5.787111411308273, 6.757772417168587, 7.810457403318609, 8.805838556104842, 9.826036223754514, 10.76550822109111, 14.684468443501261, 13.635269716165991, 12.657430637080184, 11.593911199593832, 10.663216065894485, 9.736033503568205, 8.806355613994686, 7.767516329175476, 6.813660701046515, 5.840191158520766, 4.810834515752545, 3.861786003105705, 2.8952692708808945, 3.836003132463361, 4.830596398816912, 5.794433258093138, 6.826227135279691, 7.874094990969665, 8.900316194651769, 9.81423480154854, 13.97610290008707, 12.958027869167394, 12.015101339844183, 11.012583618905749, 9.992690858982867, 8.955298930566247, 7.987492200456603, 6.968547237654291, 5.942376611981688, 4.872921426899625, 3.8690464234597046, 2.924851344527886, 1.9302254788278717, 2.9148230150663603, 3.874333042995477, 4.817491089270366, 5.876338891091466, 6.931266267238734, 7.899186571099005, 8.756678064915612, 12.93398851510964, 11.994031655500835, 11.022837640782141, 10.004296011706925, 9.041302647951582, 7.992616864220022, 7.010703544627279, 5.959422406072842, 4.9972691955275055, 3.978737933167842, 2.9458596125542806, 1.979462730473346, 0.9852633648440704, 1.9644441639282246, 2.895752684112679, 3.9484555095403637, 4.935464904720369, 5.878291245095225, 6.857898946665033, 7.786964775189565, 12.096026423348961, 11.022904557034908, 10.059571848731277, 9.007566730942756, 8.009619447753039, 7.06988318634224, 6.030410735213497, 5.00260945320595, 4.04432538476988, 2.9841016443042863, 1.974351480502466, 0.9981547242848466, 0.0, 0.9382046347751136, 2.001548518400857, 3.021331702098032, 3.9687516214169003, 4.953037211972176, 5.908283037017798, 6.917829003083093, 11.57939569590337, 11.837966894340736, 10.857952169654489, 9.89110124242852, 8.935443106168966, 7.976594533292759, 6.911494826305674, 5.975970921470244, 4.99884515202492, 3.975496723327662, 2.994189767326592, 2.0165029260961482, 1.036929780454227, 1.9024878931416231, 2.8572285481512036, 3.784678434204787, 4.718692245619039, 5.684288511691093, 6.7294789541530555, 7.770185411216892, 10.63954725836042, 11.558507813017462, 11.770086543011605, 10.77601034928812, 9.83314101861586, 8.851870010037493, 7.915580886227923, 6.889248784867518, 5.900022343436159, 4.970184508214951, 3.9661642098689267, 3.0201740204533585, 2.07987447253088, 2.8952576024059766, 3.89449087687864, 4.78303350446456, 5.693182227661209, 6.617586413233819, 7.682033487693591, 8.71266705083179, 9.666952049158938, 10.613699643145292, 11.63480220629338, 11.815411821563686, 10.848105256677991, 9.919739790348173, 8.904714415498095, 7.945429901738837, 6.954044374439821, 5.934041526150681, 4.954098736585027, 3.985334508219612, 3.1260039067300287, 3.8300460114149137, 4.822417942924995, 5.772161692093774, 6.713723800255983, 7.678071409690906, 8.607403921505105, 9.60881441325944, 8.826838442466519, 9.89513859333238, 10.888866618905112, 11.867643079505031, 11.871120750245774, 10.922302086566011, 9.906702707911128, 8.87680153721378, 7.985170872410377, 6.91961762312632, 5.933081758147278, 4.9395533037263615, 4.134002592515812, 4.800719471041293, 5.763266052076237, 6.717890818711589, 7.667266835058236, 8.701631222010814, 9.646150199483927, 10.579622317392642, 7.8488132823343815, 8.914849349075002, 9.960595009102406, 10.894706773524783, 11.950348612455407, 11.836506161465769, 10.866371973997339, 9.871572820213524, 8.898354074528159, 7.882575920195777, 6.949774042535538, 5.964039361608226, 5.059220715858365, 5.789204458023652, 6.7266534554953425, 7.673584982748348, 8.668940181404372, 9.64504731152748, 10.579465566360573, 11.504980299803835, 8.793196072767039, 9.764760089682165, 10.83774659884769, 11.827305382296773, 12.83214921545206, 12.793831320918605, 11.811640182419518, 10.775573109848244, 9.826338005833069, 8.885565998894824, 7.8433179808336595, 6.9154730314160195, 6.0065348444115285, 6.722444433619506, 7.676631600961979, 8.5986670399365, 9.591686083764547, 10.590093655770536, 11.582762962002555, 12.459464348952023, 9.762558794732318, 10.752372828482496, 11.793009601038188, 12.866456845501563, 13.801884200443164, 13.712000904111248, 12.75462232803257, 11.80141660754353, 10.853854861128605, 9.815525979787962, 8.772593509835367, 7.887141774430987, 6.977039223301668, 7.773111073037678, 8.662144036185682, 9.619841696792319, 10.522907394756864, 11.521965305647964, 12.471413327937768, 13.404210032760947, 10.742825188609434, 11.688918588948194, 12.750932629160593, 13.722173461424623, 14.578031343768412, 13.608185475617967, 12.627412474315854, 11.678403072564315, 11.829564893479635, 10.839635266887147, 9.829380879191289, 8.86751690729005, 8.027314932707611, 8.818039287893761, 9.628617016589029, 10.552889928787934, 11.537195374170508, 12.536588803818796, 13.433845460560693, 14.392328571582171, 11.683625730912338, 12.648057705824554, 13.616013825180275, 14.55022583507148, 13.617274372602745, 12.621505951143817, 11.633233099464476, 10.681466953718278, 11.717790997200902, 11.840968301511577, 10.775924460904736, 9.835032459846682, 9.037939676902425, 9.837850124178468, 10.641212907799789, 11.51174446129027, 12.52324237093922, 13.514567618579107, 14.497208685872828, 15.430721916477403, 12.730014707961043, 13.699276893457991, 14.544711805604376, 13.533059491239118, 12.57492408846147, 11.568936088498909, 10.701256963359421, 9.691716962149526, 10.678102105517892, 11.558235292238178, 11.727738792033305, 10.804096663956468, 10.099384097718556, 10.792470329213986, 11.582420576501528, 12.527799655271304, 13.457193253593632, 14.386829564074937, 15.375874798401943, 16.310549226967808, 13.707289404138649, 14.573053257848358, 13.635899944604116, 12.62908015450395, 11.574402999086226, 10.616891649853386, 9.690830750465135, 8.751935443277437, 9.686633661654808, 10.588794403395113, 11.534164351928023, 11.809600358246605, 11.060046903623679, 11.818485619363026, 12.593277937691294, 13.460981236416778, 14.397858170694304, 15.361343711732008, 16.310368807021973, 17.26348059463465, 14.643330488231715, 13.634249423083173, 12.605158309835401, 11.63169241525733, 10.55688417685595, 9.67933591708755, 8.677263353996723, 7.787853859610434, 8.759054687051563, 9.631983284852275, 10.587846281176471, 11.487032137139014, 11.988749874917822, 12.817357698267525, 13.576389837478962, 14.434972866367477, 15.434176492302983, 16.397709840532006, 17.28220684176959, 18.2151662421715], [18.27800429389298, 17.410480620225034, 16.48225628662272, 15.463925849490536, 14.524408467892702, 13.583263863583829, 12.837973628719794, 12.512144528472671, 11.492915038224067, 10.554200285572355, 9.625460811048407, 8.6680287482893, 7.792791104892033, 6.983070792538822, 7.915892160916378, 8.86982093625222, 9.889559598661258, 10.832236290380534, 11.83335374649109, 12.775964493674541, 17.275540966745698, 17.42490579108677, 16.45226521159443, 15.511919401332355, 14.529537189590467, 13.578506603206016, 12.58087953192499, 11.54582430817798, 10.66261394270841, 9.725932501883117, 8.725784742613415, 7.7331452798627485, 6.800468540993852, 6.049035585317622, 6.926338099936769, 7.905064312853606, 8.929511822938867, 9.851783866674625, 10.805734040245428, 11.757315152943034, 16.44491625625358, 16.5236747164837, 15.505818665441234, 14.526777282442696, 13.583883964028269, 12.612685029503512, 11.618587524301942, 10.5992547937126, 9.640436557152709, 8.72403061233367, 7.787951586740323, 6.786765387831934, 5.762639295909364, 5.010608137436526, 5.951908482148895, 6.920045353109783, 7.958462276175041, 8.907726089988303, 9.84723854717047, 10.798047367535954, 15.519711642103506, 15.565920365589514, 14.56860730150802, 13.51620529706643, 12.587054092346806, 11.635042426471264, 10.678652479107793, 9.649018907083477, 8.665210936400582, 7.679082635063652, 6.721701563682274, 5.735537597729133, 4.777073112990601, 4.068272099675928, 5.005906763924405, 5.970356491297848, 6.947647668062841, 7.931774724221334, 8.951972391871006, 9.827303586315997, 14.474420041015344, 14.573474350941106, 13.595635271855299, 12.532115834368946, 11.6014207006696, 10.67423813834332, 9.744560248769801, 8.70572096395059, 7.751865335821629, 6.77839579329588, 5.7490391505276595, 4.799990637880819, 3.833473905656008, 3.0836980179571025, 3.9565325669334035, 4.920369426209629, 5.952163303396183, 7.0000311590861575, 7.962111559876654, 8.876030166773427, 13.412310309367017, 13.896232503942507, 12.953305974619296, 11.950788253680862, 10.930895493757982, 9.893503565341362, 8.925696835231717, 7.906751872429405, 6.880581246756802, 5.811126061674739, 4.807251058234819, 3.8630559793029997, 2.8684301136029853, 2.0824844655708707, 2.9361284082203634, 3.8792864544952517, 4.938134256316351, 5.993061632463621, 6.960981936323891, 7.8184734301404974, 12.449435107096313, 12.932236290275949, 11.961042275557254, 10.942500646482038, 9.979507282726695, 8.930821498995135, 7.948908179402393, 6.897627040847956, 5.9354738303026195, 4.916942567942956, 3.884064247329394, 2.9176673652484597, 1.923467999619184, 1.026239529153111, 1.9575480493375652, 3.0102508747652497, 3.9972602699452553, 4.940086610320112, 5.919694311889919, 6.848760140414451, 11.518806475115953, 11.96110919181002, 10.99777648350639, 9.945771365717869, 8.947824082528152, 8.008087821117353, 6.968615369988611, 5.940814087981064, 4.982530019544994, 3.9223062790794003, 2.91255611527758, 1.9363593590599604, 0.9382046347751136, 0.0, 1.0633438836257432, 2.0831270673229185, 3.0305469866417867, 4.014832577197062, 4.970078402242684, 5.979624368307979, 10.641191061128257, 11.678882493613694, 11.796156804429602, 10.829305877203634, 9.87364774094408, 8.914799168067875, 7.849699461080789, 6.914175556245358, 5.937049786800035, 4.913701358102776, 3.9093181857684174, 2.8703571825308654, 1.8907840368889444, 0.9642832583665095, 1.9190239133760902, 2.846473799429673, 3.7804876108439256, 4.746083876915979, 5.791274319377942, 6.831980776441779, 9.701342623585308, 10.620303178242347, 11.620925079895985, 11.696323199545466, 10.753453868873207, 9.772182860294839, 8.83589373648527, 7.8047922876791835, 6.815565846247825, 5.885728011026616, 4.820018466303644, 3.8740282768880756, 2.9337287289655976, 1.9570529676308632, 2.9562862421035265, 3.844828869689447, 4.754977592886096, 5.679381778458706, 6.743828852918478, 7.774462416056676, 8.728747414383824, 9.675495008370177, 10.696597571518264, 11.726674697979185, 11.768418106935338, 10.840052640605519, 9.810902903073094, 8.851618389313836, 7.8326199114922, 6.787895782585398, 5.807952993019744, 4.839188764654329, 3.955577489097659, 2.8918413766398006, 3.884213308149882, 4.833957057318662, 5.77551916548087, 6.739866774915793, 7.669199286729992, 8.670609778484327, 7.888633807691406, 8.956933958557267, 9.950661984129999, 10.929438444729918, 11.956180539821409, 11.82849057414101, 10.812891195486127, 9.78299002478878, 8.839025128845094, 7.773471879561037, 6.786936014581995, 5.793407560161079, 4.870507594473851, 3.86251483626618, 4.825061417301124, 5.779686183936476, 6.729062200283122, 7.763426587235701, 8.707945564708815, 9.64141768261753, 6.910608647559267, 7.976644714299888, 9.022390374327292, 9.95650213874967, 11.012143977680294, 11.975486655739983, 11.758177723387023, 10.763378569603208, 9.747964719839082, 8.7321865655067, 7.799384687846461, 6.759684985615348, 5.7957257178164046, 4.8509998232485385, 5.788448820720229, 6.735380347973235, 7.730735546629258, 8.706842676752366, 9.64126093158546, 10.566775665028722, 7.854991437991925, 8.826555454907052, 9.899541964072576, 10.88910074752166, 11.893944580676948, 12.915407839548669, 12.647693525234391, 11.579372557084724, 10.63013745306955, 9.689365446131305, 8.63896360484078, 7.7111186554231415, 6.743039846369568, 5.784239798844393, 6.738426966186866, 7.660462405161386, 8.653481448989432, 9.651889020995423, 10.644558327227442, 11.52125971417691, 8.824354159957203, 9.814168193707381, 10.854804966263073, 11.928252210726448, 12.86367956566805, 13.85485768236307, 12.95871429619792, 12.60521605478001, 11.657654308365085, 10.619325427024442, 9.568239133842487, 8.672489698052939, 7.713544225259707, 6.834906438262565, 7.7239394014105685, 8.681637062017206, 9.584702759981749, 10.58376067087285, 11.533208693162655, 12.466005397985834, 9.804620553834319, 10.75071395417308, 11.812727994385478, 12.783968826649508, 13.811462424301098, 12.928861048981679, 11.957614345530407, 12.61660770733943, 12.633364340716115, 11.643434714123627, 10.614728802813241, 9.652864830912002, 8.763819934665648, 7.879834653118647, 8.690412381813916, 9.614685294012821, 10.598990739395393, 11.598384169043683, 12.49564082578558, 13.454123936807058, 10.745421096137223, 11.709853071049439, 12.67780919040516, 13.633152108015915, 12.870938489132737, 11.875170067673809, 10.943129519542698, 11.619671588493391, 12.655995631976015, 12.626316225133529, 11.561272384526688, 10.620380383468634, 9.774444678860462, 8.899645489403355, 9.703008273024675, 10.573539826515157, 11.585037736164107, 12.576362983803994, 13.559004051097716, 14.492517281702291, 11.791810073185932, 12.761072258682876, 13.607610663809924, 12.78672360776911, 11.828588204991462, 10.8226002050289, 10.011153383437643, 10.629921596924639, 11.616306740293005, 12.496439927013293, 12.513086715655257, 11.58944458757842, 10.818949509024712, 9.854265694438872, 10.644215941726415, 11.58959502049619, 12.518988618818518, 13.448624929299823, 14.43767016362683, 15.372344592192695, 12.769084769363538, 13.771851347548438, 12.86624744243439, 11.882744271033939, 10.828067115616218, 9.870555766383378, 8.99015715287343, 9.69014007805255, 10.624838296429921, 11.526999038170228, 12.472368986703136, 12.594948281868557, 11.779612314929835, 10.880280984587912, 11.65507330291618, 12.522776601641665, 13.459653535919191, 14.423139076956895, 15.372164172246862, 16.32527595985954, 13.705125853456604, 12.829533814486561, 11.823281676545262, 10.885356531787322, 9.810548293385942, 8.933000033617542, 7.930927470526714, 8.726058494385548, 9.697259321826676, 10.570187919627388, 11.526050915951584, 12.425236771914127, 12.708315286223979, 11.879153063492412, 12.638185202703848, 13.496768231592364, 14.49597185752787, 15.459505205756894, 16.344002206994478, 17.276961607396387], [17.4923795426007, 16.62485586893275, 15.69663153533044, 14.750700106639796, 13.814171248102756, 12.873026643793885, 13.822923009787333, 13.517845261548086, 12.498615771299482, 11.55990101864777, 10.631161544123822, 9.673729481364715, 8.798491837967449, 7.82909546312807, 7.03965403014803, 7.931249363707429, 8.905580215291527, 9.797937318978487, 10.799054775089044, 11.712620610048798, 16.489916215453416, 17.319266486751708, 16.65871596045034, 15.718370150188267, 14.743325461609356, 13.813225970047814, 13.603328621492707, 12.568273397745697, 11.685063032276126, 10.731633234958531, 9.73148547568883, 8.738846012938163, 7.806169274069267, 6.89506025590687, 6.031397870116704, 6.966492740308816, 7.945532439569137, 8.817484895272578, 9.771435068843381, 10.693971269317291, 15.607498821792447, 16.386234893280438, 16.528267755008947, 15.549226372010411, 14.606333053595986, 13.635134119071228, 12.641036613869659, 11.621703883280317, 10.662885646720426, 9.746479701901388, 8.81040067630804, 7.792466120907349, 6.768340028984779, 5.856632808025774, 5.056968252328829, 5.936065969740054, 6.974482892805311, 7.873427118586257, 8.812939575768423, 9.734703483910211, 14.595179713151886, 15.42848054238625, 15.591056391075735, 14.538654386634144, 13.609503181914521, 12.65749151603898, 11.70110156867551, 10.671467996651193, 9.687660025968299, 8.70153172463137, 7.744150653249991, 6.741238330804548, 5.782773846066016, 4.914296770265175, 4.021927380554676, 4.986377107928119, 5.963668284693111, 6.897475752819287, 7.91767342046896, 8.763959702690254, 13.549888112063725, 14.436034527737842, 14.618084361423014, 13.554564923936661, 12.623869790237315, 11.696687227911037, 10.767009338337518, 9.728170053518307, 8.774314425389345, 7.800844882863598, 6.771488240095377, 5.805691370956234, 4.839174638731424, 3.9297226885463497, 2.972553183563674, 3.9363900428399, 4.968183920026453, 5.96573218768411, 6.89876767625091, 7.812686283147683, 12.487778380415397, 13.428856251420054, 14.016649858245039, 13.014132137306605, 11.994239377383725, 10.956847448967105, 9.98904071885746, 8.964196521606079, 7.90303033632452, 6.8335751512424565, 5.829700147802536, 4.885505068870717, 3.8741308466784012, 2.928509136160118, 1.952149024850634, 2.895307071125522, 3.954154872946622, 4.929717748837877, 5.897638052698147, 6.755129546514754, 11.524903178144692, 12.464860037753496, 13.024386159182997, 12.005844530107781, 11.042851166352438, 9.994165382620878, 9.012252063028136, 7.960970924473699, 6.9988177139283625, 5.980286451568699, 4.917218728226938, 3.9508218461460043, 2.9291687326946, 1.90487718615229, 0.9735686659678358, 2.02627149139552, 2.9339163863195123, 3.8767427266943684, 4.856350428264175, 5.785416256788707, 10.594274546164332, 11.667396412478386, 12.061120367132135, 11.009115249343614, 10.011167966153897, 9.071431704743098, 8.031959253614355, 7.004157971606807, 6.045873903170737, 4.985650162705143, 3.9758999989033232, 2.9997032426857038, 2.001548518400857, 1.0633438836257432, 0.0, 1.0197831836971754, 1.9672031030160433, 2.951488693571319, 3.90673451861694, 4.916280484682236, 9.716659132176636, 10.754350564662074, 11.64385564273525, 11.854333836108822, 10.898675699849267, 9.916422091757543, 8.851322384770457, 7.9157984799350265, 6.935529812367341, 5.912181383670083, 4.894267566835958, 3.855306563598406, 2.875733417956485, 1.94923263943405, 0.9944919844244694, 1.9219418704780526, 2.855955681892305, 3.821551947964359, 4.866742390426322, 5.8843212124809465, 8.776810694633687, 9.695771249290727, 10.696393150944365, 11.69046934466785, 11.738403249940747, 10.75713224136238, 9.82084311755281, 8.789741668746725, 7.800515227315366, 6.870677392094158, 5.804967847371185, 4.8589776579556165, 3.918678110033138, 2.942002348698404, 2.0317543131519056, 2.9202969407378263, 3.830445663934476, 4.754849849507085, 5.819296923966857, 6.8499304871050555, 7.804215485432204, 8.750963079418558, 9.772065642566645, 10.802142769027565, 11.828182606994375, 11.82500202167306, 10.795852284140635, 9.836567770381377, 8.81756929255974, 7.7728451636529385, 6.792902374087285, 5.82413814572187, 4.9405268701652, 3.876790757707341, 3.0684454821905827, 3.9898991727236774, 4.8509872365292495, 5.8153348459641725, 6.744667357778371, 7.746077849532706, 6.9135798145670915, 7.949499264159051, 8.927532130135733, 9.866094561104175, 10.892836656195666, 11.862370664797364, 11.797840576553668, 10.767939405856321, 9.823974509912633, 8.758421260628577, 7.7718853956495355, 6.778356941228619, 5.855456975541392, 4.84746421733372, 4.109222069949116, 5.01095587486302, 5.804530271331502, 6.838894658284081, 7.783413635757194, 8.716885753665908, 5.8472647639335245, 6.913300830674145, 7.9590464907015495, 8.893158255123927, 9.948800094054551, 10.91214277211424, 11.88227695958267, 11.74832795067075, 10.732914100906624, 9.717135946574242, 8.784334068914003, 7.744634366682888, 6.780675098883945, 5.835949204316079, 5.072609473368221, 5.96665003889978, 6.806203617677639, 7.7823107478007465, 8.71672900263384, 9.6422437360771, 6.791647554366181, 7.763211571281307, 8.836198080446831, 9.825756863895917, 10.830600697051205, 11.852063955922926, 12.82754516800485, 12.564321938152265, 11.61508683413709, 10.674314827198845, 9.623912985908321, 8.696068036490681, 7.727989227437108, 6.769189179911933, 6.028189746396922, 6.891732096087931, 7.752961990669725, 8.727357092043803, 9.720026398275822, 10.596727785225289, 7.761010276331459, 8.750824310081637, 9.791461082637328, 10.864908327100704, 11.800335682042308, 12.791513798737327, 13.748892374816005, 13.59016543584755, 12.642603689432626, 11.604274808091983, 10.553188514910028, 9.65743907912048, 8.698493606327247, 7.8198558193301055, 7.013702181620625, 7.9451756355273, 8.684183301662042, 9.65922874192123, 10.608676764211035, 11.541473469034214, 8.741276670208576, 9.687370070547336, 10.749384110759735, 11.720624943023765, 12.748118540675355, 12.05262291821333, 12.803639016119655, 13.622308440414844, 13.618313721783656, 12.628384095191167, 11.599678183880782, 10.637814211979542, 9.748769315733188, 8.864784034186187, 7.980175162023972, 8.878223867522914, 9.698471281075687, 10.673852240092064, 11.57110889683396, 12.529592007855438, 9.68207721251148, 10.646509187423696, 11.614465306779417, 12.569808224390172, 11.932366916587945, 10.99893193690546, 11.789154190131946, 12.625372321568808, 13.661696365051432, 13.61126560620107, 12.546221765594229, 11.605329764536174, 10.759394059928002, 9.884594870470893, 8.992771053234732, 9.83707840002525, 10.734077173284817, 11.671215801671512, 12.634472122146096, 13.567985352750672, 10.728466189560187, 11.697728375057135, 12.54426678018418, 11.848152035224318, 10.89001663244667, 9.946362074260552, 10.85717805402689, 11.635622330000055, 12.62200747336842, 13.502140660088708, 13.498036096722798, 12.57439396864596, 11.80389889009225, 10.839215075506411, 9.933978721936471, 10.879357800706247, 11.733363867526236, 12.663000178007541, 13.652045412334548, 14.581544513686653, 11.705740885737793, 12.708507463922697, 11.831948471032343, 10.944172698489147, 9.889495543071426, 8.99431763561503, 9.836181823462677, 10.695840811127967, 11.630539029505336, 12.532699771245642, 13.478069719778551, 13.579897662936098, 12.764561695997374, 11.865230365655451, 10.944836083126237, 11.812539381851721, 12.674028784626909, 13.637514325664613, 14.58653942095458, 15.539651208567259, 12.641781969830859, 11.795234843084515, 10.788982705143216, 9.912608478718047, 8.87197672084115, 8.056761902849194, 8.776952141115963, 9.731759227460964, 10.702960054902091, 11.575888652702803, 12.531751649027, 13.430937504989542, 13.693264667291515, 12.86410244455995, 11.927947982913905, 12.78653101180242, 13.710347106235588, 14.673880454464612, 15.558377455702196, 16.49133685610411], [16.54824156265071, 15.680717888982764, 14.75249355538045, 13.806562126689807, 12.878194567334251, 13.745058260939025, 14.712419775506628, 14.53762844524526, 13.518398954996657, 12.579684202344945, 11.650944727820997, 10.69351266506189, 9.818275021664624, 8.848878646825245, 8.059437213845206, 7.185278345794141, 7.96751012274453, 8.778154135281314, 9.779271591391868, 10.692837426351623, 15.545778235503429, 16.37512850680172, 15.714577980500353, 14.774232170238278, 13.80734878084085, 14.685257587192954, 14.623111805189883, 13.588056581442872, 12.704846215973301, 11.751416418655706, 10.751268659386005, 9.758629196635338, 8.825952457766443, 7.914843439604045, 7.051181053813879, 6.220521722395528, 7.007462347022139, 7.797701711575404, 8.751651885146206, 9.674188085620116, 14.66336084184246, 15.442096913330449, 16.384719780173224, 15.750393946333734, 14.75300200640305, 14.654917302768403, 13.660819797566834, 12.641487066977492, 11.682668830417601, 10.766262885598563, 9.830183860005214, 8.812249304604524, 7.788123212681954, 6.876415991722949, 6.076751436026004, 5.190094951826766, 6.036412800258313, 6.853643934889082, 7.793156392071248, 8.714920300213036, 13.651041733201899, 14.484342562436263, 15.44750841624001, 15.558437570331323, 14.6292863656117, 13.677274699736156, 12.720884752372685, 11.691251180348369, 10.707443209665474, 9.721314908328544, 8.763933836947166, 7.761021514501723, 6.802557029763191, 5.934079953962351, 5.041710564251851, 4.240406090014831, 5.025598192146114, 5.877692569122112, 6.897890236771785, 7.744176518993079, 12.605750132113737, 13.491896547787855, 14.469735626873662, 14.57434810763384, 13.643652973934493, 12.716470411608213, 11.786792522034695, 10.747953237215484, 9.794097609086522, 8.820628066560774, 7.791271423792552, 6.825474554653409, 5.858957822428599, 4.949505872243526, 3.9923363672608496, 3.1904190249266122, 4.030113827479456, 4.945949003986935, 5.878984492553735, 6.792903099450508, 11.54364040046541, 12.484718271470067, 13.509234807038421, 14.03391532100378, 13.0140225610809, 11.97663063266428, 11.008823902554635, 9.983979705303254, 8.922813520021695, 7.853358334939632, 6.8494833314997114, 5.9052882525678925, 4.893914030375576, 3.948292319857294, 2.9719322085478095, 2.140594549565853, 2.988711374635182, 3.909934565140702, 4.877854869000972, 5.7353463628175785, 10.580765198194705, 11.520722057803509, 12.491916072522203, 13.025627713804957, 12.062634350049613, 11.013948566318053, 10.03203524672531, 8.980754108170874, 8.018600897625538, 7.0000696352658744, 5.9370019119241135, 4.970605029843179, 3.948951916391775, 2.9246603698494655, 1.993351849665011, 1.070082375921046, 1.9141332026223368, 2.856959542997193, 3.836567244567, 4.765633073091532, 9.650136566214345, 10.717054593581885, 11.620535920779338, 12.028898433040789, 11.030951149851072, 10.091214888440273, 9.05174243731153, 8.023941155303982, 7.065657086867912, 6.005433346402318, 4.995683182600498, 4.019486426382879, 3.021331702098032, 2.0831270673229185, 1.0197831836971754, 0.0, 0.947419919318868, 1.9317055098741436, 2.886951334919765, 3.8964973009850605, 8.77252115222665, 9.762968045827705, 10.652473123900881, 11.61932405112685, 11.809437492006445, 10.82718388391472, 9.762084176927635, 8.826560272092205, 7.846291604524521, 6.8229431758272625, 5.805029358993138, 4.766068355755586, 3.7864952101136646, 2.85999443159123, 1.9052537765816489, 0.9778038905280656, 1.911817701942318, 2.877413968014372, 3.9226044104763353, 4.8645380287837705, 7.822756234954505, 8.704388730456358, 9.705010632109996, 10.699086825833481, 11.64195615650574, 11.66789403351956, 10.73160490970999, 9.700503460903905, 8.711277019472547, 7.7814391842513375, 6.715729639528365, 5.769739450112796, 4.829439902190318, 3.8527641408555837, 2.9037859302970466, 1.9761589607878394, 2.886307683984489, 3.8107118695570987, 4.875158944016871, 5.8585479682706865, 6.812832966597835, 7.759580560584188, 8.780683123732274, 9.810760250193194, 10.836800088160004, 11.765165554489823, 11.706614076297814, 10.747329562538557, 9.72833108471692, 8.683606955810118, 7.703664166244465, 6.7348999378790495, 5.851288662322379, 4.787552549864521, 3.9404770993357237, 3.04576119277369, 3.906849256579263, 4.871196866014186, 5.800529377828385, 6.80193986958272, 5.893796630869916, 6.929716080461876, 7.9077489464385575, 8.846311377407002, 9.873053472498492, 10.84258748110019, 11.858186859755074, 11.6787011980135, 10.734736302069813, 9.669183052785757, 8.682647187806715, 7.689118733385799, 6.766218767698572, 5.7582260094909, 4.981253687094257, 4.066817894913033, 4.860392291381515, 5.894756678334094, 6.839275655807207, 7.772747773715921, 4.827481580236349, 5.89351764697697, 6.939263307004374, 7.873375071426753, 8.929016910357378, 9.892359588417067, 10.862493775885497, 11.857292929669311, 11.643675893063804, 10.627897738731422, 9.695095861071183, 8.655396158840068, 7.691436891041125, 6.746710996473259, 5.944641090513362, 5.0225120589497925, 5.862065637727651, 6.838172767850759, 7.772591022683854, 8.698105756127113, 5.771864370669006, 6.743428387584132, 7.816414896749657, 8.805973680198742, 9.81081751335403, 10.83228077222575, 11.807761984307676, 12.854460398633176, 12.52584862629427, 11.585076619356025, 10.5346747780655, 9.60682982864786, 8.638751019594288, 7.679950972069113, 6.900221363542063, 5.947594116137943, 6.8088240107197375, 7.783219112093816, 8.775888418325836, 9.652589805275301, 6.741227092634284, 7.731041126384462, 8.771677898940155, 9.845125143403529, 10.780552498345132, 11.771730615040152, 12.72910919111883, 13.759319189379838, 13.553365481589806, 12.515036600249163, 11.463950307067208, 10.568200871277659, 9.609255398484427, 8.730617611487286, 7.885733798765766, 7.001037655577313, 7.740045321712054, 8.715090761971243, 9.664538784261048, 10.597335489084227, 7.721493486511401, 8.667586886850161, 9.72960092706256, 10.70084175932659, 11.72833535697818, 12.698181225128625, 13.678954226430738, 14.627963628182277, 14.529075513940835, 13.539145887348347, 12.510439976037961, 11.548576004136722, 10.65953110789037, 9.775545826343368, 8.852206779169112, 7.934085887572928, 8.754333301125698, 9.729714260142076, 10.626970916883973, 11.58545402790545, 8.662294028814305, 9.626726003726521, 10.594682123082242, 11.550025040692997, 11.186395898674657, 12.018715120602636, 12.80893737382912, 13.645155505265983, 14.681479548748607, 14.52202739835825, 13.456983557751409, 12.516091556693354, 11.670155852085184, 10.795356662628075, 9.864802670379872, 8.892940420075265, 9.789939193334828, 10.727077821721522, 11.690334142196107, 12.623847372800682, 9.708683005863012, 10.67794519135996, 11.524483596487006, 11.030709765970744, 10.144045614533383, 10.966145257957727, 11.876961237724066, 12.65540551369723, 13.641790657065595, 14.521923843785883, 14.408797888879977, 13.48515576080314, 12.714660682249432, 11.749976867663593, 10.806010339081611, 9.94338111993774, 10.789225887576247, 11.718862198057552, 12.707907432384559, 13.637406533736664, 10.685957702040618, 11.688724280225522, 10.81216528733517, 10.035717866094085, 9.143524525158139, 10.014100819312205, 10.855965007159853, 11.715623994825142, 12.65032221320251, 13.552482954942818, 14.497852903475726, 14.49065945509328, 13.675323488154556, 12.775992157812633, 11.816867700271377, 10.876562701083214, 11.72989080467692, 12.693376345714624, 13.64240144100459, 14.59551322861727, 11.621998786133684, 10.77545165938734, 9.769199521446042, 8.97453838617105, 8.126005702927863, 9.07654508654637, 9.796735324813138, 10.75154241115814, 11.722743238599266, 12.595671836399978, 13.551534832724174, 14.450720688686717, 14.604026459448697, 13.753599210279246, 12.799979600059045, 11.850554331033914, 12.766209126285599, 13.729742474514623, 14.614239475752207, 15.54719887615412], [15.661337134510756, 14.79381346084281, 13.865589127240495, 12.919657698549852, 13.76652850515513, 14.672965948659776, 15.64032746322738, 15.485048364564129, 14.465818874315527, 13.527104121663815, 12.598364647139867, 11.64093258438076, 10.765694940983492, 9.796298566144113, 9.006857133164074, 8.064735519273123, 7.020090203425662, 7.830734215962446, 8.831851672073, 9.745417507032755, 14.658873807363474, 15.430161351434291, 14.827673552360396, 13.887327742098321, 14.695682718661729, 15.613165274913705, 15.57053172450875, 14.53547650076174, 13.65226613529217, 12.698836337974576, 11.698688578704875, 10.706049115954208, 9.77337237708531, 8.862263358922913, 7.998600973132747, 7.099978895874509, 6.060042427703271, 6.850281792256536, 7.804231965827337, 8.726768166301248, 13.776456413702503, 14.497129757963021, 15.439752624805797, 14.907782489066998, 15.641335944223927, 15.602337222087272, 14.608239716885702, 13.58890698629636, 12.630088749736469, 11.71368280491743, 10.777603779324084, 9.759669223923394, 8.735543132000823, 7.823835911041817, 7.024171355344873, 6.080552120789203, 5.088992880939445, 5.9062240155702135, 6.84573647275238, 7.767500380894168, 12.764137305061942, 13.539375407068835, 14.502541260872583, 15.554943265314172, 15.576706284930568, 14.624694619055024, 13.668304671691553, 12.638671099667237, 11.654863128984342, 10.668734827647413, 9.711353756266035, 8.708441433820592, 7.749976949082059, 6.881499873281219, 5.989130483570719, 5.130863258977268, 4.0781782728272455, 4.930272649803244, 5.9504703174529165, 6.796756599674211, 11.71884570397378, 12.546929392420427, 13.524768471506235, 14.516267149611206, 14.591072893253362, 13.663890330927082, 12.734212441353563, 11.695373156534352, 10.74151752840539, 9.768047985879642, 8.738691343111421, 7.772894473972277, 6.806377741747467, 5.896925791562393, 4.939756286579717, 4.110711682465901, 3.0826939081605875, 3.998529084668067, 4.9315645732348665, 5.84548318013164, 10.656735972325453, 11.53975111610264, 12.564267651670994, 13.566785372609427, 13.961442480399766, 12.924050551983147, 11.956243821873501, 10.931399624622122, 9.870233439340563, 8.8007782542585, 7.79690325081858, 6.852708171886761, 5.8413339496944445, 4.895712239176161, 3.919352127866677, 3.060887207105141, 2.0412914553163137, 2.962514645821834, 3.9304349496821036, 4.78792644349871, 9.635798042827277, 10.575754902436081, 11.546948917154776, 12.565490546229992, 13.01005426936848, 11.96136848563692, 10.979455166044177, 9.92817402748974, 8.966020816944404, 7.947489554584742, 6.884421831242982, 5.918024949162048, 4.896371835710643, 3.8720802891683332, 2.940771768983879, 1.990375033460334, 0.9667132833034688, 1.9095396236783249, 2.889147325248132, 3.818213153772664, 8.705169410846917, 9.769634674263017, 10.67311600146047, 11.661332980720614, 11.978371069169938, 11.03863480775914, 9.999162356630396, 8.971361074622848, 8.013077006186778, 6.952853265721186, 5.943103101919365, 4.966906345701746, 3.9687516214169, 3.0305469866417862, 1.9672031030160433, 0.947419919318868, 0.0, 0.9842855905552755, 1.939531415600897, 2.9490773816661924, 7.827553996859223, 8.815548126508837, 9.705053204582013, 10.671904131807981, 11.627562268067535, 11.774603803233589, 10.709504096246503, 9.773980191411074, 8.793711523843388, 7.770363095146131, 6.752449278312006, 5.713488275074454, 4.733915129432533, 3.807414350910098, 2.852673695900517, 1.9252238098469336, 1.0249132738023623, 1.9905095398744161, 3.0021362464546715, 3.9171181094649024, 6.875336315635637, 7.75696881113749, 8.757590712791128, 9.751666906514613, 10.694536237186872, 11.67580724576524, 11.679024829028856, 10.647923380222771, 9.658696938791413, 8.728859103570205, 7.663149558847233, 6.7171593694316645, 5.776859821509186, 4.800184060174452, 3.8512058496159147, 2.9235788801067075, 1.9994032558445332, 2.923807441417143, 3.954690779995207, 4.911128048951818, 5.865413047278967, 6.8121606412653195, 7.833263204413407, 8.863340330874328, 9.889380168841138, 10.817745635170956, 11.892571932914802, 11.694749481857425, 10.675751004035789, 9.631026875128986, 8.651084085563333, 7.682319857197918, 6.798708581641248, 5.734972469183389, 4.887897018654591, 3.993181112092558, 3.019944828439307, 3.98429243787423, 4.880061213806721, 5.856972714215292, 4.946376711551048, 5.982296161143007, 6.960329027119689, 7.898891458088133, 8.925633553179624, 9.89516756178132, 10.910766940436204, 11.904644293350186, 11.68215622138868, 10.616602972104625, 9.630067107125583, 8.636538652704667, 7.71363868701744, 6.705645928809768, 5.928673606413124, 4.974997557526462, 3.973487863241559, 5.007852250194138, 5.918807491785544, 6.827780618348494, 3.8800616609174807, 4.946097727658101, 5.991843387685505, 6.925955152107884, 7.981596991038508, 8.944939669098197, 9.915073856566627, 10.909873010350442, 11.925286860114568, 11.57531765805029, 10.64251578039005, 9.602816078158936, 8.638856810359993, 7.694130915792127, 6.892061009832229, 5.930691721563222, 4.975161209587696, 5.951268339710802, 6.885686594543897, 7.753138600759686, 4.824444451350137, 5.7960084682652635, 6.868994977430789, 7.8585537608798735, 8.863397594035161, 9.884860852906883, 10.860342064988806, 11.907040479314306, 12.85627558332948, 12.532496538674893, 11.482094697384369, 10.554249747966729, 9.586170938913156, 8.627370891387981, 7.8476412828609305, 6.855773778751373, 5.921919582579783, 6.896314683953859, 7.888983990185879, 8.707622649907876, 5.7938071733154155, 6.783621207065594, 7.824257979621286, 8.89770522408466, 9.833132579026264, 10.824310695721284, 11.781689271799962, 12.81189927006097, 13.776652281873588, 13.46245651956803, 12.411370226386076, 11.515620790596527, 10.556675317803295, 9.678037530806154, 8.833153718084633, 7.892758776619821, 6.853140893572099, 7.828186333831286, 8.77763435612109, 9.71043106094427, 6.7740735671925325, 7.720166967531293, 8.782181007743691, 9.753421840007721, 10.780915437659312, 11.750761305809757, 12.73153430711187, 13.680543708863409, 14.74850560837572, 14.486565806667215, 13.45785989535683, 12.49599592345559, 11.606951027209238, 10.722965745662236, 9.79962669848798, 8.825807008615435, 7.867428872985743, 8.842809832002118, 9.740066488744016, 10.698549599765494, 7.714874109495437, 8.679306084407653, 9.647262203763374, 10.602605121374129, 11.596593739008995, 12.66243010718306, 13.665678991235653, 14.592575424584851, 15.628899468067475, 15.469447317677119, 14.404403477070277, 13.463511476012222, 12.617575771404052, 11.742776581946943, 10.811691540255191, 9.78466154111777, 8.903034765194873, 9.840173393581566, 10.80342971405615, 11.736942944660726, 8.761263086544144, 9.730525272041092, 10.577063677168137, 10.083289846651876, 11.023502788012365, 11.913565177276595, 12.824381157042934, 13.602825433016099, 14.589210576384465, 15.469343763104751, 15.356217808198846, 14.432575680122008, 13.6620806015683, 12.69739678698246, 11.752899208956931, 10.83171505775862, 9.902321459436292, 10.831957769917597, 11.821003004244604, 12.750502105596707, 9.73853778272175, 10.741304360906653, 9.864745368016301, 9.088297946775217, 10.022981698637121, 10.961520738631073, 11.80338492647872, 12.66304391414401, 13.59774213252138, 14.499902874261686, 15.445272822794596, 15.438079374412148, 14.622743407473424, 13.723412077131501, 12.763756570146697, 11.764896638904094, 10.842986376536965, 11.806471917574669, 12.755497012864636, 13.708608800477315, 10.674578866814816, 9.828031740068472, 8.821779602127174, 8.027118466852182, 9.005462876406845, 10.023965005865238, 10.744155244132006, 11.698962330477007, 12.670163157918136, 13.543091755718848, 14.498954752043044, 15.398140608005587, 15.551446378767565, 14.681506897999997, 13.727887287779795, 12.738888268854794, 11.879304698145644, 12.842838046374668, 13.727335047612252, 14.660294448014165], [14.82424202677023, 14.00348293670776, 13.075258603105446, 13.901154831775738, 14.748025638381016, 15.654463081885662, 16.621824596453266, 16.469333955119406, 15.450104464870803, 14.51138971221909, 13.582650237695143, 12.625218174936036, 11.749980531538768, 10.780584156699389, 9.965818747915424, 8.974136455463091, 7.922723000776004, 6.959994517322573, 7.9042526400596165, 8.76113191647748, 13.821778699622948, 14.445875760879018, 14.111564423765426, 14.868824875324208, 15.677179851887615, 16.59466240813959, 16.554817315064025, 15.519762091317014, 14.636551725847443, 13.683121928529852, 12.68297416926015, 11.690334706509484, 10.757657967640586, 9.846548949478189, 8.982886563688023, 8.050380315131418, 7.01044384696018, 5.979542093616663, 6.876632933813954, 7.7424825757459725, 12.815425037127792, 13.512844167407748, 14.455467034250523, 15.455858444228507, 16.45325038415919, 16.586622812642545, 15.592525307440976, 14.573192576851634, 13.614374340291743, 12.697968395472705, 11.761889369879357, 10.74395481447867, 9.719828722556098, 8.808121501597093, 8.008456945900148, 7.064837711344478, 6.073278471494721, 5.035484316930341, 5.918137440738997, 6.783214790338892, 11.80310592848723, 12.555089816513561, 13.51825567031731, 14.570657674758898, 15.448310084432485, 15.608980209610298, 14.652590262246827, 13.62295669022251, 12.639148719539616, 11.653020418202686, 10.69563934682131, 9.692727024375868, 8.734262539637335, 7.865785463836494, 6.9734160741259945, 6.1151488495325435, 5.062463863382521, 4.059532951163371, 4.989653357662694, 5.812471009118935, 10.75781432739907, 11.562643801865153, 12.540482880950961, 13.531981559055932, 14.462676692755279, 14.648175921482355, 13.718498031908837, 12.679658747089626, 11.725803118960664, 10.752333576434916, 9.722976933666695, 8.757180064527553, 7.790663332302743, 6.881211382117669, 5.924041877134993, 5.0949972730211766, 4.066979498715863, 3.1277893860281942, 3.9472789826795918, 4.861197589576364, 9.695704595750742, 10.555465525547366, 11.57998206111572, 12.582499782054153, 13.51013779521817, 13.908336142538422, 12.940529412428777, 11.915685215177396, 10.854519029895837, 9.785063844813774, 8.781188841373854, 7.836993762442036, 6.82561954024972, 5.879997829731437, 4.903637718421953, 4.045172797660417, 3.0255770458715894, 2.0917749471819613, 2.946149359126829, 3.803640852943435, 8.651512452272003, 9.591469311880807, 10.562663326599502, 11.581204955674718, 12.54419831943006, 12.945654076192195, 11.963740756599453, 10.912459618045016, 9.95030640749968, 8.931775145140017, 7.868707421798257, 6.902310539717323, 5.880657426265919, 4.856365879723609, 3.9250573595391547, 2.9746606240156095, 1.9509988738587443, 1.0387999250384519, 1.9048617346928567, 2.833927563217389, 7.720883820291642, 8.785349083707741, 9.688830410905194, 10.677047390165338, 11.569100335928187, 12.022920398314415, 10.983447947185672, 9.955646665178124, 8.997362596742054, 7.937138856276461, 6.927388692474641, 5.951191936257022, 4.953037211972175, 4.014832577197062, 2.951488693571319, 1.9317055098741436, 0.9842855905552755, 0.0, 0.9552458250456214, 1.9647917911109167, 6.843268406303947, 7.831262535953561, 8.720767614026737, 9.687618541252705, 10.64327667751226, 11.625530285603984, 11.693789686801777, 10.758265781966347, 9.777997114398662, 8.754648685701405, 7.736734868867281, 6.6977738656297285, 5.7182007199878075, 4.791699941465373, 3.836959286455792, 2.909509400402209, 2.009198864357638, 1.0668408133723515, 2.017850655899396, 2.9328325189096267, 5.89105072508036, 6.772683220582214, 7.773305122235852, 8.767381315959337, 9.710250646631597, 10.691521655209964, 11.627810779019534, 11.632208970778045, 10.642982529346687, 9.713144694125479, 8.647435149402506, 7.701444959986938, 6.761145412064461, 5.784469650729727, 4.83549144017119, 3.9078644706619827, 2.98090038907042, 2.000138714915078, 2.9704051894399313, 3.9268424583965422, 4.88112745672369, 5.827875050710043, 6.84897761385813, 7.879054740319051, 8.905094578285862, 9.83346004461568, 10.908286342359526, 11.851730338269853, 11.660036594591062, 10.61531246568426, 9.635369676118607, 8.666605447753192, 7.782994172196522, 6.719258059738664, 5.872182609209867, 4.977466702647834, 4.0014419616651935, 3.0606237113721653, 3.8957756232514456, 4.872687123660016, 3.962091120995772, 4.998010570587732, 5.976043436564414, 6.914605867532858, 7.941347962624349, 8.910881971226047, 9.92648134988093, 10.92035870279491, 11.898263783044678, 11.600888562659899, 10.614352697680857, 9.620824243259941, 8.697924277572715, 7.689931519365043, 6.911119457387701, 5.95649469075235, 4.954984996467446, 4.117164622697024, 4.934521901230268, 5.843495027793218, 2.895776070362205, 3.9618121371028256, 5.0075577971302305, 5.941669561552609, 6.997311400483233, 7.960654078542922, 8.930788266011351, 9.925587419795166, 10.941001269559292, 11.956779423891675, 11.626801370945326, 10.587101668714212, 9.623142400915269, 8.678416506347402, 7.8744365298493, 6.912188854789109, 5.956658342813583, 5.130132324828237, 5.952022291812965, 6.768853010204411, 3.8401588607948622, 4.811722877709989, 5.884709386875514, 6.874268170324598, 7.879112003479885, 8.900575262351605, 9.87605647443353, 10.92275488875903, 11.871989992774205, 12.81276199971245, 12.466380287939645, 11.538535338522005, 10.570456529468432, 9.611656481943257, 8.830016802878001, 7.83727091197726, 6.903416715805669, 6.075178669071294, 6.9553196874549466, 7.7233370593526, 4.809521582760141, 5.799335616510319, 6.839972389066011, 7.913419633529386, 8.848846988470987, 9.840025105166006, 10.797403681244685, 11.827613679505692, 12.79236669131831, 13.742721980605587, 13.395655816941352, 12.499906381151803, 11.54096090835857, 10.66232312136143, 9.815529238101703, 8.874255909845708, 7.834638026797985, 7.00705031894872, 7.881965872978831, 8.780908628413119, 5.789787976637258, 6.735881376976018, 7.797895417188417, 8.769136249452446, 9.796629847104036, 10.766475715254481, 11.747248716556594, 12.696258118308133, 13.764220017820444, 14.766831267704772, 14.442145485912105, 13.480281514010866, 12.591236617764512, 11.707251336217512, 10.78200221850505, 9.807304141841323, 8.848926006211629, 8.021673817119552, 8.844398005601757, 9.802881116623235, 6.730588518940162, 7.695020493852378, 8.662976613208098, 9.618319530818853, 10.612308148453721, 11.678144516627786, 12.68139340068038, 13.69319423715417, 14.729518280636794, 15.706688329595805, 15.388689067625553, 14.447797066567498, 13.601861361959326, 12.727062172502219, 11.79318867348108, 10.766158674343659, 9.884531898420759, 9.019037378699, 9.907761230913891, 10.841274461518466, 7.776977495988869, 8.746239681485816, 9.592778086612862, 10.604430400978119, 11.562565803755767, 12.622165446883717, 13.613369536785434, 14.587111023571374, 15.57349616693974, 16.45362935366003, 16.340503398754123, 15.416861270677284, 14.646366192123576, 13.681682377537737, 12.73439634218282, 11.813212190984506, 10.883818592662179, 10.030988518890455, 10.957839021646516, 11.854833622454448, 8.754252192166474, 9.757018770351378, 8.99400566937643, 9.99093074412556, 10.93238263482709, 11.886154396339691, 12.787670517033996, 13.647329504699286, 14.582027723076656, 15.484188464816963, 16.42955841334987, 16.42236496496742, 15.6070289980287, 14.707697667686777, 13.745253703372585, 12.74639377212998, 11.824483509762851, 11.01614139343962, 11.965166488729587, 12.887980062508289, 9.69029327625954, 8.900432708055089, 7.951039903487302, 8.929751264202524, 9.914863812596813, 10.948598663573856, 11.728440834687282, 12.683247921032283, 13.654448748473412, 14.527377346274124, 15.48324034259832, 16.38242619856086, 16.535731969322843, 15.663004031225883, 14.709384421005682, 13.72038540208068, 12.86080183137153, 12.052507522239619, 12.937004523477203, 13.83966571004514], [13.868996201724608, 13.057272277768213, 13.876320999877649, 14.779023465257522, 15.625894271862801, 16.532331715367445, 17.499693229935048, 17.42457978016503, 16.405350289916427, 15.466635537264713, 14.537896062740765, 13.580463999981658, 12.70522635658439, 11.73582998174501, 10.832738503860625, 9.841056211408292, 8.789642756721205, 7.826914273267774, 6.949006815013995, 7.805886091431859, 12.866532874577326, 13.490629935833395, 14.463270515325734, 15.403616325587809, 16.385998537329698, 17.38090190444299, 17.510063140109647, 16.47500791636264, 15.591797550893066, 14.638367753575475, 13.638219994305773, 12.645580531555106, 11.712903792686209, 10.80179477452381, 9.896026283993455, 8.91730007107662, 7.877363602905381, 6.846461849561864, 5.921387108768332, 6.787236750700351, 11.86017921208217, 12.557598342362125, 13.5002212092049, 14.500612619182885, 15.49800455911357, 16.415080330740487, 16.5477711324866, 15.528438401897256, 14.569620165337366, 13.653214220518327, 12.71713519492498, 11.699200639524292, 10.67507454760172, 9.763367326642713, 8.963702770945769, 7.9716157337881155, 6.966088857806996, 5.902404072875542, 4.962891615693375, 5.8279689652932705, 10.847860103441608, 11.599843991467939, 12.563009845271687, 13.615411849713276, 14.493064259386863, 15.437437727708241, 15.60783608729245, 14.578202515268133, 13.594394544585239, 12.608266243248309, 11.650885171866932, 10.64797284942149, 9.689508364682958, 8.821031288882116, 7.928661899171616, 7.021926871976181, 5.9692418858261584, 4.955008879356666, 4.034407532617072, 4.857225184073314, 9.802568502353447, 10.60739797681953, 11.585237055905338, 12.57673573401031, 13.507430867709656, 14.434613430035935, 14.67374385695446, 13.634904572135248, 12.681048944006287, 11.707579401480539, 10.678222758712318, 9.712425889573176, 8.745909157348365, 7.83645720716329, 6.879287702180615, 6.041110147104743, 5.013092372799431, 4.023265314221489, 2.99203315763397, 3.9059517645307427, 8.74045877070512, 9.600219700501743, 10.624736236070097, 11.62725395700853, 12.554891970172548, 13.56257435661419, 13.8957752374744, 12.870931040223018, 11.80976485494146, 10.740309669859396, 9.736434666419477, 8.792239587487659, 7.780865365295342, 6.8352436547770585, 5.858883543467575, 4.9912856717439835, 3.9716899199551565, 2.9872508753752562, 1.9909035340812071, 2.8483950278978134, 7.696266627226381, 8.636223486835185, 9.60741750155388, 10.625959130629095, 11.588952494384438, 12.595328031622591, 12.918986581645076, 11.867705443090639, 10.905552232545302, 9.887020970185638, 8.82395324684388, 7.857556364762945, 6.8359032513115405, 5.811611704769231, 4.880303184584776, 3.9207734980991766, 2.8971117479423114, 1.9542854075674556, 0.9496159096472352, 1.878681738171767, 6.765637995246021, 7.8301032586621195, 8.733584585859573, 9.721801565119717, 10.613854510882566, 11.553590772293365, 11.938693772231295, 10.910892490223747, 9.952608421787676, 8.892384681322083, 7.8826345175202635, 6.906437761302644, 5.908283037017798, 4.970078402242684, 3.9067345186169407, 2.886951334919765, 1.939531415600897, 0.9552458250456214, 0.0, 1.0095459660652955, 5.8880225812583245, 6.87601671090794, 7.765521788981117, 8.732372716207085, 9.688030852466639, 10.670284460558364, 11.676651013896162, 11.71351160701197, 10.733242939444285, 9.709894510747027, 8.691980693912903, 7.65301969067535, 6.673446545033429, 5.746945766510994, 4.7922051115014135, 3.864755225447831, 2.9644446894032592, 2.022086638417973, 1.0626048308537746, 1.9775866938640054, 4.935804900034739, 5.817437395536593, 6.818059297190231, 7.8121354909137155, 8.755004821585976, 9.736275830164344, 10.672564953973913, 11.703666402779998, 11.59822835439231, 10.668390519171101, 9.602680974448129, 8.656690785032561, 7.7163912371100825, 6.739715475775348, 5.790737265216812, 4.863110295707605, 3.9361462141160417, 2.9553845399606997, 2.01515936439431, 2.971596633350921, 3.9258816316780694, 4.872629225664422, 5.893731788812509, 6.923808915273431, 7.949848753240241, 8.87821421957006, 9.953040517313905, 10.896484513224234, 11.91548299104587, 11.570558290729883, 10.59061550116423, 9.621851272798814, 8.738239997242143, 7.6745038847842855, 6.82742843425549, 5.932712527693456, 4.956687786710816, 3.958199809248229, 2.940529798205824, 3.9174412986143947, 3.006845295950151, 4.042764745542111, 5.020797611518793, 5.959360042487236, 6.986102137578727, 7.955636146180424, 8.971235524835308, 9.96511287774929, 10.943017957999057, 12.008571207283113, 11.56959852272648, 10.576070068305564, 9.653170102618336, 8.645177344410664, 7.866365282433324, 6.911740515797972, 5.9102308215130686, 4.9985729723024885, 3.9792760761846466, 4.8882492027475966, 1.9405302453165838, 3.0065663120572044, 4.052311972084609, 4.986423736506987, 6.042065575437611, 7.005408253497301, 7.9755424409657305, 8.970341594749545, 9.985755444513671, 11.001533598846054, 11.934335476506293, 11.542347493759832, 10.57838822596089, 9.633662331393023, 8.829682354894922, 7.867434679834732, 6.907301851723545, 5.931194721600439, 4.9967764667673435, 5.813607185158789, 2.8849130357492405, 3.856477052664367, 4.929463561829892, 5.919022345278977, 6.923866178434264, 7.945329437305984, 8.92081064938791, 9.96750906371341, 10.916744167728584, 11.857516174666829, 12.902229498788323, 12.493781163567625, 11.525702354514053, 10.566902306988878, 9.785262627923624, 8.792516737022883, 7.8540602247156315, 6.876241065843495, 6.000073862409325, 6.768091234306978, 3.8542757577145186, 4.844089791464698, 5.884726564020389, 6.958173808483764, 7.893601163425366, 8.884779280120386, 9.842157856199064, 10.872367854460071, 11.83712086627269, 12.787476155559967, 13.83150502779003, 13.455152206197424, 12.496206733404192, 11.61756894640705, 10.770775063147326, 9.82489941875567, 8.785281535707949, 7.808112715720922, 6.926720047933209, 7.825662803367498, 4.834542151591635, 5.780635551930396, 6.842649592142794, 7.813890424406823, 8.841384022058413, 9.811229890208859, 10.792002891510972, 11.74101229326251, 12.808974192774821, 13.811585442659151, 14.862749382932932, 14.435527339056486, 13.546482442810134, 12.662497161263133, 11.737248043550673, 10.757947650751285, 9.799569515121593, 8.822736213891755, 7.889152180556135, 8.847635291577612, 5.775342693894539, 6.7397746688067555, 7.7077307881624755, 8.66307370577323, 9.657062323408098, 10.722898691582163, 11.726147575634757, 12.737948412108548, 13.774272455591172, 14.751442504550182, 15.80929296464638, 15.403042891613119, 14.557107187004949, 13.68230799754784, 12.743832182391042, 11.716802183253622, 10.81142502311109, 9.820099775471203, 8.952515405868269, 9.886028636472844, 6.821731670943247, 7.790993856440194, 8.63753226156724, 9.649184575932496, 10.607319978710144, 11.666919621838094, 12.658123711739812, 13.667663712949707, 14.738836555538088, 15.666987738017117, 16.66802994964175, 16.372107095722907, 15.593262142464505, 14.628578327878666, 13.636459903236066, 12.69108082446629, 11.761687226143962, 10.832050915662657, 10.002593196600893, 10.899587797408826, 7.799006367120853, 8.801772945305755, 9.58879643979677, 10.595616229896937, 11.607841068085389, 12.610690885249435, 13.553644062524219, 14.492539369711917, 15.429580642960852, 16.365347226368822, 17.384804238395496, 17.377610790013044, 16.553924948369627, 15.654593618027706, 14.643687227084326, 13.624262405611764, 12.702352143244635, 11.817203790211822, 11.01895582979004, 11.932734237462666, 8.73504745121392, 7.945186883009467, 8.817959659432503, 9.796671020147725, 10.781783568542014, 11.815518419519057, 12.683686659732903, 13.638493746077906, 14.609694573519034, 15.482623171319746, 16.438486167643944, 17.337672023606487, 17.48262791966377, 16.540872664707667, 15.587253054487466, 14.598254035562464, 13.738670464853314, 12.853569919011822, 11.990793864537656, 12.884419884999517], [12.859450235659313, 13.425639779318013, 14.416722157084184, 15.361740403070982, 16.301257784668817, 17.31155526463163, 18.186707262361544, 18.434125746230325, 17.414896255981724, 16.47618150333001, 15.547442028806062, 14.590009966046955, 13.648172036298902, 12.638314564735726, 11.70549319635817, 10.713810903905836, 9.66239744921875, 8.69966896576532, 7.821761507511541, 6.915857272045106, 11.856986908512031, 12.481083969768099, 13.453724549260437, 14.394070359522512, 15.3764525712644, 16.3713559383777, 17.231930887474483, 17.48455388242793, 16.601343516958362, 15.647913719640771, 14.64776596037107, 13.655126497620403, 12.722449758751505, 11.719427111124093, 10.768780976491001, 9.790054763574165, 8.750118295402928, 7.71921654205941, 6.794141801265878, 5.8972079313135986, 10.850633246016875, 11.548052376296829, 12.490675243139604, 13.491066653117588, 14.488458593048273, 15.405534364675196, 16.269638879851435, 16.53798436796255, 15.579166131402662, 14.662760186583624, 13.726681160990275, 12.708746605589589, 11.684620513667017, 10.772913292708008, 9.950126427885056, 8.9023004505704, 7.838843550304542, 6.775158765373088, 5.835646308190921, 4.937940145906518, 9.838314137376313, 10.590298025402642, 11.55346387920639, 12.60586588364798, 13.483518293321568, 14.427891761642949, 15.329703834657286, 15.58774848133343, 14.603940510650535, 13.617812209313605, 12.660431137932227, 11.657518815486787, 10.699054330748254, 9.83057725494741, 8.938207865236912, 7.990029709638492, 6.9373447234884695, 5.923111717018977, 4.907162225114618, 3.9671963646865613, 8.793022536288152, 9.597852010754234, 10.575691089840042, 11.567189767945015, 12.497884901644362, 13.425067463970642, 14.35474535354416, 14.644450538200543, 13.690594910071582, 12.717125367545833, 11.687768724777612, 10.721971855638472, 9.755455123413661, 8.846003173228585, 7.88883366824591, 7.009212984767054, 5.981195210461742, 4.9913681518838, 3.960135995296281, 3.0159229451439904, 7.730912804639825, 8.590673734436447, 9.615190270004803, 10.617707990943236, 11.545346004107254, 12.553028390548894, 13.520835120658539, 13.880477006288313, 12.819310821006754, 11.74985563592469, 10.745980632484772, 9.801785553552953, 8.790411331360637, 7.844789620842354, 6.86842950953287, 5.959388509406295, 4.939792757617468, 3.9553537130375673, 2.959006371743518, 1.9583662085110607, 6.686720661161085, 7.626677520769889, 8.597871535488585, 9.6164131645638, 10.579406528319144, 11.585782065557295, 12.567695385150037, 12.877251409155935, 11.915098198610599, 10.896566936250935, 9.833499212909175, 8.86710233082824, 7.845449217376836, 6.821157670834526, 5.889849150650072, 4.888876335761488, 3.865214585604623, 2.922388245229767, 1.9177187473095465, 0.9886529187850145, 5.756092029180725, 6.820557292596823, 7.7240386197942765, 8.712255599054421, 9.60430854481727, 10.544044806228069, 11.583517257356812, 11.920438456289043, 10.962154387852973, 9.90193064738738, 8.892180483585559, 7.915983727367939, 6.917829003083092, 5.979624368307979, 4.916280484682236, 3.8964973009850605, 2.9490773816661924, 1.9647917911109167, 1.0095459660652955, 0.0, 4.87847661519303, 5.866470744842644, 6.75597582291582, 7.722826750141788, 8.678484886401343, 9.660738494493067, 10.667105047830866, 11.602628952666295, 11.742788905509581, 10.719440476812323, 9.7015266599782, 8.662565656740647, 7.682992511098726, 6.756491732576291, 5.80175107756671, 4.874301191513126, 3.9739906554685547, 3.031632604483268, 2.0087471848625467, 0.9680407277987101, 3.926258933969444, 4.807891429471297, 5.808513331124935, 6.802589524848419, 7.745458855520679, 8.726729864099047, 9.663018987908616, 10.694120436714702, 11.68334687814606, 11.677936485236398, 10.612226940513425, 9.666236751097857, 8.725937203175379, 7.749261441840645, 6.800283231282107, 5.8726562617728995, 4.945692180181337, 3.9649305060259947, 2.961301718403082, 1.9620506672856257, 2.916335665612774, 3.8630832595991267, 4.884185822747214, 5.914262949208135, 6.940302787174945, 7.868668253504764, 8.943494551248609, 9.886938547158937, 10.905937024980574, 11.950661153887376, 11.600161467229526, 10.63139723886411, 9.747785963307441, 8.684049850849583, 7.836974400320784, 6.94225849375875, 5.966233752776111, 4.9043421632570015, 3.8866721522145964, 2.9078953325490997, 1.9972993298848554, 3.0332187794768153, 4.0112516454534966, 4.949814076421941, 5.976556171513431, 6.946090180115129, 7.961689558770012, 8.955566911683993, 9.93347199193376, 10.999025241217817, 11.941481794829256, 11.58561603437086, 10.662716068683634, 9.654723310475962, 8.875911248498618, 7.921286481863267, 6.919776787578363, 5.915565940287896, 4.8962690441700545, 3.8787032366823015, 0.9309842792512885, 1.997020345991909, 3.0427660060193134, 3.9768777704416918, 5.032519609372316, 5.995862287432005, 6.965996474900435, 7.960795628684249, 8.976209478448375, 9.991987632780758, 10.924789510440997, 11.964489212672111, 11.587934192026188, 10.64320829745832, 9.725522221845356, 8.763274546785166, 7.712432937939139, 6.736325807816033, 5.801907552982938, 4.8040612190934935, 1.9833569604921761, 2.9549209774073026, 4.027907486572827, 4.909476379213681, 5.914320212368968, 6.935783471240688, 7.911264683322614, 8.957963097648113, 9.907198201663288, 10.847970208601533, 11.892683532723026, 12.820528482140666, 12.53524832057935, 11.576448273054176, 10.681102494874057, 9.652210354759273, 8.659191310931226, 7.681372152059089, 6.783022307689899, 5.758545268241683, 2.962913342578623, 3.9425337162076333, 4.983170488763324, 5.980970014437979, 6.88405519736007, 7.875233314055089, 8.832611890133768, 9.862821888394775, 10.827574900207393, 11.77793018949467, 12.821959061724733, 13.792197225155633, 13.480570627500555, 12.523525353161977, 11.587728165577902, 10.630030504971264, 9.590412621923543, 8.613243801936516, 7.709668493213783, 6.816116837302202, 3.94317973645574, 4.889273136794501, 5.9512871770069, 6.922528009270929, 7.900664321952488, 8.870510190102934, 9.83371184080128, 10.78272124255282, 11.803284932558423, 12.802039476593855, 13.853203416867636, 14.772572358014695, 14.530846336906496, 13.56845356801806, 12.55420114598125, 11.56307873696688, 10.604700601337187, 9.627867300107349, 8.672100625836709, 7.846335109389105, 4.883980278758645, 5.848412253670861, 6.816368373026581, 7.771711290637335, 8.765699908272202, 9.831536276446267, 10.83478516049886, 11.779657361398858, 12.795596958926154, 13.772767007885165, 14.799746998581083, 15.740087910571328, 15.54147108110131, 14.559033009111156, 13.548963268606636, 12.521933269469216, 11.616556109326682, 10.625230861686795, 9.735463851148843, 8.884728454284337, 5.931702851556495, 6.899631441304299, 7.746169846431345, 8.757822160796602, 9.71595756357425, 10.7755572067022, 11.766761296603915, 12.76940735296761, 13.84058019555599, 14.76873137803502, 15.751561329709652, 16.709152114681114, 16.398393228680096, 15.433709414094258, 14.441590989451658, 13.496211910681883, 12.566818312359555, 11.63718200187825, 10.785541641881467, 9.898287615220319, 6.908977547734101, 7.910410530169861, 8.697434024660875, 9.704253814761042, 10.716478652949494, 11.71932847011354, 12.662281647388324, 13.601176954576022, 14.538218227824958, 15.473984811232928, 16.54700273626122, 17.529924492489766, 17.35905603458522, 16.459724704243296, 15.448818313299919, 14.429393491827357, 13.507483229460227, 12.622334876427415, 11.801904275070614, 10.93143405527416, 7.845018631827168, 8.817941575507012, 9.690714351930048, 10.66942571264527, 11.654538261039558, 12.656884202879375, 13.58617124272362, 14.565258538243025, 15.465797202428202, 16.430795929775766, 17.38665892609996, 18.347217989671783, 18.287759005879362, 17.34600375092326, 16.392384140703058, 15.403385121778056, 14.543801551068906, 13.658701005227414, 12.77374230981823, 11.88311970281101], [8.035776818870985, 8.601966362529685, 9.593048740295856, 10.538066986282654, 11.477584367880489, 12.4878818478433, 13.363033845573215, 14.32903533724512, 15.348264827493722, 16.286979580145434, 17.215719054669382, 18.17315111742849, 18.43398216602029, 17.516791179928756, 16.5839698115512, 15.592287519098864, 14.540874064411778, 13.578145580958347, 12.70023812270457, 11.794333887238135, 7.033313491723703, 7.657410552979772, 8.63005113247211, 9.570396942734185, 10.552779154476072, 11.54768252158937, 12.408257470686154, 13.43664612184864, 14.4514836342634, 15.45631743070272, 16.456465189972423, 17.44910465272309, 17.441659602122108, 16.597903726317117, 15.647257591684028, 14.668531378767192, 13.628594910595954, 12.597693157252438, 11.672618416458908, 10.775684546506628, 6.026959829228547, 6.724378959508502, 7.667001826351276, 8.66739323632926, 9.664785176259945, 10.581860947886867, 11.445965463063105, 12.490076607383259, 13.44889484394315, 14.489582396140891, 15.529231356352524, 16.54184991651265, 16.40383035703762, 15.57329194020241, 14.773627384505465, 13.780777065763429, 12.71732016549757, 11.653635380566117, 10.71412292338395, 9.816416761099548, 5.014640720587986, 5.766624608614315, 6.7297904624180624, 7.7821924668596525, 8.65984487653324, 9.604218344854619, 10.506030417868956, 11.535663989893273, 12.519471960576167, 13.505600261913097, 14.462981333294476, 15.490622126409848, 15.418264174118859, 14.630955902441812, 13.738586512731311, 12.868506324831522, 11.8158213386815, 10.801588332212008, 9.785638840307648, 8.845672979879591, 3.9693491194998236, 4.774178593965907, 5.752017673051714, 6.743516351156687, 7.674211484856033, 8.601394047182312, 9.531071936755831, 10.569911221575042, 11.523766849704003, 12.497236392229752, 13.561937802843923, 14.565220996332577, 14.474664966784266, 13.646381820722986, 12.68921231574031, 11.887689599960085, 10.859671825654772, 9.869844767076831, 8.838612610489312, 7.89439956033702, 2.907239387851497, 3.7670003176481193, 4.791516853216475, 5.794034574154908, 6.721672587318926, 7.759064515735545, 8.72687124584519, 9.7592617922065, 10.820427977488059, 11.813275527981961, 12.81715053142188, 13.761345610353699, 13.509621174731242, 12.645168268336754, 11.66880815702727, 10.837865124599325, 9.818269372810498, 8.833830328230597, 7.837482986936548, 6.836842823704091, 1.8630472443727575, 2.8030041039815616, 3.7741981187002565, 4.792739747775473, 5.755733111530816, 6.804418895262375, 7.786332214855118, 8.837613353409555, 9.802890887367676, 10.8271020594952, 11.898765874491085, 12.865162756572019, 12.564659060747442, 11.621536318328927, 10.690227798144472, 9.767352950954518, 8.743691200797652, 7.800864860422797, 6.796195362502576, 5.867129533978044, 0.932418612392397, 2.0055404787064512, 2.968873187010081, 3.9926000678640423, 4.884653013626892, 5.8243892750376896, 6.863861726166433, 7.89166300817398, 8.84994707661005, 9.910170817075644, 10.919920980877464, 11.896117737095084, 11.57939569590337, 10.641191061128257, 9.716659132176636, 8.77252115222665, 7.827553996859223, 6.843268406303947, 5.888022581258325, 4.87847661519303, 0.0, 1.0563055670391945, 2.036320291725442, 3.00317121895141, 3.9588293552109644, 4.941082963302689, 6.006182670289774, 6.941706575125204, 7.9219752426928896, 8.945323671390149, 9.963237488224273, 11.002198491461826, 10.603408581284182, 9.676907802761747, 8.722167147752167, 7.794717261698584, 6.860703450284332, 5.895107184212278, 4.849916741750315, 3.91043588739432, 1.0537419358343307, 2.1098179256980822, 2.9837827835163275, 3.977858977239812, 4.903800906094808, 5.885071914673175, 6.8213610384827446, 7.852462487288831, 8.841688928720188, 9.771526763941397, 10.83723630866437, 10.948445762674634, 9.954758972117354, 8.884761258915947, 7.8833409207866545, 6.955713951277447, 5.945788838222285, 4.965027164066942, 3.8973622082097794, 2.9164259479074044, 2.0636652041910004, 3.010412798177353, 4.020619446384979, 5.017260449515378, 5.946978605211871, 6.875344071541691, 7.854130805840532, 8.81341531959979, 9.832413797421426, 10.773104862051857, 11.03373920946593, 9.983285274908381, 9.005672955017557, 7.957436304667935, 6.965064373157854, 6.015320623989075, 5.024543503871155, 3.98966178544067, 2.971991774398265, 1.9705812826439302, 2.995162814468795, 4.020265351747048, 5.01399337731978, 6.033097992072581, 6.9699940987796545, 7.929229976574103, 8.856119098253565, 9.744786955074733, 10.815954806200574, 11.065146110884179, 10.022594933822548, 9.029066479401632, 7.997674269231774, 6.989681511024102, 6.027134929989158, 5.072510163353806, 4.071000469068903, 3.0366360821163236, 2.0173391859984817, 0.9997733785107283, 4.061477865102362, 5.056463785231954, 5.982479016753963, 6.916590781176342, 7.941620929132206, 8.879457869257227, 9.849592056725657, 10.739558238074478, 11.754972087838604, 11.742581817299703, 10.809779939639464, 9.770080237408349, 8.806120969609406, 7.851911538282746, 6.805910425231492, 5.843662750171301, 4.792821141325275, 3.8167140112021674, 2.8822957563690728, 1.8844494224796287, 5.11385054634325, 6.085414563258376, 6.967637651454657, 7.8491893899483305, 8.854033223103619, 9.836783028710062, 10.794860265147836, 11.736725707038342, 12.685960811053517, 12.699760697924306, 11.649358856633782, 10.721513907216142, 9.75343509816257, 8.715677865602666, 7.761490698260193, 6.7325985581454075, 5.739579514317361, 4.761760355445224, 3.853249919317806, 2.8287728798695895, 6.093406928429697, 7.073027302058707, 7.9979113053315976, 8.920683025172629, 9.823768208094721, 10.776232871524464, 11.733611447603142, 12.762569204733628, 13.713477666349053, 13.629720678817444, 12.566346751416958, 11.51990430367992, 10.560958830886689, 9.603913556548111, 8.668116368964036, 7.710418708357399, 6.670800825309677, 5.693632005322651, 4.77989610484169, 3.8535442992326794, 7.073673322306814, 8.019766722645574, 9.068804730863157, 9.879346973672703, 10.840377332687138, 11.774079391088149, 12.734711398270655, 13.683720800022193, 14.689187698700083, 14.513307348714005, 13.462143408440223, 12.500279436538984, 11.611234540292632, 10.648841771404193, 9.634589349367383, 8.643466940353013, 7.685088804723321, 6.708255503493483, 5.742328237464616, 4.883762571319583, 8.014473864609718, 8.978905839521934, 9.946861958877655, 10.852357042662943, 11.84634566029781, 12.827770372396019, 13.749196224258364, 14.68065691886823, 15.681499725067814, 15.473730830760513, 14.40868699015367, 13.467794989095616, 12.621859284487446, 11.63942121249729, 10.62935147199277, 9.60232147285535, 8.696944312712816, 7.70561906507293, 6.805691462776751, 5.922155916214815, 9.087045873623833, 10.030125027155371, 10.876663432282418, 11.869523386495304, 12.827658789272952, 13.880340235040928, 14.68117236036342, 15.670406910436983, 16.741579753025363, 16.36154353290687, 15.36050132128224, 14.436859193205402, 13.478781432066231, 12.514097617480392, 11.521979192837792, 10.576600114068016, 9.647206515745689, 8.717570205264384, 7.855769253509375, 6.935715077150797, 10.064320569801438, 11.040904116020933, 11.82792761051195, 12.834747400612116, 13.828179878648196, 14.831029695812243, 15.702168590927633, 16.610188429309073, 17.54722970255801, 17.33098442174994, 16.349332767544798, 15.427053055251639, 14.439444237971355, 13.540112907629432, 12.529206516686052, 11.50978169521349, 10.587871432846361, 9.702723079813548, 8.87213188669852, 7.968861517204639, 11.000361653894505, 11.988294623958266, 12.870893376401076, 13.887022886290588, 14.845698700878472, 15.768585428578078, 16.761398273274345, 17.574270012976076, 18.474808677161253, 18.160446163248363, 17.29565083829635, 16.28058656118378, 15.256377316056867, 14.321854410800597, 13.43296050872328, 12.48377332516419, 11.578419986686862, 10.615799821161684, 9.668444775760243, 8.920547164741489], [8.738092945483341, 7.750128984699511, 8.741211362465682, 9.686229608452482, 10.625746990050317, 11.618730879972501, 12.493882877702417, 13.459884369374322, 14.479113859622924, 15.417828612274636, 16.346568086798584, 17.30400014955769, 17.4512318354304, 16.652949384223046, 15.730742712114255, 14.779400745078359, 13.872891667471098, 12.910163184017668, 12.215461387904904, 12.78232801688775, 7.735629618336058, 6.805573175149598, 7.778213754641936, 8.71855956490401, 9.700941776645898, 10.678531553718573, 11.539106502815356, 12.567495153977841, 13.582332666392603, 14.587166462831922, 15.587314222101623, 16.579953684852292, 17.528148032798608, 17.58589785596673, 16.635251721333642, 15.656525508416806, 14.616589040245568, 13.585687286902052, 12.660612546108522, 11.763678676156243, 6.873136212873679, 5.872541581678328, 6.815164448521102, 7.815555858499086, 8.809317708254252, 9.712709980016069, 10.576814495192307, 11.62092563951246, 12.579743876072351, 13.620431428270093, 14.660080388481726, 15.672698948641852, 16.591752150939946, 16.610983372687848, 15.811318816990903, 14.768771195413043, 13.705314295147184, 12.641629510215731, 11.702117053033565, 10.804410890749162, 5.960543111879238, 4.914787230784141, 5.8779530845878885, 6.9303550890294785, 7.790693908662442, 8.735067376983821, 9.636879449998158, 10.666513022022475, 11.65032099270537, 12.636449294042299, 13.593830365423678, 14.62147115853905, 15.606185968021183, 15.66864733492725, 14.77627794521675, 13.856500454481136, 12.803815468331115, 11.789582461861622, 10.773632969957262, 9.833667109529205, 4.971539943471003, 3.9223412161357323, 4.90018029522154, 5.891678973326513, 6.805060516985235, 7.732243079311514, 8.661920968885033, 9.700760253704244, 10.654615881833205, 11.628085424358954, 12.692786834973125, 13.69607002846178, 14.66258676068659, 14.684073253208425, 13.726903748225748, 12.8756837296097, 11.847665955304388, 10.857838896726445, 9.826606740138928, 8.882393689986635, 3.933237970737622, 2.915162939817945, 3.939679475386301, 4.942197196324734, 5.8275130854113915, 6.77706729231932, 7.744874022428964, 8.777264568790272, 9.78886388236109, 10.756969960942765, 11.760844964382684, 12.705040043314503, 13.716414265506819, 13.682859700822192, 12.706499589512708, 11.82585925424894, 10.806263502460114, 9.821824457880213, 8.825477116586164, 7.824836953353706, 2.891123585760192, 1.9511667261513874, 2.9223607408700825, 3.9409023699452987, 4.8615736096232816, 5.80982096732772, 6.791734286920462, 7.792170394001677, 8.74658532032848, 9.770796492456004, 10.842460307451889, 11.808857189532823, 12.823230259184806, 12.659227750814365, 11.72791923062991, 10.755347080604134, 9.731685330447268, 8.788858990072413, 7.7841894921521915, 6.855123663627659, 1.9887241794315915, 0.9540865477541793, 1.9174192560578092, 2.9362945008248476, 3.8283474465876965, 4.768083707998494, 5.8075561591272375, 6.835357441134785, 7.793641509570855, 8.853865250036447, 9.863615413838268, 10.839812170055888, 11.837966894340735, 11.678882493613695, 10.754350564662074, 9.762968045827705, 8.815548126508837, 7.831262535953562, 6.87601671090794, 5.866470744842645, 1.0563055670391945, 0.0, 0.9800147246862475, 1.9468656519122152, 2.9025237881717696, 3.8847773962634937, 4.949877103250579, 5.885401008086008, 6.8656696756536935, 7.889018104350952, 8.906931921185077, 9.94589292442263, 10.925466070064552, 10.714599235247185, 9.759858580237605, 8.832408694184021, 7.898394882769769, 6.932798616697715, 5.887608174235752, 4.8984300170439345, 2.1100475028735253, 1.0585793153713472, 1.927477216477133, 2.9215534102006173, 3.847495339055613, 4.828766347633981, 5.76505547144355, 6.796156920249636, 7.785383361680995, 8.715221196902204, 9.780930741625177, 10.726920931040745, 10.992450404602788, 9.922452691401382, 8.921032353272091, 7.993405383762884, 6.983480270707721, 6.00271859655238, 4.935053640695217, 3.9044200775570186, 2.95013507922987, 2.0033874852435174, 2.9643138793457835, 3.960954882476183, 4.890673038172676, 5.819038504502496, 6.797825238801337, 7.757109752560594, 8.77610823038223, 9.716799295012665, 10.696742084578318, 11.039590841947575, 10.061978522056753, 9.01374187170713, 8.021369940197047, 7.071626191028269, 6.080849070910349, 5.045967352479865, 4.02829734143746, 3.026886849683125, 3.881632689507665, 3.013240038813212, 4.006968064385944, 5.017407769718297, 5.913688531740458, 6.8729244095349085, 7.799813531214371, 8.688481388035537, 9.759649239161378, 10.702375391988303, 11.078900500861742, 10.085372046440826, 9.053979836270969, 8.045987078063296, 7.083440497028352, 6.128815730393001, 5.127306036108097, 4.092941649155518, 3.0736447530376765, 2.056078945549923, 4.947947740141232, 4.049438472298118, 4.975453703820127, 5.909565468242506, 6.88531536209301, 7.823152302218032, 8.793286489686462, 9.683252671035282, 10.698666520799408, 11.71444467513179, 11.866085506678658, 10.826385804447543, 9.8624265366486, 8.90821710532194, 7.862215992270686, 6.8999683172104955, 5.849126708364469, 4.873019578241363, 3.9386013234082675, 2.9407549895188234, 6.00032042138212, 5.09968982206348, 5.960612338520821, 6.842164077014495, 7.847007910169782, 8.780477461670868, 9.738554698108642, 10.680420139999146, 11.629655244014321, 12.570427250952566, 12.705664423672976, 11.777819474255336, 10.809740665201764, 9.77198343264186, 8.817796265299387, 7.788904125184602, 6.7958850813565554, 5.818065922484419, 4.88132626070524, 3.856849221257024, 6.979876803468566, 6.087302560863811, 6.990885992397762, 7.913657712238793, 8.816742895160884, 9.71992730448527, 10.677305880563948, 11.706263637694432, 12.657172099309857, 13.500387231845703, 13.622652318456154, 12.576209870719117, 11.617264397925885, 10.660219123587307, 9.724421936003232, 8.766724275396594, 7.727106392348872, 6.749937572361846, 5.807972446229124, 4.8795428821188045, 7.960143197345683, 7.159612045204911, 8.061779417929323, 8.872321660738868, 9.8333520197533, 10.717773824048955, 11.67840583123146, 12.627415232983, 13.632882131660887, 14.524496518944888, 14.51844897547942, 13.55658500357818, 12.667540107331828, 11.705147338443389, 10.69089491640658, 9.69977250739221, 8.741394371762516, 7.764561070532679, 6.77040457885205, 5.909761154205707, 8.900943739648588, 8.2098925354731, 8.995086380329518, 9.845331729729107, 10.839320347363973, 11.771464805356825, 12.69289065721917, 13.624351351829038, 14.625194158028618, 15.575315287200246, 15.464992557192867, 14.524100556134812, 13.678164851526642, 12.695726779536486, 11.685657039031966, 10.658627039894546, 9.753249879752014, 8.761924632112127, 7.833767804164185, 6.94815449910094, 9.973515748662702, 9.261111723106538, 9.924887853734282, 10.862498073561468, 11.820633476339117, 12.824034668001733, 13.624866793324225, 14.61410134339779, 15.68527418598617, 16.6134253684652, 16.416806888321435, 15.493164760244598, 14.53508699910543, 13.57040318451959, 12.57828475987699, 11.632905681107214, 10.703512082784886, 9.773875772303581, 8.880382305500431, 7.9457078769345655, 10.950790444840308, 10.2718908119721, 10.876152031963812, 11.857489973438128, 12.82115456571436, 13.776079106647256, 14.645863023888438, 15.553882862269878, 16.490924135518814, 17.426690718926785, 17.28645989298904, 16.303538136760494, 15.315929319480212, 14.451575521834298, 13.532121476695453, 12.512696655222891, 11.551517049162566, 10.588031508124862, 9.639006412834895, 8.685894625222216, 11.886831528933374, 11.219281319909433, 11.91911779785294, 12.918669453361163, 13.838673387944636, 14.713634839413091, 15.705092706235153, 16.517964445936883, 17.418503110122057, 17.291295195377565, 16.454795573162297, 15.411435593312984, 14.387226348186068, 13.4527034429298, 12.563809540852482, 11.653387226350652, 10.72658260885669, 9.76396244333151, 8.816607397930069, 9.637580272759067], [9.715401902911246, 8.727437942127418, 8.006840641336717, 8.878550674487283, 9.704110422636802, 10.638716155286255, 11.513868153016169, 12.479869644688074, 13.499099134936678, 14.43781388758839, 15.366553362112338, 16.323985424871445, 16.471217110744146, 15.672934659536798, 14.750727987428007, 13.812865744263574, 12.906356666656311, 11.94362818320288, 12.790340920326072, 13.671833094960924, 8.712938575763964, 7.782882132577504, 6.970534820676738, 7.910880630938812, 8.774956209130202, 9.698516829032327, 10.559091778129108, 11.587480429291594, 12.602317941706355, 13.607151738145674, 14.607299497415376, 15.599938960166043, 16.54813330811236, 16.606969866757996, 15.756348580579024, 14.777622367662188, 13.866404442378702, 12.92408060690879, 13.550117624181697, 12.653183754229417, 7.850445170301586, 6.849850539106234, 5.918867890627853, 6.9192593006058365, 7.829302983568004, 8.732695255329823, 9.59679977050606, 10.640910914826213, 11.599729151386104, 12.640416703583846, 13.680065663795476, 14.692684223955602, 15.611737426253699, 16.544246786025983, 16.70082389506408, 15.658276273486218, 14.594819373220359, 13.531134588288905, 12.591622131106739, 11.693915968822337, 6.937852069307144, 5.892096188212047, 4.981656526694639, 5.961691820099429, 6.810679183976195, 7.755052652297574, 8.65686472531191, 9.686498297336227, 10.670306268019122, 11.656434569356051, 12.613815640737428, 13.6414564338528, 14.626171243334936, 15.601910748265386, 15.665783023289926, 14.74600553255431, 13.693320546404289, 12.679087539934796, 11.663138048030437, 10.72317218760238, 5.94884890089891, 4.899650173563639, 4.003883737328291, 4.923009113461408, 5.825045792298988, 6.752228354625267, 7.681906244198785, 8.720745529017996, 9.674601157146958, 10.648070699672706, 11.712772110286878, 12.716055303775532, 13.682572036000343, 14.623305897582808, 14.616408826298924, 13.765188807682874, 12.737171033377562, 11.74734397479962, 10.716111818212102, 9.77189876805981, 4.9105469281655285, 3.892471897245852, 3.0108336261879525, 3.973527336459629, 4.847498360725144, 5.797052567633072, 6.764859297742716, 7.797249844104026, 8.808849157674844, 9.77695523625652, 10.780830239696439, 11.725025318628257, 12.736399540820573, 13.720997077059062, 13.596004667585884, 12.715364332322114, 11.695768580533288, 10.711329535953388, 9.714982194659338, 8.714342031426881, 3.8684325431880984, 2.928475683579294, 1.9935148916717338, 2.965239729260805, 3.881558884937034, 4.829806242641473, 5.811719562234215, 6.8121556693154295, 7.766570595642233, 8.790781767769758, 9.862445582765643, 10.828842464846577, 11.843215534498558, 12.822396333582711, 12.617424308703086, 11.644852158677308, 10.621190408520443, 9.678364068145587, 8.673694570225367, 7.7446287417008355, 2.968738904117839, 1.9313955051820861, 0.9680627968784563, 1.9562797761386, 2.848332721901449, 3.7880689833122467, 4.82754143444099, 5.855342716448537, 6.813626784884607, 7.873850525350201, 8.88360068915202, 9.85979744536964, 10.857952169654487, 11.7961568044296, 11.64385564273525, 10.652473123900881, 9.705053204582013, 8.720767614026737, 7.765521788981117, 6.755975822915821, 2.036320291725442, 0.9800147246862475, 0.0, 0.9668509272259678, 1.922509063485522, 2.904762671577246, 3.969862378564331, 4.905386283399761, 5.885654950967446, 6.909003379664704, 7.926917196498829, 8.965878199736382, 9.945451345378304, 10.871952123900739, 10.649363658310781, 9.721913772257198, 8.787899960842946, 7.822303694770891, 6.777113252308928, 5.787935095117111, 3.004160383308275, 1.9480843934445238, 0.9474624917908855, 1.94153868551437, 2.867480614369365, 3.8487516229477334, 4.785040746757303, 5.816142195563389, 6.805368636994747, 7.735206472215956, 8.800916016938928, 9.746906206354495, 10.754249085161145, 10.81195776947456, 9.810537431345267, 8.88291046183606, 7.872985348780897, 6.892223674625556, 5.824558718768393, 4.793925155630195, 3.8396401573030468, 2.892892563316694, 1.9842991546595363, 2.9809401577899353, 3.9106583134864286, 4.839023779816248, 5.81781051411509, 6.7770950278743465, 7.796093505695982, 8.736784570326417, 9.71672735989207, 10.712066694120749, 11.041993246743, 9.993756596393379, 9.001384664883297, 8.051640915714517, 7.060863795596597, 6.025982077166113, 5.0083120661237075, 4.0069015743693726, 4.771137767580842, 3.902745116886389, 3.0404330635711583, 4.037393045032049, 4.933673807054211, 5.892909684848661, 6.819798806528123, 7.70846666334929, 8.77963451447513, 9.722360667302056, 10.742061242897421, 11.065386771127073, 10.033994560957217, 9.026001802749544, 8.0634552217146, 7.108830455079248, 6.1073207607943445, 5.072956373841766, 4.053659477723924, 3.0360936702361703, 5.837452818214409, 4.938943550371295, 4.008918703005342, 4.943030467427721, 5.9053006374067625, 6.843137577531785, 7.813271765000215, 8.703237946349034, 9.71865179611316, 10.734429950445543, 11.667231828105782, 11.806400529133791, 10.842441261334848, 9.888231830008188, 8.842230716956934, 7.879983041896743, 6.829141433050717, 5.85303430292761, 4.918616048094515, 3.9207697142050706, 6.889825499455297, 5.989194900136657, 4.994077337706036, 5.87562907619971, 6.880472909354997, 7.8004627369846204, 8.758539973422394, 9.700405415312899, 10.649640519328074, 11.590412526266318, 12.635125850387812, 12.757834198941584, 11.789755389888011, 10.751998157328108, 9.797810989985635, 8.76891884987085, 7.775899806042803, 6.798080647170667, 5.858635218133147, 4.83415817868493, 7.869381881541743, 6.976807638936988, 6.024350991582977, 6.947122711424008, 7.850207894346099, 8.739912579799022, 9.6972911558777, 10.726248913008185, 11.67715737462361, 12.520372507159456, 13.564401379389519, 13.556224595405364, 12.597279122612132, 11.640233848273555, 10.70443666068948, 9.746739000082842, 8.70712111703512, 7.729952297048094, 6.785281403657031, 5.856851839546711, 8.84964827541886, 8.049117123278087, 7.095244417114537, 7.905786659924083, 8.866817018938516, 9.737759099362707, 10.698391106545213, 11.647400508296752, 12.65286740697464, 13.54448179425864, 14.595645734532422, 14.536599728264427, 13.647554832018074, 12.685162063129637, 11.670909641092827, 10.679787232078457, 9.721409096448765, 8.744575795218926, 7.7477135362799565, 6.887070111633614, 9.790448817721764, 8.996507498870452, 8.028551379514731, 8.878796728914322, 9.87278534654919, 10.791450080670577, 11.712875932532922, 12.644336627142788, 13.64517943334237, 14.595300562513998, 15.542189316245869, 15.50411528082106, 14.658179576212888, 13.675741504222733, 12.665671763718214, 11.638641764580793, 10.73326460443826, 9.741939356798373, 8.81107676159209, 7.925463456528846, 10.863020826735879, 10.01401059186388, 8.958352852919495, 9.895963072746683, 10.854098475524331, 11.844019943315486, 12.644852068637977, 13.63408661871154, 14.70525946129992, 15.63341064377895, 16.494003647374438, 16.27668623402637, 15.296577400699086, 14.497576087297091, 13.558299484563236, 12.61292040579346, 11.683526807471132, 10.753890496989827, 9.857691262928336, 8.923016834362471, 11.840295522913484, 10.846770344393267, 9.909617031149025, 10.890954972623343, 11.854619564899576, 12.796064381961008, 13.66584829920219, 14.573868137583629, 15.510909410832564, 16.446675994240536, 16.30644516830279, 15.323523412074247, 14.335914594793962, 13.47156079714805, 12.566906715953904, 11.705742288887837, 10.95522199650017, 10.065957851002544, 10.616315370262802, 9.663203582650123, 12.77633660700655, 11.7941608523306, 10.952582797038152, 11.952134452546378, 12.872138387129851, 13.733620114726843, 14.725077981548905, 15.537949721250632, 16.438488385435807, 16.31128047069132, 15.474780848476051, 14.431420868626738, 13.40721162349982, 12.472688718243552, 11.583794816166236, 10.731750658937138, 9.91890367489149, 9.029591722202545, 9.793916355357975, 10.614889230186973], [10.682252830137216, 9.694288869353388, 8.973691568562685, 7.993537668766876, 8.737259495410834, 9.671865228060286, 10.547017225790201, 11.513018717462106, 12.532248207710708, 13.47096296036242, 14.399702434886368, 15.357134497645475, 15.504366183518181, 14.70608373231083, 13.78387706020204, 12.974072383765742, 12.131665452593765, 12.897913994897324, 13.744626732020516, 14.638684022186894, 9.679789502989934, 8.749733059803473, 7.937385747902706, 7.025867625218406, 7.808105281904235, 8.731665901806357, 9.59224085090314, 10.620629502065626, 11.635467014480387, 12.640300810919706, 13.640448570189408, 14.633088032940075, 15.58128238088639, 15.64011893953203, 14.792133220233366, 13.938829007164356, 13.091713228316156, 13.878366418603234, 14.516968551407667, 13.620034681455387, 8.817296097527553, 7.816701466332202, 6.885718817853821, 6.00541287824973, 6.862452056342036, 7.765844328103854, 8.629948843280092, 9.674059987600245, 10.632878224160136, 11.673565776357878, 12.71321473656951, 13.725833296729636, 14.64488649902773, 15.577395858800015, 15.76656283802124, 14.96925577773312, 14.062762775079982, 14.497985515514875, 13.558473058332709, 12.660766896048306, 7.904702996533112, 6.858947115438015, 5.948507453920607, 4.994840892873462, 5.843828256750227, 6.788201725071606, 7.690013798085943, 8.719647370110259, 9.703455340793154, 10.689583642130083, 11.646964713511462, 12.674605506626834, 13.659320316108968, 14.635059821039418, 15.607563249201753, 15.71285645978028, 14.660171473630259, 13.645938467160766, 12.629988975256406, 11.69002311482835, 6.915699828124878, 5.866501100789607, 4.970734664554259, 3.9561581862354402, 4.85819486507302, 5.785377427399299, 6.715055316972817, 7.7538946017920285, 8.70775022992099, 9.681219772446738, 10.74592118306091, 11.749204376549564, 12.715721108774375, 13.65645497035684, 14.651048236710391, 14.732039734908843, 13.704021960603532, 12.71419490202559, 11.682962745438072, 10.73874969528578, 5.8773978553914965, 4.859322824471819, 3.97768455341392, 3.0066764092336613, 3.880647433499176, 4.830201640407105, 5.798008370516749, 6.830398916878059, 7.841998230448876, 8.810104309030551, 9.81397931247047, 10.758174391402289, 11.769548613594605, 12.754146149833094, 13.730506261142578, 13.682215259548084, 12.662619507759258, 11.678180463179357, 10.681833121885308, 9.68119295865285, 4.835283470414066, 3.8953266108052618, 2.9603658188977016, 1.9983888020348375, 2.9147079577110664, 3.8629553154155056, 4.844868635008249, 5.845304742089462, 6.799719668416266, 7.823930840543791, 8.895594655539675, 9.861991537620609, 10.876364607272592, 11.855545406356745, 12.7868539265412, 12.611703085903278, 11.588041335746412, 10.645214995371557, 9.640545497451336, 8.711479668926804, 3.935589831343807, 2.8982464324080537, 1.934913724104424, 0.9894288489126323, 1.8814817946754814, 2.821218056086279, 3.8606905072150224, 4.88849178922257, 5.84677585765864, 6.906999598124234, 7.916749761926054, 8.892946518143674, 9.89110124242852, 10.829305877203634, 11.85433383610882, 11.61932405112685, 10.671904131807981, 9.687618541252705, 8.732372716207085, 7.722826750141789, 3.00317121895141, 1.9468656519122152, 0.9668509272259678, 0.0, 0.9556581362595543, 1.9379117443512786, 3.003011451338364, 3.938535356173794, 4.918804023741479, 5.942152452438737, 6.960066269272862, 7.999027272510414, 8.978600418152336, 9.90510119667477, 10.859841851684351, 10.688764699483166, 9.754750888068914, 8.78915462199686, 7.743964179534896, 6.754786022343079, 3.9710113105342426, 2.9149353206704913, 1.9143134190168531, 1.0467425385506595, 1.9006296871433976, 2.881900695721766, 3.8181898195313346, 4.849291268337421, 5.838517709768779, 6.768355544989988, 7.8340650897129605, 8.78005527912853, 9.78739815793518, 10.857395871136585, 10.777388358571235, 9.849761389062028, 8.839836276006865, 7.859074601851524, 6.791409645994361, 5.760776082856163, 4.806491084529014, 3.8597434905426615, 2.951150081885504, 2.0861440108262252, 2.9438073862604615, 3.872172852590281, 4.850959586889122, 5.8102441006483785, 6.829242578470014, 7.769933643100449, 8.749876432666102, 9.745215766894782, 10.737736621651583, 10.960607523619345, 9.968235592109263, 9.018491842940485, 8.027714722822564, 6.99283300439208, 5.975162993349675, 4.97375250159534, 5.737988694806809, 4.869596044112356, 4.007283990797125, 3.142596898068339, 3.966822879828244, 4.926058757622693, 5.852947879302155, 6.741615736123322, 7.812783587249163, 8.755509740076088, 9.775210315671453, 10.699434562401532, 11.000845488183185, 9.992852729975512, 9.030306148940568, 8.075681382305216, 7.0741716880203125, 6.039807301067733, 5.020510404949891, 4.002944597462138, 6.804303745440376, 5.905794477597262, 4.975769630231309, 4.115533204048588, 4.938449710180796, 5.876286650305817, 6.846420837774247, 7.736387019123066, 8.751800868887193, 9.767579023219575, 10.700380900879814, 11.723920620283396, 11.809292188560816, 10.855082757234156, 9.809081644182902, 8.846833969122711, 7.795992360276685, 6.819885230153577, 5.885466975320482, 4.887620641431038, 7.856676426681264, 6.956045827362624, 5.960928264932003, 5.048131812820577, 5.94917990254566, 6.8336118097586525, 7.791689046196425, 8.73355448808693, 9.682789592102106, 10.62356159904035, 11.668274923161844, 12.596119872579484, 12.75660631711398, 11.718849084554076, 10.764661917211603, 9.735769777096817, 8.742750733268771, 7.764931574396634, 6.825486145359115, 5.801009105910898, 8.836232808767711, 7.943658566162955, 6.991201918808943, 6.119625448044875, 6.918914887536762, 7.773061652573054, 8.730440228651732, 9.759397985782217, 10.710306447397642, 11.553521579933488, 12.597550452163551, 13.56778861559445, 13.5641300498381, 12.607084775499523, 11.671287587915447, 10.71358992730881, 9.673972044261088, 8.696803224274062, 7.752132330882999, 6.823702766772679, 9.816499202644827, 9.015968050504055, 8.04953022880898, 7.0782893965449505, 7.93552401212918, 8.770908172136739, 9.731540179319245, 10.680549581070784, 11.686016479748671, 12.577630867032672, 13.628794807306454, 14.548163748453513, 14.614405759244043, 13.652012990355605, 12.637760568318795, 11.646638159304425, 10.688260023674733, 9.711426722444894, 8.714564463505925, 7.853921038859582, 10.757299744947732, 9.950793310564896, 8.982837191209175, 8.05129946553519, 8.972954830885225, 9.824599153444609, 10.746025005306954, 11.677485699916822, 12.678328506116403, 13.62844963528803, 14.575338389019901, 15.515679301010145, 15.39117089428925, 14.48534536510664, 13.55212081861944, 12.605492691806761, 11.70011553166423, 10.708790284024342, 9.77792768881806, 8.892314383754815, 11.829871753961847, 10.968296403558323, 9.912638664613938, 9.06846580936755, 10.0153051150265, 10.877169016089518, 11.67800114141201, 12.667235691485574, 13.738408534073955, 14.666559716552984, 15.52715272014847, 15.309835306800405, 14.32972647347312, 13.530725160071123, 12.6109131499177, 11.672072942807345, 11.010873907880436, 11.720741424215797, 10.824542190154304, 9.88986776158844, 12.807146450139452, 11.80105615608771, 10.86390284284347, 10.06345770924421, 11.015826204401744, 11.82921345473504, 12.698997371976223, 13.607017210357663, 14.544058483606598, 15.479825067014568, 15.339594241076824, 14.35667248484828, 13.369063667567996, 12.504709869922083, 11.600055788727934, 10.73889136166187, 10.070208990779763, 11.032808778228512, 11.583166297488772, 10.630054509876093, 13.743187534232518, 12.748446664025044, 11.906868608732596, 11.124637189167245, 12.03334502663202, 12.766769187500875, 13.758227054322937, 14.571098794024666, 15.471637458209843, 15.344429543465349, 14.507929921250081, 13.464569941400768, 12.440360696273853, 11.505837791017584, 10.616943888940266, 9.764899731711171, 9.033890669171084, 9.996442649428513, 10.760767282583945, 11.581740157412943], [11.637910966396767, 10.649947005612939, 9.780664325533813, 8.721118740749114, 7.78160135915128, 8.716207091800733, 9.591359089530648, 10.557360581202554, 11.576590071451157, 12.51530482410287, 13.444044298626817, 14.401476361385924, 14.548708047258627, 13.750425596051276, 12.828218923942485, 12.018414247506188, 12.942208484688045, 13.708457026991605, 14.555169764114796, 15.509265397408234, 10.635447639249485, 9.705391196063024, 8.775175167648644, 7.834829357386569, 6.852447145644681, 7.776007765546804, 8.636582714643588, 9.664971365806073, 10.679808878220834, 11.684642674660154, 12.684790433929855, 13.677429896680522, 14.625624244626838, 14.684460803272476, 13.836475083973811, 12.983170870904802, 13.902256260410436, 14.688909450697514, 15.47262668766722, 14.57569281771494, 9.772954233787106, 8.772359602591754, 7.806934693585099, 6.827893310586563, 5.906793920082482, 6.810186191844299, 7.674290707020538, 8.718401851340692, 9.677220087900583, 10.717907640098325, 11.757556600309952, 12.770175160470078, 13.689228362768176, 14.62173772254046, 14.810904701761686, 14.013597641473565, 14.873305807174262, 15.453643651774428, 14.514131194592261, 13.616425032307859, 8.860361132792665, 7.814605251697568, 6.869723329651886, 5.817321325210296, 4.888170120490672, 5.832543588812052, 6.734355661826388, 7.763989233850704, 8.747797204533597, 9.733925505870527, 10.691306577251904, 11.718947370367276, 12.703662179849413, 13.679401684779863, 14.651905112942199, 14.963286503285499, 15.615829609889813, 14.60159660342032, 13.585647111515959, 12.645681251087902, 7.871357964384431, 6.82215923704916, 5.896751299999163, 4.833231862512812, 3.9025367288134656, 4.829719291139744, 5.759397180713263, 6.798236465532474, 7.752092093661435, 8.725561636187184, 9.790263046801355, 10.79354624029001, 11.76006297251482, 12.700796834097286, 13.695390100450837, 14.659226959727063, 14.659680096863084, 13.669853038285144, 12.638620881697625, 11.694407831545332, 6.83305599165105, 5.814980960731373, 4.932848513344113, 3.9303307924056794, 2.9249892972396214, 3.8745435041475504, 4.842350234257195, 5.874740780618504, 6.886340094189322, 7.854446172770998, 8.858321176210918, 9.802516255142736, 10.813890477335052, 11.798488013573541, 12.774848124883025, 13.718006171157914, 13.61827764401881, 12.63383859943891, 11.63749125814486, 10.636851094912403, 5.79094160667362, 4.850984747064816, 3.9160239551572555, 2.9220431852068556, 1.959049821451512, 2.907297179155951, 3.8892104987486937, 4.889646605829908, 5.8440615321567115, 6.868272704284236, 7.9399365192801215, 8.906333401361056, 9.920706471013036, 10.899887270097189, 11.831195790281644, 12.879519867927492, 12.543699472005965, 11.60087313163111, 10.59620363371089, 9.667137805186357, 4.891247967603361, 3.853904568667608, 2.8905718603639783, 1.9237709416056443, 0.925823658415927, 1.8655599198267248, 2.905032370955468, 3.9328336529630157, 4.891117721399086, 5.951341461864679, 6.9610916256665, 7.937288381884119, 8.935443106168965, 9.873647740944078, 10.898675699849266, 11.809437492006445, 11.627562268067535, 10.64327667751226, 9.688030852466639, 8.678484886401343, 3.9588293552109644, 2.9025237881717696, 1.922509063485522, 0.9556581362595543, 0.0, 0.9822536080917241, 2.0473533150788095, 2.9828772199142395, 3.9631458874819248, 4.986494316179183, 6.004408133013308, 7.04336913625086, 8.022942281892782, 8.949443060415216, 9.904183715424796, 10.83163360147838, 10.710409024328468, 9.744812758256414, 8.69962231579445, 7.710444158602633, 4.926669446793797, 3.8705934569300458, 2.8699715552764076, 1.887840881556103, 0.9449715508838432, 1.9262425594622115, 2.86253168327178, 3.8936331320778663, 4.882859573509225, 5.8126974087304335, 6.878406953453406, 7.824397142868975, 8.831740021675625, 9.901737734877031, 10.903158073006324, 10.805419525321582, 9.79549441226642, 8.814732738111077, 7.747067782253915, 6.716434219115717, 5.762149220788569, 4.815401626802216, 3.9068082181450583, 2.9272423538316685, 1.9881492500009068, 2.916514716330726, 3.8953014506295673, 4.854585964388824, 5.8735844422104595, 6.814275506840895, 7.794218296406548, 8.789557630635228, 9.782078485392029, 10.836526143885969, 10.923893728368817, 9.974149979200039, 8.983372859082118, 7.948491140651634, 6.930821129609229, 5.929410637854894, 6.6936468310663635, 5.8252541803719105, 4.96294212705668, 3.9836952410737823, 3.0111647435686892, 3.9704006213631384, 4.897289743042601, 5.785957599863767, 6.857125450989608, 7.799851603816534, 8.819552179411899, 9.743776426141977, 10.775168636311834, 10.948510866235067, 9.985964285200122, 9.03133951856477, 8.029829824279867, 6.9954654373272875, 5.976168541209446, 4.958602733721692, 7.7599618816999305, 6.861452613856817, 5.89074331147641, 4.956631547054031, 3.9827915739212414, 4.920628514046262, 5.890762701514692, 6.780728882863512, 7.796142732627638, 8.81192088696002, 9.74472276462026, 10.768262484023841, 11.700386759654387, 11.81074089349371, 10.764739780442456, 9.802492105382266, 8.75165049653624, 7.775543366413132, 6.841125111580037, 5.843278777690593, 8.81233456294082, 7.911703963622179, 6.875901946177104, 5.88923015582602, 4.993521766286106, 5.877953673499098, 6.836030909936871, 7.777896351827376, 8.727131455842551, 9.667903462780796, 10.71261678690229, 11.64046173631993, 12.64770088820755, 12.67450722081363, 11.720320053471157, 10.691427913356371, 9.698408869528325, 8.720589710656188, 7.781144281618668, 6.756667242170452, 9.791890945027266, 8.89931670242251, 7.906175600054044, 6.930168480139155, 5.963256751277208, 6.817403516313499, 7.7747820923921775, 8.803739849522662, 9.754648311138087, 10.597863443673933, 11.641892315903997, 12.612130479334896, 13.571075952128128, 13.562742911759077, 12.626945724175002, 11.669248063568364, 10.629630180520643, 9.652461360533616, 8.707790467142551, 7.779360903032233, 10.772157338904382, 9.922087301115658, 8.86007326090326, 7.888832428639231, 6.979865875869626, 7.815250035877185, 8.77588204305969, 9.72489144481123, 10.730358343489117, 11.621972730773118, 12.6731366710469, 13.592505612193959, 14.62135166153407, 14.549498065131795, 13.59341870457835, 12.60229629556398, 11.643918159934287, 10.667084858704449, 9.670222599765477, 8.809579175119136, 11.712957881207286, 10.761336342659176, 9.793380223303455, 8.86184249762947, 8.01729669462567, 8.868941017185055, 9.7903668690474, 10.721827563657268, 11.722670369856848, 12.672791499028476, 13.619680252760347, 14.56002116475059, 14.435512758029695, 13.529687228847088, 12.596462682359887, 11.766855506410266, 12.645095099111538, 11.664448420283897, 10.733585825077611, 9.84797252001437, 12.785529890221401, 11.778839435652603, 10.723181696708219, 9.87900884146183, 9.059646978766946, 9.921510879829963, 10.722343005152455, 11.71157755522602, 12.7827503978144, 13.710901580293429, 14.571494583888915, 14.35417717054085, 13.374068337213565, 12.57506702381157, 11.655255013658147, 10.71641480654779, 11.645808404870118, 12.575444715351423, 11.780200326413857, 10.845525897847992, 13.63459034766965, 12.61159918818199, 11.67444587493775, 10.87400074133849, 10.06016806814219, 10.873555318475486, 11.743339235716668, 12.651359074098108, 13.588400347347044, 14.524166930755014, 14.38393610481727, 13.401014348588726, 12.413405531308442, 11.54905173366253, 10.644397652468381, 9.783233225402316, 10.744412831462641, 11.707898372500345, 12.538824433748323, 11.585712646135644, 14.570631431762717, 13.558989696119324, 12.717411640826876, 11.935180221261525, 11.077686890372465, 11.81111105124132, 12.802568918063383, 13.615440657765111, 14.515979321950288, 14.388771407205798, 13.55227178499053, 12.508911805141217, 11.4847025600143, 10.55017965475803, 9.661285752680714, 8.809241595451617, 9.761471741153322, 10.741779333662365, 11.716425418843496, 12.537398293672494], [12.620164574488491, 11.632200613704663, 10.762917933625538, 9.703372348840839, 8.763854967243004, 7.945388116909169, 8.807038402390122, 9.773039894062027, 10.792269384310629, 11.730984136962341, 12.659723611486289, 13.617155674245396, 13.644644013000653, 12.864525125244992, 11.957815586970296, 12.915169922379897, 13.92446209277977, 14.69071063508333, 15.53742337220652, 16.49151900549996, 11.61770124734121, 10.687644804154749, 9.757428775740369, 8.817082965478294, 7.8347007537364055, 7.00518879065524, 7.852262027503062, 8.880650678665548, 9.891568775233583, 10.896402571672903, 11.896550330942604, 12.777698531098139, 13.725892879044455, 13.798560332466192, 12.966071747001623, 13.879926545778511, 14.88450986850216, 15.671163058789238, 16.454880295758944, 15.557946425806664, 10.75520784187883, 9.754613210683479, 8.789188301676823, 7.810146918678288, 6.889047528174206, 6.039367216952736, 6.889970019880013, 7.934081164200166, 8.869391389677883, 9.897568851402504, 10.876251968571912, 11.831318639067325, 12.740226011594375, 13.67273537136666, 13.940501364789498, 14.910353316347274, 15.855559415265986, 16.435897259866152, 15.496384802683986, 14.598678640399584, 9.84261474088439, 8.796858859789292, 7.85197693774361, 6.79957493330202, 5.870423728582397, 5.061724613920489, 5.950034974685863, 6.979668546710179, 7.894165768925755, 8.852620874132485, 9.810001945513864, 10.780090848964523, 11.754659828675612, 12.730399333606062, 13.702902761768398, 14.67356376762871, 15.726248753778732, 15.583850211512045, 14.567900719607684, 13.627934859179627, 8.853611572476154, 7.8044128451408845, 6.879004908090888, 5.815485470604536, 4.88479033690519, 4.058900316248181, 4.975076493572738, 5.999608467524425, 6.865659976294932, 7.83912951882068, 8.841260695627554, 9.844543889116208, 10.811060621341019, 11.751794482923485, 12.746387749277035, 13.710224608553261, 14.742018485739814, 14.652106646376868, 13.62087448978935, 12.676661439637057, 7.815309599742775, 6.7972345688230975, 5.915102121435837, 4.912584400497403, 3.907242905331346, 3.045554413084866, 4.01336114319451, 4.939922864535151, 5.927491521313117, 6.895597599894792, 7.899472603334712, 8.843667682266531, 9.855041904458847, 10.839639440697336, 11.81599955200682, 12.759157598281709, 13.815895258549903, 13.616092207530635, 12.619744866236585, 11.619104703004128, 6.7731952147653445, 5.83323835515654, 4.89827756324898, 3.9042967932985797, 2.941303429543236, 2.0783080880932667, 3.0602214076860093, 3.9307980329537022, 4.885212959280506, 5.909424131408031, 6.981087946403916, 7.94748482848485, 8.96185789813683, 9.941038697220984, 10.872347217405439, 11.897266259835767, 12.741317086537057, 12.583126739722834, 11.578457241802614, 10.649391413278082, 5.8735015756950855, 4.836158176759332, 3.8728254684557024, 2.9060245496973685, 1.908077266507651, 1.03657082876404, 2.0450998305795114, 2.97398508008681, 3.93226914852288, 4.992492888988473, 6.002243052790294, 6.978439809007913, 7.97659453329276, 8.914799168067873, 9.916422091757541, 10.82718388391472, 11.774603803233589, 11.625530285603984, 10.670284460558364, 9.660738494493067, 4.941082963302688, 3.8847773962634937, 2.904762671577246, 1.9379117443512786, 0.9822536080917241, 0.0, 1.0650997069870851, 2.0006236118225154, 2.9808922793902006, 4.004240708087459, 5.022154524921584, 6.061115528159136, 7.040688673801057, 7.967189452323492, 8.921930107333072, 9.849379993386655, 10.783393804800907, 10.72706636634814, 9.681875923886176, 8.692697766694357, 5.908923054885522, 4.85284706502177, 3.8522251633681317, 2.870094489647827, 1.9272251589755673, 0.9782415990478577, 1.9145307228574264, 2.9456321716635125, 3.9272768198604426, 4.857114655081651, 5.922824199804624, 6.8688143892201925, 7.8761572680268435, 8.946154981228249, 9.94757531935754, 10.847735063646429, 10.777748020358146, 9.796986346202804, 8.72932139034564, 7.698687827207442, 6.744402828880293, 5.7976552348939405, 4.889061826236782, 3.9094959619233927, 2.9704028580926307, 2.0461113793585377, 2.9473004902152136, 3.9065850039744703, 4.925583481796106, 5.858692753192113, 6.838635542757766, 7.833974876986446, 8.826495731743247, 9.880943390237187, 10.873315321747269, 10.956403587291764, 9.965626467173843, 8.930744748743358, 7.913074737700954, 6.911664245946619, 7.675900439158088, 6.807507788463635, 5.9451957351484035, 4.965948849165507, 3.9934183516604134, 3.09999728439095, 3.949288782628247, 4.837956639449414, 5.9091244905752545, 6.844268850167752, 7.863969425763117, 8.788193672493195, 9.819585882663052, 10.827578640870724, 10.968217893291847, 10.013593126656495, 9.012083432371591, 7.977719045419012, 6.95842214930117, 5.940856341813417, 8.742215489791654, 7.843706221948541, 6.872996919568134, 5.938885155145756, 4.9650451820129655, 4.050225177074074, 5.000631267550663, 5.832727922449158, 6.848141772213285, 7.863919926545667, 8.796721804205905, 9.81267973037506, 10.744804006005605, 11.699013437332265, 11.74699338853418, 10.78474571347399, 9.733904104627964, 8.757796974504856, 7.823378719671761, 6.825532385782317, 9.794588171032542, 8.893957571713903, 7.858155554268828, 6.871483763917745, 5.97577537437783, 5.00755033652691, 5.945899475972841, 6.8298953914130225, 7.779130495428198, 8.719902502366443, 9.764615826487935, 10.692460775905575, 11.692118134558768, 12.63225341292812, 12.702573661562882, 11.673681521448096, 10.68066247762005, 9.702843318747913, 8.763397889710394, 7.7389208502621765, 10.774144553118989, 9.881570310514235, 8.88842920814577, 7.912422088230879, 6.945510359368932, 5.947000179341311, 6.888881621585893, 7.8557388891083075, 8.806647350723734, 9.64986248325958, 10.693891355489642, 11.664129518920541, 12.623074991713773, 13.58012026605235, 13.609199332266726, 12.651501671660089, 11.611883788612367, 10.63471496862534, 9.690044075234278, 8.761614511123957, 11.754410946996105, 10.904340909207383, 9.842326868994984, 8.871086036730954, 7.914692567055442, 6.944846698904996, 7.889981572253406, 8.820827410553255, 9.782357383074764, 10.673971770358765, 11.725135710632546, 12.644504651779604, 13.673350701119716, 13.765177377991268, 12.838239598679081, 13.584549903655704, 12.626171768026012, 11.649338466796173, 10.652476207857204, 9.791832783210861, 12.695211489299009, 11.7435899507509, 10.77563383139518, 9.844096105721194, 8.952123385811486, 7.998537680212866, 8.904466398241116, 9.817763529399294, 10.774669409442495, 11.724790538614123, 12.671679292345994, 13.612020204336236, 13.65119207088917, 12.745366541706561, 11.825643707468322, 12.74910911450199, 13.627348707203263, 12.646702028375621, 11.71583943316934, 10.830226128106094, 13.767783498313124, 12.761093043744328, 11.705435304799943, 10.861262449553555, 9.994473669952761, 9.051107542857775, 9.83644253434617, 10.807513520968046, 11.842898373730824, 12.771049556209853, 13.623493623474562, 13.569856483400326, 12.58974765007304, 11.790746336671043, 10.884436038766582, 11.698668414639515, 12.628062012961843, 13.557698323443148, 12.762453934505581, 11.827779505939716, 14.616843955761375, 13.593852796273715, 12.656699483029474, 11.856254349430214, 10.994994759328005, 10.003151981503297, 10.857438764910384, 11.747295039840134, 12.68433631308907, 13.62010289649704, 13.599615417676745, 12.6166936614482, 11.629084844167917, 10.764731046522003, 9.873578677576816, 10.765486833494041, 11.726666439554366, 12.69015198059207, 13.521078041840047, 12.567966254227368, 15.552885039854441, 14.541243304211049, 13.6996652489186, 12.91743382935325, 11.974442565246175, 10.940707714269132, 11.916668447257099, 12.711376623507137, 13.611915287692314, 13.60445072006527, 12.767951097850002, 11.724591118000689, 10.700381872873773, 9.765858967617504, 8.890466777789149, 9.791495203543342, 10.743725349245047, 11.72403294175409, 12.69867902693522, 13.519651901764218], [13.615083205193045, 12.627119244409217, 11.715412013252134, 10.655866428467435, 9.7163490468696, 8.793461171166726, 7.812385873449372, 8.778387365121278, 9.766233017593063, 10.704947770244775, 11.633687244768723, 12.59111930752783, 12.684305557579693, 11.954080462309815, 12.84461088471699, 13.801965220126592, 14.853378674813678, 15.656918207363015, 16.503630944486208, 17.457726577779646, 12.612619878045763, 11.682563434859302, 10.709922855366964, 9.769577045104889, 8.787194833363001, 7.855236569843337, 6.857609498562312, 7.885998149724798, 8.826469068246496, 9.831302864685815, 10.831450623955517, 11.712598824111053, 12.66079317205737, 12.888115669531015, 13.838761804164106, 14.766721843525206, 15.806658311696443, 16.637370631068926, 17.461246849096742, 16.56431297914446, 11.760133063541238, 10.759538432345886, 9.741682381303422, 8.762640998304883, 7.841541607800803, 6.889414996140832, 5.895317490939264, 6.939428635259417, 7.804291682690796, 8.832469144415418, 9.811152261584825, 10.766218932080239, 11.67512630460729, 12.607635664379574, 13.548936009091943, 14.558152922453559, 15.621609822719417, 16.615728111816715, 16.502751356021786, 15.605045193737382, 10.847539962546797, 9.8017840814517, 8.804471017370208, 7.752069012928617, 6.822917808208993, 5.911772393108585, 4.955382445745114, 5.973729634495043, 6.829066061938669, 7.7875211671454, 8.744902238526777, 9.714991141977437, 10.689560121688526, 11.665299626618976, 12.637803054781312, 13.608464060641625, 14.661149046791646, 15.639776746049746, 15.574267272945482, 14.634301412517425, 9.858536794138562, 8.809338066803292, 7.8314989877174845, 6.767979550231132, 5.837284416531786, 4.910101854205507, 3.9804239646319886, 4.934508760537339, 5.800560269307846, 6.774029811833595, 7.776160988640467, 8.779444182129122, 9.745960914353933, 10.686694775936399, 11.68128804228995, 12.645124901566176, 13.676918778752729, 14.708033180914569, 14.627241043127148, 13.683027992974855, 8.88040930672986, 7.862334275810183, 6.966233691060154, 5.96371597012172, 4.958374474955662, 3.986515344363405, 3.0187086142537605, 3.874823157548066, 4.862391814326031, 5.830497892907706, 6.8343728963476265, 7.778567975279445, 8.789942197471762, 9.77453973371025, 10.750899845019735, 11.694057891294623, 12.750795551562817, 13.672018742068335, 13.626111419574384, 12.625471256341926, 7.83829492175243, 6.898338062143626, 5.963377270236066, 4.955428362922897, 3.9924349991675525, 3.023833278017179, 2.0419199584244363, 2.865698325966617, 3.82011325229342, 4.844324424420945, 5.91598823941683, 6.882385121497764, 7.896758191149744, 8.875938990233898, 9.807247510418353, 10.832166552848681, 11.676217379549971, 12.619043719924827, 12.584823795140412, 11.65575796661588, 6.938601282682171, 5.901257883746418, 4.937925175442788, 3.957156119321685, 2.9592088361319675, 2.0194725747211697, 0.9800001235924264, 1.9088853730997246, 2.8671694415357947, 3.9273931820013877, 4.937143345803208, 5.913340102020827, 6.911494826305674, 7.849699461080787, 8.851322384770457, 9.762084176927635, 10.709504096246503, 11.693789686801779, 11.676651013896162, 10.667105047830866, 6.006182670289774, 4.9498771032505795, 3.969862378564332, 3.003011451338364, 2.0473533150788095, 1.0650997069870851, 0.0, 0.93552390483543, 1.9157925724031153, 2.939141001100374, 3.957054817934498, 4.99601582117205, 5.975588966813971, 6.902089745336406, 7.856830400345987, 8.78428028639957, 9.718294097813821, 10.683890363885876, 10.688242477223975, 9.699064320032155, 6.91528960822332, 5.859213618359568, 4.858591716705931, 3.8645155229824466, 2.921646192310187, 1.9403751837318186, 1.0040860599222496, 1.8900654316821917, 2.8621771128733573, 3.792014948094566, 4.857724492817539, 5.803714682233108, 6.811057561039759, 7.881055274241164, 8.882475612370456, 9.782635356659343, 10.692784079855992, 10.803352899540602, 9.73568794368344, 8.70505438054524, 7.750769382218092, 6.804021788231739, 5.895428379574581, 4.903916995258012, 3.936610430372318, 3.0082449640424986, 2.036855827280037, 2.9462465485535114, 3.9161991438770185, 4.793593046205027, 5.77353583577068, 6.768875169999362, 7.761396024756163, 8.815843683250101, 9.808215614760183, 10.757959363928961, 11.030021046464043, 9.96510295612104, 8.947432945078635, 7.946022453324301, 8.682266992495887, 7.813874341801434, 6.951562288486203, 5.9603698825001254, 4.9596259239401, 4.054443498347954, 3.0388441196930707, 3.8776181840284547, 4.948786035154296, 5.779169143180666, 6.798869718776031, 7.723093965506111, 8.754486175675968, 9.76247893388364, 10.725025514918585, 11.07869283364358, 10.077183139358675, 9.042818752406097, 8.023521856288255, 7.005956048800503, 9.748582043129453, 8.850072775286339, 7.867417952902753, 6.933306188480374, 5.931252754292652, 5.004671391031078, 4.090186604615487, 4.872389467028199, 5.887803316792326, 6.80256947290641, 7.735371350566648, 8.747580023387975, 9.679704299018521, 10.633913730345181, 11.679914843396435, 11.849845420461076, 10.79900381161505, 9.822896681491942, 8.888478426658848, 7.890632092769403, 10.80095472437034, 9.9003241250517, 8.852576587603448, 7.865904797252364, 6.941982946657516, 5.961996550483914, 5.035454813037665, 5.869556935992064, 6.818792040007239, 7.759564046945482, 8.703265372848678, 9.631110322266318, 10.627018427571684, 11.567153705941037, 12.52134087328351, 12.738781228435183, 11.745762184607136, 10.767943025734999, 9.82849759669748, 8.804020557249263, 11.780511106456787, 10.88793686385203, 9.882850241480387, 8.878629660510565, 7.911717931648618, 6.901446393298315, 5.9784369586507164, 6.89540043368735, 7.8463088953027755, 8.68952402783862, 9.632540901850385, 10.602779065281284, 11.561724538074516, 12.518769812413094, 13.45456699999717, 13.716601378647175, 12.676983495599453, 11.699814675612426, 10.755143782221364, 9.826714218111043, 12.760777500333903, 11.870548481487068, 10.80853444127467, 9.83729360901064, 8.869138781012445, 7.899292912862, 6.97953690931823, 7.860488955132296, 8.822018927653806, 9.713633314937805, 10.694400938277363, 11.583154198140347, 12.61200024748046, 12.770524849050519, 13.672598869786889, 14.630293511282943, 13.691271475013098, 12.71443817378326, 11.71757591484429, 10.856932490197945, 13.674229497942802, 12.709797523030586, 11.741841403674865, 10.81030367800088, 9.90656959976849, 8.95298389416987, 7.994021735305939, 8.857425073978334, 9.814330954021537, 10.764452083193163, 11.64094451999081, 12.55066975069698, 12.656539541948419, 11.750714012765812, 12.660002978576129, 13.671438978780607, 14.549678571481879, 13.711801735362705, 12.780939140156423, 11.886894022740782, 14.746801506956917, 13.727300616024014, 12.671642877079629, 11.827470021833241, 10.948919883909765, 9.987550391669078, 8.925997871410994, 9.847175065547086, 10.882559918309866, 11.810711100788895, 12.59275885111938, 12.575203954459575, 11.595095121132289, 10.796093807730294, 11.71879530987439, 12.620998278918131, 13.55039187724046, 14.480028187721764, 13.767379156167989, 12.832704727602124, 15.58305152804106, 14.560060368553401, 13.62290705530916, 12.8224619217099, 11.892797096414037, 10.889947279249991, 9.946994101975207, 10.786956584419174, 11.72399785766811, 12.65976444107608, 12.604962888735994, 11.62204113250745, 10.634432315227166, 9.770078517581254, 10.707937948684624, 11.687816697772657, 12.648996303832982, 13.612481844870686, 14.5159966725446, 13.562884884931922, 16.519092612134127, 15.507450876490735, 14.665872821198287, 13.883641401632936, 12.86123786299287, 11.827503012015827, 11.006223784321921, 11.751038168086177, 12.651576832271354, 12.578414353347704, 11.741914731132436, 10.698554751283122, 9.705729343933024, 8.771206438676755, 9.724826048896956, 10.713825067821958, 11.696219428871643, 12.676527021380686, 13.690715956094893, 14.514570532468772], [14.550607110028475, 13.562643149244646, 12.650935918087564, 11.591390333302865, 10.65187295170503, 9.728985076002155, 8.747909778284802, 8.055759072141441, 8.830709112757633, 9.769423865409346, 10.698163339933293, 11.6555954026924, 11.748781652744261, 12.758639124307438, 13.686088996078087, 14.643443331487688, 15.694856786174775, 16.56072622323368, 17.40743896035687, 18.36153459365031, 13.548143782881192, 12.618087339694732, 11.645446760202393, 10.705100949940318, 9.72271873819843, 8.790760474678766, 7.793133403397742, 6.9865558738507945, 7.890945163411067, 8.895778959850386, 9.895926719120087, 10.777074919275622, 11.725269267221938, 12.710539207425239, 13.587841722044386, 14.566567934961222, 15.60650440313246, 16.62426198366761, 17.57821215723841, 17.499836883979896, 12.695656968376667, 11.695062337181316, 10.67720628613885, 9.698164903140313, 8.777065512636232, 7.824938900976262, 6.830841395774693, 6.039986359385414, 6.868767777855367, 7.896945239579988, 8.875628356749397, 9.830695027244808, 10.739602399771858, 11.672111759544142, 12.613412104256511, 13.622629017618127, 14.686085917883986, 15.680204206981287, 16.619716664163455, 16.540569098572814, 11.783063867382227, 10.73730798628713, 9.739994922205636, 8.687592917764047, 7.758441713044423, 6.847296297944014, 5.8909063505805435, 5.038205729659612, 5.89354215710324, 6.85199726230997, 7.809378333691348, 8.779467237142006, 9.754036216853095, 10.729775721783545, 11.70227914994588, 12.672940155806193, 13.725625141956215, 14.704252841214318, 15.72445050886399, 15.569825317352857, 10.794060698973992, 9.744861971638722, 8.767022892552914, 7.703503455066562, 6.772808321367216, 5.845625759040937, 4.915947869467418, 3.998984855701909, 4.865036364472417, 5.838505906998165, 6.840637083805037, 7.843920277293691, 8.810437009518502, 9.751170871100967, 10.745764137454518, 11.709600996730744, 12.741394873917297, 13.772509276079141, 14.705544764645941, 14.618551897810287, 9.81593321156529, 8.797858180645614, 7.9017575958955835, 6.89923987495715, 5.893898379791093, 4.922039249198835, 3.9542325190891905, 2.939299252712636, 3.9268679094906007, 4.894973988072276, 5.898848991512196, 6.843044070444015, 7.854418292636332, 8.839015828874821, 9.815375940184305, 10.758533986459193, 11.815271646727387, 12.736494837232907, 13.704415141093177, 13.560995161177358, 8.77381882658786, 7.833861966979056, 6.8989011750714955, 5.890952267758326, 4.927958904002983, 3.959357182852609, 2.9774438632598663, 1.9301744211311869, 2.88458934745799, 3.908800519585515, 4.9804643345813995, 5.946861216662334, 6.961234286314315, 7.9404150853984685, 8.871723605582924, 9.896642648013252, 10.740693474714542, 11.683519815089397, 12.663127516659205, 12.591281871451312, 7.874125187517601, 6.836781788581847, 5.873449080278218, 4.892680024157115, 3.8947327409673975, 2.9549964795565997, 1.9155240284278565, 0.9733614682642946, 1.9316455367003647, 2.991869277165958, 4.0016194409677786, 4.977816197185398, 5.975970921470244, 6.9141755562453575, 7.9157984799350265, 8.826560272092205, 9.773980191411074, 10.75826578196635, 11.71351160701197, 11.602628952666297, 6.941706575125203, 5.885401008086009, 4.9053862833997615, 3.938535356173794, 2.9828772199142395, 2.0006236118225154, 0.93552390483543, 0.0, 0.9802686675676852, 2.0036170962649438, 3.0215309130990686, 4.060491916336621, 5.040065061978542, 5.9665658405009765, 6.921306495510557, 7.84875638156414, 8.782770192978392, 9.748366459050446, 10.79355690151241, 10.634588224867587, 7.8508135130587515, 6.794737523195, 5.794115621541361, 4.800039427817877, 3.857170097145617, 2.8758990885672486, 1.9396099647576797, 0.9545415268467615, 1.926653208037927, 2.856491043259136, 3.9222005879821085, 4.868190777397677, 5.875533656204328, 6.9455313694057335, 7.9469517075350256, 8.847111451823913, 9.757260175020562, 10.681664360593173, 10.67121184851887, 9.640578285380672, 8.686293287053523, 7.73954569306717, 6.830952284410012, 5.839440900093443, 4.872134335207748, 3.9437688688779287, 2.9700071574773386, 2.0107226437180814, 2.980675239041588, 3.8580691413695973, 4.8380119309352505, 5.83335126516393, 6.8258721199207315, 7.880319778414671, 8.872691709924752, 9.82243545909353, 10.777801747615335, 10.900626860956471, 9.882956849914066, 8.881546358159731, 9.617790897331318, 8.749398246636865, 7.887086193321633, 6.895893787335557, 5.89514982877553, 4.987594828545255, 3.971995449890372, 2.9420942791930247, 4.013262130318866, 4.843645238345236, 5.863345813940602, 6.78757006067068, 7.818962270840537, 8.826955029048209, 9.789501610083153, 10.744126376718505, 11.012707044194107, 9.978342657241528, 8.959045761123686, 7.941479953635932, 10.684105947964884, 9.78559668012177, 8.802941857738183, 7.868830093315806, 6.8651415815047026, 5.901798903445013, 4.931664715976583, 3.9368655621927693, 4.952279411956896, 5.8670455680709805, 6.799847445731219, 7.812056118552544, 8.74418039418309, 9.69838982550975, 10.744390938561004, 11.699820540755265, 11.73452771645048, 10.758420586327372, 9.824002331494277, 8.826155997604832, 11.736478629205772, 10.835848029887131, 9.788100492438877, 8.801428702087795, 7.875871773869567, 6.859124062897849, 5.876932924398762, 4.934033031156633, 5.883268135171809, 6.824040142110053, 7.767741468013248, 8.695586417430887, 9.691494522736253, 10.631629801105605, 11.585816968448079, 12.624902597943416, 12.681286089442565, 11.703466930570428, 10.764021501532909, 9.739544462084693, 12.716035011292218, 11.823460768687461, 10.818374146315819, 9.78243767638123, 8.815525947519282, 7.777293646090492, 6.819915070011813, 5.959876528851918, 6.910784990467346, 7.75400012300319, 8.697016997014956, 9.667255160445853, 10.626200633239085, 11.583245907577663, 12.519043095161738, 13.476740755768375, 13.612507400434882, 12.635338580447856, 11.690667687056793, 10.762238122946474, 13.696301405169335, 12.774356497357733, 11.712342457145335, 10.741101624881304, 9.744986033804622, 8.775140165654177, 7.821015020679327, 6.924965050296865, 7.886495022818376, 8.778109410102374, 9.758877033441934, 10.647630293304916, 11.676476342645028, 12.628174122433744, 13.485516075565085, 14.40978898776399, 14.626795379848527, 13.649962078618689, 12.653099819679719, 11.792456395033376, 14.578037513813467, 13.61360553890125, 12.64564941954553, 11.714111693871544, 10.782416852560667, 9.828831146962047, 8.835499846667036, 7.921901169142902, 8.878807049186108, 9.828928178357732, 10.705420615155381, 11.615145845861548, 11.933911248968585, 12.686237917601241, 13.595526883411559, 14.606962883616035, 15.485202476317308, 14.647325640198137, 13.716463044991855, 12.822417927576211, 15.650609522827581, 14.63110863189468, 13.575450892950293, 12.731278037703905, 11.824767136701942, 10.829028503030175, 9.76747598277209, 8.911651160711655, 9.947036013474436, 10.875187195953465, 11.65723494628395, 11.838241896954532, 10.872466828152454, 11.731617712565724, 12.654319214709819, 13.556522183753561, 14.485915782075889, 15.415552092557194, 14.702903061003418, 13.768228632437554, 16.486859543911724, 15.463868384424066, 14.526715071179824, 13.726269937580565, 12.734275207775134, 11.731425390611088, 10.788472213336304, 9.851432679583743, 10.788473952832678, 11.724240536240648, 11.752708897048558, 10.832738202664393, 9.911804022247331, 10.705602422416684, 11.643461853520053, 12.623340602608087, 13.584520208668412, 14.548005749706116, 15.45152057738003, 14.498408789767351, 17.42290062800479, 16.4112588923614, 15.569680837068951, 14.777524212755345, 13.702715974353966, 12.668981123376923, 11.847701895683018, 10.815514263250746, 11.716052927435923, 11.642890448512274, 10.806390826297006, 9.763030846447693, 8.983101050953188, 9.706730343512184, 10.660349953732386, 11.649348972657387, 12.631743333707073, 13.612050926216115, 14.626239860930323, 15.450094437304202], [15.53087577759616, 14.542911816812332, 13.631204585655249, 12.57165900087055, 11.632141619272716, 10.709253743569842, 9.728178445852489, 8.913821440124291, 7.901171825710641, 8.839886578362353, 9.768626052886301, 10.726058115645408, 11.788054544073125, 12.715037127599446, 13.647858495977003, 14.601787271312844, 15.637014891807858, 16.59974337526129, 17.62556319591639, 18.53912903087614, 14.528412450448878, 13.598356007262417, 12.625715427770078, 11.685369617508004, 10.702987405766116, 9.771029142246451, 8.773402070965428, 7.844618241833644, 6.961407876364074, 7.966241672803394, 8.966389432073095, 9.847537632228628, 10.795731980174944, 11.781001920378246, 12.658304434997394, 13.63703064791423, 14.676967116085468, 15.643993316099923, 16.597943489670726, 17.520479690144633, 13.675925635944353, 12.675331004749001, 11.657474953706535, 10.678433570707998, 9.757334180203918, 8.805207568543947, 7.811110063342379, 6.898048727368264, 5.939230490808374, 6.967407952532994, 7.946091069702403, 8.901157740197814, 9.810065112724866, 10.74257447249715, 11.683874817209519, 12.693091730571135, 13.756548630836994, 14.699935539413602, 15.639447996595768, 16.561211904737554, 12.763332534949912, 11.717576653854815, 10.720263589773321, 9.667861585331732, 8.738710380612108, 7.8275649655117, 6.871175018148229, 5.9285755795120885, 4.964004870056247, 5.922459975262976, 6.879841046644354, 7.849929950095013, 8.824498929806103, 9.800238434736553, 10.772741862898888, 11.743402868759201, 12.796087854909223, 13.723984173646633, 14.744181841296305, 15.590468123517597, 11.774329366541677, 10.725130639206407, 9.7472915601206, 8.683772122634247, 7.753076988934901, 6.825894426608622, 5.896216537035103, 4.889354705554385, 3.935499077425423, 4.908968619951171, 5.911099796758044, 6.914382990246699, 7.88089972247151, 8.821633584053975, 9.816226850407526, 10.780063709683752, 11.811857586870305, 12.792240608511456, 13.725276097078256, 14.639194703975027, 10.796201879132976, 9.778126848213299, 8.882026263463269, 7.879508542524835, 6.874167047358778, 5.90230791676652, 4.934501186656876, 3.919567920280321, 2.9973306224436076, 3.9654367010252827, 4.969311704465203, 5.913506783397022, 6.924881005589338, 7.909478541827827, 8.873178195020397, 9.816336241295286, 10.835002979159702, 11.756226169665222, 12.724146473525492, 13.581637967342099, 9.754087494155545, 8.814130634546741, 7.879169842639181, 6.871220935326011, 5.908227571570668, 4.939625850420294, 3.9577125308275516, 2.910443088698872, 1.9550520604109969, 2.9792632325385218, 4.050927047534406, 4.981998433928573, 5.98410851686899, 6.963289315953144, 7.894597836137598, 8.916373980445567, 9.760424807146856, 10.703251147521712, 11.68285884909152, 12.611924677616052, 8.854393855085286, 7.817050456149532, 6.853717747845903, 5.872948691724801, 4.875001408535083, 3.935265147124285, 2.895792695995542, 1.9536301358319799, 1.0021082496533715, 2.014743507720634, 3.024493671522454, 4.000690427740073, 4.99884515202492, 5.937049786800033, 6.935529812367341, 7.84629160452452, 8.793711523843388, 9.777997114398664, 10.733242939444285, 11.742788905509581, 7.921975242692889, 6.865669675653694, 5.885654950967447, 4.918804023741479, 3.9631458874819248, 2.9808922793902006, 1.9157925724031153, 0.9802686675676852, 0.0, 1.0233484286972585, 2.0412622455313834, 3.0802232487689354, 4.059796394410856, 4.986297172933291, 5.941037827942872, 6.868487713996455, 7.802501525410707, 8.768097791482761, 9.813288233944725, 10.85399469100856, 8.831082180626437, 7.775006190762685, 6.774384289109046, 5.780308095385562, 4.837438764713302, 3.856167756134934, 2.919878632325365, 1.9348101944144467, 0.9463845404702419, 1.8762223756914507, 2.941931920414423, 3.887922109829992, 4.895264988636643, 5.965262701838048, 6.96668303996734, 7.866842784256228, 8.776991507452879, 9.701395693025487, 10.76584276748526, 10.620846952948357, 9.666561954621208, 8.719814360634855, 7.811220951977697, 6.819709567661128, 5.852403002775433, 4.9240375364456135, 3.950275825045023, 2.9909913112857662, 2.000406571473903, 2.877800473801912, 3.8577432633675657, 4.853082597596245, 5.845603452353046, 6.900051110846985, 7.892423042357066, 8.842166791525845, 9.797533080047653, 10.761880689482574, 10.863225517481752, 9.861815025727417, 10.598059564899003, 9.72966691420455, 8.86735486088932, 7.876162454903242, 6.875418496343215, 5.9678634961129395, 4.952264117458056, 3.9223629467607095, 3.0664412673645813, 3.863376570777551, 4.883077146372917, 5.807301393102994, 6.838693603272851, 7.846686361480523, 8.809232942515468, 9.76385770915082, 10.751076114849905, 10.958611324809214, 9.939314428691372, 8.921748621203617, 11.66437461553257, 10.765865347689456, 9.783210525305869, 8.849098760883491, 7.845410249072387, 6.882067571012698, 5.911933383544268, 4.917134229760454, 4.023703780849967, 4.886776900503295, 5.8195787781635335, 6.831787450984859, 7.7639117266154045, 8.718121157942065, 9.764122270993319, 10.71955187318758, 11.752749461196041, 11.738689253895057, 10.804270999061963, 9.806424665172518, 12.716747296773457, 11.816116697454817, 10.768369160006563, 9.78169736965548, 8.856140441437251, 7.8393927304655335, 6.857201591966446, 5.914301698724318, 5.093123649898986, 5.889766979202344, 6.7874728004455624, 7.715317749863202, 8.711225855168568, 9.65136113353792, 10.605548300880393, 11.644633930375731, 12.637652974203778, 12.683735598138114, 11.744290169100594, 10.719813129652378, 13.696303678859904, 12.803729436255146, 11.798642813883504, 10.762706343948915, 9.795794615086967, 8.757562313658177, 7.800183737579498, 6.9401451964196035, 6.1206405051945225, 6.8197269600954815, 7.71674832944727, 8.68698649287817, 9.645931965671402, 10.602977240009979, 11.538774427594054, 12.496472088200692, 13.536089971248414, 13.615607248015541, 12.670936354624478, 11.74250679051416, 14.67657007273702, 13.754625164925418, 12.69261112471302, 11.72137029244899, 10.725254701372307, 9.755408833221862, 8.801283688247011, 7.90523371786455, 7.096350537545552, 7.843836247194666, 8.778608365874248, 9.667361625737232, 10.696207675077343, 11.647905454866061, 12.505247407997402, 13.429520320196307, 14.436625739153461, 14.630230746186374, 13.633368487247404, 12.772725062601062, 15.558306181381152, 14.593874206468936, 13.625918087113215, 12.69438036143923, 11.762685520128352, 10.809099814529732, 9.81576851423472, 8.902169836710588, 8.088662563913283, 8.894655015450024, 9.725151947587696, 10.634877178293864, 11.609221909736164, 12.64886549095477, 13.517843299208161, 14.388374852698643, 15.399872762347593, 15.627594307765822, 14.69673171255954, 13.802686595143896, 16.63087819039527, 15.611377299462365, 14.555719560517979, 13.71154670527159, 12.805035804269627, 11.80929717059786, 10.747744650339776, 9.89191982827934, 9.156891528201612, 9.95190956448272, 10.676966278716264, 10.908704609907538, 11.730529196135304, 12.695213010721144, 13.634587882277506, 14.536790851321248, 15.466184449643576, 16.39582076012488, 15.683171728571104, 14.748497300005239, 17.467128211479412, 16.444137051991753, 15.50698373874751, 14.70653860514825, 13.71454387534282, 12.711694058178773, 11.768740880903989, 10.831701347151428, 10.148359972064696, 10.921350453325786, 10.823171610001566, 9.9032009156174, 10.769866390230181, 11.68587108998437, 12.62373052108774, 13.603609270175774, 14.564788876236099, 15.528274417273803, 16.431789244947716, 15.478677457335037, 18.40316929557248, 17.391527559929084, 16.549949504636636, 15.75779288032303, 14.682984641921651, 13.649249790944609, 12.827970563250704, 11.795782930818431, 11.075938946667941, 10.713353161465282, 9.876853539250014, 8.8334935594007, 9.841163418936038, 10.686999011079871, 11.640618621300073, 12.629617640225074, 13.612012001274758, 14.5923195937838, 15.606508528498008, 16.430363104871887], [16.54029826402981, 15.552334303245983, 14.6406270720889, 13.581081487304202, 12.641564105706367, 11.718676230003492, 10.737600932286139, 9.888910794711613, 8.876261180297963, 7.973422764024581, 8.902162238548529, 9.783499568874447, 10.789133012292393, 11.704903399336493, 12.63772476771405, 13.59165354304989, 14.626881163544905, 15.589609646998335, 16.60221476721913, 17.515780602178886, 15.537834936882529, 14.607778493696069, 13.63513791420373, 12.694792103941655, 11.712409892199767, 10.780451628680103, 9.782824557399078, 8.819707596420967, 7.936497230951396, 7.046585687435682, 8.013642637933915, 8.848616100447895, 9.796810448394211, 10.770868192115293, 11.64817070673444, 12.626896919651276, 13.666833387822514, 14.620644887402666, 15.574595060973468, 16.49713126144738, 14.685348122378006, 13.684753491182654, 12.666897440140188, 11.68785605714165, 10.76675666663757, 9.814630054977599, 8.82053254977603, 7.873138081955585, 6.9143198453956956, 5.997913900576657, 6.956780368319117, 7.902236208417081, 8.799931384461912, 9.732440744234196, 10.673741088946565, 11.682958002308181, 12.74641490257404, 13.676587110716344, 14.61609956789851, 15.537863476040297, 13.772755021383565, 12.726999140288468, 11.729686076206974, 10.677284071765383, 9.74813286704576, 8.836987451945351, 7.88059750458188, 6.906020612607247, 5.9390942246435685, 4.952965923306639, 5.890530345261068, 6.85100841831428, 7.814365201543149, 8.790104706473599, 9.762608134635935, 10.733269140496247, 11.785954126646269, 12.700635744949375, 13.720833412599047, 14.56711969482034, 12.78375185297533, 11.73455312564006, 10.756714046554253, 9.6931946090679, 8.762499475368553, 7.8353169130422735, 6.905639023468755, 5.866799738649544, 4.912944110520582, 3.939474567994834, 4.917867932106454, 5.915461458465966, 6.870765994208557, 7.811499855791023, 8.806093122144574, 9.7699299814208, 10.801723858607353, 11.768892179814198, 12.701927668380998, 13.61584627527777, 11.819550307830236, 10.801475276910558, 9.905374692160526, 8.902856971222093, 7.897515476056036, 6.9256563454637785, 5.957849615354134, 4.94291634897758, 4.020679051140866, 2.9722048363736926, 3.976079839813613, 4.904038619285855, 5.905722202155534, 6.890319738394023, 7.849829766323139, 8.792987812598028, 9.811654550462444, 10.732877740967965, 11.700798044828234, 12.558289538644841, 10.777435922852804, 9.837479063244, 8.902518271336438, 7.894569364023269, 6.931576000267926, 5.962974279117553, 4.98106095952481, 3.9337915173961306, 2.9784004891082554, 1.9860313678869315, 3.0576951828828163, 3.9586500052313154, 4.960760088171733, 5.9399408872558865, 6.871249407440341, 7.893025551748309, 8.737076378449599, 9.679902718824454, 10.659510420394263, 11.588576248918795, 9.877742283782544, 8.840398884846792, 7.8770661765431615, 6.896297120422059, 5.898349837232341, 4.958613575821543, 3.9191411246928003, 2.9769785645292384, 2.02545667835063, 0.9913950790233758, 2.001145242825196, 2.9773419990428156, 3.9754967233276624, 4.9137013581027755, 5.912181383670083, 6.8229431758272625, 7.770363095146131, 8.754648685701406, 9.709894510747027, 10.719440476812323, 8.945323671390147, 7.889018104350953, 6.909003379664705, 5.942152452438737, 4.986494316179183, 4.004240708087459, 2.939141001100374, 2.0036170962649438, 1.0233484286972585, 0.0, 1.0179138168341246, 2.056874820071677, 3.036447965713598, 3.9629487442360327, 4.917689399245614, 5.845139285299197, 6.77915309671345, 7.7447493627855035, 8.789939805247467, 9.830646262311303, 9.854430609323694, 8.798354619459943, 7.797732717806305, 6.803656524082821, 5.860787193410561, 4.879516184832193, 3.9432270610226237, 2.9137520615398564, 1.924525620108498, 0.9946877848872892, 2.060397329610262, 3.0063875190258305, 4.013730397832481, 4.955718453500387, 5.95495172797305, 6.8434943555589705, 7.753643078755621, 8.67804726432823, 9.742494338788003, 10.773127901926202, 10.689910383318466, 9.743162789332112, 8.834569380674957, 7.843057996358386, 6.875751431472692, 5.947385965142873, 4.929217692170433, 3.969933178411176, 2.978547651112159, 1.9962658829977502, 2.976208672563404, 3.971548006792084, 4.964068861548885, 5.890506862509324, 6.882878794019405, 7.832622543188184, 8.774184651350396, 9.738532260785316, 10.667864772599517, 10.885163454424674, 10.887299293560929, 10.753015342901808, 9.890703289586579, 8.8995108836005, 7.898766925040475, 6.94680536323835, 5.931205984583467, 4.901304813886119, 4.044582347002837, 2.9818419799733893, 4.001542555568755, 4.925766802298833, 5.95715901246869, 6.861180322135703, 7.823726903170647, 8.778351669806, 9.727727686152647, 10.762092073105226, 10.96266285738863, 9.945097049900875, 11.650424756063613, 11.789213776386713, 10.806558954003126, 9.872447189580749, 8.824352116197797, 7.861009438138108, 6.890875250669678, 5.896076096885864, 5.001844860488223, 4.005242309699133, 4.938044187359371, 5.950252860180697, 6.882377135811243, 7.8365865671379025, 8.787114306589752, 9.73404583384276, 10.729401032498783, 11.705508162621891, 11.82761942775922, 10.829773093869775, 12.594807546496268, 12.839465126152074, 11.79171758870382, 10.805045798352738, 9.835082308562662, 8.818334597590944, 7.836143459091857, 6.893243565849728, 5.949004395336425, 5.008232388398182, 5.9059382096414, 6.83378315905904, 7.829691264364406, 8.769826542733757, 9.72401371007623, 10.659127891030911, 11.652146934858958, 12.650554506864948, 12.767638597797854, 11.743161558349637, 13.564170268461545, 13.827077864952404, 12.815095455537698, 11.741648211074324, 10.774736482212376, 9.736504180783585, 8.779125604704907, 7.919087063545014, 6.976521250631962, 5.938192369291319, 6.835213738643107, 7.805451902074007, 8.764397374867238, 9.721442649205816, 10.657239836789891, 11.614937497396529, 12.583368245851275, 13.582426156742375, 13.694284783321738, 12.765855219211419, 14.544436662338661, 14.733567032050827, 13.671552991838428, 12.700312159574398, 11.704196568497716, 10.734350700347271, 9.78022555537242, 8.884175584989961, 7.952231282982992, 6.962301656390504, 7.897073775070084, 8.785827034933071, 9.814673084273181, 10.766370864061898, 11.623712817193239, 12.547985729392144, 13.555091148349298, 14.59354833016317, 14.656716915944664, 13.796073491298323, 15.485237204641566, 15.572816073594344, 14.604859954238623, 13.673322228564638, 12.74162738725376, 11.788041681655141, 10.79471038136013, 9.881111703835998, 8.944543309350724, 8.01312042464586, 8.84361735678353, 9.753342587489703, 10.727687318932002, 11.76733090015061, 12.636308708403998, 13.50684026189448, 14.51833817154343, 15.509663419183317, 15.720080141256798, 14.81210908157755, 16.531626181690275, 16.590319166587772, 15.534661427643387, 14.690488572397, 13.783977671395036, 12.788239037723269, 11.726686517465184, 10.87086169540475, 9.998526156157586, 9.070374973678557, 9.7954316879121, 10.72240679159949, 11.702515624926775, 12.667199439512615, 13.577516377105738, 14.522895455875513, 15.452289054197841, 16.381925364679148, 16.692594215004757, 15.757919786438892, 17.50890087786788, 17.42307891911716, 16.485925605872918, 15.685480472273658, 14.693485742468228, 13.690635925304182, 12.747682748029398, 11.810643214276839, 10.975582445929593, 10.039815862521623, 9.956707795663794, 10.878290270204722, 11.744955744817503, 12.69529357641802, 13.63315300752139, 14.613031756609423, 15.574211362669748, 16.537696903707452, 17.441211731381365, 16.488099943768688, 18.444941961960946, 17.598394835214602, 16.580655033163065, 15.607189138584992, 14.532380900183613, 13.654832640415213, 12.652760077324386, 11.722400401785908, 10.812730142411823, 9.84688934712751, 9.010389724912242, 9.808582913988023, 10.81625277352336, 11.696421497513521, 12.650041107733722, 13.639040126658724, 14.62143448770841, 15.601742080217452, 16.615931014931657, 17.439785591305537], [17.558212080863935, 16.570248120080105, 15.658540888923024, 14.598995304138326, 13.659477922540491, 12.736590046837616, 11.755514749120263, 10.889839064654193, 9.877189450240541, 8.97435103396716, 8.189510243586223, 8.802192612873379, 9.807826056291322, 10.723596443335422, 11.656417811712979, 12.61034658704882, 13.645574207543834, 14.58318349427445, 15.584300950385007, 16.49786678534476, 16.555748753716653, 15.625692310530193, 14.653051731037854, 13.712705920775779, 12.730323709033891, 11.798365445514227, 10.800738374233202, 9.820635866363546, 8.937425500893974, 8.04751395737826, 7.119625414540685, 7.867309144446826, 8.815503492393141, 9.789561236114222, 10.66686375073337, 11.645589963650206, 12.685526431821444, 13.602731070568542, 14.556681244139344, 15.479217444613251, 15.70326193921213, 14.702667308016778, 13.684811256974312, 12.705769873975774, 11.784670483471693, 10.832543871811723, 9.838446366610153, 8.874066351898165, 7.915248115338274, 6.998842170519236, 6.0627631449258885, 6.920929252416011, 7.818624428460842, 8.751133788233126, 9.692434132945495, 10.701651046307111, 11.76510794657297, 12.65867329388222, 13.598185751064387, 14.519949659206171, 14.79066883821769, 13.744912957122592, 12.747599893041098, 11.695197888599507, 10.766046683879884, 9.854901268779475, 8.898511321416004, 7.923830465269042, 6.940022494586147, 5.9538941932492175, 4.99651312186784, 5.86970146231321, 6.8330582455420785, 7.808797750472529, 8.781301178634864, 9.751962184495177, 10.804647170645199, 11.682721928115251, 12.702919595764923, 13.549205877986214, 13.801665669809454, 12.752466942474184, 11.774627863388377, 10.711108425902024, 9.780413292202677, 8.853230729876397, 7.923552840302879, 6.8847135554836685, 5.930857927354707, 4.957388384828959, 4.023850708713225, 4.934154502464896, 5.8894590382074865, 6.830192899789953, 7.824786166143504, 8.78862302541973, 9.820416902606283, 10.750978362980074, 11.684013851546872, 12.597932458443644, 12.837464124664361, 11.819389093744684, 10.923288508994652, 9.920770788056219, 8.91542929289016, 7.943570162297903, 6.975763432188259, 5.960830165811704, 5.038592867974991, 3.9901186532078174, 3.0820626164203846, 3.922731663284785, 4.924415246154464, 5.909012782392953, 6.845446593988782, 7.78860464026367, 8.793740733628319, 9.71496392413384, 10.682884227994109, 11.540375721810715, 11.79534973968693, 10.855392880078126, 9.920432088170564, 8.912483180857395, 7.949489817102051, 6.980888095951677, 5.998974776358935, 4.9517053342302555, 3.9963143059423802, 3.003945184721056, 2.085986386078352, 2.977343049230245, 3.9794531321706623, 4.935557714921529, 5.8668662351059835, 6.875111734914183, 7.719162561615474, 8.66198890199033, 9.641596603560137, 10.570662432084669, 10.89565610061667, 9.858312701680918, 8.894979993377287, 7.9142109372561835, 6.916263654066466, 5.976527392655668, 4.937054941526925, 3.994892381363363, 3.043370495184755, 2.0093088958575005, 1.019838286824126, 1.9960350430417453, 2.994189767326592, 3.909318185768418, 4.894267566835958, 5.805029358993137, 6.752449278312005, 7.736734868867281, 8.691980693912901, 9.701526659978196, 9.963237488224273, 8.906931921185079, 7.926917196498831, 6.960066269272863, 6.004408133013309, 5.022154524921584, 3.9570548179344986, 3.0215309130990686, 2.0412622455313834, 1.0179138168341246, 0.0, 1.0389610032375522, 2.0185341488794735, 2.9450349274019083, 3.899775582411489, 4.8272254684650715, 5.761239279879324, 6.726835545951378, 7.772025988413341, 8.812732445477177, 10.87234442615782, 9.816268436294068, 8.81564653464043, 7.821570340916946, 6.8787010102446855, 5.897430001666318, 4.9611408778567485, 3.9316658783739804, 2.9424394369426223, 2.0126016017214137, 1.0528549514129397, 1.9988451408285082, 3.006188019635159, 3.937804636666262, 4.937037911138925, 5.825580538724845, 6.735729261921495, 7.660133447494104, 8.724580521953875, 9.755214085092074, 10.709499083419223, 10.761076606166238, 9.85248319750908, 8.860971813192512, 7.893665248306817, 6.965299781976998, 5.947131509004557, 4.987846995245301, 3.9964614679462835, 3.0141796998318746, 2.04078947812904, 2.964005628594762, 3.9565264833515625, 4.872593045675199, 5.864964977185281, 6.81470872635406, 7.756270834516269, 8.720618443951192, 9.649950955765389, 10.651361447519724, 9.869385476726805, 10.937685627592666, 10.908617106420703, 9.917424700434626, 8.9166807418746, 7.964719180072474, 6.949119801417591, 5.919218630720244, 5.062496163836961, 3.9997557968075137, 3.066123361134391, 3.9182244241015107, 4.949616634271368, 5.843266505301578, 6.8058130863365225, 7.760437852971874, 8.709813869318522, 9.7441782562711, 10.688697233744211, 10.963010866735, 10.632510939229485, 11.698547005970106, 11.824472770837252, 10.890361006414874, 9.842265933031921, 8.878923254972232, 7.908789067503802, 6.9139899137199885, 6.019758677322347, 5.01561752318289, 4.082815645522651, 4.942710481983374, 5.874834757613921, 6.82904418894058, 7.769200489755628, 8.716132017008634, 9.711487215664658, 10.687594345787765, 11.62201260062086, 11.847686910703901, 11.576893729662142, 12.548457746577268, 12.809631405537946, 11.822959615186864, 10.852996125396785, 9.836248414425068, 8.854057275925982, 7.908614712835357, 6.959379608820182, 6.018607601881938, 5.05070966780468, 5.894144151791168, 6.822148886167084, 7.762284164536435, 8.716471331878909, 9.641214074196785, 10.63423311802483, 11.632640690030822, 12.62530999626284, 12.761075375183763, 12.546256451627421, 13.5360704853776, 13.833009272371825, 12.75956202790845, 11.792650299046501, 10.754417997617711, 9.797039421539033, 8.934458210530643, 7.986896464115719, 6.948567582775076, 5.979985196806387, 6.865812894806135, 7.792653265057224, 8.749698539395801, 9.685495726979877, 10.643193387586514, 11.565454429017148, 12.56451233990825, 13.513960362198054, 13.783769036045545, 13.526522845504537, 14.472616245843298, 14.689466808672554, 13.718225976408524, 12.722110385331842, 11.752264517181397, 10.798139372206546, 9.89954673197559, 8.96260649646675, 7.9726768698742605, 7.0418452332333645, 7.846188027665199, 8.842928974463167, 9.794626754251883, 10.651968707383224, 11.57624161958213, 12.579742408430793, 13.579135838079083, 14.47639249482098, 14.813987308132447, 14.467323387807442, 15.431755362719658, 15.62277377107275, 14.691236045398764, 13.759541204087887, 12.805955498489267, 11.812624198194255, 10.896482850821627, 9.95491852283448, 9.023495638129617, 7.988388814946811, 8.813703580221832, 9.78804831166413, 10.81443759053659, 11.664564598593984, 12.535096152084465, 13.546594061733416, 14.537919309373303, 15.539755720133115, 15.830022898411674, 15.513712364856147, 16.482974550353095, 16.552575244477513, 15.708402389231125, 14.801891488229161, 13.806152854557395, 12.74460033429931, 11.88623284239038, 10.869396540179041, 9.941245357700012, 8.94020314607538, 9.782767784331618, 10.762876617658904, 11.727560432244744, 12.605772267295723, 13.551151346065499, 14.480544944387827, 15.410181254869132, 16.39922648919614, 16.775833603273014, 16.490987061033753, 17.493753639218657, 16.617194646328308, 15.623269921830541, 14.568592766412818, 13.577891918725417, 12.634938741450632, 11.696043434262934, 10.759002161014, 10.091048470708042, 9.929034592337938, 10.788271478621756, 11.723539423564027, 12.709276290944349, 13.616629628485489, 14.484332927210973, 15.4212098614885, 16.384695402526205, 17.33372049781617, 17.506013760602812, 17.42702814512682, 16.58048101838048, 15.574228880439179, 14.625882182583922, 13.551073944182543, 12.673525684414143, 11.671453121323315, 10.741093445784838, 9.831423186410754, 9.134237352165204, 10.01131799485482, 10.809511183930601, 11.81718104346594, 12.714335314347645, 13.667954924567846, 14.656953943492848, 15.639348304542533, 16.619655897051576, 17.63384483176578, 18.45769940813966], [18.44719106670247, 17.459227105918643, 16.547519874761562, 15.487974289976862, 14.548456908379027, 13.606496709811365, 12.625421412094012, 11.676398214356926, 10.657168724108322, 9.71845397145661, 8.789714496932662, 7.832282434173555, 8.837915877591499, 9.745909602104978, 10.678730970482535, 11.632659745818376, 12.66788736631339, 13.544222491036898, 14.545339947147454, 15.458905782107207, 17.444727739555187, 16.51467129636873, 15.54203071687639, 14.601684906614315, 13.619302694872427, 12.668272108487976, 11.67064503720695, 10.635589813459942, 9.752379447990371, 8.862467904474657, 7.89003842849767, 6.897398965747003, 7.8455933136933185, 8.811874394883779, 9.689176909502926, 10.667903122419762, 11.707839590591, 12.563770067330989, 13.517720240901792, 14.4402564413757, 16.614034852961012, 15.61344022176566, 14.595584170723194, 13.616542787724656, 12.673649469310229, 11.702450534785472, 10.708353029583902, 9.689020298994562, 8.730202062434671, 7.813796117615632, 6.8777170920222845, 5.951019073716188, 6.840937587230398, 7.773446947002682, 8.714747291715051, 9.723964205076669, 10.787421105342528, 11.619712290644667, 12.559224747826834, 13.48098865596862, 15.701441751966572, 14.655685870871475, 13.65837280678998, 12.60597080234839, 11.676819597628766, 10.724807931753224, 9.768417984389753, 8.738784412365437, 7.754976441682543, 6.7688481403456136, 5.811467068964236, 4.8997912836133874, 5.855371404311635, 6.831110909242085, 7.803614337404421, 8.774275343264735, 9.7916665479017, 10.643760924877698, 11.66395859252737, 12.510244874748663, 14.712438583558336, 13.663239856223067, 12.685400777137259, 11.621881339650907, 10.69118620595156, 9.76400364362528, 8.834325754051761, 7.795486469232551, 6.84163084110359, 5.868161298577841, 4.838804655809621, 3.964244323765073, 4.911772196977043, 5.852506058559509, 6.82688974946427, 7.790726608740496, 8.796182183235041, 9.712017359742521, 10.645052848309321, 11.558971455206093, 13.876425127901912, 12.858350096982235, 11.962249512232205, 10.959731791293772, 9.954390296127714, 8.982531165535457, 8.014724435425812, 6.996517377711366, 5.970346752038763, 4.9008915669567, 3.89701656351678, 2.9528214845849616, 3.94672840492402, 4.931325941162509, 5.80648559075123, 6.749643637026118, 7.7547797303907675, 8.676002920896288, 9.643923224756557, 10.501414718573164, 12.834310742924481, 11.894353883315677, 10.959393091408115, 9.951444184094948, 8.988450820339605, 8.01984909918923, 7.037935779596488, 5.987392546129917, 5.025239335584581, 4.006708073224917, 2.9738297526113557, 2.0074328705304216, 3.0017662909402185, 3.896596711683977, 4.8279052318684315, 5.836150731676632, 6.680201558377923, 7.623027898752779, 8.602635600322586, 9.531701428847118, 11.93461710385422, 10.897273704918469, 9.933940996614838, 8.953171940493736, 7.955224657304019, 7.015488395893221, 5.976015944764478, 5.030579593263025, 4.072295524826955, 3.0120717843613614, 2.0023216205595413, 1.026124864341922, 2.0165029260961482, 2.870357182530866, 3.8553065635984063, 4.766068355755586, 5.713488275074454, 6.697773865629729, 7.653019690675351, 8.662565656740647, 11.002198491461824, 9.94589292442263, 8.965878199736382, 7.999027272510414, 7.04336913625086, 6.061115528159136, 4.996015821172051, 4.060491916336621, 3.0802232487689354, 2.056874820071677, 1.0389610032375522, 0.0, 0.9795731456419212, 1.9060739241643563, 2.860814579173937, 3.78826446522752, 4.722278276641772, 5.687874542713826, 6.733064985175789, 7.773771442239625, 10.643133289383155, 10.820664112391723, 9.820042210738086, 8.8259660170146, 7.883096686342341, 6.9018256777639735, 5.965536553954404, 4.934435105148318, 3.9452086637169597, 3.015370828495751, 1.9496612837727787, 1.0036710943572102, 2.0110139731638608, 2.8988436334287098, 3.8980769079013733, 4.786619535487294, 5.696768258683942, 6.621172444256552, 7.685619518716324, 8.716253081854523, 9.670538080181672, 10.617285674168025, 10.856878873606735, 9.865367489290167, 8.898060924404472, 7.9696954580746535, 6.940545720542227, 5.98126120678297, 4.962262728961335, 3.9175386000545327, 2.937595810488879, 1.9688315821234639, 2.961352436880265, 3.833632042437647, 4.826003973947728, 5.775747723116507, 6.717309831278716, 7.681657440713639, 8.610989952527838, 9.612400444282173, 8.830424473489252, 9.898724624355113, 10.892452649927845, 10.921820376532281, 9.921076417972255, 8.958133391610144, 7.94253401295526, 6.9126328422579135, 5.968667946314229, 4.903114697030172, 3.9165788320511297, 2.9230503776302132, 3.95444258780007, 4.804305502064026, 5.7668520830989705, 6.721476849734322, 7.670852866080969, 8.705217253033547, 9.649736230506662, 10.583208348415376, 9.593549935991936, 10.659586002732556, 11.70533166275996, 11.881182856438695, 10.82554101750807, 9.862198339448382, 8.892064151979952, 7.897264998196137, 6.88185114843201, 5.866072994099628, 4.93327111643939, 3.947536435512077, 4.879660711142623, 5.792790489046385, 6.730239486518076, 7.677171013771082, 8.672526212427105, 9.648633342550212, 10.583051597383307, 11.508566330826568, 10.537932726424591, 11.509496743339717, 12.582483252505241, 12.813781465210685, 11.836271209872935, 10.819523498901217, 9.827391151901763, 8.759070183752096, 7.809835079736921, 6.869063072798677, 5.82681505473751, 4.89897010531987, 5.826974839695787, 6.726030464642239, 7.680217631984712, 8.602253070959232, 9.595272114787278, 10.59367968679327, 11.586348993025288, 12.463050379974757, 11.507295448389868, 12.497109482140047, 13.537746254695739, 13.73289590388423, 12.765984175022282, 11.727751873593492, 10.770373297514814, 9.784913681447382, 8.837351935032457, 7.799023053691815, 6.756090583739217, 5.8706388483348375, 6.797479218585925, 7.754524492924502, 8.665730067208415, 9.623427727815052, 10.526493425779595, 11.525551336670697, 12.4749993589605, 13.40779606378368, 12.487561842266985, 13.433655242605745, 14.495669282818143, 14.677124071748016, 13.649630474096426, 12.679784605945981, 11.699011604643868, 10.750002202892329, 9.813061967383486, 8.823132340790998, 7.812877953095141, 6.851013981193901, 7.8477549279918675, 8.799452707780585, 9.632203047611762, 10.556475959810667, 11.54078140519324, 12.54017483484153, 13.437431491583427, 14.395914602604904, 13.428362384569889, 14.392794359482105, 15.360750478837826, 15.650134140738256, 14.687061292852471, 13.716745314684172, 12.713496430631578, 11.746938321738366, 10.801635424374439, 9.824465375415429, 8.759421534808588, 7.818529533750533, 8.792874265192832, 9.819263544065292, 10.644798938822522, 11.515330492313003, 12.526828401961954, 13.51815364960184, 14.500794716895562, 15.434307947500137, 14.474751361618598, 15.444013547115542, 16.29055195224259, 15.549562417335267, 14.591427014557619, 13.560026178671116, 12.675454775645095, 11.6659147744352, 10.78056042617726, 10.71227807756179, 9.711235865937157, 8.78759373786032, 9.767702571187606, 10.732386385773445, 11.586006607524261, 12.531385686294037, 13.460779284616365, 14.39041559509767, 15.379460829424676, 16.314135257990543, 15.452026057796203, 16.454792635981104, 15.578233643090753, 14.645583080600098, 13.590905925182375, 12.607981740025593, 11.665028562750809, 10.726133255563111, 9.789091982314176, 10.691252724054483, 10.700067312199716, 9.793097432150457, 10.728365377092729, 11.71410224447305, 12.596863968714027, 13.464567267439511, 14.401444201717037, 15.364929742754741, 16.313954838044708, 17.267066625657385, 16.38806714188927, 15.541520015142925, 14.535267877201626, 13.648195341353478, 12.573387102952099, 11.695838843183699, 10.693766280092872, 9.771183267085014, 8.861513007710931, 9.734441605511643, 10.69030460183584, 10.862804788367157, 11.657068348386872, 12.71297432337755, 13.579975868501695, 14.43855889739021, 15.437762523325716, 16.40129587155474, 17.285792872792324, 18.218752273194234], [18.24022181404891, 17.37269814038096, 16.44447380677865, 15.42614336964646, 14.486625988048626, 13.545481383739755, 12.800191148875719, 11.879162073275339, 11.591640183903182, 10.65292543125147, 9.724185956727522, 8.766753893968415, 7.891516250571146, 8.766336456463058, 9.699157824840615, 10.653086600176456, 11.68831422067147, 12.564649345394976, 13.565766801505532, 14.479332636465287, 17.237758486901626, 17.49424444201065, 16.52160386251831, 15.581258052256237, 14.59887584051435, 13.647845254129898, 12.650218182848873, 11.615162959101863, 10.731952593632291, 9.824657647562232, 8.82450988829253, 7.8318704255418625, 6.899193686672965, 7.832301249241858, 8.709603763861006, 9.688329976777842, 10.72826644494908, 11.584196921689067, 12.53814709525987, 13.46068329573378, 16.40713377640951, 16.593013367407583, 15.575157316365116, 14.596115933366578, 13.653222614952151, 12.682023680427394, 11.687926175225824, 10.668593444636482, 9.709775208076591, 8.793369263257553, 7.8572902376642055, 6.885490533511048, 5.861364441588477, 6.793873801360762, 7.735174146073131, 8.744391059434749, 9.807847959700608, 10.640139145002745, 11.579651602184912, 12.5014155103267, 15.481929162259432, 15.635259016513396, 14.637945952431902, 13.585543947990312, 12.656392743270688, 11.704381077395146, 10.747991130031675, 9.718357558007359, 8.734549587324464, 7.7484212859875345, 6.791040214606157, 5.834262743408247, 4.875798258669714, 5.851537763600164, 6.8240411917625, 7.794702197622814, 8.81209340225978, 9.664187779235776, 10.684385446885448, 11.530671729106743, 14.43663756117127, 14.642813001864988, 13.66497392277918, 12.601454485292829, 11.670759351593482, 10.743576789267204, 9.813898899693685, 8.775059614874474, 7.821203986745512, 6.847734444219763, 5.818377801451542, 4.898715783559933, 3.9321990513351217, 4.872932912917588, 5.847316603822348, 6.811153463098574, 7.816609037593121, 8.7324442141006, 9.665479702667401, 10.579398309564173, 13.374527829522943, 13.837923242624155, 12.941822657874123, 11.93930493693569, 10.933963441769633, 9.962104311177377, 8.994297581067732, 7.976090523353288, 6.949919897680685, 5.880464712598622, 4.876589709158702, 3.9323946302268826, 2.967155259282099, 3.9517527955205876, 4.826912445109308, 5.770070491384196, 6.775206584748847, 7.696429775254367, 8.664350079114637, 9.521841572931244, 12.41165262725224, 12.873927028957597, 11.938966237050035, 10.931017329736866, 9.968023965981523, 8.99942224483115, 8.017508925238408, 6.966965691771839, 6.0048124812265025, 4.986281218866839, 3.9534028982532767, 2.9870060161723426, 2.0221931452982975, 2.9170235660420554, 3.8483320862265096, 4.85657758603471, 5.700628412736002, 6.643454753110857, 7.623062454680666, 8.552128283205198, 11.48102399527188, 11.876846850560389, 10.913514142256759, 9.932745086135656, 8.934797802945939, 7.995061541535141, 6.955589090406398, 6.010152738904947, 5.051868670468877, 3.9916449300032832, 2.9818947662014628, 2.0056980099838433, 1.036929780454227, 1.8907840368889444, 2.8757334179564853, 3.7864952101136646, 4.733915129432533, 5.718200719987808, 6.67344654503343, 7.682992511098726, 10.603408581284183, 10.92546607006455, 9.945451345378302, 8.978600418152334, 8.02294228189278, 7.040688673801056, 5.975588966813971, 5.040065061978542, 4.059796394410856, 3.036447965713598, 2.0185341488794735, 0.9795731456419212, 0.0, 0.926500778522435, 1.8812414335320158, 2.808691319585599, 3.7427051309998514, 4.708301397071906, 5.753491839533869, 6.794198296597705, 9.663560143741233, 10.582520698398273, 10.799615356380007, 9.805539162656522, 8.862669831984263, 7.881398823405895, 6.945109699596326, 5.91400825079024, 4.9247818093588815, 3.9949439741376724, 2.9292344294147, 1.9832442399991315, 1.042944692076653, 1.9192704877867888, 2.9185037622594523, 3.8070463898453726, 4.717195113042022, 5.641599298614632, 6.706046373074404, 7.736679936212602, 8.69096493453975, 9.637712528526103, 10.65881509167419, 10.844940634932088, 9.877634070046394, 8.949268603716575, 7.920118866184149, 6.960834352424892, 5.941835874603257, 4.897111745696455, 3.9171689561308005, 2.948404727765385, 2.0890741262758015, 2.854058896795726, 3.8464308283058073, 4.796174577474586, 5.737736685636796, 6.702084295071719, 7.631416806885918, 8.632827298640253, 7.850851327847332, 8.919151478713193, 9.912879504285925, 10.931984119038727, 10.900649563614177, 9.937706537252065, 8.922107158597182, 7.892205987899835, 6.948241091956151, 5.882687842672094, 4.896151977693051, 3.9026235232721342, 3.097072812061585, 3.824732356422105, 4.7872789374570495, 5.741903704092401, 6.691279720439049, 7.725644107391627, 8.67016308486474, 9.603635202773456, 8.613976790350014, 9.680012857090635, 10.725758517118038, 11.659870281540416, 11.805114163149991, 10.841771485090302, 9.871637297621872, 8.876838143838057, 7.861424294073931, 6.845646139741549, 5.912844262081311, 4.9271095811539976, 4.022290935404138, 4.813217343404464, 5.750666340876155, 6.697597868129161, 7.692953066785185, 8.669060196908292, 9.603478451741386, 10.528993185184648, 9.558359580782671, 10.529923597697797, 11.602910106863323, 12.592468890312405, 12.815844355514855, 11.799096644543138, 10.806964297543685, 9.738643329394018, 8.789408225378843, 7.848636218440598, 6.806388200379431, 5.878543250961791, 4.969605063957301, 5.746457319000319, 6.700644486342792, 7.622679925317311, 8.615698969145358, 9.614106541151349, 10.606775847383368, 11.483477234332836, 10.52772230274795, 11.517536336498129, 12.55817310905382, 13.631620353517196, 13.745557320664204, 12.707325019235414, 11.749946443156736, 10.764486827089303, 9.816925080674379, 8.778596199333736, 7.735663729381139, 6.8502119939767585, 5.94010944284744, 6.797123958418491, 7.686156921566495, 8.643854582173132, 9.546920280137675, 10.545978191028777, 11.49542621331858, 12.42822291814176, 11.507988696625066, 12.454082096963827, 13.516096137176225, 14.487336969440255, 14.629203619738348, 13.659357751587903, 12.67858475028579, 11.72957534853425, 10.792635113025408, 9.80270548643292, 8.792451098737061, 7.830587126835822, 6.990385152253382, 7.842052173274573, 8.652629901969842, 9.576902814168747, 10.56120825955132, 11.56060168919961, 12.457858345941506, 13.416341456962984, 12.44878923892797, 13.413221213840187, 14.381177333195907, 15.336520250806663, 14.654204153056973, 13.658435731598045, 12.670162879918703, 11.718396734172504, 11.78120857001636, 10.80403852105735, 9.738994680450508, 8.798102679392455, 8.001009896448197, 8.86186300955928, 9.665225793180602, 10.535757346671083, 11.547255256320033, 12.53858050395992, 13.52122157125364, 14.454734801858216, 13.495178215976676, 14.464440401473624, 15.310978806600671, 14.569989271693347, 13.611853868915698, 12.605865868953137, 11.738186743813648, 10.728646742603752, 11.71503188597212, 11.69185122320371, 10.690809011579077, 9.767166883502242, 9.062454317264327, 9.816483214594797, 10.606433461882341, 11.551812540652117, 12.481206138974445, 13.41084244945575, 14.399887683782756, 15.334562112348621, 14.472452912154282, 15.475219490339185, 14.598660497448831, 13.666009934958176, 12.611332779540454, 11.653821430307614, 10.727760530919362, 9.788865223731664, 10.723563442109036, 11.625724183849343, 11.679640457841636, 10.772670577792379, 10.02311712316945, 10.842498504743837, 11.617290823072107, 12.484994121797591, 13.421871056075117, 14.385356597112821, 15.334381692402788, 16.287493480015467, 15.408493996247348, 14.561946869501003, 13.555694731559704, 12.668622195711558, 11.593813957310179, 10.716265697541779, 9.714193134450952, 8.82478364006466, 9.795984467505791, 10.668913065306503, 11.6247760616307, 11.842377934009079, 10.951820094463592, 11.841370583648336, 12.600402722859775, 13.45898575174829, 14.458189377683796, 15.42172272591282, 16.306219727150406, 17.239179127552315], [17.313721035526473, 16.446197361858527, 15.517973028256213, 14.499642591124026, 13.560125209526191, 12.61898060521732, 11.873690370353286, 12.671374006669215, 12.457198296590576, 11.518483543938864, 10.589744069414916, 9.632312006655809, 8.757074363258543, 7.947354050905332, 8.880175419282889, 9.83410419461873, 10.827504554335759, 11.638148566872541, 12.639266022983097, 13.55283185794285, 16.31125770837919, 17.24131415156565, 16.40765844493457, 15.467312634672496, 14.48927942303279, 13.559179931471249, 12.828466745240346, 12.51010756654449, 11.626897201074918, 10.690215760249625, 9.690068000979924, 8.697428538229257, 7.764751799360361, 7.013318843684132, 7.89062135830328, 8.869347571220116, 9.867456778613368, 10.657696143166632, 11.611646316737435, 12.534182517211343, 15.480632997887072, 16.346483563865547, 16.47010192380774, 15.491060540809203, 14.548167222394778, 13.57696828787002, 12.58287078266845, 11.563538052079108, 10.604719815519218, 9.68831387070018, 8.752234845106832, 7.751048646198443, 6.726922554275873, 5.974891395803036, 6.916191740515405, 7.884328611476293, 8.896407231849542, 9.71363836648031, 10.653150823662477, 11.574914731804263, 14.555428383736997, 15.388729212971361, 15.532890559874527, 14.480488555432936, 13.551337350713313, 12.599325684837773, 11.642935737474302, 10.613302165449985, 9.62949419476709, 8.643365893430161, 7.685984822048783, 6.699820856095642, 5.74135637135711, 5.032555358042438, 5.9701900222909146, 6.934639749664358, 7.885592623737343, 8.737687000713342, 9.757884668363014, 10.604170950584306, 13.510136782648836, 14.396283198322953, 14.559918530221806, 13.496399092735453, 12.565703959036107, 11.638521396709828, 10.70884350713631, 9.670004222317099, 8.716148594188137, 7.74267905166239, 6.713322408894169, 5.764273896247328, 4.797757164022518, 4.047981276323612, 4.920815825299913, 5.884652684576139, 6.890108259070685, 7.805943435578165, 8.738978924144964, 9.652897531041736, 12.448027051000508, 13.389104922005165, 13.868323436396562, 12.865805715458128, 11.860464220292071, 10.85778682370787, 9.889980093598226, 8.871035130795914, 7.8448645051233115, 6.775409320041248, 5.771534316601328, 4.827339237669509, 3.832713371969495, 3.0467677239373803, 3.900411666586873, 4.843569712861761, 5.848705806226411, 6.769928996731932, 7.7378493005922016, 8.595340794408807, 11.485151848729803, 12.425108708338607, 12.865467015572472, 11.857518108259304, 10.894524744503961, 9.895104757361644, 8.913191437768901, 7.861910299214466, 6.899757088669129, 5.881225826309466, 4.848347505695903, 3.8819506236149692, 2.8877512579856934, 1.9905227875196205, 2.9218313077040747, 3.9300768075122754, 4.774127634213566, 5.716953974588423, 6.69656167615823, 7.625627504682762, 10.554523216749443, 11.627645083063497, 11.840014920779195, 10.859245864658094, 9.861298581468377, 8.921562320057578, 7.882089868928834, 6.905097346347573, 5.946813277911503, 4.88658953744591, 3.8768393736440894, 2.90064261742647, 1.9024878931416231, 0.9642832583665095, 1.94923263943405, 2.8599944315912293, 3.8074143509100975, 4.791699941465373, 5.746945766510994, 6.75649173257629, 9.676907802761747, 10.714599235247185, 10.871952123900739, 9.90510119667477, 8.949443060415216, 7.967189452323493, 6.902089745336408, 5.966565840500977, 4.986297172933292, 3.9629487442360336, 2.9450349274019088, 1.9060739241643563, 0.926500778522435, 0.0, 0.9547406550095807, 1.8821905410631639, 2.816204352477416, 3.78180061854947, 4.826991061011433, 5.8676975180752695, 8.737059365218798, 9.656019919875838, 10.656641821529476, 10.732039941178957, 9.789170610506698, 8.80789960192833, 7.871610478118761, 6.840509029312675, 5.851282587881316, 4.921444752660108, 3.855735207937135, 2.9097450185215665, 1.969445470599088, 0.9927697092643537, 1.992002983737017, 2.8805456113229377, 3.790694334519587, 4.715098520092196, 5.779545594551968, 6.8101791576901665, 7.764464156017315, 8.711211750003669, 9.732314313151756, 10.762391439612676, 10.804134848568829, 9.87576938223901, 8.846619644706584, 7.887335130947327, 6.8683366531256915, 5.823612524218889, 4.843669734653235, 3.87490550628782, 2.9912942307311496, 1.927558118273291, 2.9199300497833724, 3.8696737989521517, 4.81123590711436, 5.7755835165492835, 6.704916028363482, 7.706326520117817, 6.924350549324896, 7.992650700190757, 8.98637872576349, 10.005483340516292, 11.032225435607783, 10.8642073157745, 9.848607937119617, 8.81870676642227, 7.874741870478585, 6.8091886211945285, 5.8226527562154855, 4.829124301794569, 3.906224336107342, 2.8982315778996703, 3.860778158934615, 4.815402925569966, 5.764778941916613, 6.799143328869192, 7.743662306342305, 8.677134424251019, 7.687476011827578, 8.7535120785682, 9.799257738595603, 10.73336950301798, 11.789011341948605, 11.764028652488943, 10.793894465020513, 9.799095311236698, 8.783681461472572, 7.76790330714019, 6.835101429479952, 5.795401727248838, 4.831442459449895, 3.886716564882029, 4.82416556235372, 5.771097089606726, 6.76645228826275, 7.7425594183858575, 8.676977673218952, 9.602492406662211, 8.631858802260236, 9.603422819175362, 10.676409328340888, 11.66596811178997, 12.670811944945259, 12.721353811941778, 11.683410266867883, 10.615089298718216, 9.66585419470304, 8.725082187764796, 7.674680346474272, 6.746835397056632, 5.778756588003058, 4.819956540477884, 5.7741437078203575, 6.696179146794877, 7.689198190622923, 8.687605762628914, 9.680275068860933, 10.5569764558104, 9.601221524225512, 10.591035557975694, 11.631672330531385, 12.705119574994761, 13.640546929936361, 13.583770988559612, 12.626392412480934, 11.640932796413502, 10.693371049998577, 9.655042168657934, 8.603955875475979, 7.708206439686429, 6.749260966893198, 5.870623179896056, 6.75965614304406, 7.717353803650697, 8.62041950161524, 9.619477412506342, 10.568925434796146, 11.501722139619325, 10.581487918102628, 11.527581318441388, 12.589595358653787, 13.560836190917817, 14.588329788569407, 13.893144307348189, 12.921897603896918, 12.606021317858449, 11.669081082349607, 10.679151455757118, 9.650445544446733, 8.688581572545493, 7.79953667629914, 6.915551394752138, 7.726129123447407, 8.650402035646312, 9.634707481028885, 10.634100910677175, 11.531357567419072, 12.48984067844055, 11.522288460405532, 12.486720435317748, 13.454676554673469, 14.410019472284224, 13.835221747499247, 12.839453326040319, 11.907412777909208, 12.583954846859902, 12.639203015726032, 11.662032966767022, 10.59698912616018, 9.656097125102125, 8.810161420493955, 7.935362231036845, 8.738725014658167, 9.609256568148648, 10.620754477797599, 11.612079725437486, 12.594720792731206, 13.52823402333578, 12.568677437454241, 13.537939622951185, 14.384478028078233, 13.75100686613562, 12.792871463357972, 11.78688346339541, 10.975436641804153, 11.59420485529115, 12.580589998659514, 12.549845668913381, 11.548803457288749, 10.625161329211911, 9.854666250658203, 8.889982436072364, 9.679932683359906, 10.625311762129682, 11.55470536045201, 12.484341670933315, 13.473386905260321, 14.408061333826186, 13.545952133631847, 14.548718711816747, 13.672159718926396, 12.84702752940045, 11.792350373982728, 10.834839024749888, 9.95444041123994, 10.654423336419061, 11.58912155479643, 12.491282296536735, 12.537634903551307, 11.63066502350205, 10.815329056563327, 9.915997726221404, 10.690790044549672, 11.558493343275156, 12.495370277552682, 13.458855818590386, 14.407880913880353, 15.360992701493032, 14.481993217724913, 13.635446090978569, 12.62919395303727, 11.834532817762279, 10.774831551752452, 9.897283291984053, 8.895210728893225, 9.690341752752058, 10.661542580193185, 11.534471177993897, 12.490334174318093, 12.70037237971875, 11.744032027857468, 10.914869805125903, 11.67390194433734, 12.532484973225856, 13.531688599161361, 14.495221947390386, 15.37971894862797, 16.31267834902988], [16.49788755817623, 15.630363884508283, 14.702139550905969, 13.756208122215325, 12.819679263678289, 11.878534659369416, 12.828431025362864, 13.626114661678795, 13.411938951600156, 12.473224198948444, 11.544484724424496, 10.587052661665389, 9.711815018268123, 8.823587447552539, 8.0341460145725, 8.9257413481319, 9.872763899326179, 10.683407911862961, 11.684525367973517, 12.598091202933272, 15.495424231028947, 16.324774502327237, 15.664223976025871, 14.723878165763796, 13.748833477184888, 12.818733985623345, 13.783207400249925, 13.46484822155407, 12.581637856084498, 11.644956415259205, 10.644808655989504, 9.652169193238837, 8.719492454369941, 7.889552240331339, 7.025889854541173, 7.9609847247332866, 8.912716123603788, 9.702955488157052, 10.656905661727855, 11.579441862201765, 14.613006837367978, 15.391742908855967, 16.334365775698743, 15.691878642677771, 14.694486702747087, 13.784555559325849, 13.53761143767803, 12.518278707088689, 11.559460470528798, 10.64305452570976, 9.706975500116412, 8.705789301208023, 7.681663209285453, 6.851124792450243, 6.051460236753298, 6.930557954164524, 7.941666576839962, 8.75889771147073, 9.698410168652897, 10.620174076794685, 13.600687728727417, 14.433988557961781, 15.397154411765529, 15.43522921044252, 14.506078005722896, 13.554066339847353, 12.597676392483882, 11.568042820459565, 10.58423484977667, 9.598106548439741, 8.640725477058364, 7.654561511105222, 6.69609702636669, 5.908788754689645, 5.016419364979145, 5.980869092352589, 6.9308519687277625, 7.7829463457037615, 8.803144013353434, 9.649430295574728, 12.555396127639256, 13.441542543313373, 14.41938162239918, 14.451139747745037, 13.52044461404569, 12.59326205171941, 11.663584162145892, 10.62474487732668, 9.67088924919772, 8.69741970667197, 7.66806306390375, 6.719014551256908, 5.752497819032098, 4.92421467297082, 3.9670451679881436, 4.93088202726437, 5.9353676040611045, 6.851202780568585, 7.784238269135384, 8.698156876032158, 11.493286395990928, 12.434364266995585, 13.45888080256394, 13.820546370467708, 12.815204875301651, 11.81252747871745, 10.844720748607806, 9.825775785805494, 8.799605160132893, 7.730149975050829, 6.726274971610909, 5.78207989267909, 4.787454026979075, 3.923001120584588, 2.9466410092751034, 3.889799055549992, 4.893965151216831, 5.815188341722352, 6.7831086455826215, 7.640600139399228, 10.530411193720223, 11.470368053329027, 12.441562068047721, 12.812258763268884, 11.849265399513541, 10.849845412371224, 9.867932092778481, 8.816650954224045, 7.854497743678709, 6.835966481319046, 5.803088160705484, 4.83669127862455, 3.842491912995274, 2.8993691705767595, 1.9680606503923053, 2.975336152502695, 3.819386979203986, 4.7622133195788425, 5.74182102114865, 6.670886849673182, 9.599782561739863, 10.672904428053917, 11.617426455189237, 11.813986519667672, 10.816039236477955, 9.876302975067157, 8.836830523938414, 7.859838001357153, 6.901553932921083, 5.84133019245549, 4.831580028653669, 3.8553832724360504, 2.8572285481512036, 1.9190239133760902, 0.9944919844244694, 1.9052537765816489, 2.852673695900517, 3.8369592864557927, 4.792205111501414, 5.80175107756671, 8.722167147752167, 9.759858580237605, 10.649363658310781, 10.859841851684353, 9.904183715424798, 8.921930107333074, 7.856830400345988, 6.921306495510557, 5.941037827942872, 4.917689399245614, 3.899775582411489, 2.860814579173937, 1.8812414335320158, 0.9547406550095807, 0.0, 0.9274498860535831, 1.8614636974678356, 2.8270599635398894, 3.8722504060018528, 4.9129568630656895, 7.782318710209218, 8.701279264866258, 9.701901166519896, 10.695977360243381, 10.743911265516278, 9.76264025693791, 8.826351133128341, 7.795249684322255, 6.806023242890896, 5.876185407669688, 4.810475862946715, 3.864485673531147, 2.924186125608669, 1.9475103642739344, 1.0372623287274363, 1.9258049563133568, 2.8359536795100064, 3.760357865082616, 4.824804939542388, 5.855438502680586, 6.809723501007735, 7.756471094994088, 8.777573658142174, 9.807650784603094, 10.833690622569904, 10.83051003724859, 9.801360299716166, 8.842075785956908, 7.823077308135272, 6.7783531792284695, 5.798410389662815, 4.829646161297401, 3.94603488574073, 2.8822987732828715, 2.073953497766113, 2.9954071882992075, 3.8564952521047804, 4.820842861539703, 5.750175373353902, 6.751585865108237, 5.969609894315316, 7.037910045181177, 8.03163807075391, 9.050742685506712, 10.077484780598203, 11.149996995761544, 10.803348592129199, 9.77344742143185, 8.829482525488165, 7.7639292762041086, 6.7773934112250664, 5.78386495680415, 4.860964991116923, 3.852972232909251, 3.114730085524646, 4.016463890438551, 4.810038286907033, 5.844402673859612, 6.788921651332725, 7.722393769241439, 6.732735356817998, 7.798771423558619, 8.844517083586023, 9.7786288480084, 10.834270686939025, 11.797613364998714, 11.748635120030094, 10.75383596624628, 9.738422116482154, 8.722643962149771, 7.789842084489533, 6.750142382258419, 5.786183114459476, 4.84145721989161, 4.078117488943751, 4.972158054475311, 5.81171163325317, 6.787818763376277, 7.7222370182093725, 8.647751751652631, 7.677118147250655, 8.648682164165782, 9.721668673331308, 10.71122745678039, 11.716071289935678, 12.7375345488074, 12.638150921877463, 11.569829953727796, 10.62059484971262, 9.679822842774376, 8.629421001483852, 7.701576052066213, 6.733497243012639, 5.774697195487464, 5.033697761972452, 5.897240111663462, 6.758470006245256, 7.732865107619334, 8.725534413851355, 9.60223580080082, 8.646480869215933, 9.636294902966114, 10.676931675521805, 11.750378919985181, 12.685806274926781, 13.6769843916218, 13.581133067490514, 12.595673451423082, 11.648111705008157, 10.609782823667514, 9.558696530485559, 8.66294709469601, 7.704001621902778, 6.8253638349056365, 6.019210197196155, 6.950683651102831, 7.689691317237572, 8.664736757496762, 9.614184779786566, 10.546981484609745, 9.62674726309305, 10.57284066343181, 11.634854703644208, 12.606095535908239, 13.633589133559829, 13.0471149026378, 13.798131000544124, 13.560761972868029, 12.623821737359187, 11.633892110766698, 10.605186199456313, 9.643322227555073, 8.754277331308721, 7.870292049761718, 6.985683177599502, 7.883731883098446, 8.703979296651216, 9.679360255667595, 10.576616912409492, 11.535100023430969, 10.567547805395954, 11.53197978030817, 12.49993589966389, 13.455278817274646, 12.926858901012418, 11.99342392132993, 12.783646174556415, 13.538695501869482, 13.593943670735612, 12.616773621776602, 11.55172978116976, 10.610837780111705, 9.764902075503535, 8.890102886046424, 7.998279068810262, 8.842586415600783, 9.739585188860346, 10.67672381724704, 11.639980137721626, 12.5734933683262, 11.61393678244466, 12.583198967941609, 13.429737373068654, 12.842644019648791, 11.884508616871143, 10.940854058685021, 11.85167003845136, 12.54894551030073, 13.535330653669094, 13.504586323922961, 12.503544112298329, 11.579901984221491, 10.809406905667782, 9.844723091081942, 8.939486737512002, 9.884865816281778, 10.738871883101766, 11.66850819358307, 12.657553427910077, 13.587052529262182, 12.591211478622267, 13.59397805680717, 12.717419063916816, 11.938664682913622, 10.883987527495899, 9.988809620039499, 10.830673807887147, 11.609163991428641, 12.54386220980601, 13.446022951546315, 13.492375558560887, 12.58540567851163, 11.770069711572905, 10.870738381230982, 9.950344098701768, 10.818047397427252, 11.679536800202438, 12.643022341240142, 13.592047436530109, 14.545159224142788, 13.527252562715333, 12.680705435968989, 11.67445329802769, 10.879792162752699, 9.866468705265623, 9.051253887273663, 9.771444125540432, 10.645082407761638, 11.616283235202765, 12.489211833003477, 13.445074829327673, 13.65511303472833, 12.698772682867048, 11.869610460135481, 10.933455998489436, 11.792039027377951, 12.715855121811117, 13.679388470040141, 14.563885471277725, 15.496844871679638], [15.570437672122646, 14.702913998454699, 13.774689664852385, 12.828758236161741, 11.900390676806186, 12.76725437041096, 13.734615884978563, 14.553564547732378, 14.339388837653742, 13.400674085002029, 12.471934610478081, 11.514502547718974, 10.639264904321706, 9.751037333606122, 8.961595900626083, 8.163082236322209, 8.945314013272597, 9.755958025809377, 10.757075481919934, 11.670641316879689, 14.567974344975363, 15.397324616273654, 14.736774089972288, 13.796428279710213, 12.829544890312786, 13.707453696664889, 14.689392259865624, 14.392298107607653, 13.509087742138082, 12.57240630131279, 11.57225854204309, 10.579619079292423, 9.646942340423525, 8.817002126384923, 7.953339740594757, 7.198325612923595, 7.9852662375502055, 8.775505602103468, 9.729455775674271, 10.651991976148182, 13.685556951314394, 14.464293022802384, 15.406915889645159, 14.772590055805669, 13.775198115874984, 14.673275270367393, 14.465061323731614, 13.445728593142272, 12.486910356582381, 11.570504411763343, 10.634425386169996, 9.633239187261609, 8.609113095339037, 7.778574678503826, 6.978910122806882, 6.167898842354832, 7.014216690786379, 7.831447825417147, 8.770960282599313, 9.692724190741101, 12.673237842673833, 13.506538671908197, 14.469704525711945, 15.522106530153536, 14.793821915466793, 14.481516225900936, 13.525126278537465, 12.495492706513149, 11.511684735830254, 10.525556434493325, 9.568175363111948, 8.582011397158807, 7.623546912420274, 6.836238640743228, 5.943869251032728, 5.218209980542897, 6.00340208267418, 6.855496459650177, 7.87569412729985, 8.721980409521144, 11.627946241585672, 12.51409265725979, 13.491931736345597, 14.483430414450568, 14.447894500099274, 13.520711937772994, 12.591034048199475, 11.552194763380264, 10.598339135251303, 9.624869592725554, 8.595512949957334, 7.646464437310492, 6.679947705085682, 5.851664559024402, 4.894495054041727, 4.168222915454678, 5.007917718007522, 5.923752894515, 6.8567883830818, 7.7707069899785735, 10.565836509937345, 11.506914380942002, 12.531430916510356, 13.53394863744879, 13.742654761355235, 12.739977364771034, 11.77217063466139, 10.753225671859077, 9.727055046186475, 8.657599861104412, 7.653724857664492, 6.709529778732673, 5.714903913032659, 4.8504510066381705, 3.8740908953286866, 3.1183984400939186, 3.9665152651632476, 4.887738455668767, 5.855658759529037, 6.713150253345644, 9.60296130766664, 10.542918167275444, 11.514112181994138, 12.532653811069354, 12.776715285567125, 11.777295298424807, 10.795381978832065, 9.744100840277628, 8.781947629732292, 7.763416367372629, 6.730538046759067, 5.764141164678133, 4.7699417990488575, 3.8268190566303426, 2.8955105364458884, 2.0478862664491118, 2.8919370931504025, 3.8347634335252585, 4.814371135095065, 5.743436963619597, 8.67233267568628, 9.745454542000333, 10.689976569135654, 11.678193548395798, 11.743489122531539, 10.80375286112074, 9.764280409991997, 8.787287887410736, 7.829003818974666, 6.768780078509073, 5.759029914707252, 4.782833158489633, 3.784678434204787, 2.846473799429673, 1.9219418704780526, 0.9778038905280656, 1.9252238098469336, 2.909509400402209, 3.8647552254478303, 4.874301191513126, 7.794717261698583, 8.832408694184021, 9.721913772257198, 10.688764699483166, 10.831633601478382, 9.849379993386657, 8.784280286399571, 7.848756381564141, 6.868487713996456, 5.845139285299197, 4.827225468465072, 3.7882644652275204, 2.808691319585599, 1.8821905410631639, 0.9274498860535831, 0.0, 0.9340138114142523, 1.8996100774863063, 2.944800519948269, 3.985506977012106, 6.854868824155634, 7.773829378812675, 8.774451280466312, 9.768527474189797, 10.711396804862057, 10.690090142991494, 9.753801019181925, 8.72269957037584, 7.733473128944481, 6.803635293723272, 5.7379257490003, 4.791935559584731, 3.8516360116622517, 2.8749602503275176, 1.9259820397689809, 0.9983550702597737, 1.9085037934564233, 2.832907979029033, 3.8973550534888046, 4.927988616627003, 5.882273614954151, 6.829021208940504, 7.850123772088591, 8.880200898549512, 9.906240736516322, 10.83460620284614, 10.728810185769749, 9.769525672010491, 8.750527194188855, 7.705803065282053, 6.7258602757164, 5.757096047350984, 4.873484771794313, 3.8097486593364547, 2.962673208807658, 2.067957302245625, 2.9290453660511973, 3.8933929754861203, 4.8227254873003185, 5.824135979054653, 5.042160008261733, 6.1104601591275935, 7.104188184700326, 8.123292799453127, 9.150034894544618, 10.222547109707959, 11.238146488362842, 10.700897307485434, 9.756932411541747, 8.691379162257691, 7.70484329727865, 6.711314842857734, 5.7884148771705055, 4.780422118962834, 4.003449796566191, 3.089014004384968, 3.8825884008534493, 4.916952787806029, 5.861471765279141, 6.794943883187855, 5.805285470764415, 6.871321537505035, 7.91706719753244, 8.851178961954817, 9.906820800885441, 10.87016347894513, 11.84029766641356, 11.681285852299863, 10.665872002535737, 9.650093848203355, 8.717291970543116, 7.677592268312002, 6.713633000513059, 5.768907105945193, 4.966837199985296, 4.044708168421728, 4.884261747199586, 5.860368877322694, 6.794787132155789, 7.720301865599048, 6.749668261197071, 7.721232278112197, 8.794218787277721, 9.783777570726807, 10.788621403882095, 11.810084662753816, 12.78556587483574, 12.49727983978138, 11.548044735766204, 10.60727272882796, 9.556870887537436, 8.629025938119796, 7.660947129066222, 6.702147081541048, 5.922417473013997, 4.969790225609879, 5.831020120191672, 6.805415221565751, 7.79808452779777, 8.674785914747236, 7.719030983162349, 8.708845016912527, 9.749481789468218, 10.822929033931594, 11.758356388873198, 12.749534505568217, 13.706913081646896, 13.523123337476665, 12.57556159106174, 11.537232709721097, 10.486146416539142, 9.590396980749594, 8.631451507956362, 7.75281372095922, 6.9079299082376995, 6.023233765049248, 6.7622414311839885, 7.737286871443177, 8.686734893732982, 9.619531598556161, 8.699297377039466, 9.645390777378227, 10.707404817590625, 11.678645649854655, 12.706139247506245, 13.67598511565669, 14.656758116958803, 14.488211858921613, 13.55127162341277, 12.561341996820282, 11.532636085509896, 10.570772113608657, 9.681727217362305, 8.797741935815303, 7.874402888641047, 6.956281997044863, 7.776529410597632, 8.75191036961401, 9.649167026355908, 10.607650137377385, 9.64009791934237, 10.604529894254586, 11.572486013610307, 12.527828931221062, 12.164199789202726, 12.920873807383513, 13.711096060609998, 14.466145387923065, 14.521393556789196, 13.544223507830186, 12.479179667223343, 11.538287666165289, 10.692351961557119, 9.81755277210001, 8.886998779851806, 7.915136529547199, 8.812135302806762, 9.749273931193457, 10.712530251668042, 11.646043482272617, 10.686486896391077, 11.655749081888025, 12.50228748701507, 12.008513656498812, 11.121849505061451, 11.868303944738605, 12.779119924504943, 13.476395396354313, 14.46278053972268, 14.432036209976545, 13.430993998351912, 12.507351870275075, 11.736856791721367, 10.772172977135527, 9.828206448553546, 8.965577229409675, 9.811421997048182, 10.741058307529487, 11.730103541856494, 12.659602643208599, 11.663761592568683, 12.666528170753587, 11.789969177863233, 11.013521756622152, 10.121328415686207, 10.916259506093082, 11.75812369394073, 12.536613877482225, 13.471312095859595, 14.373472837599902, 14.419825444614471, 13.512855564565214, 12.69751959762649, 11.798188267284567, 10.839063809743312, 9.89875881055515, 10.752086914148855, 11.715572455186559, 12.664597550476525, 13.617709338089204, 12.59980267666175, 11.753255549915405, 10.747003411974106, 9.952342276699117, 9.103809593455932, 9.978703773327247, 10.698894011594016, 11.572532293815222, 12.54373312125635, 13.416661719057062, 14.372524715381259, 14.582562920781914, 13.626222568920632, 12.77579531975118, 11.82217570953098, 10.872750440505849, 11.788405235757534, 12.751938583986558, 13.636435585224142, 14.569394985626055], [14.636423860708394, 13.768900187040447, 12.840675853438134, 11.89474442474749, 12.741615231352768, 13.648052674857414, 14.615414189425017, 15.487578359146632, 15.273402649067993, 14.33468789641628, 13.405948421892333, 12.448516359133226, 11.573278715735958, 10.685051145020374, 9.895609712040335, 9.089648793075487, 8.045003477228025, 8.855647489764808, 9.856764945875362, 10.770330780835117, 13.633960533561112, 14.463310804859402, 13.802760278558035, 12.86241446829596, 13.670769444859367, 14.588252001111343, 15.570190564312078, 15.326311919021906, 14.443101553552335, 13.506420112727042, 12.50627235345734, 11.513632890706674, 10.580956151837777, 9.751015937799174, 8.887353552009008, 8.124892169676873, 7.084955701505634, 7.8751950660588985, 8.8291452396297, 9.75168144010361, 12.751543139900141, 13.530279211388132, 14.472902078230907, 13.882869215264636, 14.616422670421565, 15.554073574813847, 15.399075135145868, 14.379742404556525, 13.420924167996635, 12.504518223177596, 11.568439197584247, 10.56725299867586, 9.543126906753288, 8.712588489918078, 7.912923934221134, 7.101912653769085, 6.113906154741808, 6.931137289372576, 7.870649746554743, 8.79241365469653, 11.73922403125958, 12.572524860493946, 13.535690714297694, 14.588092718739283, 15.46574512841287, 15.41553003731519, 14.459140089951719, 13.429506517927402, 12.445698547244508, 11.459570245907578, 10.5021891745262, 9.516025208573058, 8.557560723834525, 7.7702524521574805, 6.877883062446981, 6.15222379195715, 5.103091546629608, 5.955185923605606, 6.975383591255278, 7.821669873476574, 10.693932430171419, 11.580078845845538, 12.557917924931346, 13.549416603036317, 14.480111736735664, 14.454725749187245, 13.525047859613727, 12.486208574794516, 11.532352946665554, 10.558883404139806, 9.529526761371585, 8.580478248724743, 7.613961516499933, 6.785678370438655, 5.828508865455979, 5.102236726868931, 4.10760718196295, 5.0234423584704295, 5.956477847037229, 6.870396453934003, 9.631822698523091, 10.57290056952775, 11.597417105096104, 12.599934826034538, 13.527572839198555, 13.673991176185286, 12.70618444607564, 11.687239483273329, 10.661068857600727, 9.591613672518664, 8.587738669078744, 7.643543590146925, 6.64891772444691, 5.784464818052423, 4.808104706742939, 4.052412251508171, 3.0662047291186765, 3.9874279196241966, 4.955348223484466, 5.812839717301073, 8.668947496252388, 9.608904355861192, 10.580098370579886, 11.598639999655102, 12.561633363410445, 12.711309109839059, 11.729395790246317, 10.67811465169188, 9.715961441146543, 8.697430178786881, 7.664551858173319, 6.698154976092385, 5.703955610463109, 4.760832868044595, 3.829524347860141, 2.981900077863364, 1.9916265571058311, 2.9344528974806874, 3.9140605990504946, 4.843126427575027, 7.738318864272028, 8.811440730586082, 9.755962757721402, 10.744179736981547, 11.636232682744396, 11.73776667253499, 10.698294221406247, 9.721301698824988, 8.763017630388918, 7.702793889923325, 6.6930437261215046, 5.7168469699038855, 4.718692245619039, 3.7804876108439256, 2.855955681892305, 1.911817701942318, 1.0249132738023623, 2.009198864357638, 2.9644446894032592, 3.9739906554685547, 6.860703450284332, 7.89839488276977, 8.787899960842946, 9.754750888068914, 10.710409024328468, 10.783393804800907, 9.718294097813821, 8.782770192978392, 7.802501525410707, 6.779153096713449, 5.761239279879324, 4.722278276641772, 3.742705130999851, 2.816204352477416, 1.8614636974678356, 0.9340138114142523, 0.0, 0.965596266072054, 2.010786708534017, 3.0514931655978534, 5.920855012741383, 6.839815567398423, 7.840437469052061, 8.834513662775546, 9.777382993447805, 10.758654002026173, 10.687814830596176, 9.656713381790091, 8.667486940358733, 7.737649105137524, 6.671939560414551, 5.725949370998983, 4.785649823076504, 3.80897406174177, 2.8599958511832333, 1.932368881674026, 0.9744899820421709, 1.8988941676147806, 2.9633412420745526, 3.9939748052127513, 4.9482598035399, 5.8950073975262525, 6.91610996067434, 7.946187087135261, 8.97222692510207, 9.90059239143189, 10.975418689175735, 10.703539483424743, 9.684541005603107, 8.639816876696305, 7.659874087130651, 6.691109858765236, 5.807498583208566, 4.743762470750707, 3.8966870202219104, 2.985808674754865, 1.9950315546369448, 2.959379164071868, 3.888711675886067, 4.890122167640402, 4.10814619684748, 5.176446347713341, 6.170174373286073, 7.1892789880388746, 8.216021083130366, 9.288533298293707, 10.30413267694859, 11.354739515278572, 10.690946222955999, 9.625392973671943, 8.638857108692902, 7.645328654271985, 6.722428688584758, 5.714435930377086, 4.904709050359452, 3.9500842837241006, 2.948574589439197, 3.9829389763917757, 4.92745795386489, 5.860930071773604, 4.904974934719843, 5.971011001460464, 7.016756661487868, 7.9508684259102465, 9.006510264840871, 9.96985294290056, 10.93998713036899, 11.934786284152805, 11.59988581394999, 10.584107659617608, 9.651305781957369, 8.611606079726254, 7.647646811927311, 6.702920917359445, 5.868026122821051, 4.90577844776086, 3.9502479357853333, 4.9263550659084405, 5.860773320741536, 6.786288054184796, 5.8493577251525, 6.820921742067626, 7.893908251233151, 8.883467034682235, 9.888310867837523, 10.909774126709245, 11.88525533879117, 12.93195375311667, 12.482058547180456, 11.541286540242211, 10.490884698951687, 9.563039749534047, 8.594960940480474, 7.636160892955299, 6.823606395849752, 5.830860504949011, 4.89700630877742, 5.871401410151497, 6.864070716383517, 7.7407721033329855, 6.818720447117778, 7.808534480867957, 8.849171253423648, 9.922618497887022, 10.858045852828626, 11.849223969523646, 12.806602545602324, 13.836812543863331, 13.509575402475992, 12.471246521135349, 11.420160227953394, 10.524410792163845, 9.565465319370613, 8.686827532373472, 7.809118831073454, 6.867845502817458, 5.828227619769736, 6.803273060028924, 7.752721082318729, 8.685517787141908, 7.798986840994895, 8.745080241333657, 9.807094281546055, 10.778335113810085, 11.805828711461675, 12.77567457961212, 13.756447580914234, 14.705456982665773, 14.485285434827022, 13.495355808234534, 12.466649896924148, 11.504785925022908, 10.615741028776554, 9.731755747229554, 8.7755918114768, 7.800893734813073, 6.84251559918338, 7.817896558199756, 8.715153214941655, 9.673636325963132, 8.7397873832978, 9.704219358210016, 10.672175477565737, 11.627518395176493, 12.62150701281136, 13.687343380985425, 14.64510987202425, 15.400159199337317, 15.455407368203446, 14.478237319244435, 13.413193478637595, 12.47230147757954, 11.626365772971369, 10.751566583514261, 9.78677826645283, 8.759748267315409, 7.878121491392511, 8.815260119779204, 9.778516440253789, 10.712029670858364, 9.786176360346506, 10.755438545843454, 11.601976950970501, 11.10820312045424, 12.048416061814729, 12.802317756152856, 13.713133735919195, 14.410409207768565, 15.396794351136931, 15.366050021390796, 14.365007809766164, 13.441365681689327, 12.670870603135619, 11.706186788549779, 10.72798593515457, 9.806801783956258, 8.87740818563393, 9.807044496115235, 10.796089730442242, 11.725588831794346, 10.763451056524111, 11.766217634709015, 10.889658641818663, 10.11321122057758, 11.047894972439485, 11.850273317507334, 12.692137505354982, 13.470627688896476, 14.405325907273847, 15.307486649014152, 15.353839256028722, 14.446869375979464, 13.631533409040742, 12.732202078698819, 11.738843296344335, 10.739983365101732, 9.818073102734603, 10.781558643772307, 11.730583739062274, 12.683695526674953, 11.699492140617178, 10.852945013870833, 9.846692875929536, 9.052031740654545, 10.030376150209209, 10.912717584741499, 11.632907823008267, 12.506546105229473, 13.477746932670602, 14.350675530471314, 15.30653852679551, 15.516576732196164, 14.560236380334885, 13.656593624197635, 12.702974013977434, 11.713974995052432, 10.854391424343282, 11.817924772572306, 12.70242177380989, 13.635381174211803], [13.804165797003355, 12.936642123335409, 12.008417789733095, 12.834314018403386, 13.681184825008664, 14.58762226851331, 15.554983783080914, 16.441065524049918, 16.23899891514005, 15.300284162488337, 14.37154468796439, 13.414112625205282, 12.538874981808014, 11.650647411092427, 10.86120597811239, 10.04097726883544, 8.989563814148354, 8.026835330694924, 8.971093453431967, 9.827972729849831, 12.801702469856073, 13.49771453878735, 13.044723610393074, 13.801984061951856, 14.610339038515264, 15.52782159476724, 16.509760157967975, 16.291908185093963, 15.40869781962439, 14.472016378799099, 13.471868619529397, 12.47922915677873, 11.546552417909833, 10.716612203871227, 9.852949818081063, 9.090488435748926, 8.050551967577688, 7.046382906989015, 7.943473747186305, 8.809323389118324, 11.867263815036123, 12.564682945316079, 13.507305812158855, 14.507697222136839, 15.505089162067524, 16.422164933694447, 16.364671401217922, 15.34533867062858, 14.38652043406869, 13.470114489249651, 12.534035463656302, 11.532849264747917, 10.508723172825345, 9.67818475599013, 8.878520200293188, 8.067508919841138, 7.079502420813862, 6.102325130302693, 6.984978254111348, 7.850055603711244, 10.854944706395562, 11.606928594421893, 12.57009444822564, 13.622496452667232, 14.500148862340817, 15.444522330662197, 15.424736356023773, 14.395102783999457, 13.411294813316562, 12.425166511979633, 11.467785440598254, 10.481621474645115, 9.523156989906582, 8.735848718229533, 7.8434793285190345, 7.117820058029204, 6.068687812701662, 5.126373764535723, 6.056494171035045, 6.879311822491287, 9.809653105307401, 10.614482579773485, 11.592321658859293, 12.583820336964264, 13.51451547066361, 14.44169803298989, 14.490644125685781, 13.45180484086657, 12.497949212737609, 11.52447967021186, 10.49512302744364, 9.5460745147968, 8.579557782571989, 7.751274636510709, 6.794105131528033, 6.067832992940985, 5.073203448035004, 4.194630199400546, 5.014119796051943, 5.928038402948716, 8.747543373659074, 9.607304303455697, 10.631820839024051, 11.634338559962485, 12.561976573126502, 13.599368501543122, 13.671780712147696, 12.652835749345384, 11.626665123672781, 10.557209938590718, 9.553334935150799, 8.609139856218981, 7.614513990518965, 6.750061084124477, 5.773700972814993, 5.018008517580225, 4.03180099519073, 3.1586157605543126, 4.01299017249918, 4.870481666315786, 7.703351230180334, 8.643308089789139, 9.614502104507833, 10.63304373358305, 11.596037097338392, 12.644722881069953, 12.694992056318371, 11.643710917763935, 10.681557707218598, 9.663026444858934, 8.630148124245375, 7.66375124216444, 6.669551876535164, 5.726429134116649, 4.795120613932195, 3.947496343935418, 2.9572228231778848, 2.1056407384108033, 2.971702548065208, 3.90076837658974, 6.772722598199974, 7.845844464514028, 8.790366491649348, 9.778583470909492, 10.670636416672341, 11.61037267808314, 11.663890487478302, 10.686897964897042, 9.728613896460972, 8.668390155995379, 7.658639992193559, 6.68244323597594, 5.6842885116910935, 4.746083876915979, 3.821551947964359, 2.877413968014372, 1.9905095398744161, 1.0668408133723515, 2.022086638417973, 3.0316326044832684, 5.895107184212279, 6.932798616697715, 7.822303694770891, 8.78915462199686, 9.744812758256414, 10.727066366348138, 10.683890363885876, 9.748366459050446, 8.768097791482761, 7.744749362785503, 6.726835545951378, 5.687874542713826, 4.708301397071905, 3.78180061854947, 2.8270599635398894, 1.8996100774863063, 0.965596266072054, 0.0, 1.0451904424619631, 2.0858968995257996, 4.955258746669328, 5.874219301326368, 6.874841202980006, 7.86891739670349, 8.81178672737575, 9.793057735954118, 10.729346859763687, 10.622309647862142, 9.633083206430785, 8.703245371209576, 7.637535826486604, 6.691545637071036, 5.751246089148558, 4.774570327813824, 3.825592117255287, 2.89796514774608, 1.9140595756980687, 0.9332979015427266, 1.9977449760024986, 3.028378539140697, 3.982663537467845, 4.929411131454198, 5.950513694602285, 6.980590821063206, 8.006630659030016, 8.934996125359834, 10.00982242310368, 10.969106936862937, 10.65013727167516, 9.605413142768358, 8.625470353202704, 7.656706124837289, 6.77309484928062, 5.709358736822761, 4.862283286293964, 3.9253782684107628, 2.9346011482928427, 1.993782897999814, 2.9231154098140126, 3.9245259015683476, 3.1425499307754263, 4.210850081641287, 5.20457810721402, 6.223682721966821, 7.250424817058311, 8.322937032221652, 9.338536410876536, 10.389143249206517, 11.460311100332358, 10.590989239743996, 9.604453374764955, 8.610924920344038, 7.688024954656812, 6.68003219644914, 5.84427864401535, 4.889653877379998, 3.8881441830950947, 3.050323809324673, 3.9618616877928354, 4.89533380570155, 3.962616883734557, 5.028652950475177, 6.074398610502581, 7.00851037492496, 8.064152213855584, 9.027494891915273, 9.997629079383703, 10.992428233167518, 12.007842082931644, 11.549703925689661, 10.616902048029422, 9.577202345798307, 8.613243077999364, 7.668517183431499, 6.807595716476948, 5.845348041416758, 4.889817529441231, 4.063291511455886, 4.979362078375532, 5.820691788112742, 4.9069996741672135, 5.87856369108234, 6.951550200247865, 7.9411089836969495, 8.945952816852238, 9.967416075723959, 10.942897287805883, 11.989595702131382, 12.938830806146557, 12.506882806314264, 11.45648096502374, 10.5286360156061, 9.560557206552527, 8.601757159027354, 7.763175989505649, 6.770430098604908, 5.836575902433317, 5.008337855698943, 5.982659474017513, 6.775175837260932, 5.876362396132492, 6.86617642988267, 7.906813202438362, 8.980260446901736, 9.91568780184334, 10.90686591853836, 11.864244494617038, 12.894454492878046, 13.859207504690664, 13.436842787207402, 12.385756494025447, 11.490007058235898, 10.531061585442666, 9.652423798445527, 8.748688424729352, 7.807415096473355, 6.7677972134256335, 5.9402095055763695, 6.889657527866174, 7.822454232689353, 6.856628790009609, 7.802722190348369, 8.864736230560768, 9.835977062824798, 10.863470660476388, 11.833316528626833, 12.814089529928946, 13.763098931680485, 14.831060831192795, 14.460952074306586, 13.4322461629962, 12.470382191094961, 11.581337294848609, 10.69735201330161, 9.715161405132699, 8.74046332846897, 7.782085192839277, 6.954833003747202, 7.852089660489099, 8.810572771510577, 7.797429332312513, 8.761861307224729, 9.72981742658045, 10.685160344191205, 11.679148961826073, 12.744985330000137, 13.748234214052731, 14.760035050526522, 15.796359094009146, 15.44383358531649, 14.378789744709648, 13.437897743651593, 12.591962039043423, 11.717162849586316, 10.726347860108726, 9.699317860971306, 8.817691085048407, 7.952196565326649, 8.915452885801233, 9.848966116405808, 8.843818309361222, 9.813080494858166, 10.659618899985214, 11.67127121435047, 12.629406617128119, 13.689006260256068, 14.678730001991248, 15.376005473840621, 16.362390617208987, 16.33164628746285, 15.330604075838217, 14.40696194776138, 13.624357768038905, 12.659673953453066, 11.667555528810466, 10.746371377612155, 9.816977779289827, 8.964147705518103, 9.95319293984511, 10.86252527734179, 9.821093005538827, 10.823859583723728, 10.06084648274878, 11.05777155749791, 11.999223448199439, 12.815869583579389, 13.657733771427035, 14.436223954968533, 15.370922173345903, 16.27308291508621, 16.319435522100775, 15.412465642051519, 14.585020573944028, 13.685689243602106, 12.678412890000232, 11.679552958757629, 10.7576426963905, 9.949300580067268, 10.898325675357235, 11.851437462969914, 10.757134089631894, 9.967273521427439, 9.017880716859652, 9.996592077574874, 10.981704625969163, 11.878313850813553, 12.59850408908032, 13.47214237130153, 14.443343198742658, 15.31627179654337, 16.27213479286757, 16.48217299826822, 15.513723545238172, 14.596163217853531, 13.64254360763333, 12.653544588708328, 11.793961017999179, 10.985666708867267, 11.870163710104851, 12.803123110506764], [12.822857740642334, 11.99466744691444, 12.813716169023873, 13.716418634403746, 14.563289441009026, 15.46972688451367, 16.437088399081272, 17.34736506762174, 17.284189357602013, 16.3454746049503, 15.416735130426353, 14.459303067667246, 13.584065424269978, 12.69583785355439, 11.895343334714399, 10.903661042262065, 9.852247587574979, 8.889519104121549, 8.01161164586777, 8.868490922285634, 11.820394413495052, 12.452524096325384, 13.425164675817722, 14.365510486079797, 15.347892697821685, 16.342796064934983, 17.203371014031767, 17.33709862755592, 16.453888262086352, 15.517206821261063, 14.517059061991361, 13.524419599240694, 12.591742860371797, 11.76180264633319, 10.898140260543025, 9.979904901930393, 8.939968433759155, 7.909066680415639, 6.983991939622107, 7.849841581554126, 10.82207337257416, 11.519492502854114, 12.462115369696889, 13.462506779674873, 14.459898719605558, 15.37697449123248, 16.241079006408718, 16.39052911309054, 15.431710876530651, 14.515304931711613, 13.579225906118264, 12.57803970720988, 11.553913615287309, 10.723375198452095, 9.92371064275515, 9.034220564641888, 8.02869368866077, 6.965008903729316, 6.02549644654715, 6.890573796147046, 9.809754263933598, 10.561738151959927, 11.524904005763675, 12.577306010205266, 13.454958419878853, 14.399331888200232, 15.301143961214569, 15.440293226461419, 14.456485255778524, 13.470356954441595, 12.512975883060216, 11.526811917107079, 10.568347432368546, 9.781039160691497, 8.888669770980997, 8.084531702829954, 7.031846716679933, 6.017613710210441, 5.097012363470847, 5.919830014927089, 8.764462662845437, 9.56929213731152, 10.547131216397327, 11.5386298945023, 12.469325028201647, 13.396507590527925, 14.326185480101444, 14.496995283328532, 13.543139655199571, 12.569670112673823, 11.540313469905602, 10.591264957258764, 9.624748225033953, 8.796465078972671, 7.839295573989996, 7.103714977958519, 6.075697203653205, 5.085870145075264, 4.054637988487745, 4.968556595384518, 7.70235293119711, 8.562113860993732, 9.586630396562088, 10.589148117500521, 11.516786130664538, 12.554178059081158, 13.521984789190803, 13.69802619180735, 12.671855566134743, 11.60240038105268, 10.598525377612761, 9.654330298680943, 8.659704432980929, 7.79525152658644, 6.818891415276956, 6.053890502597759, 5.0342947508089315, 4.049855706229031, 3.0535083649349817, 3.9109998587515884, 6.65816078771837, 7.598117647327174, 8.56931166204587, 9.587853291121085, 10.550846654876429, 11.599532438607989, 12.581445758200731, 12.6889013602259, 11.726748149680564, 10.7082168873209, 9.675338566707337, 8.708941684626403, 7.714742318997128, 6.771619576578612, 5.840311056394158, 4.983378328952952, 3.9597165787960864, 3.0168902384212304, 2.01222074050101, 2.941286569025542, 5.72753215573801, 6.800654022052064, 7.745176049187386, 8.73339302844753, 9.625445974210379, 10.565182235621178, 11.604654686749921, 11.732088407359008, 10.773804338922938, 9.713580598457344, 8.703830434655524, 7.727633678437904, 6.729478954153057, 5.791274319377943, 4.866742390426322, 3.9226044104763353, 3.0021362464546715, 2.017850655899396, 1.0626048308537746, 2.0087471848625467, 4.849916741750315, 5.887608174235753, 6.777113252308929, 7.743964179534897, 8.699622315794452, 9.681875923886176, 10.688242477223975, 10.79355690151241, 9.813288233944725, 8.789939805247466, 7.772025988413342, 6.7330649851757896, 5.753491839533869, 4.826991061011434, 3.8722504060018528, 2.9448005199482696, 2.010786708534017, 1.0451904424619631, 0.0, 1.0407064570638365, 3.910068304207365, 4.8290288588644055, 5.829650760518044, 6.823726954241528, 7.766596284913788, 8.747867293492156, 9.684156417301725, 10.71525786610781, 10.678273648892748, 9.74843581367154, 8.682726268948567, 7.736736079532999, 6.796436531610522, 5.819760770275788, 4.8707825597172505, 3.9431555902080433, 2.9592500181600316, 1.9784883440046896, 0.9525545335405354, 1.9831880966787339, 2.937473095005882, 3.884220688992235, 4.905323252140322, 5.935400378601243, 6.961440216568054, 7.889805682897873, 8.964631980641718, 9.923916494400975, 10.942914972222612, 10.650603585230321, 9.670660795664668, 8.701896567299253, 7.818285291742583, 6.754549179284725, 5.901033938024157, 4.951290188855378, 3.960513068737458, 2.8955949783944543, 1.8779249673520495, 2.879335459106384, 2.0973594883134634, 3.1656596391793244, 4.159387664752057, 5.178492279504858, 6.2052343745963485, 7.277746589759689, 8.293345968414572, 9.343952806744554, 10.415120657870395, 11.48067390715445, 10.649643817226918, 9.656115362806002, 8.733215397118776, 7.725222638911104, 6.870190564459966, 5.915565797824614, 4.914056103539711, 3.935968141448714, 2.916671245330872, 3.850143363239586, 2.939731464113835, 4.005767530854456, 5.0515131908818605, 5.985624955304239, 7.041266794234863, 8.004609472294552, 8.974743659762982, 9.969542813546797, 10.984956663310923, 12.000734817643306, 11.662092490491387, 10.622392788260273, 9.65843352046133, 8.713707625893463, 7.833507636921564, 6.871259961861374, 5.844697020869772, 4.868589890746664, 3.934171635913569, 4.775501345650778, 3.9475178666030155, 4.919081883518142, 5.992068392683667, 6.918223564076229, 7.923067397231516, 8.944530656103236, 9.920011868185162, 10.966710282510661, 11.915945386525836, 12.85671739346408, 12.501671407485706, 11.573826458068066, 10.605747649014493, 9.646947601489318, 8.789087909950267, 7.784474437689904, 6.791455393861858, 5.813636234989721, 4.93746903155555, 5.729985394798968, 4.916880588568294, 5.906694622318472, 6.947331394874164, 7.989717199300527, 8.892802382222618, 9.883980498917637, 10.841359074996316, 11.871569073257323, 12.836322085069941, 13.786677374357218, 13.430946936487413, 12.535197500697864, 11.576252027904632, 10.65578943609261, 9.719992248508534, 8.762294587901897, 7.722676704854174, 6.7455078848671475, 5.864115217079434, 6.787556963859487, 5.897146982445411, 6.843240382784171, 7.9052544229965696, 8.876495255260599, 9.903988852912189, 10.873834721062634, 11.842459025663828, 12.791468427415367, 13.812032117420971, 14.810786661456403, 14.477436605458166, 13.515572633556927, 12.626527737310575, 11.700717650948691, 10.686465228911882, 9.695342819897512, 8.736964684267818, 7.7601313830379794, 6.82654734970236, 7.785030460723838, 6.837947524748315, 7.802379499660531, 8.770335619016251, 9.725678536627006, 10.719667154261874, 11.785503522435938, 12.788752406488532, 13.788404546261404, 14.804344143788702, 15.781514192747712, 15.423980187171614, 14.483088186113559, 13.637152481505389, 12.691297092041788, 11.681227351537268, 10.654197352399848, 9.748820192257314, 8.757494944617427, 7.889910575014495, 8.82342380561907, 7.884336501797023, 8.85359868729397, 9.700137092421015, 10.711789406786272, 11.66992480956392, 12.72952445269187, 13.720728542593587, 14.730268543803483, 15.801441386391863, 16.729592568870892, 16.375794518300182, 15.452152390223345, 14.53065731161073, 13.56597349702489, 12.57385507238229, 11.628475993612515, 10.699082395290187, 9.769446084808882, 8.93998836574712, 9.836982966555052, 8.861611197974629, 9.86437777615953, 10.651401270650545, 11.658221060750712, 12.670445898939164, 13.67329571610321, 14.616248893377994, 15.481414397430497, 16.416112615807865, 17.318273357548172, 17.36462596456274, 16.457656084513484, 15.491320117515853, 14.59198878717393, 13.581082396230551, 12.561657574757989, 11.63974731239086, 10.754598959358047, 9.956350998936266, 10.870129406608893, 9.797652282067695, 9.007791713863242, 9.880564490286277, 10.859275851001499, 11.844388399395788, 12.87812325037283, 13.643694531542284, 14.517332813763494, 15.488533641204622, 16.361462239005334, 17.31732523532953, 17.45550702943633, 16.420023088809995, 15.478267833853891, 14.52464822363369, 13.535649204708688, 12.676065633999539, 11.790965088158046, 10.928189033683882, 11.821815054145743], [11.891409507860603, 12.457599051519303, 13.448681429285473, 14.393699675272273, 15.333217056870108, 16.34351453683292, 17.218666534562836, 18.184668026234743, 18.32489581466585, 17.38618106201414, 16.45744158749019, 15.500009524731082, 14.616212764097611, 13.606355292534435, 12.673533924156878, 11.681851631704545, 10.630438177017458, 9.667709693564028, 8.789802235310251, 7.883897999843816, 10.88894618071332, 11.513043241969388, 12.485683821461727, 13.426029631723802, 14.40841184346569, 15.403315210578992, 16.263890159675775, 17.292278810838262, 17.494594719150186, 16.5579132783249, 15.557765519055197, 14.56512605630453, 13.632449317435633, 12.687467838922801, 11.73682170428971, 10.758095491372874, 9.718159023201636, 8.687257269858119, 7.762182529064588, 6.865248659112308, 9.882592518218164, 10.580011648498118, 11.522634515340894, 12.523025925318878, 13.520417865249563, 14.437493636876487, 15.301598152052726, 16.34570929637288, 16.472417333594485, 15.556011388775447, 14.6199323631821, 13.618746164273716, 12.594620072351145, 11.74095402050672, 10.918167155683765, 9.87034117836911, 8.80688427810325, 7.743199493171797, 6.803687035989631, 5.905980873705228, 8.870273409577603, 9.622257297603932, 10.58542315140768, 11.63782515584927, 12.51547756552286, 13.45985103384424, 14.361663106858577, 15.391296678882894, 15.497191712842358, 14.511063411505429, 13.553682340124052, 12.567518374170914, 11.609053889432381, 10.798617982746123, 9.906248593035622, 8.958070437437202, 7.90538545128718, 6.8911524448176875, 5.875202952913328, 4.935237092485271, 7.824981808489441, 8.629811282955524, 9.607650362041332, 10.599149040146306, 11.529844173845653, 12.457026736171933, 13.386704625745452, 14.425543910564663, 14.583846112263407, 13.610376569737658, 12.581019926969438, 11.6319714143226, 10.665454682097788, 9.814043901027297, 8.85687439604462, 7.977253712565765, 6.949235938260452, 5.959408879682511, 4.9281767230949916, 3.9839636729427, 6.762872076841115, 7.622633006637737, 8.647149542206094, 9.649667263144527, 10.577305276308545, 11.584987662750184, 12.552794392859829, 13.57388747758022, 13.71256202319858, 12.643106838116516, 11.639231834676597, 10.695036755744779, 9.700410890044765, 8.812830348641064, 7.8364702373315795, 6.927429237205005, 5.9078334854161785, 4.923394440836278, 3.9270470995422286, 2.9264069363097707, 5.718679933362376, 6.65863679297118, 7.629830807689875, 8.648372436765092, 9.611365800520435, 10.617741337758584, 11.599654657351326, 12.564762645998771, 12.7674546067444, 11.748923344384735, 10.716045023771173, 9.749648141690239, 8.755448776060964, 7.789198398633236, 6.857889878448781, 5.856917063560198, 4.833255313403333, 3.890428973028477, 2.8857594751082565, 1.9566936465837246, 4.788051301382016, 5.852516564798113, 6.755997891995566, 7.74421487125571, 8.63626781701856, 9.576004078429358, 10.615476529558102, 11.607949693131879, 11.814510795986774, 10.75428705552118, 9.74453689171936, 8.76834013550174, 7.770185411216893, 6.83198077644178, 5.884321212480946, 4.8645380287837705, 3.9171181094649024, 2.9328325189096267, 1.9775866938640054, 0.9680407277987101, 3.91043588739432, 4.898430017043934, 5.78793509511711, 6.754786022343078, 7.710444158602632, 8.692697766694357, 9.699064320032155, 10.634588224867585, 10.853994691008563, 9.830646262311303, 8.81273244547718, 7.773771442239626, 6.794198296597705, 5.86769751807527, 4.9129568630656895, 3.985506977012106, 3.0514931655978534, 2.0858968995257996, 1.0407064570638365, 0.0, 2.9582182061707334, 3.839850701672587, 4.840472603326225, 5.834548797049709, 6.777418127721969, 7.758689136300337, 8.694978260109906, 9.726079708915991, 10.715306150347349, 10.789142270735377, 9.723432726012405, 8.777442536596837, 7.837142988674358, 6.860467227339624, 5.911489016781086, 4.983862047271879, 3.9999564752238683, 3.0191948010685263, 1.993260990604372, 0.9940099394869156, 1.948294937814064, 2.8950425318004167, 3.916145094948504, 4.946222221409425, 5.972262059376234, 6.900627525706054, 7.975453823449898, 8.934738337209156, 9.953736815030792, 10.998460943937594, 10.711367252728506, 9.74260302436309, 8.858991748806421, 7.7952556363485614, 6.941740395087994, 5.991996645919214, 5.001219525801295, 3.936301435458291, 2.918631424415886, 1.9398546047503897, 1.0566530312496267, 2.1249531821154877, 3.1186812076882204, 4.137785822441022, 5.164527917532513, 6.237040132695853, 7.252639511350736, 8.303246349680718, 9.374414200806559, 10.439967450090615, 11.482518627152245, 10.69682181986984, 9.773921854182612, 8.76592909597494, 7.910897021523803, 6.956272254888451, 5.954762560603547, 4.947525212489187, 3.928228316371345, 2.9106625088835916, 1.8990250070499985, 2.9650610737906193, 4.010806733818024, 4.944918498240402, 6.000560337171026, 6.9639030152307155, 7.9340372026991455, 8.92883635648296, 9.944250206247085, 10.960028360579468, 11.892830238239707, 11.663099245324108, 10.699139977525165, 9.754414082957299, 8.757481494046647, 7.795233818986457, 6.744392210140431, 5.768285080017323, 4.833866825184228, 3.8360204912947835, 2.9513976882908866, 3.922961705206013, 4.995948214371538, 5.877517107012391, 6.882360940167678, 7.9038241990393985, 8.879305411121324, 9.926003825446823, 10.875238929461998, 11.816010936400243, 12.860724260521737, 12.614532915131901, 11.646454106078329, 10.667248934417822, 9.713061767075349, 8.684169626960564, 7.691150583132517, 6.71333142426038, 5.814981579891189, 4.7905045404429725, 3.9309540703773336, 4.910574444006343, 5.951211216562035, 6.949010742236689, 7.85209592515878, 8.8432740418538, 9.800652617932478, 10.830862616193485, 11.795615628006104, 12.74597091729338, 13.789999789523444, 13.471475372495078, 12.512529899701846, 11.555484625363269, 10.619687437779193, 9.661989777172556, 8.622371894124834, 7.6452030741378065, 6.741627765415073, 5.848076109503491, 4.91122046425445, 5.857313864593211, 6.919327904805609, 7.890568737069638, 8.868705049751197, 9.838550917901642, 10.80175256859999, 11.75076197035153, 12.771325660357133, 13.770080204392565, 14.821244144666347, 14.451850505354141, 13.562805609107787, 12.60041284021935, 11.58616041818254, 10.59503800916817, 9.636659873538479, 8.659826572308639, 7.704059898037999, 6.878294381590394, 5.852021006557354, 6.8164529814695705, 7.7844091008252905, 8.739752018436045, 9.733740636070912, 10.799577004244977, 11.802825888297571, 12.747698089197566, 13.763637686724865, 14.740807735683875, 15.767787726379794, 15.419366057910773, 14.573430353302602, 13.590992281312447, 12.580922540807927, 11.553892541670507, 10.648515381527973, 9.657190133888086, 8.767423123350135, 7.916687726485627, 6.899743579355205, 7.867672169103009, 8.714210574230055, 9.725862888595312, 10.68399829137296, 11.743597934500912, 12.734802024402626, 13.737448080766319, 14.808620923354699, 15.736772105833728, 16.719602057508364, 16.38843026202056, 15.430352500881389, 14.46566868629555, 13.47355026165295, 12.528171182883174, 11.598777584560846, 10.669141274079541, 9.817500914082759, 8.930246887421609, 7.87701827553281, 8.87845125796857, 9.665474752459586, 10.672294542559753, 11.684519380748204, 12.68736919791225, 13.630322375187035, 14.569217682374733, 15.506258955623668, 16.44202553903164, 17.515043464059932, 17.378624124066793, 16.39101530678651, 15.49168397644459, 14.48077758550121, 13.461352764028648, 12.539442501661519, 11.654294148628706, 10.833863547271905, 9.96339332747545, 8.813059359625877, 9.785982303305722, 10.658755079728756, 11.637466440443978, 12.622578988838267, 13.624924930678086, 14.554211970522328, 15.533299266041736, 16.43383793022691, 17.398836657574478, 18.354699653898674, 18.35520221870699, 17.319718278080654, 16.37796302312455, 15.42434341290435, 14.435344393979348, 13.575760823270198, 12.690660277428705, 11.805701582019521, 10.9150789750123], [9.089518754705317, 9.655708298364017, 10.646790676130188, 11.591808922116986, 12.53132630371482, 13.541623783677633, 14.416775781407548, 15.382777273079453, 16.402006763328057, 17.34072151597977, 18.269460990503717, 18.36937137187461, 17.492508919900537, 16.564573498705165, 15.63175213032761, 14.640069837875277, 13.58865638318819, 12.62592789973476, 11.748020441480984, 10.842116206014548, 8.087055427558035, 8.711152488814102, 9.683793068306441, 10.624138878568516, 11.606521090310403, 12.601424457423704, 13.461999406520487, 14.490388057682972, 15.505225570097734, 16.510059366537053, 17.510207125806755, 17.43448790344806, 16.501811164579163, 15.645686045093532, 14.69503991046044, 13.716313697543605, 12.676377229372367, 11.645475476028851, 10.720400735235321, 9.823466865283041, 7.080701765062878, 7.778120895342831, 8.720743762185606, 9.72113517216359, 10.718527112094275, 11.6356028837212, 12.499707398897439, 13.543818543217592, 14.502636779777482, 15.543324331975224, 16.582973292186857, 16.488108011417243, 15.463981919494673, 14.63344350265946, 13.833778946962516, 12.828559384539842, 11.765102484273983, 10.70141769934253, 9.761905242160363, 8.864199079875961, 6.068382656422316, 6.820366544448644, 7.783532398252392, 8.835934402693983, 9.713586812367572, 10.657960280688952, 11.55977235370329, 12.589405925727606, 13.5732138964105, 14.55934219774743, 15.516723269128807, 15.436880221314443, 14.47841573657591, 13.691107464898863, 12.798738075188362, 11.916288643607935, 10.863603657457913, 9.849370650988421, 8.833421159084061, 7.893455298656005, 5.023091055334154, 5.827920529800236, 6.805759608886044, 7.797258286991019, 8.727953420690366, 9.655135983016645, 10.584813872590164, 11.623653157409375, 12.577508785538337, 13.550978328064085, 14.615679738678256, 14.501333261466128, 13.534816529241317, 12.706533383180037, 11.74936387819736, 10.935471918736498, 9.907454144431187, 8.917627085853244, 7.886394929265725, 6.942181879113434, 3.9609813236858273, 4.820742253482449, 5.845258789050806, 6.84777650998924, 7.775414523153257, 8.801212950941348, 9.769019681050993, 10.790112765771385, 11.77768142254935, 12.745787501131026, 13.749662504570946, 13.564398602888307, 12.569772737188293, 11.705319830793805, 10.72895971948432, 9.885647443375738, 8.866051691586913, 7.881612647007011, 6.885265305712962, 5.8846251424805045, 2.916789180207088, 3.856746039815892, 4.827940054534587, 5.846481683609804, 6.809475047365147, 7.833966625949749, 8.815879945542491, 9.780987934189936, 10.73540286051674, 11.759614032644265, 12.83127784764015, 12.619009988833767, 11.624810623204493, 10.681687880785978, 9.750379360601523, 8.815135269730932, 7.791473519574067, 6.848647179199211, 5.84397768127899, 4.914911852754458, 1.9861605482267277, 3.0592824145407818, 3.9722231801867314, 4.9604401594468746, 5.852493105209724, 6.792229366620522, 7.831701817749265, 8.824174981323043, 9.782459049759114, 10.842682790224707, 11.852432954026527, 11.637701982645268, 10.639547258360421, 9.701342623585308, 8.776810694633687, 7.822756234954505, 6.875336315635637, 5.891050725080361, 4.935804900034739, 3.9262589339694434, 1.0537419358343307, 2.1100475028735253, 3.004160383308275, 3.9710113105342426, 4.926669446793797, 5.908923054885522, 6.91528960822332, 7.85081351305875, 8.831082180626435, 9.854430609323693, 10.872344426157817, 10.643133289383155, 9.663560143741233, 8.737059365218798, 7.782318710209218, 6.854868824155634, 5.920855012741382, 4.955258746669328, 3.910068304207365, 2.9582182061707334, 0.0, 1.0560759898637513, 2.0566978915173895, 3.050774085240874, 3.9936434159131338, 4.974914424491502, 5.911203548301071, 6.942304997107157, 7.931531438538515, 8.861369273759724, 9.927078818482697, 10.022253413381051, 9.014910534574401, 7.944912821372996, 6.943492483243704, 6.0158655137344965, 5.005940400679334, 4.0251787265239924, 2.9575137706668295, 1.9642082666838179, 1.0099232683566697, 1.9566708623430227, 2.97777342549111, 4.007850551952031, 5.033890389918842, 5.962255856248661, 6.943973315658858, 7.903257829418115, 8.922256307239751, 9.862947371870185, 10.154335140809714, 9.103881206252165, 8.111360351495364, 7.047624239037505, 6.055252307527423, 5.105508558358644, 4.1147314382407245, 3.0498133478977207, 2.0321433368553157, 1.0307328451009807, 1.9414208786344647, 2.966523415912717, 3.96025144148545, 4.9793560562382515, 6.006098151329742, 7.016141761281073, 7.945961608071891, 8.834629464893059, 9.9057973160189, 10.848523468845823, 11.019868937796621, 10.026340483375705, 8.994948273205848, 7.986955514998177, 7.024408933963232, 6.069784167327881, 5.068274473042977, 4.038403452839778, 3.019106556721936, 2.0015407492341826, 3.0077359292680317, 4.0027218493976235, 4.928737080919634, 5.862848845342012, 6.918490684272636, 7.881833362332325, 8.851967549800754, 9.829400747892803, 10.84481459765693, 11.860592751989312, 11.852229248805209, 10.812529546574094, 9.848570278775151, 8.89436084744849, 7.848359734397237, 6.886112059337046, 5.83527045049102, 4.859163320367913, 3.9247450655348186, 2.9268987316453745, 4.0601086105089195, 5.0316726274240455, 5.913895715620328, 6.795447454114001, 7.800291287269288, 8.821754546141008, 9.797235758222934, 10.826568216856668, 11.775803320871843, 12.716575327810087, 12.691808165799527, 11.763963216381887, 10.795884407328314, 9.758127174768411, 8.803940007425938, 7.7750478673111525, 6.782028823483106, 5.80420966461097, 4.90585982024178, 3.881382780793564, 5.039664992595366, 6.019285366224376, 6.944169369497268, 7.866941089338299, 8.77002627226039, 9.76120438895541, 10.718582965034088, 11.748792963295095, 12.713545975107714, 13.646535308703225, 13.608796060582705, 12.562353612845667, 11.603408140052435, 10.646362865713858, 9.710565678129782, 8.752868017523145, 7.713250134475422, 6.736081314488397, 5.832506005765664, 4.90728623506701, 6.019931386472483, 6.966024786811244, 8.015062795028829, 8.825605037838374, 9.786635396852807, 10.756481265003252, 11.7196829157016, 12.66869231745314, 13.689256007458743, 14.67064459580241, 14.50459271760597, 13.54272874570473, 12.653683849458378, 11.69129108056994, 10.67703865853313, 9.68591624951876, 8.727538113889066, 7.7507048126592295, 6.79493813838859, 5.937504507153913, 6.960731928775387, 7.925163903687603, 8.893120023043323, 9.798615106828613, 10.79260372446348, 11.810172246311122, 12.73416774168931, 13.665628436299176, 14.681568033826474, 15.658738082785485, 15.451136299319417, 14.510244298261362, 13.664308593653193, 12.681870521663036, 11.671800781158517, 10.644770782021096, 9.739393621878564, 8.748068374238677, 7.858301363700725, 6.975897852049146, 8.033303937789503, 8.976383091321042, 9.822921496448087, 10.815781450660975, 11.773916853438623, 12.833516496566574, 13.666143877794365, 14.655378427867928, 15.726551270456309, 16.65470245293534, 16.402950630447986, 15.479308502371149, 14.52123074123198, 13.55654692664614, 12.56442850200354, 11.619049423233765, 10.689655824911437, 9.760019514430132, 8.90837915443335, 7.9894570129851274, 9.010578633967109, 9.987162180186603, 10.774185674677618, 11.781005464777785, 12.774437942813867, 13.777287759977913, 14.687140108358578, 15.595159946740017, 16.532201219988952, 17.467967803396924, 17.391782076710545, 16.469502364417387, 15.481893547137103, 14.58256221679518, 13.571655825851801, 12.552231004379239, 11.63032074201211, 10.745172388979297, 9.924741787622496, 9.022603453038968, 9.946619718060175, 10.934552688123937, 11.817151440566745, 12.833280950456256, 13.791956765044143, 14.714843492743748, 15.746369790705293, 16.55924153040702, 17.459780194592195, 18.42477892193976, 18.338100147462097, 17.334328497018117, 16.310119251891198, 15.37559634663493, 14.486702444557613, 13.526222634329939, 12.632161922521194, 11.669541756996015, 10.722186711594574, 9.974289100575819], [9.796672260854686, 8.808708300070858, 9.799790677837029, 10.744808923823829, 11.652194816081325, 12.586800548730778, 13.461952546460694, 14.427954038132599, 15.447183528381203, 16.385898281032915, 17.314637755556863, 17.47714807565872, 16.480646227429684, 15.645325090536904, 14.712503722159347, 13.720821429707014, 12.814312352099751, 11.85158386864632, 11.156882072533557, 11.723748701516403, 8.794208933707404, 7.864152490520945, 8.836793070013282, 9.777138880275357, 10.723040602574725, 11.64660122247685, 12.507176171573633, 13.535564822736118, 14.55040233515088, 15.555236131590199, 16.5553838908599, 17.548023353610567, 17.4207717192362, 16.527318540595385, 15.576672405962295, 14.597946193045459, 13.558009724874221, 12.527107971530706, 11.602033230737176, 10.705099360784896, 7.931715528245026, 6.9311208970496745, 7.866952284072378, 8.867343694050362, 9.777387377012527, 10.680779648774346, 11.544884163950584, 12.588995308270738, 13.547813544830628, 14.58850109702837, 15.628150057240001, 16.625432550439807, 16.38294247415171, 15.552404057316501, 14.752739501619557, 13.710191880041696, 12.646734979775838, 11.583050194844384, 10.643537737662218, 9.745831575377816, 7.0191224272505846, 5.9733665461554875, 6.929740920139164, 7.909776213543954, 8.758763577420718, 9.703137045742098, 10.604949118756435, 11.634582690780752, 12.618390661463646, 13.604518962800576, 14.561900034181953, 15.574204760337006, 15.39737629123295, 14.610068019555904, 13.717698629845403, 12.79792113910979, 11.745236152959768, 10.731003146490275, 9.715053654585915, 8.775087794157859, 6.03011925884235, 4.9809205315070795, 5.951968130772816, 6.8710935069059325, 7.773130185743511, 8.700312748069791, 9.62999063764331, 10.668829922462521, 11.622685550591482, 12.59615509311723, 13.635374607000037, 14.63865780048869, 14.453777083898357, 13.625493937837078, 12.668324432854401, 11.817104414238353, 10.78908663993304, 9.799259581355098, 8.76802742476758, 7.823814374615288, 4.99181728610897, 3.9737422551892925, 4.958918019632477, 5.9216117299041535, 6.795582754169668, 7.745136961077597, 8.712943691187242, 9.734036775907635, 10.721605432685601, 11.689711511267276, 12.693586514707196, 13.637781593639014, 13.488733291845334, 12.624280385450845, 11.647920274141361, 10.767279938877593, 9.747684187088765, 8.763245142508865, 7.7668978012148155, 6.766257637982358, 3.949702901131539, 3.009746041522735, 3.941599285116258, 4.91332412270533, 5.829643278381558, 6.777890636085997, 7.7598039556787395, 8.724911944326186, 9.679326870652991, 10.703538042780515, 11.7752018577764, 12.741598739857334, 12.543771177861533, 11.600648435443018, 10.669339915258563, 9.696767765232785, 8.67310601507592, 7.730279674701064, 6.725610176780844, 5.796544348256312, 3.0422365380904792, 2.0126658631255268, 2.91614719032298, 3.904364169583124, 4.796417115345973, 5.7361533767567705, 6.775625827885514, 7.768098991459294, 8.726383059895365, 9.786606800360959, 10.79635696416278, 11.7725537203804, 11.558507813017462, 10.620303178242349, 9.695771249290727, 8.704388730456358, 7.75696881113749, 6.7726832205822145, 5.817437395536593, 4.807891429471297, 2.1098179256980822, 1.0585793153713472, 1.9480843934445238, 2.9149353206704918, 3.870593456930046, 4.85284706502177, 5.859213618359569, 6.794737523195, 7.775006190762685, 8.798354619459943, 9.816268436294067, 10.820664112391723, 10.582520698398273, 9.656019919875838, 8.701279264866258, 7.773829378812675, 6.839815567398422, 5.874219301326368, 4.8290288588644055, 3.839850701672587, 1.0560759898637513, 0.0, 1.0006219016536382, 1.9946980953771227, 2.9375674260493825, 3.9188384346277507, 4.85512755843732, 5.886229007243406, 6.8754554486747645, 7.805293283895973, 8.871002828618945, 9.816993018034513, 9.933871089231442, 8.863873376030035, 7.862453037900744, 6.934826068391537, 5.9249009553363745, 4.944139281181033, 3.87647432532387, 2.8458407621856714, 1.8915557638585232, 0.9448081698721703, 1.9659107330202574, 2.995987859481178, 3.980745125166446, 4.909110591496265, 5.887897325795107, 6.847181839554364, 7.866180317375999, 8.806871382006435, 9.786814171572088, 10.159957196115915, 9.167436341359114, 8.103700228901255, 7.111328297391174, 6.161584548222395, 5.170807428104475, 4.105889337761472, 3.088219326719067, 2.086808834964732, 2.823053374136318, 1.9546607234418651, 2.948388749014598, 3.9674933637673995, 4.99423545885889, 5.962996496528678, 6.88988561820814, 7.778553475029307, 8.849721326155148, 9.792447478982073, 10.812148054577438, 11.082416473239457, 10.0510242630696, 9.043031504861927, 8.080484923826983, 7.125860157191632, 6.124350462906728, 5.094479442703529, 4.075182546585687, 3.057616739097934, 3.889368424769885, 2.9908591569267715, 3.9168743884487816, 4.85098615287116, 5.906627991801784, 6.869970669861473, 7.840104857329903, 8.773324758029052, 9.788738607793178, 10.80451676212556, 11.7373186397858, 11.868605536437846, 10.904646268638903, 9.950436837312242, 8.904435724260988, 7.942188049200798, 6.891346440354772, 5.915239310231665, 4.98082105539857, 3.982974721509126, 4.941741106010773, 4.041110506692133, 4.9020330231494755, 5.78358476164315, 6.788428594798437, 7.809891853670157, 8.785373065752083, 9.770492226992916, 10.719727331008091, 11.660499337946336, 12.70521266206783, 12.820039206245639, 11.851960397192066, 10.814203164632163, 9.86001599728969, 8.831123857174905, 7.838104813346858, 6.860285654474722, 5.939905576076588, 4.915428536628371, 5.92129748809722, 5.028723245492464, 5.932306677026416, 6.855078396867448, 7.758163579789539, 8.749341696484558, 9.706720272563237, 10.736930270824244, 11.701683282636862, 12.590459318839473, 13.634488191069536, 13.61842960270942, 12.659484129916187, 11.70243885557761, 10.766641667993534, 9.808944007386897, 8.769326124339175, 7.792157304352148, 6.866551761600472, 5.938122197490152, 6.901563881974337, 6.101032729833564, 7.003200102557976, 7.813742345367523, 8.774772704381956, 9.744618572532401, 10.70782022323075, 11.656829624982288, 12.677393314987892, 13.614568605938658, 14.665732546212439, 14.598804735568482, 13.709759839322128, 12.747367070433691, 11.733114648396882, 10.741992239382512, 9.78361410375282, 8.806780802522981, 7.828983894223398, 6.968340469577055, 7.842364424277241, 7.151313220101753, 7.936507064958171, 8.786752414357762, 9.78074103199263, 10.798309553840271, 11.722305049218459, 12.653765743828327, 13.669705341355623, 14.646875390314634, 15.612276127925886, 15.566320288125114, 14.720384583516942, 13.737946511526788, 12.727876771022268, 11.700846771884848, 10.795469611742314, 9.804144364102427, 8.892347119535533, 8.006733814472287, 8.914936433291356, 8.202532407735191, 8.866308538362935, 9.803918758190123, 10.762054160967772, 11.821653804095721, 12.654281185323514, 13.643515735397079, 14.71468857798546, 15.642839760464488, 16.564090459054455, 16.5353844922349, 15.57730673109573, 14.61262291650989, 13.62050449186729, 12.675125413097515, 11.745731814775187, 10.816095504293882, 9.938961620871778, 9.004287192305913, 9.892211129468961, 9.213311496600753, 9.817572716592466, 10.798910658066783, 11.762575250343016, 12.765425067507062, 13.675277415887727, 14.583297254269167, 15.520338527518103, 16.456105110926075, 17.529123035954367, 17.27160780551877, 16.283998988238487, 15.419645190592576, 14.514991109398427, 13.571275970594238, 12.610096364533913, 11.646610823496209, 10.697585728206242, 9.744473940593563, 10.828252213562028, 10.160702004538086, 10.860538482481592, 11.860090137989818, 12.780094072573291, 13.702980800272897, 14.734507098234442, 15.54737883793617, 16.447917502121346, 17.412916229468912, 17.422865241920576, 16.379505262071262, 15.355296016944346, 14.420773111688076, 13.531879209610759, 12.679835052381662, 11.785161924228037, 10.822541758702856, 9.875186713301416, 10.696159588130413], [10.662864394702133, 9.674900433918305, 8.954303133127603, 9.82601316627817, 10.651572914427687, 11.586178647077139, 12.461330644807054, 13.42733213647896, 14.446561626727561, 15.385276379379274, 16.31401585390322, 16.537183868999566, 15.540682020770527, 14.742399569563178, 13.820192897454387, 12.865403252472689, 11.958894174865426, 10.996165691411996, 11.842878428535187, 12.72437060317004, 9.66040106755485, 8.73034462436839, 7.917997312467623, 8.858343122729698, 9.722418700921088, 10.64597932082321, 11.506554269919993, 12.534942921082479, 13.54978043349724, 14.55461422993656, 15.554761989206261, 16.54740145195693, 16.533004584668706, 15.676434776784378, 14.808886088788139, 13.830159875871303, 12.918941950587817, 11.976618115117905, 12.602655132390813, 11.705721262438534, 8.79790766209247, 7.7973130308971195, 6.866330382418738, 7.866721792396722, 8.77676547535889, 9.680157747120706, 10.544262262296945, 11.588373406617098, 12.547191643176989, 13.58787919537473, 14.627528155586363, 15.624810648786166, 16.533718021313216, 16.55302595897014, 15.753361403273194, 14.710813781695334, 13.647356881429475, 12.583672096498022, 11.644159639315856, 10.746453477031453, 7.8853145610980295, 6.839558680002932, 5.929119018485525, 6.909154311890315, 7.75814167576708, 8.702515144088458, 9.604327217102796, 10.633960789127112, 11.617768759810007, 12.603897061146936, 13.561278132528315, 14.573582858683364, 15.548151838394453, 15.610689921209541, 14.71832053149904, 13.798543040763427, 12.745858054613405, 11.731625048143913, 10.715675556239553, 9.775709695811496, 6.896311392689795, 5.8471126653545245, 4.951346229119177, 5.870471605252294, 6.772508284089873, 7.699690846416152, 8.62936873598967, 9.668208020808882, 10.622063648937843, 11.595533191463591, 12.634752705346395, 13.63803589883505, 14.60455263105986, 14.626115839490716, 13.668946334508039, 12.81772631589199, 11.789708541586679, 10.799881483008736, 9.768649326421219, 8.824436276268926, 5.8580094199564146, 4.8399343890367374, 3.958296117978838, 4.920989828250515, 5.794960852516029, 6.744515059423959, 7.712321789533603, 8.733414874253995, 9.72098353103196, 10.689089609613635, 11.692964613053555, 12.637159691985373, 13.648533914177689, 13.624902287104483, 12.648542175794999, 11.76790184053123, 10.748306088742405, 9.763867044162504, 8.767519702868455, 7.766879539635997, 4.815895034978984, 3.87593817537018, 2.940977383462619, 3.912702221051691, 4.829021376727919, 5.77726873443236, 6.759182054025102, 7.724290042672547, 8.67870496899935, 9.702916141126874, 10.774579956122759, 11.740976838203693, 12.755349907855676, 12.601270337096656, 11.6699618169122, 10.697389666886425, 9.67372791672956, 8.730901576354704, 7.7262320784344825, 6.79716624990995, 3.9162013959087245, 2.8788579969729717, 1.915525288669342, 2.9037422679294855, 3.7957952136923345, 4.735531475103133, 5.775003926231876, 6.767477089805655, 7.725761158241725, 8.785984898707317, 9.795735062509138, 10.771931818726758, 11.770086543011605, 11.620925079895986, 10.696393150944365, 9.705010632109996, 8.757590712791128, 7.773305122235853, 6.818059297190231, 5.808513331124936, 2.9837827835163275, 1.927477216477133, 0.9474624917908855, 1.9143134190168531, 2.8699715552764076, 3.8522251633681317, 4.858591716705931, 5.79411562154136, 6.7743842891090456, 7.797732717806304, 8.815646534640429, 9.820042210738086, 10.799615356380007, 10.656641821529476, 9.701901166519896, 8.774451280466312, 7.84043746905206, 6.874841202980006, 5.829650760518043, 4.8404726033262255, 2.0566978915173895, 1.0006219016536382, 0.0, 0.9940761937234844, 1.9369455243957443, 2.9182165329741125, 3.8545056567836813, 4.885607105589767, 5.874833547021126, 6.804671382242335, 7.870380926965307, 8.816371116380875, 9.823713995187525, 9.864495277683673, 8.863074939554382, 7.935447970045175, 6.925522856990012, 5.944761182834671, 4.877096226977508, 3.8464626638393096, 2.892177665512161, 1.9454300715258084, 1.0368366628686507, 2.03347766599905, 2.980123223512808, 3.9084886898426277, 4.887275424141468, 5.846559937900725, 6.865558415722361, 7.806249480352796, 8.78619226991845, 9.781531604147128, 10.168058243012753, 9.104322130554895, 8.111950199044813, 7.162206449876034, 6.171429329758114, 5.10651123941511, 4.088841228372705, 3.08743073661837, 3.823675275789956, 2.955282625095503, 2.0929705717802722, 3.089930553241164, 4.00313871708059, 4.96237459487504, 5.889263716554502, 6.777931573375668, 7.849099424501509, 8.791825577328435, 9.8115261529238, 10.735750399653877, 10.981457052748102, 9.97346429454043, 9.010917713505485, 8.056292946870133, 7.05478325258523, 6.020418865632651, 5.001121969514809, 3.983556162027056, 4.889990326423523, 3.9914810585804092, 3.061456211214456, 3.995567975636834, 4.974765547433142, 5.912602487558164, 6.882736675026594, 7.772702856375413, 8.78811670613954, 9.803894860471923, 10.736696738132162, 11.760236457535742, 11.789903753125733, 10.835694321799073, 9.789693208747819, 8.827445533687628, 7.776603924841602, 6.800496794718495, 5.8660785398854, 4.868232205995956, 5.942363007664411, 5.041732408345771, 4.04661484591515, 4.928166584408823, 5.93301041756411, 6.869927647011, 7.828004883448773, 8.769870325339276, 9.719105429354451, 10.659877436292696, 11.704590760414192, 12.632435709831832, 12.737217881678896, 11.699460649118993, 10.74527348177652, 9.716381341661734, 8.723362297833688, 7.745543138961552, 6.806097709924033, 5.781620670475816, 6.921919389750857, 6.029345147146102, 5.076888499792091, 5.999660219633121, 6.902745402555212, 7.809377489825401, 8.76675606590408, 9.795713823034562, 10.746622284649987, 11.589837417185834, 12.633866289415899, 13.604104452846798, 13.544741614403017, 12.58769634006444, 11.651899152480365, 10.694201491873727, 9.654583608826005, 8.677414788838979, 7.732743895447917, 6.804314331337597, 7.902185783627974, 7.101654631487202, 6.147781925323651, 6.958324168133196, 7.91935452714763, 8.807224009389087, 9.767856016571592, 10.716865418323131, 11.722332317001017, 12.613946704285018, 13.6651106445588, 14.58447958570586, 14.59501732380896, 13.632624554920522, 12.618372132883712, 11.627249723869342, 10.66887158823965, 9.692038287009812, 8.695176028070843, 7.8345326034245, 8.842986325930879, 8.049045007079567, 7.081088887723846, 7.931334237123436, 8.925322854758303, 9.860914990696957, 10.782340842559302, 11.713801537169168, 12.714644343368748, 13.664765472540376, 14.611654226272247, 15.551995138262493, 15.605642068003775, 14.623203996013618, 13.613134255509099, 12.586104256371678, 11.680727096229147, 10.68940184858926, 9.758539253382978, 8.872925948319732, 9.915558334944993, 9.066548100072996, 8.01089036112861, 8.948500580955798, 9.906635983733446, 10.913484853341865, 11.714316978664357, 12.70355152873792, 13.7747243713263, 14.70287555380533, 15.563468557400816, 16.52105934237228, 16.244039892489972, 15.445038579087976, 14.505761976354123, 13.560382897584347, 12.63098929926202, 11.701352988780714, 10.805153754719221, 9.870479326153356, 10.8928330311226, 9.899307852602382, 8.96215453935814, 9.943492480832457, 10.90715707310869, 11.865529291987388, 12.73531320922857, 13.643333047610009, 14.580374320858944, 15.516140904266914, 16.552300003663376, 16.27098590386513, 15.28337708658485, 14.419023288938936, 13.514369207744787, 12.653204780678724, 11.902684488291056, 11.01342034279343, 11.563777862053689, 10.61066607444101, 11.828874115215665, 10.846698360539715, 10.005120305247267, 11.004671960755493, 11.924675895338966, 12.803085024753223, 13.794542891575285, 14.607414631277011, 15.507953295462189, 16.472952022809753, 16.422243340266935, 15.378883360417621, 14.354674115290706, 13.420151210034437, 12.53125730795712, 11.679213150728025, 10.866366166682377, 9.97705421399343, 10.741378847148862, 11.56235172197786], [11.656940588425616, 10.668976627641788, 9.948379326851088, 9.040280207317537, 9.669442240707383, 10.604047973356836, 11.47919997108675, 12.445201462758655, 13.464430953007259, 14.403145705658972, 15.331885180182919, 15.543107675276081, 14.546605827047044, 13.748323375839693, 12.826116703730902, 11.938625942333784, 11.084922914043108, 11.851171456346666, 12.697884193469857, 13.651979826763295, 10.654477261278334, 9.724420818091874, 8.912073506191108, 8.072610163769065, 8.740288027200783, 9.663848647102908, 10.52442359619969, 11.552812247362175, 12.567649759776936, 13.572483556216255, 14.572631315485957, 15.565270778236624, 15.538928390945225, 14.682358583060893, 13.834372863762228, 12.903382565732398, 12.0449706897655, 12.831623880052575, 13.596731326114297, 12.699797456162017, 9.791983855815955, 8.791389224620604, 7.860406576142223, 7.052155416800389, 7.794634801638585, 8.698027073400404, 9.56213158857664, 10.606242732896794, 11.565060969456685, 12.605748521654426, 13.645397481866057, 14.630734455062685, 15.539641827589735, 15.720786030941989, 14.808802481550103, 13.933809336301161, 13.016020236529325, 13.577748290221505, 12.638235833039339, 11.740529670754936, 8.879390754821515, 7.833634873726417, 6.92319521220901, 6.0415834314241215, 6.776011002046776, 7.720384470368155, 8.622196543382492, 9.651830115406808, 10.635638086089703, 11.621766387426632, 12.57914745880801, 13.579506664959883, 14.554075644670972, 15.529815149601422, 15.712396725222524, 14.79261923448691, 13.739934248336889, 12.725701241867396, 11.709751749963036, 10.76978588953498, 7.89038758641328, 6.841188859078009, 5.945422422842662, 5.0029007247861, 5.7903776103695686, 6.717560172695848, 7.647238062269366, 8.686077347088577, 9.639932975217539, 10.613402517743287, 11.640676511622914, 12.643959705111568, 13.610476437336379, 14.551210298918845, 14.663022528231522, 13.811802509615474, 12.783784735310162, 11.79395767673222, 10.762725520144702, 9.81851246999241, 6.852085613679899, 5.8340105827602216, 4.952372311702323, 4.053418947784321, 4.812830178795725, 5.762384385703653, 6.730191115813297, 7.739338680530513, 8.726907337308479, 9.695013415890154, 10.698888419330073, 11.643083498261891, 12.654457720454207, 13.639055256692696, 13.642618369518482, 12.761978034254714, 11.742382282465888, 10.757943237885987, 9.761595896591938, 8.76095573335948, 5.8099712287024685, 4.870014369093664, 3.935053577186104, 3.045131340585497, 3.846890703007615, 4.795138060712054, 5.777051380304796, 6.730213848949064, 7.6846287752758675, 8.708839947403392, 9.780503762399277, 10.746900644480212, 11.761273714132193, 12.722562728698579, 12.664038010635684, 11.691465860609908, 10.667804110453043, 9.724977770078187, 8.720308272157967, 7.791242443633434, 4.910277589632209, 3.8729341906964563, 2.9096014823928265, 2.0361713874632916, 2.81366453997203, 3.7534008013828277, 4.792873252511571, 5.773400896082172, 6.731684964518242, 7.791908704983835, 8.801658868785655, 9.777855625003275, 10.776010349288121, 11.696323199545468, 11.690469344667848, 10.699086825833481, 9.751666906514613, 8.767381315959337, 7.8121354909137155, 6.80258952484842, 3.977858977239812, 2.9215534102006173, 1.94153868551437, 1.0467425385506595, 1.887840881556103, 2.870094489647827, 3.8645155229824466, 4.800039427817877, 5.780308095385562, 6.803656524082821, 7.821570340916946, 8.8259660170146, 9.805539162656522, 10.732039941178957, 10.69597736024338, 9.768527474189796, 8.834513662775544, 7.86891739670349, 6.823726954241527, 5.83454879704971, 3.050774085240874, 1.9946980953771227, 0.9940761937234844, 0.0, 0.9428693306722599, 1.924140339250628, 2.8604294630601967, 3.8915309118662824, 4.880757353297641, 5.81059518851885, 6.876304733241822, 7.822294922657391, 8.829637801464042, 9.899635514665448, 9.857151133277867, 8.92952416376866, 7.919599050713497, 6.938837376558155, 5.871172420700992, 4.840538857562794, 3.8862538592356457, 2.939506265249293, 2.0309128565921353, 1.0394014722755656, 1.9860470297893236, 2.9144124961191427, 3.8931992304179843, 4.852483744177241, 5.8714822219988765, 6.812173286629311, 7.792116076194965, 8.787455410423645, 9.779976265180446, 10.098398324278378, 9.106026392768296, 8.156282643599518, 7.165505523481598, 6.100587433138594, 5.082917422096189, 4.081506930341854, 4.817751469513441, 3.949358818818988, 3.0870467655037572, 2.0958543595176797, 3.0090625233571062, 3.968298401151555, 4.8951875228310175, 5.783855379652184, 6.855023230778025, 7.79774938360495, 8.817449959200315, 9.741674205930394, 10.773066416100251, 10.967540488263914, 10.00499390722897, 9.050369140593618, 8.048859446308715, 7.014495059356135, 5.995198163238293, 4.97763235575054, 5.884066520147008, 4.985557252303894, 4.002902429920307, 3.0687906654979287, 3.9806893537096584, 4.918526293834679, 5.888660481303109, 6.778626662651929, 7.794040512416055, 8.809818666748438, 9.742620544408677, 10.766160263812258, 11.698284539442804, 11.829770515522558, 10.783769402471304, 9.821521727411113, 8.770680118565087, 7.794572988441979, 6.860154733608884, 5.86230839971944, 6.936439201387896, 6.035808602069256, 4.988061064621001, 4.001389274269918, 4.991419546074523, 5.875851453287515, 6.833928689725288, 7.775794131615793, 8.725029235630968, 9.665801242569213, 10.710514566690707, 11.638359516108347, 12.645598667995968, 12.693536842842478, 11.739349675500005, 10.71045753538522, 9.717438491557173, 8.739619332685036, 7.800173903647517, 6.7756968641993005, 7.915995583474342, 7.023421340869587, 6.018334718497941, 5.072882909494217, 5.961154531065625, 6.815301296101916, 7.7726798721805945, 8.80163762931108, 9.752546090926504, 10.59576122346235, 11.639790095692414, 12.610028259123313, 13.568973731916545, 13.581772533787925, 12.64597534620385, 11.688277685597212, 10.64865980254949, 9.671490982562464, 8.726820089171401, 7.798390525061081, 8.89626197735146, 8.06480173047072, 7.002787690258321, 6.031546857994292, 6.977763655658043, 7.813147815665602, 8.773779822848107, 9.722789224599646, 10.728256123277534, 11.619870510561535, 12.671034450835316, 13.590403391982376, 14.619249441322488, 14.626700748644007, 13.612448326607197, 12.621325917592827, 11.662947781963135, 10.686114480733297, 9.689252221794327, 8.828608797147984, 9.837062519654364, 8.904050772014237, 7.936094652658516, 7.004556926984532, 7.9985455446193985, 8.866838796973472, 9.788264648835817, 10.719725343445685, 11.720568149645265, 12.670689278816893, 13.617578032548764, 14.557918944539008, 15.532263675981307, 15.41752811040319, 14.48430356391599, 13.580180450095163, 12.67480328995263, 11.683478042312743, 10.75261544710646, 9.867002142043216, 10.909634528668478, 9.921553865007667, 8.86589612606328, 8.021723270816894, 8.979858673594542, 9.91940865961838, 10.720240784940872, 11.709475335014437, 12.780648177602817, 13.708799360081846, 14.569392363677332, 15.526983148648794, 15.261909218769667, 14.462907905367672, 13.54309589521425, 12.604255688103892, 12.057616446431096, 12.695429182504197, 11.799229948442706, 10.864555519876841, 11.777304777024712, 10.754313617537052, 9.81716030429281, 9.016715170693553, 9.980379762969786, 10.871453098263903, 11.741237015505085, 12.649256853886525, 13.58629812713546, 14.52206471054343, 15.558223809939891, 15.288855230144828, 14.301246412864543, 13.436892615218632, 12.532238534024485, 11.671074106958418, 11.116951529330423, 12.007496536516914, 12.557854055777172, 11.604742268164493, 12.713345861117778, 11.701704125474386, 10.860126070181938, 10.077894650616589, 10.997898585200062, 11.809008831029738, 12.8004666978518, 13.613338437553528, 14.513877101738705, 15.47887582908627, 15.440112666546632, 14.396752686697319, 13.372543441570402, 12.438020536314133, 11.549126634236817, 10.697082477007719, 10.080633207721744, 10.971130407716915, 11.735455040872345, 12.556427915701343], [12.582882517280611, 11.594918556496783, 10.725635876417655, 9.666090291632957, 8.726572910035122, 9.661178642684575, 10.53633064041449, 11.502332132086396, 12.521561622335, 13.460276374986712, 14.38901584951066, 14.600238344603822, 13.603736496374784, 12.805454045167433, 11.883247373058643, 11.073442696622346, 11.997236933804203, 12.76348547610776, 13.610198213230952, 14.56429384652439, 11.580419190133329, 10.650362746946868, 9.720146718532487, 8.779800908270412, 7.797418696528523, 8.720979316430647, 9.58155426552743, 10.609942916689915, 11.624780429104677, 12.629614225543996, 13.629761984813697, 14.622401447564364, 14.596059060272966, 13.739489252388633, 12.891503533089969, 12.03819932002096, 12.957284709526594, 13.74393789981367, 14.539600656786558, 13.642666786834278, 10.71792578467095, 9.717331153475598, 8.751906244468941, 7.7728648614704055, 6.851765470966324, 7.755157742728143, 8.619262257904381, 9.663373402224535, 10.622191638784425, 11.662879190982167, 12.702528151193798, 13.687865124390424, 14.596772496917474, 14.77791670026973, 13.865933150877844, 13.068626090589722, 13.92833425629042, 14.520617620893766, 13.5811051637116, 12.683399001427198, 9.80533268367651, 8.759576802581412, 7.814694880535728, 6.762292876094138, 5.833141671374515, 6.777515139695895, 7.679327212710231, 8.708960784734547, 9.692768755417442, 10.678897056754371, 11.63627812813575, 12.636637334287622, 13.61120631399871, 14.586945818929161, 14.900974022651997, 14.018314952401656, 14.682803579009152, 13.66857057253966, 12.652621080635297, 11.71265522020724, 8.816329515268274, 7.767130787933004, 6.841722850883006, 5.778203413396654, 4.847508279697308, 5.774690842023587, 6.704368731597106, 7.743208016416316, 8.697063644545278, 9.670533187071026, 10.697807180950653, 11.701090374439307, 12.667607106664118, 13.608340968246583, 14.602934234600134, 14.754671840287736, 13.726654065982423, 12.736827007404482, 11.705594850816963, 10.76138180066467, 7.778027542534894, 6.759952511615217, 5.877820064227956, 4.875302343289523, 3.8699608481234646, 4.819515055031394, 5.787321785141038, 6.796469349858253, 7.784038006636218, 8.752144085217893, 9.756019088657812, 10.70021416758963, 11.711588389781946, 12.696185926020435, 13.67254603732992, 13.704847364926977, 12.68525161313815, 11.700812568558248, 10.7044652272642, 9.703825064031742, 6.735913157557464, 5.79595629794866, 4.8609955060411, 3.867014736090699, 2.904021372335355, 3.8522687300397944, 4.8341820496325365, 5.787344518276804, 6.741759444603607, 7.765970616731132, 8.837634431727016, 9.80403131380795, 10.818404383459933, 11.77969339802632, 12.711001918210775, 12.634335191282169, 11.610673441125304, 10.667847100750448, 9.663177602830228, 8.734111774305696, 5.836219518487205, 4.798876119551451, 3.835543411247822, 2.8687424924894875, 1.8707952092997702, 2.810531470710568, 3.850003921839311, 4.8305315654099115, 5.7888156338459815, 6.849039374311575, 7.858789538113395, 8.834986294331015, 9.833141018615862, 10.753453868873208, 11.738403249940747, 11.64195615650574, 10.694536237186872, 9.710250646631597, 8.755004821585976, 7.74545885552068, 4.903800906094808, 3.8474953390556133, 2.8674806143693656, 1.9006296871433976, 0.9449715508838432, 1.9272251589755673, 2.9216461923101864, 3.8571700971456164, 4.837438764713301, 5.86078719341056, 6.878701010244685, 7.883096686342341, 8.862669831984263, 9.789170610506698, 10.743911265516278, 10.711396804862057, 9.777382993447805, 8.81178672737575, 7.7665962849137875, 6.77741812772197, 3.9936434159131338, 2.9375674260493825, 1.9369455243957443, 0.9428693306722599, 0.0, 0.9812710085783681, 1.917560132387937, 2.948661581194023, 3.9378880226253816, 4.86772585784659, 5.933435402569563, 6.8794255919851315, 7.8867684707917824, 8.956766183993189, 9.958186522122482, 9.872393494440919, 8.862468381385757, 7.881706707230415, 6.814041751373252, 5.783408188235054, 4.8291231899079055, 3.8823755959215527, 2.973782187264395, 1.9822708029478253, 1.0431776991170636, 1.971543165446883, 2.950329899745724, 3.909614413504981, 4.928612891326616, 5.869303955957052, 6.849246745522706, 7.8445860797513856, 8.837106934508187, 9.891554593002127, 10.048895723440559, 9.099151974271779, 8.108374854153858, 7.0434567638108545, 6.025786752768449, 5.0243762610141145, 5.7606208001857, 4.892228149491247, 4.0299160961760165, 3.038723690189939, 2.066193192684846, 3.025429070479295, 3.9523181921587573, 4.840986048979924, 5.912153900105765, 6.854880052932691, 7.874580628528057, 8.798804875258135, 9.830197085427992, 10.838189843635664, 10.930935836083966, 9.976311069448615, 8.974801375163711, 7.940436988211132, 6.92114009209329, 5.903574284605536, 6.826935850819267, 5.9284265829761535, 4.945771760592566, 4.011659996170188, 3.037820023037398, 3.975656963162419, 4.945791150630849, 5.835757331979669, 6.851171181743796, 7.8669493360761775, 8.799751213736416, 9.82329093314, 10.755415208770545, 11.709624640097205, 11.7097113313263, 10.74746365626611, 9.696622047420083, 8.720514917296976, 7.786096662463881, 6.788250328574437, 7.879308532060155, 6.978677932741515, 5.93093039529326, 4.944258604942178, 4.048550215402263, 4.932982122615255, 5.891059359053028, 6.832924800943533, 7.782159904958709, 8.722931911896953, 9.767645236018446, 10.695490185436086, 11.702729337323708, 12.64286461569306, 12.665291604355001, 11.636399464240217, 10.64338042041217, 9.665561261540033, 8.726115832502511, 7.701638793054296, 8.858864914146602, 7.966290671541846, 6.961204049170201, 5.985196929255312, 5.018285200393365, 5.872431965429656, 6.829810541508334, 7.858768298638818, 8.809676760254245, 9.652891892790091, 10.696920765020153, 11.667158928451052, 12.626104401244284, 13.583149675582861, 13.571917275058846, 12.614219614452209, 11.574601731404487, 10.59743291141746, 9.652762018026396, 8.724332453916077, 9.839131308023719, 8.977115750231814, 7.9151017100194165, 6.943860877755387, 6.034894324985783, 6.870278484993341, 7.830910492175848, 8.779919893927387, 9.785386792605275, 10.677001179889276, 11.728165120163057, 12.647534061310115, 13.676380110650225, 14.628077890438943, 14.538390255462193, 13.547267846447824, 12.588889710818131, 11.612056409588293, 10.615194150649321, 9.754550726002979, 10.779931850326623, 9.816364791775332, 8.84840867241961, 7.916870946745627, 7.0723251437418275, 7.923969466301212, 8.845395318163558, 9.776856012773425, 10.777698818973006, 11.727819948144633, 12.674708701876504, 13.615049613866747, 14.589394345309046, 14.47465877973093, 13.541434233243729, 12.711827057294109, 13.59006664999538, 12.609419971167739, 11.678557375961457, 10.792944070898212, 11.852503859340738, 10.833867884768761, 9.778210145824374, 8.934037290577988, 8.114675427883103, 8.97653932894612, 9.777371454268613, 10.766606004342178, 11.837778846930558, 12.765930029409587, 13.626523033005073, 14.584113817976533, 14.319039888097407, 13.520038574695413, 12.60022656454199, 11.661386357431633, 12.59077995575396, 13.520416266235266, 12.7251718772977, 11.790497448731836, 12.689618796785807, 11.666627637298147, 10.729474324053905, 9.929029190454647, 9.115196517258347, 9.928583767591643, 10.798367684832826, 11.706387523214266, 12.643428796463201, 13.579195379871171, 14.615354479267632, 14.345985899472568, 13.358377082192284, 12.494023284546373, 11.589369203352224, 10.728204776286159, 11.689384382346484, 12.652869923384188, 13.483795984632167, 12.530684197019488, 13.625659880878873, 12.61401814523548, 11.772440089943032, 10.990208670377683, 10.132715339488623, 10.866139500357479, 11.85759736717954, 12.670469106881269, 13.571007771066446, 14.536006498414011, 14.497243335874373, 13.45388335602506, 12.429674110898143, 11.495151205641873, 10.606257303564556, 9.75421314633546, 10.706443292037164, 11.686750884546207, 12.66139696972734, 13.482369844556338], [13.564153525858979, 12.57618956507515, 11.706906884996025, 10.647361300211326, 9.707843918613491, 8.923629715957029, 9.752761057181193, 10.718762548853098, 11.706608201324883, 12.645322953976596, 13.574062428500543, 13.662904262181831, 12.666402413952794, 11.886283526197134, 10.97957398792244, 11.93692832333204, 12.950294481327639, 13.716543023631198, 14.563255760754389, 15.517351394047827, 12.561690198711696, 11.631633755525236, 10.701417727110854, 9.76107191684878, 8.778689705106892, 7.983430389703099, 8.797984682294132, 9.826373333456617, 10.766844251978316, 11.771678048417636, 12.771825807687337, 13.652974007842872, 13.658724977850975, 12.820318733418334, 11.987830147953765, 12.901684946730654, 13.91034225705003, 14.696995447337107, 15.520871665364925, 14.623937795412646, 11.699196793249317, 10.698602162053966, 9.73317725304731, 8.754135870048774, 7.833036479544694, 7.017608816000595, 7.835692674671082, 8.879803818991236, 9.744666866422616, 10.772844328147237, 11.751527445316645, 12.706594115812058, 13.615501488339108, 13.85874618129943, 12.96225976574164, 13.932111717299417, 14.881391803813855, 15.501888629472134, 14.562376172289968, 13.664670010005565, 10.786603692254877, 9.74084781115978, 8.795965889114097, 7.743563884672508, 6.814412679952884, 6.039966212968348, 6.8957576294769325, 7.914104818226861, 8.769441245670489, 9.727896350877218, 10.685277422258597, 11.655366325709256, 12.629935305420345, 13.605674810350795, 13.997300637515794, 14.881800579111351, 15.66407458758752, 14.649841581118027, 13.633892089213665, 12.693926228785609, 9.797600523846642, 8.748401796511372, 7.822993859461375, 6.759474421975023, 5.828779288275677, 5.03714191529604, 5.920799148363807, 6.874883944269158, 7.740935453039665, 8.714404995565413, 9.716536172372287, 10.71981936586094, 11.686336098085752, 12.627069959668217, 13.621663226021768, 14.585500085297994, 14.70792507456079, 13.71809801598285, 12.686865859395331, 11.742652809243038, 8.759298551113261, 7.741223520193585, 6.859091072806324, 5.85657335186789, 4.851231856701833, 4.023796012132724, 4.9590837979855795, 5.815198341279884, 6.80276699805785, 7.770873076639526, 8.774748080079446, 9.718943159011264, 10.73031738120358, 11.71491491744207, 12.691275028751553, 13.634433075026442, 13.666522621716517, 12.682083577136616, 11.685736235842567, 10.68509607261011, 7.717184166135832, 6.777227306527028, 5.842266514619467, 4.848285744669067, 3.8852923809137234, 3.0565496871411244, 3.982295142156255, 4.806073509698435, 5.7604884360252395, 6.784699608152764, 7.856363423148649, 8.822760305229584, 9.837133374881564, 10.798422389447952, 11.729730909632407, 12.737976409440606, 12.591944449703671, 11.649118109328816, 10.644448611408595, 9.715382782884063, 6.817490527065573, 5.780147128129819, 4.81681441982619, 3.850013501067856, 2.8520662178781384, 2.014812427811898, 2.920375307324245, 3.8492605568315432, 4.807544625267614, 5.867768365733207, 6.877518529535028, 7.853715285752647, 8.851870010037493, 9.77218286029484, 10.75713224136238, 11.66789403351956, 11.675807245765242, 10.691521655209966, 9.736275830164345, 8.726729864099049, 5.885071914673175, 4.828766347633981, 3.8487516229477334, 2.881900695721766, 1.9262425594622115, 0.9782415990478577, 1.9403751837318186, 2.8758990885672486, 3.856167756134934, 4.879516184832193, 5.897430001666318, 6.9018256777639735, 7.8813988234058945, 8.80789960192833, 9.76264025693791, 10.690090142991494, 10.758654002026175, 9.79305773595412, 8.747867293492156, 7.7586891363003385, 4.974914424491502, 3.9188384346277507, 2.9182165329741125, 1.924140339250628, 0.9812710085783681, 0.0, 0.9362891238095689, 1.9673905726156549, 2.956617014047013, 3.8864548492682216, 4.952164393991194, 5.898154583406763, 6.905497462213414, 7.975495175414819, 8.97691551354411, 9.904542483053318, 9.843739389964126, 8.862977715808784, 7.795312759951621, 6.764679196813423, 5.810394198486274, 4.863646604499921, 3.9550531958427633, 2.9635418115261936, 1.9962352466404993, 1.06786978031068, 1.9690588911673563, 2.928343404926613, 3.9473418827482485, 4.888032947378683, 5.867975736944336, 6.863315071173016, 7.855835925929817, 8.910283584423757, 9.902655515933839, 10.080422982850147, 9.089645862732226, 8.024727772389223, 7.007057761346817, 6.005647269592482, 6.741891808764069, 5.873499158069616, 5.011187104754385, 4.019994698768308, 3.0192507402082818, 2.1217556853430923, 2.9710471835803896, 3.8597150404015563, 4.930882891527397, 5.873609044354322, 6.8933096199496875, 7.817533866679765, 8.848926076849622, 9.856918835057295, 10.819465416092239, 10.957582078026983, 9.956072383742079, 8.9217079967895, 7.9024111006716575, 6.884845293183904, 7.808206859397636, 6.909697591554522, 5.927042769170935, 4.992931004748557, 3.990877570560834, 3.0719835780262166, 4.0223896685028055, 4.854486323401301, 5.869900173165428, 6.88567832749781, 7.818480205158048, 8.84201992456163, 9.774144200192175, 10.728353631518836, 11.77435474457009, 11.728734664844477, 10.677893055998451, 9.701785925875344, 8.76736767104225, 7.7695213371528045, 8.860579540638524, 7.959948941319884, 6.912201403871629, 5.9255296135205455, 5.0016077629256985, 4.029308737479052, 4.967657876924984, 5.851653792365165, 6.800888896380341, 7.741660903318585, 8.786374227440078, 9.714219176857718, 10.721458328745339, 11.66159360711469, 12.615780774457164, 12.617670472818585, 11.624651428990537, 10.6468322701184, 9.707386841080881, 8.682909801632665, 9.84013592272497, 8.947561680120215, 7.942475057748569, 6.938254476778748, 5.9713427479168, 4.9687585802934535, 5.910640022538035, 6.87749729006045, 7.828405751675878, 8.671620884211723, 9.715649756441785, 10.685887919872684, 11.644833392665916, 12.601878667004494, 13.537675854588569, 13.595490623030576, 12.555872739982854, 11.578703919995828, 10.634033026604765, 9.705603462494444, 10.820402316602086, 9.930173297755251, 8.868159257542853, 7.896918425278823, 6.936450968007585, 5.966605099857139, 6.911739973205549, 7.842585811505397, 8.804115784026909, 9.695730171310908, 10.74689411158469, 11.666263052731747, 12.695109102071857, 13.646806881860575, 13.816481197726942, 14.528538855026191, 13.5701607193965, 12.59332741816666, 11.59646515922769, 10.735821734581346, 11.733854314210985, 10.76942233929877, 9.801466219943048, 8.869928494269063, 7.97388178676363, 7.020296081165009, 7.926224799193258, 8.839521930351435, 9.79642781039464, 10.746548939566265, 11.693437693298137, 12.633778605288379, 13.608123336730678, 13.691089196497632, 12.803885306516182, 13.693098065872476, 14.571337658573748, 13.590690979746107, 12.659828384539825, 11.77421507947658, 12.8064263232251, 11.786925432292197, 10.731267693347812, 9.887094838101424, 9.016232070904906, 8.072865943809918, 8.858200935298314, 9.829271921920187, 10.864656774682969, 11.792807957161997, 12.645252024426705, 13.602842809398165, 13.53547030486411, 12.736468991462115, 11.862677637814443, 12.64265736601, 13.572050964332329, 14.501687274813634, 13.706442885876069, 12.771768457310204, 13.642676344309244, 12.619685184821584, 11.682531871577343, 10.882086737978083, 10.01675316028015, 9.02491038245544, 9.879197165862527, 10.769053440792275, 11.70609471404121, 12.64186129744918, 13.634083470689264, 13.56241631623927, 12.574807498958986, 11.710453701313075, 10.851820276624677, 11.709475784864527, 12.670655390924852, 13.634140931962555, 14.465066993210534, 13.511955205597856, 14.57871742840231, 13.567075692758918, 12.72549763746647, 11.943266217901119, 10.996200966198318, 9.962466115221275, 10.938426848209241, 11.733135024459278, 12.633673688644455, 13.59867241599202, 13.682289914864256, 12.638929935014943, 11.646104527664844, 10.711581622408575, 9.86870837683701, 10.735484154913827, 11.687714300615534, 12.668021893124576, 13.642667978305708, 14.463640853134706], [14.50044264966855, 13.512478688884721, 12.643196008805594, 11.583650424020895, 10.64413304242306, 9.797547231088975, 8.816471933371622, 9.782473425043527, 10.770319077515314, 11.709033830167026, 12.637773304690974, 12.726615138372262, 11.730113290143224, 10.949994402387565, 11.840524824794741, 12.797879160204342, 13.849292614891429, 14.652832147440765, 15.499544884563957, 16.453640517857394, 13.497979322521267, 12.567922879334807, 11.637706850920424, 10.697361040658349, 9.714978828916461, 8.859322629765586, 7.861695558484562, 8.890084209647048, 9.830555128168747, 10.835388924608067, 11.835536683877768, 12.716684884033302, 12.722435854041406, 11.884029609608765, 12.834675744241856, 13.762635783602956, 14.802572251774194, 15.633284571146675, 16.45716078917449, 15.560226919222213, 12.635485917058888, 11.634891285863537, 10.66946637685688, 9.690424993858343, 8.769325603354263, 7.893501056063082, 6.899403550861513, 7.943514695181666, 8.808377742613047, 9.836555204337667, 10.815238321507076, 11.770304992002488, 12.679212364529539, 12.922457057489861, 13.809105362029731, 14.79306255417172, 15.77362179853802, 16.438177753281703, 15.498665296099535, 14.600959133815133, 11.722892816064448, 10.67713693496935, 9.732255012923666, 8.679853008482077, 7.750701803762453, 6.915858453030834, 5.959468505667363, 6.977815694417292, 7.833152121860919, 8.791607227067649, 9.748988298449028, 10.719077201899687, 11.693646181610776, 12.669385686541226, 13.641889114703561, 14.612550120563874, 15.665235106713896, 15.586130704927593, 14.570181213023233, 13.630215352595176, 10.733889647656213, 9.684690920320943, 8.759282983270944, 7.695763545784592, 6.765068412085246, 5.914187914127757, 4.984510024554238, 5.938594820459588, 6.804646329230096, 7.778115871755844, 8.780247048562718, 9.783530242051372, 10.750046974276183, 11.690780835858648, 12.685374102212199, 13.649210961488425, 14.681004838674978, 14.654387139792416, 13.623154983204898, 12.678941933052606, 9.695587674922832, 8.677512644003155, 7.795380196615893, 6.79286247567746, 5.7875209805114025, 4.9600851359422915, 4.02279467417601, 4.878909217470316, 5.866477874248281, 6.834583952829957, 7.838458956269877, 8.782654035201695, 9.794028257394011, 10.7786257936325, 11.754985904941984, 12.698143951216872, 13.720316284345172, 13.618372700946184, 12.622025359652135, 11.621385196419677, 8.653473289945401, 7.713516430336597, 6.778555638429037, 5.784574868478636, 4.821581504723293, 3.9928388109506927, 3.0460060183466857, 3.8697843858888668, 4.82419931221567, 5.848410484343195, 6.92007429933908, 7.886471181420014, 8.900844251071995, 9.86213326563838, 10.793441785822836, 11.801687285631036, 12.645738112332326, 12.585407233138383, 11.580737735218163, 10.65167190669363, 7.753779650875142, 6.716436251939388, 5.753103543635759, 4.7863026248774245, 3.788355341687707, 2.9511015516214663, 1.984086183514676, 2.9129714330219745, 3.8712555014580445, 4.931479241923638, 5.941229405725458, 6.9174261619430775, 7.915580886227924, 8.83589373648527, 9.82084311755281, 10.73160490970999, 11.679024829028858, 11.627810779019532, 10.672564953973911, 9.663018987908616, 6.8213610384827446, 5.76505547144355, 4.785040746757303, 3.8181898195313346, 2.86253168327178, 1.9145307228574264, 1.0040860599222496, 1.9396099647576797, 2.9198786323253647, 3.943227061022623, 4.961140877856748, 5.965536553954404, 6.945109699596325, 7.87161047811876, 8.826351133128341, 9.753801019181925, 10.687814830596176, 10.72934685976369, 9.684156417301725, 8.694978260109906, 5.911203548301071, 4.855127558437319, 3.8545056567836813, 2.8604294630601967, 1.917560132387937, 0.9362891238095689, 0.0, 1.031101448806086, 2.020327890237444, 2.950165725458653, 4.015875270181626, 4.9618654595971945, 5.9692083384038455, 7.039206051605251, 8.040626389734543, 8.96825335924375, 9.978178472298913, 9.799266839618353, 8.73160188376119, 7.700968320622991, 6.7466833222958424, 5.79993572830949, 4.891342319652332, 3.8998309353357623, 2.932524370450068, 2.0041589041202488, 1.0327697673577874, 1.9920542811170443, 3.01105275893868, 3.951743823569114, 4.931686613134767, 5.927025947363449, 6.91954680212025, 7.973994460614188, 8.96636639212427, 9.91611014129305, 10.025934986541795, 8.961016896198792, 7.943346885156386, 6.9419363934020515, 7.678180932573637, 6.809788281879184, 5.9474762285639535, 4.956283822577876, 3.9555398640178505, 3.050357438425704, 2.034758059770821, 2.9234259165919876, 3.9945937677178285, 4.937319920544753, 5.957020496140118, 6.881244742870198, 7.912636953040055, 8.920629711247727, 9.883176292282672, 10.837801058918023, 10.892361507551646, 9.857997120599068, 8.838700224481226, 7.821134416993473, 8.744495983207205, 7.8459867153640905, 6.863331892980503, 5.929220128558125, 4.927166694370403, 4.000585331108828, 3.0861005446932372, 3.918197199591732, 4.933611049355859, 5.9493892036882405, 6.882191081348479, 7.905730800752062, 8.837855076382608, 9.792064507709268, 10.838065620760522, 11.793495222954784, 11.61418217980802, 10.638075049684913, 9.703656794851819, 8.705810460962374, 9.796868664448093, 8.896238065129452, 7.848490527681197, 6.861818737330115, 5.937896886735267, 4.957910490561664, 4.031368753115416, 4.915364668555596, 5.864599772570772, 6.805371779509016, 7.850085103630508, 8.777930053048147, 9.785169204935771, 10.725304483305123, 11.679491650647597, 12.718577280142934, 12.560940552800107, 11.58312139392797, 10.64367596489045, 9.619198925442234, 10.77642504653454, 9.883850803929782, 8.878764181558138, 7.874543600588316, 6.907631871726369, 5.897360333376065, 4.974350898728467, 5.941208166250881, 6.892116627866309, 7.735331760402153, 8.779360632632216, 9.749598796063113, 10.708544268856345, 11.665589543194923, 12.601386730778998, 13.559084391385635, 13.492161863792424, 12.514993043805397, 11.570322150414334, 10.641892586304015, 11.756691440411656, 10.866462421564819, 9.80444838135242, 8.83320754908839, 7.865052721090197, 6.895206852939751, 5.975450849395981, 6.906296687695828, 7.867826660217339, 8.759441047501337, 9.810604987775118, 10.729973928922176, 11.758819978262288, 12.710517758051004, 13.567859711182345, 14.49213262338125, 14.506449843206068, 13.52961654197623, 12.53275428303726, 11.67211085839092, 12.670143438020553, 11.705711463108337, 10.737755343752616, 9.80621761807863, 8.90248353984624, 7.948897834247621, 6.989935675383689, 7.903232806541865, 8.86013868658507, 9.810259815756694, 10.757148569488566, 11.697489481478808, 12.671834212921107, 12.754800072688061, 13.664089038498378, 14.629387189682046, 15.507626782383317, 14.526980103555676, 13.596117508349394, 12.710504203286153, 13.742715447034668, 12.723214556101766, 11.66755681715738, 10.823383961910992, 9.944833823987516, 8.983464331746829, 7.921911811488744, 8.892982798110618, 9.9283676508734, 10.856518833352428, 11.708962900617134, 12.666553685588594, 12.59918118105454, 11.800179867652544, 12.722881369796639, 13.57894648981957, 14.508340088141898, 15.437976398623203, 14.64273200968564, 13.708057581119775, 14.578965468118811, 13.555974308631152, 12.61882099538691, 11.81837586178765, 10.888711036491788, 9.885861219327742, 8.942908042052958, 9.832764316982706, 10.769805590231641, 11.705572173639611, 12.697794346879693, 12.626127192429701, 11.638518375149417, 10.774164577503504, 11.712024008606873, 12.645764908674096, 13.60694451473442, 14.570430055772125, 15.401356117020105, 14.448244329407427, 15.515006552211878, 14.503364816568485, 13.661786761276037, 12.879555341710686, 11.85715180307062, 10.823416952093577, 10.002137724399672, 10.796845900649709, 11.697384564834886, 12.66238329218245, 12.746000791054687, 11.702640811205374, 10.709815403855274, 9.775292498599004, 10.728912108819205, 11.671773278723396, 12.624003424425103, 13.604311016934146, 14.578957102115279, 15.399929976944277], [15.505148636875237, 14.517184676091409, 13.605477444934326, 12.545931860149627, 11.606414478551793, 10.683526602848918, 9.702451305131564, 9.010300598988202, 9.785250639604394, 10.723965392256106, 11.652704866780054, 11.79074197412654, 10.794240125897502, 11.804097597460679, 12.731547469231327, 13.688901804640928, 14.740315259328014, 15.606184696386917, 16.45289743351011, 17.406993066803548, 14.502685309727955, 13.572628866541494, 12.599988287049156, 11.65964247678708, 10.677260265045193, 9.745302001525529, 8.747674930244504, 7.941097400697556, 8.845486690257827, 9.850320486697147, 10.850468245966848, 11.731616446122384, 11.786562689795684, 12.738132804681879, 13.68877893931497, 14.653658428039542, 15.69359489621078, 16.586637120092828, 17.451158465040876, 16.5542245950886, 13.65019849522343, 12.649603864028078, 11.631747812985614, 10.652706429987076, 9.731607039482995, 8.779480427823025, 7.785382922621456, 6.994527886232175, 7.823309304702128, 8.85148676642675, 9.830169883596158, 10.78523655409157, 11.69414392661862, 12.626653286390905, 13.567953631103274, 14.57717054446489, 15.640627444730749, 16.554147395792985, 16.49266297196592, 15.594956809681516, 12.73760539422899, 11.691849513133892, 10.6945364490524, 9.642134444610809, 8.712983239891186, 7.801837824790777, 6.845447877427306, 5.992747256506374, 6.8480836839500006, 7.806538789156731, 8.76391986053811, 9.734008763988768, 10.708577743699857, 11.684317248630308, 12.656820676792643, 13.627481682652956, 14.680166668802977, 15.578196030026016, 15.564178888889616, 14.62421302846156, 11.748602225820754, 10.699403498485484, 9.721564419399677, 8.658044981913324, 7.727349848213978, 6.800167285887699, 5.870489396314181, 4.95352638254867, 5.819577891319177, 6.793047433844926, 7.795178610651798, 8.798461804140453, 9.764978536365264, 10.70571239794773, 11.70030566430128, 12.664142523577507, 13.69593640076406, 14.646452464890839, 14.654256432010985, 13.710043381858693, 10.726689123728919, 9.708614092809242, 8.82648164542198, 7.823963924483547, 6.818622429317489, 5.876580776045596, 4.908774045935952, 3.8938407795593974, 4.881409436337362, 5.849515514919037, 6.853390518358958, 7.797585597290777, 8.808959819483093, 9.793557355721582, 10.740920695899549, 11.684078742174437, 12.689214835539087, 13.610438026044605, 13.653126808458222, 12.652486645225764, 9.684574738751488, 8.744617879142684, 7.809657087235123, 6.815676317284723, 5.852682953529379, 4.913898709699371, 3.931985390106628, 2.8847159479779485, 3.8391308743047516, 4.863342046432276, 5.935005861428161, 6.872402066771171, 7.874512149711588, 8.831031816832295, 9.76234033701675, 10.770585836824951, 11.614636663526241, 12.557463003901097, 12.61183918402425, 11.682773355499718, 8.784881099681227, 7.747537700745475, 6.784204992441845, 5.8174040736835115, 4.819456790493794, 3.9095380064033614, 2.870065555274618, 1.9279029951110562, 2.8861870635471263, 3.905147140563232, 4.914897304365052, 5.891094060582671, 6.889248784867518, 7.804792287679184, 8.789741668746725, 9.700503460903905, 10.647923380222773, 11.632208970778048, 11.703666402779998, 10.694120436714703, 7.852462487288831, 6.796156920249636, 5.816142195563389, 4.849291268337421, 3.8936331320778663, 2.9456321716635125, 1.8900654316821917, 0.9545415268467615, 1.9348101944144467, 2.9137520615398564, 3.9316658783739813, 4.934435105148319, 5.91400825079024, 6.840509029312675, 7.795249684322256, 8.72269957037584, 9.656713381790091, 10.622309647862146, 10.715257866107812, 9.726079708915993, 6.942304997107158, 5.886229007243406, 4.885607105589767, 3.891530911866283, 2.948661581194023, 1.9673905726156549, 1.031101448806086, 0.0, 0.9892264414313583, 1.9190642766525672, 2.9847738213755397, 3.9307640107911084, 4.938106889597759, 6.008104602799165, 7.009524940928457, 7.937151910437664, 8.947077023492827, 9.92783869764817, 9.762703332567277, 8.732069769429078, 7.7777847711019295, 6.831037177115577, 5.922443768458418, 4.930932384141848, 3.963625819256154, 3.035260352926335, 2.015465630630577, 1.0561811168713198, 2.0432484724350193, 2.9206423747630286, 3.900585164328682, 4.895924498557362, 5.888445353314163, 6.942893011808102, 7.935264943318183, 8.885008692486963, 9.875785812604883, 9.99211834500488, 8.974448333962474, 7.9730378422081385, 8.709282381379724, 7.840889730685271, 6.97857767737004, 5.987385271383962, 4.986641312823936, 4.0330533016984935, 3.01745392304361, 1.987552752346263, 3.058720603472104, 3.9062184717386677, 4.925919047334033, 5.850143294064111, 6.881535504233968, 7.889528262441639, 8.852074843476585, 9.806699610111936, 10.80820930439684, 10.889098569405155, 9.869801673287313, 8.852235865799559, 9.775597432013292, 8.877088164170177, 7.8944333417865895, 6.960321577364211, 5.910600054657941, 4.947257376598252, 3.9771231891298218, 2.9823240353460077, 3.9977378851101344, 4.929618801464412, 5.86242067912465, 6.874629351945975, 7.806753627576521, 8.760963058903181, 9.806964171954435, 10.762393774148697, 11.809882650742976, 11.669176498490998, 10.734758243657904, 9.736911909768459, 10.82797011325418, 9.92733951393554, 8.879591976487283, 7.8929201861362, 6.921330247022805, 5.9045825360510875, 4.922391397552, 3.979491504309872, 4.928726608325047, 5.869498615263291, 6.830314701406679, 7.758159650824319, 8.754067756129684, 9.694203034499036, 10.64839020184151, 11.687475831336847, 12.680494875164893, 12.614222842734055, 11.674777413696537, 10.65030037424832, 11.807526495340626, 10.914952252735869, 9.901343393997841, 8.827896149534467, 7.86098442067252, 6.82275211924373, 5.8653735431650516, 5.0053350020051575, 5.956243463620584, 6.799458596156429, 7.759590230408387, 8.729828393839286, 9.688773866632518, 10.645819140971096, 11.581616328555171, 12.539313989161808, 13.57893187220953, 13.546094492611482, 12.601423599220421, 11.672994035110102, 12.765908370849731, 11.81981497051097, 10.757800930298572, 9.786560098034542, 8.790444506957861, 7.820598638807415, 6.866473493832565, 5.970423523450104, 6.931953495971614, 7.823567883255613, 8.821450266835365, 9.710203526698349, 10.739049576038461, 11.690747355827178, 12.548089308958518, 13.472362221157423, 14.479467640114578, 14.560717990782315, 13.563855731843347, 12.703212307197006, 13.623495986966704, 12.659064012054488, 11.691107892698767, 10.759570167024782, 9.827875325713906, 8.874289620115286, 7.880958319820274, 6.967359642296142, 7.924265522339345, 8.87438665151097, 9.767993848548812, 10.677719079254981, 11.65206381069728, 12.691707391915887, 13.560685200169278, 14.43121675365976, 15.44271466330871, 15.558081552361763, 14.627218957155481, 13.74160565209224, 14.696067995980819, 13.676567105047916, 12.62090936610353, 11.776736510857143, 10.870225609855181, 9.874486976183414, 8.81293445592533, 7.957109633864895, 8.992494486627674, 9.920645669106703, 10.719808179677381, 11.646783283364767, 11.827008354999215, 12.686159239412486, 13.608860741556581, 14.511063710600324, 15.440457308922651, 16.370093619403956, 15.657444587850181, 14.722770159284316, 15.532318017064963, 14.509326857577303, 13.572173544333062, 12.771728410733802, 11.779733680928373, 10.776883863764327, 9.833930686489543, 8.896891152736984, 9.83393242598592, 10.76969900939389, 11.70863962593994, 11.787279729511154, 10.866345549094092, 11.660143949263446, 12.598003380366816, 13.57788212945485, 14.539061735515174, 15.502547276552878, 16.40606210422679, 15.452950316614114, 16.46835910115803, 15.456717365514637, 14.615139310222188, 13.822982685908585, 12.748174447507205, 11.714439596530163, 10.893160368836257, 9.860972736403987, 10.761511400589164, 11.726510127936727, 11.760932353143767, 10.717572373294454, 9.937642577799949, 10.661271870358947, 11.614891480579148, 12.60389049950415, 13.586284860553835, 14.566592453062878, 15.580781387777085, 16.404635964150962], [16.4772603180664, 15.489296357282571, 14.577589126125488, 13.51804354134079, 12.578526159742955, 11.655638284040082, 10.674562986322728, 9.860205980594532, 8.847556366180882, 9.786271118832595, 10.715010593356542, 11.158784979735076, 11.783466567328858, 12.793324038892035, 13.720773910662684, 14.678128246072285, 15.729541700759372, 16.595411137818278, 17.442123874941466, 18.396219508234907, 15.474796990919117, 14.544740547732657, 13.572099968240318, 12.631754157978243, 11.649371946236355, 10.717413682716693, 9.719786611435667, 8.791002782303886, 7.907792416834316, 8.912626213273635, 9.912773972543336, 10.773141720556394, 11.72133606850271, 12.695393812223791, 13.572696326842939, 14.551422539759775, 15.591359007931013, 16.508978731047947, 17.46292890461875, 17.543451036519954, 14.622310176414594, 13.621715545219242, 12.603859494176776, 11.624818111178238, 10.703718720674157, 9.751592109014188, 8.757494603812619, 7.844433267838506, 6.885615031278616, 7.913792493003237, 8.881305988427615, 9.82676182852558, 10.72445700457041, 11.656966364342695, 12.598266709055064, 13.60748362241668, 14.670940522682539, 15.564920954361625, 16.504433411543793, 16.584183251112876, 13.709717075420153, 12.663961194325056, 11.666648130243562, 10.614246125801971, 9.685094921082348, 8.77394950598194, 7.81755955861847, 6.8749601199823305, 5.910389410526489, 6.868844515733219, 7.815055965369566, 8.775534038422778, 9.738890821651648, 10.714630326582098, 11.687133754744433, 12.657794760604746, 13.710479746754768, 14.588969588594656, 15.609167256244328, 15.613439469892919, 12.720713907011918, 11.671515179676648, 10.69367610059084, 9.630156663104488, 8.699461529405141, 7.772278967078863, 6.8426010775053445, 5.835739246024627, 4.8818836178956655, 5.855353160421414, 6.8423935522149515, 7.839987078574463, 8.795291614317055, 9.73602547589952, 10.730618742253071, 11.694455601529297, 12.72624947871585, 13.65722602345948, 14.59026151202628, 14.69926982329005, 11.715915565160277, 10.6978405342406, 9.815708086853338, 8.813190365914904, 7.807848870748846, 6.848692457236761, 5.880885727127117, 4.865952460750563, 3.9437151629138496, 4.8967304564821905, 5.900605459922111, 6.828564239394352, 7.830247822264031, 8.81484535850252, 9.75169425446819, 10.694852300743078, 11.699988394107727, 12.621211584613246, 13.589131888473517, 13.641713086657122, 10.673801180182846, 9.733844320574041, 8.79888352866648, 7.80490275871608, 6.841909394960736, 5.886010390890535, 4.904097071297793, 3.856827629169114, 2.901436600881239, 3.910556987995429, 4.982220802991314, 5.883175625339812, 6.88528570828023, 7.841805375400937, 8.773113895585391, 9.781359395393592, 10.625410222094882, 11.568236562469737, 12.547844264039545, 12.671999796931075, 9.774107541112585, 8.736764142176833, 7.773431433873203, 6.806630515114869, 5.808683231925151, 4.8816496875945266, 3.8421772364657834, 2.900014676302222, 1.9484927901236135, 2.9159206991318736, 3.9256708629336936, 4.901867619151313, 5.900022343436159, 6.815565846247826, 7.800515227315366, 8.711277019472545, 9.658696938791413, 10.642982529346689, 11.59822835439231, 11.683346878146061, 8.841688928720188, 7.785383361680994, 6.805368636994746, 5.838517709768778, 4.882859573509224, 3.9272768198604417, 2.862177112873357, 1.926653208037927, 0.9463845404702419, 1.924525620108498, 2.9424394369426228, 3.94520866371696, 4.9247818093588815, 5.851282587881316, 6.806023242890897, 7.73347312894448, 8.667486940358732, 9.633083206430786, 10.67827364889275, 10.71530615034735, 7.931531438538515, 6.875455448674764, 5.874833547021125, 4.880757353297641, 3.937888022625381, 2.956617014047013, 2.020327890237444, 0.9892264414313583, 0.0, 0.9298378352212088, 1.9955473799441812, 2.94153756935975, 3.948880448166401, 5.018878161367806, 6.020298499497098, 6.9479254690063055, 7.957850582061468, 8.93861225621681, 10.006277212073973, 9.721296210860435, 8.767011212533287, 7.820263618546934, 6.911670209889776, 5.920158825573207, 4.9528522606875125, 4.024486794357693, 3.0046920720619346, 2.045407558302678, 1.0540220310036612, 1.93141593333167, 2.9113587228973237, 3.9066980571260035, 4.899218911882804, 5.953666570376743, 6.946038501886825, 7.895782251055604, 8.886559371173524, 9.951477461516527, 9.96367477539383, 8.962264283639495, 9.698508822811082, 8.830116172116629, 7.967804118801397, 6.976611712815321, 5.975867754255296, 5.022279743129851, 4.006680364474968, 2.976779193777621, 2.1200567268943393, 2.916992030307309, 3.9366926059026746, 4.860916852632752, 5.892309062802609, 6.900301821010281, 7.862848402045225, 8.817473168680577, 9.81898286296548, 10.853347249918059, 10.859028114718669, 9.841462307230916, 10.764823873444648, 9.866314605601534, 8.883659783217947, 7.94954801879557, 6.8998264960892985, 5.936483818029609, 4.966349630561179, 3.9715504767773657, 3.077319240379725, 3.9403923600330533, 4.8731942376932915, 5.885402910514616, 6.8175271861451625, 7.771736617471822, 8.817737730523076, 9.773167332717337, 10.820656209311617, 11.796763339434724, 11.723984685089262, 10.726138351199817, 11.817196554685536, 10.916565955366895, 9.868818417918641, 8.88214662756756, 7.910556688454163, 6.893808977482445, 5.911617838983358, 4.96871794574123, 4.146739109428744, 4.943382438732102, 5.84108825997532, 6.76893320939296, 7.764841314698326, 8.704976593067677, 9.65916376041015, 10.698249389905488, 11.691268433733534, 12.741809683677781, 12.664003855127895, 11.639526815679679, 12.796752936771982, 11.904178694167225, 10.8905698354292, 9.817122590965827, 8.850210862103879, 7.811978560675088, 6.854599984596409, 5.994561443436515, 5.1742559647242805, 5.8733424196252395, 6.770363788977027, 7.7406019524079275, 8.699547425201159, 9.656592699539736, 10.592389887123812, 11.550087547730449, 12.58970543077817, 13.65008986524946, 13.590650040651779, 12.66222047654146, 13.75513481228109, 12.80904141194233, 11.747027371729931, 10.775786539465901, 9.779670948389217, 8.809825080238772, 7.855699935263923, 6.959649964881462, 6.14996599707531, 6.897451706724424, 7.832223825404005, 8.720977085266991, 9.749823134607102, 10.701520914395818, 11.558862867527159, 12.483135779726064, 13.490241198683218, 14.52869838049709, 14.553082173274705, 13.692438748628362, 14.612722428398063, 13.648290453485847, 12.680334334130126, 11.748796608456141, 10.817101767145262, 9.863516061546642, 8.870184761251632, 7.956586083727499, 7.142278023443041, 7.948270474979781, 8.778767407117451, 9.688492637823623, 10.662837369265922, 11.70248095048453, 12.571458758737919, 13.4419903122284, 14.45348822187735, 15.444813469517237, 15.61644539858684, 14.730832093523595, 15.685294437412178, 14.665793546479275, 13.61013580753489, 12.765962952288502, 11.859452051286537, 10.863713417614772, 9.802160897356687, 8.946336075296252, 8.210506987731371, 9.005525024012478, 9.73058173824602, 10.65755684193341, 11.637665675260696, 12.602349489846535, 13.512666427439658, 14.458045506209434, 15.387439104531762, 16.31707541501307, 16.629556269041345, 15.69488184047548, 16.521544458496322, 15.498553299008663, 14.561399985764421, 13.760954852165161, 12.768960122359731, 11.766110305195685, 10.8231571279209, 9.88611759416834, 9.201975431594455, 9.974965912855543, 10.719413184508578, 10.849585456087642, 11.716250930700422, 12.63225563045461, 13.57011506155798, 14.549993810646013, 15.511173416706338, 16.474658957744044, 17.378173785417953, 16.425061997805276, 17.45758554258939, 16.445943806945994, 15.604365751653548, 14.812209127339942, 13.737400888938563, 12.70366603796152, 11.882386810267615, 10.850199177835343, 10.1295544061977, 10.931777031398383, 10.823238079720255, 9.779878099870942, 10.787547959406279, 11.63338355155011, 12.587003161770312, 13.576002180695314, 14.558396541744997, 15.53870413425404, 16.552893068968245, 17.376747645342125], [17.40709815328761, 16.41913419250378, 15.507426961346699, 14.447881376562, 13.508363994964165, 12.58547611926129, 11.604400821543937, 10.790043815815743, 9.77739420140209, 8.96811054891187, 9.896850023435817, 10.778187353761735, 11.783820797179681, 12.699591184223781, 13.632412552601338, 14.586341327937179, 15.621568948432193, 16.55959331953265, 17.560710775643205, 18.474276610602956, 16.404634826140327, 15.474578382953867, 14.501937803461528, 13.561591993199453, 12.579209781457566, 11.647251517937901, 10.649624446656876, 9.720840617525095, 8.837630252055524, 8.041273472322972, 9.008330422821203, 9.843303885335184, 10.7914982332815, 11.765555977002581, 12.642858491621729, 13.621584704538565, 14.661521172709802, 15.57914089582674, 16.533091069397543, 17.45562726987145, 15.552148011635804, 14.551553380440453, 13.533697329397986, 12.554655946399448, 11.633556555895368, 10.681429944235397, 9.687332439033828, 8.774271103059714, 7.815452866499824, 6.992601685463947, 7.951468153206406, 8.89692399330437, 9.7946191693492, 10.727128529121485, 11.668428873833854, 12.67764578719547, 13.741102687461328, 14.635083119140418, 15.574595576322585, 16.49635948446437, 14.639554910641364, 13.593799029546267, 12.596485965464773, 11.544083961023182, 10.614932756303558, 9.70378734120315, 8.747397393839679, 7.804797955203539, 6.840227245747697, 5.947653708193928, 6.885218130148357, 7.845696203201569, 8.809052986430437, 9.784792491360887, 10.757295919523223, 11.727956925383536, 12.780641911533557, 13.65913175337345, 14.679329421023121, 15.525615703244414, 13.650551742233128, 12.601353014897859, 11.623513935812051, 10.559994498325699, 9.629299364626352, 8.702116802300072, 7.772438912726553, 6.765577081245835, 5.811721453116874, 4.934162352882123, 5.912555716993743, 6.9101492433532545, 7.865453779095845, 8.806187640678312, 9.800780907031863, 10.764617766308088, 11.796411643494642, 12.727388188238272, 13.660423676805072, 14.574342283701844, 12.645753400381487, 11.62767836946181, 10.745545922074546, 9.743028201136113, 8.737686705970054, 7.77853029245797, 6.8107235623483255, 5.795790295971772, 4.873552998135058, 3.966892621260982, 4.970767624700902, 5.898726404173144, 6.900409987042822, 7.8850075232813115, 8.82185641924698, 9.765014465521869, 10.770150558886519, 11.691373749392039, 12.659294053252308, 13.516785547068915, 11.603639015404056, 10.663682155795252, 9.72872136388769, 8.734740593937289, 7.771747230181945, 6.8158482261117435, 5.833934906519001, 4.786665464390323, 3.8312744361024476, 2.9807191527742205, 4.0523829677701055, 4.953337790118604, 5.955447873059021, 6.911967540179728, 7.8432760603641825, 8.851521560172383, 9.695572386873673, 10.638398727248529, 11.618006428818337, 12.547072257342869, 10.703945376333794, 9.666601977398043, 8.703269269094413, 7.736468350336078, 6.73852106714636, 5.811487522815735, 4.772015071686992, 3.8298525115234305, 2.878330625344822, 1.986082863910665, 2.995833027712485, 3.9720297839301044, 4.970184508214951, 5.885728011026617, 6.870677392094158, 7.781439184251337, 8.728859103570205, 9.71314469412548, 10.668390519171101, 11.677936485236398, 9.771526763941397, 8.715221196902203, 7.735206472215956, 6.768355544989988, 5.8126974087304335, 4.857114655081651, 3.792014948094566, 2.856491043259136, 1.8762223756914507, 0.9946877848872892, 2.0126016017214137, 3.0153708284957514, 3.994943974137673, 4.921444752660108, 5.876185407669689, 6.803635293723271, 7.737649105137524, 8.703245371209578, 9.748435813671541, 10.789142270735377, 8.861369273759724, 7.805293283895972, 6.804671382242335, 5.8105951885188505, 4.86772585784659, 3.886454849268222, 2.9501657254586533, 1.9190642766525672, 0.9298378352212088, 0.0, 1.0657095447229725, 2.011699734138541, 3.019042612945192, 4.0890403261465975, 5.09046066427589, 6.018087633785097, 7.028012746840259, 8.008774420995602, 9.076439376852765, 10.107072939990964, 9.696849047754496, 8.750101453768142, 7.841508045110985, 6.849996660794416, 5.882690095908722, 4.9543246295789025, 3.934529907283144, 2.975245393523887, 1.9838598662248699, 1.0015780981104612, 1.9815208876761148, 2.976860221904795, 3.9693810766615956, 5.023828735155535, 6.0162006666656165, 6.965944415834396, 7.956721535952315, 9.021639626295318, 10.001809810664279, 9.892102118860706, 10.62834665803229, 9.759954007337837, 8.897641954022607, 7.906449548036529, 6.905705589476504, 5.952117578351061, 4.936518199696177, 3.9066170289988302, 3.049894562115548, 1.9871541950861, 3.006854770681466, 3.9310790174115438, 4.962471227581401, 5.970463985789072, 6.9330105668240165, 7.887635333459368, 8.889145027744272, 9.92350941469685, 10.942806310814692, 10.771300142452125, 11.694661708665858, 10.796152440822743, 9.813497618439156, 8.879385854016778, 7.829664331310507, 6.866321653250818, 5.896187465782388, 4.901388311998574, 4.007157075600934, 3.010554524811844, 3.9433564024720824, 4.955565075293407, 5.887689350923954, 6.841898782250613, 7.887899895301867, 8.843329497496129, 9.890818374090408, 10.866925504213516, 11.80134375904661, 11.655976186421025, 12.747034389906746, 11.846403790588106, 10.79865625313985, 9.811984462788768, 8.840394523675371, 7.823646812703654, 6.841455674204567, 5.898555780962439, 4.954316610449136, 4.013544603510892, 4.911250424754112, 5.839095374171752, 6.835003479477117, 7.775138757846468, 8.729325925188942, 9.76841155468428, 10.761430598512327, 11.811971848456572, 12.804641154688591, 12.569364650900889, 13.726590771993193, 12.834016529388435, 11.820407670650411, 10.746960426187036, 9.780048697325087, 8.741816395896297, 7.784437819817618, 6.924399278657724, 5.981833465744673, 4.94350458440403, 5.840525953755819, 6.810764117186719, 7.76970958997995, 8.726754864318528, 9.662552051902603, 10.62024971250924, 11.659867595556962, 12.720252030028252, 13.669700052318056, 13.59205831176267, 14.684972647502299, 13.738879247163538, 12.67686520695114, 11.70562437468711, 10.709508783610428, 9.739662915459983, 8.785537770485131, 7.88948780010267, 6.957543498095703, 5.9676138715032145, 6.902385990182796, 7.791139250045783, 8.819985299385891, 9.77168307917461, 10.62902503230595, 11.553297944504855, 12.56040336346201, 13.598860545275882, 14.632132184940982, 14.622276583849573, 15.542560263619272, 14.578128288707056, 13.610172169351335, 12.67863444367735, 11.746939602366472, 10.793353896767853, 9.800022596472841, 8.886423918948708, 7.949855524463434, 7.018432639758572, 7.848929571896242, 8.758654802602415, 9.732999534044714, 10.772643115263321, 11.64162092351671, 12.512152477007191, 13.523650386656142, 14.514975634296029, 15.520341277234415, 15.660669928744806, 16.61513227263339, 15.595631381700485, 14.539973642756099, 13.695800787509711, 12.789289886507747, 11.79355125283598, 10.731998732577896, 9.87617391051746, 9.003838371270298, 8.07568718879127, 8.800743903024811, 9.727719006712201, 10.707827840039487, 11.672511654625326, 12.58282859221845, 13.528207670988225, 14.457601269310553, 15.387237579791858, 16.376282814118866, 16.62471967569669, 17.451382293717533, 16.428391134229873, 15.49123782098563, 14.69079268738637, 13.69879795758094, 12.695948140416894, 11.75299496314211, 10.815955429389549, 9.980894661042305, 9.045128077634335, 9.78957534928737, 10.73322270100234, 11.66849064594461, 12.654227513324932, 13.593685953408215, 14.4613892521337, 15.398266186411226, 16.36175172744893, 17.310776822738895, 17.354899833026487, 18.3874233778106, 17.375781642167205, 16.534203586874757, 15.742046962561151, 14.667238724159771, 13.633503873182729, 12.812224645488824, 11.780037013056551, 10.90847363564555, 10.001939196177172, 10.00507750979953, 10.70971593509215, 11.71738579462749, 12.56322138677132, 13.51684099699152, 14.505840015916522, 15.488234376966208, 16.46854196947525, 17.482730904189456, 18.306585480563335], [18.47280769801058, 17.484843737226754, 16.573136506069673, 15.513590921284974, 14.57407353968714, 13.651185663984265, 12.670110366266911, 11.855753360538714, 10.843103746125063, 10.0272059853801, 9.242365194999165, 9.781943717946332, 10.787577161364277, 11.695570885877757, 12.628392254255314, 13.582321029591155, 14.617548650086169, 15.493883774809674, 16.49500123092023, 17.408567065879986, 17.470344370863298, 16.54028792767684, 15.567647348184503, 14.627301537922428, 13.64491932618054, 12.712961062660876, 11.71533399137985, 10.786550162248068, 9.903339796778496, 9.100368908791202, 8.172480365953627, 8.84706024951978, 9.795254597466096, 10.761535678656557, 11.638838193275705, 12.61756440619254, 13.657500874363778, 14.513431351103765, 15.467381524674568, 16.38991772514848, 16.61785755635878, 15.617262925163427, 14.59940687412096, 13.620365491122422, 12.699266100618342, 11.747139488958371, 10.753041983756802, 9.839980647782687, 8.881162411222796, 8.051697121932177, 7.115618096338829, 7.900680357488966, 8.790598871003176, 9.72310823077546, 10.66440857548783, 11.673625488849446, 12.737082389115304, 13.569373574417444, 14.50888603159961, 15.430649939741398, 15.705264455364338, 14.65950857426924, 13.662195510187747, 12.609793505746156, 11.680642301026532, 10.769496885926124, 9.813106938562653, 8.87050749992651, 7.90593679047067, 7.006749144662158, 6.04936807328078, 6.849452567386165, 7.805032688084413, 8.780772193014863, 9.753275621177199, 10.723936627037512, 11.741327831674479, 12.593422208650475, 13.613619876300147, 14.459906158521441, 14.716261286956103, 13.667062559620833, 12.689223480535025, 11.625704043048673, 10.695008909349326, 9.767826347023046, 8.838148457449527, 7.831286625968808, 6.877430997839847, 5.999871897605096, 5.076705660126166, 5.913905607537851, 6.861433480749821, 7.802167342332288, 8.776551033237048, 9.740387892513274, 10.74584346700782, 11.661678643515298, 12.5947141320821, 13.508632738978871, 13.711462945104458, 12.69338791418478, 11.811255466797519, 10.808737745859085, 9.803396250693028, 8.844239837180945, 7.8764331070713, 6.861499840694744, 5.939262542858032, 5.032602165983954, 4.134917567833325, 4.90248276835774, 5.896389688696798, 6.8809872249352875, 7.756146874524007, 8.699304920798896, 9.704441014163546, 10.625664204669064, 11.593584508529336, 12.451076002345943, 12.669348560127027, 11.729391700518223, 10.79443090861066, 9.800450138660262, 8.837456774904918, 7.881557770834718, 6.899644451241976, 5.852375009113295, 4.8969839808254205, 4.046428697497193, 3.138841337491292, 3.9570941543032, 4.951427574712997, 5.846257995456755, 6.777566515641209, 7.785812015449411, 8.6298628421507, 9.572689182525556, 10.552296884095364, 11.481362712619896, 11.769654921056766, 10.732311522121014, 9.768978813817384, 8.80217789505905, 7.8042306118693325, 6.877197067538709, 5.837724616409965, 4.895562056246403, 3.9440401700677947, 3.0517924086336374, 2.0726932382370657, 2.9757861481147008, 3.9661642098689267, 4.820018466303644, 5.804967847371184, 6.715729639528364, 7.663149558847232, 8.647435149402508, 9.602680974448129, 10.612226940513423, 10.83723630866437, 9.780930741625175, 8.800916016938928, 7.8340650897129605, 6.878406953453406, 5.922824199804624, 4.857724492817539, 3.9222005879821085, 2.941931920414423, 2.060397329610262, 1.0528549514129397, 1.9496612837727787, 2.9292344294147, 3.8557352079371348, 4.810475862946715, 5.737925749000299, 6.671939560414551, 7.637535826486605, 8.682726268948569, 9.723432726012405, 9.927078818482697, 8.871002828618945, 7.870380926965307, 6.876304733241823, 5.933435402569563, 4.952164393991195, 4.015875270181626, 2.9847738213755397, 1.9955473799441812, 1.0657095447229725, 0.0, 0.9459901894155684, 1.9533330682222192, 3.0233307814236245, 4.024751119552917, 4.952378089062124, 5.962303202117287, 6.943064876272629, 8.010729832129792, 9.041363395267991, 9.99564839359514, 9.815810998491115, 8.907217589833959, 7.915706205517388, 6.948399640631695, 6.020034174301875, 4.9908844367694485, 4.031599923010192, 3.012601445188556, 1.967877316281754, 0.9879345267161004, 1.911150677181822, 2.903671531938623, 3.9581191904325617, 4.950491121942643, 5.900234871111422, 6.891011991229342, 7.955930081572346, 8.936100265941306, 9.937510757695641, 10.780085757262032, 10.82566355206081, 9.963351498745581, 8.972159092759503, 7.971415134199477, 7.008472107837365, 5.992872729182482, 4.962971558485135, 4.019006662541449, 2.953453413257393, 2.0132684097214515, 2.8653694726885712, 3.896761682858428, 4.9047544410661, 5.867301022101044, 6.8219257887363955, 7.823435483021299, 8.857799869973878, 9.87709676609172, 10.894662573579474, 11.543211219764713, 11.861861985545715, 10.875772464149815, 9.941660699727437, 8.886018860796813, 7.922676182737124, 6.952541995268694, 5.95774284148488, 4.976269176026835, 3.96276257176995, 3.029960694109712, 3.889855530570435, 4.821979806200981, 5.776189237527641, 6.822190350578895, 7.777619952773155, 8.825108829367435, 9.801215959490543, 10.735634214323637, 11.733480548213082, 12.48759401019737, 12.912113335311076, 11.860931098850509, 10.874259308499427, 9.896749053161678, 8.88000134218996, 7.897810203690873, 6.8557597614224175, 5.9065246574072425, 4.965752650468999, 3.9978547163917413, 4.841289200378228, 5.7692939347541445, 6.709429213123496, 7.663616380465969, 8.702702009961307, 9.695721053789352, 10.7462623037336, 11.738931609965618, 12.68796459736127, 13.456956732162649, 13.899726074111406, 12.876762200136714, 11.80331495567334, 10.836403226811392, 9.798170925382601, 8.840792349303923, 7.881603259117703, 6.9340415127027795, 5.895712631362136, 4.927130245393449, 5.8129579433931955, 6.739798313644284, 7.696843587982861, 8.632640775566937, 9.590338436173575, 10.62694236478167, 11.678133953611027, 12.627581975900831, 13.56037868072401, 14.437223126039765, 14.795233776649843, 13.733219736437444, 12.761978904173414, 11.746320051766748, 10.776474183616303, 9.79570118231419, 8.84669178056265, 7.909751545053809, 6.919821918461321, 5.988990281820426, 6.793333076252259, 7.790074023050226, 8.741771802838944, 9.599113755970285, 10.52338666816919, 11.530492087126344, 12.568949268940216, 13.590014108523757, 14.548497219545235, 15.378023668342669, 15.63448281819336, 14.66652669883764, 13.734988973163654, 12.783750870522793, 11.813434892354493, 10.8101860083019, 9.843627899408688, 8.902063571421541, 7.970640686716678, 6.935533863533872, 7.760848628808892, 8.735193360251191, 9.76158263912365, 10.611709647181044, 11.482241200671526, 12.493739110320476, 13.485064357960363, 14.49043000089875, 15.517908539680743, 16.424412645391374, 16.651985911186788, 15.596328172242403, 14.752155316996015, 13.826101154664068, 12.803714664665039, 11.742162144406954, 10.83337789097744, 9.816541588766103, 8.888390406287074, 7.887348194662442, 8.729912832918679, 9.710021666245964, 10.674705480831804, 11.552917315882784, 12.49829639465256, 13.427689992974887, 14.357326303456192, 15.346371537783199, 16.281045966349065, 17.40168734156898, 17.484745663716176, 16.547592350471934, 15.670014608831295, 14.615337453413574, 13.612487636249528, 12.669534458974743, 11.730639151787045, 10.79359787853811, 9.85783129513014, 8.876179640925, 9.735416527208816, 10.670684472151088, 11.65642133953141, 12.56377467707255, 13.431477975798034, 14.36835491007556, 15.331840451113264, 16.28086554640323, 17.233977334015908, 18.337728425662046, 17.491181298915702, 16.484929160974403, 15.597856625126257, 14.523048386724877, 13.645500126956478, 12.64342756386565, 11.720844550857793, 10.811174291483708, 10.187092303578146, 9.822497711676553, 10.805123883425516, 11.59938744344523, 12.655293418435908, 13.546886576860217, 14.405469605748733, 15.404673231684239, 16.368206579913263, 17.252703581150847, 18.185662981552756], [18.24071547863378, 17.373191804965835, 16.444967471363523, 15.426637034231334, 14.487119652633499, 13.527816022230665, 12.546740724513311, 11.580739232841406, 10.791455427700008, 10.72212506581382, 9.793385591289873, 8.835953528530766, 9.84158697194871, 10.74958069646219, 11.682402064839746, 12.636330840175587, 13.671558460670601, 14.54789358539411, 15.549011041504667, 16.462576876464418, 17.2382521514865, 17.486278117092407, 16.51363753760007, 15.573291727337995, 14.590909515596108, 13.658951252076443, 12.661324180795418, 11.639260907817153, 10.756050542347582, 9.866138998831868, 8.89370952285488, 7.901070060104213, 8.849264408050528, 9.81554548924099, 10.692848003860137, 11.671574216776973, 12.71151068494821, 13.567441161688201, 14.521391335259004, 15.44392753573291, 16.407627440994382, 16.563253114578995, 15.545397063536528, 14.56635568053799, 13.64525629003391, 12.69312967837394, 11.69903217317237, 10.692691393351772, 9.733873156791882, 8.817467211972843, 7.881388186379495, 6.954690168073398, 7.844608681587609, 8.777118041359893, 9.718418386072262, 10.727635299433878, 11.791092199699737, 12.62338338500188, 13.562895842184046, 14.48465975032583, 15.611272410459156, 15.605498763684809, 14.608185699603315, 13.555783695161724, 12.6266324904421, 11.715487075341692, 10.75909712797822, 9.74245550672265, 8.758647536039755, 7.772519234702824, 6.815138163321446, 5.903462377970597, 6.859042498668845, 7.834782003599296, 8.807285431761631, 9.777946437621944, 10.795337642258911, 11.64743201923491, 12.667629686884583, 13.513915969105874, 14.622803134337953, 14.6130527490364, 13.635213669950593, 12.57169423246424, 11.640999098764894, 10.713816536438614, 9.784138646865095, 8.777276815384376, 7.8234211872554145, 6.871832392935053, 5.842475750166832, 4.967915418122283, 5.915443291334253, 6.85617715291672, 7.8305608438214795, 8.794397703097706, 9.799853277592252, 10.715688454099734, 11.648723942666532, 12.562642549563304, 13.560693402689626, 13.63937810360035, 12.757245656213087, 11.754727935274653, 10.749386440108596, 9.790230026596513, 8.822423296486868, 7.807490030110313, 6.8852527322735995, 5.9045626613139115, 4.900687657873991, 3.9564925789421723, 4.950399499281231, 5.93499703551972, 6.810156685108439, 7.753314731383328, 8.758450824747978, 9.6796740152535, 10.647594319113768, 11.505085812930375, 12.670149800865106, 12.675381889933792, 11.74042109802623, 10.74644032807583, 9.783446964320486, 8.827547960250286, 7.8456346406575435, 6.798365198528864, 5.842974170240989, 4.992418886912762, 3.9775008469685664, 3.0111039648876323, 4.005437385297429, 4.900267806041187, 5.831576326225641, 6.839821826033843, 7.6838726527351335, 8.62669899310999, 9.606306694679796, 10.535372523204328, 11.739521168884746, 11.678301711536584, 10.714969003232953, 9.748168084474619, 8.750220801284902, 7.823187256954276, 6.783714805825533, 5.841552245661972, 4.890030359483363, 3.997782598049206, 3.005992714916752, 2.0297959586991325, 3.0201740204533585, 3.874028276888076, 4.8589776579556165, 5.769739450112796, 6.7171593694316645, 7.70144495998694, 8.656690785032561, 9.666236751097856, 10.948445762674634, 10.726920931040745, 9.746906206354497, 8.78005527912853, 7.824397142868975, 6.868814389220192, 5.803714682233107, 4.868190777397677, 3.887922109829992, 3.0063875190258305, 1.9988451408285082, 1.0036710943572102, 1.9832442399991315, 2.9097450185215665, 3.8644856735311475, 4.791935559584731, 5.7259493709989835, 6.691545637071037, 7.736736079533, 8.777442536596837, 10.022253413381051, 9.816993018034514, 8.816371116380877, 7.822294922657392, 6.8794255919851315, 5.898154583406764, 4.9618654595971945, 3.9307640107911084, 2.94153756935975, 2.011699734138541, 0.9459901894155684, 0.0, 1.0073428788066507, 2.0773405920080563, 3.0787609301373484, 4.006387899646556, 5.016313012701718, 5.99707468685706, 7.064739642714223, 8.095373205852422, 9.04965820417957, 9.996405798165924, 9.853207779249527, 8.861696394932958, 7.894389830047263, 6.966024363717444, 5.936874626185016, 4.9775901124257595, 3.958591634604124, 2.9138675056973224, 1.9339247161316688, 0.9651604877662536, 1.9576813425230546, 3.0121290010169934, 4.004500932527074, 4.954244681695854, 5.945021801813773, 7.009939892156777, 7.9901100765257365, 8.991520568280071, 9.834095567846465, 10.902395718712325, 10.909341688161149, 9.918149282175072, 8.917405323615046, 7.954462297252933, 6.9388629185980495, 5.908961747900703, 4.964996851957018, 3.8994436026729615, 2.9129077376939194, 1.9193792832730028, 2.9507714934428595, 3.958764251650531, 4.921310832685475, 5.875935599320827, 6.877445293605731, 7.91180968055831, 8.931106576676152, 9.948672384163906, 10.597221030349145, 11.663257097089765, 11.811623526503862, 10.877511762081484, 9.82186992315086, 8.858527245091171, 7.888393057622741, 6.8935939038389265, 5.878180054074799, 4.862401899742418, 3.9296000220821794, 2.9438653411548668, 3.8759896167854127, 4.830199048112072, 5.876200161163326, 6.831629763357586, 7.879118639951868, 8.855225770074975, 9.78964402490807, 10.787490358797514, 11.541603820781802, 12.513167837696928, 12.796782161204556, 11.810110370853474, 10.832600115515724, 9.815852404544007, 8.823720057544552, 7.755399089394885, 6.80616398537971, 5.865391978441466, 4.8231439603803, 3.89529901096266, 4.823303745338576, 5.763439023707926, 6.7176261910504, 7.756711820545737, 8.749730864373785, 9.800272114318032, 10.79294142055005, 11.741974407945703, 12.51096654274708, 13.50078057649726, 13.802672053990396, 12.72922480952702, 11.762313080665072, 10.724080779236282, 9.766702203157603, 8.781242587090171, 7.833680840675247, 6.795351959334604, 5.752419489382007, 4.866967753977627, 5.793808124228715, 6.750853398567291, 7.686650586151367, 8.644348246758003, 9.680952175366102, 10.73214376419546, 11.681591786485264, 12.614388491308443, 13.491232936624197, 14.437326336962958, 14.644693809654836, 13.673452977390806, 12.645959379739216, 11.67611351158877, 10.695340510286657, 9.746331108535118, 8.809390873026278, 7.8194612464337885, 6.80920685873793, 5.847342886836691, 6.844083833634657, 7.795781613423373, 8.653123566554715, 9.577396478753618, 10.584501897710773, 11.622959079524644, 12.64402391910819, 13.602507030129667, 14.432033478927101, 15.396465453839317, 15.57800077205503, 14.646463046381045, 13.68339019849526, 12.71307422032696, 11.709825336274367, 10.743267227381157, 9.797964330017228, 8.820794281058218, 7.755750440451377, 6.814858439393323, 7.789203170835622, 8.815592449708081, 9.665719457765475, 10.536251011255954, 11.547748920904905, 12.539074168544792, 13.544439811483178, 14.571918350265172, 15.478422455975807, 16.447684641472755, 16.507802245459796, 15.663629390213407, 14.725740482636535, 13.703353992637506, 12.641801472379422, 11.707931008271988, 10.636758165683608, 9.708606983204579, 8.707564771579946, 7.783922643503109, 8.764031476830395, 9.728715291416234, 10.606927126467214, 11.55230620523699, 12.481699803559318, 13.411336114040623, 14.40038134836763, 15.335055776933494, 16.455697152153412, 17.458463730338316, 16.581904737447967, 15.649254174957306, 14.594577019539585, 13.611652834382804, 12.66869965710802, 11.729804349920322, 10.792763076671386, 10.678047872047644, 9.696396217842505, 8.789426337793248, 9.724694282735518, 10.71043115011584, 11.61778448765698, 12.485487786382464, 13.42236472065999, 14.385850261697694, 15.334875356987661, 16.28798714460034, 17.39173823624648, 16.545191109500138, 15.538938971558839, 14.651866435710689, 13.57705819730931, 12.69950993754091, 11.697437374450082, 10.774854361442225, 9.865184102068142, 10.738112699868854, 10.642714288594057, 9.859133694009948, 10.65339725402966, 11.709303229020339, 12.600896387444648, 13.459479416333163, 14.45868304226867, 15.422216390497693, 16.30671339173528, 17.23967279213719], [17.34407210517585, 16.476548431507904, 15.548324097905592, 14.529993660773407, 13.590476279175572, 12.6493316748667, 11.802218872870592, 10.836217381198686, 11.780597897286398, 11.69587012332812, 10.767130648804173, 9.809698586045066, 8.934460942647798, 9.80928114853971, 10.742102516917267, 11.696031292253108, 12.731258912748123, 13.607594037471632, 14.608711493582188, 15.52227732854194, 16.34160877802857, 17.271665221215027, 16.43800951458395, 15.497663704321877, 14.519630492682172, 13.589531001120628, 12.756995247757652, 11.905420579489334, 11.76339342115423, 10.867602339638882, 9.86745458036918, 8.874815117618514, 7.942138378749617, 8.87524594131851, 9.752548455937658, 10.731274668854494, 11.771211137025732, 12.627141613765723, 13.581091787336526, 14.503627987810432, 15.510984067536452, 16.511578698731803, 16.552739942343177, 15.57369855934464, 14.65259916884056, 13.70047255718059, 12.70637505197902, 11.70003427215842, 10.74121603559853, 9.824810090779492, 8.888731065186144, 7.9284352255877, 6.904309133665129, 7.8368184934374145, 8.778118838149783, 9.7873357515114, 10.850792651777258, 11.683083837079401, 12.622596294261568, 13.544360202403352, 14.68187139962976, 15.58750382931031, 15.615528578409965, 14.563126573968374, 13.63397536924875, 12.722829954148342, 11.76644000678487, 10.749798385529298, 9.765990414846403, 8.779862113509473, 7.822481042128096, 6.877207435484899, 5.918742950746366, 6.894482455676816, 7.866985883839153, 8.837646889699466, 9.855038094336432, 10.707132471312432, 11.727330138962104, 12.573616421183395, 13.636579798541598, 14.595057814661901, 14.642556548757243, 13.57903711127089, 12.648341977571544, 11.721159415245264, 10.791481525671745, 9.784619694191026, 8.830764066062065, 7.879175271741703, 6.849818628973482, 5.941660475636585, 4.975143743411774, 5.9158776049942405, 6.890261295899001, 7.854098155175227, 8.859553729669774, 9.775388906177255, 10.708424394744053, 11.622343001640825, 12.574470066893271, 13.587879538344113, 13.764588535019737, 12.762070814081303, 11.756729318915246, 10.797572905403163, 9.829766175293518, 8.814832908916962, 7.8925956110802495, 6.911905540120562, 5.908030536680641, 4.963835457748822, 4.010099951358751, 4.99469748759724, 5.869857137185961, 6.813015183460849, 7.8181512768255, 8.739374467331022, 9.70729477119129, 10.564786265007896, 11.683926465068751, 12.623883324677555, 12.74776397683288, 11.75378320688248, 10.790789843127136, 9.834890839056936, 8.852977519464194, 7.805708077335514, 6.850317049047639, 5.999761765719413, 4.9848437257752165, 4.018446843694282, 3.0651378373749503, 3.9599682581187086, 4.891276778303163, 5.899522278111364, 6.743573104812655, 7.6863994451875115, 8.666007146757318, 9.59507297528185, 10.753297833088391, 11.826419699402445, 11.722311882039604, 10.755510963281269, 9.757563680091552, 8.830530135760927, 7.791057684632183, 6.848895124468622, 5.8973732382900135, 5.005125476855857, 4.013335593723402, 3.0371388375057826, 2.07987447253088, 2.9337287289655976, 3.9186781100331385, 4.829439902190318, 5.776859821509186, 6.761145412064462, 7.716391237110083, 8.725937203175379, 9.954758972117352, 10.992450404602788, 10.754249085161147, 9.78739815793518, 8.831740021675625, 7.876157268026842, 6.811057561039757, 5.875533656204327, 4.895264988636642, 4.0137303978324805, 3.006188019635159, 2.0110139731638608, 1.042944692076653, 1.969445470599088, 2.924186125608669, 3.851636011662252, 4.785649823076504, 5.751246089148558, 6.796436531610521, 7.8371429886743575, 9.014910534574401, 9.933871089231442, 9.823713995187527, 8.829637801464042, 7.886768470791782, 6.905497462213414, 5.969208338403845, 4.9381068895977585, 3.9488804481664004, 3.0190426129451917, 1.9533330682222192, 1.0073428788066507, 0.0, 1.0699977132014054, 2.0714180513306975, 2.9990450208399047, 4.008970133895067, 4.98973180805041, 6.0573967639075725, 7.088030327045771, 8.042315325372918, 8.989062919359272, 10.01016548250736, 9.869039273739608, 8.901732708853913, 7.973367242524094, 6.944217504991667, 5.9849329912324105, 4.965934513410775, 3.9212103845039734, 2.94126759493832, 1.9725033665729044, 1.0461294341991487, 2.0047861222103425, 2.997158053720424, 3.946901802889203, 4.937678923007123, 6.002597013350127, 6.982767197719086, 7.984177689473421, 8.893796019923984, 9.962096170789845, 10.955824196362578, 10.925492160981722, 9.924748202421696, 8.961805176059585, 7.9462057974047005, 6.916304626707354, 5.972339730763668, 4.906786481479612, 3.92025061650057, 2.9267221620796535, 2.0541281199849326, 2.9754595818367218, 3.9380061628716665, 4.892630929507018, 5.891221957809376, 6.925586344761955, 7.944883240879797, 8.954985593606624, 9.656921482426668, 10.722957549167289, 11.768703209194694, 11.884854640888134, 10.82921280195751, 9.865870123897821, 8.895735936429391, 7.9009367826455765, 6.88552293288145, 5.869744778549069, 4.93694290088883, 3.943305511126429, 2.9793462433274858, 3.9335556746541456, 4.901393566290771, 5.848325093543777, 6.8928953041555125, 7.86900243427862, 8.803420689111714, 9.80126702300116, 10.601304272859323, 11.57286828977445, 12.645854798939975, 12.817453249660124, 11.839942994322374, 10.823195283350657, 9.831062936351204, 8.762741968201537, 7.813506864186361, 6.872734857248117, 5.822584130351863, 4.894739180934223, 3.9266603718806485, 4.86679565025, 5.820982817592474, 6.773407150731928, 7.766426194559974, 8.814048778521677, 9.806718084753696, 10.755751072149348, 11.570666994824602, 12.560481028574781, 13.601117801130473, 13.736567688333672, 12.769655959471724, 11.731423658042933, 10.774045081964255, 9.788585465896823, 8.841023719481898, 7.802694838141255, 6.7518596593535705, 5.856110223564019, 4.897164750770788, 5.8542100251093645, 6.79000721269344, 7.747704873300076, 8.697647505552291, 9.745920428399105, 10.695368450688909, 11.628165155512088, 12.550933388701718, 13.49702678904048, 14.559040829252877, 14.680795856197458, 13.653302258545867, 12.683456390395422, 11.702683389093309, 10.75367398734177, 9.816733751832928, 8.82680412524044, 7.798349328324322, 6.836485356423083, 5.94744046017673, 6.899138239965446, 7.756480193096787, 8.680753105295691, 9.687858524252846, 10.726315706066718, 11.657800583311834, 12.616283694333312, 13.491733931004623, 14.456165905916839, 15.42412202527256, 15.653805925187697, 14.690733077301912, 13.720417099133613, 12.717168215081019, 11.750610106187807, 10.78710679960362, 9.80993675064461, 8.74489291003777, 7.804000908979715, 6.958065204371545, 7.918949076250153, 8.769076084307546, 9.639607637798028, 10.651105547446978, 11.642430795086865, 12.647796438025251, 13.654677039228545, 14.538122908053328, 15.507385093550276, 16.353923498677325, 15.612933963769999, 14.65479856099235, 13.648810561029789, 12.7811314358903, 11.771591434680404, 11.62590063527, 10.697749452790971, 9.696707241166338, 8.773065113089501, 8.019509625187675, 8.873569281285672, 9.710283753009286, 10.655662831779061, 11.585056430101389, 12.514692740582694, 13.5037379749097, 14.438412403475565, 15.515397604230934, 16.518164182415838, 15.641605189525487, 14.708954627034828, 13.654277471617107, 12.696766122384266, 11.770705222996014, 10.831809915808316, 11.766508134185687, 11.667190341634036, 10.685538687428897, 9.778568807379639, 8.980172431092798, 9.899584571434712, 10.721141114199051, 11.588844412924535, 12.525721347202062, 13.489206888239766, 14.438231983529732, 15.391343771142411, 16.451438688324, 15.60489156157766, 14.59863942363636, 13.71156688778821, 12.636758649386831, 11.759210389618431, 10.757137826527604, 9.867728332141313, 10.838929159582442, 11.711857757383154, 11.631856758180449, 10.848276163596339, 9.90887540238694, 10.898456650339211, 11.704253013986719, 12.562836042875235, 13.56203966881074, 14.525573017039765, 15.410070018277349, 16.34302941867926], [16.32095132626212, 15.453427652594174, 14.52520331899186, 13.506872881859675, 12.56735550026184, 11.626210895952967, 10.88092066108893, 11.67860429740486, 12.639924404144455, 12.511253253203217, 11.58251377867927, 10.625081715920162, 9.749844072522896, 8.940123760169685, 9.872945128547242, 10.826873903883083, 11.820274263600115, 12.630918276136894, 13.63203573224745, 14.545601567207205, 15.318487999114838, 16.2485444423013, 15.41488873567022, 14.474542925408144, 13.49650971376844, 12.566410222206896, 11.835697035975992, 12.747807495695508, 12.619666910339273, 11.682985469513978, 10.682837710244277, 9.69019824749361, 8.757521508624714, 8.006088552948485, 8.883391067567633, 9.862117280484469, 10.860226487877725, 11.650465852430985, 12.604416026001788, 13.526952226475698, 14.48786328862272, 15.475260467003089, 16.417883333845865, 15.439554879261323, 14.442162939330638, 13.5322317959094, 12.79798904359904, 12.556307761343463, 11.597489524783573, 10.681083579964534, 9.745004554371185, 8.743818355462796, 7.719692263540226, 6.967661105067389, 7.908961449779758, 8.877098320740647, 9.889176941113899, 10.706408075744664, 11.64592053292683, 12.567684441068618, 13.611873686428353, 14.517506116108903, 15.48067196991265, 15.473258264697291, 14.544107059977668, 13.592095394102127, 12.635705446738656, 11.60607187471434, 10.622263904031445, 9.636135602694516, 8.678754531313137, 7.692590565359995, 6.734126080621463, 6.025325067306792, 6.9629597315552685, 7.927409458928712, 8.878362333001698, 9.730456709977695, 10.750654377627367, 11.596940659848661, 12.566582085340192, 13.525060101460495, 14.502899180546303, 14.489168801999808, 13.558473668300461, 12.631291105974183, 11.701613216400665, 10.662773931581453, 9.708918303452492, 8.735448760926744, 7.706092118158523, 6.757043605511681, 5.790526873286871, 5.040750985587966, 5.913585534564267, 6.877422393840493, 7.882877968335039, 8.798713144842518, 9.73174863340932, 10.645667240306091, 11.504472353691865, 12.517881825142707, 13.542398360711061, 13.83206852728271, 12.826727032116652, 11.850556532972224, 10.882749802862579, 9.863804840060267, 8.837634214387666, 7.768179029305602, 6.764304025865682, 5.820108946933863, 4.825483081233848, 4.039537433201734, 4.893181375851227, 5.836339422126115, 6.841475515490766, 7.762698705996285, 8.730619009856555, 9.588110503673162, 10.613928751867345, 11.553885611476149, 12.525079626194843, 12.823780920083886, 11.860787556328543, 10.887874466625997, 9.905961147033254, 8.854680008478818, 7.892526797933482, 6.873995535573819, 5.841117214960257, 4.874720332879323, 3.880520967250047, 2.9832924967839745, 3.9146010169684287, 4.922846516776629, 5.76689734347792, 6.709723683852776, 7.689331385422584, 8.618397213947116, 9.683300119886985, 10.756421986201039, 11.719754694504669, 11.825508676482675, 10.827561393292958, 9.900527848962332, 8.861055397833589, 7.897867055611926, 6.939582987175856, 5.879359246710263, 4.869609082908442, 3.8934123266908234, 2.8952576024059766, 1.9570529676308632, 2.942002348698404, 3.8527641408555833, 4.800184060174451, 5.784469650729727, 6.739715475775348, 7.749261441840644, 8.884761258915946, 9.922452691401382, 10.811957769474558, 10.857395871136585, 9.901737734877031, 8.946154981228249, 7.881055274241163, 6.9455313694057335, 5.965262701838048, 4.955718453500387, 3.937804636666262, 2.8988436334287098, 1.9192704877867888, 0.9927697092643537, 1.9475103642739344, 2.8749602503275176, 3.80897406174177, 4.774570327813824, 5.819760770275787, 6.860467227339623, 7.944912821372996, 8.863873376030035, 9.864495277683673, 9.899635514665448, 8.956766183993189, 7.97549517541482, 7.039206051605251, 6.008104602799165, 5.018878161367806, 4.0890403261465975, 3.023330781423625, 2.0773405920080563, 1.0699977132014054, 0.0, 1.001420338129292, 1.9290473076384993, 2.938972420693662, 3.919734094849004, 4.987399050706166, 6.0180326138443645, 6.972317612171513, 7.919065206157866, 8.940167769305953, 9.970244895766873, 9.97173042205532, 9.043364955725501, 8.014215218193073, 7.054930704433816, 6.03593222661218, 4.991208097705378, 4.011265308139725, 2.991045376223597, 1.9985245214667957, 0.9347884090089372, 1.9271603405190185, 2.8769040896877978, 3.867681209805718, 4.932599300148722, 5.91276948451768, 6.914179976272015, 7.903815222449308, 8.928917759727561, 9.922645785300293, 10.941750400053095, 10.994745915623103, 10.03180288926099, 9.016203510606106, 7.986302339908759, 7.042337443965074, 5.976784194681017, 4.938375291433761, 3.944846837012845, 2.913454626842988, 1.9054618686353164, 2.868008449670261, 3.8226332163056127, 4.82122424460797, 5.855588631560549, 6.874885527678391, 7.884987880405217, 8.680245721091932, 9.746281787832553, 10.792027447859958, 11.726139212282336, 11.734601621284279, 10.77125894322459, 9.80112475575616, 8.806325601972345, 7.790911752208218, 6.775133597875836, 5.842331720215598, 4.802632017984484, 3.838672750185541, 2.893946855617675, 3.831395853089366, 4.778327380342373, 5.822897590954106, 6.799004721077214, 7.733422975910309, 8.731269309799753, 9.62462851152459, 10.596192528439715, 11.66917903760524, 12.658737821054325, 12.745331813649143, 11.728584102677425, 10.69064055760353, 9.622319589453863, 8.673084485438688, 7.732312478500443, 6.681910637209918, 5.754065687792278, 4.785986878738704, 3.8271868312135298, 4.7813739985560035, 5.7034094375305235, 6.69642848135857, 7.744051065320271, 8.736720371552291, 9.685753358947942, 10.593991233489866, 11.583805267240045, 12.624442039795737, 13.697889284259112, 13.62923358072405, 12.59100127929526, 11.63362270321658, 10.648163087149149, 9.700601340734224, 8.66227245939358, 7.611186166211626, 6.715436730422074, 5.756491257628843, 4.8778534706317025, 5.766886433779706, 6.724584094386342, 7.627649792350886, 8.675922715197698, 9.625370737487502, 10.558167442310681, 11.574257627366983, 12.520351027705743, 13.582365067918142, 14.553605900182172, 14.512879879798193, 13.543034011647748, 12.562261010345635, 11.613251608594096, 10.676311373085253, 9.686381746492765, 8.657675835182378, 7.695811863281138, 6.806766967034785, 5.922781685487784, 6.733359414183053, 7.6576323263819575, 8.64193777176453, 9.680394953578402, 10.587802870110428, 11.546285981131906, 12.515058169669887, 13.479490144582103, 14.447446263937824, 15.40278918154858, 14.8279914567636, 13.832223035304672, 12.900182487173561, 12.610187727440135, 11.646433306461677, 10.669263257502667, 9.604219416895825, 8.66332741583777, 7.8173917112296, 6.942592521772491, 7.745955305393813, 8.616486858884294, 9.627984768533244, 10.61931001617313, 11.624675659111517, 12.584679326027139, 13.561447146718596, 14.53070933221554, 15.377247737342588, 14.743776575399973, 13.785641172622325, 12.779653172659764, 11.968206351068506, 12.586974564555502, 12.485227142128055, 11.557075959649026, 10.556033748024394, 9.632391619947557, 8.861896541393849, 7.897212726808009, 8.687162974095553, 9.632542052865329, 10.561935651187657, 11.491571961668962, 12.480617195995968, 13.415291624561833, 14.538721842896202, 15.541488421081102, 14.66492942819075, 13.839797238664804, 12.785120083247081, 11.827608734014241, 10.947210120504293, 11.647193045683414, 12.581891264060783, 12.526516848492092, 11.544865194286952, 10.637895314237696, 9.822559347298972, 8.923228016957049, 9.69802033528532, 10.565723634010803, 11.50260056828833, 12.466086109326033, 13.415111204616, 14.368222992228679, 15.474762926989268, 14.628215800242922, 13.621963662301622, 12.827302527026635, 11.767601261016805, 10.890053001248406, 9.887980438157578, 10.683111462016411, 11.654312289457538, 12.52724088725825, 12.491183265038504, 11.707602670454396, 10.751262318593113, 9.922100095861548, 10.681132235072987, 11.539715263961503, 12.538918889897008, 13.502452238126033, 14.386949239363616, 15.31990863976553], [15.536012760951133, 14.668489087283186, 13.740264753680872, 12.721934316548687, 11.782416934950852, 10.84127233064198, 11.808633845209583, 12.675734404024016, 13.641344742273748, 13.510486527675882, 12.581747053151934, 11.624314990392827, 10.74907734699556, 9.860849776279975, 9.071408343299936, 9.963003676859335, 10.871296053041577, 11.681940065578358, 12.683057521688914, 13.596623356648669, 14.53354943380385, 15.46360587699031, 14.629950170359232, 13.689604360097157, 12.711571148457452, 11.781471656895908, 12.763410220096643, 13.744937602314664, 13.618900184811935, 12.682218743986644, 11.682070984716942, 10.689431521966275, 9.756754783097378, 8.926814569058775, 8.06315218326861, 8.998247053460721, 9.911248277319187, 10.701487641872449, 11.655437815443252, 12.577974015917162, 13.702924723311732, 14.552916681890453, 15.495539548733229, 14.654616313950335, 13.65722437401965, 12.747293230598412, 13.725702227719692, 13.555541035816125, 12.596722799256234, 11.680316854437196, 10.744237828843849, 9.743051629935461, 8.71892553801289, 7.888387121177679, 7.088722565480735, 7.967820282891959, 8.94019873055536, 9.757429865186127, 10.696942322368294, 11.618706230510082, 12.70228613178178, 13.595162330996267, 14.558328184800015, 15.604999378331083, 14.67584817361146, 13.72493583363066, 13.634938721211318, 12.605305149187002, 11.621497178504107, 10.635368877167178, 9.6779878057858, 8.69182383983266, 7.733359355094127, 6.946051083417081, 6.053681693706581, 7.0181314210800245, 7.929384122443161, 8.781478499419158, 9.80167616706883, 10.647962449290125, 11.656994530693618, 12.602716316347859, 13.580555395433667, 14.572054073538638, 14.557706942773127, 13.630524380446847, 12.700846490873328, 11.662007206054117, 10.708151577925156, 9.734682035399407, 8.705325392631186, 7.756276879984345, 6.789760147759535, 5.961477001698255, 5.00430749671558, 5.9681443559918055, 6.933899757776503, 7.8497349342839815, 8.782770422850783, 9.696689029747555, 10.59488479904529, 11.595538040030071, 12.620054575598425, 13.622572296536859, 13.828147370245945, 12.849789807444889, 11.881983077335244, 10.863038114532932, 9.836867488860328, 8.767412303778265, 7.763537300338346, 6.819342221406527, 5.824716355706512, 4.9602634493120235, 3.9839033380025395, 4.927061384277428, 5.892497304932229, 6.813720495437749, 7.781640799298019, 8.639132293114626, 9.691584966754709, 10.631541826363513, 11.602735841082207, 12.621277470157423, 12.862207894457836, 11.887107741098662, 10.90519442150592, 9.853913282951483, 8.891760072406145, 7.8732288100464825, 6.840350489432921, 5.873953607351987, 4.87975424172271, 3.9366314993041955, 3.0053229791197413, 3.9738683062180926, 4.817919132919384, 5.760745473294239, 6.7403531748640475, 7.66941900338858, 8.760956334774349, 9.834078201088403, 10.778600228223723, 11.766817207483868, 11.828981731422251, 10.901948187091625, 9.862475735962882, 8.89710033008459, 7.93881626164852, 6.878592521182926, 5.868842357381106, 4.892645601163487, 3.89449087687864, 2.9562862421035265, 2.0317543131519056, 2.9037859302970466, 3.8512058496159147, 4.83549144017119, 5.790737265216812, 6.8002832312821075, 7.883340920786653, 8.921032353272091, 9.810537431345267, 10.777388358571235, 10.903158073006324, 9.947575319357542, 8.882475612370456, 7.9469517075350256, 6.96668303996734, 5.95495172797305, 4.937037911138925, 3.8980769079013733, 2.918503762259452, 1.992002983737017, 1.0372623287274363, 1.9259820397689809, 2.8599958511832333, 3.825592117255287, 4.8707825597172505, 5.911489016781087, 6.943492483243704, 7.862453037900744, 8.863074939554382, 9.857151133277867, 9.95818652212248, 8.976915513544112, 8.040626389734543, 7.009524940928457, 6.020298499497098, 5.09046066427589, 4.024751119552917, 3.0787609301373484, 2.0714180513306975, 1.001420338129292, 0.0, 0.9276269695092073, 1.9375520825643697, 2.9183137567197117, 3.985978712576874, 5.016612275715072, 5.970897274042221, 6.917644868028574, 7.938747431176661, 8.968824557637582, 9.994864395604392, 10.044785293854792, 9.015635556322367, 8.05635104256311, 7.037352564741473, 5.992628435834671, 5.012685646269017, 3.992465714352889, 2.999944859596088, 1.9362087471382292, 1.036691169038677, 1.9864349182074563, 2.9580936551591437, 3.978798753176799, 4.911349146388388, 5.912759638142723, 6.902394884320016, 7.927497421598268, 8.921225447171, 9.940330061923802, 10.967072157015293, 11.033223227390284, 10.0176238487354, 8.987722678038054, 8.043757782094367, 6.97820453281031, 5.939795629563053, 4.946267175142137, 3.91487496497228, 2.9068822067646085, 2.07746775679721, 3.0074916203467996, 3.9116366899613957, 4.946001076913975, 5.950095424367211, 6.883567542275925, 7.731267510533396, 8.797303577274016, 9.843049237301422, 10.7771610017238, 11.832802840654423, 11.77267928135388, 10.80254509388545, 9.807745940101636, 8.79233209033751, 7.776553936005128, 6.84375205834489, 5.804052356113776, 4.840093088314833, 3.895367193746967, 3.0408551602163154, 3.9631857843835596, 4.913310036307532, 5.88941716643064, 6.823835421263735, 7.808925524687117, 8.675650300966053, 9.64721431788118, 10.720200827046703, 11.709759610495789, 12.714603443651077, 12.730004440806717, 11.692060895732821, 10.623739927583154, 9.674504823567979, 8.733732816629734, 7.68333097533921, 6.75548602592157, 5.787407216867996, 4.828607169342822, 3.9964354332450167, 4.888267841571711, 5.860068409299618, 6.834463510673697, 7.827132816905716, 8.763409573835306, 9.64501302293133, 10.634827056681509, 11.6754638292372, 12.748911073700576, 13.68433842864218, 13.59242161742455, 12.635043041345872, 11.64958342527844, 10.702021678863515, 9.663692797522872, 8.612606504340917, 7.716857068551367, 6.757911595758136, 5.879273808760995, 4.981947868468719, 5.9396455290753565, 6.7912897202919345, 7.766335160551123, 8.715783182840928, 9.648579887664107, 10.625279416808446, 11.571372817147207, 12.633386857359605, 13.604627689623635, 14.632121287275226, 14.084377231365236, 13.563681348474926, 12.614671946723387, 11.677731711214545, 10.687802084622056, 9.65909617331167, 8.697232201410431, 7.808187305164078, 6.9242020236170765, 5.9484208488720665, 6.8726937610709715, 7.805577699705578, 8.780958658721955, 9.678215315463854, 10.636698426485331, 11.56607995911135, 12.530511934023567, 13.498468053379288, 14.453810970990043, 13.964121229739852, 13.030686250057366, 13.820908503283851, 13.611608065569424, 12.64785364459097, 11.67068359563196, 10.605639755025118, 9.664747753967063, 8.818812049358893, 7.944012859901783, 6.961016740082826, 7.831548293573308, 8.841183591914708, 9.778322220301401, 10.74157854077599, 11.675091771380565, 12.61246893616006, 13.581731121657004, 14.428269526784051, 13.879906348376226, 12.921770945598578, 11.978116387412458, 12.888932367178796, 13.586207839028166, 13.486647480257348, 12.55849629777832, 11.557454086153687, 10.63381195807685, 9.859026648013005, 8.894342833427165, 7.902224408784566, 8.847603487554341, 9.776997085876669, 10.706633396357974, 11.69567863068498, 12.630353059250846, 13.589743632337665, 14.592510210522565, 13.715951217632213, 12.939503796391133, 11.921249856223334, 11.026071948766935, 11.867936136614583, 12.646426320156078, 13.581124538533448, 13.527937186621385, 12.546285532416245, 11.639315652366989, 10.819689453918128, 9.920358123576206, 8.913081769974331, 9.780785068699815, 10.717662002977342, 11.681147544015046, 12.630172639305012, 13.583284426917691, 14.525784716430731, 13.679237589684385, 12.672985451743086, 11.878324316468097, 10.903731033993058, 10.0885162160011, 10.808706454267869, 11.682344736489075, 12.653545563930203, 13.526474161730915, 13.492603603167797, 12.709023008583689, 11.74839242521227, 10.8498132799822, 9.896193669761999, 10.754776698650515, 11.75398032458602, 12.717513672815045, 13.602010674052629, 14.534970074454542], [14.655631432546691, 13.788107758878745, 12.859883425276431, 11.841552988144244, 10.90203560654641, 11.768899300151187, 12.73626081471879, 13.603361373533225, 14.568971711782954, 14.399029155261802, 13.470289680737855, 12.512857617978748, 11.63761997458148, 10.749392403865896, 9.959950970885856, 9.161437306581982, 9.94366908353237, 10.75431309606915, 11.755430552179707, 12.668996387139462, 13.65316810539941, 14.558321305852516, 13.749568841954789, 12.809223031692714, 11.831189820053009, 12.709098626405115, 13.69103718960585, 14.672564571823873, 14.507442812397855, 13.570761371572564, 12.570613612302862, 11.577974149552196, 10.645297410683298, 9.815357196644696, 8.95169481085453, 8.196680683183368, 8.98362130780998, 9.773860672363242, 10.727810845934044, 11.650347046407955, 12.786978270913133, 13.625289712381246, 14.567912579224021, 13.774234985545892, 12.776843045615207, 13.67492020010762, 14.6533291972289, 14.444083663402045, 13.485265426842155, 12.568859482023116, 11.632780456429769, 10.631594257521382, 9.60746816559881, 8.7769297487636, 7.977265193066656, 7.166253912614606, 8.012571761046154, 8.82980289567692, 9.769315352859087, 10.691079261000874, 11.774659162272572, 12.66753536148706, 13.630701215290808, 14.683103219732399, 13.795466845207017, 14.652562803139867, 14.523481348797239, 13.493847776772922, 12.510039806090028, 11.523911504753098, 10.566530433371721, 9.58036646741858, 8.621901982680047, 7.834593711003002, 6.942224321292502, 6.2165650508026715, 7.001757152933954, 7.853851529909951, 8.874049197559623, 9.720335479780918, 10.72936756118441, 11.675089346838652, 12.65292842592446, 13.64442710402943, 14.575122237728777, 14.519067008032767, 13.589389118459248, 12.550549833640037, 11.596694205511076, 10.623224662985328, 9.593868020217107, 8.644819507570265, 7.678302775345455, 6.850019629284176, 5.892850124301501, 5.1665779857144525, 6.006272788267296, 6.922107964774774, 7.855143453341575, 8.769062060238348, 9.667257829536084, 10.667911070520864, 11.692427606089218, 12.694945327027652, 13.62258334019167, 13.738332435030808, 12.770525704921162, 11.75158074211885, 10.725410116446248, 9.655954931364185, 8.652079927924266, 7.707884848992447, 6.713258983292432, 5.848806076897945, 4.872445965588461, 4.116753510353693, 4.964870335423022, 5.886093525928541, 6.854013829788812, 7.711505323605419, 8.763957997245502, 9.703914856854306, 10.675108871573, 11.693650500648216, 12.65664386440356, 12.77565036868458, 11.793737049091838, 10.742455910537402, 9.780302699992065, 8.761771437632403, 7.728893117018841, 6.762496234937907, 5.768296869308631, 4.825174126890117, 3.893865606705662, 3.0462413367088854, 3.8902921634101766, 4.833118503785032, 5.81272620535484, 6.741792033879372, 7.833329365265142, 8.906451231579195, 9.850973258714516, 10.83919023797466, 11.73124318373751, 11.802107931380512, 10.762635480251769, 9.78564295767051, 8.82735888923444, 7.767135148768847, 6.757384984967026, 5.781188228749407, 4.78303350446456, 3.8448288696894473, 2.9202969407378263, 1.9761589607878394, 2.9235788801067075, 3.907864470661983, 4.863110295707605, 5.8726562617729, 6.9557139512774455, 7.993405383762884, 8.88291046183606, 9.849761389062028, 10.805419525321582, 10.847735063646429, 9.782635356659343, 8.847111451823913, 7.866842784256229, 6.8434943555589705, 5.825580538724846, 4.786619535487294, 3.8070463898453726, 2.8805456113229377, 1.9258049563133568, 0.9983550702597737, 1.932368881674026, 2.89796514774608, 3.9431555902080433, 4.98386204727188, 6.0158655137344965, 6.934826068391537, 7.935447970045175, 8.92952416376866, 9.872393494440919, 9.90454248305332, 8.96825335924375, 7.937151910437664, 6.9479254690063055, 6.018087633785097, 4.952378089062124, 4.006387899646556, 2.9990450208399047, 1.9290473076384993, 0.9276269695092073, 0.0, 1.0099251130551625, 1.9906867872105045, 3.058351743067667, 4.088985306205865, 5.043270304533014, 5.990017898519366, 7.011120461667454, 8.041197588128375, 9.067237426095184, 9.995602892425003, 9.943262525831575, 8.983978012072317, 7.964979534250681, 6.9202554053438785, 5.9403126157782244, 4.920092683862096, 3.927571829105295, 2.8638357166474364, 1.9643181385478843, 1.069602231985851, 2.0304666856499365, 3.051171783667592, 3.983722176879181, 4.985132668633516, 5.974767914810808, 6.999870452089061, 7.993598477661793, 9.012703092414595, 10.039445187506086, 11.049488797457416, 10.945250818244608, 9.91534964754726, 8.971384751603575, 7.905831502319518, 6.867422599072261, 5.873894144651344, 4.842501934481487, 3.8345091762738157, 3.0050947263064174, 2.0906589341251944, 2.9840097204521885, 4.018374107404767, 5.022468454858004, 5.955940572766718, 6.803640541024189, 7.869676607764809, 8.915422267792213, 9.84953403221459, 10.905175871145214, 11.868518549204904, 11.73017206339466, 10.735372909610845, 9.719959059846719, 8.704180905514336, 7.771379027854097, 6.731679325622983, 5.76772005782404, 4.822994163256174, 3.9684821297255226, 3.0463530981619544, 3.985683066798325, 4.961790196921433, 5.896208451754528, 6.88129855517791, 7.748023331456846, 8.719587348371972, 9.792573857537498, 10.78213264098658, 11.786976474141868, 12.80843973301359, 12.619687865242028, 11.551366897092361, 10.602131793077186, 9.661359786138942, 8.610957944848417, 7.683112995430777, 6.715034186377204, 5.7562341388520295, 4.924062402754224, 3.9714351553501053, 4.932441439790411, 5.906836541164489, 6.899505847396509, 7.835782604326099, 8.717386053422125, 9.707200087172303, 10.747836859727995, 11.82128410419137, 12.75671145913297, 13.74788957582799, 13.56267001085508, 12.577210394787647, 11.629648648372722, 10.59131976703208, 9.540233473850124, 8.644484038060575, 7.685538565267343, 6.806900778270202, 5.909574837977926, 5.024878694789475, 5.863662750782727, 6.838708191041916, 7.788156213331721, 8.7209529181549, 9.697652447299241, 10.643745847638002, 11.7057598878504, 12.67700072011443, 13.70449431776602, 14.674340185916465, 14.491308317984133, 13.542298916232594, 12.605358680723752, 11.615429054131264, 10.586723142820878, 9.624859170919638, 8.735814274673285, 7.851828993126284, 6.876047818381274, 5.95792692678509, 6.877950730196371, 7.853331689212748, 8.750588345954647, 9.709071456976124, 10.638452989602145, 11.602884964514361, 12.570841083870082, 13.526184001480837, 13.1625548594625, 13.919228877643286, 14.709451130869772, 14.539235035078633, 13.575480614100176, 12.598310565141166, 11.533266724534325, 10.59237472347627, 9.746439018868099, 8.871639829410991, 7.888643709592033, 6.916781459287426, 7.913556622405501, 8.850695250792196, 9.81395157126678, 10.747464801871356, 11.68484196665085, 12.654104152147799, 13.500642557274846, 13.006868726758585, 12.120204575321225, 12.866659014998378, 13.777474994764717, 14.474750466614086, 14.414274449766555, 13.486123267287526, 12.485081055662894, 11.561438927586057, 10.786653617522212, 9.821969802936373, 8.829851378293773, 7.967222159149901, 8.896615757472228, 9.826252067953533, 10.81529730228054, 11.749971730846404, 12.662116662828456, 13.66488324101336, 12.788324248123006, 12.011876826881926, 11.11968348594598, 11.914614576352855, 12.756478764200503, 13.534968947741998, 14.469667166119368, 14.455564156130592, 13.473912501925453, 12.566942621876194, 11.747316423427336, 10.847985093085413, 9.840708739483539, 8.900403740295374, 9.8372806745729, 10.800766215610604, 11.749791310900571, 12.70290309851325, 13.598157746921522, 12.751610620175178, 11.745358482233879, 10.95069734695889, 10.102164663715705, 10.97705884358702, 11.697249081853789, 12.570887364074995, 13.542088191516124, 14.415016789316835, 14.420230572677005, 13.636649978092894, 12.676019394721479, 11.777440249491407, 10.823820639271206, 9.874395370246074, 10.87359899618158, 11.837132344410604, 12.721629345648187, 13.6545887460501], [13.661933878666224, 12.794410204998277, 11.866185871395963, 10.92025444270532, 11.767125249310599, 12.673562692815244, 13.640924207382847, 14.52700594835185, 15.546235438600451, 15.309177878458454, 14.380438403934507, 13.4230063411754, 12.547768697778132, 11.659541127062544, 10.870099694082507, 10.064138775117657, 9.019493459270196, 9.830137471806978, 10.831254927917534, 11.7420323055479, 12.659470551518941, 13.548396192797354, 12.828270296515866, 11.887924486253791, 12.696279462817198, 13.613762019069172, 14.595700582269908, 15.596209146642497, 15.417591535594507, 14.480910094769216, 13.480762335499515, 12.488122872748848, 11.55544613387995, 10.725505919841344, 9.86184353405118, 9.099382151719043, 8.059445683547805, 8.849685048101069, 9.803635221671872, 10.723382964816393, 11.77705315785797, 12.615364599326083, 13.557987466168859, 12.908379233222467, 13.641932688379397, 14.579583592771677, 15.557992589892956, 15.354232386598698, 14.395414150038807, 13.479008205219769, 12.54292917962642, 11.541742980718034, 10.517616888795462, 9.687078471960248, 8.887413916263306, 8.076402635811254, 7.088396136783979, 7.9056272714147475, 8.845139728596914, 9.764115179409313, 10.76473404921741, 11.657610248431897, 12.620776102235645, 13.673178106677234, 14.550830516350821, 15.4952039846722, 15.43363007199389, 14.403996499969574, 13.42018852928668, 12.43406022794975, 11.476679156568371, 10.490515190615232, 9.5320507058767, 8.744742434199651, 7.852373044489152, 7.12671377399932, 6.07758152867178, 6.929675905647778, 7.949873573297451, 8.793371398189356, 9.719442448129248, 10.66516423378349, 11.643003312869297, 12.634501990974268, 13.565197124673615, 14.492379686999893, 14.499537841655899, 13.460698556836688, 12.506842928707727, 11.533373386181978, 10.504016743413757, 9.554968230766917, 8.588451498542106, 7.760168352480826, 6.80299884749815, 6.076726708911101, 5.082097164005122, 5.997932340512601, 6.928179371750011, 7.842097978646785, 8.657332716480921, 9.657985957465701, 10.682502493034056, 11.68502021397249, 12.612658227136507, 13.650050155553126, 13.680674428117813, 12.661729465315501, 11.635558839642899, 10.566103654560836, 9.562228651120916, 8.618033572189098, 7.623407706489083, 6.758954800094594, 5.78259468878511, 5.0269022335503415, 4.040694711160848, 4.961917901666368, 5.927049748197248, 6.784541242013855, 7.754032884190339, 8.693989743799143, 9.665183758517838, 10.683725387593054, 11.646718751348397, 12.695404535079957, 12.703885772288489, 11.652604633734052, 10.690451423188716, 9.671920160829051, 8.639041840215492, 7.6726449581345575, 6.678445592505281, 5.735322850086766, 4.804014329902312, 3.956390059905535, 2.966116539148002, 3.9089428795228582, 4.885762123763277, 5.814827952287809, 6.823404252209979, 7.896526118524033, 8.841048145659354, 9.829265124919498, 10.721318070682347, 11.661054332093146, 11.672784203448419, 10.69579168086716, 9.73750761243109, 8.677283871965496, 7.667533708163677, 6.691336951946058, 5.693182227661211, 4.754977592886097, 3.830445663934476, 2.886307683984489, 1.9994032558445332, 2.9809003890704204, 3.9361462141160417, 4.945692180181338, 5.945788838222283, 6.983480270707721, 7.872985348780897, 8.839836276006865, 9.79549441226642, 10.777748020358144, 10.692784079855993, 9.757260175020564, 8.776991507452879, 7.75364307875562, 6.735729261921495, 5.696768258683943, 4.717195113042022, 3.7906943345195874, 2.8359536795100064, 1.9085037934564233, 0.9744899820421709, 1.9140595756980687, 2.9592500181600316, 3.9999564752238683, 5.005940400679334, 5.9249009553363745, 6.925522856990012, 7.919599050713496, 8.862468381385757, 9.843739389964124, 9.97817847229891, 8.947077023492826, 7.957850582061468, 7.028012746840259, 5.962303202117287, 5.016313012701718, 4.008970133895067, 2.938972420693662, 1.9375520825643697, 1.0099251130551625, 0.0, 0.980761674155342, 2.0484266300125045, 3.0790601931507027, 4.033345191477851, 4.980092785464204, 6.001195348612291, 7.031272475073212, 8.057312313040022, 8.98567777936984, 10.060504077113686, 9.99390312512748, 8.974904647305843, 7.930180518399041, 6.950237728833387, 5.930017796917259, 4.9374969421604575, 3.873760829702599, 2.9610624418814733, 2.011318692712694, 1.020541572594774, 2.0412466706124293, 2.9737970638240183, 3.9752075555783533, 4.964842801755646, 5.989945339033898, 6.983673364606631, 8.002777979359433, 9.029520074450923, 10.039563684402253, 11.055163063057137, 10.925274760602424, 9.981309864658735, 8.91575661537468, 7.877347712127423, 6.883819257706507, 5.85242704753665, 4.844434289328978, 3.930219068317281, 2.9755943016819293, 1.974084607397026, 3.008448994349605, 4.012543341802841, 4.946015459711555, 5.876676459432626, 6.9427125261732465, 7.952159004040814, 8.886270768463191, 9.941912607393816, 10.905255285453505, 11.875389472921935, 11.745298022666008, 10.729884172901881, 9.714106018569499, 8.78130414090926, 7.741604438678146, 6.777645170879203, 5.832919276311337, 4.893536140778879, 3.9312884657186893, 2.9757579537431624, 3.9518650838662697, 4.886283338699364, 5.8713734421227475, 6.821059249865282, 7.792623266780408, 8.865609775945934, 9.818869377235181, 10.82371321039047, 11.84517646926219, 12.820657681344114, 12.561292010147524, 11.612056906132349, 10.671284899194104, 9.62088305790358, 8.69303810848594, 7.724959299432366, 6.766159251907192, 5.849116413807581, 4.856370522906841, 3.922516326735249, 4.896911428109327, 5.8895807343413455, 6.825857491270937, 7.79042197183056, 8.78023600558074, 9.820872778136431, 10.89036301245948, 11.793448195381572, 12.784626312076592, 13.74200488815527, 13.58713550784281, 12.639573761427885, 11.601244880087242, 10.550158586905287, 9.654409151115738, 8.695463678322506, 7.770426036615358, 6.834628849031283, 5.8933555207752875, 4.853737637727566, 5.8287830779867535, 6.7782311002765585, 7.711027805099738, 8.770688365707677, 9.716781766046438, 10.778795806258836, 11.750036638522866, 12.777530236174456, 13.747376104324902, 14.728149105627015, 14.552224029287757, 13.615283793778914, 12.625354167186426, 11.59664825587604, 10.6347842839748, 9.745739387728449, 8.81535425147144, 7.80110182943463, 6.8264037527709025, 5.8680256171412095, 6.8434065761575855, 7.740663232899484, 8.699146343920962, 9.711488908010582, 10.675920882922798, 11.643877002278519, 12.599219919889274, 13.593208537524141, 14.659044905698206, 15.61959985406642, 15.549160148133794, 14.58540572715534, 13.60823567819633, 12.543191837589488, 11.602299836531433, 10.756364131923263, 9.822358024915179, 8.81228828441066, 7.785258285273239, 6.90363150935034, 7.8407701377370325, 8.80402645821162, 9.737539688816195, 10.75787788505929, 11.727140070556235, 12.573678475683282, 12.08269310249641, 13.0229060438569, 13.776807738195028, 14.687623717961365, 15.384899189810739, 15.424199562821718, 14.496048380342689, 13.495006168718056, 12.57136404064122, 11.710298192340838, 10.745614377754999, 9.753495953112399, 8.832311801914088, 7.90291820359176, 8.832554514073065, 9.821599748400072, 10.751098849752177, 11.735152581236896, 12.737919159421796, 11.864148623860833, 11.087701202619751, 12.022384954481655, 12.824763299549506, 13.666627487397152, 14.44511767093865, 15.37981588931602, 15.465489269185754, 14.483837614980615, 13.576867734931358, 12.670960998245961, 11.771629667904039, 10.764353314302165, 9.765493383059562, 8.843583120692433, 9.807068661730137, 10.756093757020103, 11.709205544632782, 12.671193665329962, 11.827434995913006, 10.821182857971706, 10.026521722696716, 11.00486613225138, 11.88720756678367, 12.607397805050438, 13.481036087271647, 14.452236914712776, 15.325165512513488, 15.430155685732167, 14.635147910166438, 13.599663969540103, 12.682103642155464, 11.728484031935263, 10.739485013010261, 9.879901442301112, 10.843434790530136, 11.72793179176772, 12.660891192169633], [12.870867895460629, 12.003344221792682, 11.075119888190368, 11.90101611686066, 12.747886923465938, 13.654324366970584, 14.621685881538188, 15.507767622507192, 16.526997112755794, 16.233582064031065, 15.304842589507116, 14.347410526748009, 13.47217288335074, 12.583945312635153, 11.794503879655116, 10.974275170378167, 9.92286171569108, 8.96013323223765, 9.904391354974694, 10.761270631392557, 11.868404568313347, 12.567634518642011, 12.111425708850348, 12.86868616040913, 13.677041136972537, 14.594523693224513, 15.576462256425248, 16.57697082079784, 16.341995721167113, 15.405314280341825, 14.405166521072124, 13.412527058321457, 12.47985031945256, 11.649910105413953, 10.78624771962379, 10.023786337291652, 8.983849869120414, 7.979680808531741, 8.876771648729031, 9.74262129066105, 10.937183794890787, 11.634602925170741, 12.577225792013516, 13.577617201991501, 14.575009141922186, 15.492084913549109, 16.356189428725347, 16.2786365721713, 15.319818335611412, 14.403412390792374, 13.467333365199027, 12.466147166290643, 11.442021074368071, 10.611482657532857, 9.811818101835915, 9.000806821383863, 8.012800322356588, 7.035623031845419, 7.918276155654074, 8.78335350525397, 9.924864686250226, 10.676848574276555, 11.640014428080303, 12.692416432521892, 13.57006884219548, 14.514442310516861, 15.416254383531198, 15.32840068554218, 14.344592714859285, 13.358464413522356, 12.401083342140979, 11.414919376187841, 10.456454891449308, 9.66914661977226, 8.77677723006176, 8.051117959571929, 7.001985714244388, 6.059671666078449, 6.989792072577771, 7.812609724034013, 8.879573085162065, 9.684402559628147, 10.662241638713954, 11.653740316818928, 12.584435450518274, 13.511618012844554, 14.441295902418073, 14.385102742409295, 13.431247114280334, 12.457777571754585, 11.428420928986364, 10.479372416339526, 9.512855684114715, 8.684572538053434, 7.727403033070759, 7.001130894483711, 6.00650134957773, 5.127928100943272, 5.947417697594669, 6.861336304491442, 7.8174633535137374, 8.677224283310359, 9.701740818878715, 10.704258539817149, 11.631896552981166, 12.669288481397786, 13.63709521150743, 13.586133650888112, 12.559963025215506, 11.490507840133443, 10.486632836693524, 9.542437757761705, 8.547811892061691, 7.683358985667203, 6.706998874357719, 5.951306419122951, 4.965098896733457, 4.091913662097039, 4.946288074041906, 5.803779567858513, 6.773271210034998, 7.713228069643802, 8.684422084362497, 9.702963713437713, 10.665957077193056, 11.714642860924616, 12.696556180517359, 12.577008819306663, 11.614855608761326, 10.596324346401662, 9.5634460257881, 8.597049143707165, 7.60284977807789, 6.659727035659375, 5.728418515474921, 4.880794245478144, 3.890520724720612, 3.03893863995353, 3.9050004496079342, 4.834066278132466, 5.842642578054638, 6.915764444368691, 7.860286471504013, 8.848503450764158, 9.740556396527007, 10.680292657937805, 11.719765109066548, 11.62019586643977, 10.6619117980037, 9.601688057538107, 8.591937893736286, 7.6157411375186665, 6.61758641323382, 5.679381778458707, 4.754849849507085, 3.8107118695570987, 2.923807441417143, 2.000138714915078, 2.9553845399606993, 3.9649305060259947, 4.965027164066942, 6.002718596552381, 6.892223674625557, 7.859074601851525, 8.81473273811108, 9.796986346202804, 10.803352899540602, 10.681664360593174, 9.70139569302549, 8.67804726432823, 7.660133447494105, 6.621172444256553, 5.641599298614632, 4.715098520092197, 3.760357865082616, 2.832907979029033, 1.8988941676147806, 0.9332979015427266, 1.9784883440046896, 3.019194801068526, 4.0251787265239924, 4.944139281181033, 5.944761182834672, 6.938837376558156, 7.881706707230416, 8.862977715808784, 9.799266839618353, 9.927838697648168, 8.93861225621681, 8.008774420995602, 6.943064876272629, 5.997074686857061, 4.98973180805041, 3.919734094849004, 2.9183137567197117, 1.9906867872105045, 0.980761674155342, 0.0, 1.0676649558571627, 2.098298518995361, 3.0525835173225095, 3.9993311113088623, 5.0204336744569495, 6.050510800917871, 7.076550638884681, 8.0049161052145, 9.079742402958345, 10.039026916717603, 9.955666321461186, 8.910942192554383, 7.930999402988729, 6.910779471072601, 5.9182586163158, 4.854522503857941, 3.9418241160368153, 2.992080366868036, 2.001303246750116, 1.0604849964570873, 1.9930353896686768, 2.9944458814230117, 3.9840811276003043, 5.009183664878557, 6.002911690451289, 7.02201630520409, 8.048758400295581, 9.058802010246913, 10.074401388901796, 10.970398552192545, 10.962071538814078, 9.896518289530022, 8.858109386282766, 7.864580931861849, 6.833188721691992, 5.825195963484321, 4.910980742472623, 3.9563559758372717, 2.954846281552368, 2.1170259077819464, 3.0317816676474996, 3.9652537855562136, 4.8959147852772835, 5.961950852017904, 6.971397329885473, 7.905509094307852, 8.961150933238477, 9.924493611298166, 10.894627798766596, 11.88942695255041, 11.710645847057226, 10.694867692724843, 9.762065815064604, 8.72236611283349, 7.758406845034545, 6.813680950466679, 5.874297814934222, 4.912050139874031, 3.9565196278985044, 3.1299936099131593, 4.0492820582301965, 4.890611767967406, 5.84029757570994, 6.811861592625066, 7.884848101790591, 8.83810770307984, 9.842951536235129, 10.86441479510685, 11.839896007188775, 12.886594421514275, 12.592818580287691, 11.652046573349446, 10.601644732058922, 9.673799782641282, 8.705720973587708, 7.7469209260625345, 6.829878087962923, 5.837132197062182, 4.903278000890591, 4.075039954156217, 5.052579453872178, 5.845095817115595, 6.809660297675218, 7.7994743314253965, 8.840111103981087, 9.909601338304139, 10.812686521226231, 11.80386463792125, 12.76124321399993, 13.791453212260937, 13.620335435583227, 12.582006554242584, 11.53092026106063, 10.635170825271079, 9.676225352477847, 8.7511877107707, 7.815390523186625, 6.874117194930629, 5.834499311882907, 5.006911604033643, 5.956359626323447, 6.889156331146626, 7.789926691552335, 8.736020091891096, 9.798034132103494, 10.769274964367524, 11.796768562019114, 12.76661443016956, 13.747387431471672, 14.696396833223211, 14.596045467934257, 13.606115841341769, 12.577409930031381, 11.615545958130141, 10.726501061883788, 9.796115925626783, 8.781863503589973, 7.807165426926244, 6.848787291296551, 6.021535102204476, 6.918791758946373, 7.8772748699678505, 8.730727233855239, 9.695159208767455, 10.663115328123176, 11.618458245733931, 12.612446863368799, 13.678283231542864, 14.681532115595457, 15.693332952069248, 15.566167401310679, 14.588997352351669, 13.523953511744828, 12.583061510686774, 11.737125806078602, 10.803119699070521, 9.793049958566002, 8.766019959428581, 7.884393183505681, 7.018898663783923, 7.982154984258508, 8.915668214863082, 9.777116210903948, 10.746378396400893, 11.59291680152794, 12.604569115893197, 13.562704518670845, 14.622304161798795, 15.612027903533974, 16.309303375383347, 16.40496123697706, 15.47681005449803, 14.475767842873397, 13.55212571479656, 12.69105986649618, 11.726376051910341, 10.734257627267741, 9.813073476069428, 8.8836798777471, 8.030849803975377, 9.019895038302383, 9.929227375799064, 10.754390907081554, 11.757157485266454, 10.994144384291506, 11.991069459040636, 12.932521349742165, 13.749167485122115, 14.591031672969761, 15.369521856511259, 16.30422007488863, 16.446250943341095, 15.464599289135956, 14.557629409086697, 13.651722672401304, 12.752391342059381, 11.745114988457507, 10.746255057214903, 9.824344794847773, 9.016002678524542, 9.965027773814509, 10.918139561427187, 11.69043199117462, 10.900571422970165, 9.951178618402379, 10.9298899791176, 11.91500252751189, 12.81161175235628, 13.531801990623046, 14.405440272844256, 15.376641100285385, 16.2495696980861, 16.410917359887506, 15.61590958432178, 14.580425643695445, 13.662865316310805, 12.709245706090604, 11.720246687165602, 10.860663116456452, 10.052368807324541, 10.936865808562125, 11.869825208964038], [11.870303207101799, 11.042112913373904, 11.861161635483336, 12.76386410086321, 13.610734907468487, 14.517172350973134, 15.484533865540737, 16.394810534081206, 17.414040024329807, 17.298029138490836, 16.36928966396689, 15.411857601207782, 14.536619957810514, 13.648392387094928, 12.847897868254933, 11.856215575802599, 10.804802121115513, 9.842073637662082, 8.964166179408306, 9.82104545582617, 10.867839879954516, 11.499969562784848, 12.472610142277187, 13.412955952539262, 14.39533816428115, 15.390241531394448, 16.25081648049123, 17.27920513165372, 17.406442795626887, 16.469761354801598, 15.469613595531897, 14.47697413278123, 13.544297393912332, 12.714357179873728, 11.850694794083562, 10.932459435470928, 9.89252296729969, 8.861621213956173, 7.936546473162642, 8.802396115094663, 9.869518839033624, 10.566937969313578, 11.509560836156354, 12.509952246134338, 13.507344186065023, 14.424419957691944, 15.288524472868183, 16.332635617188338, 16.384265410071187, 15.467859465252149, 14.5317804396588, 13.530594240750416, 12.506468148827844, 11.675929731992632, 10.876265176295687, 9.986775098182424, 8.981248222201305, 7.917563437269852, 6.978050980087685, 7.843128329687581, 8.857199730393063, 9.609183618419392, 10.57234947222314, 11.62475147666473, 12.502403886338318, 13.446777354659696, 14.348589427674034, 15.37822299969835, 15.40903978931906, 14.42291148798213, 13.465530416600751, 12.479366450647614, 11.520901965909081, 10.733593694232034, 9.841224304521534, 9.03708623637049, 7.984401250220468, 6.970168243750976, 6.049566897011382, 6.8723845484676245, 7.811908129304901, 8.616737603770984, 9.594576682856792, 10.586075360961765, 11.516770494661111, 12.44395305698739, 13.373630946560908, 14.41247023138012, 14.495694188740107, 13.522224646214358, 12.492868003446137, 11.543819490799299, 10.577302758574488, 9.749019612513209, 8.791850107530532, 8.056269511499053, 7.028251737193742, 6.038424678615799, 5.00719252202828, 5.9211111289250535, 6.7497983976565745, 7.609559327453196, 8.634075863021552, 9.636593583959986, 10.564231597124003, 11.601623525540623, 12.569430255650268, 13.601820802011577, 13.624410099675279, 12.554954914593216, 11.551079911153296, 10.606884832221478, 9.612258966521464, 8.747806060126976, 7.771445948817491, 7.006445036138294, 5.986849284349468, 5.002410239769566, 4.006062898475517, 4.863554392292124, 5.705606254177835, 6.645563113786639, 7.616757128505334, 8.63529875758055, 9.598292121335893, 10.646977905067454, 11.628891224660196, 12.601386269650055, 12.679302683221099, 11.660771420861435, 10.627893100247872, 9.661496218166938, 8.667296852537664, 7.724174110119147, 6.792865589934693, 5.9359328624934875, 4.912271112336622, 3.969444771961766, 2.9647752740415454, 3.8938411025660775, 4.774977622197475, 5.8480994885115285, 6.792621515646849, 7.780838494906993, 8.672891440669842, 9.61262770208064, 10.652100153209384, 11.644573316783163, 11.726358872463473, 10.66613513199788, 9.65638496819606, 8.68018821197844, 7.682033487693593, 6.743828852918479, 5.819296923966857, 4.875158944016871, 3.954690779995207, 2.9704051894399313, 2.01515936439431, 2.961301718403082, 3.8973622082097794, 4.935053640695217, 5.824558718768393, 6.791409645994361, 7.747067782253915, 8.729321390345639, 9.735687943683438, 10.671211848518867, 10.76584276748526, 9.742494338788001, 8.724580521953877, 7.685619518716325, 6.706046373074404, 5.779545594551969, 4.824804939542388, 3.897355053488805, 2.9633412420745526, 1.9977449760024986, 0.9525545335405354, 1.993260990604372, 2.9575137706668295, 3.8764743253238696, 4.877096226977508, 5.871172420700992, 6.814041751373252, 7.79531275995162, 8.731601883761188, 9.762703332567273, 10.006277212073972, 9.076439376852763, 8.01072983212979, 7.064739642714223, 6.057396763907572, 4.987399050706166, 3.985978712576874, 3.058351743067667, 2.0484266300125045, 1.0676649558571627, 0.0, 1.0306335631381984, 1.9849185614653466, 2.9316661554516994, 3.9527687185997866, 4.982845845060708, 6.008885683027518, 6.937251149357338, 8.012077447101182, 8.97136196086044, 9.990360438682076, 9.978607148411545, 8.998664358845891, 7.978444426929763, 6.985923572172962, 5.922187459715103, 4.9484794044836224, 3.9987356553148428, 3.0079585351969227, 1.9430404448539191, 0.9253704338115141, 1.926780925565849, 2.9164161717431414, 3.941518709021394, 4.935246734594126, 5.954351349346927, 6.981093444438418, 7.99113705438975, 9.006736433044633, 9.902733596335384, 10.973901447461225, 10.95564721181445, 9.913096034752819, 8.919567580331902, 7.888175370162045, 6.880182611954374, 5.91763603091943, 4.963011264284078, 3.9615015699991747, 2.9834136079081786, 1.9641167117903369, 2.897588829699051, 3.8922859976543704, 4.9583220643949915, 5.90373237402831, 6.837844138450689, 7.893485977381313, 8.856828655441003, 9.826962842909433, 10.821761996693247, 11.837175846457374, 11.749854341194895, 10.817052463534656, 9.777352761303542, 8.813393493504599, 7.8686675989367325, 6.880953103381028, 5.918705428320838, 4.892142487329235, 3.916035357206128, 2.9816171023730336, 3.822946812110243, 4.900072400143551, 5.871636417058677, 6.888891008729004, 7.770442747222678, 8.775286580377966, 9.796749839249687, 10.772231051331612, 11.818929465657112, 12.768164569672287, 12.707033221819499, 11.656631380528975, 10.728786431111335, 9.760707622057762, 8.790720543752203, 7.836533376409729, 6.831919904149369, 5.838900860321322, 4.861081701449185, 3.984914498015015, 4.777430861258432, 5.869435122108829, 6.859249155859008, 7.899885928414699, 8.841936382446976, 9.745021565369068, 10.736199682064088, 11.693578258142766, 12.723788256403774, 13.688541268216392, 13.636993202712636, 12.585906909530681, 11.619225649683882, 10.66028017689065, 9.703234902552072, 8.767437714967997, 7.80974005436136, 6.770122171313639, 5.792953351326612, 4.911560683538899, 5.835002430318951, 6.849701515985946, 7.795794916324707, 8.857808956537104, 9.80060033094705, 10.761630689961486, 11.73147655811193, 12.694678208810279, 13.643687610561818, 14.664251300567422, 14.612628694717966, 13.561464754444184, 12.599600782542945, 11.710555886296593, 10.748163117408154, 9.733910695371344, 8.742788286356975, 7.7844101507272825, 6.807576849497444, 5.873992816161825, 6.832475927183302, 7.79050205828885, 8.754934033201067, 9.722890152556788, 10.678233070167543, 11.67222168780241, 12.738058055976474, 13.709163034797989, 14.640623729407857, 15.656563326935153, 15.573052176764474, 14.508008336157632, 13.567116335099577, 12.721180630491407, 11.73874255850125, 10.728672817996731, 9.70164281885931, 8.796265658716777, 7.804940411076891, 6.93735604147396, 7.870869272078535, 8.836891035337558, 9.806153220834506, 10.652691625961552, 11.664343940326809, 12.622479343104457, 13.682078986232408, 14.641139170903044, 15.630373720976609, 16.70154656356499, 16.460864878910833, 15.4598226672862, 14.536180539209363, 13.578102778070193, 12.613418963484353, 11.621300538841753, 10.675921460071978, 9.74652786174965, 8.816891551268345, 7.987433832206584, 8.884428433014516, 9.814165731515164, 10.816932309700068, 11.603955804191083, 12.61077559429125, 13.623000432479701, 14.625850249643747, 15.568803426918532, 16.433968930971034, 17.3686671493484, 17.4303057677539, 16.44865411354876, 15.5263744012556, 14.538765583975316, 13.639434253633393, 12.628527862690014, 11.609103041217452, 10.687192778850322, 9.80204442581751, 9.00379646539573, 9.917574873068357, 10.75020681560823, 9.960346247403777, 10.83311902382681, 11.811830384542032, 12.796942932936322, 13.830677783913364, 14.596249065082821, 15.469887347304029, 16.441088174745158, 17.31401677254587, 17.39497218430031, 16.502952495895794, 15.467468555269459, 14.525713300313354, 13.572093690093153, 12.583094671168151, 11.723511100459001, 10.838410554617509, 9.975634500143347, 10.869260520605208], [10.897399568373688, 11.463589112032388, 12.454671489798558, 13.399689735785358, 14.339207117383193, 15.349504597346002, 16.224656595075917, 17.190658086747824, 18.209887576996426, 18.328662701629035, 17.399923227105088, 16.44249116434598, 15.56725352094871, 14.600365232021352, 13.667543863643795, 12.675861571191462, 11.624448116504375, 10.661719633050945, 9.783812174797166, 8.877907939330731, 9.894936241226405, 10.519033302482473, 11.491673881974812, 12.432019692236887, 13.414401903978774, 14.409305271092073, 15.269880220188856, 16.298268871351343, 17.313106383766105, 17.500394917939797, 16.500247158670096, 15.507607695919427, 14.57493095705053, 13.681477778409716, 12.730831643776625, 11.752105430859789, 10.712168962688551, 9.681267209345036, 8.756192468551504, 7.859258598599224, 8.88858257873125, 9.586001709011203, 10.528624575853978, 11.529015985831963, 12.526407925762648, 13.443483697389569, 14.307588212565808, 15.35169935688596, 16.31051759344585, 16.498493028390346, 15.562414002796997, 14.561227803888613, 13.537101711966042, 12.706563295130827, 11.906898739433885, 10.864351117856026, 9.800894217590168, 8.737209432658714, 7.797696975476547, 6.899990813192144, 7.876263470090688, 8.628247358117017, 9.591413211920765, 10.643815216362356, 11.521467626035943, 12.465841094357321, 13.367653167371659, 14.397286739395975, 15.38109471007887, 15.453545051120326, 14.496163979738949, 13.510000013785811, 12.551535529047278, 11.76422725737023, 10.871857867659731, 9.952080376924117, 8.899395390774096, 7.8851623843046035, 6.869212892400244, 5.929247031972187, 6.830971869002526, 7.635801343468609, 8.613640422554417, 9.60513910065939, 10.535834234358736, 11.463016796685014, 12.392694686258533, 13.431533971077744, 14.385389599206706, 14.552858209352555, 13.523501566584335, 12.574453053937496, 11.607936321712685, 10.779653175651404, 9.82248367066873, 8.971263652052679, 7.943245877747367, 6.953418819169427, 5.9221866625819075, 4.977973612429616, 5.7688621373541995, 6.628623067150821, 7.653139602719178, 8.65565732365761, 9.583295336821628, 10.590977723263268, 11.558784453372914, 12.579877538093305, 13.56744619487127, 13.585588477731413, 12.581713474291494, 11.637518395359676, 10.642892529659662, 9.778439623265173, 8.80207951195569, 7.92143917669192, 6.9018434249030935, 5.917404380323194, 4.921057039029145, 3.9204168757966866, 4.72466999387546, 5.664626853484264, 6.635820868202959, 7.654362497278175, 8.617355861033518, 9.62373139827167, 10.605644717864411, 11.570752706511856, 12.52516763283866, 12.691404983999632, 11.65852666338607, 10.692129781305136, 9.697930415675861, 8.754807673257346, 7.823499153072891, 6.850927003047113, 5.827265252890248, 4.884438912515392, 3.8797694145951724, 2.9507035860706403, 3.7940413618950997, 4.858506625311198, 5.761987952508651, 6.750204931768795, 7.6422578775316445, 8.581994138942443, 9.621466590071186, 10.613939753644964, 11.572223822081034, 11.696768695136077, 10.687018531334257, 9.710821775116637, 8.71266705083179, 7.774462416056677, 6.8499304871050555, 5.858547968270686, 4.911128048951817, 3.9268424583965422, 2.971596633350921, 1.9620506672856257, 2.9164259479074044, 3.9044200775570186, 4.793925155630195, 5.760776082856163, 6.716434219115717, 7.698687827207442, 8.70505438054524, 9.64057828538067, 10.620846952948355, 10.7731279019262, 9.755214085092076, 8.716253081854523, 7.736679936212602, 6.810179157690167, 5.855438502680586, 4.927988616627003, 3.993974805212751, 3.028378539140697, 1.9831880966787339, 0.9940099394869156, 1.9642082666838179, 2.8458407621856714, 3.8464626638393096, 4.840538857562794, 5.783408188235054, 6.764679196813422, 7.700968320622991, 8.732069769429076, 9.721296210860434, 10.10707293999096, 9.041363395267988, 8.09537320585242, 7.08803032704577, 6.0180326138443645, 5.016612275715072, 4.088985306205865, 3.079060193150703, 2.098298518995361, 1.0306335631381984, 0.0, 0.9542849983271482, 1.9010325923135012, 2.9221351554615884, 3.9522122819225096, 4.978252119889319, 5.906617586219139, 6.981443883962983, 7.94072839772224, 8.959726875543875, 10.004451004450678, 10.029297921984089, 9.009077990067961, 8.01655713531116, 6.952821022853302, 5.970364127689916, 5.020620378521137, 4.0298432584032176, 2.964925168060214, 1.947255157017809, 0.945844665263474, 1.8857826086049432, 2.9108851458831957, 3.9046131714559285, 4.92371778620873, 5.950459881300221, 6.960503491251551, 7.976102869906434, 8.872100033197183, 9.943267884323024, 10.990027101426316, 10.934980757959115, 9.941452303538199, 8.910060093368342, 7.90206733516067, 6.939520754125725, 5.984895987490374, 4.98338629320547, 3.9535152730022713, 2.9342183768844294, 1.916652569396676, 2.8930349465369143, 3.947083579368102, 4.873098810890112, 5.8072105753124905, 6.862852414243115, 7.826195092302804, 8.796329279771234, 9.791128433555048, 10.806542283319175, 11.822320437651557, 11.767341068967703, 10.727641366736588, 9.763682098937645, 8.809472667610985, 7.763471554559731, 6.80122387949954, 5.750382270653514, 4.774275140530407, 3.839856885697312, 2.842010551807868, 3.945407627777802, 4.916971644692929, 5.858257445590806, 6.73980918408448, 7.744653017239767, 8.766116276111488, 9.741597488193413, 10.788295902518913, 11.737531006534088, 12.678303013472332, 12.606919985962021, 11.679075036544381, 10.710996227490808, 9.673238994930905, 8.719051827588432, 7.690159687473646, 6.6971406436456, 5.719321484773464, 4.820971640404274, 3.7964946009560574, 4.924964009864249, 5.904584383493259, 6.888531099467746, 7.811302819308779, 8.71438800223087, 9.705566118925889, 10.662944695004567, 11.693154693265575, 12.657907705078193, 13.60826299436547, 13.523907880745199, 12.477465433008161, 11.51851996021493, 10.561474685876352, 9.625677498292276, 8.667979837685639, 7.628361954637916, 6.651193134650891, 5.747617825928158, 4.854066170016576, 5.905230403741366, 6.851323804080127, 7.913337844292525, 8.769966767808853, 9.730997126823286, 10.700842994973732, 11.66404464567208, 12.613054047423619, 13.633617737429223, 14.632372281464654, 14.419704537768464, 13.457840565867224, 12.568795669620872, 11.606402900732434, 10.592150478695624, 9.601028069681254, 8.64264993405156, 7.665816632821723, 6.7100499585510835, 5.884284442103479, 6.84603094604427, 7.810462920956486, 8.778419040312206, 9.733761957922962, 10.727750575557828, 11.754533976281602, 12.67852947165979, 13.609990166269657, 14.625929763796954, 15.603099812755964, 15.366248119481911, 14.425356118423856, 13.579420413815686, 12.59698234182553, 11.58691260132101, 10.55988260218359, 9.654505442041058, 8.663180194401171, 7.773413183863219, 6.922677786998712, 7.893753518842121, 8.861682108589925, 9.70822051371697, 10.719872828082227, 11.678008230859875, 12.737607873987827, 13.610505607764845, 14.59974015783841, 15.67091300042679, 16.59906418290582, 16.31806245061048, 15.394420322533643, 14.436342561394474, 13.471658746808634, 12.479540322166034, 11.534161243396259, 10.604767645073931, 9.675131334592626, 8.823490974595844, 7.9362369479346935, 8.871028215019725, 9.872461197455486, 10.659484691946501, 11.666304482046668, 12.67852932023512, 13.681379137399166, 14.62433231467395, 15.539521676710498, 16.476562949959433, 17.412329533367405, 17.30689389687304, 16.38461418457988, 15.397005367299597, 14.497674036957674, 13.486767646014295, 12.467342824541733, 11.545432562174604, 10.66028420914179, 9.83985360778499, 8.969383387988534, 9.807069299112792, 10.779992242792638, 11.652765019215673, 12.631476379930895, 13.616588928325184, 14.618934870165, 15.548221910009245, 16.500520910442226, 17.404141924562676, 18.34465033568407, 18.25321196762459, 17.361192279220074, 16.32570833859374, 15.383953083637635, 14.430333473417434, 13.441334454492432, 12.581750883783283, 11.69665033794179, 10.811691642532606, 9.921069035525385], [10.099442023061986, 10.665631566720686, 11.656713944486857, 12.601732190473655, 13.54124957207149, 14.478356312589302, 15.353508310319217, 16.319509801991124, 17.338739292239726, 18.27745404489144, 18.354208225432235, 17.396776162673127, 16.482585651543864, 15.554650230348498, 14.621828861970942, 13.630146569518608, 12.578733114831522, 11.616004631378091, 10.738097173124315, 9.83219293765788, 9.096978695914704, 9.721075757170771, 10.69371633666311, 11.634062146925185, 12.614596366433249, 13.538156986335373, 14.398731935432156, 15.427120586594642, 16.4419580990094, 17.44679189544872, 17.454532156997242, 16.461892694246576, 15.529215955377678, 14.635762776736863, 13.685116642103772, 12.706390429186936, 11.666453961015698, 10.635552207672182, 9.710477466878652, 8.813543596926372, 8.090625033419547, 8.788044163699501, 9.730667030542277, 10.731058440520261, 11.66894314087105, 12.572335412632869, 13.436439927809108, 14.480551072129261, 15.439369308689152, 16.480056860886894, 16.516699001124145, 15.515512802215762, 14.49138671029319, 13.660848293457978, 12.861183737761033, 11.818636116183173, 10.755179215917314, 9.69149443098586, 8.751981973803694, 7.854275811519292, 7.078305924778986, 7.830289812805315, 8.793455666609063, 9.801331977402477, 10.650319341279241, 11.594692809600621, 12.496504882614959, 13.526138454639275, 14.50994642532217, 15.4960747266591, 15.450448978066097, 14.46428501211296, 13.505820527374427, 12.71851225569738, 11.82614286598688, 10.906365375251266, 9.853680389101244, 8.839447382631752, 7.823497890727392, 6.883532030299335, 6.033014323690824, 6.837843798156907, 7.815682877242715, 8.762649270764454, 9.664685949602035, 10.591868511928315, 11.521546401501833, 12.560385686321045, 13.514241314450006, 14.487710856975754, 14.477786564911483, 13.528738052264645, 12.562221320039834, 11.733938173978554, 10.776768668995878, 9.92554865037983, 8.897530876074516, 7.907703817496574, 6.876471660909055, 5.932258610756764, 4.970904592042498, 5.830665521839119, 6.850473783490999, 7.813167493762675, 8.68713851802819, 9.63669272493612, 10.604499455045765, 11.625592539766158, 12.613161196544123, 13.5812672751258, 13.535998472618642, 12.591803393686824, 11.59717752798681, 10.732724621592322, 9.756364510282838, 8.87572417501907, 7.856128423230242, 6.871689378650341, 5.875342037356292, 4.874701874123835, 3.926712448563758, 4.866669308172562, 5.83315504897478, 6.804879886563851, 7.721199042240081, 8.66944639994452, 9.651359719537263, 10.61646770818471, 11.570882634511513, 12.595093806639039, 12.612811661713218, 11.646414779632284, 10.65221541400301, 9.709092671584495, 8.77778415140004, 7.805212001374262, 6.781550251217396, 5.838723910842541, 4.83405441292232, 3.9049885843977883, 2.9960838165833974, 3.9042216269840493, 4.807702954181503, 5.795919933441646, 6.687972879204496, 7.627709140615294, 8.667181591744036, 9.659654755317817, 10.617938823753887, 11.67816256421948, 11.641303529661405, 10.665106773443785, 9.666952049158938, 8.728747414383825, 7.804215485432204, 6.812832966597835, 5.865413047278967, 4.881127456723691, 3.9258816316780694, 2.916335665612774, 2.0636652041910004, 2.95013507922987, 3.8396401573030468, 4.806491084529014, 5.762149220788569, 6.744402828880293, 7.750769382218092, 8.686293287053521, 9.666561954621207, 10.689910383318466, 10.709499083419226, 9.670538080181673, 8.690964934539751, 7.764464156017316, 6.809723501007735, 5.882273614954151, 4.948259803539899, 3.982663537467845, 2.937473095005882, 1.948294937814064, 1.0099232683566697, 1.8915557638585232, 2.892177665512161, 3.8862538592356457, 4.8291231899079055, 5.810394198486273, 6.7466833222958424, 7.777784771101929, 8.767011212533287, 9.696849047754496, 9.995648393595136, 9.049658204179568, 8.042315325372918, 6.972317612171513, 5.970897274042221, 5.043270304533014, 4.033345191477851, 3.0525835173225095, 1.9849185614653466, 0.9542849983271482, 0.0, 0.9467475939863529, 1.96785015713444, 2.997927283595361, 4.023967121562171, 4.95233258789199, 6.027158885635835, 6.986443399395092, 8.005441877216727, 9.05016600612353, 10.030108795689182, 9.96336298839511, 8.970842133638309, 7.90710602118045, 6.924649126017065, 5.974905376848286, 4.984128256730366, 3.919210166387362, 2.901540155344957, 1.9001296635906222, 0.931497610277795, 1.9566001475560477, 2.9503281731287805, 3.9694327878815816, 4.996174882973072, 6.006218492924402, 7.021817871579286, 7.917815034870035, 8.988982885995876, 10.035742103099167, 11.055442678694533, 10.895737301865347, 9.86434509169549, 8.856352333487818, 7.893805752452874, 6.939180985817522, 5.937671291532618, 4.907800271329419, 3.8885033752115774, 2.870937567723824, 1.997812660911362, 2.9927985810409536, 3.918813812562964, 4.852925576985342, 5.908567415915966, 6.871910093975655, 7.842044281444085, 8.8368434352279, 9.852257284992026, 10.868035439324409, 11.800837316984648, 11.681926365063736, 10.717967097264793, 9.763757665938133, 8.717756552886879, 7.7555088778266885, 6.704667268980662, 5.7285601388575556, 4.7941418840244605, 3.796295550135016, 3.0501853421522496, 4.021749359067376, 4.9039724472636586, 5.785524185757332, 6.790368018912619, 7.811831277784339, 8.787312489866265, 9.834010904191764, 10.78324600820694, 11.724018015145184, 12.768731339266678, 12.63336003487153, 11.665281225817957, 10.627523993258054, 9.67333682591558, 8.644444685800796, 7.651425641972748, 6.673606483100612, 5.775256638731421, 4.750779599283205, 4.029741724238696, 5.009362097867706, 5.934246101140599, 6.85701782098163, 7.760103003903721, 8.75128112059874, 9.708659696677419, 10.738869694938426, 11.703622706751045, 12.653977996038321, 13.698006868268385, 13.43175043133531, 12.472804958542078, 11.5157596842035, 10.579962496619425, 9.622264836012787, 8.582646952965066, 7.605478132978039, 6.701902824255305, 5.808351168343725, 5.010008118115813, 5.956101518454574, 7.005139526672159, 7.815681769481706, 8.776712128496138, 9.746557996646583, 10.709759647344931, 11.65876904909647, 12.679332739102074, 13.678087283137506, 14.729251223411287, 14.412125564194373, 13.523080667948019, 12.560687899059582, 11.546435477022772, 10.555313068008402, 9.59693493237871, 8.620101631148872, 7.664334956878231, 6.838569440430628, 5.950808660418717, 6.9152406353309335, 7.8831967546866535, 8.788691838471944, 9.78268045610681, 10.800248977954453, 11.724244473332641, 12.655705167942507, 13.671644765469805, 14.648814814428816, 15.675794805124735, 15.379641116751005, 14.533705412142833, 13.551267340152679, 12.541197599648159, 11.514167600510739, 10.608790440368205, 9.617465192728318, 8.727698182190366, 7.87696278532586, 7.023380669432833, 7.966459822964372, 8.812998228091418, 9.805858182304306, 10.763993585081954, 11.823593228209905, 12.656220609437696, 13.64545515951126, 14.71662800209964, 15.644779184578669, 16.627609136253305, 16.34870532086079, 15.39062755972162, 14.42594374513578, 13.433825320493181, 12.488446241723405, 11.559052643401078, 10.629416332919773, 9.77777597292299, 8.890521946261842, 8.000655365610438, 8.977238911829932, 9.764262406320949, 10.771082196421116, 11.764514674457198, 12.767364491621244, 13.67721684000191, 14.585236678383348, 15.522277951632283, 16.45804453504025, 17.531062460068544, 17.338899182907024, 16.351290365626742, 15.45195903528482, 14.441052644341442, 13.42162782286888, 12.49971756050175, 11.614569207468938, 10.794138606112137, 9.923668386315683, 8.936696449703504, 9.924629419767266, 10.807228172210076, 11.823357682099587, 12.782033496687474, 13.70492022438708, 14.736446522348624, 15.54931826205035, 16.449856926235526, 17.41485565358309, 18.370718649907285, 18.271061025929786, 17.24685178080287, 16.312328875546598, 15.38461847174458, 14.395619452819579, 13.53603588211043, 12.650935336268937, 11.732109979951243, 10.875354033852533], [10.741480430726858, 9.75351646994303, 10.7445988477092, 11.689617093696, 12.597002985953495, 13.531608718602946, 14.406760716332862, 15.372762208004767, 16.39199169825337, 17.330706450905083, 17.41283516817572, 16.532339905786554, 15.535838057557514, 14.700516920664734, 13.767695552287178, 12.776013259834844, 11.86950418222758, 10.90677569877415, 10.212073902661386, 10.778940531644231, 9.739017103579576, 8.808960660393115, 9.781601239885454, 10.721947050147529, 11.667848772446895, 12.591409392349018, 13.451984341445801, 14.480372992608286, 15.495210505023048, 16.500044301462367, 17.50019206073207, 17.408640288232927, 16.47596354936403, 15.582510370723215, 14.631864236090124, 13.653138023173288, 12.61320155500205, 11.582299801658534, 10.657225060865004, 9.760291190912724, 8.876523698117195, 7.875929066921844, 8.811760453944547, 9.812151863922532, 10.722195546884697, 11.625587818646514, 12.489692333822752, 13.533803478142906, 14.492621714702796, 15.533309266900538, 16.57295822711217, 16.46226039620211, 15.438134304279542, 14.60759588744433, 13.807931331747385, 12.765383710169525, 11.701926809903666, 10.638242024972213, 9.698729567790046, 8.801023405505644, 7.963930597122754, 6.918174716027657, 7.8745490900113335, 8.854584383416123, 9.703571747292887, 10.647945215614266, 11.549757288628603, 12.57939086065292, 13.563198831335814, 14.549327132672744, 15.50670820405412, 15.411032606099312, 14.452568121360779, 13.665259849683732, 12.772890459973231, 11.853112969237618, 10.800427983087596, 9.786194976618104, 8.770245484713744, 7.830279624285688, 6.97492742871452, 5.925728701379249, 6.896776300644985, 7.815901676778101, 8.717938355615681, 9.64512091794196, 10.574798807515478, 11.61363809233469, 12.56749372046365, 13.540963262989399, 14.580182776872208, 14.475485646250997, 13.508968914026186, 12.680685767964906, 11.72351626298223, 10.872296244366181, 9.84427847006087, 8.854451411482927, 7.823219254895408, 6.879006204743117, 5.91765218602885, 4.918550425061462, 5.9037261895046464, 6.866419899776322, 7.740390924041837, 8.689945130949766, 9.657751861059412, 10.678844945779806, 11.666413602557771, 12.634519681139448, 13.638394684579367, 13.538550987673176, 12.543925121973162, 11.679472215578674, 10.70311210426919, 9.822471769005421, 8.802876017216596, 7.818436972636694, 6.822089631342645, 5.821449468110187, 4.873460042550111, 3.9545542113949046, 4.8864074549884275, 5.858132292577499, 6.7744514482537275, 7.722698805958167, 8.70461212555091, 9.669720114198357, 10.624135040525161, 11.648346212652687, 12.720010027648572, 12.593162373618636, 11.598963007989362, 10.655840265570847, 9.724531745386392, 8.751959595360615, 7.72829784520375, 6.785471504828894, 5.780802006908673, 4.851736178384141, 3.94283141056975, 2.9574740329976965, 3.8609553601951503, 4.8491723394552935, 5.7412252852181425, 6.68096154662894, 7.7204339977576835, 8.712907161331465, 9.671191229767535, 10.731414970233129, 11.741165134034949, 11.611854367430137, 10.61369964314529, 9.675495008370177, 8.750963079418556, 7.759580560584188, 6.8121606412653195, 5.827875050710044, 4.872629225664422, 3.8630832595991267, 3.010412798177353, 2.0033874852435174, 2.892892563316694, 3.8597434905426615, 4.815401626802216, 5.79765523489394, 6.804021788231739, 7.7395456930671696, 8.719814360634855, 9.743162789332114, 10.761076606166238, 10.617285674168023, 9.637712528526102, 8.711211750003667, 7.756471094994087, 6.829021208940504, 5.895007397526252, 4.929411131454198, 3.884220688992235, 2.8950425318004167, 1.9566708623430227, 0.9448081698721703, 1.9454300715258084, 2.939506265249293, 3.8823755959215527, 4.8636466044999205, 5.79993572830949, 6.831037177115576, 7.820263618546934, 8.750101453768144, 9.815810998491116, 9.996405798165922, 8.989062919359272, 7.919065206157867, 6.9176448680285745, 5.990017898519367, 4.980092785464205, 3.9993311113088623, 2.9316661554516994, 1.9010325923135012, 0.9467475939863529, 0.0, 1.0211025631480872, 2.0511796896090084, 3.0772195275758185, 4.005584993905638, 5.080411291649483, 6.03969580540874, 7.058694283230375, 8.103418412137177, 9.08336120170283, 10.13381513626038, 9.917589727624662, 8.853853615166804, 7.871396720003418, 6.921652970834638, 5.930875850716719, 4.865957760373715, 3.84828774933131, 2.846877257576975, 1.878245204264148, 1.0098525535696947, 2.0035805791424273, 3.022685193895229, 4.0494272889867196, 5.05947089893805, 6.075070277592934, 6.971067440883683, 8.042235292009524, 9.088994509112815, 10.108695084708181, 11.088033931767129, 10.811092685681842, 9.80309992747417, 8.840553346439226, 7.885928579803875, 6.884418885518971, 5.854547865315772, 4.83525096919793, 3.817685161710177, 2.944560254897715, 2.046050987054601, 2.972066218576611, 3.9061779829989893, 4.9618198219296135, 5.925162499989303, 6.895296687457733, 7.890095841241546, 8.905509691005673, 9.921287845338055, 10.854089722998294, 11.893789425229409, 11.664714691251147, 10.710505259924487, 9.664504146873233, 8.702256471813042, 7.651414862967016, 6.675307732843908, 5.740889478010813, 4.743043144121369, 3.996932936138603, 3.0963023368199627, 3.957224853277305, 4.838776591770978, 5.843620424926265, 6.865083683797986, 7.840564895879911, 8.88726331020541, 9.836498414220586, 10.77727042115883, 11.821983745280324, 12.749828694697964, 12.61202881980431, 11.574271587244407, 10.620084419901934, 9.591192279787148, 8.598173235959102, 7.620354077086965, 6.722004232717775, 5.697527193269559, 4.97648931822505, 4.083915075620293, 4.987498507154245, 5.9102702269952765, 6.813355409917367, 7.804533526612387, 8.761912102691065, 9.792122100952072, 10.75687511276469, 11.707230402051968, 12.751259274282031, 13.72149743771293, 13.419552552528431, 12.462507278189854, 11.526710090605778, 10.569012429999141, 9.52939454695142, 8.552225726964393, 7.648650418241659, 6.755098762330078, 5.956755712102167, 5.156224559961393, 6.058391932685805, 6.868934175495352, 7.829964534509785, 8.799810402660231, 9.763012053358578, 10.712021455110117, 11.73258514511572, 12.731339689151152, 13.782503629424934, 14.701872570571993, 14.469828261934374, 13.507435493045936, 12.493183071009126, 11.502060661994756, 10.543682526365064, 9.566849225135226, 8.611082550864584, 7.785317034416981, 6.897556254405071, 6.206505050229581, 6.9916988950859995, 7.841944244485592, 8.835932862120458, 9.853501383968101, 10.777496879346288, 11.708957573956155, 12.724897171483452, 13.702067220442462, 14.729047211138381, 15.669388123128625, 15.480453006129189, 14.498014934139032, 13.487945193634513, 12.460915194497092, 11.55553803435456, 10.564212786714673, 9.674445776176718, 8.823710379312214, 7.970128263419187, 7.25772423786302, 7.921500368490763, 8.859110588317954, 9.817245991095602, 10.876845634223553, 11.709473015451342, 12.698707565524908, 13.769880408113288, 14.698031590592317, 15.68086154226695, 16.63845232723841, 16.337375153707974, 15.372691339122136, 14.380572914479536, 13.435193835709761, 12.505800237387433, 11.576163926906128, 10.724523566909342, 9.837269540248196, 8.947402959596792, 8.268503326728581, 8.872764546720294, 9.854102488194613, 10.817767080470846, 11.820616897634892, 12.730469246015556, 13.638489084396996, 14.575530357645931, 15.511296941053901, 16.58431486608219, 17.567236622310737, 17.228807158110655, 16.364453360464744, 15.387800238327797, 14.368375416855235, 13.446465154488106, 12.561316801455293, 11.642393898078414, 10.689282110465735, 9.883444043689858, 9.215893834665914, 9.915730312609421, 10.915281968117649, 11.835285902701122, 12.758172630400727, 13.78969892836227, 14.602570668063999, 15.503109332249176, 16.46810805959674, 17.423971055920937, 17.32431343194343, 16.30010418681651, 15.365581281560244, 14.476687379482927, 13.62464322225383, 12.729970094100208, 11.767349928575028, 10.819994883173587, 11.640967758002585], [11.699701057570781, 10.711737096786953, 9.991139795996254, 10.862849829146821, 11.688409577296337, 12.623015309945789, 13.498167307675704, 14.46416879934761, 15.483398289596213, 16.422113042247926, 16.465388497944918, 15.584893235555748, 14.58839138732671, 13.753070250433929, 12.820248882056372, 11.828566589604039, 10.922057511996774, 9.959329028543344, 10.806041765666535, 11.760137398959973, 10.697237730423499, 9.767181287237038, 8.954833975336275, 9.89517978559835, 10.759255363789737, 11.68281598369186, 12.543390932788643, 13.571779583951129, 14.58661709636589, 15.59145089280521, 16.59159865207491, 16.519776703982302, 15.580713951224892, 14.687105457655129, 13.772049425919489, 12.793323213002653, 11.882105287719165, 10.939781452249253, 11.678327624013091, 10.781393754060812, 9.83474432496112, 8.834149693765768, 7.90316704528739, 8.903558455265374, 9.81360213822754, 10.716994409989356, 11.581098925165595, 12.625210069485748, 13.584028306045639, 14.62471585824338, 15.664364818455011, 16.661647311654818, 16.459236867427627, 15.628698450592417, 14.746479043707364, 13.786486273317612, 12.723029373051753, 11.6593445881203, 10.719832130938133, 9.822125968653731, 8.92215122396668, 7.876395342871582, 6.965955681354176, 7.945990974758966, 8.79497833863573, 9.739351806957108, 10.641163879971446, 11.670797451995762, 12.654605422678657, 13.640733724015586, 14.598114795396963, 15.610419521552016, 15.473670684508866, 14.68636241283182, 13.793993023121319, 12.874215532385705, 11.821530546235683, 10.807297539766191, 9.791348047861831, 8.851382187433774, 7.933148055558445, 6.883949328223174, 5.988182891987828, 6.907308268120945, 7.809344946958523, 8.736527509284802, 9.66620539885832, 10.705044683677531, 11.658900311806493, 12.632369854332241, 13.671589368215047, 14.674872561703701, 14.530071477174273, 13.701788331112994, 12.744618826130317, 11.893398807514268, 10.865381033208957, 9.875553974631014, 8.844321818043495, 7.900108767891204, 6.894846082825064, 5.876771051905387, 4.995132780847489, 5.957826491119166, 6.83179751538468, 7.781351722292609, 8.749158452402254, 9.770251537122647, 10.757820193900612, 11.725926272482287, 12.729801275922206, 13.673996354854024, 13.56502768512125, 12.70057477872676, 11.724214667417277, 10.843574332153509, 9.823978580364683, 8.83953953578478, 7.843192194490732, 6.842552031258275, 5.852731697847634, 4.91277483823883, 3.97781404633127, 4.949538883920342, 5.86585803959657, 6.8141053973010095, 7.796018716893752, 8.761126705541198, 9.715541631868001, 10.739752803995525, 11.81141661899141, 12.777813501072345, 12.620065571137449, 11.676942828718934, 10.745634308534479, 9.773062158508703, 8.749400408351837, 7.806574067976981, 6.80190457005676, 5.872838741532228, 4.953038058777375, 3.9156946598416225, 2.9523619515379926, 3.9405789307981363, 4.832631876560985, 5.772368137971783, 6.811840589100526, 7.8043137526743065, 8.762597821110376, 9.822821561575969, 10.83257172537779, 11.80876848159541, 11.634802206293378, 10.696597571518264, 9.772065642566643, 8.780683123732274, 7.833263204413407, 6.848977613858131, 5.893731788812509, 4.884185822747214, 4.020619446384979, 2.964313879345784, 1.9842991546595363, 2.951150081885504, 3.9068082181450583, 4.889061826236782, 5.895428379574581, 6.830952284410012, 7.811220951977697, 8.834569380674957, 9.85248319750908, 10.856878873606737, 10.658815091674189, 9.732314313151754, 8.777573658142174, 7.850123772088591, 6.916109960674339, 5.950513694602285, 4.905323252140322, 3.916145094948504, 2.97777342549111, 1.9659107330202574, 1.0368366628686507, 2.0309128565921353, 2.973782187264395, 3.9550531958427633, 4.891342319652332, 5.922443768458418, 6.911670209889777, 7.841508045110985, 8.907217589833959, 9.853207779249527, 10.010165482507361, 8.940167769305955, 7.938747431176662, 7.0111204616674545, 6.001195348612292, 5.0204336744569495, 3.9527687185997866, 2.9221351554615884, 1.96785015713444, 1.0211025631480872, 0.0, 1.030077126460921, 2.056116964427731, 2.9844824307575504, 4.059308728501396, 5.0185932422606525, 6.037591720082288, 7.08231584898909, 8.062258638554743, 9.112712573112292, 10.105233427869093, 9.874956178314893, 8.892499283151505, 7.942755533982726, 6.951978413864806, 5.887060323521802, 4.869390312479397, 3.867979820725062, 2.8993477674122348, 2.0309551167177817, 1.0561339089116217, 2.075238523664423, 3.0791324579955135, 4.038368335789963, 5.0539677144448465, 5.949964877735596, 7.021132728861437, 8.067891945964728, 9.087592521560094, 10.066931368619041, 11.098323578788898, 10.824202490622257, 9.861655909587313, 8.907031142951961, 7.905521448667058, 6.875650428463859, 5.856353532346017, 4.838787724858264, 3.965662818045802, 3.067153550202688, 2.0246195483458056, 2.958731312768184, 4.014373151698808, 4.977715829758497, 5.947850017226927, 6.942649171010741, 7.958063020774867, 8.97384117510725, 9.906643052767489, 10.946342754998604, 11.910302022797547, 11.731607823072574, 10.68560671002132, 9.72335903496113, 8.672517426115103, 7.6964102959919956, 6.7619920411589005, 5.764145707269456, 5.01803549928669, 4.082764692212025, 3.0097781830464996, 3.8913299215401733, 4.896173754695461, 5.917637013567182, 6.893118225649106, 7.939816639974605, 8.88905174398978, 9.829823750928025, 10.874537075049519, 11.802382024467159, 12.820441872070667, 12.595374150392495, 11.641186983050021, 10.612294842935235, 9.61927579910719, 8.641456640235052, 7.743106795865862, 6.718629756417646, 5.997591881373136, 5.070377431012355, 4.04005183692344, 4.962823556764471, 5.865908739686563, 6.857086856381583, 7.814465432460262, 8.844675430721269, 9.809428442533887, 10.759783731821162, 11.803812604051226, 12.774050767482125, 13.732996240275357, 13.483609841337941, 12.547812653753866, 11.590114993147228, 10.550497110099506, 9.57332829011248, 8.669752981389745, 7.776201325478166, 6.977858275250253, 6.142686915353455, 5.110945262455, 5.921487505264547, 6.882517864278981, 7.852363732429427, 8.815565383127774, 9.764574784879313, 10.785138474884917, 11.783893018920347, 12.835056959194128, 13.754425900341188, 14.7832719496813, 14.528538056194023, 13.514285634157213, 12.523163225142843, 11.564785089513151, 10.587951788283313, 9.632185114012671, 8.806419597565068, 7.918658817553157, 7.012208344210914, 6.044252224855194, 6.894497574254786, 7.888486191889653, 8.906054713737298, 9.830050209115484, 10.761510903725352, 11.777450501252648, 12.754620550211659, 13.781600540907576, 14.72194145289782, 15.696286184340119, 15.51911749728712, 14.5090477567826, 13.48201775764518, 12.576640597502648, 11.58531534986276, 10.695548339324805, 9.844812942460301, 8.991230826567273, 8.029711437204345, 6.974053698259958, 7.911663918087148, 8.869799320864796, 9.929398963992746, 10.762026345220539, 11.751260895294104, 12.822433737882484, 13.750584920361513, 14.733414872036144, 15.691005657007606, 16.671114490334894, 16.39379390227022, 15.401675477627624, 14.456296398857848, 13.52690280053552, 12.597266490054215, 11.74562613005743, 10.858372103396283, 9.88546234922139, 8.86247118973373, 7.925317876489489, 8.906655817963808, 9.87032041024004, 10.873170227404087, 11.783022575784752, 12.691042414166192, 13.628083687415128, 14.563850270823098, 15.636868195851388, 16.619789952079934, 16.320213749453497, 15.455859951807586, 14.551205870613437, 13.690041443547372, 12.939521151159708, 12.05025700566208, 12.600614524922337, 11.647502737309658, 10.821503433314456, 9.809861697671064, 8.968283642378616, 9.967835297886843, 10.887839232470316, 11.810725960169922, 12.842252258131467, 13.655123997833195, 14.555662662018372, 15.520661389365937, 16.476524385690134, 16.415720023286273, 15.391510778159356, 14.456987872903087, 13.56809397082577, 12.716049813596673, 11.903202829551029, 11.013890876862082, 11.77821551001751, 12.599188384846508], [12.69634206070118, 11.708378099917352, 10.987780799126654, 10.0796816795931, 10.708843712982949, 11.6434494456324, 12.518601443362316, 13.484602935034221, 14.503832425282823, 15.442547177934536, 15.463595745842738, 14.583100483453569, 13.586598635224531, 12.78831618401718, 11.86610951190839, 10.899224470058218, 10.045521441767542, 10.8117699840711, 11.658482721194291, 12.612578354487729, 11.693878733553898, 10.763822290367438, 9.951474978466674, 9.112011636044631, 9.77968949947635, 10.703250119378472, 11.563825068475255, 12.59221371963774, 13.607051232052502, 14.611885028491821, 15.612032787761523, 15.51798395188012, 14.578921199122712, 13.72235139123838, 12.842707306373669, 11.863981093456832, 11.005569217489933, 11.79222240777701, 12.656743752725058, 11.759809882772778, 10.83138532809152, 9.830790696896168, 8.899808048417789, 8.091556889075955, 8.834036273914151, 9.737428545675968, 10.601533060852207, 11.64564420517236, 12.60446244173225, 13.645149993929993, 14.684798954141625, 15.670135927338247, 15.6167504442072, 14.758437268873912, 13.817136924161543, 12.894407864025595, 11.97661876425376, 12.637760716832267, 11.6982482596501, 10.800542097365698, 9.918792227097079, 8.873036346001982, 7.962596684484575, 7.0809849036996875, 7.815412474322342, 8.75978594264372, 9.661598015658058, 10.691231587682374, 11.675039558365269, 12.661167859702198, 13.618548931083577, 14.618908137235445, 15.593477116946534, 15.70077330663451, 14.814757731697842, 13.84409672583753, 12.804194850692962, 11.78996184422347, 10.769764176573798, 9.829798316145741, 8.929789058688844, 7.880590331353574, 6.984823895118227, 6.042302197061666, 6.829779082645135, 7.756961644971414, 8.686639534544932, 9.725478819364143, 10.679334447493105, 11.652803990018853, 12.680077983898476, 13.68336117738713, 14.649877909611941, 14.731865457573914, 13.77469595259124, 12.923475933975189, 11.895458159669877, 10.905631101091938, 9.868252626971353, 8.922812378441314, 7.891487085955464, 6.873412055035787, 5.991773783977888, 5.092820420059887, 5.852231651071291, 6.801785857979219, 7.769592588088863, 8.778740152806076, 9.766308809584041, 10.734414888165716, 11.738289891605636, 12.682484970537454, 13.69385919272977, 13.730651905187683, 12.754291793878199, 11.873651458614429, 10.854055706825603, 9.869616662245704, 8.873269320951655, 7.872629157719197, 6.849372700978034, 5.9094158413692295, 4.974455049461669, 4.084532812861063, 4.886292175283181, 5.83453953298762, 6.816452852580362, 7.769615321224628, 8.72403024755143, 9.748241419678955, 10.81990523467484, 11.786302116755774, 12.800675186407757, 12.707019955179856, 11.7757114349954, 10.803139284969623, 9.779477534812758, 8.836651194437902, 7.8319816965176825, 6.90291586799315, 5.949679061907775, 4.912335662972022, 3.949002954668392, 3.0755728597388576, 3.8530660122475955, 4.792802273658394, 5.832274724787137, 6.812802368357736, 7.771086436793806, 8.831310177259398, 9.841060341061219, 10.817257097278839, 11.815411821563686, 11.726674697979185, 10.802142769027565, 9.810760250193196, 8.863340330874328, 7.879054740319053, 6.9238089152734315, 5.914262949208136, 5.017260449515378, 3.9609548824761833, 2.9809401577899357, 2.0861440108262252, 2.9272423538316685, 3.9094959619233927, 4.903916995258012, 5.839440900093441, 6.819709567661127, 7.843057996358385, 8.86097181319251, 9.865367489290167, 10.844940634932088, 10.762391439612676, 9.807650784603096, 8.880200898549512, 7.94618708713526, 6.980590821063206, 5.935400378601243, 4.946222221409426, 4.007850551952031, 2.9959878594811786, 2.03347766599905, 1.0394014722755656, 1.9822708029478253, 2.9635418115261936, 3.8998309353357623, 4.930932384141848, 5.920158825573207, 6.849996660794416, 7.915706205517388, 8.861696394932956, 9.869039273739606, 9.970244895766875, 8.968824557637582, 8.041197588128375, 7.031272475073212, 6.050510800917871, 4.982845845060708, 3.9522122819225096, 2.997927283595361, 2.0511796896090084, 1.030077126460921, 0.0, 1.02603983796681, 1.9544053042966294, 3.0292316020404746, 3.9885161157997313, 5.007514593621367, 6.052238722528169, 7.032181512093823, 8.082635446651372, 9.075156301408173, 10.138892413866031, 9.922576409612425, 8.972832660443647, 7.982055540325727, 6.917137449982723, 5.899467438940318, 4.898056947185983, 3.929424893873156, 3.061032243178703, 2.0755575019949153, 1.056452887242114, 2.0490553315345927, 3.008291209329042, 4.023890587983925, 4.919887751274675, 5.9910556024005155, 7.037814819503808, 8.057515395099173, 9.036854242158121, 10.068246452327978, 11.07623921053565, 10.891733036048235, 9.937108269412883, 8.93559857512798, 7.9057275549247805, 6.886430658806939, 5.868864851319185, 4.995739944506723, 4.0092466176721455, 2.963500957644741, 2.0293891932223627, 3.020682161887145, 3.9585191020121657, 4.928653289480596, 5.914659034274419, 6.930072884038546, 7.945851038370928, 8.878652916031166, 9.918352618262281, 10.882311886061224, 11.836521317387884, 11.71568383648224, 10.75343616142205, 9.702594552576024, 8.726487422452916, 7.792069167619822, 6.794222833730378, 5.993210118426086, 5.02164610151096, 3.948659592345435, 2.961987801994352, 3.9668316351496395, 4.9158442614650015, 5.873921497902774, 6.9118265032382835, 7.861061607253459, 8.801833614191704, 9.846546938313196, 10.774391887730836, 11.792451735334344, 12.76976129298374, 12.671264109510942, 11.642371969396155, 10.64935292556811, 9.671533766695973, 8.773183922326783, 7.748706882878567, 6.972766500512533, 6.009258840311291, 4.978933246222375, 4.033481437218651, 4.936566620140741, 5.855294104279403, 6.812672680358081, 7.842882678619088, 8.807635690431706, 9.731793595084842, 10.775822467314903, 11.746060630745802, 12.705006103539034, 13.662051377877612, 13.577889780214786, 12.620192119608149, 11.580574236560427, 10.6034054165734, 9.699830107850667, 8.806278451939086, 7.95303289438965, 7.025400258195154, 5.963386217982755, 4.992145385718726, 5.9531757447331595, 6.853140623843088, 7.813772631025595, 8.762782032777134, 9.783345722782736, 10.755902882184026, 11.807066822457807, 12.726435763604865, 13.755281812944975, 14.706979592733694, 14.544362760618133, 13.553240351603764, 12.594862215974072, 11.618028914744233, 10.662262240473593, 9.836496724025988, 8.829081274650886, 7.86464929973867, 6.89669318038295, 5.965155454708966, 6.9591440723438325, 7.906831605150959, 8.828257457013304, 9.759718151623172, 10.775657749150467, 11.752827798109477, 12.753610404171255, 13.693951316161497, 14.668296047603796, 15.707939628822404, 15.523705036191554, 14.5120948841061, 13.606717723963568, 12.61539247632368, 11.725625465785729, 10.874890068921221, 9.901653283665, 8.882152392732099, 7.826494653787714, 6.982321798541328, 7.940457201318976, 8.959401467795868, 9.76023359311836, 10.749468143191924, 11.820640985780305, 12.748792168259333, 13.705424735299824, 14.663015520271284, 15.64312435359857, 15.502309377643238, 14.582497367489815, 13.64365716037946, 13.09701791870666, 13.627343616515136, 12.775703256518353, 11.888449229857203, 10.737903304749146, 9.714912145261486, 8.777758832017245, 7.977313698417987, 8.94097829069422, 9.91144590644139, 10.781229823682573, 11.689249662064013, 12.626290935312948, 13.562057518720918, 14.635075443749209, 15.617997199977752, 15.340647885140111, 14.476294087494198, 13.571640006300049, 12.710475579233986, 12.156353001605988, 13.04689800879248, 13.597255528052736, 12.644143740440057, 11.673944388842212, 10.66230265319882, 9.820724597906372, 9.038493178341023, 9.958497112924496, 10.849001639207225, 11.840459506029287, 12.653331245731016, 13.553869909916193, 14.518868637263758, 15.474731633587954, 15.436154158972883, 14.411944913845968, 13.477422008589699, 12.588528106512381, 11.736483949283286, 11.120034679997309, 12.010531879992481, 12.77485651314791, 13.595829387976908], [13.626060216397674, 12.638096255613846, 11.76881357553472, 10.709267990750021, 9.769750609152187, 10.70435634180164, 11.579508339531554, 12.545509831203459, 13.564739321452063, 14.503454074103775, 14.437555907875925, 13.557060645486757, 12.56055879725772, 11.762276346050369, 10.840069673941578, 10.030264997505281, 10.95405923468714, 11.720307776990698, 12.567020514113889, 13.521116147407326, 12.623596889250392, 11.693540446063931, 10.76332441764955, 9.822978607387475, 8.840596395645587, 9.764157015547712, 10.624731964644493, 11.653120615806978, 12.66795812822174, 13.672791924661059, 14.67293968393076, 14.49194411391331, 13.552881361155901, 12.696311553271569, 11.848325833972904, 10.995021620903895, 11.91410701040953, 12.700760200696607, 13.565281545644657, 12.668347675692377, 11.761103483788013, 10.760508852592661, 9.795083943586006, 8.81604256058747, 7.894943170083389, 8.798335441845207, 9.662439957021444, 10.706551101341597, 11.665369337901488, 12.70605689009923, 13.745705850310861, 14.702829362452556, 14.590710606240389, 13.734739001152665, 12.822755451760779, 12.025448391472658, 12.885156557173357, 13.546298509751866, 12.6067860525697, 11.709079890285297, 10.848510382793572, 9.802754501698475, 8.857872579652792, 7.805470575211203, 6.876319370491579, 7.820692838812959, 8.722504911827295, 9.752138483851612, 10.735946454534506, 11.722074755871436, 12.679455827252813, 13.651601572349755, 14.626170552060843, 14.677075038913262, 13.857796323534933, 12.975137253284592, 13.712732643612561, 12.698499637143069, 11.678301969493397, 10.73833610906534, 9.859507214385337, 8.810308487050067, 7.88490055000007, 6.821381112513718, 5.890685978814372, 6.817868541140651, 7.74754643071417, 8.786385715533381, 9.737170699680165, 10.710640242205914, 11.712771419012785, 12.71605461250144, 13.68257134472625, 14.623305206308716, 14.800735790558049, 13.917447443877153, 12.8856535666906, 11.837785711000626, 10.795251184035216, 9.849810935505177, 8.821205241651956, 7.80313021073228, 6.920997763345019, 5.9184800424065855, 4.9131385472405285, 5.862692754148457, 6.830499484258101, 7.8114335879203844, 8.79900224469835, 9.767108323280025, 10.770983326719945, 11.715178405651763, 12.726552627844079, 13.711150164082568, 13.780331631845009, 12.899691296581238, 11.880095544792413, 10.895656500212512, 9.899309158918463, 8.898668995686005, 7.779090856674527, 6.839133997065723, 5.904173205158163, 4.910192435207762, 3.9471990714524186, 4.895446429156857, 5.877359748749599, 6.8023087563389355, 7.756723682665739, 8.780934854793264, 9.852598669789149, 10.818995551870083, 11.833368621522064, 12.79465763608845, 12.80175127296221, 11.829179122936432, 10.805517372779567, 9.862691032404712, 8.858021534484491, 7.92895570595996, 6.879397217604268, 5.842053818668514, 4.878721110364885, 3.911920191606551, 2.9139729084168335, 3.8537091698276313, 4.8931816209563745, 5.845495803472043, 6.803779871908113, 7.864003612373707, 8.873753776175526, 9.849950532393146, 10.848105256677993, 11.76841810693534, 11.828182606994375, 10.836800088160006, 9.889380168841138, 8.905094578285862, 7.949848753240241, 6.940302787174946, 5.9469786052118705, 4.890673038172676, 3.9106583134864286, 2.943807386260461, 1.9881492500009068, 2.9704028580926307, 3.936610430372318, 4.872134335207749, 5.852403002775434, 6.875751431472692, 7.893665248306817, 8.898060924404472, 9.877634070046394, 10.804134848568829, 10.833690622569906, 9.906240736516322, 8.97222692510207, 8.006630659030016, 6.961440216568053, 5.972262059376235, 5.033890389918841, 3.9807451251664463, 2.980123223512808, 1.9860470297893236, 1.0431776991170636, 1.9962352466404993, 2.9325243704500683, 3.963625819256154, 4.9528522606875125, 5.882690095908721, 6.948399640631694, 7.894389830047262, 8.901732708853913, 9.97173042205532, 9.994864395604392, 9.067237426095184, 8.057312313040022, 7.07655063888468, 6.0088856830275175, 4.978252119889319, 4.023967121562171, 3.077219527575818, 2.056116964427731, 1.02603983796681, 0.0, 0.9283654663298193, 2.003191764073664, 2.962476277832921, 3.981474755654556, 5.026198884561358, 6.0061416741270115, 7.05659560868456, 8.049116463441361, 9.11285257589922, 10.105224507409302, 9.998872498410456, 9.008095378292536, 7.943177287949533, 6.925507276907128, 5.924096785152793, 4.955464731839966, 4.062590228984807, 3.068862203412075, 2.049757588659274, 1.0230154935677827, 1.9822513713622316, 2.9978507500171148, 3.893847913307864, 4.965015764433705, 6.011774981536997, 7.031475557132363, 8.01081440419131, 9.042206614361167, 10.050199372568839, 11.012745953603783, 10.963148107379691, 9.961638413094787, 8.93176739289159, 7.912470496773748, 6.894904689285995, 6.021779782473533, 5.002551319089306, 3.956805659061901, 3.0226938946395228, 1.9946423239203348, 2.9324792640453556, 3.902613451513785, 4.888619196307609, 5.904033046071735, 6.919811200404117, 7.852613078064355, 8.89231278029547, 9.856272048094413, 10.810481479421073, 11.856482592472327, 11.77947599938886, 10.728634390542833, 9.752527260419726, 8.818109005586631, 7.820262671697187, 6.986514819843246, 6.01495080292812, 4.941964293762595, 3.955292503411512, 3.005372516285199, 3.889804423498191, 4.847881659935964, 5.885786665271473, 6.835021769286648, 7.775793776224892, 8.820507100346385, 9.748352049764025, 10.766411897367533, 11.743721455016928, 12.697908622359401, 12.668411807362965, 11.67539276353492, 10.697573604662782, 9.769293531619576, 8.74481649217136, 7.966071201929693, 7.002563541728451, 5.9722379476395355, 4.942019230138248, 3.975107501276301, 4.829254266312592, 5.7866328423912705, 6.816842840652278, 7.781595852464896, 8.70575375711803, 9.749782629348092, 10.72002079277899, 11.678966265572223, 12.6360115399108, 13.571808727494876, 13.646231957574958, 12.606614074527236, 11.62944525454021, 10.69593971714346, 9.76751015303314, 8.880031451453512, 7.933938051114751, 6.871924010902353, 5.900683178638324, 4.991716625868719, 5.8271007858762776, 6.787732793058784, 7.736742194810323, 8.757305884815926, 9.729863044217215, 10.781026984490996, 11.700395925638054, 12.729241974978166, 13.680939754766882, 14.538281707898223, 14.579280189570573, 13.620902053940881, 12.644068752711043, 11.658371849766386, 10.797728425120042, 9.737619067570485, 8.773187092658269, 7.805230973302548, 6.873693247628563, 6.029147444624764, 6.880791767184148, 7.802217619046493, 8.73367831365636, 9.749617911183657, 10.726787960142667, 11.727570566204443, 12.667911478194686, 13.642256209636985, 14.681899790855592, 14.584611932360794, 13.755004756411171, 14.632757561930378, 13.64143231429049, 12.72173507507852, 11.836121770015275, 10.8101910765846, 9.790690185651698, 8.735032446707311, 7.890859591460925, 7.0714977287660385, 7.933361629829056, 8.734193755151548, 9.723428305225113, 10.794601147813493, 11.722752330292522, 12.679384897333012, 13.636975682304472, 14.617084515631758, 14.563216273812476, 13.643404263659054, 12.704564056548696, 13.633957654871024, 14.563593965352329, 13.768349576414764, 12.833675147848899, 11.646441097668744, 10.623449938181084, 9.686296624936842, 8.885851491337585, 8.072018818141283, 8.885406068474579, 9.755189985715761, 10.663209824097201, 11.600251097346137, 12.536017680754107, 13.609035605782397, 14.591957362010941, 14.401554781309347, 13.537200983663435, 12.632546902469288, 11.771382475403222, 12.732562081463547, 13.69604762250125, 14.52697368374923, 13.57386189613655, 12.58248218176181, 11.570840446118417, 10.72926239082597, 9.94703097126062, 9.089537640371558, 9.822961801240414, 10.814419668062476, 11.627291407764204, 12.527830071949381, 13.492828799296944, 14.44869179562114, 14.497061055142122, 13.472851810015205, 12.538328904758936, 11.64943500268162, 10.797390845452522, 11.749620991154229, 12.729928583663272, 13.704574668844403, 14.525547543673401], [14.554425682727496, 13.566461721943668, 12.697179041864539, 11.63763345707984, 10.698116075482005, 9.991499496267709, 10.820630837491871, 11.786632329163776, 12.774477981635563, 13.713192734287276, 13.509190441546107, 12.628695179156939, 11.632193330927901, 10.83391087972055, 9.91170420761176, 10.86905854302136, 11.882424701016959, 12.648673243320516, 13.495385980443707, 14.449481613737145, 13.551962355580214, 12.621905912393753, 11.691689883979368, 10.751344073717293, 9.768961861975406, 9.05130017001378, 9.86585446260481, 10.894243113767295, 11.834714032288996, 12.839547828728316, 13.839695587998017, 13.56357864758349, 12.624515894826082, 11.76794608694175, 10.919960367643085, 11.833815166419974, 12.84247247673935, 13.629125667026425, 14.493647011974476, 13.596713142022196, 12.689468950117835, 11.688874318922483, 10.723449409915824, 9.744408026917288, 8.823308636413207, 8.085478596311276, 8.903562454981762, 9.947673599301915, 10.812536646733296, 11.840714108457917, 12.819397225627325, 13.774463896122736, 13.66234513991057, 12.806373534822846, 11.89438998543096, 12.864241936988737, 13.813522023503175, 14.474663976081684, 13.535151518899518, 12.637445356615116, 11.776875849123394, 10.731119968028297, 9.78623804598261, 8.733836041541021, 7.804684836821398, 7.107835993279028, 7.9636274097876125, 8.98197459853754, 9.837311025981169, 10.795766131187898, 11.753147202569277, 12.723236106019934, 13.697805085731023, 13.748709572583444, 12.929430857205114, 13.813930798800671, 14.64109810994238, 13.626865103472888, 12.606667435823216, 11.666701575395159, 10.787872680715159, 9.73867395337989, 8.813266016329889, 7.749746578843538, 6.819051445144192, 6.10501169560672, 6.988668928674487, 7.942753724579838, 8.808805233350345, 9.782274775876093, 10.784405952682965, 11.78768914617162, 12.75420587839643, 13.694939739978896, 13.978805054196116, 14.845812910206972, 13.814019033020418, 12.766151177330444, 11.723616650365035, 10.778176401834996, 9.749570707981778, 8.731495677062101, 7.8493632296748395, 6.846845508736406, 5.841504013570348, 5.091665792443404, 6.0269535782962596, 6.883068121590565, 7.87063677836853, 8.838742856950205, 9.842617860390124, 10.786812939321942, 11.798187161514258, 12.782784697752748, 13.759144809062231, 13.82805676291106, 12.808461011122233, 11.824021966542333, 10.827674625248283, 9.827034462015826, 8.707456323004347, 7.767499463395543, 6.832538671487982, 5.838557901537582, 4.875564537782238, 4.124419467451805, 5.050164922466935, 5.873943290009116, 6.8283582163359196, 7.852569388463444, 8.924233203459329, 9.890630085540263, 10.905003155192246, 11.866292169758632, 12.797600689943087, 12.757544589266253, 11.733882839109388, 10.791056498734532, 9.786387000814312, 8.85732117228978, 7.807762683934087, 6.770419284998335, 5.807086576694704, 4.840285657936371, 3.842338374746653, 3.082682208122578, 3.988245087634925, 4.917130337142224, 5.875414405578294, 6.935638146043887, 7.945388309845708, 8.921585066063328, 9.919739790348174, 10.84005264060552, 11.82500202167306, 11.765165554489826, 10.817745635170958, 9.833460044615682, 8.878214219570062, 7.868668253504765, 6.87534407154169, 5.819038504502496, 4.839023779816248, 3.8721728525902805, 2.916514716330726, 2.0461113793585377, 3.0082449640424986, 3.9437688688779287, 4.9240375364456135, 5.947385965142872, 6.965299781976997, 7.9696954580746535, 8.949268603716575, 9.87576938223901, 10.83051003724859, 10.834606202846143, 9.900592391431891, 8.934996125359836, 7.889805682897872, 6.900627525706055, 5.96225585624866, 4.909110591496265, 3.908488689842627, 2.9144124961191427, 1.971543165446883, 1.06786978031068, 2.0041589041202488, 3.0352603529263344, 4.024486794357693, 4.954324629578902, 6.020034174301874, 6.966024363717443, 7.973367242524094, 9.0433649557255, 10.04478529385479, 9.995602892425005, 8.985677779369842, 8.0049161052145, 6.937251149357337, 5.906617586219139, 4.95233258789199, 4.005584993905638, 2.9844824307575504, 1.9544053042966294, 0.9283654663298193, 0.0, 1.074826297743845, 2.034110811503102, 3.0531092893247376, 4.09783341823154, 5.077776207797193, 6.128230142354742, 7.120750997111543, 8.184487109569401, 9.176859041079483, 10.126602790248263, 9.936460844622356, 8.871542754279353, 7.8538727432369475, 6.852462251482613, 5.883830198169785, 4.990955695314627, 3.9972276697418945, 2.978123054989093, 1.951380959897602, 1.0538859050324123, 2.0694852836872957, 2.9654824469780454, 4.036650298103886, 5.083409515207179, 6.103110090802544, 7.082448937861491, 8.113841148031348, 9.12183390623902, 10.084380487273965, 11.039005253909316, 10.890003879424608, 9.86013285922141, 8.840835963103569, 7.823270155615814, 6.950145248803352, 5.930916785419124, 4.88517112539172, 3.9510593609693414, 2.9230077902501543, 2.0041137977155365, 2.974247985183966, 3.96025372997779, 4.975667579741916, 5.991445734074298, 6.924247611734536, 7.96394731396565, 8.927906581764594, 9.882116013091254, 10.928117126142508, 11.890364801202699, 11.656999856872654, 10.680892726749546, 9.746474471916452, 8.748628138027007, 7.914880286173065, 6.943316269257939, 5.870329760092414, 4.88365796974133, 3.9337379826150185, 2.9614389571683724, 3.9195161936061447, 4.957421198941654, 5.906656302956829, 6.847428309895073, 7.892141634016565, 8.819986583434204, 9.838046431037712, 10.81535598868711, 11.769543156029583, 12.81544685839085, 12.60375822986474, 11.625939070992603, 10.697658997949397, 9.67318195850118, 8.894436668259512, 7.9309290080582695, 6.900603413969354, 5.870384696468068, 4.90347296760612, 3.9008887999827735, 4.858267376061452, 5.888477374322459, 6.853230386135078, 7.777388290788211, 8.821417163018273, 9.79165532644917, 10.750600799242402, 11.70764607358098, 12.643443261165055, 13.601140921771693, 13.534979540857057, 12.55781072087003, 11.62430518347328, 10.695875619362962, 9.80839691778333, 8.86230351744457, 7.800289477232172, 6.829048644968143, 5.868581187696905, 4.898735319546459, 5.859367326728965, 6.808376728480504, 7.828940418486107, 8.801497577887396, 9.852661518161177, 10.772030459308233, 11.800876508648344, 12.752574288437062, 13.609916241568403, 14.534189153767308, 14.549267520270702, 13.572434219040863, 12.586737316096206, 11.726093891449864, 10.665984533900303, 9.701552558988087, 8.733596439632366, 7.802058713958383, 6.90601200645295, 5.952426300854329, 6.873852152716674, 7.805312847326542, 8.821252444853839, 9.798422493812849, 10.799205099874625, 11.739546011864865, 12.713890743307164, 13.753534324525772, 13.871755086826862, 14.68337022274099, 15.561123028260196, 14.56979778062031, 13.650100541408342, 12.764487236345097, 11.738556542914418, 10.719055651981517, 9.66339791303713, 8.819225057790744, 7.9483622905942255, 7.0049961634992375, 7.805828288821729, 8.795062838895294, 9.866235681483674, 10.794386863962703, 11.751019431003193, 12.708610215974652, 13.688719049301938, 13.804338771772793, 12.930547418125123, 13.632929522878515, 14.562323121200842, 15.491959431682147, 14.696715042744586, 13.762040614178721, 12.574806563998562, 11.551815404510902, 10.614662091266661, 9.814216957667403, 8.94888337996947, 7.95704060214476, 8.826824519385942, 9.734844357767383, 10.671885631016318, 11.607652214424288, 12.680670139452578, 13.663591895681122, 13.642677279269666, 12.778323481623753, 11.919690056935357, 12.69974794173304, 13.660927547793365, 14.62441308883107, 15.455339150079052, 14.502227362466373, 13.510847648091628, 12.499205912448236, 11.657627857155788, 10.875396437590439, 9.928331185887638, 8.894596334910595, 9.886054201732657, 10.698925941434386, 11.599464605619563, 12.564463332967126, 13.520326329291322, 13.706799715325623, 12.713974307975523, 11.779451402719253, 10.93657815714769, 11.725756311782341, 12.677986457484048, 13.65829404999309, 14.632940135174225, 15.453913010003223], [15.533212417026338, 14.54524845624251, 13.67596577616338, 12.616420191378682, 11.676902809780847, 10.830316998446765, 9.849241700729412, 10.815243192401317, 11.800716270234972, 12.739431022886684, 12.574340633403647, 11.693845371014477, 10.69734352278544, 9.917224635029777, 10.807755057436953, 11.765109392846554, 12.81652284753364, 13.648023143161465, 14.494735880284656, 15.448831513578094, 14.530749089879055, 13.600692646692595, 12.67047661827821, 11.730130808016135, 10.747748596274247, 9.892092397123374, 8.89446532584235, 9.922853977004836, 10.860952320888405, 11.865786117327724, 12.865933876597426, 12.62872883944103, 11.689666086683621, 10.851259842250977, 11.801905976884068, 12.729866016245168, 13.769802484416406, 14.628475566867374, 15.492996911815425, 14.596063041863145, 13.668255684416676, 12.667661053221325, 11.702236144214668, 10.72319476121613, 9.802095370712049, 8.92627082342087, 7.932173318219301, 8.976284462539455, 9.838774935332705, 10.866952397057327, 11.845635514226734, 12.800702184722146, 12.72749533176811, 11.889687290132073, 12.776335594671943, 13.760292786813931, 14.740852031180232, 15.474013875922633, 14.534501418740467, 13.636795256456065, 12.755662583422236, 11.709906702327139, 10.765024780281454, 9.712622775839863, 8.78347157112024, 7.948628220388622, 6.992238273025151, 8.008212887136953, 8.863549314580577, 9.822004419787309, 10.779385491168686, 11.749474394619345, 12.724043374330433, 12.83202332789267, 13.804526756055006, 14.709981648625865, 15.640448009783329, 14.626215003313837, 13.606017335664164, 12.666051475236108, 11.766659415014, 10.71746068767873, 9.792052750628732, 8.72853331314238, 7.797838179443033, 6.946957681485545, 6.017279791912026, 6.968992013179248, 7.835043521949755, 8.808513064475504, 9.810644241282375, 10.81392743477103, 11.78044416699584, 12.721178028578306, 13.715771294931857, 14.679608154208083, 14.813368932861367, 13.765501077171393, 12.722966550205983, 11.777526301675945, 10.72835744228062, 9.710282411360943, 8.828149963973681, 7.825632243035248, 6.82029074786919, 5.9928549033000795, 5.0555644415337975, 5.909306410189974, 6.89687506696794, 7.864981145549615, 8.868856148989535, 9.813051227921353, 10.824425450113669, 11.809022986352158, 12.747031311293457, 13.690189357568345, 13.883287308866077, 12.898848264286176, 11.902500922992127, 10.90186075975967, 9.686243057303189, 8.746286197694385, 7.811325405786824, 6.817344635836424, 5.85435127208108, 5.02560857830848, 4.078775785704473, 4.900181578608525, 5.854596504935329, 6.878807677062854, 7.950471492058739, 8.887867697401749, 9.889977780342166, 10.837142432226203, 11.768450952410658, 12.776696452218859, 12.808709136853231, 11.865882796478376, 10.861213298558155, 9.932147470033623, 8.786549418232928, 7.749206019297176, 6.785873310993546, 5.8190723922352126, 4.821125109045495, 3.9838713189792543, 3.0168559508724635, 3.943368625741633, 4.901652694177703, 5.9206127711938095, 6.93036293499563, 7.906559691213249, 8.904714415498095, 9.810902903073092, 10.795852284140633, 11.706614076297813, 11.892571932914802, 10.908286342359526, 9.953040517313905, 8.943494551248609, 7.854130805840532, 6.797825238801337, 5.81781051411509, 4.850959586889122, 3.895301450629568, 2.947300490215214, 2.036855827280037, 2.9700071574773386, 3.950275825045024, 4.929217692170433, 5.947131509004558, 6.940545720542227, 7.920118866184148, 8.846619644706584, 9.801360299716164, 10.728810185769747, 10.975418689175736, 10.009822423103682, 8.964631980641718, 7.975453823449899, 6.943973315658859, 5.887897325795107, 4.887275424141468, 3.8931992304179843, 2.9503298997457246, 1.9690588911673563, 1.0327697673577874, 2.015465630630577, 3.0046920720619354, 3.934529907283144, 4.990884436769448, 5.936874626185016, 6.944217504991667, 8.014215218193073, 9.015635556322366, 9.943262525831573, 10.060504077113688, 9.079742402958345, 8.012077447101182, 6.981443883962983, 6.027158885635835, 5.080411291649482, 4.059308728501395, 3.029231602040474, 2.003191764073664, 1.074826297743845, 0.0, 0.9592845137592569, 1.9782829915808926, 3.0230071204876943, 4.002949910053347, 5.053403844610896, 6.045924699367697, 7.109660811825556, 8.102032743335638, 9.051776492504416, 10.042553612622337, 9.946369052023197, 8.928699040980792, 7.927288549226457, 6.95865649591363, 6.065781993058471, 5.072053967485739, 4.052949352732938, 3.0262072576414467, 2.0175876710679166, 1.0019882924130334, 1.8906561492342002, 2.961824000360041, 4.008583217463333, 5.028283793058699, 6.007622640117646, 7.0390148502875025, 8.047007608495175, 9.00955418953012, 9.96417895616547, 10.965688650450375, 10.890766887956856, 9.871469991839014, 8.85390418435126, 8.024971546547196, 6.9666575051911375, 5.920911845163733, 4.986800080741355, 3.93115824181073, 2.9678155637510404, 2.0533307773354497, 2.8854274322339446, 3.9008412819980713, 4.916619436330453, 5.849421313990692, 6.8891210162218055, 7.8530802840207485, 8.807289715347409, 9.853290828398663, 10.815538503458853, 11.86638011230488, 11.670844817042699, 10.736426562209605, 9.73858022832016, 8.950621005945079, 7.979056989029952, 6.906070479864427, 5.9193986895133435, 4.941888434175595, 3.925140723203876, 2.9985989857576283, 3.882594901197809, 4.831830005212984, 5.772602012151228, 6.817315336272721, 7.7451602856903605, 8.763220133293869, 9.740529690943264, 10.694716858285737, 11.740620560647004, 12.733639604475051, 12.615891161285756, 11.676445732248238, 10.651968692800022, 9.930177388031526, 8.966669727830283, 7.936344133741367, 6.869734596309015, 5.9028228674470675, 4.864590566018277, 3.941581131370679, 4.908438398893095, 5.859346860508521, 6.702561993044365, 7.7465908652744275, 8.716829028705327, 9.675774501498559, 10.632819775837136, 11.568616963421212, 12.52631462402785, 13.565932507075571, 13.547762811163183, 12.603091917772122, 11.674662353661803, 10.80774681762428, 9.861653417285519, 8.79963937707312, 7.82839854480909, 6.832282953732409, 5.862437085581963, 4.942681082038193, 5.873526920338041, 6.8350568928595505, 7.72667128014355, 8.77783522041733, 9.69720416156439, 10.7260502109045, 11.677747990693218, 12.535089943824559, 13.459362856023464, 14.466468274980619, 14.562386309334016, 13.565524050395048, 12.704880625748707, 11.665334433741252, 10.700902458829036, 9.732946339473315, 8.80140861379933, 7.869713772488454, 6.916128066889833, 5.957165908025901, 6.870463039184079, 7.827368919227282, 8.777490048398906, 9.724378802130778, 10.664719714121022, 11.63906444556332, 12.678708026781928, 13.547685835035319, 14.4182173885258, 15.42971529817475, 15.559749870913464, 14.628887275707182, 13.74327397064394, 12.737906442755367, 11.718405551822464, 10.662747812878079, 9.818574957631691, 8.91206405662973, 7.950694564389041, 6.889142044130956, 7.860213030752832, 8.895597883515611, 9.82374906599464, 10.676193133259346, 11.633783918230808, 12.613892751558094, 12.832949635010333, 13.755651137154429, 14.611716257177358, 15.541109855499686, 16.47074616598099, 15.675501777043428, 14.740827348477563, 13.574156463839511, 12.551165304351851, 11.61401199110761, 10.81356685750835, 9.855941269134, 8.853091451969954, 7.91013827469517, 8.799994549624921, 9.737035822873857, 10.672802406281827, 11.665024579521905, 12.639287612520945, 12.671288142507205, 11.806934344861293, 12.744793775964663, 13.678534676031884, 14.639714282092209, 15.603199823129913, 16.43412588437789, 15.481014096765215, 14.510197547932577, 13.498555812289185, 12.656977756996737, 11.874746337431386, 10.824382035712832, 9.79064718473579, 8.969367957041884, 9.764076133291924, 10.664614797477102, 11.629613524824666, 12.585476521148863, 12.733038003925031, 11.742585171213063, 10.808062265956794, 11.761681876176995, 12.704543046081184, 13.65677319178289, 14.637080784291932, 15.611726869473067, 16.432699744302063], [16.492496930785595, 15.504532970001767, 14.635250289922638, 13.57570470513794, 12.636187323540105, 11.739707719720236, 10.758632422002883, 10.066481715859524, 10.841431756475714, 11.780146509127427, 11.61505611964439, 10.734560857255222, 9.738059009026184, 10.74791648058936, 11.675366352360005, 12.632720687769606, 13.684134142456692, 14.550003579515597, 15.396716316638788, 16.350811949932226, 15.490033603638313, 14.559977160451853, 13.629761132037467, 12.689415321775392, 11.707033110033505, 10.801483118396847, 9.803856047115822, 8.997278517568876, 9.901667807129147, 10.906501603568467, 11.906649362838168, 11.669444325681773, 10.730381572924365, 11.68195168781056, 12.632597822443651, 13.59747731116822, 14.637413779339457, 15.530456003221506, 16.394977348169554, 15.498043478217276, 14.627540198175934, 13.626945566980583, 12.661520657973925, 11.682479274975387, 10.761379884471307, 9.835661544694343, 8.841564039492773, 8.050709003103496, 8.879490421573447, 9.90766788329807, 10.886351000467476, 11.84141767096289, 11.768210818008853, 12.720379135691656, 13.607027440231526, 14.627904081736983, 15.608463326103283, 16.375994312276767, 15.436481855094598, 14.538775692810196, 13.714947097181494, 12.669191216086396, 11.724309294040712, 10.67190728959912, 9.742756084879497, 8.858018941662095, 7.901628994298624, 7.048928373377694, 7.904264800821321, 8.862719906028051, 9.820100977409428, 10.790189880860089, 11.764758860571177, 12.740498365501628, 13.713001793663963, 14.683662799524276, 15.736347785674297, 15.528195439667968, 14.507997772018296, 13.56803191159024, 12.725943928773258, 11.676745201437988, 10.75133726438799, 9.687817826901638, 8.757122693202291, 7.856348402759018, 6.926670513185499, 6.00970749941999, 6.875759008190498, 7.849228550716246, 8.85135972752312, 9.854642921011774, 10.821159653236585, 11.76189351481905, 12.756486781172601, 13.720323640448827, 14.75211751763538, 14.667481513525525, 13.624946986560115, 12.679506738030076, 11.687641956039878, 10.6695669251202, 9.787434477732939, 8.784916756794505, 7.779575261628447, 6.932761892916916, 5.9649551628072714, 4.950021896430718, 5.937590553208683, 6.905696631790358, 7.909571635230278, 8.853766714162097, 9.865140936354413, 10.849738472592902, 11.7877467975342, 12.730904843809089, 13.736040937173739, 13.842292260196505, 12.845944918902456, 11.845304755669998, 10.645527571062447, 9.705570711453642, 8.77060991954608, 7.776629149595681, 6.813635785840337, 5.970079826570689, 4.988166506977947, 3.9408970648492683, 4.895311991176071, 5.919523163303596, 6.991186978299481, 7.928583183642491, 8.930693266582908, 9.877857918466947, 10.809166438651403, 11.817411938459603, 12.661462765160893, 12.809326792388704, 11.804657294468484, 10.875591465943952, 9.745833931992186, 8.708490533056434, 7.745157824752804, 6.77835690599447, 5.780409622804752, 4.943155832738511, 3.926246672145938, 2.984084111982376, 3.942368180418446, 4.961328257434552, 5.971078421236372, 6.947275177453991, 7.945429901738838, 8.851618389313836, 9.836567770381377, 10.747329562538557, 11.694749481857425, 11.851730338269855, 10.896484513224234, 9.886938547158937, 8.81341531959979, 7.757109752560595, 6.777095027874347, 5.810244100648379, 4.854585964388825, 3.9065850039744707, 2.9462465485535114, 2.0107226437180814, 2.9909913112857667, 3.9699331784111758, 4.987846995245301, 5.981261206782971, 6.960834352424892, 7.887335130947327, 8.842075785956908, 9.769525672010491, 10.703539483424743, 10.96910693686294, 9.923916494400975, 8.934738337209156, 7.903257829418115, 6.847181839554363, 5.846559937900725, 4.852483744177241, 3.9096144135049813, 2.928343404926613, 1.9920542811170443, 1.0561811168713198, 2.045407558302678, 2.9752453935238865, 4.031599923010192, 4.97759011242576, 5.984932991232411, 7.054930704433817, 8.056351042563108, 8.983978012072315, 9.993903125127478, 10.039026916717603, 8.97136196086044, 7.940728397722241, 6.9864433993950925, 6.03969580540874, 5.0185932422606525, 3.9885161157997318, 2.9624762778329217, 2.034110811503102, 0.9592845137592569, 0.0, 1.0189984778216357, 2.0637226067284375, 3.043665396294091, 4.0941193308516395, 5.086640185608441, 6.150376298066299, 7.14274822957638, 8.092491978745159, 9.083269098863079, 10.148187189206082, 9.88798355474005, 8.886573062985715, 7.917941009672887, 7.025066506817729, 6.031338481244997, 5.0122338664921955, 3.9854917714007043, 2.9768721848271738, 1.9612728061722904, 0.9313716354749433, 2.002539486600784, 3.0492987037040766, 4.068999279299442, 5.048338126358389, 6.079730336528246, 7.087723094735917, 8.050269675770862, 9.004894442406213, 10.006404136691117, 11.040768523643695, 10.830754505598271, 9.813188698110517, 8.955954267907648, 7.889918201167028, 6.844172541139623, 5.910060776717245, 4.854418937786621, 3.8910762597269315, 2.920942072258502, 1.9261429184746879, 2.9415567682388146, 3.9573349225711967, 4.890136800231435, 5.929836502462549, 6.893795770261492, 7.848005201588151, 8.894006314639405, 9.856253989699596, 10.907095598545622, 11.88320272866873, 11.695711075968863, 10.697864742079418, 9.873881701920968, 8.902317685005842, 7.829331175840317, 6.842659385489235, 5.865149130151485, 4.848401419179767, 3.8662102806806806, 2.923310387438552, 3.8725454914537276, 4.813317498391972, 5.858030822513464, 6.785875771931104, 7.803935619534613, 8.781245177184006, 9.73543234452648, 10.781336046887747, 11.774355090715794, 12.828249072911786, 12.635730246007496, 11.61125320655928, 10.853438084007415, 9.885799049682214, 8.845162277126523, 7.771715032663147, 6.8048033038012, 5.76657100237241, 4.809192426293731, 3.9491538851338377, 4.900062346749264, 5.743277479285109, 6.787306351515172, 7.757544514946071, 8.716489987739303, 9.67353526207788, 10.609332449661956, 11.567030110268593, 12.606647993316315, 13.667032427787605, 13.56237643153138, 12.633946867421061, 11.70972725397841, 10.76363385363965, 9.701619813427252, 8.730378981163222, 7.734263390086541, 6.764417521936095, 5.810292376961245, 4.914242406578785, 5.875772379100294, 6.767386766384294, 7.818550706658074, 8.737919647805134, 9.766765697145246, 10.718463476933962, 11.575805430065303, 12.500078342264208, 13.507183761221363, 14.545640943035234, 14.524808564154306, 13.664165139507965, 12.567314870095384, 11.602882895183168, 10.634926775827447, 9.703389050153461, 8.771694208842586, 7.818108503243966, 6.824777202948954, 5.911178525424822, 6.868084405468025, 7.818205534639651, 8.765094288371522, 9.705435200361766, 10.679779931804065, 11.719423513022672, 12.588401321276063, 13.458932874766544, 14.470430784415495, 15.461756032055382, 15.58817178946644, 14.702558484403198, 13.639886879109499, 12.620385988176597, 11.56472824923221, 10.720555393985823, 9.81404449298386, 8.818305859312092, 7.756753339054009, 6.9009285169935755, 7.936313369756354, 8.864464552235383, 9.71690861950009, 10.674499404471552, 11.654608237798838, 12.619292052384678, 13.529608989977802, 14.474988068747578, 15.404381667069906, 16.334017977551213, 16.634786290802687, 15.70011186223682, 14.476136900193643, 13.453145740705983, 12.515992427461741, 11.715547293862482, 10.723552564057051, 9.720702746893005, 8.777749569618221, 7.840710035865665, 8.7777513091146, 9.713517892522571, 10.70574006576265, 11.680003098761691, 11.922526665965414, 12.716325066134765, 13.654184497238134, 14.634063246326168, 15.595242852386493, 16.558728393424197, 17.39341039813715, 16.440298610524472, 15.412177984286709, 14.400536248643316, 13.558958193350868, 12.766801569037263, 11.691993330635883, 10.65825847965884, 9.836979251964936, 8.804791619532669, 9.705330283717846, 10.670329011065409, 11.626192007389605, 11.773753490165774, 10.99382369467127, 11.717452987230265, 12.671072597450467, 13.660071616375468, 14.616057705542147, 15.59636529805119, 16.571011383232324, 17.39198425806132], [17.511495408607228, 16.5235314478234, 15.63161115712915, 14.572065572344451, 13.632548190746617, 12.709660315043743, 11.72858501732639, 10.914228011598194, 9.901578397184542, 10.840293149836254, 10.955615255171622, 10.104762948731414, 10.757057486847819, 11.766914958410995, 12.694364830181643, 13.651719165591244, 14.70313262027833, 15.569002057337233, 16.415714794460424, 17.369810427753865, 16.509032081459946, 15.578975638273487, 14.62612199924398, 13.685776188981905, 12.703393977240017, 11.771435713720354, 10.77380864243933, 9.845024813307546, 8.961814447837975, 9.966648244277295, 10.966796003546996, 11.039646417157966, 11.749380050746, 12.700950165632195, 13.651596300265286, 14.616475788989858, 15.656412257161096, 16.549454481043142, 17.41397582599119, 16.517041956038913, 15.646538675997569, 14.645944044802217, 13.657881525180438, 12.6788401421819, 11.757740751677819, 10.80561414001785, 9.81151663481628, 8.898455298842165, 7.939637062282276, 8.967814524006897, 9.935328019431275, 10.880783859529242, 11.778479035574072, 12.710988395346357, 13.652288740058726, 14.661505653420342, 15.7249625536862, 16.581975019606002, 16.455480332916235, 15.557774170631832, 14.733945575003128, 13.688189693908031, 12.720670161247224, 11.668268156805633, 10.73911695208601, 9.827971536985602, 8.871581589622132, 7.92898215098599, 6.964411441530149, 7.922866546736879, 8.869077996373226, 9.82955606942644, 10.79291285265531, 11.76865235758576, 12.741155785748095, 13.711816791608408, 14.753929276863035, 15.606023653839033, 15.526996249839932, 14.587030389411876, 13.744942406594893, 12.695743679259623, 11.747698131594502, 10.68417869410815, 9.753483560408803, 8.826300998082525, 7.896623108509006, 6.889761277028287, 5.935905648899325, 6.909375191425074, 7.896415583218613, 8.894009109578125, 9.849313645320716, 10.790047506903182, 11.784640773256733, 12.748477632532959, 13.758444912196376, 14.674280088703856, 14.643945464381751, 13.698505215851712, 12.706640433861512, 11.688565402941835, 10.806432955554573, 9.80391523461614, 8.798573739450081, 7.902714488240423, 6.9349077581307785, 5.919974491754224, 4.99773719391751, 5.950752487485852, 6.954627490925772, 7.882586270398014, 8.884269853267693, 9.868867389506182, 10.768748319712564, 11.711906365987453, 12.717042459352102, 13.638265649857622, 13.864943396724092, 12.864303233491635, 11.664526048884081, 10.724569189275277, 9.789608397367715, 8.795627627417316, 7.832634263661972, 6.9400324218941964, 5.958119102301454, 4.910849660172775, 3.9554586318849, 4.964579018999091, 6.036242833994976, 6.937197656343474, 7.939307739283891, 8.858859440645311, 9.790167960829766, 10.798413460637967, 11.642464287339257, 12.585290627714112, 12.82365577229012, 11.894589943765588, 10.76483240981382, 9.727489010878068, 8.764156302574438, 7.797355383816105, 6.799408100626387, 5.935671718598188, 4.896199267469445, 3.954036707305883, 3.0025148211272747, 3.969942730135535, 4.979692893937355, 5.955889650154974, 6.954044374439821, 7.8326199114922, 8.81756929255974, 9.72833108471692, 10.675751004035789, 11.660036594591064, 11.91548299104587, 10.905937024980574, 9.832413797421424, 8.77610823038223, 7.796093505695983, 6.829242578470015, 5.87358444221046, 4.925583481796107, 3.9161991438770185, 2.9806752390415885, 2.000406571473903, 2.978547651112159, 3.9964614679462835, 4.962262728961335, 5.941835874603256, 6.868336653125691, 7.823077308135272, 8.750527194188855, 9.684541005603107, 10.650137271675161, 10.942914972222612, 9.953736815030792, 8.922256307239751, 7.866180317375999, 6.8655584157223615, 5.871482221998877, 4.928612891326617, 3.947341882748249, 3.01105275893868, 2.0432484724350193, 1.0540220310036612, 1.9838598662248699, 3.0126014451885554, 3.958591634604124, 4.965934513410775, 6.03593222661218, 7.0373525647414725, 7.96497953425068, 8.974904647305841, 9.955666321461184, 9.990360438682076, 8.959726875543877, 8.005441877216729, 7.058694283230376, 6.037591720082289, 5.007514593621368, 3.981474755654557, 3.0531092893247376, 1.9782829915808926, 1.0189984778216357, 0.0, 1.0447241289068019, 2.0246669184724553, 3.075120853030004, 4.067641707786805, 5.131377820244664, 6.123749751754746, 7.073493500923525, 8.064270621041445, 9.129188711384447, 10.146858722426852, 9.905571540807351, 8.936939487494524, 8.044064984639364, 7.050336959066631, 6.03123234431383, 5.004490249222339, 3.9958706626488096, 2.9802712839939263, 1.950370113296579, 1.066034695890678, 2.0303002258824407, 3.0500008014778066, 4.029339648536753, 5.06073185870661, 6.068724616914282, 7.031271197949226, 7.985895964584578, 8.98740565886948, 10.021770045822059, 11.041066941939901, 10.832187175932152, 9.974952745729285, 8.908916678988664, 7.863171018961259, 6.92905925453888, 5.873417415608256, 4.910074737548567, 3.9399405500801374, 2.9451413962963233, 2.0232972093760635, 3.039075363708445, 3.9718772413686834, 5.011576943599797, 5.97553621139874, 6.9297456427254, 7.975746755776654, 8.937994430836845, 9.988836039682871, 10.964943169805979, 11.899361424639073, 11.716863219901052, 10.892880179742603, 9.921316162827477, 8.848329653661953, 7.861657863310869, 6.88414760797312, 5.867399897001403, 4.8852087585023165, 3.9423088652601876, 3.092717078425082, 4.033489085363326, 4.939771263650712, 5.867616213068352, 6.885676060671861, 7.862985618321254, 8.817172785663727, 9.863076488024996, 10.856095531853043, 11.909989514049036, 12.902658820281054, 12.630251684380914, 11.87243656182905, 10.90479752750385, 9.86416075494816, 8.790713510484784, 7.823801781622836, 6.785569480194046, 5.828190904115368, 4.968152362955474, 4.120233933720619, 4.963449066256463, 5.869046792652419, 6.839284956083319, 7.7982304288765505, 8.755275703215128, 9.691072890799203, 10.64877055140584, 11.688388434453563, 12.748772868924853, 13.698220891214657, 13.652945345242696, 12.728725731800047, 11.782632331461286, 10.720618291248888, 9.749377458984858, 8.753261867908178, 7.7834159997577315, 6.829290854782881, 5.93324088440042, 5.095943966071649, 5.987558353355648, 6.9309068290793965, 7.819660088942383, 8.848506138282492, 9.80020391807121, 10.65754587120255, 11.581818783401456, 12.58892420235861, 13.627381384172482, 14.660653023837583, 14.683163617329598, 13.58631334791702, 12.621881373004804, 11.653925253649083, 10.722387527975098, 9.790692686664222, 8.837106981065602, 7.84377568077059, 6.930177003246458, 6.08825599243938, 7.0383771216110045, 7.877450410792843, 8.787175641499015, 9.761520372941314, 10.801163954159922, 11.67014176241331, 12.540673315903792, 13.552171225552742, 14.54349647319263, 15.548862116131016, 15.721556962224831, 14.658885356931135, 13.639384465998234, 12.583726727053847, 11.739553871807459, 10.833042970805497, 9.83730433713373, 8.775751816875646, 7.919926994815211, 7.156484956727709, 8.084636139206738, 8.829264741921412, 9.756239845608802, 10.736348678936087, 11.701032493521927, 12.61134943111505, 13.556728509884826, 14.486122108207153, 15.415758418688458, 16.404803653015467, 16.719110340058457, 15.495135378015279, 14.47214421852762, 13.534990905283378, 12.734545771684118, 11.74255104187869, 10.739701224714644, 9.79674804743986, 8.8597085136873, 8.147953400590794, 9.054077028049804, 9.81809618818397, 10.76174353989894, 11.69701148484121, 12.682748352221532, 13.622206792304816, 14.4899100910303, 15.426787025307826, 16.39027256634553, 17.339297661635495, 17.459297088346105, 16.431176462108347, 15.419534726464953, 14.577956671172505, 13.7858000468589, 12.710991808457521, 11.677256957480479, 10.855977729786574, 9.823790097354303, 9.075532375194038, 10.010888146592642, 10.764414258935522, 10.833900130874602, 11.84156999040994, 12.687405582553772, 13.641025192773974, 14.630024211698975, 15.612418572748659, 16.5927261652577, 17.590009861053957, 18.410982735882953], [18.408676251398067, 17.42071229061424, 16.50900505945716, 15.44945947467246, 14.509942093074626, 13.587054217371753, 12.6059789196544, 11.791621913926203, 10.778972299512553, 9.96968864702233, 9.945088206645693, 10.9025202694048, 11.71672223794148, 12.726579709504657, 13.655885354710444, 14.613239690120045, 15.664653144807131, 16.613726186244037, 17.460438923367224, 18.414534556660666, 17.406212924250784, 16.476156481064326, 15.503515901571989, 14.563170091309914, 13.580787879568026, 12.648829616048364, 11.651202544767338, 10.722418715635557, 9.839208350165986, 9.042851570433433, 10.009908520931663, 10.814937565801536, 11.763131913747852, 12.729412994938313, 13.60671550955746, 14.585441722474297, 15.625378190645534, 16.48130866738552, 17.435258840956323, 17.561766084945717, 16.553726109746265, 15.553131478550913, 14.535275427508447, 13.556234044509909, 12.635134654005828, 11.68300804234586, 10.68891053714429, 9.775849201170177, 8.817030964610286, 7.994179783574407, 8.953046251316866, 9.868557673770722, 10.758476187284932, 11.690985547057217, 12.632285891769586, 13.641502805131202, 14.70495970539706, 15.537250890699198, 16.476763347881366, 16.602498299538635, 15.641133008751824, 14.595377127656727, 13.598064063575233, 12.545662059133642, 11.616510854414019, 10.705365439313612, 9.74897549195014, 8.806376053314, 7.841805343858158, 6.949231806304389, 7.8867962282588175, 8.81732988366792, 9.77291000436617, 10.74864950929662, 11.721152937458955, 12.691813943319268, 13.709205147956233, 14.56129952493223, 15.581497192581901, 15.631754518318678, 14.652129840343589, 13.602931113008319, 12.625092033922511, 11.561572596436159, 10.630877462736812, 9.703694900410534, 8.774017010837015, 7.767155179356296, 6.813299551227335, 5.935740450992584, 6.914133815104203, 7.881782923819605, 8.829310797031576, 9.770044658614042, 10.744428349518802, 11.708265208795028, 12.713720783289574, 13.629555959797052, 14.562591448363854, 14.743229344758515, 13.647331498491948, 12.62925646757227, 11.747124020185009, 10.744606299246575, 9.739264804080518, 8.780108390568433, 7.812301660458788, 6.797368394082233, 5.87513109624552, 4.968470719371442, 5.972345722811363, 6.870360084639494, 7.864267004978553, 8.848864541217042, 9.724024190805762, 10.66718223708065, 11.6723183304453, 12.593541520950819, 13.56146182481109, 13.909027362398435, 12.605217113514517, 11.665260253905712, 10.73029946199815, 9.736318692047751, 8.773325328292408, 7.817426324222206, 6.835513004629464, 5.788243562500784, 4.832852534212909, 3.9822972508846814, 5.053961065880566, 5.924971470584954, 6.919304890994751, 7.814135311738509, 8.745443831922964, 9.753689331731165, 10.597740158432455, 11.54056649880731, 12.520174200377118, 12.939314072672389, 11.705523474444256, 10.668180075508504, 9.704847367204874, 8.73804644844654, 7.740099165256822, 6.813065620926197, 5.773593169797453, 4.831430609633892, 3.8799087234552836, 2.987660962021126, 3.9974111258229463, 4.9436634643964545, 5.934041526150681, 6.787895782585398, 7.7728451636529385, 8.683606955810118, 9.631026875128986, 10.615312465684262, 11.570558290729883, 11.950661153887374, 10.77310486205186, 9.716799295012665, 8.736784570326417, 7.769933643100449, 6.814275506840895, 5.858692753192112, 4.793593046205027, 3.8580691413695973, 2.877800473801912, 1.9962658829977502, 3.0141796998318746, 3.9175386000545327, 4.897111745696454, 5.8236125242188885, 6.7783531792284695, 7.705803065282053, 8.639816876696305, 9.60541314276836, 10.650603585230323, 10.998460943937594, 9.862947371870186, 8.806871382006435, 7.806249480352796, 6.812173286629312, 5.869303955957052, 4.888032947378684, 3.9517438235691147, 2.9206423747630286, 1.93141593333167, 1.0015780981104612, 1.967877316281754, 2.9138675056973224, 3.921210384503973, 4.991208097705378, 5.99262843583467, 6.920255405343878, 7.93018051839904, 8.910942192554382, 9.978607148411545, 10.00445100445068, 9.050166006123531, 8.103418412137177, 7.082315848989091, 6.05223872252817, 5.026198884561359, 4.09783341823154, 3.0230071204876943, 2.0637226067284375, 1.0447241289068019, 0.0, 0.9799427895656536, 2.030396724123202, 3.022917578880003, 4.086653691337862, 5.079025622847944, 6.028769372016723, 7.019546492134642, 8.084464582477645, 9.10213459352005, 10.103545085274385, 9.981663616401326, 9.088789113546166, 8.095061087973434, 7.075956473220632, 6.049214378129141, 5.040594791555611, 4.0249954129007275, 2.995094242203381, 2.0511293462596956, 0.985576096975639, 2.0052766725710045, 2.9846155196299513, 4.016007729799808, 5.02400048800748, 5.986547069042424, 6.941171835677776, 7.942681529962679, 8.977045916915259, 9.9963428130331, 11.013908620520855, 11.019676874636085, 9.953640807895464, 8.90789514786806, 7.973783383445683, 6.918141544515059, 5.95479886645537, 4.98466467898694, 3.9898655252031254, 3.0083918597450814, 2.008976426701383, 2.9417783043616215, 3.9814780065927353, 4.941225853142361, 5.895435284469021, 6.941436397520275, 7.896865999714535, 8.944354876308816, 9.920462006431924, 10.854880261265018, 11.852726595154463, 11.937604308649407, 10.96604029173428, 9.893053782568755, 8.906381992217673, 7.928871736879923, 6.912124025908206, 5.929932887409119, 4.901973616353851, 3.952738512338676, 3.011966505400432, 3.909672326643651, 4.83751727606129, 5.8555771236647995, 6.828675260064875, 7.782862427407348, 8.821948056902686, 9.814967100730733, 10.86550835067498, 11.858177656907, 12.807210644302652, 12.917160690735853, 11.949521656410651, 10.90888488385496, 9.835437639391586, 8.868525910529637, 7.830293609100848, 6.87291503302217, 5.927817114049137, 4.9802553676342125, 3.9419264862935695, 4.838947855645358, 5.809186019076257, 6.768131491869489, 7.725176766208065, 8.66097395379214, 9.618671614398778, 10.6582894974465, 11.71867393191779, 12.668121954207594, 13.600918659030773, 13.77344986070685, 12.827356460368089, 11.76534242015569, 10.79410158789166, 9.79253390669818, 8.822688038547735, 7.841915037245623, 6.892905635494084, 5.955965399985242, 4.966035773392754, 5.9008078920723355, 6.789561151935321, 7.818407201275431, 8.770104981064147, 9.627446934195488, 10.551719846394393, 11.558825265351548, 12.59728244716542, 13.63055408683052, 14.589037197851997, 14.631037476823822, 13.666605501911606, 12.698649382555885, 11.7671116568819, 10.829964725454225, 9.859648747285926, 8.856399863233332, 7.889841754340122, 6.948277426352973, 6.016854541648112, 6.847351473785782, 7.757076704491954, 8.731421435934253, 9.77106501715286, 10.640042825406248, 11.51057437889673, 12.52207228854568, 13.513397536185566, 14.518763179123953, 15.546241717905946, 15.703609485837937, 14.684108594905034, 13.628450855960649, 12.784278000714261, 11.8723150095955, 10.849928519596471, 9.788375999338387, 8.879591745908874, 8.002260273159838, 7.074109090680809, 7.7991658049143515, 8.72614090860174, 9.706249741929026, 10.670933556514866, 11.581250494107987, 12.526629572877763, 13.45602317120009, 14.385659481681396, 15.374704716008402, 16.30937914457427, 16.53985950692208, 15.516868347434421, 14.57971503419018, 13.758748721825214, 12.70407156640749, 11.701221749243444, 10.75826857196866, 9.819373264780962, 8.979316562931844, 8.043549979523874, 8.787997251176911, 9.73164460289188, 10.66691254783415, 11.652649415214471, 12.592107855297753, 13.459811154023237, 14.396688088300763, 15.360173629338467, 16.309198724628434, 17.26231051224111, 17.475900591015147, 16.464258855371753, 15.622680800079307, 14.747320571387702, 13.672512332986322, 12.63877748200928, 11.817498254315375, 10.783454848447965, 9.906895537535089, 9.000361098066712, 9.734315321928463, 10.783656869732113, 11.595615519128291, 12.65152149411897, 13.57521975508542, 14.433802783973936, 15.433006409909442, 16.396539758138466, 17.28103675937605, 18.21399615977796], [18.315286709306545, 17.447763035638594, 16.519538702036286, 15.501208264904097, 14.561690883306262, 13.570282150361288, 12.589206852643935, 11.62320536097203, 10.810244898499827, 9.871530145848114, 10.230299721715262, 10.769878244662433, 11.775511688080378, 12.683505412593858, 13.616326780971415, 14.570255556307256, 15.60548317680227, 16.481818301525777, 17.482935757636334, 18.39650159259609, 17.312823382159262, 17.45609927062998, 16.483458691137642, 15.543112880875569, 14.560730669133681, 13.628772405614017, 12.631145334332992, 11.702361505201209, 10.819151139731638, 10.022794359999086, 9.160414892669724, 9.834994776235881, 10.783189124182197, 11.749470205372658, 12.626772719991806, 13.605498932908642, 14.64543540107988, 15.501365877819868, 16.45531605139067, 17.37785225186458, 16.482198671667142, 16.533074268116568, 15.515218217074102, 14.536176834075563, 13.615077443571483, 12.662950831911512, 11.668853326709943, 10.755791990735828, 9.796973754175937, 8.974122573140061, 8.103552623054927, 8.888614884205067, 9.778533397719277, 10.711042757491562, 11.65234310220393, 12.661560015565547, 13.725016915831405, 14.557308101133547, 15.496820558315713, 16.4185844664575, 15.685843641131921, 15.575319917222382, 14.578006853140888, 13.525604848699297, 12.596453643979673, 11.685308228879265, 10.728918281515794, 9.786318842879652, 8.82174813342381, 7.929174595870043, 7.037302599996879, 7.837387094102266, 8.792967214800514, 9.768706719730964, 10.7412101478933, 11.711871153753613, 12.72926235839058, 13.581356735366578, 14.60155440301625, 15.447840685237543, 14.708096581129249, 14.582873902573974, 13.605034823488166, 12.541515386001814, 11.610820252302467, 10.683637689976187, 9.753959800402669, 8.747097968921949, 7.793242340792988, 6.915683240558238, 6.064640186842265, 6.901840134253952, 7.849368007465922, 8.790101869048389, 9.76448555995315, 10.728322419229375, 11.73377799372392, 12.649613170231401, 13.5826486587982, 14.496567265694972, 13.645986849480922, 13.609199257137924, 12.72706680975066, 11.724549088812227, 10.71920759364617, 9.760051180134086, 8.792244450024441, 7.777311183647886, 6.855073885811173, 5.948413508937096, 5.122852094549424, 5.890417295073841, 6.884324215412899, 7.8689217516513885, 8.74408140124011, 9.687239447514997, 10.692375540879647, 11.613598731385167, 12.581519035245437, 13.439010529062044, 12.755443247656402, 12.645203043471366, 11.710242251563804, 10.716261481613403, 9.75326811785806, 8.797369113787859, 7.815455794195117, 6.768186352066437, 5.812795323778563, 4.962240040450335, 4.126775864207392, 4.945028681019301, 5.939362101429098, 6.834192522172856, 7.76550104235731, 8.773746542165512, 9.617797368866801, 10.560623709241657, 11.540231410811465, 12.469297239335997, 11.824814615676042, 11.648122865074157, 10.684790156770527, 9.717989238012192, 8.720041954822475, 7.79300841049185, 6.753535959363107, 5.811373399199545, 4.859851513020937, 3.9676037515867795, 3.060627764953166, 3.9637206748308014, 4.954098736585028, 5.807952993019745, 6.792902374087285, 7.703664166244465, 8.651084085563333, 9.635369676118609, 10.59061550116423, 11.600161467229526, 11.033739209465928, 10.696742084578318, 9.71672735989207, 8.749876432666102, 7.794218296406548, 6.838635542757765, 5.77353583577068, 4.8380119309352505, 3.8577432633675657, 2.976208672563404, 2.04078947812904, 2.937595810488879, 3.9171689561308005, 4.843669734653235, 5.798410389662816, 6.7258602757164, 7.659874087130652, 8.625470353202706, 9.67066079566467, 10.711367252728506, 10.154335140809714, 9.786814171572088, 8.78619226991845, 7.792116076194965, 6.849246745522705, 5.867975736944337, 4.931686613134768, 3.9005851643286817, 2.9113587228973237, 1.9815208876761148, 0.9879345267161004, 1.9339247161316688, 2.94126759493832, 4.011265308139725, 5.012685646269017, 5.9403126157782244, 6.950237728833387, 7.9309994029887285, 8.998664358845891, 10.02929792198409, 10.030108795689184, 9.08336120170283, 8.062258638554743, 7.032181512093823, 6.006141674127012, 5.077776207797193, 4.002949910053347, 3.0436653962940907, 2.0246669184724553, 0.9799427895656536, 0.0, 1.0504539345575485, 2.0429747893143495, 3.106710901772208, 4.0990828332822895, 5.048826582451069, 6.039603702568988, 7.104521792911992, 8.122191803954397, 9.123602295708732, 10.961606405966979, 10.06873190311182, 9.075003877539087, 8.055899262786285, 7.029157167694795, 6.020537581121264, 5.004938202466381, 3.975037031769034, 3.031072135825349, 1.9655188865412927, 1.025333883005351, 2.0046727300642977, 3.0360649402341546, 4.044057698441827, 5.006604279476771, 5.9612290461121225, 6.962738740397026, 7.997103127349606, 9.016400023467448, 10.0339658309552, 11.99961966420174, 10.93358359746112, 9.887837937433714, 8.953726173011336, 7.898084334080712, 6.934741656021023, 5.964607468552593, 4.969808314768779, 3.988334649310735, 2.9748280450538496, 2.0420261673936113, 3.0291587879461614, 3.9612830635767073, 4.915492494903367, 5.961493607954621, 6.916923210148882, 7.964412086743163, 8.94051921686627, 9.874937471699365, 10.87278380558881, 12.917547098215058, 11.945983081299932, 10.872996572134408, 9.886324781783326, 8.908814526445576, 7.892066815473859, 6.909875676974772, 5.8678252347063165, 4.9185901306911415, 3.977818123752898, 3.0099201896756407, 3.9377651390932806, 4.908597192129871, 5.848732470499222, 6.802919637841695, 7.842005267337033, 8.835024311165078, 9.885565561109328, 10.878234867341346, 11.827267854736998, 13.897103480301505, 12.929464445976306, 11.888827673420614, 10.81538042895724, 9.848468700095292, 8.810236398666502, 7.852857822587823, 6.893668732401602, 5.946106985986678, 4.907778104646035, 3.939195718677348, 4.909433882108248, 5.868379354901479, 6.8254246292400556, 7.761221816824131, 8.718919477430768, 9.75853736047849, 10.817437210986755, 11.76688523327656, 12.699681938099738, 14.753392650272504, 13.807299249933743, 12.745285209721345, 11.774044377457315, 10.758385525050647, 9.788539656900202, 8.807766655598089, 7.858757253846549, 6.921817018337708, 5.93188739174522, 5.001055755104326, 5.8898090149673115, 6.918655064307421, 7.8703528440961374, 8.727694797227478, 9.651967709426383, 10.659073128383538, 11.69753031019741, 12.729317365899485, 13.687800476920962, 15.610980266389477, 14.646548291477261, 13.67859217212154, 12.747054446447555, 11.795816343806692, 10.825500365638392, 9.822251481585798, 8.855693372692587, 7.914129044705439, 6.982706160000577, 5.947599336817772, 6.8573245675239445, 7.8316692989662435, 8.87131288018485, 9.740290688438238, 10.61082224192872, 11.62232015157767, 12.613645399217557, 13.619011042155943, 14.646489580937937, 16.683552275403592, 15.664051384470689, 14.608393645526304, 13.764220790279916, 12.838166627947967, 11.815780137948938, 10.754227617690853, 9.845443364261339, 8.828607062050002, 7.900455879570973, 6.899413667946342, 7.826388771633731, 8.806497604961017, 9.771181419546856, 10.681498357139978, 11.626877435909753, 12.556271034232081, 13.485907344713386, 14.474952579040393, 15.409627007606257, 17.519802296487736, 16.496811137000076, 15.559657823755835, 14.682080082115196, 13.627402926697473, 12.624553109533426, 11.681599932258642, 10.742704625070944, 9.805663351822009, 8.869896768414039, 7.888245114208901, 8.831892465923868, 9.76716041086614, 10.752897278246461, 11.692355718329743, 12.560059017055227, 13.496935951332754, 14.460421492370457, 15.409446587660424, 16.362558375273103, 18.455843380580802, 17.444201644937408, 16.602623589644963, 15.670651931677684, 14.595843693276304, 13.562108842299262, 12.740829614605357, 11.706786208737947, 10.733242326425254, 9.79042618128465, 8.834563184960453, 9.883904732764101, 10.695863382160283, 11.75176935715096, 12.67546761811741, 13.534050647005927, 14.533254272941432, 15.496787621170457, 16.38128462240804, 17.31424402280995], [17.275554990867526, 16.40803131719958, 15.479806983597268, 14.461476546465082, 13.521959164867248, 12.562655534464414, 11.58158023674706, 10.615578745075155, 9.826294939933753, 10.714520761715463, 10.758546079056124, 9.801114016297017, 10.806747459714963, 11.714741184228442, 12.647562552605999, 13.60149132794184, 14.636718948436855, 15.513054073160362, 16.514171529270918, 17.427737364230673, 16.273091663720244, 17.203148106906703, 16.369492400275625, 15.429146590013552, 14.451113378373847, 13.502854860718342, 12.53635661163412, 11.684781943365802, 10.76605888928032, 10.831299486598121, 9.858870010621132, 8.866230547870465, 9.814424895816781, 10.780705977007242, 11.65800849162639, 12.636734704543226, 13.676671172714464, 14.532601649454453, 15.486551823025255, 16.409088023499166, 15.442466953228127, 16.44306158442348, 16.510557551302778, 15.531516168304242, 14.610416777800161, 13.658290166140192, 12.664192660938623, 11.657851881118026, 10.699033644558135, 9.782627699739097, 8.846548674145748, 7.919850655839651, 8.809769169353862, 9.742278529126146, 10.683578873838515, 11.692795787200131, 12.75625268746599, 13.588543872768131, 14.528056329950298, 15.449820238092084, 14.646111922692903, 15.608566677340411, 15.573346187369566, 14.520944182927975, 13.591792978208352, 12.680647563107945, 11.724257615744474, 10.707615994488902, 9.723808023806008, 8.737679722469078, 7.7802986510876995, 6.86862286573685, 7.824202986435099, 8.799942491365549, 9.772445919527884, 10.743106925388197, 11.760498130025164, 12.612592507001162, 13.632790174650834, 14.479076456872127, 13.6576426465717, 14.616120662692003, 14.600374157716844, 13.536854720230492, 12.606159586531145, 11.678977024204867, 10.749299134631348, 9.742437303150629, 8.788581675021668, 7.836992880701306, 6.807636237933085, 5.933075905888536, 6.880603779100507, 7.821337640682973, 8.795721331587732, 9.759558190863958, 10.765013765358505, 11.680848941865985, 12.613884430432785, 13.527803037329557, 12.595532914923373, 13.608942386374215, 13.722406143979342, 12.719888423040908, 11.714546927874851, 10.755390514362766, 9.78758378425312, 8.772650517876567, 7.850413220039853, 6.869723149080165, 5.8658481456402445, 4.9216530667084255, 5.915559987047484, 6.900157523285973, 7.775317172874693, 8.718475219149582, 9.723611312514231, 10.644834503019752, 11.612754806880021, 12.470246300696628, 11.704989313098853, 12.644946172707657, 12.705581585792483, 11.711600815842084, 10.748607452086741, 9.792708448016539, 8.810795128423797, 7.763525686295117, 6.808134658007242, 5.957579374679016, 4.94266133473482, 3.9762644526538855, 4.970597873063682, 5.86542829380744, 6.796736813991894, 7.804982313800096, 8.649033140501386, 9.591859480876241, 10.57146718244605, 11.500533010970582, 10.774360681118493, 11.847482547432547, 11.680129490999207, 10.713328572240872, 9.715381289051155, 8.788347744720529, 7.748875293591786, 6.806712733428225, 5.855190847249617, 4.96294308581546, 3.971153202683005, 2.9949564464653857, 3.985334508219612, 4.839188764654329, 5.82413814572187, 6.7348999378790495, 7.682319857197918, 8.666605447753193, 9.621851272798814, 10.63139723886411, 9.98328527490838, 11.039590841947573, 10.71206669412075, 9.745215766894782, 8.789557630635228, 7.833974876986445, 6.76887516999936, 5.83335126516393, 4.853082597596245, 3.9715480067920836, 2.964005628594762, 1.9688315821234639, 2.948404727765385, 3.8749055062878197, 4.829646161297401, 5.757096047350984, 6.691109858765237, 7.6567061248372905, 8.701896567299254, 9.74260302436309, 9.103881206252165, 10.159957196115917, 9.78153160414713, 8.787455410423645, 7.844586079751385, 6.863315071173017, 5.927025947363448, 4.895924498557362, 3.906698057126003, 2.9768602219047944, 1.911150677181822, 0.9651604877662536, 1.9725033665729044, 2.991045376223597, 3.992465714352889, 4.920092683862096, 5.930017796917259, 6.910779471072601, 7.978444426929764, 9.009077990067963, 9.963362988395112, 10.13381513626038, 9.112712573112292, 8.082635446651372, 7.056595608684561, 6.128230142354742, 5.053403844610896, 4.0941193308516395, 3.075120853030004, 2.030396724123202, 1.0504539345575485, 0.0, 0.992520854756801, 2.05625696721466, 3.048628898724741, 3.9983726478935204, 4.9891497680114405, 6.054067858354444, 7.071737869396849, 8.073148361151183, 10.799256055612716, 11.119185837669368, 10.125457812096636, 9.106353197343834, 8.079611102252343, 7.070991515678813, 6.055392137023929, 5.025490966326583, 4.0558516762733525, 2.9902984269892965, 1.9477472499276658, 0.9542187955067492, 1.985611005676606, 2.993603763884278, 3.9561503449192226, 4.910775111554575, 5.912284805839478, 6.946649192792057, 7.965946088909899, 8.983511896397651, 11.5623815181154, 11.892208698765014, 10.846463038737609, 9.912351274315231, 8.856709435384607, 7.893366757324918, 6.923232569856488, 5.928433416072673, 4.913019566308546, 3.8972414119761645, 2.964439534315926, 1.978704853388613, 2.910829129019159, 3.865038560345819, 4.911039673397073, 5.866469275591334, 6.913958152185614, 7.890065282308722, 8.824483537141816, 9.822329871031261, 12.506764308548055, 12.904608182603827, 11.831621673438303, 10.84494988308722, 9.867439627749471, 8.850691916777754, 7.858559569778299, 6.790238601628632, 5.841003497613457, 4.900231490675213, 3.8579834726140465, 2.9301385231964066, 3.858143257572322, 4.798278535941673, 5.752465703284146, 6.791551332779485, 7.784570376607531, 8.835111626551779, 9.827780932783797, 10.77681392017945, 13.476127030513332, 13.878148338779832, 12.83751156622414, 11.764064321760767, 10.797152592898819, 9.758920291470028, 8.80154171539135, 7.816082099323918, 6.868520352908994, 5.830191471568351, 4.7872590016157535, 3.901807266211373, 4.8286476364624615, 5.785692910801038, 6.721490098385114, 7.67918775899175, 8.715791687599848, 9.766983276429206, 10.71643129871901, 11.64922800354219, 14.456393424390448, 14.741547362100981, 13.679533321888583, 12.708292489624553, 11.680798891972962, 10.710953023822517, 9.730180022520404, 8.781170620768865, 7.8442303852600235, 6.854300758667535, 5.844046370971675, 4.8821823990704365, 5.878923345868404, 6.83062112565712, 7.687963078788461, 8.612235990987365, 9.61934140994452, 10.657798591758391, 11.678863431341936, 12.637346542363414, 15.397193966693353, 15.580796403644499, 14.612840284288778, 13.681302558614792, 12.718229710729007, 11.747913732560708, 10.744664848508114, 9.778106739614902, 8.832803842250973, 7.855633793291963, 6.790589952685122, 5.8496979516270695, 6.824042683069369, 7.850431961941827, 8.700558969999221, 9.571090523489701, 10.582588433138651, 11.573913680778539, 12.579279323716925, 13.606757862498918, 16.44358294374206, 16.598299496637928, 15.542641757693541, 14.698468902447154, 13.760579994870282, 12.738193504871253, 11.676640984613169, 10.742770520505733, 9.671597677917353, 8.743446495438324, 7.742404283813691, 6.818762155736856, 7.798870989064143, 8.763554803649981, 9.641766638700961, 10.587145717470737, 11.516539315793064, 12.44617562627437, 13.435220860601376, 14.369895289167241, 17.420857639919667, 17.431059249167312, 16.49390593592307, 15.525070697982546, 14.470393542564823, 13.467543725400777, 12.524590548125992, 11.585695240938295, 10.64865396768936, 9.71288738428139, 8.73123573007625, 7.824265850026994, 8.759533794969265, 9.745270662349586, 10.652623999890727, 11.52032729861621, 12.457204232893737, 13.420689773931441, 14.369714869221408, 15.322826656834087, 18.356898724012733, 17.51035159726639, 16.50409945932509, 15.617026923476942, 14.542218685075563, 13.664670425307163, 12.662597862216336, 11.740014849208478, 10.830344589834393, 10.633416797151998, 9.677553800827802, 8.893973206243693, 9.688236766263408, 10.744142741254086, 11.635735899678394, 12.49431892856691, 13.493522554502416, 14.45705590273144, 15.341552903969024, 16.274512304370937], [16.297942670976703, 15.430418997308758, 14.502194663706444, 13.483864226574259, 12.544346844976424, 11.603202240667551, 10.756089438671442, 9.790087946999536, 10.73446846308725, 11.62269428486896, 11.751066933812925, 10.793634871053818, 9.980590376846948, 10.855410582738859, 11.788231951116416, 12.742160726452257, 13.777388346947271, 14.62944279760369, 15.630560253714247, 16.544126088674002, 15.295479343829422, 16.225535787015883, 15.391880080384803, 14.451534270122728, 13.473501058483023, 12.54340156692148, 11.710865813558502, 10.859291145290182, 11.674232412433817, 11.823820341354923, 10.851390865377933, 9.858751402627266, 8.988267812948767, 9.921375375517659, 10.798677890136807, 11.777404103053643, 12.81734057122488, 13.648990373897782, 14.602940547468584, 15.525476747942493, 14.464854633337303, 15.465449264532655, 16.41693763395389, 15.416546223975907, 14.419154284045222, 13.509223140623984, 12.673157821181551, 11.805860659755563, 11.691554499314936, 10.775148554495898, 9.839069528902549, 8.912371510596452, 7.950438567864278, 8.882947927636563, 9.824248272348932, 10.833465185710548, 11.887701462580694, 12.70493259721146, 13.644445054393627, 14.566208962535413, 13.66849960280208, 14.630954357449589, 15.594120211253337, 15.513465037684776, 14.584313832965153, 13.673168417864744, 12.716778470501273, 11.700136849245704, 10.716328878562809, 9.73020057722588, 8.7728195058445, 7.861143720493652, 6.964872384945515, 7.9406118898759654, 8.913115318038301, 9.883776323898614, 10.876886854468493, 11.728981231444491, 12.749178899094163, 13.595465181315456, 12.680030326680878, 13.638508342801181, 14.616347421886989, 14.529375574987293, 13.598680441287947, 12.671497878961667, 11.741819989388148, 10.73495815790743, 9.781102529778469, 8.829513735458107, 7.800157092689886, 6.9255967606453375, 6.021273177610923, 6.96200703919339, 7.912110056031063, 8.875946915307289, 9.881402489801834, 10.797237666309314, 11.730273154876114, 12.644191761772886, 11.617920595032551, 12.631330066483393, 13.655846602051747, 13.71240927779771, 12.707067782631652, 11.747911369119565, 10.78010463900992, 9.765171372633366, 8.842934074796654, 7.862244003836966, 6.858369000397046, 5.914173921465227, 5.0562293855579, 6.03806195466853, 6.8917058973180225, 7.834863943592911, 8.84000003695756, 9.76122322746308, 10.72914353132335, 11.586635025139957, 10.727376993208031, 11.667333852816835, 12.63852786753553, 12.704121670598886, 11.741128306843542, 10.785229302773338, 9.803315983180596, 8.756046541051917, 7.800655512764044, 6.950100229435817, 5.935182189491621, 4.968785307410687, 4.111267271574099, 4.98181701825077, 5.913125538435224, 6.921371038243425, 7.765421864944716, 8.708248205319572, 9.687855906889379, 10.61692173541391, 9.796748361227671, 10.869870227541725, 11.833202935845355, 11.705849426997675, 10.707902143807958, 9.78086859947733, 8.741396148348587, 7.799233588185026, 6.847711702006418, 5.955463940572261, 4.963674057439806, 3.987477301222187, 3.1260039067300287, 3.955577489097659, 4.9405268701652, 5.8512886623223785, 6.798708581641247, 7.782994172196522, 8.738239997242143, 9.74778596330744, 9.005672955017559, 10.061978522056753, 11.041993246743, 10.737736621651585, 9.78207848539203, 8.826495731743247, 7.761396024756161, 6.8258721199207315, 5.845603452353046, 4.964068861548885, 3.9565264833515625, 2.961352436880265, 2.0890741262758015, 2.9912942307311496, 3.9460348857407306, 4.873484771794313, 5.807498583208566, 6.77309484928062, 7.8182852917425825, 8.85899174880642, 8.111360351495364, 9.167436341359116, 10.168058243012753, 9.779976265180446, 8.837106934508187, 7.855835925929818, 6.919546802120249, 5.888445353314163, 4.899218911882804, 3.9693810766615956, 2.903671531938623, 1.9576813425230546, 1.0461294341991487, 1.9985245214667957, 2.999944859596088, 3.927571829105295, 4.9374969421604575, 5.9182586163158, 6.985923572172963, 8.016557135311162, 8.97084213363831, 9.917589727624664, 10.105233427869091, 9.075156301408171, 8.049116463441361, 7.120750997111543, 6.045924699367697, 5.086640185608441, 4.067641707786805, 3.022917578880003, 2.0429747893143495, 0.992520854756801, 0.0, 1.0637361124578586, 2.05610804396794, 3.0058517931367192, 3.9966289132546393, 5.061547003597643, 6.079217014640048, 7.080627506394383, 9.902339743916105, 10.92744228119436, 11.117978666853437, 10.098874052100635, 9.072131957009145, 8.063512370435614, 7.047912991780731, 6.018011821083384, 5.048372531030154, 3.9828192817460977, 2.940268104684467, 1.9467396502635501, 1.0079986857857837, 2.0159914439934554, 2.9785380250284, 3.9331627916637517, 4.9346724859486555, 5.969036872901235, 6.988333769019077, 8.005899576506831, 10.678770242558729, 11.74480630929935, 11.818899283580075, 10.884787519157697, 9.829145680227073, 8.865803002167384, 7.895668814698954, 6.90086966091514, 5.885455811151013, 4.869677656818632, 3.9368757791583935, 2.8971760769272796, 1.9332168091283366, 2.8874262404549964, 3.93342735350625, 4.888856955700511, 5.936345832294792, 6.9124529624179, 7.846871217250995, 8.84471755114044, 11.623153032991384, 12.59471704990651, 12.804057918280769, 11.817386127929687, 10.839875872591938, 9.82312816162022, 8.785184616546324, 7.716863648396657, 6.767628544381481, 5.826856537443238, 4.776454696152713, 3.848609746735073, 2.8805309376814994, 3.820666216050851, 4.774853383393324, 5.813939012888662, 6.8069580567167085, 7.857499306660957, 8.850168612892977, 9.799201600288628, 12.592515754956661, 13.58232978870684, 13.764136612992168, 12.690689368528792, 11.723777639666844, 10.685545338238054, 9.728166762159375, 8.742707146091943, 7.795145399677018, 6.756816518336375, 5.70573022515442, 4.80998078936487, 3.8510353165716387, 4.808080590910215, 5.743877778494291, 6.701575439100928, 7.738179367709025, 8.789370956538384, 9.738818978828188, 10.671615683651368, 13.572782148833777, 14.518875549172538, 14.606158368656608, 13.634917536392578, 12.607423938740988, 11.637578070590543, 10.65680506928843, 9.70779566753689, 8.770855432028048, 7.78092580543556, 6.752219894125172, 5.790355922223934, 4.901311025977581, 5.853008805766297, 6.710350758897638, 7.634623671096543, 8.641729090053698, 9.68018627186757, 10.701251111451114, 11.659734222472592, 14.513582691136682, 15.478014666048898, 15.539465331056803, 14.607927605382818, 13.644854757497033, 12.674538779328733, 11.67128989527614, 10.70473178638293, 9.74097736540447, 8.76380731644546, 7.698763475838619, 6.757871474780567, 5.911935770172395, 6.872819642051004, 7.722946650108398, 8.59347820359888, 9.60497611324783, 10.596301360887717, 11.601667003826103, 12.629145542608097, 15.55997166818539, 16.529233853682335, 16.46926680446157, 15.625093949215179, 14.687205041638308, 13.664818551639279, 12.603266031381194, 11.65094404365923, 10.57977120107085, 9.65162001859182, 8.650577806967188, 7.726935678890353, 6.973380190988525, 7.827439847086522, 8.664154318810137, 9.609533397579913, 10.53892699590224, 11.468563306383546, 12.457608540710552, 13.392282969276417, 16.537246364362996, 17.540012942547897, 16.663453949657548, 15.755084061233976, 14.700406905816255, 13.742895556583415, 12.816834657195164, 11.877939350007466, 11.556827490842856, 10.621060907434886, 9.639409253229747, 8.73243937318049, 7.9340429968936474, 8.853455137235562, 9.675011679999903, 10.542714978725387, 11.479591913002913, 12.443077454040617, 13.392102549330584, 14.345214336943263, 17.473287448456063, 16.62674032170972, 15.620488183768419, 14.757696321987359, 13.68288808358598, 12.80533982381758, 11.803267260726752, 10.913857766340463, 11.822865444591194, 11.541590320305495, 10.585727323981299, 9.80214672939719, 8.86274596818779, 9.852327216140061, 10.65812357978757, 11.516706608676087, 12.515910234611592, 13.479443582840617, 14.3639405840782, 15.296899984480113], [15.386162917253182, 14.518639243585236, 13.590414909982922, 12.572084472850737, 11.632567091252902, 10.69142248694403, 9.946132252079993, 10.743815888395922, 11.705135995135517, 12.593361816917227, 12.517302187688209, 11.559870124929102, 10.684632481531834, 9.874912169178623, 10.80773353755618, 11.761662312892021, 12.755062672609053, 13.565706685145834, 14.56682414125639, 15.480389976216143, 14.3836995901059, 15.31375603329236, 14.480100326661281, 13.539754516399206, 12.561721304759502, 11.631621813197958, 10.900908626967054, 11.81301908668657, 12.644899944482084, 12.617773878522918, 11.617626119253217, 10.62498665650255, 9.692309917633652, 8.940876961957423, 9.81817947657657, 10.796905689493407, 11.795014896886663, 12.585254261439925, 13.539204435010728, 14.461740635484636, 13.553074879613781, 14.540472057994151, 15.483094924836927, 14.504766470252385, 13.5073745303217, 12.597443386900462, 11.863200634590102, 12.75958860115195, 12.53227793379251, 11.615871988973472, 10.679792963380123, 9.678606764471736, 8.654480672549164, 7.902449514076327, 8.843749858788696, 9.811886729749583, 10.823965350122837, 11.641196484753603, 12.58070894193577, 13.502472850077556, 12.677085277419415, 13.582717707099965, 14.545883560903713, 15.455149534633133, 14.52599832991351, 13.57508598993271, 12.803135679784251, 12.540860283723278, 11.557052313040383, 10.570924011703454, 9.613542940322075, 8.627378974368934, 7.668914489630401, 6.960113476315729, 7.897748140564206, 8.862197867937649, 9.813150742010636, 10.665245118986634, 11.685442786636306, 12.531729068857599, 11.631793676331254, 12.590271692451557, 13.568110771537365, 14.559609449642336, 14.4932620773094, 13.566079514983121, 12.636401625409603, 11.597562340590391, 10.64370671246143, 9.670237169935682, 8.640880527167461, 7.691832014520619, 6.725315282295809, 5.975539394596903, 6.848373943573204, 7.81221080284943, 8.817666377343977, 9.733501553851458, 10.666537042418257, 11.580455649315029, 10.569683944682927, 11.583093416133769, 12.607609951702123, 13.610127672640557, 13.76151544112559, 12.785344941981162, 11.817538211871517, 10.798593249069205, 9.772422623396603, 8.70296743831454, 7.699092434874619, 6.7548973559428, 5.760271490242786, 4.974325842210671, 5.827969784860164, 6.771127831135052, 7.776263924499704, 8.697487115005224, 9.665407418865493, 10.5228989126821, 9.679140342858407, 10.619097202467211, 11.590291217185905, 12.608832846261121, 12.79557596533748, 11.822662875634935, 10.840749556042192, 9.789468417487756, 8.82731520694242, 7.808783944582756, 6.775905623969194, 5.80950874188826, 4.815309376258985, 3.9180809057929116, 4.849389425977366, 5.857634925785566, 6.701685752486858, 7.644512092861714, 8.624119794431522, 9.553185622956054, 8.748511710878047, 9.8216335771921, 10.78496628549573, 11.836971403284252, 11.762349802301896, 10.83531625797127, 9.795843806842527, 8.832655464620863, 7.874371396184793, 6.8141476557192, 5.8043974919173795, 4.8282007356997605, 3.830046011414914, 2.8918413766398006, 3.8767907577073415, 4.787552549864521, 5.734972469183389, 6.719258059738665, 7.674503884784286, 8.684049850849583, 7.957436304667935, 9.01374187170713, 9.993756596393377, 10.960607523619345, 10.836526143885969, 9.880943390237187, 8.815843683250101, 7.880319778414671, 6.900051110846985, 5.890506862509324, 4.872593045675199, 3.833632042437647, 2.854058896795726, 1.927558118273291, 2.882298773282872, 3.809748659336455, 4.743762470750707, 5.709358736822761, 6.754549179284724, 7.795255636348561, 7.047624239037505, 8.103700228901257, 9.104322130554895, 10.09839832427838, 9.891554593002125, 8.910283584423757, 7.973994460614188, 6.942893011808102, 5.953666570376743, 5.023828735155535, 3.958119190432562, 3.0121290010169934, 2.0047861222103425, 0.9347884090089372, 1.9362087471382292, 2.8638357166474364, 3.873760829702599, 4.854522503857941, 5.922187459715104, 6.9528210228533025, 7.907106021180451, 8.853853615166804, 9.874956178314891, 10.13889241386603, 9.11285257589922, 8.184487109569401, 7.109660811825556, 6.150376298066299, 5.131377820244664, 4.086653691337862, 3.1067109017722085, 2.05625696721466, 1.0637361124578586, 0.0, 0.9923719315100814, 1.9421156806788606, 2.9328928007967807, 3.9978108911397845, 5.01548090218219, 6.0168913939365245, 8.838603631458247, 9.863706168736499, 10.857434194309231, 11.162610164558494, 10.135868069467003, 9.127248482893473, 8.11164910423859, 7.0817479335412425, 6.111691308770512, 5.046138059486455, 4.003586882424824, 3.0100584280039078, 1.9786662178340508, 0.9706734596263792, 1.9332200406613238, 2.887844807296675, 3.8864358355990327, 4.920800222551612, 5.940097118669454, 6.957662926157207, 9.615034130100872, 10.681070196841493, 11.726815856868896, 11.855455051205965, 10.79981321227534, 9.836470534215652, 8.866336346747222, 7.871537192963407, 6.856123343199281, 5.840345188866899, 4.907543311206661, 3.867843608975547, 2.903884341176604, 1.959158446608738, 2.896607444080429, 3.843538971333435, 4.888109181945169, 5.864216312068276, 6.798634566901371, 7.796480900790815, 10.559416920533527, 11.530980937448653, 12.603967446614178, 12.788053659977955, 11.810543404640205, 10.793795693668487, 9.755852148594592, 8.687531180444925, 7.738296076429749, 6.797524069491505, 5.747122228200981, 4.819277278783341, 3.8511984697297668, 2.8923984222045926, 3.846585589547066, 4.768621028521586, 5.761640072349633, 6.809262656311333, 7.801931962543352, 8.750964949939004, 11.528779642498804, 12.518593676248983, 13.559230448804675, 13.66135690057706, 12.694445171715111, 11.656212870286321, 10.698834294207643, 9.71337467814021, 8.765812931725286, 7.727484050384643, 6.676397757202688, 5.780648321413137, 4.821702848619906, 3.9430650616227654, 4.832098024770769, 5.789795685377406, 6.692861383341949, 7.741134306188759, 8.690582328478564, 9.623379033301743, 12.50904603637592, 13.455139436714681, 14.51715347692708, 14.605585068440845, 13.578091470789255, 12.60824560263881, 11.627472601336697, 10.678463199585158, 9.741522964076315, 8.751593337483827, 7.72288742617344, 6.761023454272201, 5.871978558025848, 4.987993276478847, 5.798571005174116, 6.722843917373021, 7.707149362755593, 8.745606544569464, 9.65301446110149, 10.611497572122968, 13.449846578678825, 14.414278553591041, 15.382234672946762, 15.578595137431085, 14.6155222895453, 13.645206311377, 12.641957427324407, 11.675399318431197, 10.71164489745274, 9.73447484849373, 8.669431007886887, 7.728539006828834, 6.882603302220662, 6.007804112763554, 6.811166896384876, 7.681698449875357, 8.693196359524308, 9.684521607164195, 10.689887250102581, 11.649890917018201, 14.496235555727534, 15.465497741224478, 16.312036146351527, 15.678564984408911, 14.720429581631263, 13.714441581668702, 12.902994760077444, 12.621611575707497, 11.550438733119117, 10.622287550640088, 9.621245339015456, 8.69760321093862, 7.9271081323849115, 6.962424317799072, 7.752374565086615, 8.697753643856391, 9.627147242178719, 10.556783552660024, 11.54582878698703, 12.480503215552895, 15.47351025190514, 16.47627683009004, 15.59971783719969, 14.774585647673742, 13.71990849225602, 12.762397143023179, 11.88199852951323, 12.581981454692352, 12.527495022891124, 11.591728439483154, 10.610076785278014, 9.703106905228758, 8.887770938290034, 7.988439607948111, 8.763231926276381, 9.630935225001865, 10.567812159279391, 11.531297700317095, 12.480322795607062, 13.433434583219741, 16.409551335998206, 15.563004209251861, 14.556752071310562, 13.762090936035573, 12.702389670025743, 11.824841410257344, 10.822768847166516, 11.61789987102535, 12.589100698466478, 12.512257852353763, 11.556394856029566, 10.772814261445458, 9.816473909584175, 8.98731168685261, 9.746343826064049, 10.604926854952565, 11.60413048088807, 12.567663829117095, 13.452160830354678, 14.385120230756591], [14.499321591912455, 13.631797918244509, 12.703573584642195, 11.685243147510008, 10.745725765912173, 9.804581161603302, 10.771942676170905, 11.639043234985337, 12.658272725233939, 13.58573374842731, 13.509674119198289, 12.552242056439182, 11.677004413041914, 10.867284100688703, 10.108099512338613, 10.999694845898013, 11.907987222080255, 12.718631234617035, 13.719748690727592, 14.633314525687345, 13.496858264765173, 14.426914707951633, 13.593259001320552, 12.652913191058477, 11.674879979418773, 10.74478048785723, 11.726719051057966, 12.708246433275985, 13.598036674580506, 13.610145810032998, 12.609998050763297, 11.61735858801263, 10.684681849143733, 9.933248893467503, 9.099843352307287, 10.034938222499399, 10.947939446357864, 11.738178810911126, 12.69212898448193, 13.614665184955838, 12.666233554273054, 13.548100126484071, 14.490722993326846, 13.617925144911656, 12.62053320498097, 11.710602061559735, 12.689011058681015, 13.654815947741366, 13.524649865302589, 12.60824392048355, 11.672164894890203, 10.670978695981816, 9.646852604059244, 8.894821445586407, 8.125413734519412, 9.004511451930636, 9.976889899594038, 10.794121034224805, 11.733633491406971, 12.655397399548757, 11.684713345909334, 12.590345775589885, 13.553511629393633, 14.568308209292404, 13.63915700457278, 12.688244664591982, 13.628946103875164, 13.533232215233356, 12.549424244550462, 11.563295943213532, 10.605914871832155, 9.619750905879014, 8.661286421140481, 7.95248540782581, 7.090372862745259, 8.054822590118702, 8.966075291481838, 9.818169668457836, 10.838367336107508, 11.6846536183288, 10.639421744821172, 11.597899760941477, 12.575738840027284, 13.567237518132256, 14.497932651831603, 13.69106896226429, 13.628773556919683, 12.589934272100471, 11.63607864397151, 10.662609101445762, 9.633252458677541, 8.6842039460307, 7.717687213805889, 6.967911326106984, 6.040998665754257, 7.004835525030483, 7.970590926815179, 8.886426103322659, 9.81946159188946, 10.73338019878623, 9.577312013172845, 10.590721484623689, 11.615238020192043, 12.617755741130477, 13.545393754294494, 13.777716873491242, 12.809910143381597, 11.790965180579285, 10.764794554906683, 9.69533936982462, 8.6914643663847, 7.747269287452881, 6.752643421752866, 5.966697773720752, 5.020594507041217, 5.963752553316105, 6.929188473970905, 7.850411664476426, 8.818331968336697, 9.675823462153302, 8.686768411348327, 9.626725270957131, 10.597919285675825, 11.616460914751041, 12.579454278506384, 12.815034807145015, 11.833121487552273, 10.781840348997836, 9.8196871384525, 8.801155876092837, 7.768277555479275, 6.801880673398341, 5.807681307769065, 4.9104528373029925, 4.042014148158419, 5.01055947525677, 5.85461030195806, 6.797436642332917, 7.777044343902724, 8.706110172427255, 7.756139779367966, 8.82926164568202, 9.79259435398565, 10.844599471774172, 11.84254675496389, 11.82768818948135, 10.788215738352607, 9.825027396130944, 8.866743327694873, 7.806519587229281, 6.7967694234274605, 5.8205726672098415, 4.822417942924995, 3.8842133081498815, 3.0684454821905827, 3.9404770993357237, 4.887897018654591, 5.872182609209867, 6.827428434255489, 7.836974400320784, 6.965064373157855, 8.021369940197049, 9.001384664883297, 9.968235592109265, 10.923893728368819, 10.873315321747267, 9.808215614760181, 8.872691709924752, 7.892423042357066, 6.882878794019405, 5.86496497718528, 4.826003973947728, 3.846430828305807, 2.919930049783372, 2.073953497766113, 2.962673208807658, 3.8966870202219104, 4.862283286293964, 5.901033938024157, 6.941740395087994, 6.055252307527423, 7.111328297391175, 8.111950199044813, 9.106026392768298, 10.048895723440557, 9.902655515933837, 8.966366392124268, 7.935264943318183, 6.946038501886824, 6.016200666665616, 4.950491121942643, 4.004500932527074, 2.997158053720424, 1.9271603405190185, 1.036691169038677, 1.9643181385478843, 2.9610624418814733, 3.9418241160368153, 4.948479404483622, 5.970364127689916, 6.924649126017065, 7.871396720003418, 8.892499283151505, 9.922576409612425, 10.105224507409302, 9.176859041079483, 8.102032743335638, 7.142748229576381, 6.123749751754746, 5.079025622847944, 4.0990828332822895, 3.0486288987247407, 2.05610804396794, 0.9923719315100814, 0.0, 0.9497437491687792, 1.9405208692866993, 3.0054389596297026, 4.023108970672108, 5.024519462426443, 7.85614673629486, 8.881249273573113, 9.874977299145845, 10.894081913898647, 11.128240000977085, 10.119620414403554, 9.104021035748671, 8.074119865051324, 7.104063240280594, 6.038509990996537, 4.995958813934906, 4.00243035951399, 2.9710381493441327, 1.9630453911364607, 1.0407765877585329, 1.9708004513081225, 2.8940639040889513, 3.9284282910415302, 4.947725187159373, 5.965290994647126, 8.767958679572073, 9.833994746312694, 10.843462938580029, 11.777574703002406, 11.792185143785423, 10.828842465725733, 9.858708278257303, 8.863909124473489, 7.848495274709363, 6.832717120376981, 5.899915242716743, 4.860215540485629, 3.896256272686686, 2.9515303781188194, 2.004163991177638, 2.9264946153448825, 3.895737250435088, 4.871844380558195, 5.80626263539129, 6.804108969280734, 9.712341470004729, 10.683905486919855, 11.756891996085379, 12.710173311774396, 12.802915336150287, 11.78616762517857, 10.748224080104674, 9.679903111955007, 8.730668007939832, 7.789896001001587, 6.739494159711063, 5.811649210293423, 4.843570401239849, 3.884770353714674, 2.959744264206339, 3.8515766725330334, 4.842495623427174, 5.816890724801252, 6.809560031033271, 7.758593018428924, 10.681704191970006, 11.671518225720185, 12.712154998275876, 13.781666946998694, 13.686817103225193, 12.648584801796403, 11.691206225717725, 10.705746609650292, 9.758184863235368, 8.719855981894725, 7.66876968871277, 6.77302025292322, 5.814074780129989, 4.881053887014117, 3.9452566994300415, 4.902954360036679, 5.7737169344194905, 6.7487623746786785, 7.6982103969684825, 8.631007101791662, 11.661970585847122, 12.608063986185883, 13.670078026398281, 14.641318858662311, 14.570463402299337, 13.600617534148892, 12.619844532846779, 11.67083513109524, 10.733894895586397, 9.74396526899391, 8.715259357683523, 7.753395385782284, 6.864350489535931, 5.925982101870199, 4.911729679833389, 5.836002592032294, 6.788004913833134, 7.763385872849511, 8.660642529591408, 9.619125640612886, 12.602771128150026, 13.567203103062242, 14.535159222417963, 15.490502140028719, 15.00081239877853, 14.067377419096044, 13.634329358834488, 12.667771249941278, 11.704016828962821, 10.726846780003811, 9.66180293939697, 8.720910938338916, 7.874975233730746, 6.934395311548667, 5.9243255710441485, 6.79485712453463, 7.80635503418358, 8.76074943442896, 9.724005754903544, 10.65751898550812, 13.649160105198735, 14.61842229069568, 15.464960695822727, 14.916597517414903, 13.958462114637255, 13.014807556451135, 13.895366691587524, 13.613983507217581, 12.5428106646292, 11.614659482150172, 10.61361727052554, 9.689975142448702, 8.822335478974326, 7.857651664388487, 6.865533239745888, 7.810912318515664, 8.740305916837992, 9.669942227319297, 10.658987461646303, 11.593661890212168, 14.626434801376341, 15.629201379561241, 14.75264238667089, 13.97619496542981, 12.957941025262011, 12.062763117805613, 12.874370461023311, 13.574353386202432, 13.519866954401207, 12.584100370993237, 11.602448716788098, 10.69547883673884, 9.782998284879449, 8.883666954537526, 7.876390600935654, 8.744093899661138, 9.680970833938664, 10.644456374976368, 11.593481470266335, 12.546593257879014, 15.562475885469407, 14.715928758723063, 13.709676620781764, 12.915015485506775, 11.940422203031735, 11.125207385039777, 11.815140778676597, 12.61027180253543, 13.581472629976558, 13.504629783863846, 12.54876678753965, 11.747185196799926, 10.71170125617359, 9.813122110943523, 8.859502500723321, 9.718085529611837, 10.717289155547343, 11.680822503776367, 12.565319505013951, 13.498278905415864], [13.58602920056084, 12.718505526892894, 11.79028119329058, 10.771950756158393, 9.832433374560559, 10.738870818065205, 11.706232332632808, 12.573877785043994, 13.593107275292596, 14.531822027944308, 14.45941786836707, 13.501985805607964, 12.626748162210696, 11.817027849857483, 11.029553202871709, 10.231039538567833, 11.013271315518223, 11.823915328055001, 12.825032784165558, 13.738598619125312, 12.583565873413558, 13.513622316600019, 12.679966609968938, 11.739620799706863, 10.761587588067158, 11.679070144319134, 12.66100870751987, 13.643080983334642, 14.532871224639162, 14.55988955920178, 13.559741799932079, 12.567102337181412, 11.634425598312514, 10.882992642636284, 10.021297042840382, 9.266282915169219, 10.053223539795832, 10.843462904349092, 11.797413077919895, 12.719949278393806, 11.747288705381116, 12.598356377315291, 13.540979244158066, 12.704632753560041, 11.707240813629356, 12.644891718021638, 13.623300715142918, 14.589650497800022, 14.47439361447137, 13.557987669652332, 12.621908644058983, 11.620722445150598, 10.596596353228026, 9.844565194755187, 9.046867425052508, 8.235856144600456, 9.082173993032006, 9.89940512766277, 10.838917584844937, 11.760681492986725, 10.734969596740555, 11.640602026421105, 12.603767880224853, 13.65501581794079, 12.725864613221166, 13.622534321053886, 14.563235760337067, 14.482975964402138, 13.499167993719244, 12.513039692382314, 11.555658621000935, 10.569494655047796, 9.611030170309263, 8.90222915699459, 8.011826553278354, 7.286167282788522, 8.071359384919806, 8.923453761895802, 9.943651429545474, 10.789937711766768, 9.689677995652394, 10.648156011772697, 11.625995090858504, 12.617493768963476, 13.548188902662822, 14.475371464989102, 14.578517306088463, 13.539678021269252, 12.58582239314029, 11.612352850614542, 10.582996207846321, 9.633947695199481, 8.66743096297467, 7.917655075275763, 6.9624523562873515, 6.236180217700303, 7.075875020253147, 7.991710196760625, 8.924745685327427, 9.838664292224198, 8.627568264004067, 9.640977735454909, 10.665494271023263, 11.668011991961697, 12.595650005125714, 13.633041933542334, 13.759653892550377, 12.740708929748065, 11.714538304075463, 10.6450831189934, 9.64120811555348, 8.697013036621662, 7.7023871709216465, 6.9164415228895315, 5.942048197574311, 5.186355742339543, 6.034472567408873, 6.955695757914392, 7.923616061774663, 8.78110755559127, 7.737024662179547, 8.67698152178835, 9.648175536507045, 10.666717165582261, 11.629710529337604, 12.678396313069165, 12.782865236721053, 11.731584098166616, 10.76943088762128, 9.750899625261615, 8.718021304648056, 7.751624422567121, 6.757425056937845, 5.860196586471772, 4.963467838691513, 4.1158435686947366, 4.959894395396027, 5.902720735770883, 6.882328437340691, 7.811394265865223, 6.806396030199187, 7.87951789651324, 8.84285060481687, 9.894855722605392, 10.892803005795109, 11.832539267205908, 11.737959487521385, 10.774771145299724, 9.816487076863654, 8.75626333639806, 7.746513172596241, 6.770316416378622, 5.772161692093775, 4.833957057318661, 3.9898991727236774, 3.0457611927736905, 3.9931811120925587, 4.977466702647834, 5.932712527693456, 6.942258493758751, 6.015320623989075, 7.071626191028269, 8.051640915714517, 9.018491842940485, 9.974149979200039, 10.956403587291764, 10.75795936392896, 9.82243545909353, 8.842166791525845, 7.832622543188184, 6.814708726354059, 5.775747723116507, 4.796174577474586, 3.8696737989521512, 2.995407188299208, 2.067957302245625, 2.985808674754865, 3.9253782684107628, 4.951290188855378, 5.991996645919214, 5.105508558358644, 6.161584548222395, 7.162206449876033, 8.156282643599518, 9.099151974271777, 10.080422982850145, 9.916110141293046, 8.885008692486961, 7.8957822510556035, 6.965944415834395, 5.900234871111422, 4.954244681695854, 3.946901802889203, 2.8769040896877978, 1.9864349182074563, 1.069602231985851, 2.011318692712694, 2.992080366868036, 3.9987356553148423, 5.020620378521137, 5.974905376848286, 6.921652970834638, 7.942755533982726, 8.972832660443647, 9.998872498410456, 10.126602790248263, 9.051776492504418, 8.09249197874516, 7.073493500923524, 6.028769372016722, 5.048826582451069, 3.99837264789352, 3.0058517931367192, 1.9421156806788606, 0.9497437491687792, 0.0, 0.99077712011792, 2.0556952104609234, 3.0733652215033285, 4.074775713257663, 6.90640298712608, 7.931505524404333, 8.925233549977065, 9.944338164729867, 10.971080259821358, 11.069364163572335, 10.053764784917451, 9.023863614220105, 8.053806989449372, 6.988253740165316, 5.945702563103685, 4.952174108682769, 3.920781898512912, 2.91278914030524, 1.9756814687746949, 1.0210567021393433, 1.944320154920172, 2.978684541872751, 3.997981437990593, 5.015547245478347, 7.873242773010039, 8.93927883975066, 9.893719189411248, 10.827830953833626, 11.88347279276425, 11.778586214894514, 10.808452027426084, 9.813652873642269, 8.798239023878143, 7.78246086954576, 6.849658991885522, 5.809959289654408, 4.846000021855465, 3.9012741272875986, 2.938998541236294, 1.9767508661761033, 2.9459935012663085, 3.922100631389416, 4.856518886222511, 5.854365220111955, 8.817625563442697, 9.789189580357823, 10.862176089523349, 11.760429562605616, 12.765273395760904, 12.73591137434735, 11.697967829273454, 10.629646861123787, 9.680411757108612, 8.739639750170367, 7.689237908879842, 6.761392959462202, 5.793314150408628, 4.834514102883453, 3.894578814264995, 2.901832923364254, 3.892751874258395, 4.867146975632473, 5.859816281864492, 6.808849269260144, 9.786988285407975, 10.776802319158154, 11.817439091713846, 12.831923197829914, 13.735008380752006, 13.598328550965183, 12.640949974886505, 11.655490358819073, 10.707928612404148, 9.669599731063505, 8.61851343788155, 7.722764002091998, 6.763818529298767, 5.815888437072773, 4.880091249488697, 3.9552764628036234, 4.823973185250711, 5.799018625509899, 6.748466647799704, 7.681263352622883, 10.767254679285092, 11.713348079623852, 12.77536211983625, 13.74660295210028, 14.751617505344424, 14.550361283317672, 13.569588282015559, 12.62057888026402, 11.683638644755177, 10.69370901816269, 9.665003106852302, 8.703139134951062, 7.814094238704709, 6.860816651928855, 5.846564229892045, 4.8883246947992385, 5.838261164664355, 6.813642123680731, 7.71089878042263, 8.669381891444107, 11.708055221587996, 12.672487196500212, 13.640443315855933, 14.595786233466688, 14.23215709144835, 14.988831109629139, 14.584073108003269, 13.617514999110057, 12.6537605781316, 11.67659052917259, 10.611546688565749, 9.670654687507694, 8.824718982899524, 7.869229861607323, 6.859160121102804, 5.8471792273015755, 6.858677136950526, 7.811005685260178, 8.774262005734766, 9.70777523633934, 12.754444198636701, 13.72370638413365, 14.570244789260697, 14.076470958744437, 13.189806807307075, 13.93626124698423, 14.845110440756304, 14.56372725638636, 13.49255441379798, 12.56440323131895, 11.563361019694318, 10.63971889161748, 9.757170029032983, 8.792486214447143, 7.800367789804544, 6.89761992716405, 7.827013525486377, 8.756649835967682, 9.745695070294689, 10.680369498860554, 13.731718894814307, 14.73448547299921, 13.857926480108857, 13.081479058867778, 12.189285717931831, 12.984216808338708, 13.824114210192091, 14.524097135371214, 14.469610703569986, 13.533844120162016, 12.552192465956876, 11.645222585907618, 10.717832834938106, 9.818501504596183, 8.811225150994309, 7.830801508309524, 8.76767844258705, 9.731163983624754, 10.68018907891472, 11.6333008665274, 14.667759978907373, 13.821212852161029, 12.81496071421973, 12.020299578944742, 11.171766895701555, 12.046661075572873, 12.764884527845377, 13.560015551704211, 14.53121637914534, 14.454373533032625, 13.498510536708428, 12.682019746858582, 11.646535806232247, 10.747411767405426, 9.793792157185225, 8.804793138260223, 9.803996764195729, 10.767530112424753, 11.652027113662337, 12.58498651406425], [12.641392306071449, 11.773868632403502, 10.845644298801188, 9.899712870110545, 10.746583676715822, 11.653021120220469, 12.620382634788072, 13.506464375757076, 14.525693866005678, 15.46440861865739, 15.40097997652928, 14.443547913770173, 13.568310270372905, 12.680082699657317, 11.89064126667728, 11.08468034771243, 10.040035031864969, 10.850679044401751, 11.851796500512307, 12.762573878142673, 11.638928978924167, 12.54061085066864, 11.80772872392109, 10.867382913659014, 11.675737890222422, 12.593220446474398, 13.575159009675133, 14.575667574047724, 15.465457815352245, 15.50145166736399, 14.501303908094288, 13.508664445343621, 12.575987706474724, 11.746047492436118, 10.882385106645954, 10.119923724313816, 9.079987256142578, 9.870226620695842, 10.824176794266645, 11.743924537411166, 10.756511585263194, 11.60757925719737, 12.550202124040146, 11.88783766062769, 12.62139111578462, 13.559042020176902, 14.537451017298181, 15.522237088513105, 15.415955722633576, 14.499549777814538, 13.56347075222119, 12.562284553312807, 11.538158461390235, 10.707620044555021, 9.907955488858079, 9.096944208406027, 8.108937709378752, 8.92616884400952, 9.865681301191687, 10.784656752004086, 9.744192476622633, 10.649824906303184, 11.612990760106932, 12.665392764548521, 13.543045174222108, 14.487418642543487, 15.389230715557824, 15.424538072564344, 14.44073010188145, 13.45460180054452, 12.497220729163143, 11.511056763210005, 10.552592278471472, 9.765284006794424, 8.872914617083925, 8.147255346594093, 7.098123101266553, 7.950217478242552, 8.970415145892224, 9.813912970784129, 8.698900875534472, 9.657378891654776, 10.635217970740584, 11.626716648845555, 12.557411782544902, 13.48459434487118, 14.414272234444699, 14.481240129431459, 13.527384501302498, 12.55391495877675, 11.524558316008529, 10.57550980336169, 9.60899307113688, 8.780709925075598, 7.8235404200929235, 7.097268281505875, 6.102638736599895, 7.018473913107375, 7.948720944344786, 8.862639551241559, 7.636791143886145, 8.650200615336988, 9.674717150905343, 10.677234871843776, 11.604872885007794, 12.642264813424413, 13.610071543534058, 13.682271037910276, 12.65610041223767, 11.586645227155607, 10.582770223715688, 9.63857514478387, 8.643949279083856, 7.779496372689367, 6.803136261379883, 6.0474438061451155, 5.061236283755621, 5.982459474261142, 6.947591320792023, 7.80508281460863, 6.746247542061626, 7.68620440167043, 8.657398416389125, 9.67594004546434, 10.638933409219684, 11.687619192951244, 12.669532512543986, 12.673146206328827, 11.71099299578349, 10.692461733423826, 9.659583412810264, 8.69318653072933, 7.698987165100054, 6.755864422681539, 5.824555902497085, 4.976931632500309, 3.986658111742776, 4.929484452117633, 5.9063036963580515, 6.835369524882584, 5.815618910081266, 6.88874077639532, 7.85207348469895, 8.904078602487472, 9.902025885677189, 10.841762147087987, 11.88123459821673, 11.716333253461935, 10.758049185025865, 9.697825444560271, 8.68807528075845, 7.711878524540831, 6.713723800255984, 5.775519165480871, 4.8509872365292495, 3.906849256579263, 3.019944828439307, 4.001441961665194, 4.956687786710816, 5.966233752776112, 5.024543503871154, 6.080849070910348, 7.060863795596596, 8.027714722822564, 8.983372859082118, 9.965626467173843, 11.030021046464045, 10.777801747615339, 9.797533080047653, 8.774184651350394, 7.756270834516269, 6.717309831278717, 5.737736685636796, 4.811235907114361, 3.8564952521047804, 2.9290453660511973, 1.9950315546369448, 2.9346011482928427, 3.960513068737458, 5.001219525801295, 4.1147314382407245, 5.170807428104476, 6.171429329758114, 7.165505523481598, 8.108374854153858, 9.089645862732226, 10.025934986541795, 9.875785812604882, 8.886559371173524, 7.956721535952315, 6.891011991229343, 5.945021801813774, 4.937678923007123, 3.867681209805718, 2.9580936551591437, 2.0304666856499365, 1.020541572594774, 2.001303246750116, 3.0079585351969227, 4.0298432584032176, 4.984128256730366, 5.930875850716719, 6.951978413864806, 7.982055540325727, 9.008095378292538, 9.936460844622356, 10.042553612622338, 9.08326909886308, 8.064270621041445, 7.019546492134642, 6.039603702568989, 4.9891497680114405, 3.9966289132546393, 2.9328928007967807, 1.9405208692866993, 0.99077712011792, 0.0, 1.0649180903430036, 2.082588101385409, 3.083998593139744, 5.915625867008161, 6.940728404286413, 7.934456429859146, 8.953561044611947, 9.980303139703437, 10.990346749654769, 11.044541905035372, 10.014640734338023, 9.013241925901584, 7.947688676617528, 6.905137499555897, 5.9116090451349805, 4.880216834965124, 3.872224076757452, 2.9096774957225073, 1.9550527290871558, 0.9535430348022521, 1.987907421754831, 3.007204317872673, 4.024770125360426, 6.8972180320274, 7.9632540987680205, 8.90294206929333, 9.837053833715707, 10.892695672646331, 11.85603835070602, 11.767886963878295, 10.77308781009448, 9.757673960330354, 8.741895805997972, 7.809093928337734, 6.76939422610662, 5.805434958307677, 4.860709063739811, 3.8729945681841063, 2.9107468931239158, 1.9552163811483885, 2.9313235112714957, 3.8657417661045903, 4.863588099994034, 7.841600822460057, 8.813164839375183, 9.886151348540707, 10.769652442487697, 11.774496275642985, 12.795959534514706, 12.657402765725664, 11.589081797575997, 10.639846693560822, 9.699074686622577, 8.648672845332053, 7.720827895914414, 6.75274908686084, 5.782762008555281, 4.8285748412128076, 3.8358289503120666, 2.901974754140475, 3.8763698555145525, 4.869039161746572, 5.818072149142224, 8.810963544425334, 9.800777578175513, 10.841414350731204, 11.841146077711995, 12.744231260634088, 13.735409377329107, 13.600384911338715, 12.614925295271282, 11.667363548856358, 10.629034667515715, 9.57794837433376, 8.665875211152393, 7.706929738359162, 6.749884464020585, 5.81408727643651, 4.8728139481805135, 3.8331960651327917, 4.80824150539198, 5.757689527681784, 6.690486232504963, 9.79122993830245, 10.737323338641211, 11.79933737885361, 12.77057821111764, 13.760840385226505, 14.73068625337695, 14.529023218467769, 13.58001381671623, 12.643073581207387, 11.6531439546149, 10.608114315912696, 9.646250344011456, 8.757205447765104, 7.794812678876667, 6.780560256839857, 5.8058621801761285, 4.8474840445464356, 5.8228650035628124, 6.720121660304709, 7.678604771326187, 10.732030480605355, 11.69646245551757, 12.664418574873292, 13.619761492484047, 14.613750110118914, 15.679586478292979, 15.543508044455479, 14.576949935562268, 13.596871787191994, 12.619701738232983, 11.554657897626143, 10.613765896568088, 9.767830191959918, 8.801816452320406, 7.791746711815886, 6.7647167126784655, 5.883089936755566, 6.820228565142259, 7.783484885616844, 8.716998116221419, 11.778419457654064, 12.747681643151008, 13.594220048278055, 13.103234675091183, 14.043447616451672, 14.797349310789802, 15.708165290556138, 15.506838465446753, 14.435665622858373, 13.507514440379344, 12.506472228754712, 11.582830100677874, 10.689756619746065, 9.725072805160226, 8.732954380517626, 7.811770229319313, 6.882376630996985, 7.812012941478291, 8.801058175805299, 9.7305572771574, 12.75569415383167, 13.75846073201657, 12.884690196455606, 12.108242775214524, 13.042926527076428, 13.845304872144279, 14.687169059991925, 15.465659243533423, 15.41272191263038, 14.47695532922241, 13.49530367501727, 12.588333794968012, 11.650419425651188, 10.751088095309266, 9.743811741707392, 8.744951810464787, 7.823041548097658, 8.786527089135362, 9.735552184425329, 10.688663972038007, 13.691735237924735, 12.847976568507779, 11.84172443056648, 11.047063295291489, 12.025407704846153, 12.907749139378444, 13.62793937764521, 14.50157765986642, 15.472778487307549, 15.397484742093019, 14.441621745768822, 13.614606337571665, 12.57912239694533, 11.66156206956069, 10.707942459340488, 9.718943440415487, 8.859359869706337, 9.822893217935361, 10.707390219172945, 11.640349619574858], [11.81038289900354, 10.942859225335594, 10.01463489173328, 10.917337357113153, 11.764208163718433, 12.670645607223078, 13.63800712179068, 14.548283790331148, 15.56751328057975, 16.506228033231462, 16.365327585964206, 15.407895523205097, 14.532657879807829, 13.644430309092241, 12.854988876112202, 12.034760166835254, 10.983346712148167, 10.020618228694737, 10.907206624262225, 11.764085900680087, 10.807919571856258, 11.592269140015738, 11.05094071239326, 11.885007400661625, 12.693362377225032, 13.610844933477006, 14.592783496677741, 15.617486988621796, 16.507277229926316, 16.465799276798915, 15.465651517529212, 14.473012054778545, 13.540335315909648, 12.710395101871041, 11.846732716080876, 11.084271333748742, 10.044334865577504, 9.040165804988828, 9.879586918016562, 10.74543655994858, 9.894696687447771, 10.659237546544468, 11.601860413387243, 12.602251823365227, 13.599643763295912, 14.516719534922837, 15.380824050099076, 16.42493519441923, 16.3803033320685, 15.463897387249462, 14.527818361656115, 13.526632162747731, 12.50250607082516, 11.671967653989945, 10.872303098293001, 10.061291817840951, 9.073285318813678, 8.096108028302506, 8.921091424941604, 9.7861687745415, 8.88237757880721, 9.701483195650281, 10.66464904945403, 11.71705105389562, 12.594703463569209, 13.53907693189059, 14.440889004904927, 15.470522576929243, 15.405077711316373, 14.418949409979444, 13.461568338598067, 12.47540437264493, 11.516939887906396, 10.729631616229348, 9.837262226518847, 9.111602956029017, 8.062470710701477, 7.120156662535536, 7.992607341865301, 8.815424993321543, 7.837085977719049, 8.709037181001873, 9.686876260087681, 10.678374938192656, 11.609070071892003, 12.536252634218283, 13.465930523791801, 14.504769808611012, 14.491732110737422, 13.518262568211673, 12.488905925443452, 11.539857412796614, 10.573340680571803, 9.745057534510522, 8.787888029527846, 8.061615890940798, 7.066986346034819, 6.1884130974003595, 6.950232966882199, 7.8641515737789724, 6.774976246070723, 7.701858904684086, 8.726375440252443, 9.728893161190877, 10.656531174354894, 11.693923102771514, 12.661729832881159, 13.694120379242468, 13.620448021672594, 12.550992836590531, 11.547117833150612, 10.602922754218794, 9.60829688851878, 8.743843982124291, 7.767483870814806, 7.011791415580039, 6.025583893190545, 5.152398658554127, 5.949103343329436, 6.806594837146043, 5.797905831408725, 6.737862691017529, 7.7090567057362245, 8.727598334811441, 9.690591698566784, 10.739277482298345, 11.721190801891087, 12.772471940445524, 12.675340605218414, 11.65680934285875, 10.623931022245188, 9.657534140164254, 8.66333477453498, 7.7202120321164625, 6.788903511932008, 5.9412792419352325, 4.951005721177699, 4.099423636410617, 4.907815718895464, 5.836881547419996, 4.867277199428365, 5.940399065742419, 6.903731774046049, 7.955736891834571, 8.874314799067562, 9.814051060478361, 10.853523511607104, 11.873988329220765, 11.722396794460789, 10.662173053995195, 9.652422890193375, 8.676226133975755, 7.678071409690908, 6.739866774915794, 5.8153348459641725, 4.871196866014186, 3.98429243787423, 3.0606237113721653, 3.958199809248229, 4.9043421632570015, 3.98966178544067, 5.045967352479865, 6.025982077166113, 6.9928330043920806, 7.948491140651635, 8.93074474874336, 9.96510295612104, 10.90062686095647, 10.761880689482574, 9.738532260785316, 8.720618443951192, 7.68165744071364, 6.702084295071719, 5.775583516549284, 4.820842861539703, 3.8933929754861203, 2.959379164071868, 1.993782897999814, 2.8955949783944543, 3.936301435458291, 3.0498133478977207, 4.105889337761472, 5.106511239415109, 6.100587433138593, 7.043456763810854, 8.024727772389221, 8.96101689619879, 9.992118345004876, 9.951477461516527, 9.021639626295318, 7.955930081572347, 7.009939892156778, 6.002597013350127, 4.932599300148722, 3.978798753176799, 3.051171783667592, 2.0412466706124293, 1.0604849964570873, 1.9430404448539191, 2.964925168060214, 3.919210166387362, 4.865957760373715, 5.887060323521802, 6.917137449982723, 7.943177287949533, 8.871542754279352, 9.946369052023197, 10.148187189206084, 9.129188711384447, 8.084464582477645, 7.104521792911992, 6.054067858354443, 5.061547003597642, 3.997810891139784, 3.0054389596297026, 2.0556952104609234, 1.0649180903430036, 0.0, 1.017670011042405, 2.01908050279674, 4.850707776665157, 5.8758103139434095, 6.869538339516142, 7.888642954268943, 8.915385049360435, 9.925428659311764, 10.941028037966648, 11.079558824681026, 10.078160016244587, 9.01260676696053, 7.9700555898989, 6.976527135477983, 5.9451349253081265, 4.937142167100455, 3.9745955860655107, 3.019970819430159, 2.0184611251452558, 1.0565409113248592, 2.056416289021228, 2.989888406929942, 5.83532644250829, 6.90136250924891, 7.838023978950325, 8.772135743372703, 9.827777582303327, 10.791120260363016, 11.761254447831446, 11.838005900437485, 10.822592050673359, 9.806813896340977, 8.874012018680737, 7.834312316449623, 6.87035304865068, 5.925627154082814, 4.937912658527109, 3.975664983466919, 3.0201344714913922, 2.069508613456072, 3.0039268682891667, 3.915246389341134, 6.84311284499747, 7.814676861912596, 8.823182613651019, 9.704734352144692, 10.70957818529998, 11.731041444171701, 12.706522656253625, 12.653999887919, 11.704764783903824, 10.76399277696558, 9.713590935675056, 8.785745986257416, 7.817667177203843, 6.847680098898284, 5.89349293155581, 4.90074704065507, 3.966892844483479, 3.014554957699129, 4.007224263931148, 4.869730438489323, 7.812475566962748, 8.802289600712927, 9.842926373268618, 10.77622798736899, 11.679313170291083, 12.670491286986103, 13.627869863064781, 13.679843385614285, 12.73228163919936, 11.693952757858717, 10.642866464676763, 9.730793301495398, 8.771847828702166, 7.814802554363588, 6.879005366779513, 5.937732038523517, 4.898114155475795, 3.946426607576556, 4.895874629866361, 5.82867133468954, 8.792741960839864, 9.738835361178625, 10.800849401391023, 11.734891935869065, 12.6959222948835, 13.665768163033945, 14.628969813732294, 14.644931907059233, 13.70799167155039, 12.718062044957902, 11.6730324062557, 10.71116843435446, 9.822123538108109, 8.85973076921967, 7.84547834718286, 6.870780270519132, 5.912402134889439, 4.961050105747388, 5.858306762489287, 6.816789873510764, 9.733542503142768, 10.697974478054984, 11.665930597410705, 12.62127351502146, 13.615262132656326, 14.681098500830391, 15.643454639720003, 15.641868025905271, 14.661789877535, 13.68461982857599, 12.619575987969148, 11.678683986911093, 10.832748282302923, 9.866734542663409, 8.856664802158889, 7.829634803021468, 6.94800802709857, 5.958413667326835, 6.921669987801422, 7.855183218405997, 10.779931480191475, 11.749193665688423, 12.595732070815469, 13.607384385180726, 14.565519787958374, 15.625119431086326, 16.57543077582506, 16.571756555789758, 15.500583713201378, 14.572432530722349, 13.571390319097716, 12.647748191020879, 11.731576034320137, 10.766892219734297, 9.774773795091697, 8.829394716321922, 7.900001117999595, 6.970364807518289, 7.959410041845295, 8.868742379341978, 11.757206176369081, 12.759972754553985, 12.054629380748592, 13.051554455497723, 13.993006346199252, 14.809652481579201, 15.651516669426849, 16.430006852968347, 16.477640002973384, 15.541873419565414, 14.560221765360275, 13.653251885311018, 12.69223884022526, 11.792907509883337, 10.782001118939958, 9.762576297467396, 8.840666035100266, 7.955517682067454, 8.90454277735742, 9.8576545649701, 12.693247260462147, 11.903386692257696, 11.011663614859465, 11.990374975574687, 12.975487523968976, 13.872096748813366, 14.592286987080135, 15.465925269301344, 16.437126096742475, 16.462402832436023, 15.506539836111827, 14.656425752145736, 13.620941811519401, 12.679186556563298, 11.725566946343097, 10.736567927418095, 9.876984356708945, 8.991883810867453, 9.876380812105037, 10.80934021250695], [10.944932773290285, 10.11674247956239, 10.935791201671822, 11.838493667051695, 12.685364473656975, 13.59180191716162, 14.559163431729223, 15.46944010026969, 16.488669590518292, 17.427384343170004, 17.2946600977784, 16.337228035019294, 15.461990391622026, 14.57376282090644, 13.773268302066446, 12.781586009614113, 11.730172554927027, 10.767444071473596, 9.88953661321982, 10.746415889637682, 9.942469446143003, 10.574599128973334, 11.547239708465673, 12.487585518727748, 13.469967730469635, 14.464871097582936, 15.325446046679719, 16.353834697842206, 17.368672210256968, 17.39513178861311, 16.39498402934341, 15.402344566592742, 14.469667827723844, 13.63972761368524, 12.776065227895074, 11.85782986928244, 10.817893401111203, 9.786991647767687, 8.861916906974157, 9.727766548906175, 8.94414840522211, 9.641567535502064, 10.58419040234484, 11.584581812322824, 12.581973752253509, 13.499049523880432, 14.36315403905667, 15.407265183376824, 16.366083419936714, 16.393229899063662, 15.457150873470312, 14.455964674561928, 13.431838582639356, 12.601300165804144, 11.8016356101072, 10.912145531993938, 9.906618656012819, 8.842933871081366, 7.903421413899199, 8.768498763499094, 7.931829296581549, 8.683813184607878, 9.646979038411626, 10.699381042853215, 11.577033452526805, 12.521406920848184, 13.423218993862521, 14.452852565886838, 15.436660536569732, 15.348281921793642, 14.390900850412264, 13.404736884459126, 12.446272399720593, 11.658964128043547, 10.766594738333046, 9.962456670182004, 8.909771684031982, 7.89553867756249, 6.974937330822896, 7.797754982279138, 6.886537695493387, 7.69136716995947, 8.669206249045278, 9.660704927150253, 10.5914000608496, 11.518582623175877, 12.448260512749396, 13.487099797568607, 14.440955425697569, 14.44759508002587, 13.41823843725765, 12.469189924610811, 11.502673192386, 10.67439004632472, 9.717220541342044, 8.981639945310567, 7.9536221710052555, 6.963795112427313, 5.932562955839794, 6.846481562736567, 5.824427963845061, 6.684188893641682, 7.708705429210039, 8.711223150148474, 9.63886116331249, 10.676253091729109, 11.644059821838754, 12.676450368200063, 13.737616553481622, 13.480325348404728, 12.476450344964809, 11.53225526603299, 10.537629400332976, 9.673176493938488, 8.696816382629004, 7.931815469949808, 6.912219718160982, 5.92778067358108, 4.931433332287031, 5.788924826103638, 4.780235820366321, 5.720192679975125, 6.69138669469382, 7.709928323769036, 8.67292168752438, 9.72160747125594, 10.703520790848682, 11.754801929403119, 12.724408251203299, 12.586141854672947, 11.553263534059385, 10.58686665197845, 9.592667286349176, 8.649544543930661, 7.718236023746206, 6.861303296305001, 5.837641546148136, 4.89481520577328, 3.8901457078530592, 4.819211536377591, 3.8496071883859604, 4.922729054700015, 5.886061763003644, 6.9380668807921655, 7.856644788025157, 8.796381049435956, 9.8358535005647, 10.85631831817836, 11.81460238661443, 11.591505565809392, 10.581755402007571, 9.605558645789952, 8.607403921505105, 7.669199286729992, 6.74466735777837, 5.800529377828384, 4.88006121380672, 3.895775623251445, 2.940529798205824, 3.886672152214596, 2.971991774398265, 4.02829734143746, 5.0083120661237075, 5.9751629933496755, 6.93082112960923, 7.9130747377009545, 8.947432945078637, 9.882956849914066, 10.863225517481752, 10.667864772599515, 9.64995095576539, 8.610989952527838, 7.631416806885917, 6.704916028363482, 5.750175373353901, 4.8227254873003185, 3.8887116758860665, 2.9231154098140126, 1.8779249673520495, 2.918631424415886, 2.0321433368553157, 3.088219326719067, 4.088841228372705, 5.082917422096189, 6.025786752768449, 7.007057761346817, 7.943346885156386, 8.974448333962473, 9.96367477539383, 10.001809810664279, 8.936100265941306, 7.990110076525737, 6.982767197719086, 5.912769484517681, 4.911349146388389, 3.9837221768791813, 2.9737970638240188, 1.9930353896686768, 0.9253704338115141, 1.947255157017809, 2.901540155344957, 3.84828774933131, 4.869390312479397, 5.899467438940318, 6.925507276907128, 7.8538727432369475, 8.928699040980792, 9.88798355474005, 10.146858722426854, 9.102134593520052, 8.122191803954399, 7.07173786939685, 6.079217014640049, 5.0154809021821904, 4.023108970672109, 3.073365221503329, 2.082588101385409, 1.017670011042405, 0.0, 1.001410491754335, 3.833037765622752, 4.858140302901004, 5.851868328473737, 6.870972943226538, 7.897715038318029, 8.90775864826936, 9.923358026924243, 10.819355190214992, 11.095830027286992, 10.030276778002936, 8.987725600941305, 7.9941971465203885, 6.9628049363505315, 5.95481217814286, 4.992265597107916, 4.037640830472564, 3.036131136187661, 2.0580431740966647, 1.0387462779788228, 1.9722183958875368, 4.817656431465885, 5.883692498206505, 6.82035396790792, 7.754465732330298, 8.810107571260923, 9.773450249320613, 10.743584436789043, 11.738383590572857, 11.840262061715764, 10.824483907383382, 9.891682029723142, 8.851982327492028, 7.888023059693085, 6.943297165125219, 5.955582669569514, 4.993334994509324, 3.9667720535177216, 2.9906649233946143, 2.0562466685615197, 2.8975763782987287, 5.825442833955065, 6.797006850870191, 7.805512602608614, 8.687064341102287, 9.691908174257575, 10.713371433129296, 11.688852645211222, 12.735551059536721, 12.72243479494623, 11.781662788007985, 10.73126094671746, 9.80341599729982, 8.835337188246248, 7.865350109940689, 6.9111629425982155, 5.906549470337855, 4.9135304265098085, 3.935711267637671, 3.059544064203501, 3.852060427446918, 6.794805555920343, 7.7846195896705215, 8.825256362226213, 9.758557976326586, 10.661643159248678, 11.652821275943698, 12.610199852022376, 13.640409850283383, 13.749951650241766, 12.711622768901123, 11.660536475719168, 10.693855215872368, 9.734909743079136, 8.777864468740558, 7.842067281156483, 6.884369620549847, 5.844751737502125, 4.867582917515098, 3.986190249727385, 4.9096319965074375, 7.77507194979746, 8.721165350136221, 9.78317939034862, 10.71722192482666, 11.678252283841095, 12.64809815199154, 13.611299802689889, 14.560309204441428, 14.696524293565602, 13.687258260906452, 12.63609432063267, 11.674230348731431, 10.785185452485077, 9.82279268359664, 8.80854026155983, 7.817417852545462, 6.859039716915769, 5.88220641568593, 4.948622382350311, 5.907105493371788, 8.715872492100365, 9.680304467012581, 10.648260586368302, 11.603603503979057, 12.597592121613925, 13.66342848978799, 14.625784628677598, 15.557245323287464, 15.624851791911968, 14.647681742952958, 13.582637902346118, 12.641745901288063, 11.795810196679891, 10.813372124689739, 9.80330238418522, 8.776272385047799, 7.870895224905263, 6.879569977265377, 6.011985607662446, 6.945498838267021, 9.76226146914907, 10.731523654646018, 11.578062059773066, 12.589714374138323, 13.547849776915971, 14.60744942004392, 15.557760764782653, 16.54699531485622, 16.463645627578348, 15.535494445099319, 14.534452233474687, 13.61081010539785, 12.652732344258679, 11.68804852967284, 10.69593010503024, 9.750551026260464, 8.821157427938136, 7.891521117456831, 7.06206339839507, 7.959057999203003, 10.739536165326676, 11.74230274351158, 12.529326238002596, 13.536146028102763, 14.548370866291215, 15.551220683455261, 16.494173860730047, 17.359339364782542, 17.440701917350353, 16.504935333942385, 15.523283679737245, 14.601003967444086, 13.613395150163802, 12.71406381982188, 11.7031574288785, 10.683732607405938, 9.761822345038809, 8.876673992005996, 8.078426031584216, 8.992204439256843, 11.675577249419742, 10.88571668121529, 11.758489457638325, 12.737200818353546, 13.722313366747835, 14.756048217724878, 15.521619498894333, 16.39525778111554, 17.36645860855667, 17.42546474681299, 16.469601750488795, 15.577582062084279, 14.542098121457943, 13.60034286650184, 12.64672325628164, 11.657724237356637, 10.798140666647488, 9.913040120805995, 9.050264066331833, 9.943890086793694], [9.951554903110214, 10.517744446768914, 11.508826824535085, 12.453845070521883, 13.393362452119717, 14.40365993208253, 15.278811929812445, 16.244813421484352, 17.264042911732954, 18.202757664384666, 18.296070589532736, 17.33863852677363, 16.46340088337636, 15.546209897284823, 14.613388528907267, 13.621706236454934, 12.570292781767847, 11.607564298314417, 10.72965684006064, 9.823752604594205, 8.949091575962932, 9.573188637219, 10.545829216711338, 11.486175026973413, 12.4685572387153, 13.463460605828601, 14.324035554925384, 15.35242420608787, 16.36726171850263, 17.372095514941947, 17.396394521097744, 16.403755058347077, 15.47107831947818, 14.627322443673188, 13.676676309040097, 12.697950096123261, 11.658013627952023, 10.627111874608508, 9.702037133814978, 8.805103263862698, 7.942737913467775, 8.64015704374773, 9.582779910590505, 10.58317132056849, 11.580563260499174, 12.497639032126097, 13.361743547302336, 14.405854691622489, 15.36467292818238, 16.40536048038012, 16.458561365224647, 15.457375166316263, 14.433249074393691, 13.602710657558479, 12.803046101861534, 11.810195783119498, 10.74673888285364, 9.683054097922186, 8.74354164074002, 7.8458354784556175, 6.930418804827214, 7.682402692853543, 8.645568546657291, 9.69797055109888, 10.57562296077247, 11.51999642909385, 12.421808502108187, 13.451442074132503, 14.435250044815398, 15.421378346152327, 15.392311342166598, 14.406147376213461, 13.447682891474928, 12.660374619797881, 11.76800523008738, 10.897925042187591, 9.84524005603757, 8.831007049568077, 7.815057557663717, 6.875091697235661, 5.885127203739052, 6.689956678205135, 7.667795757290943, 8.659294435395918, 9.589989569095264, 10.517172131421543, 11.446850020995061, 12.485689305814272, 13.439544933943234, 14.413014476468982, 14.419648929011984, 13.470600416365146, 12.504083684140335, 11.675800538079056, 10.71863103309638, 9.917108317316154, 8.889090543010841, 7.8992634844328995, 6.86803132784538, 5.92381827769309, 4.823017472090726, 5.682778401887348, 6.707294937455705, 7.709812658394139, 8.637450671558156, 9.674842599974776, 10.64264933008442, 11.67503987644573, 12.73620606172729, 13.733382400063253, 13.477860836719143, 12.533665757787325, 11.539039892087311, 10.674586985692823, 9.698226874383339, 8.867283841955395, 7.847688090166567, 6.863249045586667, 5.8669017042926175, 4.86626154106016, 3.7788253286119864, 4.718782188220791, 5.689976202939486, 6.708517832014703, 7.671511195770046, 8.720196979501607, 9.702110299094349, 10.753391437648785, 11.722997759448965, 12.747208931576491, 12.55467402581372, 11.588277143732785, 10.594077778103511, 9.650955035684996, 8.719646515500541, 7.796771668310587, 6.773109918153722, 5.830283577778866, 4.825614079858646, 3.896548251334114, 2.848196696631626, 3.9213185629456797, 4.884651271249309, 5.9366563890378306, 6.855234296270822, 7.79497055768162, 8.834443008810364, 9.854907826424025, 10.813191894860095, 11.873415635325689, 11.583165893761906, 10.606969137544286, 9.60881441325944, 8.670609778484327, 7.746077849532705, 6.801939869582719, 5.856972714215292, 4.872687123660016, 3.917441298614395, 2.9078953325490997, 1.9705812826439302, 3.026886849683125, 4.0069015743693726, 4.9737525015953405, 5.929410637854895, 6.9116642459466195, 7.946022453324301, 8.881546358159731, 9.861815025727417, 10.885163454424674, 10.651361447519728, 9.612400444282175, 8.632827298640253, 7.706326520117817, 6.751585865108236, 5.824135979054653, 4.890122167640401, 3.924525901568347, 2.879335459106384, 1.9398546047503897, 1.0307328451009807, 2.086808834964732, 3.08743073661837, 4.081506930341854, 5.0243762610141145, 6.005647269592482, 6.9419363934020515, 7.973037842208138, 8.962264283639495, 9.892102118860704, 9.93751075769564, 8.991520568280071, 7.984177689473421, 6.914179976272016, 5.912759638142724, 4.985132668633517, 3.9752075555783537, 2.9944458814230117, 1.926780925565849, 0.945844665263474, 1.9001296635906222, 2.846877257576975, 3.867979820725062, 4.898056947185983, 5.924096785152793, 6.852462251482613, 7.927288549226457, 8.886573062985715, 9.905571540807351, 10.103545085274385, 9.123602295708732, 8.073148361151183, 7.080627506394382, 6.016891393936524, 5.024519462426443, 4.074775713257663, 3.083998593139744, 2.01908050279674, 1.001410491754335, 0.0, 2.831627273868417, 3.8567298111466695, 4.850457836719402, 5.869562451472203, 6.896304546563694, 7.906348156515024, 8.921947535169908, 9.817944698460657, 10.889112549586498, 11.03168726975727, 9.98913609269564, 8.995607638274723, 7.964215428104867, 6.956222669897196, 5.993676088862252, 5.0390513222269, 4.037541627941996, 3.007670607738797, 1.9883737116209552, 0.970807904133202, 3.838879611800388, 4.892928244631576, 5.818943476153585, 6.753055240575963, 7.8086970795065875, 8.772039757566278, 9.742173945034708, 10.736973098818522, 11.752386948582648, 11.754298281364468, 10.821496403704229, 9.781796701473114, 8.817837433674171, 7.863628002347511, 6.817626889296257, 5.855379214236066, 4.80453760539004, 3.828430475266933, 2.8940122204338383, 1.896165886544394, 4.891252293041276, 5.862816309956402, 6.804102110854279, 7.685653849347952, 8.69049768250324, 9.711960941374961, 10.687442153456887, 11.734140567782386, 12.683375671797561, 12.711477161989071, 11.661075320698547, 10.733230371280907, 9.765151562227334, 8.727394329667431, 7.773207162324958, 6.744315022210173, 5.751295978382126, 4.77347681950999, 3.8751269751407995, 2.850649935692583, 5.870808675127723, 6.850429048756733, 7.834375764731219, 8.75714748457225, 9.660232667494343, 10.651410784189363, 11.608789360268041, 12.638999358529048, 13.603752370341667, 13.641437142882209, 12.578063215481723, 11.531620767744686, 10.572675294951454, 9.615630020612876, 8.6798328330288, 7.722135172422164, 6.6825172893744424, 5.705348469387417, 4.801773160664684, 3.9082215047531026, 6.85107506900484, 7.7971684693436005, 8.859182509555998, 9.715811433072325, 10.67684179208676, 11.646687660237205, 12.609889310935554, 13.558898712687093, 14.579462402692696, 14.52502381277877, 13.473859872504988, 12.511995900603749, 11.622951004357397, 10.660558235468958, 9.646305813432148, 8.655183404417778, 7.696805268788086, 6.71997196755825, 5.76420529328761, 4.9384397768400055, 7.791875611307744, 8.756307586219961, 9.724263705575682, 10.679606623186437, 11.673595240821303, 12.700378641545075, 13.624374136923263, 14.55583483153313, 15.571774429060428, 15.485447294825278, 14.420403454218436, 13.47951145316038, 12.63357574855221, 11.651137676562055, 10.641067936057535, 9.614037936920115, 8.708660776777583, 7.717335529137697, 6.827568518599745, 5.976833121735238, 8.839598184105594, 9.8075267738534, 10.654065178980446, 11.665717493345703, 12.623852896123351, 13.683452539251302, 14.556350273028318, 15.545584823101882, 16.616757665690262, 16.373259996971637, 15.372217785347004, 14.448575657270167, 13.490497896130998, 12.525814081545159, 11.533695656902559, 10.588316578132783, 9.658922979810455, 8.72928666932915, 7.877646309332369, 6.99039228267122, 9.8168728802832, 10.818305862718962, 11.605329357209976, 12.612149147310143, 13.624373985498595, 14.627223802662641, 15.570176979937425, 16.48536634197397, 17.42240761522291, 17.342700885814704, 16.361049231609563, 15.438769519316406, 14.451160702036121, 13.551829371694199, 12.54092298075082, 11.521498159278257, 10.599587896911128, 9.714439543878315, 8.894008942521515, 8.02353872272506, 10.752913964376265, 11.725836908056111, 12.598609684479145, 13.577321045194367, 14.562433593588656, 15.564779535428476, 16.494066575272715, 17.396668272869874, 18.349986589826152, 18.26323029868531, 17.307367302361115, 16.415347613956598, 15.379863673330263, 14.43810841837416, 13.484488808153959, 12.495489789228957, 11.635906218519807, 10.750805672678315, 9.86584697726913, 8.97522437026191], [11.03093963333978, 11.59712917699848, 12.588211554764651, 13.53322980075145, 14.472747182349284, 15.409853922867097, 16.285005920597012, 17.25100741226892, 18.27023690251752, 18.400022239995835, 17.471282765471887, 16.556662555980708, 15.59428565485368, 14.635613894620581, 13.702792526243025, 12.711110233790691, 11.659696779103605, 10.696968295650175, 9.819060837396396, 8.91315660192996, 10.028476306192498, 10.652573367448566, 11.625213946940905, 12.56555975720298, 13.546093976711044, 14.469654596613168, 15.330229545709951, 16.35861819687244, 17.3734557092872, 17.614566309574524, 16.614418550304823, 15.621779087554156, 14.689102348685259, 13.716726441008946, 12.766080306375855, 11.787354093459019, 10.747417625287781, 9.716515871944265, 8.791441131150734, 7.894507261198454, 9.022122643697342, 9.719541773977296, 10.662164640820071, 11.662556050798056, 12.600440751148845, 13.503833022910664, 14.367937538086903, 15.412048682407056, 16.370866918966946, 16.612664420025077, 15.676585394431726, 14.675399195523342, 13.65127310360077, 12.770212622592865, 11.947425757769912, 10.899599780455256, 9.836142880189398, 8.772458095257944, 7.832945638075777, 6.935239475791374, 8.00980353505678, 8.76178742308311, 9.724953276886858, 10.732829587680273, 11.581816951557036, 12.526190419878416, 13.428002492892753, 14.45763606491707, 15.441444035599964, 15.567716442755057, 14.610335371373678, 13.62417140542054, 12.665706920682007, 11.827876584832268, 10.935507195121767, 9.987329039523347, 8.934644053373326, 7.9204110469038325, 6.9044615549994734, 5.964495694571417, 6.964511933968619, 7.769341408434702, 8.74718048752051, 9.69414688104225, 10.59618355987983, 11.52336612220611, 12.453044011779628, 13.49188329659884, 14.4457389247278, 14.667029600987284, 13.637672958219063, 12.688624445572225, 11.722107713347414, 10.843302503113442, 9.886132998130766, 9.006512314651909, 7.978494540346597, 6.988667481768656, 5.9574353251811365, 5.013222275028846, 5.9024022023202924, 6.762163132116914, 7.781971393768795, 8.744665104040472, 9.618636128305985, 10.568190335213915, 11.53599706532356, 12.557090150043953, 13.544658806821918, 13.699759869366142, 12.695884865926223, 11.751689786994405, 10.75706392129439, 9.84208895072721, 8.865728839417725, 7.95668783929115, 6.937092087502323, 5.952653042922423, 4.956305701628374, 3.955665538395916, 4.858210058841553, 5.798166918450357, 6.764652659252576, 7.736377496841647, 8.652696652517875, 9.600944010222316, 10.582857329815058, 11.547965318462504, 12.502380244789308, 12.805576375634361, 11.772698055020799, 10.806301172939865, 9.81210180731059, 8.81845700071938, 7.887148480534926, 6.886175665646343, 5.862513915489478, 4.919687575114622, 3.915018077194402, 2.9859522486698697, 3.927581426861192, 4.835719237261845, 5.739200564459298, 6.727417543719442, 7.619470489482291, 8.55920675089309, 9.598679202021833, 10.591152365595612, 11.549436434031682, 11.810940086770806, 10.801189922968986, 9.824993166751366, 8.826838442466519, 7.888633807691406, 6.913579814567091, 5.8937966308699155, 4.946376711551047, 3.962091120995772, 3.006845295950151, 1.9972993298848554, 2.995162814468795, 3.8816326895076654, 4.771137767580842, 5.73798869480681, 6.693646831066364, 7.675900439158088, 8.682266992495888, 9.617790897331318, 10.598059564899003, 10.887299293560929, 9.869385476726805, 8.830424473489252, 7.850851327847331, 6.924350549324896, 5.969609894315315, 5.042160008261733, 4.10814619684748, 3.1425499307754263, 2.0973594883134634, 1.0566530312496267, 1.9414208786344647, 2.823053374136318, 3.8236752757899564, 4.817751469513441, 5.760620800185701, 6.741891808764069, 7.678180932573638, 8.709282381379724, 9.698508822811082, 10.62834665803229, 10.78008575726203, 9.834095567846463, 8.893796019923984, 7.903815222449308, 6.902394884320016, 5.974767914810808, 4.964842801755646, 3.9840811276003043, 2.9164161717431414, 1.8857826086049432, 0.931497610277795, 1.878245204264148, 2.899347767412235, 3.929424893873156, 4.955464731839966, 5.883830198169785, 6.95865649591363, 7.917941009672886, 8.936939487494522, 9.981663616401324, 10.961606405966977, 10.799256055612716, 9.902339743916103, 8.838603631458245, 7.85614673629486, 6.90640298712608, 5.915625867008161, 4.850707776665157, 3.833037765622752, 2.831627273868417, 0.0, 1.068300150865861, 2.0620281764385937, 3.0811327911913953, 4.107874886282886, 5.180387101446227, 6.19598648010111, 7.246593318431092, 8.317761169556933, 9.383314418840989, 10.42586559590262, 11.419394050323536, 10.795842701973285, 9.787849943765613, 8.825303362730669, 7.870678596095317, 6.869168901810413, 5.839297881607214, 4.820000985489372, 3.802435178001619, 1.066315050633567, 2.1044985843507673, 3.0305138158727774, 3.9646255802951558, 5.02026741922578, 5.983610097285469, 6.953744284753899, 7.948543438537714, 8.96395728830184, 9.979735442634222, 10.912537320294462, 11.952237022525576, 11.649464707542588, 10.695255276215928, 9.649254163164674, 8.687006488104483, 7.636164879258457, 6.66005774913535, 5.725639494302255, 4.727793160412811, 2.118687731874455, 3.0902517487895813, 4.015672450573471, 4.8972241890671455, 5.902068022222433, 6.923531281094153, 7.899012493176078, 8.945710907501578, 9.894946011516753, 10.835718018454997, 11.880431342576491, 12.808276291994131, 12.596778836095751, 11.559021603535848, 10.604834436193375, 9.57594229607859, 8.582923252250543, 7.605104093378407, 6.706754249009217, 5.682277209561001, 3.098244113960902, 4.0778644875899115, 5.045946104450412, 5.968717824291444, 6.8718030072135345, 7.862981123908554, 8.820359699987232, 9.85056969824824, 10.815322710060858, 11.765677999348135, 12.809706871578198, 13.779945035009098, 13.404302568819872, 12.447257294481295, 11.51146010689722, 10.553762446290582, 9.51414456324286, 8.536975743255834, 7.633400434533101, 6.7398487786215195, 4.078510507838018, 5.024603908176779, 6.086617948389177, 6.927381772791519, 7.888412131805953, 8.858257999956399, 9.821459650654745, 10.770469052406284, 11.791032742411888, 12.78978728644732, 13.840951226721101, 14.76032016786816, 14.454578278225814, 13.492185509337377, 12.477933087300567, 11.486810678286197, 10.528432542656505, 9.551599241426667, 8.595832567156027, 7.770067050708422, 5.019311050140923, 5.983743025053139, 6.951699144408859, 7.900391841781759, 8.894380459416626, 9.911948981264269, 10.835944476642455, 11.76740517125232, 12.78334476877962, 13.76051481773863, 14.787494808434548, 15.727835720424792, 15.465203022420628, 14.482764950430473, 13.472695209925954, 12.445665210788533, 11.540288050646, 10.548962803006113, 9.65919579246816, 8.808460395603655, 6.091883059155038, 7.034962212686577, 7.881500617813623, 8.89315293217888, 9.851288334956529, 10.910887978084478, 11.76792061274751, 12.757155162821073, 13.828328005409453, 14.756479187888482, 15.739309139563117, 16.69689992453458, 16.322125169999413, 15.357441355413576, 14.365322930770976, 13.4199438520012, 12.490550253678872, 11.560913943197567, 10.709273583200785, 9.822019556539637, 7.069157755332644, 8.045741301552138, 8.832764796043154, 9.83958458614332, 10.851809424331773, 11.854659241495819, 12.788916843311723, 13.696936681693161, 14.633977954942097, 15.569744538350067, 16.642762463378357, 17.625684219606903, 17.282787975904537, 16.383456645562614, 15.372550254619236, 14.353125433146674, 13.431215170779545, 12.546066817746732, 11.725636216389931, 10.855165996593477, 8.005198839425711, 8.993131809489471, 9.875730561932281, 10.891860071821792, 11.869328246562048, 12.792214974261654, 13.848146525658438, 14.661018265360164, 15.561556929545342, 16.526555656892906, 17.482418653217103, 18.531760201020752, 18.178349391080665, 17.243826485824393, 16.316116082022376, 15.327117063097374, 14.467533492388224, 13.582432946546732, 12.663607590229038, 11.806851644130328], [11.751332984296551, 10.763369023512723, 11.754451401278894, 12.699469647265694, 13.60685553952319, 14.541461272172644, 15.416613269902559, 16.382614761574466, 17.401844251823068, 17.331722089129975, 16.402982614606028, 15.522487352216858, 14.52598550398782, 13.69066436709504, 12.757842998717484, 11.76616070626515, 10.859651628657886, 9.896923145204456, 9.202221349091692, 9.883158873362166, 10.74886965714927, 9.818813213962809, 10.791453793455148, 11.731799603717223, 12.67770132601659, 13.601261945918715, 14.461836895015498, 15.490225546177983, 16.505063058592743, 17.50989685503206, 17.45001028339408, 16.457370820643412, 15.518308067886002, 14.62469957431624, 13.7096435425806, 12.730917329663765, 11.721811410439557, 10.690909657096041, 9.765834916302511, 8.868901046350231, 9.88637625168689, 8.885781620491539, 9.821613007514243, 10.822004417492227, 11.732048100454392, 12.63544037221621, 13.49954488739245, 14.543656031712603, 15.502474268272493, 16.543161820470235, 16.74488554529759, 15.741965385066404, 14.717839293143832, 13.806132072184823, 12.921819542921687, 11.873993565607032, 10.810536665341173, 9.74685188040972, 8.807339423227553, 7.909633260943151, 8.97378315069245, 7.928027269597353, 8.884401643581029, 9.86443693698582, 10.713424300862583, 11.657797769183963, 12.5596098421983, 13.589243414222617, 14.573051384905511, 15.559179686242441, 15.678635522239539, 14.690737594963602, 13.73227311022507, 12.863796034424226, 11.93663200628075, 10.965971000420437, 9.913286014270415, 8.899053007800923, 7.878855340151251, 6.938889479723194, 7.984779982284215, 6.935581254948945, 7.906628854214681, 8.825754230347798, 9.727790909185376, 10.654973471511656, 11.584651361085175, 12.623490645904386, 13.577346274033347, 14.550815816559096, 14.705973109084924, 13.755190635115287, 12.788673902890476, 11.8792219527054, 10.922052447722725, 10.04243176424387, 9.014413989938557, 7.975590835676073, 6.933056308710663, 5.987616060180623, 6.927504739598543, 5.928402978631158, 6.913578743074342, 7.876272453346018, 8.750243477611532, 9.699797684519462, 10.667604414629107, 11.6886974993495, 12.676266156127465, 13.644372234709142, 13.764185016792084, 12.819989937860266, 11.823630110837453, 10.87800840031917, 9.901648289009685, 8.99260728888311, 7.973011537094283, 6.988572492514383, 5.9922251512203335, 4.991584987987876, 5.883312596119804, 4.9644067649646, 5.896260008558123, 6.867984846147194, 7.784304001823423, 8.732551359527863, 9.714464679120605, 10.679572667768051, 11.633987594094855, 12.65819876622238, 12.84099820588666, 11.874601323805726, 10.878667996853652, 9.854376450311342, 8.923067930126887, 7.922095115238303, 6.898433365081438, 5.955607024706582, 4.950937526786362, 4.02187169826183, 4.952683964139444, 3.967326586567392, 4.870807913764845, 5.859024893024989, 6.751077838787838, 7.690814100198636, 8.730286551327378, 9.722759714901159, 10.681043783337229, 11.741267523802822, 11.869490073834847, 10.893293317617227, 9.89513859333238, 8.956933958557267, 7.949499264159051, 6.929716080461876, 5.982296161143008, 4.9980105705877325, 4.042764745542111, 3.0332187794768153, 4.020265351747048, 3.0132400388132123, 3.902745116886389, 4.869596044112357, 5.825254180371911, 6.807507788463635, 7.8138743418014345, 8.749398246636865, 9.72966691420455, 10.753015342901808, 10.937685627592668, 9.898724624355115, 8.919151478713193, 7.992650700190757, 7.037910045181176, 6.1104601591275935, 5.176446347713341, 4.210850081641287, 3.1656596391793244, 2.1249531821154877, 2.966523415912717, 1.9546607234418651, 2.9552826250955033, 3.949358818818988, 4.892228149491248, 5.873499158069616, 6.809788281879185, 7.840889730685271, 8.830116172116629, 9.759954007337837, 10.82566355206081, 10.902395718712325, 9.962096170789845, 8.928917759727561, 7.927497421598268, 6.999870452089061, 5.989945339033898, 5.009183664878557, 3.941518709021394, 2.9108851458831957, 1.9566001475560477, 1.0098525535696947, 2.0309551167177817, 3.061032243178703, 4.062590228984808, 4.990955695314628, 6.065781993058472, 7.025066506817729, 8.044064984639364, 9.088789113546166, 10.06873190311182, 11.119185837669368, 10.927442281194358, 9.863706168736499, 8.881249273573111, 7.931505524404333, 6.940728404286413, 5.8758103139434095, 4.858140302901004, 3.8567298111466695, 1.068300150865861, 0.0, 0.9937280255727327, 2.012832640325534, 3.039574735417025, 4.112086950580366, 5.1276863292352495, 6.178293167565231, 7.249461018691072, 8.315014267975128, 9.357565445036759, 10.351093899457675, 11.382486109627532, 10.812952481043865, 9.850405900008921, 8.89578113337357, 7.894271439088666, 6.864400418885467, 5.845103522767625, 4.827537715279871, 2.102234500225527, 1.0361984334849061, 1.9622136650069164, 2.896325429429295, 3.951967268359919, 4.915309946419608, 5.885444133888038, 6.880243287671853, 7.895657137435979, 8.911435291768361, 9.8442371694286, 10.883936871659715, 11.847896139458658, 11.72035781349418, 10.674356700442926, 9.712109025382736, 8.66126741653671, 7.685160286413603, 6.750742031580508, 5.752895697691064, 3.0580138001653947, 2.086449783250268, 2.9473722997076104, 3.828924038201284, 4.833767871356572, 5.855231130228292, 6.830712342310217, 7.877410756635717, 8.826645860650892, 9.767417867589137, 10.81213119171063, 11.73997614112827, 12.758035988731779, 12.584124140814101, 11.629936973471628, 10.601044833356841, 9.608025789528796, 8.63020663065666, 7.731856786287469, 6.707379746839253, 4.037570182251842, 3.074062522050599, 3.9776459535845508, 4.900417673425583, 5.803502856347674, 6.794680973042693, 7.7520595491213715, 8.782269547382379, 9.747022559194997, 10.697377848482274, 11.741406720712337, 12.711644884143237, 13.670590356936469, 13.472359831759547, 12.536562644175472, 11.578864983568835, 10.539247100521113, 9.562078280534088, 8.658502971811354, 7.764951315899772, 5.017836576128959, 4.146372006391699, 5.048539379116111, 5.859081621925658, 6.820111980940092, 7.789957849090538, 8.753159499788884, 9.702168901540423, 10.722732591546027, 11.721487135581459, 12.77265107585524, 13.6920200170023, 14.72086606634241, 14.51728804661563, 13.50303562457882, 12.51191321556445, 11.553535079934758, 10.576701778704921, 9.62093510443428, 8.795169587986674, 5.958637118431863, 5.196652496659888, 5.981846341516306, 6.832091690915898, 7.826080308550765, 8.843648830398408, 9.767644325776594, 10.699105020386462, 11.715044617913758, 12.692214666872768, 13.719194657568687, 14.659535569558932, 15.63388030100123, 15.507867487708726, 14.497797747204206, 13.470767748066786, 12.565390587924254, 11.574065340284367, 10.684298329746415, 9.833562932881907, 7.031209127445979, 6.247871684293326, 6.91164781492107, 7.84925803474826, 8.807393437525908, 9.86699308065386, 10.699620461881649, 11.688855011955214, 12.760027854543594, 13.688179037022623, 14.671008988697256, 15.628599773668718, 16.608708606996004, 16.382543892691828, 15.39042546804923, 14.445046389279455, 13.515652790957127, 12.586016480475822, 11.73437612047904, 10.84712209381789, 8.008483823623584, 7.258650773158887, 7.8629119931506, 8.84424993462492, 9.807914526901152, 10.810764344065198, 11.720616692445862, 12.628636530827302, 13.565677804076238, 14.501444387484208, 15.574462312512498, 16.557384068741044, 17.544992886021326, 17.37430591403444, 16.397652791897492, 15.378227970424929, 14.4563177080578, 13.571169355024987, 12.652246451648107, 11.699134664035428, 8.94452490771665, 8.20604128109622, 8.905877759039727, 9.905429414547955, 10.825433349131428, 11.748320076831034, 12.779846374792577, 13.592718114494305, 14.493256778679482, 15.458255506027047, 16.414118502351243, 17.463460050154893, 17.309956740386212, 16.37543383512994, 15.486539933052624, 14.634495775823527, 13.739822647669902, 12.777202482144721, 11.82984743674328, 12.650820311572279], [12.745061009869282, 11.757097049085454, 11.047273704907877, 11.918983738058444, 12.74454348620796, 13.679149218857411, 14.554301216587326, 15.520302708259232, 16.539532198507835, 16.337994063557243, 15.409254589033296, 14.528759326644126, 13.532257478415088, 12.696936341522306, 11.76411497314475, 10.772432680692416, 9.865923603085154, 8.903195119631723, 9.749907856754914, 10.704003490048352, 11.742597682722, 10.81254123953554, 10.010967884247897, 10.951313694509972, 11.81538927270136, 12.738949892603483, 13.599524841700266, 14.627913492862751, 15.642751005277512, 16.64758480171683, 16.456282257821346, 15.463642795070678, 14.52458004231327, 13.630971548743506, 12.715915517007867, 11.73718930409103, 10.825971378807544, 9.883647543337633, 10.706015916352646, 9.809082046400366, 10.88010427725962, 9.87950964606427, 8.959300954199012, 9.959692364176997, 10.869736047139162, 11.773128318900978, 12.637232834077217, 13.68134397839737, 14.640162214957261, 15.680849767155003, 16.720498727366635, 16.410022687101492, 15.562409287397758, 14.63164547950811, 13.690345134795741, 12.767616074659793, 11.750717665391308, 10.687032880459855, 9.747520423277688, 8.849814260993286, 9.96751117626518, 8.921755295170083, 8.022089590265798, 9.002124883670588, 9.851112247547352, 10.79548571586873, 11.697297788883068, 12.726931360907384, 13.710739331590279, 14.696867632927209, 15.654248704308586, 15.668770460940285, 14.710305976201752, 13.841828900400909, 12.876813006330885, 11.906152000470572, 10.85346701432055, 9.839234007851058, 8.819036340201386, 7.879070479773329, 8.978508007856945, 7.929309280521675, 7.044316800899449, 7.963442177032565, 8.865478855870146, 9.792661418196424, 10.722339307769943, 11.761178592589154, 12.715034220718115, 13.688503763243864, 14.72772327712667, 14.73322350109197, 13.76670676886716, 12.857254818682083, 11.900085313699408, 10.995433568602735, 9.963639691416182, 8.915771835726208, 7.873237308760798, 6.927797060230758, 7.9212327651712755, 6.922131004203888, 6.05126668975911, 7.013960400030786, 7.887931424296302, 8.837485631204231, 9.805292361313876, 10.826385446034267, 11.813954102812232, 12.78206018139391, 13.785935184833829, 13.813037199006452, 12.801662976814136, 11.856041266295852, 10.879681154986368, 9.970640154859794, 8.951044403070966, 7.966605358491065, 6.970258017197016, 5.969617853964558, 6.877040621692537, 5.958134790537331, 5.033947955242891, 6.005672792831962, 6.921991948508192, 7.870239306212632, 8.852152625805374, 9.817260614452819, 10.771675540779622, 11.795886712907148, 12.867550527903033, 12.868329349378456, 11.856700862830335, 10.832409316288025, 9.90110079610357, 8.900127981214986, 7.876466231058121, 6.933639890683264, 5.928970392763044, 4.999904564238512, 5.9464119897121765, 4.961054612140123, 4.008495860449614, 4.996712839709757, 5.888765785472607, 6.828502046883405, 7.867974498012148, 8.860447661585926, 9.818731730021996, 10.87895547048759, 11.88870563428941, 11.887021343189957, 10.88886661890511, 9.950661984129997, 8.927532130135734, 7.907748946438558, 6.96032902711969, 5.976043436564415, 5.020797611518793, 4.011251645453497, 5.01399337731978, 4.006968064385944, 3.040433063571158, 4.007283990797125, 4.96294212705668, 5.945195735148404, 6.951562288486203, 7.8870861933216325, 8.867354860889318, 9.890703289586575, 10.9086171064207, 10.892452649927845, 9.912879504285923, 8.986378725763489, 8.031638070753909, 7.104188184700326, 6.170174373286073, 5.20457810721402, 4.159387664752057, 3.1186812076882204, 3.9602514414854495, 2.9483887490145975, 2.0929705717802722, 3.087046765503757, 4.0299160961760165, 5.011187104754384, 5.9474762285639535, 6.97857767737004, 7.967804118801398, 8.897641954022607, 9.96335149874558, 10.909341688161147, 10.955824196362576, 9.922645785300293, 8.921225447171, 7.993598477661793, 6.983673364606631, 6.002911690451289, 4.935246734594126, 3.904613171455928, 2.95032817312878, 2.0035805791424273, 1.0561339089116217, 2.0755575019949153, 3.068862203412075, 3.9972276697418945, 5.07205396748574, 6.031338481244997, 7.050336959066632, 8.095061087973434, 9.075003877539087, 10.125457812096636, 11.117978666853437, 10.857434194309231, 9.874977299145844, 8.925233549977065, 7.934456429859146, 6.869538339516142, 5.851868328473737, 4.850457836719402, 2.0620281764385937, 0.9937280255727327, 0.0, 1.0191046147528013, 2.0458467098442923, 3.118358925007633, 4.133958303662516, 5.184565141992498, 6.255732993118339, 7.321286242402396, 8.363837419464026, 9.357365873884943, 10.3887580840548, 11.396750842262472, 10.844133925581653, 9.889509158946302, 8.887999464661398, 7.858128444458199, 6.838831548340357, 5.821265740852604, 3.0802673662022086, 2.014231299461588, 0.9684856394341836, 1.9025974038565618, 2.958239242787186, 3.921581920846876, 4.891716108315306, 5.88651526209912, 6.901929111863247, 7.917707266195628, 8.850509143855867, 9.890208846086981, 10.854168113885924, 11.808377545212585, 11.668084726015659, 10.705837050955468, 9.654995442109442, 8.678888311986334, 7.74447005715324, 6.746623723263796, 3.9981948002155296, 3.026630783300403, 1.9536442741348778, 2.8351960126285514, 3.8400398457838385, 4.86150310465556, 5.836984316737484, 6.883682731062985, 7.83291783507816, 8.773689842016404, 9.818403166137896, 10.746248115555536, 11.764307963159045, 12.74161752080844, 12.62366499904436, 11.594772858929574, 10.601753815101528, 9.623934656229391, 8.725584811860202, 7.701107772411985, 4.977751182301977, 4.014243522100734, 2.9839179280118184, 3.9066896478528497, 4.80977483077494, 5.800952947469961, 6.758331523548639, 7.7885415218096465, 8.753294533622265, 9.703649822909542, 10.747678695139603, 11.717916858570502, 12.676862331363735, 13.633907605702312, 13.530290669748204, 12.572593009141567, 11.532975126093845, 10.555806306106819, 9.652230997384086, 8.758679341472504, 5.958017576179094, 5.086553006441834, 4.0548113535433785, 4.865353596352925, 5.826383955367358, 6.7962298235178045, 7.759431474216153, 8.708440875967693, 9.729004565973295, 10.727759110008726, 11.778923050282508, 12.698291991429565, 13.727138040769677, 14.678835820558394, 14.496763650151552, 13.505641241137182, 12.54726310550749, 11.570429804277651, 10.614663130007012, 9.788897613559406, 6.898818118481998, 5.956074435299294, 4.988118315943574, 5.838363665343165, 6.832352282978031, 7.8499208048256754, 8.773916300203862, 9.70537699481373, 10.721316592341026, 11.698486641300036, 12.725466631995955, 13.665807543986197, 14.640152275428497, 15.679795856647104, 15.491525772776939, 14.464495773639518, 13.559118613496986, 12.5677933658571, 11.678026355319147, 10.82729095845464, 7.971390127496114, 6.973577528292723, 5.917919789348337, 6.855530009175526, 7.813665411953174, 8.873265055081124, 9.705892436308917, 10.695126986382482, 11.766299828970862, 12.69445101144989, 13.677280963124524, 14.634871748095984, 15.61498058142327, 16.579664396009107, 16.384153493621962, 15.438774414852187, 14.509380816529859, 13.579744506048554, 12.728104146051772, 11.840850119390621, 8.82932844030977, 7.80633728082211, 6.869183967577868, 7.850521909052185, 8.814186501328418, 9.817036318492464, 10.72688866687313, 11.63490850525457, 12.571949778503505, 13.507716361911475, 14.580734286939766, 15.56365604316831, 16.551264860448594, 16.51199386071921, 15.60733977952506, 14.746175352458994, 13.99565506007133, 13.106390914573703, 13.645974477220838, 12.692862689608159, 9.765369524402836, 8.753727788759443, 7.912149733466995, 8.91170138897522, 9.831705323558694, 10.7545920512583, 11.786118349219844, 12.598990088921573, 13.49952875310675, 14.464527480454315, 15.420390476778511, 16.46973202458216, 16.447644687070976, 15.513121781814709, 14.624227879737392, 13.772183722508295, 12.959336738462651, 12.070024785773704, 12.823575462316011, 13.64454833714501], [13.752794947943295, 12.764830987159467, 12.044233686368768, 11.136134566835214, 11.765296600225062, 12.699902332874515, 13.57505433060443, 14.541055822276336, 15.56028531252494, 15.395527721858251, 14.466788247334303, 13.586292984945134, 12.589791136716096, 11.767275243645994, 10.834453875268437, 9.842771582816104, 8.989068554525428, 9.755317096828986, 10.602029833952177, 11.556125467245614, 12.750331620796013, 11.820275177609552, 11.007927865708789, 10.168464523286744, 10.836142386718462, 11.759703006620587, 12.62027795571737, 13.648666606879855, 14.663504119294617, 15.668337915733936, 15.513815916122352, 14.521176453371686, 13.582113700614277, 12.701310450867194, 11.786254419131554, 10.807528206214718, 9.949116330247818, 10.735769520534895, 11.600290865482945, 10.703356995530665, 11.887838215333634, 10.887243584138282, 9.956260935659904, 9.148009776318068, 9.890489161156264, 10.793881432918083, 11.657985948094321, 12.702097092414474, 13.660915328974365, 14.701602881172107, 15.741251841383738, 15.4675563454025, 14.619942945698766, 13.701984381631798, 12.760684036919429, 11.83795497678348, 10.920165877011645, 11.581307829590154, 10.641795372407987, 9.744089210123585, 10.975245114339193, 9.929489233244096, 9.01904957172669, 8.137437790941801, 8.871865361564454, 9.816238829885835, 10.718050902900172, 11.747684474924489, 12.731492445607383, 13.717620746944313, 14.67500181832569, 15.675361024477562, 15.605509128617529, 14.644320419392395, 13.758304844455727, 12.787643838595415, 11.74774196345085, 10.733508956981357, 9.713311289331685, 8.773345428903628, 9.986241945930958, 8.937043218595688, 8.041276782360342, 7.098755084303779, 7.886231969887248, 8.813414532213528, 9.743092421787047, 10.781931706606258, 11.73578733473522, 12.709256877260968, 13.736530871140593, 14.739814064629247, 14.7052691998356, 13.795817249650526, 12.838647744667849, 11.933995999571177, 10.902202122384624, 9.85433426669465, 8.81179973972924, 7.8663594911992005, 8.940337379924078, 7.929864942277901, 7.048226671220003, 6.149273307302, 6.908684538313405, 7.858238745221334, 8.826045475330979, 9.83519304004819, 10.822761696826158, 11.790867775407833, 12.794742778847752, 13.73893785777957, 13.740225407782576, 12.794603697264293, 11.818243585954809, 10.909202585828236, 9.889606834039409, 8.905167789459506, 7.908820448165458, 6.9081802849330005, 7.896145236445339, 6.965868728611344, 6.030907936703784, 5.140985700103176, 5.942745062525295, 6.890992420229734, 7.872905739822476, 8.826068208466742, 9.780483134793547, 10.804694306921071, 11.876358121916956, 12.84275500399789, 12.795263293798776, 11.770971747256466, 10.83966322707201, 9.838690412183428, 8.815028662026563, 7.872202321651707, 6.867532823731486, 5.938466995206954, 6.965516604464979, 5.968788550214136, 5.005455841910506, 4.132025746980971, 4.90951889948971, 5.8492551609005075, 6.888727612029251, 7.8692552555998505, 8.827539324035921, 9.887763064501515, 10.897513228303335, 11.873709984520955, 11.867643079505031, 10.929438444729918, 9.866094561104175, 8.846311377407, 7.898891458088133, 6.914605867532857, 5.959360042487235, 4.94981407642194, 6.033097992072582, 5.0174077697182975, 4.03739304503205, 3.142596898068339, 3.9836952410737827, 4.965948849165507, 5.960369882500126, 6.895893787335556, 7.876162454903241, 8.899510883600499, 9.917424700434623, 10.921820376532281, 10.931984119038725, 10.00548334051629, 9.05074268550671, 8.123292799453127, 7.1892789880388746, 6.223682721966821, 5.178492279504858, 4.137785822441021, 4.9793560562382515, 3.967493363767399, 3.0899305532411643, 2.0958543595176797, 3.0387236901899395, 4.019994698768308, 4.956283822577877, 5.987385271383963, 6.9766117128153216, 7.90644954803653, 8.972159092759503, 9.91814928217507, 10.92549216098172, 10.941750400053095, 9.940330061923802, 9.012703092414595, 8.002777979359433, 7.022016305204091, 5.954351349346928, 4.92371778620873, 3.9694327878815816, 3.022685193895229, 2.075238523664423, 1.056452887242114, 2.049757588659274, 2.9781230549890934, 4.052949352732938, 5.012233866492195, 6.03123234431383, 7.075956473220632, 8.055899262786285, 9.106353197343834, 10.098874052100635, 11.162610164558494, 10.894081913898646, 9.944338164729867, 8.953561044611947, 7.888642954268944, 6.870972943226539, 5.869562451472204, 3.081132791191395, 2.012832640325534, 1.0191046147528013, 0.0, 1.026742095091491, 2.099254310254832, 3.114853688909715, 4.165460527239697, 5.236628378365538, 6.302181627649594, 7.344732804711224, 8.33826125913214, 9.369653469301998, 10.37764622750967, 11.340192808544614, 10.908613773699102, 9.907104079414198, 8.877233059211001, 7.857936163093159, 6.840370355605406, 4.0188297971706515, 2.9527937304300313, 1.907048070402627, 0.9729363059802487, 1.998368925444043, 2.9617116035037325, 3.931845790972162, 4.926644944755976, 5.942058794520102, 6.957836948852484, 7.890638826512722, 8.930338528743837, 9.89429779654278, 10.84850722786944, 11.894508340920694, 11.72494166570827, 10.674100056862244, 9.697992926739136, 8.763574671906042, 7.765728338016598, 4.9367572311839725, 3.9651932142688464, 2.8922067051033213, 1.905534914752238, 2.9103787479075254, 3.9190367629565683, 4.877113999394341, 5.9238124137198405, 6.873047517735015, 7.813819524673259, 8.858532848794752, 9.786377798212392, 10.8044376458159, 11.781747203465295, 12.735934370807769, 12.613877473682376, 11.62085842985433, 10.643039270982193, 9.744689426613004, 8.720212387164787, 5.916313613270419, 4.952805953069177, 3.9224803589802617, 2.977028549976536, 3.8801137328986277, 4.8584866057709695, 5.815865181849648, 6.846075180110655, 7.810828191923273, 8.743779505566398, 9.787808377796459, 10.758046541227358, 11.71699201402059, 12.674037288359168, 13.609834475943243, 13.591697623894369, 12.552079740846647, 11.57491092085962, 10.671335612136888, 9.777783956225306, 6.896580007147536, 5.968947370953039, 4.906933330740641, 3.9356924984766115, 4.896722857491046, 5.856333125334655, 6.816965132517161, 7.7659745342687, 8.786538224274302, 9.767888792665582, 10.819052732939364, 11.738421674086421, 12.767267723426531, 13.71896550321525, 14.57630745634659, 14.524745855889984, 13.566367720260292, 12.589534419030453, 11.633767744759814, 10.808002228312208, 7.772628387408772, 6.808196412496556, 5.840240293140836, 4.908702567466851, 5.902691185101718, 6.910024106642526, 7.83144995850487, 8.762910653114737, 9.778850250642034, 10.756020299601044, 11.76559631465281, 12.705937226643053, 13.680281958085352, 14.71992553930396, 15.58890334755735, 15.48360038839232, 14.578223228249788, 13.586897980609901, 12.69713097007195, 11.846395573207442, 8.845200396422888, 7.825699505489985, 6.770041766545599, 5.925868911299213, 6.884004314076861, 7.943603957204812, 8.763426094609926, 9.75266064468349, 10.82383348727187, 11.751984669750899, 12.71741064578138, 13.67500143075284, 14.655110264080125, 15.619794078665965, 15.63895025473193, 14.700110047621573, 14.153470805948773, 14.598849120801356, 13.747208760804574, 12.859954734143423, 9.681450417507032, 8.658459258019372, 7.72130594477513, 6.9208608111758725, 7.8845254034521055, 8.887375220616152, 9.78442232517414, 10.692442163555578, 11.629483436804513, 12.565250020212483, 13.638267945240774, 14.621189701469318, 15.608798518749602, 15.532746974736312, 14.628092893542163, 13.766928466476099, 13.2128058888481, 14.103350896034595, 14.653708415294851, 13.700596627682172, 10.617491501600098, 9.605849765956705, 8.764271710664257, 7.982040291098908, 8.902044225682381, 9.824930953381987, 10.843652007520854, 11.65652374722258, 12.557062411407758, 13.522061138755323, 14.477924135079519, 15.527265682883169, 15.468397801088082, 14.533874895831813, 13.644980993754496, 12.7929368365254, 12.176487567239421, 13.066984767234596, 13.831309400390024, 14.652282275219022], [14.649075709965459, 13.66111174918163, 12.791829069102503, 11.732283484317804, 10.79276610271997, 11.727371835369421, 12.602523833099337, 13.568525324771242, 14.587754815019846, 14.368785626766762, 13.440046152242815, 12.559550889853645, 11.563049041624607, 10.764766590417254, 9.842559918308465, 9.0072495039375, 9.931043741119357, 10.697292283422914, 11.544005020546106, 12.498100653839543, 13.646612382818176, 12.716555939631716, 11.786339911217333, 10.845994100955258, 9.86361188921337, 10.787172509115493, 11.647747458212276, 12.676136109374761, 13.690973621789523, 14.695807418228842, 14.487073821030863, 13.494434358280197, 12.555371605522788, 11.698801797638454, 10.850816078339792, 9.972006127336114, 10.891091516841747, 11.677744707128824, 12.542266052076874, 11.645332182124594, 12.784118977355797, 11.783524346160446, 10.818099437153789, 9.839058054155252, 8.917958663651172, 9.821350935412989, 10.685455450589227, 11.72956659490938, 12.688384831469271, 13.729072383667013, 14.768721343878644, 14.44081425031101, 13.593200850607277, 12.73722924551955, 11.825245696127666, 11.002432897904876, 11.862141063605574, 12.523283016184083, 11.583770559001916, 10.686064396717514, 11.871525876361357, 10.82576999526626, 9.880888073220575, 8.828486068778986, 7.899334864059362, 8.843708332380741, 9.745520405395078, 10.775153977419395, 11.75896194810229, 12.745090249439219, 13.702471320820596, 14.674617065917536, 14.57876703352604, 13.679565283280148, 12.86028656790182, 11.95212175971681, 12.689717150044778, 11.675484143575286, 10.655286475925614, 9.715320615497557, 10.882522707953122, 9.833323980617852, 8.907916043567853, 7.844396606081501, 6.913701472382155, 7.840884034708434, 8.770561924281953, 9.809401209101164, 10.760186193247945, 11.733655735773693, 12.735786912580567, 13.73907010606922, 14.705586838294032, 14.664139364998974, 13.858268809585596, 12.89443195030937, 11.862638073122817, 10.814770217432843, 9.772235690467433, 8.826795441937394, 9.844220735219741, 8.826145704300064, 7.944013256912802, 6.941495535974369, 5.9361540408083115, 6.88570824771624, 7.853514977825884, 8.834449081488167, 9.82201773826613, 10.790123816847807, 11.793998820287726, 12.738193899219544, 13.74956812141186, 13.821345792355785, 12.844985681046301, 11.935944680919725, 10.9163489291309, 9.931909884550999, 8.93556254325695, 7.934922380024492, 8.80210635024231, 7.862149490633506, 6.927188698725946, 5.933207928775545, 4.970214565020202, 5.9184619227246404, 6.9003752423173825, 7.825324249906717, 8.77973917623352, 9.803950348361045, 10.87561416335693, 11.842011045437864, 12.856384115089845, 12.797713842347958, 11.866405322163503, 10.86543250727492, 9.841770757118054, 8.898944416743198, 7.894274918822978, 6.965209090298446, 7.902412711172051, 6.865069312236297, 5.901736603932668, 4.934935685174334, 3.936988401984616, 4.876724663395414, 5.916197114524158, 6.8685112970398245, 7.826795365475895, 8.887019105941487, 9.896769269743308, 10.872966025960928, 11.871120750245774, 11.95618053982141, 10.892836656195668, 9.873053472498492, 8.925633553179624, 7.941347962624349, 6.986102137578727, 5.976556171513431, 6.969994098779654, 5.913688531740459, 4.933673807054212, 3.9668228798282437, 3.0111647435686892, 3.9934183516604134, 4.9596259239401, 5.89514982877553, 6.875418496343215, 7.898766925040474, 8.916680741874599, 9.921076417972255, 10.900649563614177, 11.032225435607781, 10.077484780598201, 9.150034894544618, 8.216021083130366, 7.250424817058312, 6.205234374596349, 5.164527917532513, 6.006098151329742, 4.99423545885889, 4.00313871708059, 3.009062523357106, 2.066193192684846, 3.0192507402082818, 3.9555398640178505, 4.986641312823936, 5.975867754255295, 6.905705589476503, 7.971415134199476, 8.917405323615045, 9.924748202421695, 10.994745915623099, 10.967072157015293, 10.039445187506086, 9.029520074450923, 8.048758400295581, 6.981093444438419, 5.950459881300221, 4.996174882973072, 4.0494272889867196, 3.079132457995514, 2.0490553315345927, 1.0230154935677827, 1.951380959897602, 3.026207257641447, 3.985491771400704, 5.004490249222339, 6.049214378129141, 7.029157167694795, 8.079611102252343, 9.072131957009145, 10.135868069467003, 11.128240000977085, 10.971080259821358, 9.980303139703437, 8.915385049360435, 7.8977150383180295, 6.8963045465636945, 4.107874886282886, 3.039574735417025, 2.0458467098442923, 1.026742095091491, 0.0, 1.0725122151633406, 2.088111593818224, 3.1387184321482056, 4.209886283274047, 5.275439532558103, 6.317990709619734, 7.31151916404065, 8.342911374210507, 9.35090413241818, 10.313450713453124, 11.268075480088475, 10.933846174505689, 9.903975154302492, 8.88467825818465, 7.867112450696896, 5.045571892262143, 3.9795358255215225, 2.933790165494118, 1.9996784010717397, 0.9716268303525522, 1.9349695084122418, 2.9051036958806713, 3.8999028496644854, 4.915316699428612, 5.931094853760993, 6.863896731421232, 7.903596433652345, 8.86755570145129, 9.82176513277795, 10.867766245829204, 11.830013920889394, 11.700842151953735, 10.724735021830627, 9.790316766997533, 8.792470433108088, 5.963499326275463, 4.991935309360337, 3.918948800194812, 2.932277009843729, 1.9823570227174165, 2.8922946678650776, 3.85037190430285, 4.89707031862835, 5.846305422643525, 6.787077429581768, 7.8317907537032605, 8.7596357031209, 9.777695550724408, 10.755005108373805, 11.709192275716278, 12.755095978077545, 12.64760052494582, 11.669781366073684, 10.771431521704493, 9.746954482256276, 6.94305570836191, 5.979548048160668, 4.949222454071752, 3.919003736570466, 2.9520920077085187, 3.8317445106794787, 4.789123086758157, 5.8193330850191645, 6.784086096831782, 7.717037410474906, 8.761066282704968, 9.731304446135866, 10.690249918929098, 11.647295193267675, 12.58309238085175, 13.540790041458388, 13.578821835938138, 12.601653015951111, 11.698077707228377, 10.790525646600925, 7.8570159578857295, 6.910922557546969, 5.8489085173345705, 4.877667685070541, 3.9687011323009367, 4.829591030243164, 5.790223037425671, 6.73923243917721, 7.759796129182812, 8.741146697574091, 9.792310637847873, 10.711679578994929, 11.740525628335039, 12.692223408123757, 13.549565361255098, 14.473838273454003, 14.593109815351783, 13.616276514121944, 12.660509839851303, 11.820743918687828, 8.714603574002702, 7.750171599090485, 6.782215479734765, 5.850677754060781, 5.0061319510569815, 5.883282011551035, 6.8047078634133795, 7.736168558023247, 8.752108155550543, 9.729278204509553, 10.73885421956132, 11.67919513155156, 12.65353986299386, 13.693183444212467, 14.562161252465858, 14.778020249978955, 15.604965323341277, 14.61364007570139, 13.723873065163438, 12.859137263583062, 9.787175583016817, 8.767674692083915, 7.712016953139528, 6.867844097893142, 6.048482235198257, 6.935851874195944, 7.736683999518434, 8.725918549592, 9.79709139218038, 10.72524257465941, 11.690668550689889, 12.648259335661347, 13.628368168988633, 14.593051983574473, 14.666419757226835, 13.727579550116479, 14.656973148438807, 15.586609458920112, 14.773950855896063, 13.856690641416684, 10.62342560410096, 9.6004344446133, 8.66328113136906, 7.8628359977698015, 7.049003324573501, 7.887896312841466, 8.757680230082647, 9.665700068464089, 10.602741341713024, 11.538507925120994, 12.611525850149285, 13.594447606377829, 14.582056423658113, 14.560216477231219, 13.65556239603707, 12.794397968971005, 13.75557757503133, 14.719063116069034, 15.549989177317014, 14.596877389704336, 11.559466688194027, 10.547824952550634, 9.706246897258186, 8.924015477692837, 8.066522146803777, 8.825452045607301, 9.816909912429361, 10.629781652131092, 11.530320316316269, 12.495319043663834, 13.45118203998803, 14.50052358779168, 14.495867303582989, 13.56134439832672, 12.672450496249402, 11.820406339020305, 12.772636484722012, 13.752944077231055, 14.727590162412188, 15.548563037241186], [15.608311587759909, 14.62034762697608, 13.751064946896951, 12.691519362112253, 11.752001980514418, 11.045385401300118, 11.866829371797325, 12.83283086346923, 13.818303941302887, 13.384044011037645, 12.455304536513697, 11.574809274124528, 10.57830742589549, 9.780024974688137, 8.857818302579346, 9.815172637988947, 10.86418692978999, 11.630435472093547, 12.477148209216738, 13.431243842510176, 14.605848260612627, 13.675791817426166, 12.745575789011781, 11.805229978749706, 10.822847767007818, 10.10518607504619, 10.912052996910264, 11.940441648072749, 12.87853999195632, 13.88337378839564, 13.502332205301746, 12.50969274255108, 11.570629989793671, 10.714060181909337, 9.866074462610673, 10.779929261387561, 11.8198657295588, 12.610887895799456, 13.475409240747506, 12.578475370795227, 13.743354855150248, 12.742760223954896, 11.777335314948237, 10.7982939319497, 9.87719454144562, 9.139364501343685, 9.949760989287215, 10.993872133607368, 11.85636260640062, 12.884540068125242, 13.863223185294649, 13.456072634581894, 12.60845923487816, 11.752487629790433, 10.840504080398548, 11.810356031956324, 12.790915276322625, 13.456426204854715, 12.516913747672548, 11.619207585388146, 12.830761754155807, 11.78500587306071, 10.840123951015023, 9.787721946573434, 8.85857074185381, 8.161721898311438, 9.009825944093066, 10.025800558204867, 10.881136985648492, 11.839592090855223, 12.7969731622366, 13.767062065687261, 13.594025417796923, 12.69482366755103, 11.875544952172701, 12.760044893768258, 13.62286033871541, 12.608627332245918, 11.588429664596246, 10.64846380416819, 11.841758585747572, 10.792559858412302, 9.867151921362304, 8.803632483875951, 7.8729373501766045, 7.158897600639131, 8.03486746297994, 8.986579684247163, 9.85263119301767, 10.826100735543418, 11.828231912350292, 12.831515105838946, 13.798031838063757, 13.679397749269857, 12.924919149163703, 13.810031958856477, 12.79578126179345, 11.747913406103477, 10.705378879138067, 9.759938630608028, 10.803456613014191, 9.785381582094514, 8.903249134707252, 7.900731413768819, 6.895389918602761, 6.145551697475815, 7.073152112601713, 7.92689408125789, 8.914462738035855, 9.882568816617532, 10.886443820057451, 11.83063889898927, 12.842013121181585, 13.826610657420074, 13.814519689648, 12.905478689521424, 11.885882937732598, 10.901443893152697, 9.905096551858648, 8.90445638862619, 9.76134222803676, 8.821385368427956, 7.886424576520395, 6.892443806569995, 5.929450442814651, 5.178305372484216, 6.096363456772389, 6.917769249676441, 7.872184176003245, 8.89639534813077, 9.968059163126656, 10.905455368469664, 11.907565451410083, 12.854730103294122, 12.835939330765202, 11.834966515876618, 10.811304765719752, 9.868478425344897, 8.863808927424676, 7.934743098900144, 8.8616485889665, 7.824305190030747, 6.860972481727117, 5.894171562968784, 4.896224279779066, 4.13656811315499, 5.03444362194038, 5.960956296809549, 6.919240365245619, 7.938200442261725, 8.947950606063545, 9.924147362281165, 10.922302086566011, 11.82849057414101, 11.862370664797366, 10.84258748110019, 9.895167561781323, 8.910881971226047, 7.955636146180425, 6.94609018011513, 7.929229976574103, 6.8729244095349085, 5.892909684848661, 4.926058757622693, 3.9704006213631384, 3.09999728439095, 4.054443498347953, 4.987594828545254, 5.9678634961129395, 6.946805363238349, 7.964719180072474, 8.958133391610144, 9.937706537252065, 10.8642073157745, 11.149996995761542, 10.222547109707959, 9.288533298293707, 8.322937032221652, 7.27774658975969, 6.237040132695853, 7.016141761281073, 5.962996496528678, 4.9623745948750395, 3.968298401151555, 3.025429070479295, 2.1217556853430923, 3.0503574384257037, 4.033053301698493, 5.022279743129851, 5.95211757835106, 7.008472107837364, 7.954462297252933, 8.961805176059583, 10.031802889260987, 11.03322322739028, 11.049488797457418, 10.039563684402255, 9.058802010246913, 7.99113705438975, 6.9605034912515515, 6.006218492924403, 5.05947089893805, 4.038368335789963, 3.008291209329042, 1.9822513713622316, 1.0538859050324123, 2.0175876710679166, 2.9768721848271733, 3.9958706626488087, 5.040594791555611, 6.020537581121264, 7.070991515678813, 8.063512370435614, 9.127248482893473, 10.119620414403554, 11.069364163572335, 10.990346749654769, 9.925428659311766, 8.907758648269361, 7.906348156515025, 5.180387101446226, 4.112086950580365, 3.118358925007633, 2.099254310254832, 1.0725122151633406, 0.0, 1.0155993786548834, 2.066206216984865, 3.137374068110706, 4.202927317394762, 5.245478494456393, 6.239006948877309, 7.270399159047166, 8.278391917254838, 9.240938498289783, 10.195563264925134, 11.197072959210038, 10.914018764253823, 9.894721868135981, 8.877156060648227, 6.0151059008638414, 4.949069834123221, 3.9033241740958164, 2.969212409673438, 1.9135705707428134, 0.950227892683124, 1.9203620801515537, 2.915161233935368, 3.9305750836994946, 4.946353238031876, 5.8791551156921145, 6.918854817923228, 7.882814085722171, 8.83702351704883, 9.883024630100085, 10.845272305160275, 11.896113914006301, 11.734778631781959, 10.800360376948865, 9.80251404305942, 6.933033334877162, 5.9614693179620355, 4.88848280879651, 3.9018110184454273, 2.924300763107678, 1.9075530521359596, 2.8656302885737324, 3.912328702899232, 4.861563806914408, 5.802335813852651, 6.847049137974143, 7.774894087391783, 8.792953934995293, 9.770263492644686, 10.72445065998716, 11.770354362348426, 12.763373406176473, 12.679824976025015, 11.75154490298181, 10.727067863533593, 7.912589716963608, 6.949082056762366, 5.918756462673451, 4.852146925241098, 3.885235196379151, 2.8470028949503607, 3.8043814710290396, 4.8345914692900465, 5.799344481102665, 6.732295794745789, 7.776324666975851, 8.74656283040675, 9.705508303199982, 10.66255357753856, 11.598350765122635, 12.556048425729273, 13.595666308776995, 13.611696625902443, 12.678191088505693, 11.749761524395375, 8.790159146556363, 7.844065746217601, 6.782051706005203, 5.810810873741174, 4.814695282664492, 3.844849414514046, 4.805481421696553, 5.754490823448092, 6.775054513453695, 7.7564050818449735, 8.807569022118754, 9.726937963265813, 10.755784012605925, 11.707481792394642, 12.564823745525983, 13.489096657724888, 14.496202076682042, 14.626320124073276, 13.64062322112862, 12.779979796482277, 9.647746762673334, 8.683314787761118, 7.715358668405397, 6.783820942731413, 5.852126101420537, 4.898540395821916, 5.8199662476842615, 6.751426942294129, 7.767366539821426, 8.744536588780436, 9.754112603832201, 10.694453515822445, 11.668798247264744, 12.708441828483352, 13.577419636736742, 14.447951190227224, 15.459449099876174, 15.623683685652722, 14.703986446440755, 13.81837314137751, 10.720318771687449, 9.700817880754546, 8.64516014181016, 7.800987286563775, 6.894476385561813, 5.951110258466825, 6.751942383789316, 7.741176933862882, 8.812349776451262, 9.74050095893029, 10.70592693496077, 11.663517719932232, 12.643626553259518, 13.608310367845357, 13.984433323157532, 14.686815427910927, 15.616209026233255, 16.54584533671456, 15.750600947776999, 14.815926519211134, 11.556568792771593, 10.533577633283933, 9.596424320039691, 8.795979186440434, 7.894997474937057, 6.903154697112347, 7.77293861435353, 8.680958452734972, 9.617999725983907, 10.553766309391877, 11.626784234420168, 12.609705990648711, 13.597314807928996, 13.824522015929206, 12.973575961967766, 13.753633846765453, 14.714813452825778, 15.678298993863482, 16.509225055111465, 15.556113267498786, 12.492609876864659, 11.480968141221267, 10.639390085928818, 9.85715866636347, 8.874445280855225, 7.8407104298781825, 8.832168296700244, 9.645040036401975, 10.545578700587152, 11.510577427934717, 12.466440424258913, 13.515781972062562, 13.760172842280976, 12.825649937024707, 11.990464062180099, 12.779642216814754, 13.73187236251646, 14.712179955025503, 15.686826040206638, 16.507798915035636], [16.535200709439373, 15.547236748655543, 14.677954068576414, 13.618408483791715, 12.67889110219388, 11.832305290859797, 10.851229993142443, 11.817231484814348, 12.802704562648007, 12.51925537896625, 11.590515904442302, 10.710020642053134, 9.713518793824097, 8.915236342616744, 9.80576676502392, 10.763121100433521, 11.814534555120607, 12.64603485074843, 13.492747587871621, 14.446843221165059, 15.532737382292089, 14.602680939105628, 13.672464910691243, 12.732119100429168, 11.74973688868728, 10.894080689536407, 9.896453618255382, 10.924842269417868, 11.86294061330144, 12.86777440974076, 12.637543573230353, 11.644904110479686, 10.705841357722278, 9.849271549837944, 10.799917684471035, 11.727877723832135, 12.767814192003373, 13.62648727445434, 14.49100861940239, 13.59407474945011, 14.67024397682971, 13.669649345634358, 12.7042244366277, 11.725183053629163, 10.804083663125082, 9.928259115833903, 8.934161610632334, 9.978272754952487, 10.84076322774574, 11.86894068947036, 12.847623806639769, 12.5912840025105, 11.743670602806766, 10.88769899771904, 11.77434730225891, 12.758304494400898, 13.738863738767199, 14.472025583509598, 13.532513126327432, 12.63480696404303, 13.75765087583527, 12.711894994740172, 11.767013072694485, 10.714611068252896, 9.785459863533273, 8.950616512801655, 7.9942265654381846, 9.010201179549984, 9.865537606993612, 10.823992712200342, 11.78137378358172, 12.751462687032378, 12.72923678572553, 11.830035035479638, 12.802538463641973, 13.707993356212832, 14.638459717370294, 13.624226710900802, 12.60402904325113, 11.664063182823073, 12.768647707427034, 11.719448980091764, 10.794041043041766, 9.730521605555413, 8.799826471856067, 7.948945973898578, 7.019268084325059, 7.970980305592281, 8.837031814362788, 9.810501356888537, 10.812632533695409, 11.815915727184063, 12.782432459408874, 12.814609117198463, 13.809202383552014, 14.75798042130105, 13.811380640448332, 12.763512784758358, 11.720978257792948, 10.77553800926291, 11.730345734693653, 10.712270703773976, 9.830138256386714, 8.82762053544828, 7.822279040282223, 6.994843195713113, 6.057552733946832, 6.911294702603008, 7.898863359380973, 8.866969437962648, 9.870844441402568, 10.815039520334386, 11.826413742526702, 12.811011278765191, 13.749019603706492, 13.921078068176307, 12.901482316387481, 11.91704327180758, 10.920695930513531, 9.920055767281074, 10.688231349716222, 9.748274490107418, 8.813313698199856, 7.819332928249457, 6.856339564494113, 6.0275968707215135, 5.080764078117507, 5.902169871021559, 6.856584797348362, 7.880795969475887, 8.952459784471772, 9.889855989814782, 10.891966072755201, 11.839130724639238, 12.770439244823693, 12.8505658945315, 11.826904144374636, 10.88407780399978, 9.87940830607956, 8.950342477555028, 9.788537710645961, 8.75119431171021, 7.787861603406579, 6.821060684648246, 5.823113401458528, 4.9858596113922875, 4.018844243285497, 4.945356918154666, 5.903640986590736, 6.922601063606843, 7.932351227408663, 8.908547983626283, 9.90670270791113, 10.812891195486127, 11.797840576553668, 11.858186859755072, 10.910766940436204, 9.926481349880929, 8.971235524835308, 7.961689558770013, 8.856119098253565, 7.799813531214371, 6.819798806528123, 5.852947879302155, 4.897289743042601, 3.9492887826282472, 3.0388441196930707, 3.971995449890372, 4.952264117458057, 5.931205984583467, 6.9491198014175914, 7.942534012955262, 8.922107158597184, 9.848607937119619, 10.803348592129199, 11.238146488362842, 10.30413267694859, 9.338536410876536, 8.293345968414572, 7.252639511350736, 7.945961608071892, 6.88988561820814, 5.889263716554502, 4.8951875228310175, 3.952318192158758, 2.9710471835803896, 2.034758059770821, 3.01745392304361, 4.006680364474969, 4.936518199696177, 5.992872729182483, 6.938862918598051, 7.946205797404702, 9.016203510606108, 10.0176238487354, 10.945250818244608, 11.055163063057138, 10.074401388901796, 9.006736433044633, 7.976102869906434, 7.021817871579286, 6.075070277592933, 5.053967714444846, 4.023890587983924, 2.9978507500171148, 2.0694852836872957, 1.0019882924130334, 1.9612728061722904, 2.9802712839939263, 4.024995412900728, 5.004938202466382, 6.055392137023931, 7.047912991780732, 8.111649104238591, 9.104021035748673, 10.053764784917451, 11.044541905035372, 10.941028037966648, 9.923358026924243, 8.921947535169908, 6.1959864801011095, 5.127686329235249, 4.133958303662516, 3.114853688909715, 2.088111593818224, 1.0155993786548834, 0.0, 1.0506068383299816, 2.1217746894558225, 3.187327938739879, 4.22987911580151, 5.2234075702224265, 6.2547997803922835, 7.262792538599955, 8.2253391196349, 9.17996388627025, 10.181473580555155, 11.215837967507733, 10.873458284252045, 9.855892476764293, 7.030705279518725, 5.964669212778104, 4.9189235527507, 3.9848117883283214, 2.929169949397697, 1.9658272713380074, 1.0513424849224162, 2.045378121329726, 3.060791971093853, 4.076570125426235, 5.009372003086473, 6.049071705317587, 7.01303097311653, 7.9672404044431895, 9.013241517494443, 9.975489192554633, 11.02633080140066, 12.002437931523767, 11.738414854622638, 10.740568520733193, 7.948632713532045, 6.977068696616919, 5.904082187451394, 4.91741039710031, 3.9399001417625614, 2.923152430790843, 1.996610693344595, 3.0425455902935905, 3.991780694308766, 4.93255270124701, 5.977266025368502, 6.905110974786142, 7.923170822389651, 8.900480380039044, 9.854667547381517, 10.900571249742784, 11.893590293570831, 12.947484275766824, 12.678434024661271, 11.653956985213055, 8.928189095618492, 7.9646814354172495, 6.934355841328334, 5.867746303895982, 4.900834575034034, 3.862602273605244, 2.939592838957646, 3.969802837218653, 4.9345558490312715, 5.862512682140148, 6.906541554370209, 7.876779717801109, 8.83572519059434, 9.792770464932918, 10.728567652516993, 11.68626531312363, 12.725883196171353, 13.786267630642643, 13.605080210185156, 12.676650646074837, 9.805758525211244, 8.859665124872484, 7.797651084660086, 6.826410252396057, 5.830294661319376, 4.8604487931689295, 3.9406927896251593, 4.889702191376698, 5.910265881382301, 6.886621969239332, 7.937785909513113, 8.857154850660173, 9.886000900000283, 10.837698679789, 11.69504063292034, 12.619313545119246, 13.6264189640764, 14.664876145890272, 14.567512342808081, 13.706868918161739, 10.663346141328217, 9.698914166416001, 8.73095804706028, 7.799420321386297, 6.86772548007542, 5.9141397744768, 4.955177615612868, 5.886638310222736, 6.902577907750032, 7.879747956709043, 8.88432949122656, 9.824670403216805, 10.799015134659104, 11.838658715877711, 12.7076365241311, 13.578168077621582, 14.589665987270532, 15.58099123491042, 15.630875568120217, 14.745262263056972, 11.735918150342332, 10.716417259409429, 9.660759520465044, 8.816586665218658, 7.910075764216696, 6.9487062719760075, 5.887153751717923, 6.876388301791489, 7.947561144379869, 8.875712326858899, 9.836143822355128, 10.793734607326591, 11.773843440653877, 12.738527255239717, 13.64884419283284, 14.594223271602615, 15.523616869924943, 16.45325318040625, 16.67749006945646, 15.742815640890596, 12.572168171426476, 11.549177011938816, 10.612023698694575, 9.811578565095317, 8.853952976720967, 7.851103159556921, 6.908149982282136, 7.816169820663578, 8.753211093912514, 9.688977677320484, 10.761995602348774, 11.744917358577318, 12.732526175857602, 12.808922637274325, 13.746782068377694, 14.680522968444915, 15.64170257450524, 16.605188115542944, 17.436114176790923, 16.483002389178246, 13.508209255519542, 12.49656751987615, 11.654989464583702, 10.872758045018353, 9.822393743299799, 8.788658892322756, 7.967379664628851, 8.780251404330581, 9.680790068515758, 10.645788795863321, 11.601651792187518, 12.650993339991167, 12.744573463626095, 11.810050558369825, 12.763670168590027, 13.706531338494216, 14.658761484195923, 15.639069076704965, 16.6137151618861, 17.434688036715094], [17.423868566260538, 16.435904605476708, 15.56662192539758, 14.507076340612882, 13.567558959015047, 12.67107935519518, 11.690004057477827, 10.997853351334467, 11.772803391950657, 11.612423958693395, 10.683684484169447, 9.803189221780277, 8.80668737355124, 9.816544845114416, 10.743994716885062, 11.701349052294663, 12.75276250698175, 13.618631944040654, 14.465344681163845, 15.419440314457283, 16.421405239113255, 15.491348795926795, 14.56113276751241, 13.620786957250335, 12.638404745508447, 11.732854753871791, 10.735227682590766, 9.928650153043819, 10.83303944260409, 11.83787323904341, 11.730712152957496, 10.73807269020683, 9.799009937449421, 10.750580052335616, 11.701226186968707, 12.666105675693277, 13.706042143864515, 14.599084367746563, 15.463605712694614, 14.566671842742334, 15.558911833650876, 14.558317202455525, 13.592892293448868, 12.61385091045033, 11.692751519946249, 10.767033180169287, 9.772935674967718, 8.982080638578438, 9.81086205704839, 10.839039518773012, 11.817722635942419, 11.684452582237643, 10.83683918253391, 11.789007500216712, 12.675655804756582, 13.69653244626204, 14.677091690628341, 15.444622676801822, 14.505110219619656, 13.607404057335254, 14.646318732656436, 13.600562851561339, 12.655680929515654, 11.603278925074063, 10.67412772035444, 9.78939057713704, 8.833000629773569, 7.980300008852637, 8.835636436296262, 9.794091541502993, 10.75147261288437, 11.721561516335031, 11.822405365452672, 12.73134353797731, 13.703846966139645, 14.646221308073974, 15.611056810662518, 14.596823804193026, 13.576626136543354, 12.636660276115297, 13.6573155642482, 12.60811683691293, 11.682708899862932, 10.61918946237658, 9.688494328677233, 8.787720038233962, 7.858042148660443, 6.941079134894933, 7.80713064366544, 8.780600186191188, 9.782731362998062, 10.786014556486716, 11.752531288711527, 12.693265150293993, 13.687858416647543, 14.65169527592377, 14.783977733740556, 13.736109878050582, 12.693575351085173, 11.748135102555134, 12.61901359151482, 11.600938560595143, 10.718806113207881, 9.716288392269448, 8.710946897103389, 7.86413352839186, 6.896326798282216, 5.88139353190566, 6.868962188683625, 7.837068267265301, 8.840943270705221, 9.78513834963704, 10.796512571829355, 11.781110108067844, 12.719118433009145, 13.662276479284033, 13.895359669301463, 12.910920624721562, 11.914573283427513, 10.913933120195056, 11.576899206537389, 10.636942346928585, 9.701981555021023, 8.708000785070624, 7.74500742131528, 6.9014514620456335, 5.9195381424528914, 4.872268700324211, 5.826683626651015, 6.85089479877854, 7.922558613774425, 8.859954819117434, 9.862064902057853, 10.809229553941892, 11.740538074126347, 12.748783573934546, 12.820781497288618, 11.877955156913762, 10.873285658993542, 9.94421983046901, 10.677205567467128, 9.639862168531376, 8.676529460227746, 7.7097285414694126, 6.711781258279695, 5.874527468213454, 4.857618307620881, 3.9154557474573193, 4.873739815893389, 5.892699892909495, 6.902450056711316, 7.878646812928935, 8.876801537213781, 9.78299002478878, 10.76793940585632, 11.6787011980135, 11.904644293350188, 10.920358702794912, 9.965112877749291, 8.955566911683995, 9.744786955074732, 8.688481388035537, 7.70846666334929, 6.741615736123322, 5.785957599863767, 4.8379566394494145, 3.8776181840284547, 2.9420942791930247, 3.92236294676071, 4.901304813886119, 5.919218630720244, 6.9126328422579135, 7.8922059878998345, 8.81870676642227, 9.77344742143185, 10.700897307485434, 11.354739515278572, 10.389143249206517, 9.343952806744554, 8.303246349680718, 8.834629464893059, 7.778553475029307, 6.777931573375668, 5.783855379652184, 4.840986048979924, 3.8597150404015563, 2.9234259165919876, 1.987552752346263, 2.976779193777621, 3.90661702899883, 4.962971558485135, 5.908961747900704, 6.916304626707355, 7.98630233990876, 8.987722678038052, 9.91534964754726, 10.925274760602422, 10.970398552192547, 9.902733596335384, 8.872100033197185, 7.917815034870037, 6.971067440883684, 5.949964877735597, 4.9198877512746755, 3.893847913307865, 2.9654824469780454, 1.8906561492342002, 0.9313716354749433, 1.950370113296579, 2.995094242203381, 3.9750370317690344, 5.025490966326583, 6.018011821083384, 7.0817479335412425, 8.074119865051324, 9.023863614220105, 10.014640734338025, 11.079558824681028, 10.819355190214994, 9.817944698460659, 7.246593318431091, 6.17829316756523, 5.184565141992498, 4.165460527239697, 3.1387184321482056, 2.066206216984865, 1.0506068383299816, 0.0, 1.071167851125841, 2.1367211004098974, 3.1792722774715285, 4.172800731892445, 5.204192942062302, 6.212185700269973, 7.174732281304918, 8.12935704794027, 9.130866742225173, 10.165231129177752, 11.184528025295593, 10.74456033358546, 8.024582632432706, 6.958546565692085, 5.912800905664681, 4.978689141242302, 3.923047302311678, 2.959704624251988, 1.9895704367835587, 0.9947712829997445, 2.0101851327638713, 3.0259632870962534, 3.9587651647564917, 4.9984648669876055, 5.9624241347865485, 6.916633566113208, 7.962634679164462, 8.924882354224653, 9.97572396307068, 10.951831093193787, 11.886249348026881, 11.62923637755436, 8.942510066446026, 7.9709460495309, 6.897959540365375, 5.911287750014292, 4.9337774946765425, 3.917029783704824, 2.9348386452057373, 1.9919387519636087, 2.941173855978784, 3.881945862917028, 4.926659187038521, 5.8545041364561605, 6.87256398405967, 7.849873541709062, 8.804060709051535, 9.849964411412804, 10.842983455240851, 11.896877437436844, 12.889546743668863, 12.542624842034222, 9.922066448532473, 8.95442741420727, 7.913790641651579, 6.840343397188204, 5.873431668326257, 4.835199366897466, 3.877820790818788, 3.017782249658894, 3.968690711274321, 4.811905843810166, 5.8559347160402275, 6.826172879471128, 7.785118352264359, 8.742163626602936, 9.677960814187012, 10.63565847479365, 11.675276357841371, 12.735660792312661, 13.685108814602465, 13.565318502896003, 10.778355618503468, 9.832262218164708, 8.77024817795231, 7.799007345688279, 6.802891754611598, 5.833045886461152, 4.878920741486302, 3.982870771103841, 4.9444007436253505, 5.836015130909351, 6.887179071183131, 7.806548012330191, 8.8353940616703, 9.787091841459018, 10.644433794590359, 11.568706706789264, 12.575812125746419, 13.61426930756029, 14.64754094722539, 14.595536774982907, 11.635943234620441, 10.671511259708225, 9.703555140352504, 8.772017414678519, 7.840322573367643, 6.886736867769022, 5.8934055674740105, 4.979806889949879, 5.936712769993082, 6.886833899164708, 7.8337226528965775, 8.774063564886823, 9.748408296329123, 10.78805187754773, 11.657029685801119, 12.5275612392916, 13.53905914894055, 14.530384396580438, 15.535750039518824, 15.63393011987814, 12.708515243634556, 11.689014352701655, 10.633356613757268, 9.78918375851088, 8.882672857508918, 7.88693422383715, 6.825381703579065, 5.969556881518632, 7.004941734281411, 7.93309291676044, 8.785536984025146, 9.74312776899661, 10.723236602323896, 11.687920416909735, 12.598237354502858, 13.543616433272634, 14.473010031594962, 15.402646342076267, 16.391691576403275, 16.631483497711763, 13.5447652647187, 12.52177410523104, 11.584620791986799, 10.78417565838754, 9.792180928582109, 8.789331111418063, 7.846377934143279, 6.9093384003907214, 7.846379673639657, 8.782146257047627, 9.774368430287705, 10.748631463286749, 11.683899408229019, 12.66963627560934, 13.609094715692624, 14.476798014418108, 15.413674948695634, 16.37716048973334, 17.326185585023303, 17.371670245999415, 14.480806348811766, 13.469164613168374, 12.627586557875926, 11.83542993356232, 10.76062169516094, 9.726886844183898, 8.905607616489993, 7.873419984057724, 8.773958648242902, 9.738957375590466, 10.694820371914663, 11.744161919718312, 11.925195330146213, 12.64882462270521, 13.60244423292541, 14.591443251850412, 15.54742934101709, 16.527736933526132, 17.502383018707263, 18.323355893536263], [18.495036417386377, 17.50707245660255, 16.637789776523423, 15.578244191738724, 14.63872681014089, 13.742247206321021, 12.761171908603668, 11.980262707488873, 10.967613093075222, 10.735346523932508, 9.889580559280944, 9.038728252840736, 9.784592453801007, 10.794449925364184, 11.72189979713483, 12.67925413254443, 13.730667587231517, 14.596537024290422, 15.443249761413613, 16.397345394707052, 17.492573090239095, 16.562516647052636, 15.632300618638252, 14.691954808376178, 13.70957259663429, 12.804022604997632, 11.806395533716607, 10.911059509198227, 10.027849143728655, 11.032682940167975, 10.959465388326482, 9.973611721267288, 10.776915017699189, 11.728485132585384, 12.679131267218475, 13.644010755943045, 14.683947224114283, 15.576989447996331, 16.44151079294438, 15.544576922992102, 16.630079684776717, 15.629485053581366, 14.66406014457471, 13.685018761576172, 12.763919371072092, 11.838201031295128, 10.844103526093559, 9.964489994732846, 9.005671758172955, 10.033849219897576, 11.001362715321953, 10.919991613298102, 11.814744262783677, 12.76691258046648, 13.65356088500635, 14.674437526511808, 15.654996770878109, 16.42252775705159, 15.483015299869423, 14.585309137585021, 15.717486583782277, 14.67173070268718, 13.726848780641497, 12.674446776199906, 11.745295571480282, 10.86055842826288, 9.90416848089941, 8.99501684687667, 8.030446137420828, 8.988901242627557, 9.935112692263905, 10.868459229927618, 11.824039350625865, 12.799778855556315, 13.772282283718651, 14.742943289578964, 15.760334494215929, 15.574728884442793, 14.554531216793121, 13.614565356365064, 14.728483415374042, 13.679284688038772, 12.753876750988775, 11.690357313502423, 10.759662179803076, 9.858887889359803, 8.929209999786284, 7.955795972918965, 7.001940344790004, 7.975409887315752, 8.96245027910929, 9.932912270079303, 10.880440143291272, 11.821174004873738, 12.795557695778498, 13.759394555054724, 14.76485012954927, 14.71401495830035, 13.67148043133494, 12.726040182804901, 13.690181442640661, 12.672106411720984, 11.789973964333722, 10.787456243395289, 9.782114748229231, 8.935301379517702, 7.9674946494080565, 6.952561383031501, 6.063771889808189, 7.016787183376531, 8.02066218681645, 8.921489430899191, 9.915396351238249, 10.899993887476738, 11.775153537065458, 12.718311583340347, 13.723447676704996, 13.88882570497133, 12.89247836367728, 11.891838200444823, 12.64806705766323, 11.708110198054426, 10.773149406146864, 9.779168636196465, 8.816175272441122, 7.972619313171474, 6.990705993578732, 5.943436551450052, 5.021493327775579, 6.030613714889769, 7.102277529885654, 7.97610081684465, 8.970434237254448, 9.865264657998205, 10.79657317818266, 11.80481867799086, 12.64886950469215, 12.85586023716353, 11.85119073924331, 10.922124910718777, 11.74837341859297, 10.711030019657217, 9.747697311353587, 8.780896392595253, 7.782949109405536, 6.945695319339295, 5.928786158746722, 4.98662359858316, 4.068549517017953, 5.035977426026213, 6.045727589828034, 6.9947928106561506, 7.985170872410377, 8.839025128845094, 9.823974509912635, 10.734736302069814, 11.682156221388682, 11.898263783044678, 10.943017957999057, 9.933471991933763, 10.815954806200573, 9.759649239161378, 8.77963451447513, 7.812783587249163, 6.857125450989608, 5.909124490575255, 4.948786035154296, 4.013262130318865, 3.0664412673645813, 4.044582347002837, 5.062496163836962, 5.968667946314229, 6.94824109195615, 7.8747418704785845, 8.829482525488165, 9.756932411541749, 10.690946222956, 11.460311100332358, 10.415120657870395, 9.374414200806559, 9.9057973160189, 8.849721326155148, 7.849099424501509, 6.855023230778025, 5.912153900105765, 4.930882891527397, 3.994593767717828, 3.058720603472104, 2.1200567268943393, 3.049894562115548, 4.019006662541449, 4.964996851957018, 5.972339730763669, 7.042337443965074, 8.043757782094367, 8.971384751603575, 9.981309864658737, 10.96207153881408, 10.973901447461227, 9.943267884323028, 8.98898288599588, 8.042235292009526, 7.021132728861438, 5.991055602400516, 4.965015764433706, 4.036650298103886, 2.961824000360041, 2.002539486600784, 1.066034695890678, 2.0511293462596956, 3.031072135825349, 4.055851676273353, 5.048372531030155, 6.111691308770512, 7.104063240280594, 8.053806989449374, 9.013241925901584, 10.078160016244587, 11.095830027286992, 10.889112549586502, 8.317761169556931, 7.249461018691071, 6.255732993118339, 5.236628378365538, 4.209886283274047, 3.137374068110706, 2.1217746894558225, 1.071167851125841, 0.0, 1.0655532492840565, 2.1081044263456876, 3.101632880766604, 4.133025090936461, 5.1410178491441325, 6.103564430179077, 7.058189196814428, 8.059698891099332, 9.09406327805191, 10.113360174169753, 11.130925981657505, 9.002487712682473, 7.936451645941853, 6.890705985914448, 5.95659422149207, 4.900952382561446, 3.937609704501756, 2.9674755170333267, 1.9726763632495126, 0.9572625134853857, 1.9730406678177674, 2.9058425454780057, 3.9455422477091195, 4.909501515508063, 5.863710946834722, 6.909712059885976, 7.8719597349461665, 8.922801343792193, 9.8989084739153, 10.833326728748395, 11.83117306263784, 9.920415146695793, 8.948851129780667, 7.875864620615142, 6.88919283026406, 5.91168257492631, 4.8949348639545915, 3.9127437254555053, 2.969843832213377, 2.026682382534404, 2.967454389472648, 3.873736567760035, 4.801581517177675, 5.819641364781184, 6.796950922430577, 7.75113808977305, 8.797041792134317, 9.790060835962365, 10.843954818158357, 11.836624124390376, 12.785657111786028, 10.89997152878224, 9.932332494457038, 8.891695721901346, 7.818248477437972, 6.851336748576025, 5.813104447147235, 4.8557258710685565, 3.9956873299086624, 3.0541992378299403, 3.8974143703657855, 4.8030120967617425, 5.773250260192642, 6.732195732985873, 7.6892410073244495, 8.625038194908525, 9.582735855515162, 10.622353738562884, 11.682738173034174, 12.632186195323978, 13.564982900147157, 11.756260698753236, 10.810167298414475, 9.748153258202077, 8.776912425938047, 7.780796834861366, 6.81095096671092, 5.85682582173607, 4.960775851353609, 4.02990927018097, 4.92152365746497, 5.86487213318872, 6.753625393051705, 7.782471442391815, 8.734169222180531, 9.591511175311872, 10.515784087510777, 11.522889506467932, 12.561346688281803, 13.594618327946904, 14.553101438968381, 12.613848314870209, 11.649416339957993, 10.681460220602272, 9.749922494928287, 8.818227653617411, 7.864641948018791, 6.871310647723779, 5.957711970199647, 5.022221296548701, 5.972342425720328, 6.811415714902166, 7.721140945608338, 8.695485677050637, 9.735129258269245, 10.604107066522632, 11.474638620013113, 12.486136529662064, 13.47746177730195, 14.482827420240337, 15.51030595902233, 13.686420323884324, 12.66691943295142, 11.611261694007036, 10.767088838760648, 9.860577937758686, 8.864839304086917, 7.803286783828834, 6.9474619617684, 6.090450260837031, 7.01860144331606, 7.763230046030736, 8.690205149718125, 9.67031398304541, 10.63499779763125, 11.545314735224371, 12.490693813994147, 13.420087412316475, 14.34972372279778, 15.338768957124786, 16.27344338569065, 14.522670344968468, 13.499679185480808, 12.562525872236566, 11.762080738637307, 10.770086008831877, 9.76723619166783, 8.824283014393046, 7.887243480640489, 7.081918704700115, 7.988042332159125, 8.752061492293295, 9.695708844008262, 10.630976788950534, 11.616713656330855, 12.556172096414137, 13.423875395139621, 14.360752329417148, 15.324237870454851, 16.273262965744816, 17.226374753357494, 15.458711429061534, 14.447069693418142, 13.605491638125693, 12.813335013812088, 11.738526775410708, 10.704791924433666, 9.88351269673976, 8.851325064307492, 8.00949767930336, 8.944853450701963, 9.698379563044847, 10.747721110848495, 11.559679760244677, 12.615585735235355, 13.539283996201805, 14.39786702509032, 15.397070651025826, 16.36060399925485, 17.245101000492433, 18.178060400894342], [18.229462749298914, 17.361939075630964, 16.433714742028656, 15.415384304896467, 14.475866923298632, 13.484458190353658, 12.503382892636305, 11.5373814009644, 10.724420938492196, 9.785706185840484, 8.959512109670055, 9.916944172429162, 10.731146140965842, 11.741003612529019, 12.670309257734806, 13.627663593144407, 14.679077047831493, 15.641805531284923, 16.5007887428497, 17.454884376143138, 17.226999422151632, 17.461732578039964, 16.489091998547625, 15.548746188285552, 14.566363976543665, 13.634405713024002, 12.636778641742977, 11.707994812611195, 10.824784447141624, 10.028427667409073, 10.029396938715593, 10.851827640855713, 11.723468704864024, 12.675038819750219, 13.62568495438331, 14.59242021654302, 15.632356684714258, 16.622257954990832, 17.499049774380467, 16.60211590442819, 16.39637471165951, 16.53870757552655, 15.520851524484085, 14.541810141485547, 13.620710750981466, 12.668584139321498, 11.674486634119928, 10.761425298145815, 9.802607061585924, 8.979755880550048, 9.938622348292505, 10.854133770746362, 11.744052284260572, 12.676561644032857, 13.617861988745226, 14.627078902106842, 15.6905358023727, 16.52282698767484, 16.54055428130551, 15.642848119021107, 15.60001968112429, 15.580953224632365, 14.583640160550871, 13.53123815610928, 12.602086951389657, 11.69094153628925, 10.734551588925779, 9.791952150289639, 8.827381440833797, 7.934807903280029, 8.872372325234457, 9.80290598064356, 10.75848610134181, 11.73422560627226, 12.706729034434595, 13.677390040294908, 14.694781244931873, 15.546875621907871, 15.612070198229206, 14.67210433780115, 14.623757205084644, 14.588507209983957, 13.61066813089815, 12.547148693411797, 11.61645355971245, 10.689270997386172, 9.759593107812654, 8.752731276331934, 7.798875648202973, 6.921316547968224, 7.899709912079843, 8.867359020795245, 9.814886894007216, 10.755620755589682, 11.730004446494442, 12.693841305770668, 13.699296880265214, 14.615132056772694, 14.729019412771025, 13.783579164240987, 13.561647473436317, 13.614832564547909, 12.732700117160647, 11.730182396222213, 10.724840901056156, 9.765684487544071, 8.797877757434426, 7.782944491057871, 6.860707193221158, 5.954046816347082, 6.9579218197870025, 7.855936181615134, 8.849843101954193, 9.834440638192682, 10.709600287781402, 11.65275833405629, 12.65789442742094, 13.57911761792646, 13.958031612961337, 12.95739144972888, 12.764192166613407, 12.65083635088135, 11.715875558973789, 10.72189478902339, 9.758901425268046, 8.803002421197844, 7.821089101605102, 6.773819659476422, 5.818428631188548, 4.967873347860321, 6.039537162856206, 6.910547567560594, 7.904880987970391, 8.799711408714149, 9.731019928898604, 10.739265428706805, 11.583316255408095, 12.52614259578295, 12.916743988527365, 11.987678160002833, 11.833563534633047, 11.653756172484142, 10.690423464180512, 9.723622545422177, 8.72567526223246, 7.798641717901835, 6.759169266773092, 5.81700670660953, 4.865484820430922, 3.973237058996765, 4.982987222798585, 5.9292395613720945, 6.919617623126321, 7.773471879561038, 8.758421260628579, 9.669183052785758, 10.616602972104626, 11.600888562659902, 12.008571207283115, 10.999025241217819, 11.065146110884179, 10.702375391988303, 9.722360667302056, 8.755509740076088, 7.799851603816533, 6.84426885016775, 5.779169143180665, 4.8436452383452355, 3.8633765707775507, 2.9818419799733893, 3.9997557968075137, 4.903114697030173, 5.882687842672094, 6.8091886211945285, 7.763929276204109, 8.691379162257693, 9.625392973671945, 10.590989239744, 11.480673907154452, 10.439967450090617, 10.848523468845825, 9.792447478982073, 8.791825577328435, 7.79774938360495, 6.85488005293269, 5.873609044354322, 4.937319920544753, 3.9062184717386668, 2.9169920303073087, 1.9871541950861, 2.9534534132573933, 3.899443602672962, 4.906786481479613, 5.976784194681018, 6.97820453281031, 7.905831502319518, 8.91575661537468, 9.896518289530022, 10.955647211814451, 10.990027101426318, 10.03574210309917, 9.088994509112815, 8.067891945964728, 7.037814819503808, 6.011774981536997, 5.083409515207178, 4.008583217463333, 3.0492987037040766, 2.0303002258824407, 0.985576096975639, 1.9655188865412927, 2.9902984269892965, 3.9828192817460977, 5.046138059486456, 6.038509990996538, 6.988253740165317, 7.9476886766175285, 9.012606766960532, 10.030276778002937, 11.031687269757272, 9.383314418840989, 8.315014267975128, 7.321286242402395, 6.302181627649594, 5.275439532558103, 4.202927317394762, 3.187327938739879, 2.1367211004098974, 1.0655532492840565, 0.0, 1.042551177061631, 2.0360796314825476, 3.0674718416524045, 4.0754645998600765, 5.038011180895021, 5.992635947530372, 6.994145641815276, 8.028510028767855, 9.047806924885696, 10.06537273237345, 10.06804096196653, 9.002004895225909, 7.956259235198504, 7.022147470776126, 5.966505631845502, 5.003162953785813, 4.033028766317383, 3.038229612533569, 2.0228157627694423, 1.0234003297257441, 1.9562022073859824, 2.9959019096170962, 3.9598611774160393, 4.914070608742699, 5.960071721793953, 6.922319396854143, 7.973161005700169, 8.949268135823276, 9.88368639065637, 10.881532724545815, 10.985968395979851, 10.014404379064725, 8.9414178698992, 7.954746079548116, 6.977235824210366, 5.9604881132386485, 4.978296974739561, 3.9163975193782123, 2.967162415363037, 2.026390408424793, 2.9240962296680117, 3.8519411790856517, 4.8700010266891605, 5.847310584338553, 6.801497751681026, 7.847401454042294, 8.84042049787034, 9.894314480066333, 10.886983786298352, 11.836016773694004, 11.965524778066298, 10.997885743741096, 9.957248971185404, 8.883801726722028, 7.916889997860081, 6.878657696431291, 5.9212791203526125, 4.942241017073497, 3.9946792706585734, 2.9563503893179304, 3.853371758669719, 4.823609922100618, 5.7825553948938495, 6.739600669232426, 7.6753978568165016, 8.633095517423138, 9.67271340047086, 10.73309783494215, 11.682545857231954, 12.615342562055133, 12.813799680189321, 11.86770627985056, 10.805692239638162, 9.834451407374132, 8.806957809722542, 7.837111941572096, 6.856338940269983, 5.907329538518444, 4.970389303009603, 3.980459676417115, 4.915231795096696, 5.803985054959682, 6.832831104299792, 7.784528884088508, 8.641870837219848, 9.566143749418753, 10.573249168375908, 11.61170635018978, 12.64497798985488, 13.603461100876357, 13.671387296306294, 12.706955321394078, 11.738999202038357, 10.807461476364372, 9.844388628478587, 8.874072650310286, 7.870823766257692, 6.904265657364482, 5.962701329377334, 5.031278444672472, 5.861775376810143, 6.771500607516314, 7.745845338958613, 8.78548892017722, 9.654466728430608, 10.52499828192109, 11.53649619157004, 12.527821439209927, 13.533187082148313, 14.560665620930306, 14.74395930532041, 13.724458414387506, 12.668800675443121, 11.824627820196733, 10.886738912619862, 9.864352422620831, 8.802799902362747, 7.894015648933235, 7.016684176184198, 6.088532993705169, 6.813589707938712, 7.7405648116261005, 8.720673644953386, 9.685357459539226, 10.595674397132347, 11.541053475902123, 12.47044707422445, 13.400083384705756, 14.389128619032762, 15.323803047598627, 15.580209326404553, 14.557218166916893, 13.620064853672652, 12.773172624849575, 11.718495469431852, 10.715645652267806, 9.772692474993022, 8.833797167805324, 7.993740465956204, 7.057973882548234, 7.802421154201272, 8.746068505916238, 9.68133645085851, 10.667073318238831, 11.606531758322113, 12.474235057047597, 13.411111991325123, 14.374597532362827, 15.323622627652794, 16.276734415265473, 16.51625041049762, 15.504608674854227, 14.663030619561779, 13.761744474412064, 12.686936236010684, 11.653201385033642, 10.831922157339736, 9.797878751472327, 8.921319440559449, 8.014785001091074, 8.748739224952823, 9.798080772756471, 10.610039422152653, 11.66594539714333, 12.58964365810978, 13.448226686998296, 14.447430312933802, 15.410963661162826, 16.29546066240041, 17.22842006280232], [17.289952826301192, 16.422429152633246, 15.494204819030934, 14.475874381898748, 13.536357000300914, 12.544948267355936, 11.563872969638583, 10.597871477966677, 9.784911015494476, 8.846196262842764, 9.70981940685828, 10.667251469617387, 11.614719715226112, 12.624577186789288, 13.553882831995075, 14.511237167404676, 15.562650622091763, 16.525379105545195, 17.42688257517245, 18.38097820846589, 16.28748949915391, 17.21754594234037, 16.38389023570929, 15.443544425447218, 14.465511213807513, 13.485147593609865, 12.518649344525643, 11.667074676257325, 10.724674964841043, 9.773033339431663, 10.185748775675076, 10.813977797798133, 11.762172145744449, 12.72845322693491, 13.605755741554058, 14.584481954470894, 15.624418422642131, 16.48034889938212, 17.43429907295292, 17.528209736750938, 15.456864788661793, 16.457459419857145, 16.540552100079452, 15.561510717080916, 14.640411326576835, 13.688284714916865, 12.694187209715295, 11.78112587374118, 10.82230763718129, 9.999456456145413, 9.12888650606028, 9.867597905767319, 10.75751641928153, 11.690025779053814, 12.631326123766183, 13.640543037127799, 14.703999937393657, 15.536291122695797, 16.475803579877965, 16.56894195134386, 14.660509758126569, 15.639836872324468, 15.60334073614624, 14.55093873170465, 13.621787526985026, 12.710642111884617, 11.754252164521146, 10.811652725885004, 9.847082016429162, 8.954508478875395, 8.062636483002231, 8.816370115664517, 9.771950236362766, 10.747689741293216, 11.720193169455552, 12.690854175315865, 13.70824537995283, 14.560339756928828, 15.5805374245785, 15.598198170123903, 13.684247282086922, 14.64739085767606, 14.630368706493519, 13.566849269007166, 12.63615413530782, 11.70897157298154, 10.77929368340802, 9.772431851927301, 8.81857622379834, 7.94101712356359, 7.089974069847617, 7.880823155816202, 8.828351029028173, 9.769084890610639, 10.7434685815154, 11.707305440791625, 12.712761015286171, 13.628596191793651, 14.56163168036045, 14.70967299656374, 12.622137550438595, 13.640212581358272, 13.752400692756012, 12.749882971817579, 11.744541476651522, 10.785385063139438, 9.817578333029793, 8.802645066653238, 7.880407768816525, 6.973747391942449, 6.1481859775547765, 6.869400316636091, 7.8633072369751496, 8.847904773213639, 9.72306442280236, 10.666222469077248, 11.671358562441897, 12.592581752947417, 13.560502056807687, 13.899848003340319, 11.74429897201302, 12.684255831621824, 12.735576134569156, 11.741595364618755, 10.778602000863412, 9.822702996793211, 8.840789677200469, 7.793520235071789, 6.838129206783914, 5.987573923455687, 5.1521097472127435, 5.924011702581551, 6.918345122991348, 7.813175543735106, 8.744484063919561, 9.752729563727762, 10.596780390429052, 11.539606730803907, 12.519214432373715, 12.930134713614272, 10.81367034003266, 11.886792206346714, 11.710124039775879, 10.743323121017545, 9.745375837827828, 8.818342293497203, 7.778869842368459, 6.836707282204896, 5.885185396026288, 4.992937634592131, 4.085961647958517, 4.9427036963930515, 5.933081758147278, 6.786936014581995, 7.7718853956495355, 8.682647187806715, 9.630067107125583, 10.614352697680859, 11.56959852272648, 11.941481794829258, 10.022594933822546, 11.07890050086174, 10.742061242897423, 9.775210315671455, 8.8195521794119, 7.863969425763117, 6.798869718776032, 5.863345813940602, 4.883077146372917, 4.001542555568755, 3.066123361134391, 3.9165788320511297, 4.896151977693051, 5.8226527562154855, 6.7773934112250664, 7.70484329727865, 8.638857108692902, 9.604453374764956, 10.64964381722692, 11.482518627152245, 11.019868937796623, 10.812148054577438, 9.8115261529238, 8.817449959200315, 7.874580628528056, 6.893309619949688, 5.957020496140119, 4.925919047334033, 3.9366926059026746, 3.006854770681466, 2.0132684097214515, 2.9129077376939194, 3.92025061650057, 4.938375291433761, 5.939795629563053, 6.867422599072261, 7.877347712127423, 8.858109386282765, 9.91309603475282, 10.934980757959115, 11.055442678694535, 10.108695084708181, 9.087592521560094, 8.057515395099173, 7.031475557132363, 6.103110090802543, 5.028283793058699, 4.068999279299442, 3.0500008014778066, 2.0052766725710045, 1.025333883005351, 1.9477472499276658, 2.940268104684467, 4.003586882424824, 4.995958813934905, 5.945702563103684, 6.905137499555898, 7.970055589898902, 8.987725600941307, 9.989136092695642, 10.42586559590262, 9.357565445036759, 8.363837419464026, 7.344732804711224, 6.317990709619734, 5.2454784944563935, 4.22987911580151, 3.1792722774715285, 2.1081044263456876, 1.042551177061631, 0.0, 0.9935284544209166, 2.0249206645907734, 3.032913422798445, 3.9954600038333896, 4.950084770468742, 5.951594464753645, 6.985958851706224, 8.005255747824066, 9.022821555311818, 11.010497515577969, 9.944461448837348, 8.898715788809943, 7.964604024387564, 6.90896218545694, 5.945619507397251, 4.975485319928821, 3.980686166145007, 2.9652723163808803, 1.9494941620484987, 1.0166922843882602, 2.0180145123027806, 2.9501387879333265, 3.9043482192599863, 4.95034933231124, 5.905778934505501, 6.953267811099781, 7.929374941222889, 8.863793196055983, 9.861639529945428, 11.928424949591287, 10.956860932676161, 9.883874423510637, 8.897202633159553, 7.9196923778218045, 6.902944666850087, 5.910812319850634, 4.842491351700967, 3.8932562476857915, 2.9524842407475473, 1.9845863066702893, 2.9124312560879293, 3.8974529164864893, 4.837588194855841, 5.791775362198314, 6.830860991693652, 7.823880035521698, 8.874421285465946, 9.867090591697965, 10.816123579093617, 12.907981331677734, 11.930401088852166, 10.889764316296475, 9.816317071833101, 8.849405342971153, 7.8111730415423635, 6.853794465463685, 5.868334849396252, 4.920773102981328, 3.882444221640685, 2.9138618356719967, 3.884099999102896, 4.8430454718961276, 5.800090746234704, 6.73588793381878, 7.693585594425416, 8.733203477473138, 9.793587911944428, 10.743035934234232, 11.675832639057411, 13.739893512512074, 12.793800112173313, 11.731786071960915, 10.760545239696885, 9.733051642045295, 8.76320577389485, 7.782432772592737, 6.833423370841198, 5.896483135332358, 4.9065535087398695, 3.9757218720989744, 4.864475131961959, 5.89332118130207, 6.845018961090786, 7.702360914222127, 8.626633826421031, 9.633739245378186, 10.672196427192057, 11.705468066857158, 12.663951177878635, 14.597481128629047, 13.633049153716831, 12.66509303436111, 11.733555308687125, 10.77048246080134, 9.80016648263304, 8.796917598580446, 7.830359489687236, 6.888795161700089, 5.957372276995226, 4.922265453812421, 5.831990684518592, 6.806335415960891, 7.845978997179499, 8.714956805432887, 9.585488358923367, 10.596986268572318, 11.588311516212205, 12.593677159150591, 13.621155697932585, 15.670053137643162, 14.650552246710259, 13.594894507765874, 12.750721652519486, 11.812832744942614, 10.790446254943586, 9.728893734685501, 8.820109481255988, 7.803273179044652, 6.875121996565623, 5.8740797849409905, 6.801054888628379, 7.781163721955665, 8.745847536541504, 9.656164474134627, 10.601543552904403, 11.53093715122673, 12.460573461708035, 13.449618696035042, 14.384293124600907, 16.506303158727306, 15.483311999239646, 14.546158685995405, 13.656746199109843, 12.602069043692122, 11.599219226528076, 10.656266049253292, 9.717370742065594, 8.780329468816658, 7.844562885408688, 6.86291123120355, 7.806558582918517, 8.741826527860788, 9.72756339524111, 10.667021835324393, 11.534725134049877, 12.471602068327403, 13.435087609365107, 14.384112704655074, 15.337224492267753, 17.442344242820372, 16.430702507176978, 15.589124451884532, 14.645318048672333, 13.570509810270954, 12.536774959293911, 11.715495731600006, 10.681452325732597, 9.707908443419903, 8.7650922982793, 7.809229301955102, 8.85857084975875, 9.67052949915493, 10.726435474145608, 11.65013373511206, 12.508716764000576, 13.507920389936082, 14.471453738165106, 15.35595073940269, 16.288910139804603], [16.32133619536078, 15.45381252169283, 14.525588188090516, 13.507257750958331, 12.567740369360497, 11.608436738957662, 10.627361441240309, 9.661359949568403, 8.872076144427004, 9.760301966208713, 10.62392511022423, 10.755332811803767, 11.760966255221712, 12.668959979735192, 13.601781348112748, 14.55571012344859, 15.590937743943604, 16.46727286866711, 17.468390324777666, 18.38195615973742, 15.318872868213495, 16.248929311399955, 15.415273604768876, 14.474927794506801, 13.496894582867096, 12.548636065211591, 11.58213781612737, 10.730563147859051, 9.81184009377357, 10.687139042797611, 10.813088806127881, 9.820449343377215, 10.76864369132353, 11.734924772513992, 12.61222728713314, 13.590953500049975, 14.630889968221213, 15.4868204449612, 16.440770618532003, 17.363306819005913, 14.488248157721376, 15.488842788916727, 16.440331158337962, 15.43993974835998, 14.442547808429294, 13.514457638914095, 12.544429823750418, 11.677132662324432, 10.83401747932927, 10.736846495245844, 9.800767469652497, 8.8740694513464, 9.763987964860611, 10.696497324632896, 11.637797669345264, 12.64701458270688, 13.71047148297274, 14.542762668274879, 15.482275125457045, 16.40403903359883, 13.691893127186153, 14.654347881833662, 15.61751373563741, 15.475162978434723, 14.5460117737151, 13.634866358614692, 12.678476411251221, 11.66183478999565, 10.678026819312755, 9.691898517975826, 8.734517446594449, 7.8228416612436, 8.778421781941848, 9.754161286872298, 10.726664715034634, 11.697325720894947, 12.714716925531913, 13.56681130250791, 14.587008970157582, 15.433295252378876, 12.70342385106495, 13.661901867185254, 14.639740946271061, 14.49107351573724, 13.560378382037893, 12.633195819711615, 11.703517930138096, 10.696656098657378, 9.742800470528417, 8.791211676208055, 7.761855033439835, 6.887294701395286, 7.834822574607256, 8.775556436189722, 9.749940127094483, 10.713776986370709, 11.719232560865255, 12.635067737372733, 13.568103225939534, 14.482021832836306, 11.641314119416624, 12.654723590867466, 13.67924012643582, 13.674107218547656, 12.668765723381599, 11.709609309869514, 10.741802579759868, 9.726869313383315, 8.804632015546602, 7.823941944586914, 6.820066941146994, 5.875871862215175, 6.869778782554233, 7.854376318792722, 8.729535968381443, 9.672694014656331, 10.67783010802098, 11.5990532985265, 12.56697360238677, 13.424465096203377, 10.750770517592104, 11.690727377200908, 12.661921391919602, 12.665819611348832, 11.702826247593489, 10.746927243523286, 9.765013923930544, 8.717744481801866, 7.762353453513992, 6.911798170185765, 5.896880130241569, 4.930483248160635, 5.924816668570432, 6.81964708931419, 7.750955609498644, 8.759201109306845, 9.603251936008135, 10.54607827638299, 11.525685977952799, 12.454751806477331, 9.820141885611744, 10.893263751925797, 11.856596460229428, 11.667547367747622, 10.669600084557905, 9.742566540227278, 8.703094089098535, 7.760931528934974, 6.809409642756366, 5.917161881322209, 4.925371998189754, 3.949175241972135, 4.9395533037263615, 5.793407560161079, 6.778356941228619, 7.689118733385799, 8.636538652704667, 9.620824243259943, 10.576070068305564, 11.585616034370858, 9.029066479401632, 10.085372046440826, 11.065386771127073, 10.699434562401532, 9.743776426141977, 8.788193672493195, 7.723093965506109, 6.78757006067068, 5.807301393102994, 4.925766802298833, 3.9182244241015107, 2.9230503776302132, 3.9026235232721342, 4.829124301794569, 5.78386495680415, 6.711314842857734, 7.645328654271986, 8.61092492034404, 9.656115362806004, 10.69682181986984, 10.026340483375705, 11.082416473239457, 10.73575039965388, 9.741674205930394, 8.798804875258135, 7.817533866679766, 6.881244742870197, 5.850143294064111, 4.860916852632752, 3.9310790174115438, 2.8653694726885712, 1.9193792832730028, 2.9267221620796535, 3.944846837012845, 4.946267175142137, 5.873894144651344, 6.883819257706507, 7.864580931861848, 8.919567580331904, 9.941452303538197, 10.895737301865346, 11.088033931767127, 10.06693136861904, 9.03685424215812, 8.01081440419131, 7.082448937861491, 6.007622640117646, 5.048338126358389, 4.029339648536753, 2.9846155196299513, 2.0046727300642977, 0.9542187955067492, 1.9467396502635501, 3.0100584280039078, 4.002430359513989, 4.952174108682768, 5.9116090451349805, 6.976527135477984, 7.994197146520389, 8.995607638274723, 11.419394050323536, 10.351093899457675, 9.357365873884943, 8.33826125913214, 7.31151916404065, 6.23900694887731, 5.2234075702224265, 4.172800731892445, 3.101632880766604, 2.0360796314825476, 0.9935284544209166, 0.0, 1.031392210169857, 2.0393849683775285, 3.001931549412473, 3.9565563160478248, 4.958066010332728, 5.9924303972853075, 7.011727293403149, 8.029293100890904, 12.004025969998883, 10.937989903258263, 9.89224424323086, 8.958132478808482, 7.902490639877858, 6.939147961818168, 5.9690137743497385, 4.974214620565924, 3.9588007708017967, 2.943022616469415, 2.010220738809177, 1.0244860578818638, 1.9566103335124099, 2.9108197648390695, 3.9568208778903236, 4.912250480084585, 5.959739356678865, 6.935846486801973, 7.870264741635068, 8.868111075524512, 12.921953404012205, 11.95038938709708, 10.877402877931553, 9.890731087580471, 8.913220832242722, 7.896473121271004, 6.9043407742715495, 5.836019806121882, 4.8867847021067075, 3.9460126951684638, 2.903764677107297, 1.9759197276896572, 2.903924462065573, 3.844059740434924, 4.798246907777398, 5.837332537272736, 6.830351581100782, 7.8808928310450295, 8.87356213727705, 9.8225951246727, 13.901509786098652, 12.923929543273085, 11.883292770717393, 10.809845526254017, 9.84293379739207, 8.804701495963279, 7.847322919884601, 6.861863303817168, 5.914301557402244, 4.875972676061601, 3.8330402061090045, 2.947588470704624, 3.874428840955712, 4.831474115294289, 5.767271302878364, 6.724968963485001, 7.761572892093098, 8.812764480922457, 9.762212503212261, 10.69500920803544, 14.733421966932992, 13.787328566594232, 12.725314526381833, 11.754073694117803, 10.726580096466213, 9.756734228315768, 8.775961227013655, 7.826951825262115, 6.890011589753274, 5.900081963160786, 4.889827575464926, 3.927963603563687, 4.924704550361654, 5.876402330150371, 6.733744283281712, 7.658017195480616, 8.66512261443777, 9.703579796251642, 10.724644635835187, 11.683127746856664, 15.591009583049965, 14.62657760813775, 13.658621488782028, 12.727083763108043, 11.764010915222258, 10.793694937053958, 9.790446053001364, 8.823887944108153, 7.878585046744224, 6.9014149977852135, 5.836371157178372, 4.89547915612032, 5.869823887562619, 6.896213166435078, 7.746340174492471, 8.616871727982952, 9.628369637631902, 10.61969488527179, 11.625060528210176, 12.65253906699217, 16.66358159206408, 15.644080701131177, 14.588422962186792, 13.744250106940404, 12.806361199363533, 11.783974709364504, 10.72242218910642, 9.788551724998984, 8.717378882410603, 7.789227699931574, 6.788185488306942, 5.8645433602301065, 6.844652193557393, 7.809336008143233, 8.68754784319421, 9.632926921963985, 10.562320520286313, 11.491956830767618, 12.481002065094625, 13.41567649366049, 17.499831613148224, 16.476840453660564, 15.539687140416323, 14.570851902475795, 13.516174747058074, 12.513324929894027, 11.570371752619243, 10.631476445431545, 9.69443517218261, 8.75866858877464, 7.7770169345695015, 6.870047054520245, 7.8053149994625155, 8.791051866842837, 9.698405204383976, 10.56610850310946, 11.502985437386986, 12.46647097842469, 13.415496073714657, 14.368607861327336, 18.43587269724129, 17.424230961597896, 16.575553261927794, 15.559423752038285, 14.484615513636905, 13.450880662659863, 12.629601434965958, 11.595558029098548, 10.622014146785855, 9.679198001645249, 8.723335005321053, 7.939754410736944, 8.734017970756657, 9.789923945747336, 10.681517104171643, 11.54010013306016, 12.539303758995665, 13.502837107224689, 14.387334108462273, 15.320293508864186], [15.289943985190922, 14.422420311522975, 13.494195977920661, 12.475865540788476, 11.536348159190641, 10.595203554881769, 9.748090752885659, 8.782089261213754, 9.726469777301466, 10.614695599083177, 11.478318743098693, 11.786725021973625, 10.988589062632732, 11.853578387012673, 12.78639975539023, 13.740328530726071, 14.733728890443103, 15.544372902979884, 16.54549035909044, 17.45905619405019, 14.28748065804364, 15.2175371012301, 14.38388139459902, 13.443535584336946, 12.465502372697241, 11.535402881135697, 10.70286712777272, 9.8512924595044, 10.666233726648032, 11.541532675672077, 11.84448101629774, 10.851841553547073, 9.99626649873455, 10.919543179791473, 11.79684569441062, 12.775571907327457, 13.773681114720713, 14.563920479273975, 15.517870652844778, 16.440406853318684, 13.45685594755152, 14.457450578746872, 15.408938948168108, 14.408547538190124, 13.41115559825944, 12.501224454838201, 11.665159135395768, 10.79786197396978, 11.688411112203733, 11.768238705415703, 10.832159679822354, 9.90546166151626, 8.958437253650063, 9.881115731910377, 10.822416076622746, 11.790552947583633, 12.802631567956887, 13.619862702587653, 14.55937515976982, 15.481139067911606, 12.660500917016298, 13.622955671663805, 14.586121525467552, 15.358930602570872, 14.429779397851249, 13.478867057870449, 12.605094180589917, 11.799642603695583, 11.709419029482614, 10.723290728145685, 9.765909656764306, 8.854233871413458, 7.9728710707312995, 8.93877969414978, 9.876414358398256, 10.840864085771699, 11.791816959844686, 12.643911336820684, 13.664109004470356, 14.510395286691649, 11.672031640895094, 12.630509657015397, 13.608348736101204, 14.599847414206176, 14.591770592207752, 13.664588029881472, 12.734910140307953, 11.728048308827235, 10.774192680698274, 9.822603886377912, 8.793247243609692, 7.918686911565143, 7.0292718633967075, 7.954205612430954, 8.827040161407254, 9.79087702068348, 10.796332595178027, 11.712167771685507, 12.645203260252307, 13.559121867149079, 10.609921909246767, 11.623331380697609, 12.647847916265963, 13.650365637204397, 13.700157933551454, 12.74100152003937, 11.773194789929725, 10.758261523553172, 9.836024225716459, 8.85533415475677, 7.851459151316851, 6.907264072385032, 6.064228071343685, 6.952992060044722, 7.806636002694215, 8.749794048969104, 9.754930142333754, 10.676153332839274, 11.644073636699543, 12.50156513051615, 9.719378307422247, 10.65933516703105, 11.630529181749745, 12.649070810824961, 12.734218457763344, 11.778319453693143, 10.796406134100401, 9.749136691971723, 8.793745663683849, 7.943190380355622, 6.928272340411426, 5.961875458330492, 5.119265957359883, 5.896747123626962, 6.828055643811417, 7.836301143619618, 8.680351970320908, 9.623178310695764, 10.602786012265572, 11.531851840790104, 8.788749675441887, 9.86187154175594, 10.82520425005957, 11.877209367848092, 11.70099229472776, 10.773958750397135, 9.734486299268392, 8.79232373910483, 7.840801852926223, 6.948554091492066, 5.956764208359611, 4.980567452141992, 4.134002592515813, 4.870507594473851, 5.855456975541392, 6.766218767698572, 7.71363868701744, 8.697924277572715, 9.653170102618336, 10.662716068683633, 7.997674269231775, 9.053979836270969, 10.033994560957217, 11.000845488183185, 10.775168636311832, 9.819585882663052, 8.754486175675966, 7.818962270840537, 6.838693603272851, 5.95715901246869, 4.949616634271368, 3.9544425878000697, 3.097072812061586, 3.906224336107342, 4.860964991116923, 5.788414877170506, 6.722428688584759, 7.688024954656813, 8.733215397118776, 9.773921854182612, 8.994948273205848, 10.0510242630696, 10.981457052748102, 10.77306641610025, 9.83019708542799, 8.848926076849622, 7.912636953040054, 6.881535504233968, 5.892309062802609, 4.962471227581401, 3.896761682858428, 2.9507714934428595, 2.0541281199849326, 2.913454626842988, 3.91487496497228, 4.842501934481487, 5.85242704753665, 6.833188721691991, 7.888175370162046, 8.910060093368342, 9.86434509169549, 10.811092685681844, 11.098323578788897, 10.068246452327976, 9.042206614361167, 8.113841148031348, 7.0390148502875025, 6.079730336528246, 5.06073185870661, 4.016007729799808, 3.0360649402341546, 1.985611005676606, 1.0079986857857837, 1.9786662178340508, 2.9710381493441322, 3.9207818985129115, 4.880216834965124, 5.945134925308127, 6.962804936350532, 7.964215428104867, 10.795842701973285, 11.382486109627532, 10.3887580840548, 9.369653469301998, 8.342911374210507, 7.270399159047166, 6.254799780392283, 5.204192942062301, 4.13302509093646, 3.067471841652404, 2.0249206645907734, 1.031392210169857, 0.0, 1.0079927582076718, 1.9705393392426163, 2.925164105877968, 3.926673800162871, 4.9610381871154505, 5.980335083233292, 6.997900890721046, 11.593700347934922, 11.856646257821698, 10.810900597794292, 9.876788833371915, 8.82114699444129, 7.857804316381602, 6.887670128913172, 5.892870975129357, 4.87745712536523, 3.8616789710328483, 2.92887709337261, 1.8891773911414962, 0.9252181233425529, 1.8794275546692125, 2.9254286677204666, 3.880858269914728, 4.928347146509008, 5.904454276632116, 6.838872531465211, 7.836718865354655, 12.538083138367577, 12.86904574166051, 11.796059232494986, 10.809387442143905, 9.831877186806155, 8.815129475834437, 7.77718593076054, 6.708864962610873, 5.759629858595698, 4.818857851657454, 3.7684560103669296, 2.8406110609492896, 1.872532251895716, 2.812667530265067, 3.7668546976075405, 4.805940327102879, 5.798959370930925, 6.8495006208751725, 7.842169927107192, 8.791202914502843, 13.507445860332854, 13.796774699762073, 12.756137927206382, 11.682690682743008, 10.71577895388106, 9.67754665245227, 8.720168076373591, 7.734708460306159, 6.787146713891235, 5.748817832550592, 4.697731539368637, 3.8019821035790864, 2.8430366307858552, 3.8000819051244323, 4.735879092708508, 5.693576753315146, 6.730180681923241, 7.781372270752599, 8.730820293042404, 9.663616997865583, 14.48771225420997, 14.660173723083222, 13.598159682870824, 12.626918850606794, 11.599425252955204, 10.629579384804758, 9.648806383502645, 8.699796981751106, 7.762856746242265, 6.7729271196497765, 5.74422120833939, 4.78235723643815, 3.8933123401917973, 4.845010119980515, 5.7023520731118555, 6.626624985310761, 7.633730404267916, 8.672187586081787, 9.69325242566533, 10.651735536686807, 15.428512796512875, 15.49942276462674, 14.531466645271019, 13.599928919597033, 12.636856071711248, 11.666540093542949, 10.663291209490355, 9.696733100597143, 8.732978679618688, 7.755808630659677, 6.690764790052836, 5.749872788994782, 4.903937084386612, 5.864820956265222, 6.714947964322615, 7.585479517813097, 8.596977427462047, 9.588302675101934, 10.59366831804032, 11.621146856822314, 16.474901773561584, 16.51692585762017, 15.461268118675783, 14.617095263429395, 13.679206355852523, 12.656819865853494, 11.59526734559541, 10.642945357873447, 9.571772515285067, 8.643621332806038, 7.642579121181406, 6.718936993104569, 5.965381505202743, 6.819441161300739, 7.656155633024355, 8.60153471179413, 9.530928310116458, 10.460564620597763, 11.44960985492477, 12.384284283490635, 17.45217646973919, 17.349685610149553, 16.41253229690531, 15.42524553535026, 14.370568379932537, 13.367718562768491, 12.424765385493707, 11.485870078306009, 10.548828805057074, 9.613062221649104, 8.631410567443965, 7.724440687394707, 6.926044311107865, 7.845456451449778, 8.66701299421412, 9.534716292939605, 10.47159322721713, 11.435078768254835, 12.384103863544802, 13.33721565115748, 18.388217553832256, 17.54167042708591, 16.535418289144612, 15.740757153869623, 14.681055887859793, 13.803507628091394, 12.801435065000566, 11.921856452126248, 11.476407779660319, 10.533591634519713, 9.577728638195516, 8.794148043611406, 7.854747282402007, 8.844328530354279, 9.650124894001788, 10.508707922890304, 11.50791154882581, 12.471444897054834, 13.355941898292418, 14.28890129869433], [14.415489457626803, 13.547965783958857, 12.619741450356543, 11.601411013224357, 10.661893631626523, 9.72074902731765, 8.975458792453614, 9.773142428769543, 10.734462535509138, 11.622688357290848, 12.486311501306364, 12.530543584555481, 11.655305941158213, 10.845585628805003, 11.77840699718256, 12.7323357725184, 13.725736132235431, 14.536380144772213, 15.53749760088277, 16.45106343584252, 13.41302613047952, 14.343082573665981, 13.509426867034902, 12.569081056772827, 11.591047845133122, 10.660948353571579, 9.930235167340674, 10.84234562706019, 11.674226484855705, 12.549525433879747, 12.588299578879596, 11.59566011612893, 10.662983377260032, 9.911550421583803, 10.78885293620295, 11.767579149119786, 12.76568835651304, 13.555927721066304, 14.509877894637107, 15.432414095111014, 12.582401419987402, 13.572717264350318, 14.515340131193094, 13.534093010626005, 12.53670107069532, 11.626769927274083, 10.892527174963723, 11.788915141525571, 12.696403870411405, 12.586545448599852, 11.650466423006502, 10.649280224098115, 9.625154132175544, 8.873122973702706, 9.814423318415075, 10.782560189375962, 11.794638809749214, 12.611869944379983, 13.55138240156215, 14.473146309703933, 11.709330483775583, 12.614962913456132, 13.57812876725988, 14.484476075006754, 13.55532487028713, 12.60441253030633, 11.832462220157872, 12.790695771251373, 12.527725772666763, 11.541597471329833, 10.584216399948454, 9.598052433995313, 8.63958794925678, 7.930786935942108, 8.868421600190585, 9.832871327564028, 10.783824201637014, 11.635918578613014, 12.656116246262686, 13.502402528483977, 10.664038882687422, 11.622516898807724, 12.600355977893532, 13.591854655998503, 14.52254978969785, 13.607236827978637, 12.807420701270997, 12.56823580021677, 11.61438017208781, 10.640910629562061, 9.61155398679384, 8.662505474146998, 7.695988741922188, 6.946212854223282, 7.819047403199583, 8.78288426247581, 9.788339836970355, 10.704175013477837, 11.637210502044635, 12.551129108941407, 9.601929151039094, 10.615338622489936, 11.63985515805829, 12.642372878996724, 13.570010892160742, 13.748994278247041, 12.781187548137396, 11.766254281760842, 10.743096083022982, 9.673640897940919, 8.669765894501, 7.7255708155691805, 6.730944949869166, 5.944999301837051, 6.798643244486543, 7.7418012907614315, 8.746937384126081, 9.668160574631603, 10.636080878491871, 11.493572372308478, 8.711385549214574, 9.651342408823378, 10.622536423542073, 11.641078052617289, 12.604071416372632, 12.786312211900814, 11.804398892308072, 10.757129450179393, 9.797988666568799, 8.779457404209136, 7.746579083595575, 6.7801822015146405, 5.785982835885364, 4.888754365419291, 5.820062885603745, 6.828308385411946, 7.6723592121132365, 8.615185552488093, 9.5947932540579, 10.523859082582431, 7.780756917234214, 8.853878783548268, 9.817211491851898, 10.86921660964042, 11.867163892830137, 11.781951508604806, 10.742479057476062, 9.800316497312501, 8.845044855811173, 7.78482111534558, 6.77507095154376, 5.798874195326141, 4.800719471041294, 3.86251483626618, 4.84746421733372, 5.758226009490899, 6.705645928809767, 7.689931519365043, 8.645177344410664, 9.654723310475958, 6.989681511024102, 8.045987078063296, 9.026001802749544, 9.992852729975512, 10.948510866235067, 10.827578640870723, 9.762478933883637, 8.826955029048207, 7.846686361480523, 6.861180322135703, 5.843266505301578, 4.804305502064026, 3.824732356422105, 2.8982315778996703, 3.8529722329092513, 4.780422118962834, 5.714435930377086, 6.68003219644914, 7.725222638911103, 8.76592909597494, 7.986955514998176, 9.043031504861927, 9.97346429454043, 10.967540488263914, 10.838189843635663, 9.856918835057295, 8.920629711247726, 7.889528262441639, 6.900301821010281, 5.970463985789072, 4.9047544410661, 3.9587642516505315, 2.9754595818367218, 1.9054618686353164, 2.9068822067646085, 3.8345091762738157, 4.844434289328978, 5.825195963484321, 6.880182611954374, 7.902067335160669, 8.856352333487816, 9.80309992747417, 10.824202490622257, 11.076239210535649, 10.050199372568839, 9.12183390623902, 8.047007608495175, 7.087723094735918, 6.068724616914283, 5.024000488007481, 4.044057698441827, 2.993603763884278, 2.0159914439934554, 0.9706734596263792, 1.9630453911364607, 2.91278914030524, 3.8722240767574516, 4.937142167100455, 5.95481217814286, 6.956222669897195, 9.787849943765611, 10.812952481043865, 11.396750842262472, 10.37764622750967, 9.35090413241818, 8.278391917254838, 7.262792538599955, 6.212185700269973, 5.1410178491441325, 4.075464599860076, 3.032913422798445, 2.0393849683775285, 1.0079927582076718, 0.0, 0.9625465810349446, 1.9171713476702963, 2.9186810419551996, 3.9530454289077785, 4.97234232502562, 5.989908132513373, 10.585707589727248, 11.651743656467868, 11.818893356001963, 10.884781591579586, 9.829139752648961, 8.865797074589272, 7.895662887120842, 6.900863733337028, 5.885449883572901, 4.86967172924052, 3.9368698515802816, 2.8971701493491677, 1.9332108815502247, 0.9884849869823588, 1.9259339844540495, 2.8728655117070563, 3.920354388301336, 4.896461518424443, 5.830879773257538, 6.8287261071469825, 11.530090380159905, 12.501654397075031, 12.804051990702657, 11.817380200351575, 10.839869945013826, 9.823122234042108, 8.785178688968212, 7.716857720818545, 6.7676226168033695, 5.826850609865126, 4.776448768574601, 3.848603819156961, 2.8805250101033875, 1.9217249625782133, 2.8759121299206867, 3.797947568895207, 4.7909666127232535, 5.8415078626675, 6.83417716889952, 7.783210156295172, 12.499453102125184, 13.489267135875362, 13.764130685414056, 12.69068344095068, 11.723771712088732, 10.685539410659942, 9.728160834581264, 8.742701218513831, 7.7951394720989065, 6.756810590758263, 5.7057242975763085, 4.809974861786758, 3.8510293889935268, 2.972391601996386, 3.8614245651443895, 4.819122225751027, 5.72218792371557, 6.773379512544927, 7.722827534834732, 8.65562423965791, 13.4797194960023, 14.42581289634106, 14.606152441078496, 13.634911608814466, 12.607418011162876, 11.63757214301243, 10.656799141710318, 9.707789739958779, 8.770849504449936, 7.780919877857448, 6.75221396654706, 5.790349994645822, 4.901305098399469, 4.017319816852468, 4.827897545547737, 5.752170457746642, 6.736475903129214, 7.774933084943084, 8.685259667457657, 9.643742778479135, 14.420520038305204, 15.38495201321742, 15.539459403478691, 14.607921677804706, 13.64484882991892, 12.674532851750621, 11.671283967698027, 10.704725858804817, 9.740971437826358, 8.763801388867348, 7.698757548260507, 6.757865547202455, 5.911929842594283, 5.037130653137175, 5.840493436758496, 6.711024990248978, 7.722522899897928, 8.713848147537815, 9.719213790476202, 10.682136123374367, 15.46690901535391, 16.436171200850858, 16.469260876883457, 15.625088021637067, 14.687199114060196, 13.664812624061167, 12.603260103803082, 11.650938116081118, 10.579765273492738, 9.651614091013709, 8.650571879389076, 7.726929751312241, 6.956434672758532, 5.991750858172693, 6.781701105460236, 7.727080184230012, 8.65647378255234, 9.586110093033644, 10.575155327360651, 11.509829755926516, 16.444183711531515, 17.44695028971642, 16.57039129682607, 15.745259107300122, 14.690581951882399, 13.733070602649558, 12.85267198913961, 12.49386283651368, 11.556821563264744, 10.621054979856774, 9.639403325651635, 8.732433445602378, 7.9170974786636545, 7.017766148321732, 7.792558466650002, 8.660261765375486, 9.597138699653012, 10.560624240690716, 11.509649335980683, 12.462761123593362, 17.38022479562458, 16.53367766887824, 15.527425530936942, 14.73276439566195, 13.673063129652123, 12.795514869883723, 11.793442306792896, 12.588573330651728, 12.48440053786799, 11.541584392727383, 10.585721396403187, 9.802140801819078, 8.845800449957796, 8.016638227226231, 8.77567036643767, 9.634253395326185, 10.633457021261691, 11.596990369490715, 12.4814873707283, 13.414446771130212], [13.458545004153923, 12.591021330485976, 11.662796996883662, 10.644466559751475, 9.70494917815364, 8.76380457384477, 9.731166088412373, 10.598266647226804, 11.617496137475406, 12.556210890127119, 13.432604685906998, 13.493090165590427, 12.617852522193159, 11.808132209839945, 11.148876100097146, 12.040471433656545, 12.948763809838788, 13.759407822375568, 14.760525278486124, 15.67225137386518, 12.45608167700664, 13.3861381201931, 12.55248241356202, 11.612136603299945, 10.63410339166024, 9.704003900098698, 10.685942463299433, 11.667469845517452, 12.557260086821973, 13.483047966716018, 13.550846159914542, 12.558206697163875, 11.625529958294978, 10.874097002618745, 10.14061994006582, 11.075714810257931, 11.988716034116397, 12.778955398669659, 13.732905572240462, 14.653602033133673, 11.625456966514522, 12.610170683315374, 13.55279355015815, 12.577148557153123, 11.579756617222438, 10.669825473801202, 11.648234470922482, 12.614039359982833, 13.572857596542724, 13.549092029634794, 12.613013004041447, 11.611826805133061, 10.58770071321049, 9.835669554737649, 9.166190322277945, 10.045288039689169, 11.017666487352571, 11.834897621983338, 12.774410079165504, 13.694334247726593, 10.746783902740638, 11.652416332421188, 12.615582186224936, 13.527531621533871, 12.598380416814248, 11.64746807683345, 12.588169516116631, 13.615819989708635, 13.490272353701705, 12.504144052364776, 11.546762980983399, 10.56059901503026, 9.602134530291726, 8.893333516977052, 8.131149450503791, 9.095599177877235, 10.00685187924037, 10.858946256216369, 11.87914392386604, 12.723590466506636, 9.701492301652477, 10.65997031777278, 11.637809396858588, 12.629308074963559, 13.560003208662906, 12.650292374505756, 13.563127997229756, 13.530782381251715, 12.576926753122754, 11.603457210597005, 10.574100567828784, 9.625052055181945, 8.658535322957134, 7.908759435258227, 7.08177525351279, 8.045612112789016, 9.011367514573712, 9.927202691081192, 10.858398440067294, 11.772317046964066, 8.63938257000415, 9.652792041454992, 10.677308577023346, 11.67982629796178, 12.607464311125797, 13.644856239542417, 13.743734129172342, 12.728800862795788, 11.705642664057926, 10.636187478975863, 9.632312475535944, 8.688117396604126, 7.69349153090411, 6.907545882871995, 6.06137109479975, 7.004529141074638, 7.969965061729438, 8.891188252234958, 9.85726881651453, 10.714760310331137, 7.748838968179629, 8.688795827788434, 9.659989842507128, 10.678531471582344, 11.641524835337687, 12.690210619069248, 12.766945473343018, 11.71967603121434, 10.760535247603743, 9.742003985244079, 8.70912566463052, 7.742728782549585, 6.7485294169203085, 5.851300946454235, 5.0827907359169515, 6.051336063015302, 6.895386889716593, 7.8382132300914495, 8.815981192080558, 9.74504702060509, 6.818210336199269, 7.891332202513323, 8.854664910816952, 9.906670028605474, 10.90461731179519, 11.84435357320599, 11.705025638511009, 10.762863078347447, 9.807591436846117, 8.747367696380524, 7.737617532578704, 6.761420776361085, 5.763266052076238, 4.825061417301124, 4.109222069949116, 4.981253687094256, 5.928673606413124, 6.911119457387701, 7.866365282433323, 8.875911248498618, 6.027134929989158, 7.083440497028352, 8.0634552217146, 9.030306148940568, 9.985964285200122, 10.968217893291847, 10.725025514918583, 9.789501610083153, 8.809232942515468, 7.823726903170647, 6.8058130863365225, 5.7668520830989705, 4.7872789374570495, 3.8607781589346146, 3.1147300855246467, 4.003449796566191, 4.904709050359452, 5.84427864401535, 6.870190564459965, 7.910897021523802, 7.024408933963231, 8.080484923826983, 9.010917713505485, 10.00499390722897, 10.930935836083965, 10.819465416092239, 9.88317629228267, 8.852074843476585, 7.862848402045226, 6.933010566824017, 5.867301022101045, 4.921310832685476, 3.9380061628716665, 2.868008449670261, 2.07746775679721, 3.0050947263064174, 3.9302190683172813, 4.910980742472623, 5.91763603091943, 6.9395207541257244, 7.893805752452873, 8.840553346439226, 9.861655909587313, 10.891733036048233, 11.012745953603785, 10.084380487273966, 9.009554189530121, 8.050269675770863, 7.031271197949227, 5.986547069042425, 5.006604279476771, 3.956150344919222, 2.9785380250284, 1.9332200406613238, 1.0407765877585329, 1.9756814687746949, 2.9096774957225073, 3.9745955860655107, 4.992265597107916, 5.993676088862251, 8.825303362730669, 9.850405900008921, 10.844133925581653, 11.340192808544614, 10.313450713453124, 9.240938498289783, 8.2253391196349, 7.174732281304918, 6.103564430179077, 5.038011180895021, 3.99546000383339, 3.001931549412473, 1.9705393392426163, 0.9625465810349446, 0.0, 0.9546247666353516, 1.9561344609202551, 2.990498847872834, 4.009795743990676, 5.027361551478429, 9.806895527749907, 10.872931594490527, 11.812619565015837, 11.84732817261453, 10.791686333683906, 9.828343655624217, 8.858209468155787, 7.863410314371972, 6.847996464607846, 5.832218310275464, 4.899416432615226, 3.859716730384112, 2.895757462585169, 1.9510315680173034, 0.963387403419105, 1.9103189306721116, 2.9578078072663914, 3.9339149373894986, 4.868333192222593, 5.866179526112037, 10.751278318182564, 11.72284233509769, 12.795828844263216, 12.77992678138652, 11.80241652604877, 10.785668815077052, 9.747725270003157, 8.67940430185349, 7.730169197838314, 6.78939719090007, 5.738995349609546, 4.811150400191906, 3.8430715911383317, 2.87315484379028, 1.9189676764478065, 2.8354009878602624, 3.828420031688309, 4.878961281632556, 5.8716305878645745, 6.820663575260227, 11.720641040147843, 12.710455073898022, 13.751091846453713, 13.653230021985625, 12.686318293123676, 11.648085991694886, 10.690707415616208, 9.705247799548776, 8.75768605313385, 7.719357171793208, 6.668270878611253, 5.756268046387392, 4.797322573594161, 3.8402772992555843, 2.904480111671509, 3.862177772278146, 4.759641342680625, 5.8108329315099825, 6.760280953799787, 7.6930776586229666, 12.700907434024959, 13.64700083436372, 14.709014874576118, 14.59745818984941, 13.56996459219782, 12.600118724047375, 11.619345722745262, 10.670336320993723, 9.73339608548488, 8.743466458892392, 7.698507151147695, 6.736643179246456, 5.847598283000103, 4.885205514111666, 3.8709530920748563, 4.7952260042737604, 5.773929322094269, 6.81238650390814, 7.722713086422713, 8.68119619744419, 13.641707976327863, 14.60613995124008, 15.5740960705958, 15.57046825883965, 14.607395410953865, 13.637079432785566, 12.633830548732972, 11.66727243983976, 10.687264622426994, 9.710094573467984, 8.645050732861142, 7.704158731803089, 6.858223027194917, 5.8936187237901345, 4.883548983285616, 5.754080536776097, 6.765578446425048, 7.756903694064934, 8.762269337003321, 9.719589542339424, 14.688096953376569, 15.657359138873517, 16.503897544000566, 15.957374105173436, 14.999238702395788, 14.055584144209668, 13.565806684838027, 12.597231300681752, 11.526058458093372, 10.597907275614343, 9.59686506398971, 8.673222935912875, 7.781558891215794, 6.816875076629954, 5.8247566519873555, 6.770135730757131, 7.699529329079459, 8.629165639560764, 9.61821087388777, 10.552885302453635, 15.665371649554174, 16.668138227739078, 15.793418974429423, 15.016971553188343, 13.998717613020544, 13.103539705564145, 13.815218570174553, 13.440156021114314, 12.503114747865379, 11.567348164457409, 10.58569651025227, 9.678726630203013, 8.742221697120916, 7.8428903667789935, 6.835614013177121, 7.703317311902605, 8.640194246180132, 9.603679787217835, 10.552704882507802, 11.505816670120481, 16.60141273364724, 15.756705346481596, 14.750453208540296, 13.955792073265307, 12.981198790790268, 12.16598397279831, 12.755988887827838, 13.551119911686675, 13.430693722468623, 12.487877577328018, 11.532014581003821, 10.706408609041393, 9.670924668415058, 8.77234552318499, 7.818725912964789, 8.677308941853305, 9.67651256778881, 10.640045916017835, 11.524542917255419, 12.457502317657331], [12.564972498421497, 11.69744882475355, 10.769224491151236, 9.75089405401905, 8.811376672421215, 9.717814115925862, 10.685175630493465, 11.55282108290465, 12.572050573153252, 13.510765325804964, 14.387159121584844, 14.447714932225779, 13.57247728882851, 12.762756976475297, 12.05060990501105, 11.252096240707177, 11.995087760952126, 12.805731773488906, 13.806849229599463, 14.717626607229828, 11.562509171274215, 12.492565614460675, 11.658909907829594, 10.71856409756752, 9.740530885927814, 10.65801344217979, 11.639952005380525, 12.622024281195298, 13.511814522499819, 14.437602402393864, 14.505470926549894, 13.512831463799227, 12.58015472493033, 11.828721769254097, 11.042353744979724, 10.287339617308563, 11.035039985229735, 11.825279349782997, 12.7792295233538, 13.698977266498321, 10.731884460782098, 11.65554591668002, 12.598168783522796, 11.683576051420697, 10.686184111490013, 11.623835015882294, 12.602244013003574, 13.568593795660679, 14.52741203222057, 14.503716796270146, 13.567637770676797, 12.566451571768413, 11.542325479845841, 10.790294321373, 10.06792412719185, 9.2569128467398, 10.06399043846591, 10.881221573096676, 11.820734030278842, 12.739709481091241, 9.792159136105285, 10.697791565785835, 11.660957419589582, 12.633959115801446, 11.704807911081822, 12.601477618914542, 13.542179058197723, 14.57037442538648, 14.444897120337057, 13.458768819000127, 12.501387747618748, 11.515223781665611, 10.556759296927078, 9.847958283612403, 9.032883255417696, 8.307223984927866, 9.053175830353709, 9.905270207329707, 10.925467874979379, 11.768965699871284, 8.746867535017124, 9.705345551137427, 10.683184630223234, 11.674683308328207, 12.605378442027554, 13.532561004353834, 14.462238893927353, 14.485407147887065, 13.531551519758104, 12.558081977232355, 11.528725334464134, 10.579676821817296, 9.613160089592485, 8.863384201893577, 7.983509058426694, 7.257236919839646, 8.05769146568705, 8.97352664219453, 9.903773673431942, 10.817692280328714, 7.6847578033687975, 8.698167274819639, 9.722683810387995, 10.725201531326428, 11.652839544490446, 12.690231472907065, 13.65803820301671, 13.68342562943114, 12.660267430693276, 11.590812245611213, 10.586937242171294, 9.642742163239475, 8.648116297539461, 7.8621706495073465, 6.963104899713654, 6.207412444478886, 7.016289012842776, 7.937512203348297, 8.902644049879179, 9.760135543695785, 6.7942142015442775, 7.734171061153082, 8.705365075871777, 9.723906704946993, 10.686900068702336, 11.735585852433896, 12.717499172026638, 12.67430079784969, 11.715160014239096, 10.696628751879432, 9.66375043126587, 8.697353549184935, 7.70315418355566, 6.805925713089587, 5.984524540830856, 5.136900270834079, 5.9417108408299315, 6.884537181204788, 7.861356425445207, 8.790422253969739, 5.863585569563917, 6.936707435877971, 7.900040144181601, 8.952045261970122, 9.949992545159839, 10.889728806570638, 11.929201257699381, 11.717487844982799, 10.76221620348147, 9.701992463015877, 8.692242299214056, 7.7160455429964365, 6.71789081871159, 5.779686183936476, 5.01095587486302, 4.066817894913034, 4.974997557526462, 5.95649469075235, 6.911740515797971, 7.921286481863267, 5.072510163353806, 6.128815730393001, 7.108830455079248, 8.075681382305216, 9.03133951856477, 10.013593126656495, 11.078692833643581, 10.744126376718505, 9.76385770915082, 8.778351669805998, 7.760437852971874, 6.721476849734322, 5.741903704092401, 4.815402925569966, 4.016463890438551, 3.089014004384968, 3.9500842837241006, 4.889653877379998, 5.9155657978246134, 6.95627225488845, 6.06978416732788, 7.125860157191632, 8.056292946870133, 9.050369140593618, 9.976311069448613, 10.95758207802698, 10.837801058918021, 9.806699610111936, 8.817473168680579, 7.887635333459369, 6.821925788736396, 5.875935599320828, 4.892630929507018, 3.8226332163056127, 3.0074916203467996, 2.0906589341251944, 2.9755943016819297, 3.9563559758372717, 4.963011264284078, 5.984895987490373, 6.939180985817521, 7.885928579803874, 8.907031142951961, 9.937108269412882, 10.963148107379691, 11.039005253909318, 9.964178956165473, 9.004894442406215, 7.985895964584579, 6.9411718356777765, 5.961229046112123, 4.910775111554575, 3.9331627916637517, 2.8878448072966756, 1.9708004513081225, 1.0210567021393433, 1.9550527290871558, 3.019970819430159, 4.037640830472564, 5.039051322226899, 7.870678596095316, 8.89578113337357, 9.889509158946302, 10.908613773699104, 11.268075480088475, 10.195563264925134, 9.17996388627025, 8.12935704794027, 7.058189196814428, 5.992635947530372, 4.950084770468742, 3.956556316047825, 2.9251641058779683, 1.9171713476702963, 0.9546247666353516, 0.0, 1.0015096942849036, 2.0358740812374823, 3.055170977355324, 4.0727367848430776, 8.852270761114555, 9.918306827855176, 10.857994798380485, 11.792106562802863, 11.746311100319259, 10.78296842225957, 9.81283423479114, 8.818035081007325, 7.802621231243198, 6.786843076910817, 5.854041199250578, 4.8143414970194645, 3.8503822292205214, 2.905656334652655, 1.9179418390969505, 0.9556941640367599, 2.00318304063104, 2.979290170754147, 3.9137084255872416, 4.911554759476686, 9.796653551547212, 10.768217568462338, 11.841204077627864, 12.724705171574852, 12.757041292684123, 11.740293581712406, 10.70235003663851, 9.634029068488843, 8.684793964473668, 7.744021957535423, 6.693620116244898, 5.765775166827258, 4.797696357773685, 3.8277092794681256, 2.8735221121256522, 1.8807762212249108, 2.8737952650529572, 3.924336514997204, 4.917005821229223, 5.866038808624875, 10.766016273512491, 11.75583030726267, 12.796467079818362, 13.79619880679915, 13.64094305975903, 12.60271075833024, 11.645332182251561, 10.659872566184129, 9.712310819769204, 8.673981938428561, 7.622895645246606, 6.710822482065238, 5.751877009272007, 4.79483173493343, 3.8590345473493546, 2.93421976066428, 3.805016576045274, 4.856208164874631, 5.805656187164436, 6.738452891987615, 11.746282667389607, 12.692376067728368, 13.754390107940766, 14.725630940204796, 14.524589358833174, 13.554743490682728, 12.573970489380615, 11.624961087629076, 10.688020852120234, 9.698091225527746, 8.65306158682554, 7.6911976149243015, 6.802152718677949, 5.839759949789512, 4.825507527752702, 3.8672679926598947, 4.819304555458918, 5.857761737272789, 6.768088319787362, 7.726571430808839, 12.687083209692512, 13.651515184604728, 14.619471303960449, 15.574814221571204, 15.253213793587694, 14.591704199420919, 13.588455315368325, 12.621897206475115, 11.64181905810484, 10.66464900914583, 9.599605168538988, 8.658713167480935, 7.812777462872763, 6.84817315946798, 5.8381034189634615, 4.826122525162232, 5.837620434811182, 6.828945682451068, 7.831451545099497, 8.764964775704073, 13.733472186741217, 14.702734372238165, 15.549272777365212, 15.05828740417834, 14.210863509446419, 14.957317949123572, 14.52043145147338, 13.551785736359598, 12.480612893771218, 11.552461711292189, 10.551419499667556, 9.627777371590721, 8.736113326893639, 7.7714295123078, 6.779311087665201, 5.876563225024706, 6.805956823347033, 7.735593133828339, 8.724638368155347, 9.659312796721212, 14.710746882918823, 15.713513461103727, 14.839742925542762, 14.063295504301681, 13.210342420071175, 14.00527351047805, 14.769843336809904, 14.39471045679216, 13.457669183543224, 12.521902600135254, 11.540250945930115, 10.633281065880858, 9.696776132798762, 8.79744480245684, 7.790168448854967, 6.809744806170181, 7.746621740447706, 8.71010728148541, 9.659132376775377, 10.612244164388056, 15.646787967011889, 14.803029297594934, 13.796777159653635, 13.002116024378646, 12.1928235978409, 13.067717777712215, 13.71061365446319, 14.505744678322026, 14.385248158146469, 13.442432013005863, 12.486569016681667, 11.660963044719239, 10.625479104092904, 9.726355065266082, 8.772735455045881, 7.783736436120879, 8.782940062056385, 9.74647341028541, 10.630970411522993, 11.563929811924906], [11.687849271269197, 10.82032559760125, 9.892101263998937, 8.946169835308293, 9.79304064191357, 10.699478085418217, 11.66683959998582, 12.552921340954825, 13.572150831203427, 14.51086558385514, 15.388668815869748, 15.397090948572425, 14.521853305175156, 13.633625734459569, 12.844184301479531, 12.038223382514683, 10.993578066667222, 11.804222079204003, 12.805339535314559, 13.716116912944925, 10.685385944121915, 11.587067815866387, 10.854185689118838, 9.913839878856763, 10.72219485542017, 11.639677411672146, 12.621615974872881, 13.622124539245473, 14.511914780549994, 15.437702660444039, 15.45484694289654, 14.462207480145873, 13.529530741276975, 12.69959052723837, 11.835928141448205, 11.07346675911607, 10.033530290944832, 10.823769655498094, 11.777719829068896, 12.697467572213418, 9.802968550460943, 10.654036222395117, 11.596659089237892, 10.934294625825439, 11.667848080982369, 12.60549898537465, 13.58390798249593, 14.568694053710853, 15.527512290270744, 15.45309281261679, 14.517013787023442, 13.515827588115059, 12.491701496192487, 11.661163079357273, 10.86149852366033, 10.050487243208279, 9.062480744181006, 9.879711878811772, 10.819224335993939, 11.738199786806337, 8.790649441820381, 9.696281871500931, 10.659447725304679, 11.71184972974627, 12.589502139419858, 13.533875607741239, 14.435687680755576, 15.465321252779892, 15.394273136683701, 14.408144835346771, 13.450763763965394, 12.464599798012257, 11.506135313273724, 10.718827041596676, 9.826457651886177, 9.100798381396345, 8.051666136068805, 8.903760513044803, 9.923958180694475, 10.76745600558638, 7.74535784073222, 8.703835856852523, 9.68167493593833, 10.673173614043305, 11.603868747742652, 12.531051310068932, 13.46072919964245, 14.499568484461662, 14.48092753610475, 13.507457993579001, 12.47810135081078, 11.529052838163942, 10.562536105939131, 9.73425295987785, 8.777083454895175, 8.050811316308126, 7.056181771402146, 7.972016947909626, 8.902263979147039, 9.81618258604381, 6.683248109083894, 7.696657580534736, 8.721174116103093, 9.723691837041526, 10.651329850205544, 11.688721778622163, 12.656528508731808, 13.688919055093118, 13.609643447039922, 12.540188261957859, 11.53631325851794, 10.592118179586121, 9.597492313886107, 8.733039407491619, 7.756679296182135, 7.000986840947367, 6.014779318557872, 6.936002509063393, 7.901134355594275, 8.758625849410882, 5.792704507259375, 6.732661366868179, 7.703855381586874, 8.72239701066209, 9.685390374417434, 10.734076158148994, 11.715989477741736, 12.767270616296173, 12.664536030585742, 11.646004768226078, 10.613126447612515, 9.646729565531581, 8.652530199902307, 7.709407457483791, 6.778098937299337, 5.93047466730256, 4.940201146545028, 5.883027486919884, 6.859846731160303, 7.788912559684835, 4.8620758752790145, 5.935197741593068, 6.898530449896699, 7.95053556768522, 8.948482850874937, 9.888219112285736, 10.927691563414479, 11.955492845422027, 11.711592219828116, 10.651368479362523, 9.641618315560702, 8.665421559343082, 7.667266835058236, 6.729062200283122, 5.804530271331501, 4.8603922913815145, 3.973487863241559, 4.954984996467446, 5.910230821513068, 6.919776787578363, 4.071000469068903, 5.127306036108097, 6.1073207607943445, 7.0741716880203125, 8.029829824279867, 9.012083432371591, 10.077183139358677, 11.012707044194107, 10.751076114849905, 9.727727686152646, 8.709813869318522, 7.670852866080969, 6.691279720439048, 5.764778941916613, 4.810038286907032, 3.8825884008534493, 2.948574589439197, 3.8881441830950947, 4.914056103539711, 5.954762560603547, 5.068274473042977, 6.124350462906728, 7.05478325258523, 8.048859446308715, 8.974801375163711, 9.956072383742079, 10.892361507551648, 10.80820930439684, 9.818982862965482, 8.889145027744274, 7.8234354830213, 6.8774452936057315, 5.891221957809376, 4.82122424460797, 3.9116366899613957, 2.9840097204521885, 1.974084607397026, 2.954846281552368, 3.961501569999175, 4.98338629320547, 5.937671291532618, 6.884418885518971, 7.905521448667058, 8.93559857512798, 9.96163841309479, 10.890003879424608, 10.965688650450376, 10.006404136691119, 8.987405658869482, 7.94268152996268, 6.962738740397026, 5.9122848058394775, 4.934672485948655, 3.8864358355990327, 2.8940639040889513, 1.944320154920172, 0.9535430348022521, 2.0184611251452558, 3.036131136187661, 4.037541627941996, 6.869168901810413, 7.894271439088666, 8.887999464661398, 9.9071040794142, 10.93384617450569, 11.197072959210038, 10.181473580555155, 9.130866742225173, 8.059698891099332, 6.994145641815275, 5.9515944647536445, 4.958066010332728, 3.926673800162871, 2.9186810419551996, 1.9561344609202551, 1.0015096942849036, 0.0, 1.034364386952579, 2.053661283070421, 3.071227090558174, 7.8507610668296515, 8.916797133570272, 9.856485104095581, 10.790596868517959, 11.846238707448583, 11.784478116544472, 10.814343929076042, 9.819544775292227, 8.804130925528101, 7.7883527711957194, 6.855550893535481, 5.815851191304367, 4.851891923505424, 3.9071660289375583, 2.919451533381854, 1.9572038583216633, 1.0016733463461365, 1.9777804764692437, 2.9121987313023383, 3.9100450651917824, 8.795143857262309, 9.766707874177435, 10.839694383342959, 11.723195477289948, 12.728039310445237, 12.741803275997308, 11.703859730923412, 10.635538762773745, 9.68630365875857, 8.745531651820325, 7.695129810529801, 6.767284861112161, 5.7992060520585875, 4.829218973753028, 3.875031806410555, 2.882285915509814, 1.948431719338223, 2.9228268207123005, 3.91549612694432, 4.864529114339971, 9.764506579227586, 10.754320612977764, 11.794957385533456, 12.794689112514247, 13.69777429543634, 13.604220452615142, 12.646841876536463, 11.661382260469031, 10.713820514054106, 9.675491632713463, 8.624405339531508, 7.712332176350141, 6.7533867035569095, 5.796341429218333, 4.8605442416342575, 3.919270913378262, 2.8796530303305397, 3.854698470589727, 4.804146492879532, 5.736943197702711, 10.744772973104702, 11.690866373443463, 12.752880413655861, 13.724121245919891, 14.714383420028756, 14.55625318496763, 13.575480183665517, 12.626470781913978, 11.689530546405136, 10.699600919812648, 9.654571281110444, 8.692707309209204, 7.803662412962852, 6.841269644074415, 5.827017222037605, 4.852319145373877, 3.893941009744184, 4.869321968760559, 5.766578625502458, 6.725061736523935, 11.685573515407606, 12.650005490319822, 13.617961609675543, 14.573304527286298, 15.567293144921166, 15.593213893705821, 14.589965009653227, 13.623406900760017, 12.643328752389742, 11.666158703430732, 10.601114862823891, 9.660222861765837, 8.814287157157667, 7.848273417518153, 6.8382036770136345, 5.811173677876214, 4.929546901953314, 5.866685530340006, 6.829941850814593, 7.763455081419168, 12.731962492456315, 13.70122467795326, 14.547763083080307, 14.056777709893437, 14.996990651253926, 15.750892345592053, 15.521941145758282, 14.553295430644502, 13.482122588056122, 12.553971405577093, 11.55292919395246, 10.629287065875623, 9.736213584943814, 8.771529770357974, 7.779411345715374, 6.858227194517061, 5.928833596194734, 6.8584699066760395, 7.847515141003047, 8.777014242355149, 13.70923718863392, 14.712003766818821, 13.838233231257858, 13.061785810016778, 13.996469561878682, 14.79884790694653, 15.640712094794177, 15.396220151077063, 14.459178877828128, 13.523412294420158, 12.541760640215019, 11.63479076016576, 10.696876390848937, 9.797545060507014, 8.79026870690514, 7.791408775662536, 6.869498513295406, 7.832984054333111, 8.782009149623077, 9.735120937235756, 14.645278272726987, 13.80151960331003, 12.795267465368731, 12.000606330093742, 12.978950739648406, 13.861292174180695, 14.581482412447462, 15.455120694668672, 15.386757852431373, 14.443941707290767, 13.48807871096657, 12.661063302769413, 11.625579362143078, 10.708019034758438, 9.754399424538237, 8.765400405613235, 7.905816834904085, 8.86935018313311, 9.753847184370693, 10.686806584772606], [10.753841987678681, 9.886318314010735, 8.958093980408421, 9.860796445788296, 10.707667252393573, 11.61410469589822, 12.581466210465823, 13.491742879006292, 14.510972369254894, 15.449687121906607, 16.378426596430554, 16.431455335525005, 15.556217692127735, 14.667990121412148, 13.87854868843211, 13.072587769467264, 12.027942453619803, 11.077159140019596, 11.947579787316483, 12.804459063734345, 9.7513786605314, 10.622255041528357, 9.9943998010684, 10.828466489336765, 11.636821465900173, 12.554304022152149, 13.536242585352884, 14.56094607729694, 15.45073631860146, 16.376524198495506, 16.48921132984912, 15.496571867098451, 14.563895128229554, 13.733954914190948, 12.870292528400784, 12.10783114606865, 11.067894677897412, 10.096706716313687, 10.91996008107082, 11.785809723002838, 8.838155776122914, 9.689223448057087, 10.631846314899862, 11.632237724877847, 12.582474691462371, 13.520125595854653, 14.410809951611693, 15.454921095931846, 16.413739332491737, 16.48745719956937, 15.55137817397602, 14.550191975067637, 13.526065883145066, 12.695527466309851, 11.895862910612909, 11.084851630160857, 10.096845131133586, 9.152648939627365, 9.961464587995863, 10.826541937595758, 7.825836667482352, 8.7314690971629, 9.694634950966648, 10.747036955408237, 11.624689365081828, 12.569062833403207, 13.470874906417544, 14.50050847844186, 15.484316449124755, 15.44250922229935, 14.485128150917973, 13.498964184964835, 12.540499700226302, 11.753191428549254, 10.860822038838755, 10.135162768348923, 9.086030523021385, 8.176697573860396, 9.03298050491956, 9.855798156375801, 6.78054506639419, 7.739023082514493, 8.7168621616003, 9.708360839705275, 10.639055973404622, 11.5662385357309, 12.495916425304419, 13.53475571012363, 14.488611338252591, 14.54182238053158, 13.512465737763359, 12.56341722511652, 11.59690049289171, 10.768617346830428, 9.811447841847754, 9.085175703260704, 8.090546158354726, 7.244954008725219, 7.990606129936459, 8.904524736833231, 5.718435334745863, 6.731844806196705, 7.756361341765062, 8.758879062703496, 9.686517075867512, 10.723909004284131, 11.691715734393776, 12.724106280755086, 13.785272466036645, 13.574552648910437, 12.570677645470518, 11.6264825665387, 10.631856700838686, 9.767403794444197, 8.791043683134713, 8.035351227899945, 7.049143705510453, 6.208939569878986, 6.989476506383696, 7.846968000200302, 4.827891732921343, 5.7678485925301475, 6.739042607248843, 7.757584236324059, 8.720577600079402, 9.769263383810962, 10.751176703403704, 11.802457841958141, 12.772064163758321, 12.680369155178656, 11.647490834565094, 10.68109395248416, 9.686894586854885, 8.74377184443637, 7.812463324251915, 6.964839054255139, 5.974565533497607, 5.1559645477354765, 5.948188881949724, 6.877254710474256, 3.8972631009409833, 4.970384967255037, 5.9337176755586665, 6.985722793347188, 7.921289095743216, 8.861025357154015, 9.900497808282758, 10.928299090290306, 11.886583158726376, 11.685732866315101, 10.67598270251328, 9.69978594629566, 8.701631222010814, 7.763426587235701, 6.8388946582840795, 5.894756678334093, 5.007852250194138, 4.117164622697024, 4.9985729723024885, 5.915565940287897, 3.0366360821163236, 4.092941649155518, 5.072956373841766, 6.039807301067734, 6.995465437327288, 7.977719045419013, 9.042818752406099, 9.978342657241528, 10.958611324809214, 10.762092073105224, 9.7441782562711, 8.705217253033547, 7.725644107391626, 6.799143328869191, 5.84440267385961, 4.916952787806028, 3.9829389763917757, 3.050323809324673, 3.935968141448714, 4.947525212489187, 4.038403452839778, 5.094479442703529, 6.020418865632651, 7.014495059356135, 7.940436988211132, 8.9217079967895, 9.85799712059907, 10.889098569405155, 10.853347249918059, 9.92350941469685, 8.857799869973878, 7.91180968055831, 6.925586344761954, 5.855588631560549, 4.946001076913975, 4.018374107404767, 3.008448994349605, 2.1170259077819464, 2.9834136079081786, 3.953515273002271, 4.907800271329419, 5.854547865315772, 6.875650428463859, 7.9057275549247805, 8.93176739289159, 9.860132859221409, 10.890766887956858, 11.040768523643697, 10.02177004582206, 8.977045916915259, 7.997103127349606, 6.946649192792057, 5.969036872901234, 4.920800222551612, 3.9284282910415302, 2.978684541872751, 1.987907421754831, 1.0565409113248592, 2.0580431740966647, 3.007670607738797, 5.839297881607214, 6.864400418885467, 7.858128444458199, 8.877233059211001, 9.903975154302492, 10.914018764253822, 11.215837967507733, 10.165231129177752, 9.09406327805191, 8.028510028767855, 6.985958851706224, 5.9924303972853075, 4.9610381871154505, 3.9530454289077785, 2.990498847872834, 2.0358740812374823, 1.034364386952579, 0.0, 1.019296896117842, 2.0368627036055953, 6.846550219539186, 7.900598852370373, 8.826614083892382, 9.76072584831476, 10.816367687245384, 11.779710365305073, 11.848708316028622, 10.853909162244808, 9.838495312480681, 8.822717158148299, 7.889915280488061, 6.850215578256947, 5.886256310458004, 4.941530415890138, 3.9538159203344327, 2.9915682452742423, 1.9890748322543201, 1.012967702131213, 1.9473859569643075, 2.9452322908537516, 7.8834860080517295, 8.855050024966856, 9.811772718593076, 10.69332445708675, 11.698168290242037, 12.719631549113759, 12.73822411787599, 11.669903149726323, 10.720668045711149, 9.779896038772904, 8.72949419748238, 7.801649248064741, 6.833570439011167, 5.863583360705608, 4.9093961933631345, 3.916650302462393, 2.9358332052464067, 1.9580140463742697, 2.950683352606289, 3.899716340001941, 8.852848730017008, 9.842662763767187, 10.842046372470016, 11.764818092311048, 12.66790327523314, 13.65908139192816, 13.681206263489042, 12.69574664742161, 11.748184901006685, 10.709856019666042, 9.658769726484087, 8.716157994608965, 7.757212521815734, 6.800167247477157, 5.864370059893082, 4.906672399286445, 3.8670545162387233, 2.889885696251697, 3.8393337185415013, 4.772130423364681, 9.833115123894125, 10.779208524232885, 11.841222564445284, 12.723482040811122, 13.684512399825557, 14.654358267976002, 14.609844570618096, 13.660835168866557, 12.7188270723022, 11.709561039643049, 10.658397099369267, 9.696533127468028, 8.807488231221676, 7.845095462333239, 6.830843040296429, 5.83972063128206, 4.881342495652367, 3.904509194422529, 4.8017658511644274, 5.760248962185905, 10.773915666197029, 11.738347641109245, 12.706303760464966, 13.661646678075721, 14.655635295710589, 15.708049249283873, 15.624329396605805, 14.657771287712595, 13.647154570648567, 12.669984521689557, 11.604940681082715, 10.66404868002466, 9.81811297541649, 8.835674903426337, 7.825605162921818, 6.798575163784397, 5.893198003641863, 4.901872756001977, 5.8651290764765625, 6.7986423070811375, 11.820304643245734, 12.789566828742682, 13.63610523386973, 14.647757548234987, 15.605892951012635, 16.665492594140584, 16.556305532710862, 15.557121248903325, 14.485948406314945, 13.557797223835916, 12.556755012211283, 11.633112884134446, 10.67503512299528, 9.71035130840944, 8.71823288376684, 7.772853804997064, 6.843460206674736, 5.91382389619343, 6.902869130520438, 7.812201468017119, 12.79757933942334, 13.800345917608244, 13.111170292073451, 14.096150196969358, 15.030833948831262, 15.83321229389911, 16.675076481746757, 16.40004596933589, 15.463004696086951, 14.527238112678981, 13.545586458473842, 12.623306746180686, 11.635697928900402, 10.73636659855848, 9.7254602076151, 8.706035386142538, 7.784125123775409, 6.898976770742595, 7.848001866032561, 8.80111365364524, 13.733620423516406, 12.943759855311955, 12.068204526184324, 13.034970717046322, 14.013315126600986, 14.895656561133274, 15.61584679940004, 16.48948508162125, 16.390583670690194, 15.44776752554959, 14.491904529225394, 13.59988484082088, 12.564400900194546, 11.62264564523844, 10.66902603501824, 9.680027016093238, 8.820443445384088, 7.935342899542594, 8.819839900780178, 9.75279930118209], [9.906186495311463, 9.077996201583566, 9.897044923693, 10.799747389072875, 11.646618195678151, 12.553055639182798, 13.520417153750401, 14.43069382229087, 15.449923312539472, 16.388638065191184, 17.31737753971513, 17.375974312998117, 16.500736669600848, 15.612509098885264, 14.812014580045268, 13.820332287592935, 12.768918832905849, 11.806190349452418, 10.928282891198641, 11.785162167616505, 8.90372316816418, 9.619946540573551, 10.59258712006589, 11.532932930327965, 12.515315142069852, 13.493254965436726, 14.370793458279937, 15.399182109442423, 16.38968726188604, 17.315475141780084, 17.433730307322232, 16.441090844571566, 15.508414105702668, 14.678473891664064, 13.814811505873898, 12.896576147261264, 11.856639679090026, 10.825737925746509, 9.900663184952979, 10.766512826884998, 7.9462660293299745, 8.68691494710228, 9.629537813945056, 10.62992922392304, 11.627321163853725, 12.54439693548065, 13.408501450656889, 14.452612594977042, 15.411430831536933, 16.452118383734675, 16.495897151449135, 15.494710952540752, 14.47058486061818, 13.640046443782968, 12.840381888086023, 11.950891809972761, 10.945364933991641, 9.881680149060188, 8.942167691878021, 9.807245041477918, 6.933946920689413, 7.729160596208095, 8.692326450011842, 9.744728454453433, 10.622380864127022, 11.566754332448403, 12.46856640546274, 13.498199977487056, 14.48200794816995, 15.46813624950688, 15.429647128391087, 14.44348316243795, 13.485018677699417, 12.69771040602237, 11.80534101631187, 11.001202948160827, 9.948517962010806, 8.934284955541314, 8.013683608801719, 8.836501260257961, 5.888655319601251, 6.736714581559687, 7.714553660645494, 8.70605233875047, 9.636747472449816, 10.563930034776096, 11.493607924349615, 12.532447209168826, 13.486302837297787, 14.459772379823535, 14.456984715236473, 13.507936202589635, 12.541419470364824, 11.713136324303544, 10.755966819320868, 10.02038622328939, 8.992368448984077, 8.002541390406137, 6.971309233818617, 7.88522784071539, 4.826545587952925, 5.729536305241899, 6.754052840810256, 7.756570561748689, 8.684208574912706, 9.721600503329325, 10.68940723343897, 11.72179777980028, 12.782963965081839, 13.780140303417802, 13.515196622943632, 12.571001544011814, 11.5763756783118, 10.711922771917312, 9.735562660607828, 8.970561747928631, 7.950965996139804, 6.966526951559903, 5.970179610265854, 6.8276711040824605, 3.8255832319665375, 4.765540091575342, 5.736734106294037, 6.755275735369253, 7.718269099124596, 8.766954882856156, 9.748868202448898, 10.800149341003335, 11.769755662803515, 12.793966834931041, 12.592009812038208, 11.625612929957274, 10.631413564328, 9.688290821909485, 8.75698230172503, 7.900049574283823, 6.876387824126958, 5.9335614837521025, 4.928891985831882, 5.857957814356414, 2.894954599986177, 3.9680764663002313, 4.931409174603861, 5.983414292392382, 6.901992199625374, 7.841728461036172, 8.881200912164914, 9.909002194172462, 10.867286262608532, 11.927510003074126, 11.620501679986395, 10.644304923768775, 9.646150199483928, 8.707945564708815, 7.783413635757194, 6.8392756558072065, 5.918807491785544, 4.934521901230268, 3.9792760761846466, 4.8962690441700545, 2.0173391859984817, 3.0736447530376765, 4.053659477723924, 5.020510404949892, 5.9761685412094465, 6.958422149301171, 8.023521856288257, 8.959045761123686, 9.939314428691372, 10.96266285738863, 10.688697233744216, 9.649736230506663, 8.670163084864742, 7.743662306342306, 6.788921651332725, 5.861471765279141, 4.927457953864889, 3.961861687792835, 2.916671245330872, 3.9282283163713445, 3.019106556721936, 4.075182546585687, 5.001121969514809, 5.995198163238293, 6.92114009209329, 7.9024111006716575, 8.838700224481226, 9.869801673287311, 10.859028114718669, 10.942806310814692, 9.87709676609172, 8.931106576676152, 7.944883240879797, 6.874885527678392, 5.950095424367211, 5.022468454858004, 4.012543341802841, 3.0317816676474996, 1.9641167117903369, 2.934218376884429, 3.8885033752115774, 4.83525096919793, 5.856353532346017, 6.886430658806939, 7.912470496773748, 8.840835963103567, 9.871469991839014, 10.830754505598271, 11.041066941939901, 9.996342813033099, 9.016400023467446, 7.965946088909898, 6.988333769019075, 5.9400971186694544, 4.947725187159373, 3.997981437990593, 3.007204317872673, 2.056416289021228, 1.0387462779788228, 1.9883737116209552, 4.820000985489372, 5.845103522767625, 6.838831548340357, 7.857936163093158, 8.88467825818465, 9.89472186813598, 10.873458284252047, 11.184528025295593, 10.113360174169753, 9.047806924885696, 8.005255747824066, 7.0117272934031485, 5.9803350832332915, 4.97234232502562, 4.009795743990676, 3.055170977355324, 2.053661283070421, 1.019296896117842, 0.0, 1.0175658074877534, 5.827253323421343, 6.881301956252531, 7.80731718777454, 8.741428952196918, 9.797070791127542, 10.760413469187231, 11.730547656655661, 11.87320605836265, 10.857792208598523, 9.84201405426614, 8.909212176605902, 7.869512474374788, 6.905553206575845, 5.960827312007979, 4.941115059445115, 3.978867384384925, 2.9280257755388988, 1.9519186454157915, 1.017500390582697, 1.9429237898989453, 6.864189111933888, 7.835753128849014, 8.792475822475234, 9.674027560968907, 10.678871394124196, 11.700334652995917, 12.67581586507784, 12.689200045844165, 11.73996494182899, 10.799192934890746, 9.748791093600222, 8.820946144182582, 7.852867335129008, 6.85088249981629, 5.896695332473817, 4.867803192359032, 3.8747841485309853, 2.8969649896588483, 2.020797786224678, 2.8974078390471347, 7.833551833899166, 8.823365867649343, 9.822749476352175, 10.745521196193206, 11.648606379115298, 12.639784495810318, 13.597163071888996, 13.715043543539451, 12.767481797124526, 11.729152915783883, 10.678066622601929, 9.655108937893546, 8.696163465100314, 7.739118190761737, 6.803321003177661, 5.845623342571024, 4.806005459523302, 3.8288366395362754, 2.9474439717485623, 3.880240676571742, 8.813818227776283, 9.759911628115043, 10.821925668327442, 11.70418514469328, 12.665215503707715, 13.63506137185816, 14.598263022556509, 14.680132064984399, 13.657778015586782, 12.64851198292763, 11.597348042653849, 10.635484070752609, 9.746439174506257, 8.784046405617818, 7.769793983581009, 6.778671574566639, 5.820293438936946, 4.843460137707108, 3.909876104371488, 4.868359215392966, 9.754618770079187, 10.719050744991403, 11.687006864347124, 12.64234978195788, 13.636338399592745, 14.68875235316603, 15.612747848544219, 15.622429557415773, 14.586105513933148, 13.608935464974138, 12.543891624367296, 11.602999623309241, 10.757063918701071, 9.774625846710915, 8.764556106206395, 7.737526107068975, 6.832148946926441, 5.840823699286555, 4.973239329683623, 5.906752560288198, 10.801007747127894, 11.770269932624842, 12.616808337751888, 13.628460652117145, 14.586596054894793, 15.646195698022744, 16.544723984649274, 16.496072192187906, 15.424899349599526, 14.496748167120497, 13.495705955495865, 12.572063827419028, 11.613986066279857, 10.649302251694017, 9.657183827051417, 8.711804748281642, 7.782411149959315, 6.852774839478009, 6.023317120416247, 6.92031172122418, 11.7782824433055, 12.781049021490404, 13.568072515981418, 14.574892306081585, 15.587117144270037, 16.589966961434083, 17.532920138708867, 17.33899691262047, 16.401955639371533, 15.466189055963563, 14.484537401758423, 13.562257689465264, 12.57464887218498, 11.675317541843057, 10.664411150899678, 9.644986329427116, 8.723076067059989, 7.837927714027174, 7.039679753605393, 7.9534581612780215, 12.714323527398566, 11.924462959194113, 12.797235735617146, 13.775947096332368, 14.761059644726657, 15.7947944957037, 16.560365776873155, 17.434004059094363, 17.329534613974776, 16.38671846883417, 15.430855472509975, 14.538835784105459, 13.503351843479123, 12.561596588523019, 11.607976978302817, 10.618977959377816, 9.759394388668667, 8.874293842827173, 8.011517788353009, 8.905143808814872], [8.980746998977013, 9.546936542635713, 10.538018920401884, 11.483037166388684, 12.422554547986518, 13.432852027949327, 14.308004025679242, 15.274005517351148, 16.29323500759975, 17.231949760251464, 18.16068923477541, 18.30944643090683, 17.434208787509565, 16.517017801418028, 15.58419643304047, 14.592514140588136, 13.54110068590105, 12.57837220244762, 11.700464744193843, 10.794560508727407, 7.978283671829731, 8.602380733085798, 9.575021312578137, 10.515367122840212, 11.4977493345821, 12.492652701695398, 13.353227650792181, 14.381616301954667, 15.396453814369428, 16.401287610808748, 17.40143537007845, 17.37456296248028, 16.441886223611384, 15.598130347806391, 14.6474842131733, 13.668758000256464, 12.628821532085226, 11.59791977874171, 10.67284503794818, 9.7759111679959, 6.971930009334574, 7.6693491396145275, 8.611972006457302, 9.612363416435286, 10.609755356365971, 11.526831127992894, 12.390935643169133, 13.435046787489286, 14.393865024049177, 15.434552576246919, 16.47420153645855, 16.428183070449464, 15.404056978526894, 14.573518561691682, 13.773854005994737, 12.781003687252701, 11.717546786986842, 10.653862002055389, 9.714349544873222, 8.81664338258882, 5.959610900694012, 6.71159478872034, 7.674760642524088, 8.727162646965677, 9.604815056639268, 10.549188524960647, 11.451000597974984, 12.4806341699993, 13.464442140682195, 14.450570442019124, 15.407951513400501, 15.376955280346664, 14.41849079560813, 13.631182523931084, 12.738813134220583, 11.868732946320794, 10.816047960170772, 9.80181495370128, 8.78586546179692, 7.845899601368863, 4.91431929960585, 5.7191487740719325, 6.69698785315774, 7.688486531262715, 8.619181664962062, 9.54636422728834, 10.476042116861858, 11.51488140168107, 12.46873702981003, 13.44220657233578, 14.50690798294995, 14.441408320498349, 13.474891588273538, 12.646608442212258, 11.689438937229582, 10.887916221449357, 9.859898447144044, 8.870071388566103, 7.838839231978583, 6.894626181826292, 3.8522095679575235, 4.7119704977541454, 5.736487033322502, 6.739004754260936, 7.666642767424953, 8.704034695841573, 9.671841425951218, 10.704231972312527, 11.765398157594086, 12.76257449593005, 13.766449499369969, 13.504473661920528, 12.509847796220514, 11.645394889826026, 10.669034778516542, 9.838091746088597, 8.81849599429977, 7.834056949719869, 6.83770960842582, 5.837069445193363, 2.808017424478784, 3.7479742840875883, 4.7191682988062835, 5.7377099278815, 6.700703291636843, 7.749389075368403, 8.731302394961146, 9.782583533515583, 10.752189855315763, 11.776401027443288, 12.848064842439173, 12.559085047865988, 11.564885682236714, 10.621762939818199, 9.690454419633744, 8.76757957244379, 7.7439178222869245, 6.801091481912069, 5.7964219839918485, 4.867356155467316, 1.8773887924984236, 2.950510658812478, 3.9138433671161077, 4.96584848490463, 5.88442639213762, 6.8241626535484174, 7.863635104677161, 8.891436386684708, 9.849720455120778, 10.909944195586371, 11.919694359388192, 11.57777704167749, 10.579622317392642, 9.64141768261753, 8.716885753665908, 7.7727477737159205, 6.827780618348494, 5.843495027793218, 4.8882492027475966, 3.8787032366823015, 0.9997733785107283, 2.056078945549923, 3.0360936702361707, 4.002944597462139, 4.958602733721693, 5.940856341813417, 7.005956048800502, 7.941479953635932, 8.921748621203617, 9.945097049900877, 10.963010866735, 10.583208348415376, 9.603635202773454, 8.677134424251019, 7.722393769241439, 6.794943883187855, 5.860930071773603, 4.895333805701549, 3.850143363239586, 2.9106625088835916, 2.0015407492341826, 3.057616739097934, 3.9835561620270563, 4.977632355750541, 5.903574284605536, 6.884845293183904, 7.821134416993473, 8.852235865799559, 9.841462307230916, 10.771300142452125, 10.894662573579472, 9.948672384163904, 8.954985593606622, 7.884987880405217, 6.883567542275925, 5.955940572766718, 4.946015459711555, 3.9652537855562136, 2.8975888296990506, 1.916652569396676, 2.870937567723824, 3.817685161710177, 4.838787724858264, 5.868864851319185, 6.894904689285996, 7.823270155615815, 8.853904184351261, 9.813188698110519, 10.832187175932155, 11.013908620520853, 10.0339658309552, 8.983511896397651, 8.00589957650683, 6.957662926157207, 5.965290994647125, 5.015547245478346, 4.024770125360426, 2.989888406929942, 1.9722183958875368, 0.970807904133202, 3.802435178001619, 4.827537715279871, 5.821265740852604, 6.840370355605405, 7.8671124506968955, 8.877156060648227, 9.855892476764295, 10.744560333585461, 11.130925981657505, 10.065372732373449, 9.022821555311818, 8.029293100890902, 6.997900890721045, 5.989908132513373, 5.027361551478429, 4.0727367848430776, 3.071227090558174, 2.0368627036055953, 1.0175658074877534, 0.0, 4.80968751593359, 5.863736148764778, 6.789751380286788, 7.723863144709166, 8.779504983639791, 9.74284766169948, 10.71298184916791, 11.707781002951725, 11.799268531563648, 10.783490377231265, 9.850688499571026, 8.810988797339911, 7.847029529540968, 6.892820098214309, 5.846818985163055, 4.8845713101028645, 3.8337297012568383, 2.857622571133731, 1.9232043163006363, 0.925357982411192, 5.862060197174478, 6.833624214089604, 7.774910014987482, 8.656461753481155, 9.661305586636443, 10.682768845508164, 11.65825005759009, 12.70494847191559, 12.681441264794113, 11.740669257855869, 10.690267416565344, 9.762422467147704, 8.794343658094132, 7.75658642553423, 6.802399258191756, 5.773507118076972, 4.780488074248925, 3.802668915376788, 2.9043190710075977, 1.8798420315593813, 6.841616579260925, 7.821236952889935, 8.805183668864423, 9.727955388705453, 10.631040571627546, 11.622218688322565, 12.579597264401244, 13.609807262662251, 13.70895812008965, 12.670629238749006, 11.607255311348522, 10.560812863611485, 9.601867390818253, 8.644822116479675, 7.7090249288956, 6.751327268288963, 5.7117093852412415, 4.734540565254215, 3.830965256531482, 2.9374136006199008, 7.821882973138042, 8.767976373476802, 9.8299904136892, 10.686619337205528, 11.647649696219963, 12.617495564370408, 13.580697215068756, 14.529706616820295, 14.563481941304719, 13.554215908645569, 12.503051968371787, 11.541187996470548, 10.652143100224194, 9.689750331335757, 8.675497909298947, 7.684375500284578, 6.725997364654885, 5.749164063425047, 4.793397389154407, 3.9676318727068036, 8.762683515440946, 9.727115490353162, 10.695071609708883, 11.650414527319638, 12.644403144954506, 13.671186545678278, 14.595182041056466, 15.526642735666332, 15.491809439651085, 14.514639390692075, 13.449595550085235, 12.50870354902718, 11.662767844419008, 10.680329772428856, 9.670260031924336, 8.643230032786915, 7.73785287264438, 6.746527625004494, 5.856760614466542, 5.006025217602036, 9.810406088238796, 10.7783346779866, 11.624873083113647, 12.636525397478904, 13.594660800256552, 14.654260443384501, 15.527158177161521, 16.516392727235086, 16.330603275317465, 15.402452092838436, 14.401409881213803, 13.477767753136966, 12.519689991997796, 11.555006177411956, 10.562887752769356, 9.61750867399958, 8.688115075677253, 7.758478765195948, 6.906838405199166, 6.019584378538018, 10.787680784416402, 11.78911376685216, 12.576137261343177, 13.582957051443344, 14.595181889631796, 15.598031706795842, 16.540984884070628, 17.456174246107174, 17.307659565089473, 16.3718929816815, 15.390241327476362, 14.467961615183203, 13.480352797902919, 12.581021467560996, 11.570115076617617, 10.550690255145055, 9.628779992777925, 8.743631639745113, 7.923201038388312, 7.05273081859186, 11.723721868509468, 12.696644812189314, 13.569417588612348, 14.54812894932757, 15.533241497721859, 16.535587439561677, 17.46487447940592, 18.36747617700308, 18.235238539692716, 17.29242239455211, 16.336559398227912, 15.444539709823395, 14.40905576919706, 13.467300514240957, 12.513680904020756, 11.524681885095754, 10.665098314386604, 9.779997768545112, 8.895039073135928, 8.00441646612871], [12.097254683973347, 12.663444227632047, 13.654526605398217, 14.599544851385016, 15.53906223298285, 16.476168973500666, 17.35132097123058, 18.31732246290249, 18.31199298627912, 17.373278233627406, 16.44453875910346, 15.52099424529824, 14.567541648485253, 13.569298843987013, 12.636477475609457, 11.644795183157123, 10.593381728470037, 9.630653245016607, 8.75274578676283, 7.846841551296395, 11.094791356826065, 11.718888418082132, 12.691528997574471, 13.631874807836546, 14.612409027344613, 15.535969647246738, 16.39654459634352, 17.424933247506008, 17.532327796209646, 16.578897998892057, 15.578750239622355, 14.586110776871688, 13.653434038002791, 12.65041139037538, 11.699765255742289, 10.721039042825453, 9.681102574654215, 8.650200821310698, 7.725126080517167, 6.828192210564887, 10.088437694330908, 10.785856824610862, 11.728479691453638, 12.728871101431622, 13.666755801782415, 14.570148073544233, 15.434252588720472, 16.478363733040627, 16.510150410653946, 15.593744465834908, 14.65766544024156, 13.639730884840874, 12.615604792918303, 11.703897571959295, 10.881110707136344, 9.833284729821688, 8.76982782955583, 7.706143044624376, 6.76663058744221, 5.8689244251578065, 9.076118585690347, 9.828102473716676, 10.791268327520424, 11.79914463831384, 12.648132002190605, 13.592505470511986, 14.494317543526323, 15.52395111555064, 15.534924789901819, 14.54879648856489, 13.591415417183512, 12.588503094738073, 11.63003860999954, 10.761561534198698, 9.8691921444882, 8.92101398888978, 7.868329002739758, 6.8540959962702654, 5.838146504365906, 4.89818064393785, 8.030826984602186, 8.835656459068268, 9.813495538154076, 10.760461931675817, 11.6624986105134, 12.58968117283968, 13.519359062413198, 14.558198347232409, 14.621579189322867, 13.648109646797119, 12.618753004028898, 11.652956134889758, 10.686439402664947, 9.776987452479872, 8.819817947497198, 7.940197264018344, 6.912179489713031, 5.922352431135089, 4.8911202745475695, 3.9469072243952787, 6.968717252953859, 7.828478182750481, 8.848286444402362, 9.810980154674038, 10.684951178939555, 11.634505385847483, 12.602312115957128, 13.623405200677519, 13.75029510025804, 12.680839915175977, 11.676964911736057, 10.73276983280424, 9.721395610611923, 8.775773900093641, 7.7994137887841575, 6.890372788657584, 5.870777036868757, 4.886337992288856, 3.8899906509948066, 2.889350487762349, 5.92452510947512, 6.864481969083924, 7.830967709886143, 8.802692547475214, 9.719011703151445, 10.667259060855883, 11.649172380448626, 12.61428036909607, 12.846082477861886, 11.827551215502222, 10.76448349216046, 9.798086610079526, 8.776433496628123, 7.7521419500858135, 6.820833429901359, 5.819860615012777, 4.796198864855912, 3.8533725244810553, 2.848703026560835, 1.919637198036303, 4.99389647749476, 5.902034287895412, 6.805515615092865, 7.793732594353009, 8.685785540115859, 9.625521801526657, 10.6649942526554, 11.657467416229178, 11.89313866710426, 10.832914926638667, 9.823164762836846, 8.846968006619226, 7.84881328233438, 6.9106086475592665, 5.847264763933524, 4.827481580236348, 3.8800616609174807, 2.895776070362205, 1.9405302453165838, 0.9309842792512885, 4.061477865102362, 4.947947740141233, 5.837452818214409, 6.804303745440377, 7.759961881699931, 8.742215489791656, 9.748582043129455, 10.684105947964884, 11.66437461553257, 11.650424756063613, 10.632510939229489, 9.593549935991936, 8.613976790350014, 7.687476011827578, 6.732735356817997, 5.805285470764414, 4.904974934719843, 3.9626168837345563, 2.939731464113835, 1.8990250070499985, 3.0077359292680317, 3.889368424769885, 4.889990326423524, 5.884066520147008, 6.826935850819268, 7.808206859397636, 8.744495983207205, 9.77559743201329, 10.764823873444648, 11.694661708665857, 11.543211219764714, 10.597221030349147, 9.656921482426666, 8.680245721091932, 7.731267510533394, 6.803640541024187, 5.876676459432625, 4.895914785277283, 3.8922859976543704, 2.8930349465369143, 1.997812660911362, 2.944560254897715, 3.9656628180458022, 4.995739944506723, 6.0217797824735335, 6.950145248803353, 8.024971546547198, 8.95595426790765, 9.974952745729286, 11.019676874636088, 11.999619664201742, 11.5623815181154, 10.678770242558729, 9.61503413010087, 8.767958679572072, 7.873242773010038, 6.897218032027399, 5.83532644250829, 4.817656431465885, 3.8388796118003885, 1.066315050633567, 2.102234500225527, 3.0802673662022086, 4.018829797170652, 5.045571892262143, 6.015105900863841, 7.030705279518724, 8.024582632432706, 9.002487712682473, 10.06804096196653, 11.010497515577969, 12.004025969998885, 11.593700347934922, 10.58570758972725, 9.806895527749907, 8.852270761114555, 7.8507610668296515, 6.846550219539186, 5.827253323421344, 4.80968751593359, 0.0, 1.0660360667406206, 2.111781726768025, 3.0458934911904034, 4.101535330121028, 5.064878008180717, 6.035012195649147, 7.029811349432961, 8.045225199197088, 9.06100335352947, 9.99380523118971, 11.033504933420824, 11.997464201219767, 11.574192576709608, 10.656506501096645, 9.694258826036455, 8.643417217190429, 7.667310087067322, 6.732891832234227, 5.735045498344783, 1.0523726812408878, 2.0239366981560143, 3.0969232073215394, 3.9784920999623927, 4.98333593311768, 6.004799191989401, 6.980280404071325, 8.026978818396826, 8.976213922412, 9.916985929350245, 10.961699253471739, 11.889544202889379, 12.907604050492887, 12.507432552305463, 11.612086774125347, 10.58319463401056, 9.590175590182515, 8.61235643131038, 7.7140065869411885, 6.689529547492972, 2.031929063327335, 3.011549436956345, 4.052186209512037, 5.0499857351866915, 5.953070918108782, 6.944249034803802, 7.90162761088248, 8.931837609143487, 9.896590620956106, 10.846945910243383, 11.890974782473446, 12.861212945904345, 13.820158418697577, 13.454509632413266, 12.518712444829191, 11.561014784222554, 10.521396901174832, 9.544228081187807, 8.640652772465073, 7.747101116553491, 3.012195457204452, 3.958288857543213, 5.020302897755611, 5.99154373001964, 6.9696800427012, 7.939525910851646, 8.902727561549993, 9.851736963301532, 10.872300653307136, 11.871055197342567, 12.922219137616349, 13.841588078763408, 14.870434128103518, 14.499437847269348, 13.485185425232538, 12.494063016218169, 11.535684880588477, 10.55885157935864, 9.603084905087998, 8.777319388640393, 3.9529959995073565, 4.917427974419573, 5.885384093775293, 6.840727011386047, 7.834715629020914, 8.900551997194977, 9.903800881247571, 10.84867308214757, 11.864612679674867, 12.841782728633877, 13.868762719329796, 14.80910363132004, 15.78344836276234, 15.490017288362445, 14.479947547857925, 13.452917548720505, 12.547540388577973, 11.556215140938086, 10.666448130400134, 9.815712733535626, 5.025568008521472, 5.968647162053011, 6.815185567180057, 7.826837881545314, 8.784973284322962, 9.844572927450912, 10.835777017352626, 11.838423073716323, 12.909595916304703, 13.837747098783732, 14.820577050458365, 15.778167835429826, 16.758276668757112, 16.364693693345547, 15.372575268702949, 14.427196189933174, 13.497802591610846, 12.56816628112954, 11.716525921132758, 10.829271894471608, 6.002842704699078, 6.979426250918571, 7.766449745409588, 8.773269535509755, 9.785494373698207, 10.788344190862253, 11.731297368137037, 12.670192675324735, 13.60723394857367, 14.54300053198164, 15.61601845700993, 16.598940213238475, 17.586549030518757, 17.390708983494587, 16.379802592551208, 15.360377771078648, 14.438467508711518, 13.553319155678706, 12.732888554321905, 11.862418334525449, 6.938883788792145, 7.926816758855904, 8.809415511298715, 9.825545021188226, 10.803013195928482, 11.725899923628088, 12.78442436902421, 13.634274258991738, 14.534812923176915, 15.499811650524478, 16.455674646848674, 17.505016194652324, 18.5152520018129, 18.27698803017455, 17.32336841995435, 16.334369401029345, 15.474785830320197, 14.589685284478705, 13.704726589069521, 12.8141039820623], [12.787531417781457, 11.799567456997629, 12.7906498347638, 13.7356680807506, 14.643053973008096, 15.577659705657549, 16.452811703387464, 17.41881319505937, 17.353968836802178, 16.415254084150465, 15.486514609626518, 14.606019347237348, 13.60951749900831, 12.774196362115527, 11.84137499373797, 10.849692701285637, 9.943183623678374, 8.980455140224944, 8.166022915606785, 8.846960439877263, 11.785068090634175, 10.855011647447714, 11.827652226940053, 12.767998037202128, 13.713899759501496, 14.63746037940362, 15.498035328500404, 16.52642397966289, 17.541261492077652, 17.342091160739365, 16.53354227841457, 15.5409028156639, 14.601840062906492, 13.654921792675816, 12.704275658042725, 11.725549445125889, 10.685612976954651, 9.654711223611136, 8.729636482817606, 7.832702612865325, 10.922574685171796, 9.921980053976444, 10.857811440999148, 11.858202850977133, 12.768246533939298, 13.671638805701116, 14.535743320877355, 15.579854465197508, 16.5386727017574, 16.65978053257553, 15.723701506982183, 14.705766951581497, 13.681640859658925, 12.769933638699918, 11.885621109436782, 10.837795132122126, 9.774338231856268, 8.710653446924814, 7.771140989742648, 6.873434827458245, 10.009981584177355, 8.964225703082258, 9.920600077065934, 10.900635370470726, 11.749622734347488, 12.693996202668869, 13.595808275683206, 14.625441847707522, 15.609249818390417, 15.614832555305512, 14.657451483924135, 13.654539161478695, 12.696074676740162, 11.82759760093932, 10.900433572795844, 9.929772566935531, 8.87708758078551, 7.862854574316017, 6.8426569066663445, 5.902691046238288, 9.02097841576912, 7.97177968843385, 8.942827287699586, 9.861952663832703, 10.763989342670282, 11.691171904996562, 12.62084979457008, 13.659689079389292, 14.613544707518253, 14.714145713537741, 13.68478907076952, 12.71899220163038, 11.752475469405569, 10.843023519220495, 9.885854014237818, 9.006233330758963, 7.978215556453652, 6.939392402191166, 5.8968578752257566, 4.951417626695717, 7.96370317308345, 6.964601412116063, 7.949777176559247, 8.912470886830924, 9.786441911096437, 10.735996118004367, 11.703802848114012, 12.724895932834405, 13.71246458961237, 13.746875981916599, 12.74300097847668, 11.798805899544861, 10.787431677352545, 9.841809966834262, 8.865449855524778, 7.956408855398204, 6.936813103609378, 5.952374059029476, 4.956026717735427, 3.9553865545029696, 6.9195110296047115, 6.000605198449506, 6.932458442043028, 7.904183279632099, 8.820502435308327, 9.768749793012768, 10.75066311260551, 11.715771101252956, 12.67018602757976, 12.893587282242843, 11.830519558901083, 10.864122676820148, 9.842469563368745, 8.818178016826435, 7.88686949664198, 6.8858966817533975, 5.862234931596532, 4.919408591221676, 3.9147390933014554, 2.9856732647769233, 5.9888823976243515, 5.003525020052297, 5.907006347249751, 6.895223326509894, 7.787276272272743, 8.727012533683542, 9.766484984812285, 10.758958148386064, 11.717242216822134, 11.898950993379287, 10.889200829577467, 9.913004073359847, 8.914849349075, 7.976644714299887, 6.913300830674144, 5.893517646976969, 4.946097727658101, 3.9618121371028256, 3.0065663120572044, 1.997020345991909, 5.056463785231954, 4.049438472298118, 4.938943550371294, 5.905794477597262, 6.861452613856817, 7.8437062219485405, 8.85007277528634, 9.78559668012177, 10.765865347689456, 11.789213776386713, 11.698547005970108, 10.659586002732555, 9.680012857090633, 8.753512078568198, 7.798771423558618, 6.871321537505034, 5.971011001460463, 5.028652950475177, 4.005767530854455, 2.965061073790619, 4.0027218493976235, 2.990859156926771, 3.9914810585804092, 4.985557252303893, 5.9284265829761535, 6.909697591554521, 7.8459867153640905, 8.877088164170177, 9.866314605601534, 10.796152440822743, 11.861861985545715, 11.663257097089765, 10.722957549167285, 9.746281787832551, 8.797303577274015, 7.8696766077648075, 6.942712526173246, 5.961950852017903, 4.958322064394991, 3.947083579368102, 2.9927985810409536, 2.046050987054601, 3.067153550202688, 4.0092466176721455, 5.002551319089305, 5.930916785419124, 6.9666575051911375, 7.889918201167029, 8.908916678988664, 9.953640807895466, 10.93358359746112, 11.892208698765012, 11.744806309299348, 10.681070196841489, 9.833994746312692, 8.939278839750658, 7.96325409876802, 6.9013625092489095, 5.883692498206504, 4.892928244631576, 2.1044985843507673, 1.0361984334849061, 2.014231299461588, 2.9527937304300313, 3.9795358255215225, 4.949069834123221, 5.964669212778104, 6.958546565692085, 7.936451645941853, 9.002004895225909, 9.944461448837346, 10.937989903258263, 11.856646257821698, 11.651743656467868, 10.872931594490527, 9.918306827855176, 8.916797133570272, 7.900598852370373, 6.881301956252531, 5.863736148764778, 1.0660360667406206, 0.0, 1.0457456600274044, 1.9798574244497826, 3.035499263380407, 3.9988419414400966, 4.968976128908526, 5.963775282692341, 6.979189132456467, 7.994967286788849, 8.927769164449087, 9.967468866680202, 10.931428134479145, 11.885637565805805, 11.710555133927834, 10.748307458867643, 9.697465850021617, 8.72135871989851, 7.786940465065414, 6.78909413117597, 2.0218153666804883, 1.0502513497653618, 2.0309042947280984, 2.9124560332217717, 3.917299866377059, 4.93876312524878, 5.914244337330705, 6.960942751656205, 7.91017785567138, 8.850949862609625, 9.895663186731117, 10.823508136148757, 11.841567983752265, 12.81887754140166, 12.666135406956535, 11.63724326684175, 10.644224223013703, 9.666405064141566, 8.768055219772375, 7.7435781803241595, 3.0013717487669354, 2.0378640885656925, 3.061177948605039, 3.98394966844607, 4.887034851368161, 5.878212968063181, 6.8355915441418595, 7.865801542402867, 8.830554554215485, 9.780909843502762, 10.824938715732824, 11.795176879163723, 12.754122351956955, 13.711167626295532, 13.57276107766038, 12.615063417053742, 11.57544553400602, 10.598276714018994, 9.694701405296259, 8.80114974938468, 3.9816381426440524, 3.1101735729067923, 4.132071374136599, 4.942613616946145, 5.903643975960579, 6.873489844111025, 7.836691494809373, 8.785700896560913, 9.806264586566515, 10.805019130601947, 11.856183070875728, 12.775552012022786, 13.804398061362896, 14.756095841151614, 14.539234058063727, 13.548111649049357, 12.589733513419665, 11.612900212189826, 10.657133537919185, 9.831368021471583, 4.922438684946957, 4.160454063174981, 5.065378336536794, 5.915623685936385, 6.909612303571252, 7.927180825418896, 8.851176320797082, 9.782637015406952, 10.798576612934246, 11.775746661893256, 12.802726652589175, 13.743067564579418, 14.717412296021717, 15.757055877240324, 15.533996180689114, 14.506966181551693, 13.60158902140916, 12.610263773769272, 11.72049676323132, 10.869761366366816, 5.995010693961072, 5.21167325080842, 5.995179809941558, 6.932790029768746, 7.8909254325463944, 8.950525075674346, 9.783152456902137, 10.772387006975704, 11.843559849564084, 12.771711032043113, 13.754540983717744, 14.712131768689204, 15.69224060201649, 16.65692441660233, 16.426623901534136, 15.48124482276436, 14.551851224442032, 13.622214913960727, 12.770574553963945, 11.883320527302798, 6.972285390138678, 6.22245233967398, 6.946443988171088, 7.9277819296454055, 8.891446521921639, 9.894296339085685, 10.80414868746635, 11.712168525847792, 12.649209799096727, 13.584976382504697, 14.657994307532988, 15.640916063761532, 16.628524881041816, 17.614261748422138, 17.433851225382394, 16.414426403909832, 15.492516141542705, 14.607367788509892, 13.688444885133013, 12.735333097520334, 7.908326474231745, 7.169842847611313, 7.989409754060215, 8.988961409568441, 9.908965344151914, 10.83185207185152, 11.863378369813065, 12.676250109514795, 13.576788773699972, 14.541787501047537, 15.497650497371733, 16.546992045175383, 17.55722785233596, 17.411632268614845, 16.522738366537528, 15.670694209308433, 14.776021081154807, 13.813400915629627, 12.866045870228186, 13.687018745057184], [13.713546649303467, 12.725582688519639, 12.01575934434206, 12.887469377492625, 13.67234467062769, 14.606950403277143, 15.482102401007058, 16.448103892678965, 16.30822317677477, 15.369508424123058, 14.44076894959911, 13.560273687209941, 12.563771838980903, 11.728450702088123, 10.795629333710567, 9.803947041258233, 8.897437963650969, 7.934709480197538, 8.78142221732073, 9.735517850614167, 12.711083322156185, 11.781026878969724, 10.97945352368208, 11.919799333944155, 12.74319045712109, 13.666751077023214, 14.527326026119997, 15.555714677282483, 16.570552189697242, 16.296345500711958, 15.48779661838716, 14.495157155636493, 13.556094402879085, 12.662485909309323, 11.747429877573683, 10.768703664656847, 9.85748573937336, 8.915161903903448, 9.737530276918463, 8.840596406966181, 11.848589916693806, 10.847995285498454, 9.927786593633195, 10.92817800361118, 11.797537231558891, 12.70092950332071, 13.565034018496949, 14.609145162817102, 15.567963399376993, 16.608650951574734, 16.478725869770955, 15.441537047667307, 14.593923647963573, 13.663159840073927, 12.721859495361558, 11.79913043522561, 10.782232025957125, 9.718547241025671, 8.779034783843505, 7.881328621559102, 10.935996815699365, 9.890240934604268, 8.990575229699981, 9.970610523104773, 10.778913431967082, 11.723286900288462, 12.6250989733028, 13.654732545327116, 14.63854051601001, 15.62466881734694, 15.70319714395154, 14.7002848215061, 13.741820336767567, 12.873343260966724, 11.908327366896701, 10.937666361036388, 9.884981374886367, 8.870748368416875, 7.850550700767202, 6.910584840339145, 9.94699364729113, 8.89779491995586, 8.012802440333633, 8.93192781646675, 9.793280040289876, 10.720462602616156, 11.650140492189674, 12.688979777008885, 13.642835405137847, 14.616304947663595, 14.730534730796926, 13.764737861657785, 12.798221129432974, 11.888769179247898, 10.931599674265223, 10.026947929168552, 8.995154051981999, 7.947286196292024, 6.904751669326614, 5.959311420796574, 8.88971840460546, 7.890616643638073, 7.019752329193294, 7.98244603946497, 8.815732608716031, 9.765286815623961, 10.733093545733606, 11.742241110450818, 12.729809767228783, 13.69791584581046, 13.788746638504085, 12.844551559572267, 11.83317733737995, 10.887555626861667, 9.911195515552183, 9.002154515425609, 7.982558763636781, 6.998119719056881, 6.001772377762832, 5.001132214530374, 7.845526261126722, 6.926620429971516, 6.0024335946770755, 6.9741584322661465, 7.849793132927922, 8.798040490632362, 9.779953810225104, 10.73311627886937, 11.687531205196173, 12.711742377323699, 12.876265218928488, 11.909868336847554, 10.88821522339615, 9.86392367685384, 8.932615156669385, 7.931642341780801, 6.907980591623936, 5.96515425124908, 4.96048475332886, 4.031418924804328, 6.9148976291463615, 5.929540251574307, 4.976981499883798, 5.965198479143941, 6.816566969892337, 7.756303231303135, 8.795775682431877, 9.776303326002477, 10.734587394438547, 11.79481113490414, 11.934946489604872, 10.958749733387252, 9.960595009102406, 9.022390374327292, 7.9590464907015495, 6.939263307004374, 5.991843387685506, 5.0075577971302305, 4.052311972084609, 3.0427660060193134, 5.982479016753964, 4.975453703820128, 4.0089187030053415, 4.9757696302313095, 5.89074331147641, 6.872996919568134, 7.867417952902753, 8.802941857738183, 9.783210525305869, 10.806558954003126, 11.82447277083725, 11.70533166275996, 10.725758517118038, 9.799257738595603, 8.844517083586023, 7.91706719753244, 7.016756661487868, 6.074398610502582, 5.0515131908818605, 4.010806733818024, 4.928737080919634, 3.916874388448781, 3.0614562112144563, 4.002902429920306, 4.945771760592566, 5.927042769170934, 6.863331892980503, 7.8944333417865895, 8.883659783217947, 9.813497618439156, 10.875772464149815, 11.81162352650386, 11.76870320919469, 10.792027447859956, 9.84304923730142, 8.915422267792213, 7.952159004040816, 6.971397329885473, 5.90373237402831, 4.873098810890112, 3.9188138125629637, 2.972066218576611, 2.0246195483458056, 2.963500957644741, 3.9568056590619007, 4.88517112539172, 5.920911845163733, 6.844172541139623, 7.863171018961259, 8.90789514786806, 9.887837937433714, 10.846463038737607, 11.818899283580077, 11.726815856868894, 10.843462938580029, 9.89371918941125, 8.90294206929333, 7.838023978950326, 6.820353967907921, 5.818943476153586, 3.0305138158727774, 1.9622136650069164, 0.9684856394341836, 1.907048070402627, 2.933790165494118, 3.9033241740958164, 4.9189235527507, 5.91280090566468, 6.8907059859144475, 7.9562592351985035, 8.898715788809941, 9.892244243230857, 10.810900597794292, 11.818893356001965, 11.812619565015837, 10.857994798380485, 9.856485104095581, 8.826614083892384, 7.807317187774541, 6.789751380286788, 2.111781726768025, 1.0457456600274044, 0.0, 0.9341117644223782, 1.9897536033530026, 2.953096281412692, 3.9232304688811217, 4.918029622664935, 5.933443472429062, 6.949221626761443, 7.8820235044216815, 8.921723206652796, 9.88568247445174, 10.8398919057784, 11.885893018829654, 11.674322690389653, 10.623481081543627, 9.64737395142052, 8.712955696587425, 7.71510936269798, 3.0297091607813456, 2.058145143866219, 0.9851586347006942, 1.8667103731943675, 2.871554206349655, 3.8930174652213756, 4.8684986773033, 5.9151970916288, 6.864432195643975, 7.805204202582218, 8.849917526703711, 9.777762476121351, 10.79582232372486, 11.773131881374255, 12.727319048716728, 12.563258498363759, 11.570239454535713, 10.592420295663576, 9.694070451294385, 8.669593411846169, 4.009265542867793, 3.0457578826665497, 2.0154322885776343, 2.9382040084186656, 3.841289191340757, 4.832467308035777, 5.789845884114455, 6.8200558823754625, 7.78480889418808, 8.735164183475357, 9.779193055705418, 10.749431219136317, 11.70837669192955, 12.665421966268127, 13.601219153852202, 13.541078648575752, 12.50146076552803, 11.524291945541004, 10.620716636818269, 9.727164980906688, 4.98953193674491, 4.118067367007649, 3.0863257141091944, 3.896867956918741, 4.857898315933175, 5.827744184083621, 6.790945834781969, 7.739955236533508, 8.76051892653911, 9.759273470574541, 10.810437410848323, 11.72980635199538, 12.758652401335492, 13.710350181124209, 14.56769213425555, 14.474126880571367, 13.515748744941675, 12.538915443711836, 11.583148769441195, 10.757383252993591, 5.930332479047814, 4.987588795865109, 4.019632676509389, 4.869878025908981, 5.863866643543847, 6.881435165391492, 7.8054306607696775, 8.736891355379544, 9.75283095290684, 10.730001001865851, 11.75698099256177, 12.697321904552012, 13.671666635994312, 14.711310217212919, 15.58028802546631, 15.432981413073703, 14.527604252931171, 13.536279005291284, 12.646511994753329, 11.795776597888825, 7.0029044880619296, 6.005091888858538, 4.949434149914152, 5.887044369741343, 6.845179772518991, 7.904779415646941, 8.737406796874733, 9.726641346948297, 10.797814189536677, 11.725965372015706, 12.708795323690339, 13.666386108661799, 14.646494941989085, 15.611178756574924, 16.52149569416805, 16.407260054286372, 15.477866455964044, 14.548230145482739, 13.696589785485953, 12.809335758824806, 7.8608428008755835, 6.837851641387925, 5.900698328143683, 6.882036269618002, 7.845700861894235, 8.848550679058281, 9.758403027438947, 10.666422865820385, 11.60346413906932, 12.53923072247729, 13.61224864750558, 14.595170403734125, 15.582779221014409, 16.56851608839473, 16.53514096394479, 15.673976536878726, 14.964140699505512, 14.074876554007886, 14.614460116655023, 13.661348329042344, 8.79688388496865, 7.785242149325257, 6.94366409403281, 7.943215749541038, 8.86321968412451, 9.786106411824116, 10.817632709785661, 11.630504449487388, 12.531043113672565, 13.49604184102013, 14.451904837344326, 15.501246385147976, 16.511482192308552, 16.44092296623444, 15.552029064157123, 14.699984906928027, 13.927822377896833, 13.038510425207887, 13.792061101750196, 14.613033976579194], [14.647658413725846, 13.659694452942018, 12.94987110876444, 12.109070872815465, 12.73823290620531, 13.672838638854763, 14.547990636584679, 15.513992128256584, 15.374111412352391, 14.435396659700679, 13.506657185176731, 12.626161922787563, 11.629660074558526, 10.794338937665746, 9.86151756928819, 8.869835276835856, 8.01613224854518, 8.782380790848737, 9.629093527971929, 10.583189161265366, 13.645195086578564, 12.715138643392104, 11.91356528810446, 11.141400829266994, 11.80907869269871, 12.732639312600835, 13.593214261697618, 14.621602912860103, 15.636440425274865, 15.362233736289578, 14.553684853964782, 13.561045391214115, 12.621982638456707, 11.728374144886946, 10.813318113151306, 9.83459190023447, 8.97618002426757, 9.762833214554647, 10.627354559502695, 9.730420689550416, 12.782701681116185, 11.782107049920834, 10.861898358055575, 10.120946082298317, 10.863425467136512, 11.76681773889833, 12.63092225407457, 13.675033398394723, 14.633851634954613, 15.674539187152355, 15.544614105348577, 14.50742528324493, 13.659811883541195, 12.72904807565155, 11.78774773093918, 10.865018670803233, 9.947229571031396, 10.608371523609904, 9.668859066427737, 8.771152904143335, 11.870108580121745, 10.824352699026647, 9.92468699412236, 9.110374096922051, 9.844801667544703, 10.789175135866083, 11.69098720888042, 12.720620780904737, 13.704428751587631, 14.69055705292456, 15.647938124305938, 15.558653073347731, 14.645378066459958, 13.671384113412147, 12.78536853847548, 11.814707532615166, 10.7748056574706, 9.760572651001107, 8.740374983351435, 7.800409122923378, 10.88110541171351, 9.83190668437824, 8.946914204756013, 8.071691390284029, 8.859168275867496, 9.786350838193776, 10.716028727767295, 11.754868012586506, 12.708723640715467, 13.682193183241216, 14.70946717712084, 14.698849626080165, 13.732332893855354, 12.822880943670278, 11.865711438687603, 10.96105969359093, 9.929265816404376, 8.881397960714402, 7.838863433748992, 6.8934231852189525, 9.823830169027838, 8.824728408060452, 7.953864093615673, 7.122209613282249, 7.881620844293653, 8.831175051201582, 9.798981781311227, 10.808129346028439, 11.795698002806404, 12.76380408138808, 13.767679084828, 13.778663323994646, 12.76728910180233, 11.821667391284047, 10.845307279974563, 9.936266279847988, 8.91667052805916, 7.932231483479259, 6.93588414218521, 5.9352439789527525, 8.779638025549099, 7.8607321943938935, 6.936545359099454, 6.113922006083425, 6.915681368505543, 7.863928726209982, 8.845842045802724, 9.79900451444699, 10.753419440773794, 11.77763061290132, 12.849294427897204, 12.843980101269933, 11.82232698781853, 10.79803544127622, 9.866726921091765, 8.86575410620318, 7.842092356046315, 6.899266015671459, 5.894596517751238, 4.965530689226706, 7.849009393568739, 6.863652015996686, 5.911093264306176, 5.10496205296122, 5.882455205469958, 6.8221914668807555, 7.861663918009499, 8.842191561580098, 9.800475630016168, 10.860699370481761, 11.870449534283582, 11.892861497809632, 10.894706773524785, 9.956502138749672, 8.893158255123929, 7.873375071426753, 6.925955152107885, 5.941669561552609, 4.986423736506987, 3.9768777704416918, 6.9165907811763425, 5.909565468242507, 4.94303046742772, 4.115533204048588, 4.956631547054031, 5.938885155145755, 6.933306188480374, 7.868830093315804, 8.84909876088349, 9.872447189580747, 10.89036100641487, 11.881182856438695, 11.659870281540417, 10.733369503017983, 9.778628848008402, 8.851178961954819, 7.950868425910247, 7.008510374924961, 5.985624955304239, 4.944918498240402, 5.862848845342012, 4.85098615287116, 3.9955679756368343, 3.0687906654979282, 4.011659996170188, 4.992931004748556, 5.929220128558125, 6.960321577364211, 7.94954801879557, 8.879385854016778, 9.941660699727437, 10.877511762081484, 11.884854640888134, 11.726139212282336, 10.7771610017238, 9.849534032214592, 8.886270768463193, 7.905509094307852, 6.837844138450689, 5.8072105753124905, 4.852925576985342, 3.9061779829989893, 2.9587313127681836, 2.0293891932223627, 3.0226938946395223, 3.9510593609693414, 4.986800080741355, 5.910060776717245, 6.92905925453888, 7.973783383445682, 8.953726173011336, 9.912351274315231, 10.8847875191577, 11.855455051205967, 11.777574703002408, 10.827830953833628, 9.837053833715707, 8.772135743372704, 7.754465732330299, 6.753055240575964, 3.9646255802951553, 2.8963254294292944, 1.9025974038565618, 0.9729363059802487, 1.9996784010717397, 2.969212409673438, 3.9848117883283214, 4.9786891412423016, 5.95659422149207, 7.022147470776126, 7.964604024387564, 8.958132478808482, 9.876788833371915, 10.884781591579587, 11.847328172614532, 11.792106562802863, 10.790596868517959, 9.760725848314761, 8.74142895219692, 7.723863144709166, 3.0458934911904034, 1.9798574244497826, 0.9341117644223782, 0.0, 1.0556418389306244, 2.018984516990314, 2.9891187044587433, 3.9839178582425574, 4.999331708006684, 6.015109862339066, 6.947911739999304, 7.987611442230418, 8.951570710029362, 9.905780141356022, 10.951781254407276, 11.914028929467467, 11.557592845966004, 10.581485715842897, 9.647067461009803, 8.649221127120358, 3.963820925203724, 2.9922569082885975, 1.9192703991230724, 0.9325986087719893, 1.9374424419272767, 2.958905700798997, 3.934386912880922, 4.981085327206421, 5.930320431221597, 6.871092438159841, 7.915805762281333, 8.843650711698972, 9.86171055930248, 10.839020116951877, 11.79320728429435, 12.839110986655617, 12.50435121895809, 11.526532060085954, 10.628182215716762, 9.603705176268546, 4.943377307290171, 3.979869647088928, 2.9495440530000128, 2.0040922439962876, 2.9071774269183788, 3.8983555436133983, 4.855734119692077, 5.885944117953084, 6.850697129765702, 7.801052419052978, 8.84508129128304, 9.815319454713938, 10.77426492750717, 11.731310201845748, 12.667107389429823, 13.62480505003646, 13.435572529950408, 12.458403709963381, 11.554828401240647, 10.661276745329065, 5.923643701167288, 4.99601106497279, 3.933997024760392, 2.962756192496363, 3.923786551510797, 4.893632419661243, 5.85683407035959, 6.805843472111129, 7.826407162116732, 8.825161706152162, 9.876325646425943, 10.795694587573001, 11.824540636913113, 12.77623841670183, 13.63358036983317, 14.557853282032076, 14.449860509364052, 13.473027208134214, 12.517260533863572, 11.691495017415967, 6.799692081428523, 5.835260106516307, 4.867303987160587, 3.9357662614866027, 4.92975487912147, 5.947323400969113, 6.871318896347299, 7.802779590957167, 8.818719188484463, 9.795889237443474, 10.82286922813939, 11.763210140129633, 12.737554871571932, 13.77719845279054, 14.64617626104393, 15.516707814534412, 15.461716017353547, 14.47039076971366, 13.580623759175708, 12.7298883623112, 7.872264090442639, 6.852763199509737, 5.797105460565351, 4.952932605318964, 5.9110680080966125, 6.970667651224563, 7.803295032452354, 8.792529582525919, 9.8637024251143, 10.791853607593328, 11.77468355926796, 12.73227434423942, 13.712383177566705, 14.677066992152545, 15.58738392974567, 15.673046353601821, 15.126407111929025, 15.482341909905115, 14.630701549908332, 13.743447523247182, 8.708514111526783, 7.685522952039124, 6.748369638794882, 5.9479245051956235, 6.9115890974718575, 7.9144389146359035, 8.824291263016567, 9.732311101398007, 10.669352374646943, 11.605118958054913, 12.678136883083203, 13.661058639311747, 14.648667456592031, 15.634404323972353, 15.601029199522412, 14.739864772456347, 14.185742194828352, 15.008988318430266, 15.548571881077402, 14.595460093464723, 9.64455519561985, 8.632913459976457, 7.791335404684009, 7.009103985118659, 7.929107919702133, 8.851994647401739, 9.883520945363282, 10.69639268506501, 11.596931349250188, 12.56193007659775, 13.517793072921947, 14.567134620725597, 15.577370427886173, 15.506811201812061, 14.617917299734744, 13.765873142505647, 13.149423873219673, 13.972622189630266, 14.726172866172575, 15.547145741001573], [15.620702540318012, 14.632738579534184, 13.763455899455055, 12.703910314670356, 11.764392933072521, 12.698998665721973, 13.574150663451888, 14.540152155123794, 14.335873549065923, 13.39715879641421, 12.468419321890263, 11.587924059501093, 10.591422211272056, 9.793139760064703, 8.870933087955912, 8.035622673584946, 8.959416910766805, 9.725665453070363, 10.572378190193554, 11.526473823486992, 14.61823921317073, 13.68818276998427, 12.757966741569884, 11.81762093130781, 10.835238719565922, 11.758799339468045, 12.619374288564828, 13.647762939727313, 14.662600452142074, 14.32399587300311, 13.515446990678312, 12.522807527927645, 11.583744775170237, 10.727174967285903, 9.879189247987238, 9.00037929698356, 9.919464686489196, 10.706117876776272, 11.570639221724322, 10.673705351772043, 13.755745807708351, 12.755151176513, 11.78972626750634, 10.810684884507804, 9.889585494003724, 10.79297776576554, 11.65708228094178, 12.701193425261932, 13.660011661821823, 14.700699214019565, 14.506376242062107, 13.469187419958459, 12.621574020254725, 11.765602415166999, 10.853618865775113, 10.030806067552323, 10.890514233253022, 11.551656185831531, 10.612143728649365, 9.714437566364962, 12.84315270671391, 11.797396825618813, 10.852514903573127, 9.800112899131538, 8.870961694411914, 9.815335162733293, 10.71714723574763, 11.746780807771946, 12.730588778454841, 13.71671707979177, 14.674098151173148, 14.52041521006126, 13.607140203173488, 12.707938452927596, 11.888659737549267, 10.980494929364257, 11.718090319692227, 10.703857313222734, 9.683659645573062, 8.743693785145005, 11.854149538305675, 10.804950810970405, 9.879542873920407, 8.816023436434055, 7.885328302734708, 8.812510865060986, 9.742188754634505, 10.781028039453716, 11.730177945977118, 12.703647488502867, 13.705778665309738, 14.709061858798393, 14.550739410508081, 13.692512534646422, 12.886641979233044, 11.922805119956818, 10.891011242770265, 9.843143387080291, 8.800608860114881, 7.855168611584842, 10.815847565572295, 9.797772534652617, 8.915640087265356, 7.913122366326922, 6.907780871160864, 7.857335078068793, 8.825141808178438, 9.804440834217338, 10.792009490995303, 11.760115569576978, 12.763990573016898, 13.708185651948716, 13.822930940732952, 12.877309230214669, 11.900949118905185, 10.99190811877861, 9.972312366989785, 8.987873322409882, 7.991525981115834, 6.990885817883377, 9.773733180594864, 8.83377632098606, 7.898815529078498, 6.904834759128098, 5.941841395372754, 6.890088753077194, 7.872002072669936, 8.79531600263589, 9.749730928962693, 10.773942101090217, 11.845605916086102, 12.783002121429112, 12.877968826749152, 11.853677280206842, 10.922368760022387, 9.921395945133805, 8.89773419497694, 7.954907854602083, 6.950238356681862, 6.02117252815733, 8.874039541524603, 7.836696142588851, 6.873363434285221, 5.906562515526887, 4.908615232337169, 5.848351493747967, 6.88782394487671, 7.838503049768997, 8.796787118205067, 9.815747195221173, 10.825497359022993, 11.801694115240613, 11.950348612455407, 11.012143977680294, 9.948800094054551, 8.929016910357376, 7.981596991038509, 6.997311400483233, 6.042065575437611, 5.032519609372316, 7.941620929132206, 6.885315362093012, 5.905300637406764, 4.938449710180796, 3.982791573921242, 4.965045182012966, 5.931252754292653, 6.8651415815047026, 7.845410249072388, 8.824352116197797, 9.842265933031921, 10.825541017508069, 11.805114163149991, 11.789011341948605, 10.834270686939025, 9.906820800885441, 9.006510264840871, 8.064152213855584, 7.041266794234863, 6.000560337171026, 6.918490684272636, 5.906627991801784, 4.974765547433143, 3.9806893537096584, 3.0378200230373986, 3.9908775705608344, 4.9271666943704036, 5.910600054657941, 6.899826496089299, 7.829664331310508, 8.886018860796813, 9.821869923150858, 10.829212801957508, 11.734601621284279, 11.832802840654422, 10.905175871145214, 9.941912607393817, 8.961150933238475, 7.893485977381313, 6.862852414243115, 5.908567415915966, 4.9618198219296135, 4.014373151698808, 3.020682161887145, 1.9946423239203348, 2.9230077902501543, 3.9311582418107305, 4.854418937786621, 5.873417415608256, 6.918141544515058, 7.898084334080712, 8.856709435384605, 9.829145680227073, 10.79981321227534, 11.792185143785423, 11.883472792764252, 10.892695672646331, 9.827777582303328, 8.810107571260923, 7.808697079506588, 5.02026741922578, 3.951967268359919, 2.958239242787186, 1.998368925444043, 0.9716268303525522, 1.9135705707428134, 2.929169949397697, 3.923047302311678, 4.900952382561446, 5.966505631845502, 6.90896218545694, 7.902490639877857, 8.821146994441289, 9.829139752648961, 10.791686333683906, 11.746311100319257, 11.846238707448583, 10.816367687245387, 9.797070791127545, 8.779504983639791, 4.101535330121028, 3.035499263380407, 1.9897536033530026, 1.0556418389306244, 0.0, 0.9633426780596895, 1.9334768655281191, 2.9282760193119333, 3.94368986907606, 4.959468023408442, 5.89226990106868, 6.931969603299794, 7.895928871098737, 8.850138302425396, 9.89613941547665, 10.85838709053684, 11.909228699382867, 11.637127554773523, 10.702709299940429, 9.704862966050984, 5.019462764134348, 4.047898747219222, 2.9749122380536965, 1.9882404477026137, 1.0107301923648644, 1.920667837512525, 2.8787450739502978, 3.9254434882757976, 4.874678592290973, 5.815450599229217, 6.860163923350709, 7.788008872768349, 8.806068720371858, 9.783378278021251, 10.737565445363725, 11.783469147724992, 12.776488191553039, 12.58217389901658, 11.683824054647388, 10.659347015199172, 5.999019146220794, 5.035511486019552, 4.005185891930637, 2.9473769062179143, 1.9804651773559665, 2.860117680326926, 3.817496256405605, 4.847706254666612, 5.81245926647923, 6.745410580122354, 7.789439452352417, 8.759677615783316, 9.718623088576548, 10.675668362915125, 11.6114655504992, 12.569163211105838, 13.60878109415356, 13.514045548894007, 12.610470240171272, 11.716918584259691, 6.885389127533178, 5.939295727194417, 4.877281686982019, 3.9060408547179897, 2.997074301948384, 3.8579641998906116, 4.818596207073118, 5.767605608824657, 6.78816929883026, 7.769519867221539, 8.82068380749532, 9.740052748642379, 10.76889879798249, 11.720596577771207, 12.577938530902548, 13.502211443101453, 14.509316862058608, 14.52866904706484, 13.572902372794198, 12.747136856346593, 7.742976743650149, 6.778544768737933, 5.810588649382213, 4.879050923708229, 4.034505120704429, 4.911655181198482, 5.833081033060827, 6.764541727670695, 7.780481325197991, 8.757651374157001, 9.767227389208767, 10.70756830119901, 11.68191303264131, 12.721556613859917, 13.590534422113308, 14.46106597560379, 15.47256388525274, 15.526032608644286, 14.636265598106334, 13.785530201241826, 8.815548752664265, 7.796047861731362, 6.740390122786977, 5.896217267540591, 5.076855404845704, 5.96422504384339, 6.765057169165882, 7.754291719239448, 8.825464561827827, 9.753615744306856, 10.719041720337335, 11.676632505308797, 12.656741338636083, 13.621425153221923, 14.531742090815047, 14.69920638046903, 15.628599978791359, 16.53798374883574, 15.686343388838958, 14.799089362177808, 9.651798773748409, 8.628807614260749, 7.6916543010165075, 6.89120916741725, 6.077376494220948, 6.916269482488913, 7.786053399730095, 8.694073238111537, 9.631114511360472, 10.566881094768442, 11.639899019796733, 12.622820776025277, 13.610429593305561, 14.596166460685883, 14.627189226389621, 13.766024799323556, 14.727204405383882, 15.690689946421585, 16.521616007669568, 15.568504220056889, 10.587839857841475, 9.576198122198083, 8.734620066905634, 7.952388647340285, 7.094895316451224, 7.853825215254748, 8.84528308207681, 9.65815482177854, 10.558693485963717, 11.523692213311282, 12.479555209635478, 13.528896757439128, 14.539132564599704, 14.532971228679271, 13.644077326601954, 12.792033169372857, 13.744263315074564, 14.724570907583606, 15.699216992764741, 16.52018986759374], [16.55853948044303, 15.570575519659204, 14.701292839580075, 13.641747254795376, 12.702229873197542, 11.995613293983242, 12.81705726448045, 13.783058756152355, 13.372530871006234, 12.433816118354521, 11.505076643830574, 10.624581381441404, 9.628079533212366, 8.829797082005014, 7.9075904098962235, 8.864944745305824, 9.913959037106865, 10.680207579410423, 11.526920316533614, 12.481015949827052, 15.55607615329575, 14.62601971010929, 13.695803681694905, 12.75545787143283, 11.773075659690942, 11.055413967729313, 11.86228088959339, 12.888354777295808, 13.79274406685608, 13.36065319494342, 12.552104312618622, 11.559464849867956, 10.620402097110548, 9.763832289226213, 8.91584656992755, 9.829701368704438, 10.869637836875675, 11.660660003116332, 12.52518134806438, 11.628247478112101, 14.693582747833371, 13.69298811663802, 12.727563207631361, 11.748521824632824, 10.827422434128744, 10.089592394026809, 10.89998888197034, 11.941785262830427, 12.77056668130038, 13.798744143025, 13.543033564002418, 12.50584474189877, 11.658231342195036, 10.80225973710731, 9.890276187715425, 10.8601281392732, 11.840687383639501, 12.50619831217159, 11.566685854989423, 10.66897969270502, 13.78098964683893, 12.735233765743834, 11.790351843698147, 10.737949839256558, 9.808798634536934, 9.111949790994561, 9.960053836776192, 10.940004633104625, 11.795341060548253, 12.753796165754983, 13.711177237136361, 13.557072532001571, 12.643797525113799, 11.744595774867907, 10.92531705948958, 11.809817001085134, 12.672632446032285, 11.658399439562793, 10.63820177191312, 9.698235911485064, 12.791986478430696, 11.742787751095426, 10.817379814045427, 9.753860376559075, 8.823165242859728, 8.109125493322255, 8.985095355663066, 9.900783759146922, 10.766835267917429, 11.740304810443178, 12.74243598725005, 13.745719180738703, 13.587396732448392, 12.729169856586733, 11.97469125648058, 12.859804066173353, 11.845553369110325, 10.797685513420351, 9.755150986454941, 8.809710737924902, 11.753684505697315, 10.735609474777638, 9.853477027390376, 8.850959306451943, 7.8456178112858845, 7.095779590158939, 8.023380005284839, 8.84109815615765, 9.828666812935614, 10.79677289151729, 11.800647894957208, 12.744842973889027, 13.756217196081343, 13.730383408972965, 12.864291796964874, 11.9552507968383, 10.935655045049474, 9.951216000469573, 8.954868659175524, 7.954228495943066, 10.711570120719884, 9.77161326111108, 8.83665246920352, 7.842671699253119, 6.879678335497775, 6.12853326516734, 7.046591349455515, 7.8319733245762, 8.786388250903004, 9.810599423030528, 10.882263238026413, 11.819659443369423, 12.821769526309842, 12.817019958266531, 11.885711438082076, 10.884738623193494, 9.861076873036628, 8.918250532661773, 7.913581034741552, 6.9845152062170195, 9.811876481649625, 8.774533082713871, 7.811200374410242, 6.844399455651907, 5.84645217246219, 5.086796005838114, 5.984671514623504, 6.875160371709308, 7.833444440145378, 8.852404517161483, 9.862154680963304, 10.838351437180924, 11.83650616146577, 11.975486655739983, 10.91214277211424, 9.892359588417065, 8.944939669098197, 7.960654078542922, 7.005408253497301, 5.995862287432005, 8.879457869257228, 7.823152302218033, 6.8431375775317855, 5.8762866503058175, 4.920628514046263, 4.050225177074074, 5.004671391031078, 5.901798903445013, 6.882067571012699, 7.861009438138108, 8.878923254972232, 9.862198339448382, 10.841771485090304, 11.764028652488943, 11.797613364998714, 10.87016347894513, 9.969852942900559, 9.027494891915273, 8.004609472294552, 6.9639030152307155, 7.881833362332325, 6.869970669861473, 5.912602487558164, 4.91852629383468, 3.97565696316242, 3.0719835780262166, 4.000585331108828, 4.947257376598252, 5.93648381802961, 6.866321653250819, 7.922676182737123, 8.858527245091171, 9.865870123897821, 10.77125894322459, 11.77267928135388, 11.868518549204904, 10.905255285453508, 9.924493611298166, 8.856828655441003, 7.826195092302804, 6.871910093975655, 5.925162499989303, 4.977715829758497, 3.958519102012166, 2.932479264045356, 2.0041137977155365, 2.967815563751041, 3.8910762597269315, 4.910074737548567, 5.954798866455369, 6.934741656021023, 7.893366757324917, 8.865803002167384, 9.836470534215652, 10.828842465725733, 11.778586214894514, 11.85603835070602, 10.791120260363018, 9.773450249320613, 8.772039757566278, 5.983610097285469, 4.915309946419608, 3.9215819208468754, 2.9617116035037325, 1.9349695084122418, 0.950227892683124, 1.9658272713380074, 2.959704624251988, 3.937609704501756, 5.003162953785813, 5.945619507397251, 6.9391479618181675, 7.857804316381601, 8.865797074589272, 9.828343655624217, 10.782968422259568, 11.784478116544472, 11.779710365305077, 10.760413469187235, 9.74284766169948, 5.064878008180717, 3.998841941440096, 2.9530962814126918, 2.018984516990314, 0.9633426780596895, 0.0, 0.9701341874684296, 1.9649333412522436, 2.9803471910163704, 3.9961253453487524, 4.928927223008991, 5.9686269252401045, 6.9325861930390476, 7.886795624365707, 8.932796737416961, 9.895044412477151, 10.945886021323178, 11.921993151446285, 11.666051978000118, 10.668205644110673, 5.982805442194037, 5.011241425278911, 3.9382549161133857, 2.951583125762303, 1.9740728704245538, 0.9573251594528356, 1.9154023958906083, 2.962100810216108, 3.9113359142312834, 4.8521079211695275, 5.89682124529102, 6.8246661947086595, 7.842726042312169, 8.820035599961562, 9.774222767304035, 10.820126469665302, 11.81314551349335, 12.867039495689342, 12.647166732707078, 11.622689693258861, 6.9623618242804834, 5.998854164079241, 4.968528569990326, 3.9019190325579745, 2.9350073036960267, 1.8967750022672365, 2.8541535783459153, 3.8843635766069227, 4.849116588419541, 5.782067902062665, 6.826096774292727, 7.796334937723627, 8.755280410516859, 9.712325684855436, 10.648122872439512, 11.605820533046149, 12.64543841609387, 13.705822850565161, 13.573812918230962, 12.68026126231938, 7.839931253873238, 6.893837853534477, 5.831823813322079, 4.86058298105805, 3.8644673899813675, 2.894621521830922, 3.855253529013429, 4.804262930764968, 5.824826620770571, 6.80617718916185, 7.85734112943563, 8.77671007058269, 9.805556119922802, 10.757253899711518, 11.614595852842859, 12.538868765041764, 13.545974183998919, 14.58443136581279, 14.536245050853887, 13.710479534406282, 8.697518869990208, 7.733086895077993, 6.765130775722273, 5.8335930500482895, 4.901898208737412, 3.9483125031387925, 4.869738355001138, 5.8011990496110055, 6.817138647138302, 7.794308696097312, 8.803884711149077, 9.744225623139322, 10.71857035458162, 11.758213935800228, 12.627191744053619, 13.4977232975441, 14.50922120719305, 15.500546454832937, 15.599608276166023, 14.748872879301516, 9.770090879004323, 8.750589988071422, 7.694932249127037, 6.850759393880651, 5.944248492878687, 5.000882365783701, 5.801714491106193, 6.790949041179759, 7.862121883768139, 8.790273066247169, 9.755699042277646, 10.713289827249108, 11.693398660576394, 12.658082475162233, 13.568399412755358, 14.513778491525134, 15.443172089847462, 16.37280840032877, 16.64968606689865, 15.762432040237497, 10.606340900088469, 9.58334974060081, 8.646196427356568, 7.84575129375731, 6.944769582253931, 5.952926804429223, 6.822710721670406, 7.730730560051848, 8.667771833300783, 9.603538416708753, 10.676556341737044, 11.659478097965588, 12.647086915245872, 13.632823782626193, 13.92380385465089, 14.703861739448577, 15.665041345508902, 16.628526886546606, 17.459452947794585, 16.506341160181908, 11.542381984181535, 10.530740248538143, 9.689162193245695, 8.906930773680346, 7.924217388172101, 6.890482537195059, 7.88194040401712, 8.69481214371885, 9.595350807904028, 10.560349535251593, 11.516212531575789, 12.565554079379439, 13.575789886540015, 13.775877829707833, 12.940691954863222, 13.729870109497877, 14.682100255199584, 15.662407847708627, 16.63705393288976, 17.458026807718756], [17.528673667911463, 16.540709707127633, 15.671427027048505, 14.611881442263806, 13.672364060665972, 12.883647775782212, 11.902572478064858, 12.868573969736763, 12.406627646695547, 11.467912894043835, 10.539173419519887, 9.65867815713072, 8.662176308901682, 7.863893857694327, 8.754424280101505, 9.711778615511106, 10.763192070198192, 11.629061507257095, 12.475774244380286, 13.429869877673724, 16.52621034076418, 15.59615389757772, 14.665937869163335, 13.72559205890126, 12.743209847159372, 11.945423174458822, 10.947796103177797, 11.91822058982738, 12.822609879387649, 12.394749970632734, 11.586201088307938, 10.593561625557271, 9.654498872799863, 8.797929064915527, 9.748575199548618, 10.67653523890972, 11.716471707080958, 12.609513930963004, 13.474035275911055, 12.577101405958775, 15.663716935301801, 14.66312230410645, 13.697697395099793, 12.718656012101254, 11.797556621597174, 10.979601600756318, 9.985504095554749, 10.971651075361999, 11.800432493831948, 12.828609955556571, 12.577130339691733, 11.539941517588085, 10.692328117884351, 9.836356512796623, 10.723004817336493, 11.706962009478483, 12.687521253844784, 13.455052240018263, 12.515539782836097, 11.617833620551695, 14.75112383430736, 13.705367953212264, 12.760486031166579, 11.708084026724988, 10.778932822005364, 10.00195899772407, 9.0455690503606, 9.969870445636197, 10.825206873079821, 11.783661978286553, 12.74104304966793, 12.591169307690887, 11.677894300803114, 10.77869255055722, 11.751195978719556, 12.656650871290417, 13.621486373878959, 12.607253367409466, 11.587055699759794, 10.647089839331738, 13.762120665899126, 12.712921938563856, 11.787514001513857, 10.723994564027505, 9.793299430328158, 9.000288458820993, 8.070610569247474, 8.930649571678492, 9.796701080449, 10.770170622974748, 11.772301799781621, 12.775584993270275, 12.621493508137707, 11.763266632276046, 12.757859898629597, 13.706637936378636, 12.794407296956999, 11.746539441267025, 10.704004914301615, 9.758564665771576, 12.723818693165745, 11.705743662246068, 10.823611214858806, 9.821093493920372, 8.815751998754314, 8.04618568063553, 7.108895218869247, 7.870963968689219, 8.858532625467184, 9.826638704048861, 10.83051370748878, 11.774708786420598, 12.786083008612914, 12.764480184662279, 13.740840295971763, 12.925384984306728, 11.905789232517902, 10.921350187938001, 9.925002846643952, 8.924362683411495, 11.681704308188314, 10.74174744857951, 9.806786656671948, 8.812805886721549, 7.849812522966205, 7.07893935564393, 6.1321065630399225, 6.86183913710777, 7.816254063434574, 8.8404652355621, 9.912129050557985, 10.849525255900993, 11.851635338841412, 12.784417252540132, 12.855845625550506, 11.854872810661922, 10.831211060505057, 9.888384720130201, 8.88371522220998, 7.954649393685449, 10.782010669118053, 9.744667270182301, 8.781334561878671, 7.814533643120337, 6.81658635993062, 6.037202096314704, 5.070186728207913, 5.905026184240878, 6.863310252676948, 7.882270329693054, 8.892020493494874, 9.868217249712494, 10.86637197399734, 11.758177723387021, 11.88227695958267, 10.862493775885495, 9.915073856566627, 8.930788266011351, 7.9755424409657305, 6.965996474900435, 9.849592056725657, 8.793286489686462, 7.813271765000215, 6.846420837774247, 5.890762701514692, 5.000631267550665, 4.090186604615487, 4.931664715976583, 5.911933383544269, 6.890875250669678, 7.908789067503803, 8.892064151979952, 9.871637297621874, 10.793894465020513, 11.748635120030093, 11.84029766641356, 10.939987130368989, 9.997629079383703, 8.974743659762982, 7.9340372026991455, 8.851967549800754, 7.840104857329903, 6.882736675026593, 5.888660481303109, 4.945791150630849, 4.022389668502806, 3.0861005446932372, 3.9771231891298218, 4.96634963056118, 5.896187465782389, 6.952541995268693, 7.888393057622741, 8.895735936429391, 9.80112475575616, 10.802545093885453, 11.73017206339466, 11.875389472921938, 10.894627798766596, 9.826962842909433, 8.796329279771234, 7.842044281444085, 6.895296687457733, 5.947850017226927, 4.928653289480595, 3.902613451513785, 2.974247985183966, 2.0533307773354497, 2.920942072258502, 3.939940550080138, 4.98466467898694, 5.964607468552593, 6.923232569856487, 7.895668814698954, 8.866336346747222, 9.858708278257303, 10.808452027426082, 11.767886963878293, 11.761254447831448, 10.743584436789043, 9.742173945034708, 6.953744284753899, 5.885444133888038, 4.891716108315306, 3.9318457909721625, 2.9051036958806713, 1.9203620801515537, 1.0513424849224162, 1.9895704367835587, 2.9674755170333267, 4.033028766317383, 4.975485319928821, 5.969013774349738, 6.887670128913171, 7.895662887120842, 8.858209468155787, 9.812834234791138, 10.814343929076042, 11.84870831602862, 11.730547656655663, 10.71298184916791, 6.035012195649147, 4.968976128908526, 3.9232304688811217, 2.9891187044587433, 1.9334768655281191, 0.9701341874684296, 0.0, 0.9947991537838141, 2.010213003547941, 3.0259911578803225, 3.9587930355405607, 4.998492737771675, 5.962452005570618, 6.916661436897277, 7.962662549948531, 8.924910225008722, 9.975751833854748, 10.951858963977855, 11.88627721881095, 11.638339831579103, 6.952939629662467, 5.981375612747341, 4.908389103581816, 3.9217173132307326, 2.9442070578929833, 1.9274593469212653, 0.9452682084221787, 1.9919666227476784, 2.941201726762854, 3.881973733701098, 4.92668705782259, 5.85453200724023, 6.872591854843739, 7.849901412493132, 8.804088579835605, 9.849992282196872, 10.843011326024918, 11.896905308220912, 12.88957461445293, 12.592823880727291, 7.932496011748913, 6.964856977423713, 5.924220204868021, 4.850772960404647, 3.883861231542699, 2.8456289301139086, 1.8882503540352298, 2.918460352296237, 3.883213364108855, 4.811933714594236, 5.8559625868242975, 6.826200750255197, 7.785146223048428, 8.742191497387005, 9.67798868497108, 10.635686345577717, 11.67530422862544, 12.73568866309673, 13.685136685386533, 13.65039544978781, 8.788785181719911, 7.842691781381149, 6.780677741168751, 5.809436908904722, 4.81332131782804, 3.843475449677594, 2.8893503047027433, 3.8383597064542827, 4.858923396459885, 5.836043001693421, 6.887206941967201, 7.80657588311426, 8.83542193245437, 9.787119712243086, 10.644461665374427, 11.568734577573332, 12.575839996530487, 13.614297178344358, 14.647568818009459, 14.680613721874714, 9.646372797836882, 8.681940822924666, 7.713984703568945, 6.782446977894962, 5.850752136584084, 4.897166430985465, 3.903835130690452, 4.835295825300321, 5.851235422827616, 6.828405471786627, 7.8337505236806475, 8.774091435670893, 9.748436167113192, 10.7880797483318, 11.657057556585187, 12.527589110075668, 13.539087019724619, 14.530412267364506, 15.535777910302892, 15.719007066769947, 10.718944806850997, 9.699443915918096, 8.643786176973709, 7.799613321727323, 6.893102420725359, 5.8973637870535915, 4.835811266795507, 5.825045816869074, 6.896218659457454, 7.824369841936483, 8.785564854809216, 9.74315563978068, 10.723264473107966, 11.687948287693805, 12.598265225286926, 13.543644304056702, 14.47303790237903, 15.402674212860335, 16.39171944718734, 16.732566227705927, 11.555194827935141, 10.532203668447481, 9.59505035520324, 8.794605221603982, 7.802610491798552, 6.799760674634505, 5.85680749735972, 6.764827335741163, 7.7018686089900985, 8.637635192398069, 9.710653117426359, 10.693574873654903, 11.681183690935187, 12.666920558315509, 13.609122586476692, 14.476825885202176, 15.413702819479703, 16.37718836051741, 17.326213455807373, 17.47647534765034, 12.491235912028207, 11.479594176384815, 10.638016121092367, 9.845859496778763, 8.771051258377383, 7.73731640740034, 6.916037179706435, 7.728908919408166, 8.629447583593343, 9.594446310940906, 10.550309307265103, 11.599650855068752, 12.609886662229329, 12.86139304329224, 13.815012653512442, 14.70000429696631, 15.652234442668014, 16.632542035177057, 17.607188120358188, 18.428160995187188], [18.41863984926028, 17.430675888476454, 16.561393208397327, 15.501847623612628, 14.562330242014793, 13.665850638194925, 12.684775340477572, 11.99262463433421, 11.55636742834536, 10.617652675693648, 9.6889132011697, 8.808417938780533, 7.811916090551494, 8.82177356211467, 9.749223433885318, 10.706577769294919, 11.757991223982005, 12.623860661040908, 13.470573398164099, 14.424669031457537, 17.416176522113, 16.48612007892654, 15.555904050512156, 14.615558240250081, 13.633176028508194, 12.727626036871536, 11.72999896559051, 10.923421436043563, 11.827810725603836, 11.544489752282548, 10.735940869957751, 9.743301407207085, 8.804238654449675, 9.75580876933587, 10.706454903968961, 11.671334392693533, 12.71127086086477, 13.604313084746817, 14.468834429694867, 13.571900559742588, 16.55368311665062, 15.55308848545527, 14.587663576448614, 13.608622193450076, 12.687522802945995, 11.761804463169032, 10.767706957967462, 9.976851921578183, 10.805633340048136, 11.833810801772756, 11.726870121341546, 10.689681299237899, 9.842067899534163, 10.794236217216966, 11.680884521756836, 12.701761163262296, 13.682320407628596, 14.449851393802076, 13.51033893661991, 12.612632774335507, 15.64109001565618, 14.595334134561083, 13.6504522125154, 12.59805020807381, 11.668899003354186, 10.784161860136784, 9.827771912773313, 8.97507129185238, 9.830407719296009, 10.788862824502738, 11.746243895884117, 11.7409090893407, 10.827634082452926, 11.736572254977563, 12.709075683139899, 13.65145002507423, 14.616285527662772, 13.60205252119328, 12.581854853543607, 11.64188899311555, 14.652086847247945, 13.602888119912675, 12.677480182862679, 11.613960745376326, 10.68326561167698, 9.782491321233707, 8.852813431660188, 7.935850417894677, 8.801901926665185, 9.775371469190933, 10.777502645997805, 11.780785839486459, 11.771233289787519, 12.711967151369985, 13.706560417723535, 14.670397276999761, 13.78920645074081, 12.741338595050836, 11.698804068085426, 10.753363819555387, 13.613784874514565, 12.595709843594888, 11.713577396207626, 10.711059675269192, 9.705718180103135, 8.858904811391605, 7.89109808128196, 6.876164814905405, 7.86373347168337, 8.831839550265045, 9.835714553704964, 10.779909632636782, 11.791283854829098, 12.775881391067587, 13.699506977823573, 13.920184138090544, 12.900588386301719, 11.916149341721818, 10.919802000427769, 9.919161837195311, 12.571670489537134, 11.63171362992833, 10.696752838020767, 9.702772068070368, 8.739778704315025, 7.896222745045378, 6.914309425452636, 5.867039983323956, 6.821454909650759, 7.845666081778284, 8.917329896774168, 9.854726102117178, 10.856836185057597, 11.78961809875632, 12.720926618940775, 12.849671964445738, 11.826010214288873, 10.883183873914017, 9.878514375993797, 8.949448547469265, 11.671976850466873, 10.634633451531121, 9.67130074322749, 8.704499824469156, 7.706552541279439, 6.869298751213199, 5.852389590620626, 4.910227030457063, 5.8685110988931335, 6.88747117590924, 7.89722133971106, 8.87341809592868, 9.871572820213526, 10.763378569603208, 11.748327950670747, 11.85729292966931, 10.909873010350442, 9.925587419795166, 8.970341594749545, 7.96079562868425, 10.739558238074476, 9.683252671035282, 8.703237946349034, 7.736387019123066, 6.780728882863512, 5.832727922449159, 4.872389467028199, 3.9368655621927693, 4.917134229760454, 5.896076096885864, 6.9139899137199885, 7.897264998196137, 8.876838143838059, 9.799095311236698, 10.753835966246278, 11.681285852299862, 11.934786284152803, 10.992428233167518, 9.969542813546795, 8.92883635648296, 9.829400747892803, 8.773324758029052, 7.772702856375413, 6.778626662651929, 5.835757331979669, 4.854486323401301, 3.9181971995917317, 2.9823240353460077, 3.9715504767773657, 4.901388311998574, 5.957742841484879, 6.8935939038389265, 7.900936782645577, 8.806325601972345, 9.807745940101636, 10.735372909610843, 11.745298022666006, 11.88942695255041, 10.821761996693247, 9.791128433555048, 8.8368434352279, 7.890095841241547, 6.942649171010742, 5.914659034274418, 4.888619196307609, 3.9602537299777896, 2.8854274322339446, 1.9261429184746879, 2.9451413962963233, 3.9898655252031254, 4.969808314768779, 5.928433416072673, 6.9008696609151405, 7.871537192963408, 8.863909124473489, 9.813652873642269, 10.773087810094479, 11.838005900437482, 11.738383590572857, 10.736973098818522, 7.948543438537714, 6.880243287671853, 5.88651526209912, 4.926644944755976, 3.8999028496644854, 2.9151612339353674, 2.045378121329726, 0.9947712829997445, 1.9726763632495126, 3.038229612533569, 3.9806861661450075, 4.974214620565924, 5.892870975129357, 6.900863733337029, 7.863410314371973, 8.818035081007324, 9.819544775292227, 10.853909162244806, 11.873206058362648, 11.707781002951725, 7.029811349432961, 5.963775282692341, 4.918029622664936, 3.983917858242558, 2.9282760193119333, 1.9649333412522436, 0.9947991537838141, 0.0, 1.0154138497641267, 2.031192004096509, 2.963993881756747, 4.003693583987861, 4.967652851786804, 5.921862283113463, 6.967863396164717, 7.930111071224908, 8.980952680070935, 9.957059810194043, 10.891478065027137, 11.889324398916582, 7.947738783446281, 6.976174766531155, 5.90318825736563, 4.916516467014548, 3.939006211676798, 2.9222585007050794, 1.9400673622059927, 0.9971674689638642, 1.9464025729790397, 2.887174579917284, 3.9318879040387764, 4.859732853456416, 5.877792701059925, 6.8551022587093176, 7.809289426051791, 8.85519312841306, 9.848212172241105, 10.9021061544371, 11.894775460669118, 12.84380844806477, 8.927295165532728, 7.959656131207526, 6.919019358651834, 5.845572114188459, 4.878660385326512, 3.8404280838977223, 2.8830495078190435, 2.02301096665915, 2.9739194282745762, 3.8171345608104215, 4.861163433040484, 5.831401596471383, 6.790347069264614, 7.747392343603191, 8.683189531187267, 9.640887191793905, 10.680505074841626, 11.740889509312916, 12.69033753160272, 13.6231342364259, 9.783584335503722, 8.837490935164961, 7.775476894952564, 6.804236062688535, 5.808120471611853, 4.838274603461407, 3.884149458486557, 2.9880994881040968, 3.949629460625606, 4.841243847909606, 5.8924077881833865, 6.811776729330447, 7.840622778670556, 8.792320558459274, 9.649662511590614, 10.57393542378952, 11.581040842746674, 12.619498024560546, 13.652769664225646, 14.611252775247124, 10.641171951620695, 9.676739976708479, 8.708783857352758, 7.777246131678774, 6.845551290367898, 5.891965584769277, 4.898634284474266, 3.9850356069501345, 4.941941486993337, 5.892062616164964, 6.838951369896833, 7.779292281887079, 8.753637013329378, 9.793280594547985, 10.662258402801374, 11.532789956291856, 12.544287865940806, 13.535613113580693, 14.54097875651908, 15.568457295301073, 11.71374396063481, 10.694243069701908, 9.638585330757522, 8.794412475511136, 7.887901574509174, 6.892162940837405, 5.830610420579321, 4.974785598518888, 6.010170451281667, 6.938321633760696, 7.790765701025403, 8.748356485996865, 9.728465319324151, 10.69314913390999, 11.603466071503114, 12.54884515027289, 13.478238748595217, 14.407875059076522, 15.396920293403529, 16.331594721969395, 12.549993981718954, 11.527002822231294, 10.589849508987053, 9.789404375387795, 8.797409645582364, 7.794559828418318, 6.851606651143534, 5.914567117390977, 6.851608390639912, 7.787374974047882, 8.779597147287962, 9.753860180287003, 10.689128125229274, 11.674864992609596, 12.61432343269288, 13.482026731418363, 14.41890366569589, 15.382389206733594, 16.33141430202356, 17.284526089636238, 13.48603506581202, 12.474393330168628, 11.63281527487618, 10.840658650562576, 9.765850412161196, 8.732115561184154, 7.9108363334902485, 6.87864870105798, 7.779187365243156, 8.74418609259072, 9.700049088914916, 10.749390636718566, 11.617831096523418, 12.673737071514095, 13.597435332480547, 14.456018361369063, 15.455221987304569, 16.418755335533593, 17.303252336771177, 18.236211737173086], [18.221840573905553, 17.354316900237606, 16.426092566635294, 15.407762129503105, 14.46824474790527, 13.476836014960297, 12.495760717242943, 11.529759225571038, 10.716798763098835, 9.778084010447122, 8.93231804579556, 8.08146573935535, 8.827329940315622, 9.837187411878798, 10.764637283649446, 11.721991619059047, 12.773405073746133, 13.639274510805036, 14.485987247928227, 15.440082881221665, 17.21937724675827, 17.501533928690666, 16.57131790027628, 15.630972090014208, 14.64858987827232, 13.743039886635662, 12.745412815354637, 11.868322022683612, 10.985111657214041, 10.70492108703602, 10.002202874841098, 9.016349207781902, 9.819652504213803, 10.771222619099998, 11.721868753733089, 12.68674824245766, 13.726684710628899, 14.619726934510945, 15.484248279458996, 14.587314409506716, 16.388752536266153, 16.568502335219396, 15.60307742621274, 14.624036043214202, 13.702936652710122, 12.777218312933158, 11.783120807731589, 10.921752508218232, 9.962934271658341, 10.991111733382962, 10.999917921916364, 9.962729099812716, 10.857481749298291, 11.809650066981094, 12.696298371520964, 13.717175013026424, 14.697734257392725, 15.465265243566204, 14.525752786384038, 13.628046624099635, 15.59239750573093, 15.61074798432521, 14.665866062279527, 13.613464057837936, 12.684312853118312, 11.79957570990091, 10.84318576253744, 9.952279360362056, 8.987708650906214, 9.946163756112943, 10.89237520574929, 11.013956889915518, 11.843047932217054, 12.751986104741691, 13.724489532904027, 14.666863874838358, 15.6316993774269, 14.617466370957407, 13.597268703307735, 12.657302842879679, 14.616135029691282, 14.618301969676802, 13.692894032626805, 12.629374595140453, 11.698679461441106, 10.797905170997833, 9.868227281424314, 8.913058486404351, 7.95920285827539, 8.932672400801138, 9.919712792594677, 10.846095472197083, 11.793623345409054, 12.73435720699152, 13.704497286772487, 14.668334146048712, 14.804620300504938, 13.756752444814964, 12.714217917849554, 11.768777669319515, 13.554025298042955, 13.611123693359014, 12.728991245971752, 11.726473525033319, 10.721132029867261, 9.874318661155732, 8.906511931046087, 7.891578664669532, 7.021034403293575, 7.974049696861917, 8.977924700301836, 9.834672633016972, 10.82857955335603, 11.81317708959452, 12.684093128059446, 13.627251174334335, 13.916002236065845, 12.931563191485944, 11.935215850191895, 10.934575686959437, 12.756569991220045, 12.647127479692456, 11.712166687784894, 10.718185917834495, 9.755192554079152, 8.911636594809504, 7.929723275216762, 6.882453833088083, 5.978755841260964, 6.987876228375155, 8.05954004337104, 8.889284018962432, 9.88361743937223, 10.774204248992193, 11.705512769176648, 12.713758268984847, 12.841424064053, 11.898597723678144, 10.893928225757923, 9.964862397233391, 11.825941359239685, 11.650047301295247, 10.686714592991617, 9.719913674233283, 8.721966391043566, 7.884712600977325, 6.867803440384752, 5.925640880221191, 5.025812030503338, 5.993239939511599, 7.00299010331342, 7.907976012773933, 8.898354074528159, 9.747964719839082, 10.732914100906621, 11.6436758930638, 11.925286860114568, 10.941001269559292, 9.985755444513671, 8.976209478448377, 11.754972087838603, 10.698666520799408, 9.71865179611316, 8.751800868887193, 7.796142732627639, 6.848141772213285, 5.887803316792326, 4.952279411956896, 4.023703780849966, 5.001844860488223, 6.019758677322348, 6.881851148432011, 7.861424294073932, 8.783681461472572, 9.738422116482152, 10.665872002535735, 11.599885813949987, 12.007842082931644, 10.984956663310923, 9.944250206247087, 10.84481459765693, 9.788738607793178, 8.78811670613954, 7.794040512416056, 6.851171181743796, 5.869900173165428, 4.933611049355859, 3.9977378851101344, 3.0773192403797247, 4.007157075600934, 4.976269176026835, 5.8781800540748, 6.885522932881451, 7.790911752208219, 8.79233209033751, 9.719959059846717, 10.72988417290188, 11.710645847057222, 11.837175846457376, 10.806542283319176, 9.852257284992028, 8.905509691005674, 7.958063020774868, 6.930072884038546, 5.904033046071736, 4.975667579741916, 3.900841281998072, 2.9415567682388146, 2.0232972093760635, 3.0083918597450814, 3.988334649310735, 4.913019566308546, 5.885455811151014, 6.856123343199282, 7.848495274709363, 8.798239023878143, 9.757673960330353, 10.822592050673356, 11.84026206171576, 11.75238694858265, 8.96395728830184, 7.895657137435979, 6.901929111863247, 5.942058794520102, 4.915316699428612, 3.9305750836994946, 3.060791971093853, 2.0101851327638713, 0.9572625134853857, 2.0228157627694423, 2.9652723163808803, 3.9588007708017967, 4.877457125365231, 5.885449883572902, 6.847996464607847, 7.802621231243198, 8.804130925528101, 9.83849531248068, 10.857792208598521, 11.799268531563646, 8.045225199197088, 6.979189132456467, 5.933443472429063, 4.999331708006684, 3.94368986907606, 2.9803471910163704, 2.010213003547941, 1.0154138497641267, 0.0, 1.0157781543323818, 1.9485800319926203, 2.9882797342237346, 3.9522390020226776, 4.906448433349337, 5.952449546400591, 6.914697221460782, 7.965538830306808, 8.941645960429915, 9.876064215263009, 10.873910549152454, 8.963152633210408, 7.991588616295282, 6.9186021071297565, 5.931930316778674, 4.954420061440924, 3.9376723504692057, 2.9554812119701195, 2.012581318727991, 1.0694198690490182, 2.010191875987262, 2.9164740542746497, 3.8443190036922896, 4.862378851295799, 5.839688408945191, 6.793875576287665, 7.839779278648932, 8.832798322476979, 9.886692304672971, 10.87936161090499, 11.828394598300642, 9.942709015296854, 8.975069980971654, 7.934433208415961, 6.8609859639525865, 5.894074235090639, 4.855841933661849, 3.8984633575831706, 3.0384248164232766, 2.096936724344555, 2.9401518568803997, 3.845749583276357, 4.815987746707257, 5.774933219500488, 6.7319784938390645, 7.66777568142314, 8.625473342029776, 9.665091225077498, 10.725475659548788, 11.674923681838592, 12.607720386661772, 10.79899818526785, 9.85290478492909, 8.790890744716691, 7.819649912452662, 6.8235343213759805, 5.853688453225534, 4.899563308250684, 4.003513337868223, 3.0726467566955846, 3.9642611439795843, 4.907609619703335, 5.7963628795663205, 6.82520892890643, 7.776906708695146, 8.634248661826486, 9.558521574025391, 10.565626992982546, 11.604084174796418, 12.637355814461518, 13.595838925482996, 11.656585801384823, 10.692153826472607, 9.724197707116886, 8.7926599814429, 7.860965140132025, 6.907379434533405, 5.914048134238393, 5.000449456714261, 4.064958783063316, 5.015079912234942, 5.854153201416781, 6.763878432122953, 7.738223163565252, 8.777866744783859, 9.646844553037246, 10.517376106527728, 11.528874016176678, 12.520199263816565, 13.525564906754951, 14.553043445536945, 12.729157810398938, 11.709656919466035, 10.65399918052165, 9.809826325275262, 8.9033154242733, 7.907576790601532, 6.846024270343448, 5.990199448283014, 5.133187747351645, 6.061338929830674, 6.805967532545351, 7.732942636232739, 8.713051469560025, 9.677735284145864, 10.588052221738986, 11.533431300508761, 12.462824898831089, 13.392461209312394, 14.3815064436394, 15.316180872205265, 13.565407831483082, 12.542416671995422, 11.60526335875118, 10.804818225151921, 9.812823495346493, 8.809973678182446, 7.867020500907661, 6.929980967155103, 6.124656191214729, 7.030779818673739, 7.79479897880791, 8.738446330522876, 9.673714275465148, 10.65945114284547, 11.598909582928751, 12.466612881654235, 13.403489815931762, 14.366975356969466, 15.316000452259432, 16.26911223987211, 14.501448915576148, 13.489807179932756, 12.648229124640308, 11.856072500326704, 10.781264261925324, 9.747529410948282, 8.926250183254375, 7.894062550822106, 7.052235165817973, 7.987590937216578, 8.741117049559461, 9.79045859736311, 10.602417246759291, 11.658323221749969, 12.582021482716419, 13.440604511604935, 14.43980813754044, 15.403341485769465, 16.28783848700705, 17.22079788740896], [17.20606241957317, 16.338538745905222, 15.41031441230291, 14.391983975170724, 13.45246659357289, 12.461057860627912, 11.479982562910559, 10.513981071238653, 9.701020608766454, 8.762305856114741, 7.93611177994431, 8.893543842703417, 9.707745811240098, 10.717603282803275, 11.646908928009061, 12.604263263418662, 13.655676718105749, 14.61840520155918, 15.477388413123954, 16.431484046417392, 16.203599092425886, 17.133655535612345, 16.299999828981267, 15.359654018719194, 14.38162080707949, 13.40125718688184, 12.43475893779762, 11.583184269529301, 10.64078455811302, 9.68914293270364, 9.005996608989848, 9.82842731112997, 10.70006837513828, 11.651638490024474, 12.602284624657566, 13.569019886817276, 14.608956354988514, 15.598857625265088, 16.47564944465472, 15.578715574702443, 15.37297438193377, 16.37356901312912, 16.54425185420983, 15.565210471211293, 14.644111080707212, 13.691984469047243, 12.697886963845674, 11.78482562787156, 10.82600739131167, 10.003156210275792, 10.062858878604645, 10.774807203160783, 11.737897620222768, 12.69006593790557, 13.57671424244544, 14.59944665738604, 15.58000590175234, 16.456666408761933, 15.517153951579765, 14.619447789295362, 14.576619351398547, 15.555946465596445, 15.607040490276617, 14.554638485835026, 13.625487281115403, 12.714341866014996, 11.757951918651525, 10.815352480015385, 9.850781770559543, 8.958208233005774, 9.895772654960203, 10.765864277713018, 11.721444398411265, 12.697183903341715, 13.66968733150405, 14.640348337364363, 15.653495930877535, 15.608867536153134, 14.588669868503462, 13.648704008075406, 13.6003568753589, 14.563500450948037, 14.634068460623896, 13.570549023137543, 12.639853889438196, 11.712671327111918, 10.7829934375384, 9.77613160605768, 8.822275977928719, 7.944716877693969, 8.923110241805588, 9.830317317864703, 10.777845191076672, 11.718579052659138, 12.688719132440104, 13.65255599171633, 14.658011566210876, 14.748153610010691, 13.705619083045281, 12.760178834515242, 12.538247143710572, 13.55632217463025, 13.744769400304133, 12.7422516793657, 11.736910184199642, 10.789084817269817, 9.821278087160172, 8.806344820783616, 7.884107522946904, 6.977447146072827, 7.9813221495127475, 8.81889447868459, 9.812801399023648, 10.797398935262137, 11.668314973727064, 12.611473020001952, 13.616609113366602, 13.947341345818325, 12.950994004524276, 11.950353841291818, 11.740791836887665, 12.680748696496469, 12.727944842117276, 11.733964072166875, 10.770970708411532, 9.82640275092359, 8.844489431330848, 7.797219989202167, 6.841828960914293, 5.991273677586066, 7.062937492581951, 7.87350586463005, 8.867839285039848, 9.75842609465981, 10.689734614844266, 11.697980114652466, 12.542030941353756, 12.914375878010524, 11.909706380090304, 10.980640551565772, 10.810163204907305, 11.883285071221358, 11.702492747324, 10.735691828565665, 9.737744545375948, 8.82204204762758, 7.7825695964988375, 6.840407036335275, 5.888885150156667, 4.99663738872251, 6.00638755252433, 6.89219785844155, 7.882575920195777, 8.7321865655067, 9.71713594657424, 10.62789773873142, 11.575317658050288, 11.956779423891673, 11.001533598846052, 9.991987632780758, 11.742581817299701, 11.71444467513179, 10.734429950445543, 9.767579023219575, 8.81192088696002, 7.863919926545668, 6.802569472906411, 5.8670455680709805, 4.886776900503295, 4.005242309699134, 5.01561752318289, 5.866072994099628, 6.845646139741549, 7.76790330714019, 8.722643962149771, 9.650093848203355, 10.584107659617606, 11.549703925689661, 12.000734817643304, 10.960028360579468, 11.860592751989312, 10.80451676212556, 9.803894860471923, 8.809818666748438, 7.8669493360761775, 6.88567832749781, 5.9493892036882405, 4.929618801464412, 3.9403923600330533, 3.0105545248118446, 3.96276257176995, 4.862401899742418, 5.869744778549069, 6.775133597875836, 7.776553936005128, 8.704180905514336, 9.714106018569499, 10.694867692724841, 11.749854341194894, 11.822320437651557, 10.868035439324409, 9.921287845338055, 8.97384117510725, 7.945851038370929, 6.919811200404118, 5.991445734074299, 4.916619436330453, 3.9573349225711967, 3.039075363708445, 2.008976426701383, 2.97482804505385, 3.8972414119761645, 4.869677656818632, 5.840345188866899, 6.83271712037698, 7.782460869545759, 8.741895805997972, 9.806813896340975, 10.82448390738338, 11.754298281364468, 9.97973544263422, 8.91143529176836, 7.917707266195627, 6.957836948852485, 5.931094853760994, 4.946353238031876, 4.076570125426235, 3.0259632870962534, 1.9730406678177674, 1.0234003297257441, 1.9494941620484987, 2.943022616469415, 3.8616789710328483, 4.86967172924052, 5.832218310275464, 6.786843076910816, 7.7883527711957194, 8.822717158148299, 9.84201405426614, 10.783490377231265, 9.061003353529468, 7.994967286788849, 6.949221626761444, 6.015109862339066, 4.959468023408442, 3.9961253453487524, 3.025991157880323, 2.031192004096509, 1.0157781543323818, 0.0, 0.9328018776602384, 1.9725015798913526, 2.9364608476902956, 3.8906702790169554, 4.9366713920682095, 5.8989190671284, 6.949760675974426, 7.925867806097534, 8.860286060930628, 9.858132394820073, 9.978930787542788, 9.007366770627662, 7.934380261462138, 6.947708471111055, 5.970198215773306, 4.953450504801588, 3.961318157802135, 2.8929971896524678, 1.9437620856372924, 1.0029900786990484, 1.9006958999422676, 2.8285408493599076, 3.8466006969634163, 4.8239102546128105, 5.778097421955284, 6.824001124316551, 7.817020168144597, 8.87091415034059, 9.86358345657261, 10.812616443968261, 10.958487169629235, 9.980906926803668, 8.940270154247976, 7.866822909784601, 6.899911180922654, 5.861678879493864, 4.9043003034151855, 3.9188406873477533, 2.9712789409328293, 1.9329500595921862, 2.829971428943975, 3.800209592374874, 4.759155065168105, 5.716200339506682, 6.651997527090757, 7.609695187697394, 8.649313070745116, 9.709697505216406, 10.65914552750621, 11.591942232329389, 11.790399350463577, 10.844305950124816, 9.782291909912418, 8.811051077648388, 7.783557479996798, 6.813711611846352, 5.832938610544239, 4.8839292087927, 3.946988973283859, 2.957059346691371, 3.8918314653709523, 4.780584725233938, 5.809430774574047, 6.761128554362764, 7.618470507494105, 8.542743419693009, 9.549848838650163, 10.588306020464035, 11.621577660129136, 12.580060771150613, 12.64798696658055, 11.683554991668334, 10.715598872312613, 9.784061146638628, 8.820988298752843, 7.8506723205845415, 6.8474234365319475, 5.8808653276387375, 4.93930099965159, 4.0078781149467275, 4.838375047084399, 5.74810027779057, 6.722445009232869, 7.7620885904514765, 8.631066398704863, 9.501597952195345, 10.513095861844295, 11.504421109484182, 12.509786752422569, 13.537265291204562, 13.720558975594665, 12.701058084661764, 11.645400345717377, 10.801227490470989, 9.863338582894118, 8.840952092895087, 7.779399572637002, 6.870615319207491, 5.9932838464584535, 5.0651326639794245, 5.790189378212968, 6.717164481900356, 7.697273315227643, 8.661957129813482, 9.572274067406603, 10.517653146176379, 11.447046744498707, 12.376683054980012, 13.365728289307018, 14.300402717872883, 14.556808996678809, 13.53381783719115, 12.596664523946908, 11.74977229512383, 10.695095139706108, 9.692245322542062, 8.749292145267278, 7.81039683807958, 6.97034013623046, 6.03457355282249, 6.779020824475528, 7.722668176190495, 8.657936121132765, 9.643672988513087, 10.583131428596369, 11.450834727321853, 12.38771166159938, 13.351197202637083, 14.30022229792705, 15.253334085539729, 15.492850080771875, 14.481208345128483, 13.639630289836035, 12.73834414468632, 11.66353590628494, 10.629801055307897, 9.808521827613992, 8.774478421746583, 7.897919110833704, 6.991384671365329, 7.72533889522708, 8.774680443030729, 9.586639092426907, 10.642545067417586, 11.566243328384036, 12.424826357272552, 13.424029983208058, 14.387563331437082, 15.272060332674666, 16.20501973307658], [16.273260541912933, 15.405736868244986, 14.477512534642672, 13.459182097510485, 12.51966471591265, 11.528255982967675, 10.547180685250321, 9.581179193578416, 8.768218731106217, 7.829503978454503, 8.69312712247002, 9.650559185229127, 10.59802743083785, 11.607884902401027, 12.537190547606814, 13.494544883016415, 14.545958337703501, 15.508686821156932, 16.410190290784193, 17.364285924077635, 15.27079721476565, 16.20085365795211, 15.36719795132103, 14.426852141058955, 13.44881892941925, 12.468455309221603, 11.501957060137382, 10.650382391869062, 9.707982680452783, 8.756341055043402, 9.756488814313103, 10.58544265365568, 11.533637001601996, 12.538692001056425, 13.489338135689517, 14.459301506415029, 15.499237974586267, 16.48913924486284, 17.40845132231496, 16.511517452362682, 14.440172504273532, 15.440767135468883, 16.392255504890116, 15.391864094912133, 14.394472154981448, 13.434276882924108, 12.46424906776043, 11.596951906334443, 10.730160066008484, 9.805012841902427, 10.145578790448539, 10.88429019015558, 11.774208703669789, 12.706718063442073, 13.648018408154442, 14.657235321516058, 15.720692221781917, 16.548739795960262, 16.449955829240004, 15.552249666955602, 13.64381747373831, 14.623144587936208, 15.586310441739956, 15.487440363495262, 14.558289158775638, 13.647143743675231, 12.69075379631176, 11.74815435767562, 10.783583648219778, 9.891010110666013, 9.079328767390491, 9.833062400052778, 10.788642520751026, 11.764382025681476, 12.736885453843811, 13.707546459704124, 14.720694053217295, 15.572788430193294, 15.521471746163702, 14.581505885735645, 12.667554997698662, 13.6306985732878, 14.608537652373608, 14.503350900797779, 13.572655767098432, 12.645473204772154, 11.715795315198635, 10.708933483717917, 9.755077855588956, 8.877518755354208, 8.106666354235877, 8.897515440204463, 9.845043313416433, 10.785777174998898, 11.755917254779865, 12.71975411405609, 13.725209688550636, 14.641044865058117, 14.63842096070552, 13.692980712175482, 11.605445266050335, 12.623520296970012, 13.660952160774922, 13.675053557025938, 12.669712061859881, 11.721886694930053, 10.754079964820408, 9.739146698443854, 8.816909400607141, 7.910249023733066, 7.164878261943036, 7.886092601024352, 8.879999521363409, 9.864597057601898, 10.735513096066825, 11.678671142341713, 12.683807235706363, 13.605030426211883, 13.883795882184515, 12.883155718952057, 10.807989959227426, 11.74794681883623, 12.719140833554924, 12.666765949827115, 11.703772586071771, 10.759204628583825, 9.777291308991083, 8.730021866862405, 7.774630838574531, 6.924075555246304, 6.168802031601004, 6.940703986969812, 7.935037407379609, 8.825624216999572, 9.756932737184027, 10.765178236992227, 11.609229063693517, 12.552055404068373, 12.842508257750543, 11.913442429226011, 9.877361327247066, 10.95048319356112, 11.91381590186475, 11.668493706225904, 10.670546423036187, 9.754843925287817, 8.715371474159074, 7.773208913995513, 6.821687027816905, 5.929439266382748, 5.102653932346778, 5.959395980781312, 6.949774042535538, 7.799384687846461, 8.784334068914003, 9.69509586107118, 10.642515780390049, 11.626801370945325, 11.934335476506291, 10.924789510440997, 10.809779939639462, 11.866085506678656, 11.667231828105782, 10.700380900879814, 9.74472276462026, 8.796721804205905, 7.735371350566648, 6.799847445731219, 5.8195787781635335, 4.938044187359372, 4.082815645522651, 4.93327111643939, 5.912844262081311, 6.835101429479952, 7.789842084489533, 8.717291970543116, 9.651305781957367, 10.616902048029422, 11.662092490491386, 11.892830238239707, 11.852229248805209, 11.737318639785798, 10.73669673813216, 9.742620544408675, 8.799751213736416, 7.818480205158048, 6.882191081348479, 5.86242067912465, 4.8731942376932915, 3.943356402472083, 3.029960694109712, 3.92960002208218, 4.93694290088883, 5.842331720215598, 6.84375205834489, 7.771379027854097, 8.78130414090926, 9.762065815064602, 10.817052463534656, 11.767341068967703, 11.800837316984648, 10.854089722998294, 9.906643052767489, 8.878652916031166, 7.852613078064356, 6.924247611734536, 5.849421313990692, 4.890136800231435, 3.9718772413686843, 2.9417783043616215, 2.0420261673936113, 2.964439534315926, 3.9368757791583935, 4.907543311206661, 5.899915242716743, 6.849658991885522, 7.809093928337734, 8.874012018680737, 9.891682029723142, 10.821496403704229, 10.91253732029446, 9.844237169428599, 8.850509143855867, 7.890638826512722, 6.863896731421232, 5.8791551156921145, 5.009372003086473, 3.9587651647564917, 2.905842545478006, 1.9562022073859824, 1.0166922843882602, 2.010220738809177, 2.92887709337261, 3.9368698515802816, 4.899416432615226, 5.854041199250577, 6.855550893535481, 7.88991528048806, 8.909212176605902, 9.850688499571026, 9.993805231189707, 8.927769164449087, 7.882023504421682, 6.947911739999304, 5.89226990106868, 4.928927223008991, 3.958793035540561, 2.963993881756747, 1.9485800319926203, 0.9328018776602384, 0.0, 1.039699702231114, 2.0036589700300573, 2.957868401356717, 4.003869514407971, 4.966117189468162, 6.016958798314188, 6.993065928437295, 7.92748418327039, 8.925330517159834, 10.911732665203028, 9.940168648287901, 8.867182139122377, 7.880510348771294, 6.903000093433544, 5.8862523824618265, 4.8941200354623735, 3.8257990673127065, 2.876563963297531, 1.935791956359287, 0.9678940222820293, 1.895738971699669, 2.913798819303178, 3.891108376952572, 4.845295544295046, 5.891199246656313, 6.884218290484359, 7.9381122726803515, 8.930781578912372, 9.879814566308022, 11.891289047289474, 10.913708804463907, 9.873072031908215, 8.799624787444841, 7.832713058582893, 6.794480757154103, 5.837102181075425, 4.851642565007992, 3.9040808185930675, 2.8657519372524245, 1.8971695512837368, 2.867407714714636, 3.826353187507867, 4.783398461846444, 5.719195649430519, 6.676893310037157, 7.716511193084878, 8.776895627556168, 9.726343649845973, 10.659140354669152, 12.723201228123816, 11.777107827785056, 10.715093787572657, 9.743852955308627, 8.716359357657037, 7.746513489506591, 6.765740488204478, 5.816731086452939, 4.879790850944097, 3.889861224351609, 2.959029587710714, 3.8477828475736993, 4.876628896913809, 5.828326676702526, 6.685668629833867, 7.609941542032772, 8.617046960989926, 9.655504142803798, 10.688775782468898, 11.647258893490376, 13.58078884424079, 12.616356869328573, 11.648400749972852, 10.716863024298867, 9.753790176413082, 8.78347419824478, 7.780225314192187, 6.813667205298977, 5.8721028773118285, 4.940679992606967, 3.9055731694241604, 4.815298400130332, 5.789643131572631, 6.829286712791237, 7.698264521044626, 8.568796074535108, 9.580293984184058, 10.571619231823945, 11.576984874762331, 12.604463413544325, 14.653360853254904, 13.633859962322003, 12.578202223377616, 11.734029368131228, 10.796140460554357, 9.773753970555326, 8.712201450297242, 7.80341719686773, 6.786580894656391, 5.858429712177362, 4.85738750055273, 5.784362604240118, 6.764471437567405, 7.7291552521532445, 8.639472189746366, 9.584851268516141, 10.51424486683847, 11.443881177319774, 12.43292641164678, 13.367600840212646, 15.489610874339048, 14.466619714851388, 13.529466401607147, 12.640053914721584, 11.58537675930386, 10.582526942139815, 9.63957376486503, 8.700678457677332, 7.763637184428397, 6.827870601020427, 5.84621894681529, 6.7898662985302565, 7.725134243472527, 8.710871110852848, 9.650329550936132, 10.518032849661616, 11.454909783939142, 12.418395324976846, 13.367420420266813, 14.320532207879491, 16.425651958432116, 15.414010222788722, 14.572432167496274, 13.628625764284072, 12.553817525882693, 11.52008267490565, 10.698803447211745, 9.664760041344335, 8.691216159031642, 7.748400013891039, 6.792537017566842, 7.84187856537049, 8.65383721476667, 9.709743189757347, 10.633441450723799, 11.492024479612315, 12.49122810554782, 13.454761453776845, 14.339258455014429, 15.272217855416342], [15.328685129647312, 14.461161455979365, 13.532937122377051, 12.514606685244864, 11.57508930364703, 10.5839506810758, 9.602875383358446, 8.636873891686541, 7.84759008654514, 8.735815908326853, 9.599439052342369, 10.556871115101476, 11.504339360710201, 12.514196832273377, 13.443502477479164, 14.400856812888765, 15.452270267575852, 16.414998751029284, 17.40407879494086, 18.3581744282343, 14.32622180250003, 15.25627824568649, 14.422622539055409, 13.482276728793334, 12.504243517153629, 11.524150007329728, 10.557651758245507, 9.706077089977189, 8.787354035891706, 9.662652984915752, 10.662800744185454, 10.84493540125908, 11.793129749205397, 12.759410830395858, 13.636713345015005, 14.615439557931841, 15.65537602610308, 16.45309787041547, 17.407048043986272, 17.505405956519347, 13.49559709200791, 14.496191723203262, 15.447680092624497, 14.447288682646512, 13.449896742715827, 12.489971581032233, 11.519943765868556, 10.65264660444257, 9.809531421447407, 10.711324771774777, 10.825253527534361, 9.898555509228267, 10.788474022742477, 11.720983382514762, 12.66228372722713, 13.671500640588746, 14.691808959098383, 15.509040093729148, 16.448552550911316, 16.54613817111227, 12.699242061472688, 13.671867621237869, 14.635033475041617, 15.31535510482722, 14.386203900107596, 13.416268758426176, 12.459878811062705, 11.654427234168372, 10.784757042199534, 10.716384575857692, 9.759003504476313, 8.847327719125465, 9.802907839823714, 10.778647344754164, 11.7511507729165, 12.721811778776813, 13.680994350986182, 14.533088727962179, 15.55328639561185, 15.575394389892313, 11.720943590469158, 12.679421606589461, 13.657260685675269, 14.64875936378024, 14.584864439919759, 13.657681877593479, 12.72800398801996, 11.721142156539242, 10.767286528410281, 9.81569773408992, 8.786341091321699, 7.91178075927715, 8.859308632489121, 9.800042494071587, 10.716217552548752, 11.680054411824978, 12.685509986319524, 13.601345162827002, 14.534380651393803, 14.68686921633215, 10.658833858820831, 11.672243330271673, 12.696759865840027, 13.69927758677846, 13.693251781263461, 12.734095367751378, 11.766288637641733, 10.751355371265179, 9.829118073428466, 8.848428002468777, 7.844552999028858, 6.900357920097039, 7.894264840436097, 8.84216945118622, 9.695813393835712, 10.6389714401106, 11.64410753347525, 12.565330723980768, 13.53325102784104, 13.92285542118317, 9.76829025699631, 10.708247116605115, 11.67944113132381, 12.697982760399025, 12.727312305475351, 11.77141330140515, 10.789499981812408, 9.74223053968373, 8.786839511395856, 7.936284228067629, 6.921366188123433, 5.954969306042499, 6.949302726452296, 7.785924514768459, 8.717233034952914, 9.725478534761114, 10.569529361462404, 11.51235570183726, 12.491963403407068, 12.953142131457124, 8.83766162501595, 9.910783491330005, 10.874116199633635, 11.926121317422156, 11.694086142439767, 10.767052598109142, 9.727580146980399, 8.785417586816838, 7.83389570063823, 6.941647939204073, 5.949858056071618, 4.973661299853999, 5.964039361608226, 6.759684985615348, 7.744634366682888, 8.655396158840068, 9.602816078158936, 10.587101668714212, 11.542347493759832, 11.96448921267211, 9.770080237408347, 10.826385804447542, 11.80640052913379, 11.723920620283394, 10.76826248402384, 9.81267973037506, 8.747580023387973, 7.812056118552544, 6.831787450984859, 5.950252860180697, 4.942710481983375, 3.947536435512077, 4.927109581153998, 5.795401727248838, 6.750142382258419, 7.677592268312003, 8.611606079726254, 9.577202345798309, 10.622392788260273, 11.663099245324108, 10.812529546574094, 11.868605536437846, 11.760236457535742, 10.766160263812257, 9.823290933139997, 8.84201992456163, 7.905730800752061, 6.874629351945975, 5.885402910514617, 4.955565075293408, 3.8898555305704354, 2.9438653411548668, 3.9433055111264284, 4.802632017984484, 5.804052356113776, 6.731679325622983, 7.741604438678146, 8.722366112833488, 9.777352761303543, 10.727641366736588, 11.681926365063736, 11.893789425229407, 10.946342754998602, 9.91835261826228, 8.89231278029547, 7.963947313965651, 6.8891210162218055, 5.929836502462549, 5.011576943599798, 3.9814780065927358, 3.0291587879461614, 1.978704853388613, 2.8971760769272796, 3.867843608975547, 4.860215540485628, 5.809959289654407, 6.769394226106621, 7.8343123164496244, 8.85198232749203, 9.781796701473114, 11.952237022525573, 10.883936871659712, 9.89020884608698, 8.930338528743837, 7.903596433652346, 6.918854817923229, 6.049071705317587, 4.9984648669876055, 3.9455422477091204, 2.9959019096170967, 2.0180145123027806, 1.0244860578818638, 1.8891773911414962, 2.8971701493491677, 3.8597167303841124, 4.8143414970194645, 5.815851191304368, 6.850215578256947, 7.869512474374789, 8.810988797339911, 11.03350493342082, 9.9674688666802, 8.921723206652796, 7.987611442230419, 6.931969603299795, 5.968626925240105, 4.9984927377716755, 4.003693583987861, 2.9882797342237346, 1.9725015798913526, 1.039699702231114, 0.0, 0.9639592677989431, 1.9181686991256028, 2.9641698121768565, 3.926417487237047, 4.977259096083073, 5.95336622620618, 6.887784481039275, 7.885630814928719, 11.951432367434142, 10.979868350519016, 9.90688184135349, 8.920210051002408, 7.942699795664659, 6.925952084692941, 5.888008539619045, 4.819687571469378, 3.8704524674542022, 2.929680460515958, 1.8792786192254334, 0.9514336698077935, 1.911273396352106, 2.8514086747214575, 3.805595842063931, 4.851499544425198, 5.844518588253244, 6.898412570449237, 7.891081876681256, 8.840114864076908, 12.930988749520589, 11.907597308620579, 10.866960536064887, 9.793513291601514, 8.826601562739565, 7.788369261310774, 6.830990685232096, 5.845531069164663, 4.897969322749739, 3.8596404414090957, 2.808554148227141, 1.9231024128227603, 2.881777775242245, 3.838823049580822, 4.774620237164898, 5.732317897771535, 6.771935780819257, 7.830284220326663, 8.779732242616468, 9.712528947439647, 13.717089732280485, 12.770996331941724, 11.708982291729326, 10.737741459465296, 9.710247861813706, 8.74040199366326, 7.759628992361148, 6.810619590609609, 5.873679355100768, 4.88374972850828, 3.865341517583063, 2.903477545681824, 3.932053484648187, 4.8837512644369045, 5.741093217568245, 6.6653661297671505, 7.672471548724306, 8.710928730538177, 9.742164375239394, 10.700647486260872, 14.574677348397458, 13.610245373485242, 12.64228925412952, 11.710751528455535, 10.74767868056975, 9.777362702401451, 8.774113818348857, 7.807555709455647, 6.854098988862361, 5.876928939903351, 4.81188509929651, 3.8709930982384564, 4.845337829680756, 5.884981410899362, 6.753689108779005, 7.624220662269487, 8.635718571918437, 9.627043819558324, 10.63240946249671, 11.659888001278704, 15.647249357411573, 14.627748466478671, 13.572090727534285, 12.727917872287897, 11.790028964711025, 10.767642474711996, 9.706089954453912, 8.764065667117121, 7.692892824528741, 6.764741642049712, 5.7636994304250795, 4.840057302348243, 5.82016613567553, 6.7848499502613695, 7.694896777480745, 8.64027585625052, 9.569669454572848, 10.499305765054153, 11.48835099938116, 12.423025427947024, 16.483499378495715, 15.460508219008057, 14.523354905763815, 13.546365844593932, 12.491688689176211, 11.488838872012165, 10.54588569473738, 9.606990387549683, 8.669949114300747, 7.734182530892777, 6.752530876687639, 5.8455609966383815, 6.780828941580652, 7.766565808960973, 8.70575413867051, 9.573457437395994, 10.51033437167352, 11.473819912711225, 12.422845008001191, 13.37595679561387, 17.41954046258878, 16.40789872694539, 15.551067204045934, 14.534937694156422, 13.460129455755043, 12.426394604778, 11.605115377084095, 10.571071971216686, 9.597528088903992, 8.654711943763388, 7.698848947439191, 6.915268352855081, 7.709531912874795, 8.765437887865472, 9.688866038458178, 10.547449067346694, 11.5466526932822, 12.510186041511224, 13.394683042748808, 14.32764244315072], [14.364725861848369, 13.497202188180422, 12.568977854578108, 11.550647417445923, 10.611130035848088, 9.669985431539216, 8.822872629543104, 7.856871137871199, 8.801251653958913, 9.689477475740624, 10.55310061975614, 11.510532682515247, 11.913807185975285, 12.778796510355226, 13.711617878732783, 14.665546654068624, 15.658947013785657, 16.469591026322437, 17.470708482432993, 18.384274317392745, 13.362262534701086, 14.292318977887547, 13.458663271256468, 12.518317460994393, 11.540284249354688, 10.610184757793144, 9.777649004430165, 8.926074336161847, 9.74101560330548, 10.616314552329523, 11.616462311599225, 11.777059676889627, 10.921484622077104, 11.844761303134026, 12.722063817753174, 13.70079003067001, 14.698899238063266, 15.489138602616528, 16.44308877618733, 17.365624976661238, 12.531637824208968, 13.53223245540432, 14.483720824825555, 13.48332941484757, 12.485937474916886, 11.576006331495648, 10.739941012053213, 9.872643850627227, 10.76319298886118, 11.664986339188548, 11.757377803164907, 10.830679784858813, 9.883655376992616, 10.80633385525293, 11.7476341999653, 12.715771070926188, 13.72784969129944, 14.545080825930206, 15.484593283112373, 16.40635719125416, 11.735282793673745, 12.707908353438926, 13.671074207242674, 14.43371247922832, 13.504561274508696, 12.553648934527896, 11.679876057247363, 10.87442448035303, 11.738418609613307, 11.648508851488238, 10.691127780106859, 9.77945199475601, 8.898089194073853, 9.863997817492333, 10.80163248174081, 11.766082209114254, 12.71703508318724, 13.569129460163238, 14.58932712781291, 15.435613410034202, 10.756984322670215, 11.715462338790518, 12.693301417876325, 13.684800095981297, 14.48365579452648, 13.556473232200203, 12.654834538360488, 11.913645354310734, 11.699410804040827, 10.747822009720466, 9.718465366952245, 8.843905034907696, 7.95448998673926, 8.879423735773507, 9.752258284749809, 10.716095144026035, 11.72155071852058, 12.63738589502806, 13.57042138359486, 14.484339990491632, 9.694874591021888, 10.70828406247273, 11.732800598041084, 12.735318318979518, 13.662956332143535, 13.666219643381924, 12.698412913272279, 11.683479646895725, 10.761242349059012, 9.780552278099323, 8.776677274659404, 7.832482195727585, 6.989446194686237, 7.878210183387275, 8.731854126036769, 9.675012172311657, 10.680148265676307, 11.601371456181827, 12.569291760042097, 13.426783253858703, 8.804330989197368, 9.744287848806172, 10.715481863524866, 11.734023492600082, 12.697016856355425, 12.703537577035696, 11.721624257442954, 10.674354815314276, 9.718963787026402, 8.868408503698175, 7.853490463753979, 6.887093581673045, 6.044484080702436, 6.821965246969516, 7.75327376715397, 8.761519266962171, 9.605570093663461, 10.548396434038317, 11.528004135608125, 12.457069964132657, 7.873702357217008, 8.946824223531062, 9.910156931834692, 10.962162049623213, 11.96010933281293, 11.699176873739688, 10.659704422610945, 9.717541862447383, 8.766019976268776, 7.873772214834619, 6.881982331702164, 5.905785575484545, 5.059220715858365, 5.7957257178164046, 6.780675098883945, 7.691436891041125, 8.638856810359993, 9.623142400915269, 10.57838822596089, 11.587934192026186, 8.806120969609404, 9.862426536648599, 10.842441261334846, 11.809292188560814, 11.700386759654386, 10.744804006005605, 9.67970429901852, 8.74418039418309, 7.7639117266154045, 6.882377135811243, 5.874834757613921, 4.879660711142623, 4.022290935404138, 4.831442459449895, 5.786183114459476, 6.71363300051306, 7.647646811927312, 8.613243077999366, 9.65843352046133, 10.699139977525165, 9.848570278775153, 10.904646268638905, 11.789903753125731, 11.698284539442803, 10.755415208770543, 9.774144200192175, 8.837855076382606, 7.806753627576521, 6.8175271861451625, 5.887689350923954, 4.821979806200981, 3.8759896167854127, 2.9793462433274853, 3.838672750185541, 4.840093088314833, 5.76772005782404, 6.777645170879203, 7.7584068450345445, 8.8133934935046, 9.763682098937645, 10.717967097264793, 11.664714691251147, 11.910302022797545, 10.882311886061222, 9.856272048094413, 8.927906581764594, 7.8530802840207485, 6.893795770261492, 5.975536211398741, 4.941225853142361, 3.9612830635767073, 2.910829129019159, 1.9332168091283366, 2.903884341176604, 3.8962562726866854, 4.846000021855465, 5.805434958307677, 6.8703530486506805, 7.888023059693086, 8.817837433674171, 11.649464707542588, 11.847896139458655, 10.854168113885923, 9.89429779654278, 8.86755570145129, 7.882814085722172, 7.01303097311653, 5.9624241347865485, 4.9095015155080635, 3.9598611774160397, 2.9501387879333265, 1.9566103335124099, 0.9252181233425529, 1.9332108815502247, 2.8957574625851694, 3.850382229220521, 4.851891923505424, 5.886256310458004, 6.905553206575846, 7.847029529540968, 11.997464201219765, 10.931428134479145, 9.88568247445174, 8.951570710029362, 7.895928871098738, 6.932586193039048, 5.9624520055706185, 4.967652851786804, 3.9522390020226776, 2.9364608476902956, 2.0036589700300573, 0.9639592677989431, 0.0, 0.9542094313266597, 2.0002105443779135, 2.962458219438104, 4.01329982828413, 4.989406958407237, 5.923825213240332, 6.921671547129776, 12.915391635233084, 11.943827618317957, 10.870841109152433, 9.884169318801352, 8.906659063463602, 7.889911352491884, 6.851967807417987, 5.78364683926832, 4.834411735253145, 3.893639728314901, 2.8432378870243764, 1.9153929376067367, 0.9473141285531629, 1.8874494069225145, 2.841636574264988, 3.887540276626255, 4.880559320454301, 5.934453302650294, 6.927122608882313, 7.8761555962779655, 13.89494801731953, 12.87155657641952, 11.830919803863829, 10.757472559400455, 9.790560830538507, 8.752328529109716, 7.794949953031038, 6.809490336963606, 5.861928590548682, 4.823599709208039, 3.772513416026084, 2.8767639802365332, 1.917818507443302, 2.874863781781879, 3.810660969365955, 4.768358629972592, 5.807976513020314, 6.86632495252772, 7.815772974817525, 8.748569679640704, 14.68104900007943, 13.734955599740669, 12.67294155952827, 11.70170072726424, 10.67420712961265, 9.704361261462205, 8.723588260160092, 7.774578858408552, 6.8376386228997115, 5.847708996307223, 4.819003084996836, 3.8571391130955965, 2.968094216849244, 3.919791996637961, 4.777133949769302, 5.7014068619682075, 6.708512280925363, 7.746969462739234, 8.778205107440451, 9.736688218461929, 15.538636616196403, 14.574204641284187, 13.606248521928466, 12.67471079625448, 11.711637948368695, 10.741321970200396, 9.738073086147802, 8.77151497725459, 7.807760556276134, 6.830590507317123, 5.765546666710282, 4.824654665652229, 3.9787189610440588, 4.939602832922668, 5.789729840980062, 6.6602613944705436, 7.671759304119494, 8.66308455175938, 9.668450194697767, 10.69592873347976, 16.61120862521052, 15.591707734277616, 14.53604999533323, 13.691877140086842, 12.75398823250997, 11.731601742510941, 10.670049222252857, 9.717727234530892, 8.646554391942512, 7.718403209463483, 6.717360997838852, 5.7937188697620154, 5.0401633818601885, 5.894223037958186, 6.730937509681802, 7.676316588451577, 8.605710186773905, 9.53534649725521, 10.524391731582217, 11.459066160148081, 17.447458646294663, 16.424467486807004, 15.48731417356276, 14.500027412007704, 13.445350256589983, 12.442500439425936, 11.499547262151152, 10.560651954963454, 9.623610681714519, 8.687844098306549, 7.706192444101411, 6.799222564052154, 6.000826187765311, 6.920238328107225, 7.741794870871567, 8.609498169597051, 9.546375103874578, 10.509860644912282, 11.458885740202248, 12.411997527814927, 18.38349973038773, 17.371857994744335, 16.504728771459703, 15.488599261570194, 14.413791023168814, 13.380056172191772, 12.558776944497867, 11.524733538630457, 10.551189656317764, 9.60837351117716, 8.652510514852963, 7.868929920268853, 6.929529159059453, 7.9191104070117255, 8.724906770659235, 9.58348979954775, 10.582693425483257, 11.54622677371228, 12.430723774949865, 13.363683175351778], [13.427004470644444, 12.559480796976498, 11.631256463374184, 10.612926026241997, 9.673408644644162, 8.732264040335291, 7.986973805471256, 8.784657441787184, 9.755461085285573, 10.643686907067284, 11.5073100510828, 12.464742113841908, 12.643790928140573, 11.83407061578736, 12.766891984164916, 13.720820759500757, 14.71422111921779, 15.52486513175457, 16.525982587865126, 17.439548422824878, 12.424541143497162, 13.354597586683623, 12.520941880052542, 11.580596069790467, 10.602562858150762, 9.67246336658922, 8.941750180358316, 9.85386064007783, 10.69522503463214, 11.570523983656184, 12.570671742925885, 12.58414510311129, 11.651468364242392, 10.90003540856616, 11.777337923185307, 12.756064136102143, 13.754173343495399, 14.544412708048661, 15.498362881619464, 16.42089908209337, 11.593916433005043, 12.594511064200395, 13.54599943362163, 12.545608023643645, 11.54821608371296, 10.638284940291724, 9.904042187981364, 10.80043015454321, 11.71740242018784, 12.619195770515208, 12.638951409988861, 11.637765211080476, 10.613639119157904, 9.861607960685063, 10.802908305397432, 11.77104517635832, 12.783123796731573, 13.60035493136234, 14.539867388544506, 15.461631296686292, 10.797561402469821, 11.753698922112267, 12.716864775916015, 13.495991088024393, 12.56683988330477, 11.615927543323972, 10.843977233175513, 11.802210784269013, 12.692628040939967, 12.53008245831219, 11.572701386930813, 10.586537420977674, 9.62807293623914, 8.919271922924466, 9.856906587172944, 10.821356314546387, 11.772309188619372, 12.62440356559537, 13.644601233245043, 14.490887515466335, 9.802774891343557, 10.76125290746386, 11.739091986549667, 12.730590664654638, 13.545934403322558, 12.618751840996278, 11.818935714288639, 12.841431658226718, 12.602865159070168, 11.62939561654442, 10.600038973776199, 9.650990461129359, 8.684473728904548, 7.934697841205641, 8.807532390181942, 9.771369249458168, 10.776824823952714, 11.692660000460194, 12.625695489026993, 13.539614095923765, 8.74066515969523, 9.754074631146072, 10.778591166714426, 11.78110888765286, 12.708746900816877, 13.632097744159594, 12.780651064666866, 12.637689078222385, 11.715451780385672, 10.662125884923277, 9.658250881483358, 8.71405580255154, 7.719429936851524, 6.933484288819409, 7.787128231468902, 8.73028627774379, 9.73542237110844, 10.65664556161396, 11.62456586547423, 12.482057359290836, 7.850121557870709, 8.790078417479513, 9.761272432198208, 10.779814061273424, 11.742807425028767, 12.791493208760327, 12.675833688769615, 11.628564246640936, 10.673173218353062, 9.767942391191493, 8.735064070577934, 7.768667188496999, 6.774467822867723, 5.8772393524016495, 6.808547872586104, 7.816793372394304, 8.660844199095594, 9.60367053947045, 10.583278241040258, 11.51234406956479, 6.919492925890349, 7.992614792204403, 8.955947500508033, 10.007952618296555, 11.005899901486272, 11.94563616289707, 11.613913853937605, 10.671751293774044, 9.720229407595436, 8.773306102327938, 7.763555938526118, 6.787359182308499, 5.789204458023653, 4.8509998232485385, 5.835949204316079, 6.746710996473258, 7.694130915792126, 8.678416506347402, 9.633662331393023, 10.643208297458319, 7.851911538282746, 8.90821710532194, 9.888231830008188, 10.855082757234156, 11.81074089349371, 11.699013437332265, 10.63391373034518, 9.69838982550975, 8.718121157942065, 7.836586567137903, 6.829044188940581, 5.792790489046385, 4.813217343404464, 3.886716564882029, 4.84145721989161, 5.768907105945193, 6.702920917359445, 7.668517183431499, 8.713707625893463, 9.754414082957299, 8.894360847448493, 9.950436837312244, 10.835694321799073, 11.829770515522558, 11.709624640097203, 10.728353631518836, 9.792064507709267, 8.760963058903181, 7.771736617471823, 6.841898782250614, 5.776189237527642, 4.830199048112073, 3.9335556746541447, 2.893946855617675, 3.895367193746967, 4.822994163256174, 5.832919276311337, 6.813680950466679, 7.868667598936733, 8.809472667610986, 9.763757665938135, 10.710505259924489, 11.731607823072576, 11.836521317387882, 10.810481479421073, 9.882116013091254, 8.807289715347409, 7.848005201588152, 6.9297456427254005, 5.895435284469022, 4.915492494903368, 3.865038560345819, 2.887426240454996, 1.959158446608738, 2.9515303781188194, 3.9012741272875986, 4.860709063739811, 5.9256271540828145, 6.9432971651252195, 7.863628002347512, 10.69525527621593, 11.720357813494184, 11.808377545212583, 10.84850722786944, 9.82176513277795, 8.837023517048832, 7.96724040444319, 6.916633566113209, 5.863710946834723, 4.9140706087426995, 3.904348219259986, 2.9108197648390695, 1.8794275546692125, 0.9884849869823588, 1.9510315680173034, 2.905656334652655, 3.9071660289375583, 4.941530415890137, 5.960827312007979, 6.89282009821431, 11.574192576709608, 11.885637565805805, 10.8398919057784, 9.905780141356022, 8.850138302425398, 7.886795624365709, 6.916661436897279, 5.921862283113464, 4.906448433349337, 3.8906702790169554, 2.957868401356717, 1.9181686991256028, 0.9542094313266597, 0.0, 1.0460011130512539, 2.0082487881114446, 3.0590903969574708, 4.035197527080578, 4.9696157819136735, 5.967462115803118, 12.518575367142263, 12.898037049644618, 11.825050540479094, 10.838378750128012, 9.860868494790262, 8.844120783818544, 7.806177238744647, 6.73785627059498, 5.788621166579804, 4.8478491596415605, 3.797447318351036, 2.8696023689333963, 1.9015235598798226, 0.9332399755958547, 1.887427142938328, 2.9333308452995954, 3.926349889127642, 4.980243871323635, 5.972913177555655, 6.921946164951307, 13.48793808910754, 13.82576600774618, 12.785129235190489, 11.711681990727115, 10.744770261865167, 9.706537960436377, 8.749159384357698, 7.763699768290266, 6.816138021875341, 5.777809140534698, 4.726722847352743, 3.8309734115631935, 2.872027938769962, 1.9839066150140272, 2.872939578162031, 3.830637238768668, 4.857571200119958, 5.912115521201062, 6.861563543490867, 7.794360248314046, 14.468204482984657, 14.68916503106733, 13.62715099085493, 12.6559101585909, 11.62841656093931, 10.658570692788865, 9.677797691486752, 8.728788289735213, 7.791848054226371, 6.801918427633883, 5.773212516323497, 4.811348544422257, 3.922303648175904, 3.0288348298701093, 3.839412558565378, 4.763685470764282, 5.770790889721438, 6.809248071535309, 7.8239956761137925, 8.78247878713527, 15.409005025287561, 15.528414072610847, 14.560457953255126, 13.62892022758114, 12.665847379695355, 11.695531401527056, 10.692282517474462, 9.72572440858125, 8.761969987602795, 7.7847999386437845, 6.719756098036943, 5.778864096978889, 4.932928392370719, 4.048645666154816, 4.852008449776138, 5.722540003266619, 6.73403791291557, 7.725363160555456, 8.730728803493843, 9.758207342275837, 16.45539400233627, 16.545917165604276, 15.49025942665989, 14.646086571413502, 13.70819766383663, 12.685811173837601, 11.624258653579517, 10.671936665857555, 9.600763823269174, 8.672612640790145, 7.671570429165513, 6.747928301088676, 5.967949685776174, 5.003265871190334, 5.793216118477877, 6.738595197247653, 7.667988795569981, 8.597625106051286, 9.586670340378292, 10.521344768944157, 17.432668698513876, 17.37867691813366, 16.44152360488942, 15.454236843334368, 14.399559687916645, 13.396709870752598, 12.453756693477814, 11.514861386290116, 10.57782011304118, 9.64205352963321, 8.660401875428072, 7.753431995378814, 6.928612491681296, 6.029281161339373, 6.804073479667643, 7.671776778393127, 8.608653712670653, 9.572139253708357, 10.521164348998324, 11.474276136611003, 18.368709782606942, 17.522162655860598, 16.5159105179193, 15.72124938264431, 14.66154811663448, 13.78399985686608, 12.781927293775253, 12.478942969957119, 11.505399087644426, 10.56258294250382, 9.606719946179624, 8.823139351595513, 7.857315462975438, 7.028153240243873, 7.787185379455311, 8.645768408343827, 9.644972034279332, 10.608505382508357, 11.49300238374594, 12.425961784147853], [12.495157600734817, 11.62763392706687, 10.699409593464557, 9.68107915633237, 8.741561774734535, 7.800417170425664, 8.767778684993267, 9.634879243807699, 10.654108734056301, 11.592823486708014, 12.469217282487895, 13.426649345247002, 13.581239925612264, 12.77151961325905, 12.11226350351625, 13.003858837075649, 13.912151213257893, 14.722795225794673, 15.72391268190523, 16.63556844632678, 11.492694273587535, 12.422750716773995, 11.589095010142914, 10.64874919988084, 9.670715988241135, 8.740616496679593, 9.722555059880328, 10.704082442098347, 11.593872683402868, 12.519660563296913, 13.519808322566615, 13.52159410058298, 12.588917361714083, 11.83748440603785, 11.104007343484923, 12.039102213677035, 12.952103437535502, 13.742342802088764, 14.696292975659567, 15.61691910559527, 10.662069563095418, 11.66266419429077, 12.608075026797973, 11.613761153734018, 10.616369213803333, 9.706438070382097, 10.684847067503377, 11.650651956563728, 12.609470193123618, 13.568332350155938, 13.57640040746055, 12.575214208552167, 11.551088116629595, 10.799056958156754, 10.129577725697049, 11.008675443108272, 11.981053890771676, 12.798285025402443, 13.73779748258461, 14.65765132018819, 9.802065379380462, 10.707697809061012, 11.67086366286476, 12.564144218114766, 11.634993013395142, 10.684080673414345, 11.624782112697526, 12.65243258628953, 13.584695813875745, 13.467531455783881, 12.510150384402502, 11.523986418449365, 10.565521933710832, 9.856720920396157, 9.094536853922895, 10.058986581296338, 10.970239282659476, 11.822333659635474, 12.842531327285146, 13.686907538968233, 8.7567737782923, 9.715251794412604, 10.693090873498411, 11.684589551603384, 12.614087533412931, 11.686904971086651, 12.599740593810651, 13.638579878629862, 13.540314156541857, 12.566844614016109, 11.537487971247888, 10.58843945860105, 9.621922726376239, 8.872146838677331, 8.045162656931893, 9.00899951620812, 9.974754917992817, 10.890590094500297, 11.821715512528892, 12.735634119425663, 7.694664046643974, 8.708073518094816, 9.732590053663172, 10.735107774601605, 11.662745787765623, 12.700137716182242, 13.561455944188879, 13.683690191273639, 12.66903006747703, 11.599574882394966, 10.595699878955047, 9.651504800023229, 8.656878934323215, 7.8709332862911, 7.024758498218854, 7.967916544493742, 8.933352465148543, 9.854575655654063, 10.820585888976128, 11.678077382792734, 6.804120444819454, 7.7440773044282585, 8.715271319146954, 9.73381294822217, 10.696806311977513, 11.745492095709073, 12.727405415301815, 12.67456535969219, 11.719174331404316, 10.705391388663186, 9.672513068049623, 8.706116185968689, 7.711916820339414, 6.81468834987334, 6.046178139336056, 7.014723466434408, 7.858774293135698, 8.801600633510555, 9.779298264542156, 10.708364093066688, 5.873491812839094, 6.946613679153148, 7.9099463874567775, 8.961951505245299, 9.959898788435016, 10.899635049845815, 11.939107500974558, 11.717752406825298, 10.76623052064669, 9.71075509979963, 8.70100493599781, 7.72480817978019, 6.726653455495343, 5.788448820720229, 5.07260947336822, 5.944641090513361, 6.892061009832229, 7.8744365298493, 8.82968235489492, 9.725522221845356, 6.805910425231492, 7.862215992270686, 8.842230716956934, 9.809081644182902, 10.764739780442456, 11.74699338853418, 11.679914843396434, 10.744390938561004, 9.764122270993319, 8.787114306589752, 7.769200489755628, 6.730239486518076, 5.750666340876155, 4.82416556235372, 4.078117488943751, 4.966837199985296, 5.86802612282105, 6.807595716476948, 7.8335076369215635, 8.757481494046646, 7.8483597343972376, 8.904435724260988, 9.789693208747819, 10.783769402471304, 11.7097113313263, 11.77435474457009, 10.83806562076052, 9.806964171954435, 8.817737730523078, 7.887899895301868, 6.822190350578896, 5.876200161163327, 4.901393566290771, 3.831395853089366, 3.040855160216315, 3.968482129725522, 4.893536140778879, 5.874297814934222, 6.880953103381028, 7.763471554559731, 8.717756552886879, 9.664504146873233, 10.68560671002132, 11.71568383648224, 11.856482592472327, 10.928117126142508, 9.853290828398663, 8.894006314639405, 7.975746755776654, 6.941436397520276, 5.961493607954622, 4.911039673397073, 3.93342735350625, 2.896607444080429, 2.004163991177638, 2.938998541236294, 3.872994568184106, 4.937912658527109, 5.955582669569514, 6.817626889296257, 9.649254163164674, 10.674356700442928, 11.66808472601566, 11.894508340920693, 10.867766245829202, 9.883024630100085, 9.013241517494443, 7.962634679164461, 6.909712059885976, 5.960071721793953, 4.95034933231124, 3.9568208778903236, 2.9254286677204666, 1.9259339844540495, 0.963387403419105, 1.9179418390969505, 2.919451533381854, 3.9538159203344327, 4.941115059445115, 5.846818985163055, 10.656506501096645, 11.710555133927834, 11.885893018829652, 10.951781254407274, 9.89613941547665, 8.932796737416961, 7.962662549948531, 6.9678633961647165, 5.95244954640059, 4.936671392068209, 4.00386951440797, 2.9641698121768565, 2.0002105443779135, 1.0460011130512539, 0.0, 0.9622476750601905, 2.0130892839062167, 2.989196414029324, 3.9236146688624185, 4.921461002751863, 11.708879182337533, 12.68044319925266, 12.871051653530346, 11.884379863179264, 10.906869607841514, 9.890121896869797, 8.852178351795901, 7.783857383646234, 6.834622279631058, 5.893850272692815, 4.843448431402289, 3.91560348198465, 2.9475246729310762, 1.909767440371175, 0.9555802730287015, 1.8873297322483413, 2.8803487760763877, 3.9342427582723807, 4.9269120645044, 5.875945051900052, 12.683958112609439, 13.66805593805299, 13.831130348241743, 12.75768310377837, 11.790771374916421, 10.75253907348763, 9.795160497408952, 8.80970088134152, 7.862139134926595, 6.823810253585952, 5.772723960403997, 4.792880642968289, 3.833935170175057, 2.87688989583648, 1.941092708252404, 2.898790368859041, 3.8115700870687044, 4.866114408149808, 5.815562430439613, 6.748359135262792, 13.664224506486555, 14.610317906825316, 14.673152103906185, 13.701911271642155, 12.674417673990565, 11.70457180584012, 10.723798804538006, 9.774789402786467, 8.795549720661523, 7.786283688002372, 6.735119747728591, 5.773255775827352, 4.8842108795809995, 3.921818110692562, 2.9075656886557515, 3.8318386008546557, 4.825858066482349, 5.86431524829622, 6.7779945630625384, 7.736477674084016, 14.605025048789459, 15.569457023701675, 15.60645906630638, 14.674921340632395, 13.71184849274661, 12.74153251457831, 11.738283630525716, 10.760201262490513, 9.723877219007889, 8.746707170048879, 7.681663329442038, 6.740771328383985, 5.894835623775814, 4.93023132037103, 3.920161579866511, 4.790693133356992, 5.8021910430059425, 6.793516290645829, 7.798881933584216, 8.774871018979248, 15.651414025838168, 16.620676211335113, 16.536260539711144, 15.692087684464756, 14.754198776887884, 13.704936418730629, 12.643383898472544, 11.633843897262649, 10.562671054674269, 9.63451987219524, 8.633477660570607, 7.709835532493772, 6.818171487796689, 5.853487673210849, 4.86136924856825, 5.806748327338026, 6.736141925660354, 7.6657782361416595, 8.654823470468667, 9.589497899034532, 16.628688722015774, 17.631455300200674, 16.75680637784853, 15.980358956607448, 14.962105016439647, 14.066927108983249, 13.415663924882908, 12.47676861769521, 11.539727344446275, 10.603960761038305, 9.622309106833166, 8.715339226783911, 7.778834293701811, 6.879502963359888, 5.872226609758016, 6.7399299084835, 7.676806842761026, 8.64029238379873, 9.589317479088697, 10.542429266701376, 17.56472980610884, 16.7200927499007, 15.713840611959402, 14.919179476684413, 13.944586194209371, 13.129371376217414, 13.719376291246943, 13.440850201362213, 12.46730631904952, 11.524490173908914, 10.568627177584718, 9.743021205622288, 8.707537264995953, 7.808958119765885, 6.855338509545684, 7.713921538434199, 8.713125164369705, 9.67665851259873, 10.561155513836313, 11.494114914238226], [11.609278334384737, 10.74175466071679, 9.813530327114476, 8.795199889982289, 7.855682508384455, 8.762119951889101, 9.729481466456704, 10.59712691886789, 11.616356409116491, 12.555071161768204, 13.431464957548085, 14.388897020307192, 14.528171452865271, 13.718451140512057, 13.006304069047811, 12.207790404743935, 12.950781924988886, 13.761425937525669, 14.762543393636225, 15.673320771266587, 10.606815007237454, 11.536871450423915, 10.703215743792834, 9.762869933530759, 8.784836721891054, 9.70231927814303, 10.684257841343765, 11.666330117158537, 12.556120358463058, 13.481908238357104, 14.482055997626805, 14.468525627835987, 13.53584888896709, 12.784415933290857, 11.998047909016485, 11.243033781345321, 11.990734149266496, 12.78097351381976, 13.734923687390562, 14.65467143053508, 9.776190296745337, 10.703204484895007, 11.645827351737783, 10.727881887383937, 9.730489947453252, 10.668140851845534, 11.646549848966814, 12.612899631623918, 13.571717868183809, 14.530580025216128, 14.523331934713557, 13.522145735805173, 12.498019643882602, 11.745988485409761, 11.02361829122861, 10.212607010776559, 11.01968460250267, 11.836915737133438, 12.776428194315605, 13.695403645128, 8.839817704320271, 9.745450134000821, 10.708615987804569, 11.678264951764685, 10.749113747045062, 11.645783454877781, 12.586484894160963, 13.61468026134972, 14.546943488935936, 14.414462983036888, 13.457081911655509, 12.470917945702372, 11.512453460963838, 10.803652447649164, 9.988577419454456, 9.262918148964625, 10.00886999439047, 10.86096437136647, 11.881162039016141, 12.724659863908043, 7.79452610323211, 8.753004119352413, 9.73084319843822, 10.722341876543194, 11.65303701024254, 12.580219572568819, 13.509897462142337, 14.548736746961549, 14.487245683794864, 13.513776141269116, 12.484419498500895, 11.535370985854057, 10.568854253629246, 9.819078365930338, 8.939203222463455, 8.212931083876406, 9.01338562972381, 9.929220806231292, 10.859467837468701, 11.773386444365473, 6.732416371583784, 7.745825843034625, 8.770342378602981, 9.772860099541415, 10.700498112705432, 11.737890041122052, 12.705696771231697, 13.738087317593006, 13.615961594730036, 12.546506409647973, 11.542631406208054, 10.598436327276236, 9.603810461576222, 8.817864813544107, 7.918799063750415, 7.163106608515647, 7.971983176879537, 8.893206367385059, 9.858338213915937, 10.715829707732544, 5.841872769759264, 6.781829629368068, 7.753023644086763, 8.771565273161979, 9.734558636917322, 10.783244420648883, 11.765157740241625, 12.816438878796061, 12.670854178275857, 11.652322915916193, 10.61944459530263, 9.653047713221696, 8.658848347592421, 7.761619877126347, 6.9402187048676165, 6.09259443487084, 6.897405004866692, 7.840231345241548, 8.817050589481966, 9.746116418006498, 4.911244137778904, 5.984366004092958, 6.947698712396587, 7.999703830185108, 8.997651113374825, 9.937387374785624, 10.976859825914367, 12.004661107921915, 11.71791036751823, 10.657686627052637, 9.647936463250817, 8.671739707033197, 7.67358498274835, 6.735380347973236, 5.966650038899781, 5.022512058949793, 5.930691721563223, 6.912188854789109, 7.867434679834731, 8.763274546785166, 5.843662750171301, 6.8999683172104955, 7.879983041896743, 8.846833969122711, 9.802492105382266, 10.78474571347399, 11.849845420461076, 11.699820540755264, 10.719551873187578, 9.734045833842758, 8.716132017008634, 7.6771710137710825, 6.6975978681291615, 5.771097089606727, 4.972158054475312, 4.044708168421728, 4.90577844776086, 5.845348041416758, 6.871259961861373, 7.795233818986456, 6.886112059337047, 7.942188049200798, 8.827445533687628, 9.821521727411113, 10.74746365626611, 11.728734664844477, 11.79349522295478, 10.762393774148695, 9.773167332717337, 8.843329497496129, 7.777619952773157, 6.831629763357588, 5.848325093543778, 4.778327380342373, 3.9631857843835596, 3.046353098161954, 3.9312884657186893, 4.912050139874031, 5.918705428320838, 6.80122387949954, 7.7555088778266885, 8.702256471813042, 9.72335903496113, 10.75343616142205, 11.77947599938886, 11.890364801202699, 10.815538503458853, 9.856253989699596, 8.937994430836845, 7.896865999714537, 6.916923210148883, 5.866469275591334, 4.888856955700511, 3.8435389713334356, 2.9264946153448825, 1.9767508661761033, 2.9107468931239153, 3.9756649834669187, 4.993334994509324, 5.855379214236066, 8.687006488104483, 9.712109025382738, 10.70583705095547, 11.724941665708272, 11.830013920889394, 10.845272305160277, 9.975489192554635, 8.924882354224653, 7.871959734946167, 6.922319396854144, 5.905778934505501, 4.912250480084585, 3.880858269914728, 2.8728655117070563, 1.9103189306721116, 0.9556941640367599, 1.9572038583216633, 2.9915682452742423, 3.978867384384925, 4.8845713101028645, 9.694258826036455, 10.748307458867643, 11.674322690389653, 11.914028929467467, 10.858387090536842, 9.895044412477153, 8.924910225008723, 7.930111071224909, 6.914697221460782, 5.8989190671284, 4.966117189468162, 3.9264174872370474, 2.9624582194381044, 2.0082487881114446, 0.9622476750601905, 0.0, 1.0508416088460262, 2.0269487389691334, 2.961366993802228, 3.959213327691672, 10.746631507277343, 11.718195524192469, 12.659481325090347, 12.846627538239456, 11.869117282901707, 10.852369571929989, 9.814426026856092, 8.746105058706425, 7.796869954691249, 6.856097947753005, 5.805696106462481, 4.877851157044841, 3.909772347991267, 2.8720151154313656, 1.917827948088892, 0.925082057188151, 1.9181011010161972, 2.97199508321219, 3.9646643894442093, 4.9136973768398615, 11.721710437549248, 12.7058082629928, 13.689754978967287, 13.71993077883856, 12.753019049976611, 11.714786748547821, 10.757408172469143, 9.77194855640171, 8.824386809986786, 7.786057928646143, 6.734971635464188, 5.755128318028478, 4.796182845235247, 3.8391375708966704, 2.9033403833125946, 1.9785255966275201, 2.849322412008514, 3.9038667330896173, 4.853314755379422, 5.786111460202601, 12.701976831426364, 13.648070231765125, 14.710084271977523, 14.664158946702345, 13.636665349050755, 12.66681948090031, 11.686046479598197, 10.737037077846658, 9.757797395721713, 8.748531363062563, 7.697367422788782, 6.735503450887542, 5.846458554641189, 4.884065785752752, 3.869813363715942, 2.9115738286231347, 3.8636103914221582, 4.90206757323603, 5.815746888002348, 6.7742299990238255, 13.642777373729269, 14.607209348641485, 15.575165467997206, 15.637169015692585, 14.6740961678068, 13.7037801896385, 12.700531305585907, 11.722448937550704, 10.68612489406808, 9.70895484510907, 8.643911004502229, 7.703019003444174, 6.857083298836004, 5.89247899543122, 4.882409254926701, 3.8704283611254713, 4.8819262707744215, 5.873251518414308, 6.878617161352695, 7.812623343919058, 14.689166350777977, 15.658428536274922, 16.50496694140197, 16.0139815682151, 15.166557673483178, 14.66718409379082, 13.605631573532735, 12.59609157232284, 11.524918729734459, 10.59676754725543, 9.595725335630798, 8.67208320755396, 7.780419162856879, 6.81573534827104, 5.823616923628441, 4.920869060987946, 5.850262659310273, 6.779898969791579, 7.768944204118586, 8.703618632684451, 15.666441046955583, 16.669207625140483, 15.795437089579524, 15.018989668338442, 14.166036584107934, 14.96096767451481, 14.377911599943099, 13.4390162927554, 12.501975019506466, 11.566208436098496, 10.584556781893356, 9.677586901844098, 8.741081968762002, 7.841750638420079, 6.8344742848182065, 5.85405064213342, 6.790927576410946, 7.75441311744865, 8.703438212738616, 9.656550000351295, 16.60248213104865, 15.758723461631696, 14.752471323690397, 13.957810188415406, 13.148517761877658, 14.023411941748975, 14.66630781849995, 14.403097876422404, 13.42955399410971, 12.486737848969105, 11.530874852644908, 10.705268880682478, 9.669784940056143, 8.770660901229322, 7.8170412910091205, 6.828042272084119, 7.8272458980196244, 8.790779246248649, 9.675276247486233, 10.608235647888145], [10.68617592492306, 9.818652251255115, 8.8904279176528, 7.944496488962157, 8.791367295567433, 9.69780473907208, 10.665166253639683, 11.551247994608687, 12.570477484857289, 13.509192237509001, 14.403419801874252, 15.360851864633359, 15.523526651521292, 14.635299080805707, 13.845857647825667, 13.039896728860821, 11.99525141301336, 12.805895425550139, 13.807012881660695, 14.628290209984245, 9.683712597775777, 10.585394469520251, 9.852512342772703, 8.912166532510629, 9.720521509074032, 10.638004065326008, 11.619942628526744, 12.620451192899335, 13.510241434203856, 14.436029314097901, 15.436177073367602, 15.463880826492009, 14.531204087623111, 13.701263873584507, 12.837601487794341, 12.075140105462207, 11.03520363729097, 11.82544300184423, 12.779393175415033, 13.609640869252738, 8.801295204114808, 9.652362876048981, 10.594985742891756, 9.932621279479305, 10.66617473463623, 11.603825639028512, 12.582234636149792, 13.567020707364716, 14.525838943924606, 15.484701100956926, 15.518687133369578, 14.517500934461195, 13.493374842538623, 12.66283642570341, 11.863171870006466, 11.052160589554417, 10.064154090527143, 10.881385225157908, 11.820897682340075, 12.650373083845658, 7.788976095474246, 8.694608525154795, 9.657774378958543, 10.710176383400132, 11.587828793073722, 12.532202261395101, 13.434014334409438, 14.463647906433755, 15.44745587711665, 15.40981818169291, 14.45243711031153, 13.466273144358393, 12.50780865961986, 11.720500387942813, 10.828130998232313, 10.102471727742483, 9.053339482414943, 9.90543385939094, 10.925631527040611, 11.6796293026257, 6.743684494386084, 7.702162510506387, 8.680001589592194, 9.67150026769717, 10.602195401396516, 11.529377963722794, 12.459055853296313, 13.497895138115524, 14.451750766244485, 14.509131339925137, 13.479774697156916, 12.530726184510078, 11.564209452285267, 10.735926306223988, 9.778756801241311, 9.052484662654264, 8.057855117748284, 8.973690294255762, 9.899335009357516, 10.72835588308313, 5.681574762737758, 6.694984234188599, 7.719500769756956, 8.72201849069539, 9.649656503859406, 10.687048432276026, 11.65485516238567, 12.68724570874698, 13.74841189402854, 13.541861608303995, 12.537986604864075, 11.593791525932257, 10.599165660232243, 9.734712753837755, 8.758352642528271, 8.002660187293504, 7.01645266490401, 7.9376758554095295, 8.898205385804753, 9.670799146450202, 4.791031160913238, 5.730988020522042, 6.702182035240737, 7.720723664315953, 8.683717028071296, 9.732402811802856, 10.714316131395599, 11.765597269950035, 12.735203591750215, 12.647678114572214, 11.614799793958651, 10.648402911877717, 9.654203546248443, 8.711080803829928, 7.779772283645473, 6.932148013648696, 5.941874492891165, 6.88470083326602, 7.856917761370781, 8.701085856724156, 3.8604025289328776, 4.933524395246931, 5.896857103550561, 6.948862221339082, 7.9468095045288, 8.886545765939598, 9.926018217068341, 10.95381949907589, 11.91210356751196, 11.653041825708659, 10.643291661906838, 9.667094905689218, 8.668940181404372, 7.730735546629258, 6.806203617677637, 5.8620656377276505, 4.975161209587696, 5.956658342813583, 6.907301851723545, 7.71243293793914, 4.792821141325275, 5.849126708364469, 6.829141433050717, 7.795992360276685, 8.75165049653624, 9.733904104627964, 10.79900381161505, 11.73452771645048, 11.75274946119604, 10.729401032498782, 9.711487215664658, 8.672526212427105, 7.692953066785184, 6.766452288262749, 5.811711633253168, 4.884261747199585, 3.9502479357853333, 4.889817529441231, 5.844697020869771, 6.74439221014043, 5.835270450491021, 6.891346440354772, 7.776603924841602, 8.770680118565087, 9.696622047420082, 10.67789305599845, 11.614182179808019, 11.809882650742974, 10.820656209311617, 9.890818374090408, 8.825108829367435, 7.879118639951868, 6.892895304155512, 5.822897590954106, 4.913310036307532, 3.985683066798325, 2.9757579537431624, 3.9565196278985044, 4.892142487329235, 5.750382270653514, 6.704667268980662, 7.651414862967015, 8.672517426115103, 9.702594552576024, 10.728634390542833, 11.656999856872652, 11.866380112304878, 10.90709559854562, 9.988836039682871, 8.944354876308816, 7.964412086743163, 6.913958152185614, 5.9363458322947915, 4.888109181945169, 3.895737250435088, 2.9459935012663085, 1.9552163811483885, 3.0201344714913922, 3.9667720535177216, 4.80453760539004, 7.636164879258457, 8.66126741653671, 9.654995442109442, 10.674100056862244, 11.700842151953735, 11.896113914006301, 11.02633080140066, 9.975723963070678, 8.922801343792193, 7.973161005700169, 6.953267811099781, 5.959739356678865, 4.928347146509008, 3.920354388301336, 2.9578078072663914, 2.00318304063104, 1.0016733463461365, 1.9890748322543201, 2.9280257755388988, 3.833729701256838, 8.643417217190429, 9.697465850021615, 10.623481081543625, 11.557592845966003, 11.909228699382867, 10.945886021323178, 9.975751833854748, 8.980952680070933, 7.965538830306807, 6.949760675974425, 6.016958798314187, 4.977259096083073, 4.01329982828413, 3.0590903969574708, 2.0130892839062167, 1.0508416088460262, 0.0, 0.9761071301231072, 1.9105253849562018, 2.908371718845646, 9.695789898431316, 10.667353915346443, 11.60863971624432, 12.490191454737992, 12.919958891747731, 11.903211180776013, 10.865267635702118, 9.79694666755245, 8.847711563537276, 7.906939556599031, 6.856537715308507, 5.928692765890867, 4.960613956837293, 3.9228567242773913, 2.968669556934918, 1.939777416820133, 0.9467583729920865, 1.921153474366164, 2.913822780598183, 3.8628557679938353, 10.675346280517763, 11.654966654146772, 12.638913370121259, 13.56168508996229, 13.803860658822638, 12.765628357393847, 11.808249781315169, 10.822790165247737, 9.875228418832812, 8.836899537492169, 7.773525610091683, 6.727083162354646, 5.7681376895614145, 4.811092415222838, 3.875295227638762, 2.917597567032125, 1.8779796839844032, 2.853025124243591, 3.8024731465333956, 4.735269851356575, 11.65561267439488, 12.60170607473364, 13.663720114946038, 14.520349038462365, 14.687506957896781, 13.717661089746336, 12.736888088444223, 11.787878686692684, 10.72975224004788, 9.72048620738873, 8.669322267114948, 7.707458295213709, 6.8184133989673565, 5.85602063007892, 4.84176820804211, 3.8506457990277396, 2.892267663398047, 3.8676486224144235, 4.764905279156322, 5.723388390177799, 12.596413216697783, 13.56084519161, 14.52880131096572, 15.484144228576476, 15.724937776652826, 14.726113402130212, 13.722864518077618, 12.69440378187687, 11.658079738394246, 10.680909689435236, 9.615865848828395, 8.674973847770342, 7.829038143162171, 6.846600071172015, 5.836530330667497, 4.809500331530076, 3.9278735556071775, 4.865012183993871, 5.828268504468457, 6.761781735073032, 13.644135789495635, 14.612064379243439, 15.458602784370484, 15.058451056239575, 15.998663997600064, 15.639138938116986, 14.577586417858901, 13.568046416649006, 12.496873574060626, 11.568722391581597, 10.567680179956964, 9.644038051880129, 8.734540238597674, 7.769856424011835, 6.777737999369236, 5.856553848170924, 4.927160249848597, 5.856796560329903, 6.845841794656909, 7.775340896009014, 14.621410485673241, 15.622843468109, 14.839906577603994, 14.063459156362915, 14.99814290822482, 15.800521253292667, 15.349866444269265, 14.410971137081567, 13.473929863832632, 12.538163280424662, 11.556511626219523, 10.649541746170268, 9.695203044502797, 8.795871714160874, 7.788595360559002, 6.789735429316398, 5.867825166949269, 6.831310707986974, 7.78033580327694, 8.733447590889618, 15.557451569766307, 14.803192949656166, 13.796940811714867, 13.00227967643988, 13.980624085994544, 14.862965520526831, 15.5831557587936, 15.37505272074857, 14.401508838435877, 13.458692693295271, 12.502829696971075, 11.659389956423276, 10.62390601579694, 9.7063456884123, 8.752726078192099, 7.763727059267096, 6.904143488557948, 7.8676768367869725, 8.752173838024557, 9.685133238426468], [9.740874285547468, 8.873350611879522, 7.945126278277208, 8.847828743657082, 9.69469955026236, 10.601136993767007, 11.56849850833461, 12.478775176875079, 13.49800466712368, 14.436719419775393, 15.36545889429934, 16.322890957058448, 16.4996337816444, 15.611406210928815, 14.821964777948775, 14.016003858983927, 12.971358543136466, 12.09012684215081, 12.880201536614432, 13.652183079861137, 8.738410958400186, 9.609287339397145, 8.981432098937187, 9.815498787205552, 10.62385376376896, 11.541336320020935, 12.52327488322167, 13.547978375165727, 14.437768616470247, 15.363556496364293, 16.363704255633994, 16.439987956615116, 15.507311217746219, 14.677371003707615, 13.813708617917449, 13.051247235585313, 12.011310767414075, 11.1096744184449, 11.85258183036877, 12.63353373912963, 7.825188073991701, 8.676255745925875, 9.61887861276865, 10.619270022746635, 11.569506989331158, 12.50715789372344, 13.397842249480483, 14.441953393800636, 15.400771630360527, 16.412228283223318, 16.494794263492686, 15.493608064584302, 14.46948197266173, 13.638943555826518, 12.839279000129574, 12.028267719677524, 11.04026122065025, 10.165616641758579, 10.894086337293812, 11.67426595372255, 6.812868965351139, 7.718501395031689, 8.681667248835437, 9.734069253277028, 10.611721662950616, 11.556095131271997, 12.457907204286334, 13.48754077631065, 14.471348746993545, 15.457477048330475, 15.428544240434638, 14.4423802744815, 13.483915789742968, 12.696607518065921, 11.80423812835542, 11.07857885786559, 10.029446612538049, 9.18966527599161, 9.96560225421751, 10.703522172502593, 5.767577364262977, 6.726055380383281, 7.703894459469089, 8.695393137574063, 9.62608827127341, 10.55327083359969, 11.482948723173209, 12.52178800799242, 13.475643636121381, 14.44911317864713, 14.455881827280024, 13.506833314633186, 12.540316582408375, 11.712033436347095, 10.754863931364419, 10.028591792777371, 9.03396224787139, 8.257921710856433, 8.923227879234409, 9.752248752960023, 4.705467632614651, 5.718877104065493, 6.74339363963385, 7.745911360572284, 8.6735493737363, 9.71094130215292, 10.678748032262565, 11.711138578623874, 12.772304763905433, 13.769481102241397, 13.514093734987183, 12.569898656055365, 11.575272790355351, 10.710819883960863, 9.734459772651379, 8.978767317416612, 7.992559795027116, 7.221907272010199, 7.922098255681646, 8.694692016327094, 3.8149240307901313, 4.754880890398936, 5.726074905117631, 6.744616534192847, 7.70760989794819, 8.75629568167975, 9.738209001272493, 10.78949013982693, 11.75909646162711, 12.783307633754635, 12.590906924081759, 11.624510042000825, 10.63031067637155, 9.687187933953036, 8.75587941376858, 7.908255143771804, 6.917981623014271, 6.16893224986669, 6.880810631247674, 7.724978726601048, 2.884295398809771, 3.9574172651238246, 4.920749973427455, 5.972755091215976, 6.970702374405694, 7.910438635816492, 8.949911086945235, 9.977712368952783, 10.935996437388853, 11.996220177854447, 11.619398792029946, 10.643202035812326, 9.64504731152748, 8.706842676752366, 7.782310747800745, 6.838172767850758, 5.951268339710802, 5.130132324828238, 5.931194721600439, 6.7363258078160335, 3.816714011202168, 4.873019578241363, 5.85303430292761, 6.819885230153578, 7.775543366413133, 8.757796974504856, 9.822896681491942, 10.758420586327372, 11.738689253895057, 11.705508162621891, 10.687594345787767, 9.648633342550214, 8.669060196908292, 7.742559418385857, 6.787818763376276, 5.860368877322693, 4.9263550659084405, 4.063291511455886, 4.868589890746664, 5.768285080017323, 4.859163320367914, 5.915239310231666, 6.800496794718495, 7.794572988441979, 8.720514917296976, 9.701785925875344, 10.638075049684913, 11.669176498490998, 11.796763339434724, 10.866925504213516, 9.801215959490543, 8.855225770074975, 7.8690024342786185, 6.799004721077213, 5.88941716643064, 4.961790196921433, 3.9518650838662697, 3.1299936099131593, 3.9160353572061286, 4.774275140530407, 5.7285601388575556, 6.675307732843908, 7.6964102959919956, 8.726487422452916, 9.752527260419726, 10.680892726749544, 11.6708448170427, 11.883202728668728, 10.964943169805979, 9.920462006431922, 8.940519216866269, 7.890065282308721, 6.912452962417898, 5.864216312068276, 4.871844380558195, 3.922100631389416, 2.9313235112714957, 2.069508613456072, 2.9906649233946143, 3.828430475266933, 6.66005774913535, 7.685160286413603, 8.678888311986336, 9.697992926739138, 10.724735021830629, 11.734778631781957, 12.002437931523767, 10.951831093193785, 9.8989084739153, 8.949268135823276, 7.929374941222888, 6.935846486801972, 5.904454276632115, 4.896461518424443, 3.933914937389499, 2.9792901707541475, 1.9777804764692437, 1.012967702131213, 1.9519186454157915, 2.857622571133731, 7.667310087067322, 8.72135871989851, 9.64737395142052, 10.581485715842897, 11.637127554773521, 11.921993151446285, 10.951858963977855, 9.95705981019404, 8.941645960429915, 7.925867806097532, 6.993065928437294, 5.95336622620618, 4.989406958407237, 4.0351975270805776, 2.989196414029324, 2.0269487389691334, 0.9761071301231072, 0.0, 0.9344182548330947, 1.932264588722539, 8.71968276830821, 9.691246785223337, 10.632532586121213, 11.514084324614887, 12.518928157770175, 12.879318310899121, 11.841374765825226, 10.773053797675558, 9.823818693660384, 8.883046686722139, 7.832644845431614, 6.904799896013974, 5.9367210869604, 4.898963854400499, 3.9447766870580256, 2.91588454694324, 1.9228655031151938, 0.9450463442430569, 1.9377156504750763, 2.886748637870728, 9.699239150394657, 10.678859524023668, 11.662806239998154, 12.585577959839185, 13.488663142761277, 13.741735487516955, 12.784356911438277, 11.798897295370844, 10.85133554895592, 9.813006667615277, 8.74963274021479, 7.703190292477753, 6.744244819684522, 5.7871995453459455, 4.85140235776187, 3.8937046971552327, 2.8540868141075104, 1.8769179941204839, 2.8263660164102884, 3.759162721233468, 10.679505544271773, 11.625598944610534, 12.687612984822932, 13.54424190833926, 14.505272267353694, 14.693768219869444, 13.71299521856733, 12.763985816815792, 11.705859370170987, 10.696593337511837, 9.645429397238056, 8.683565425336816, 7.794520529090464, 6.832127760202027, 5.8178753381652175, 4.826752929150848, 3.8683747935211548, 2.8915414922913163, 3.788798149033214, 4.747281260054692, 11.620306086574677, 12.584738061486894, 13.552694180842614, 14.50803709845337, 15.502025716088237, 15.70222053225332, 14.698971648200725, 13.670510911999978, 12.634186868517354, 11.657016819558343, 10.591972978951503, 9.651080977893448, 8.805145273285278, 7.822707201295123, 6.812637460790604, 5.785607461653184, 4.880230301510649, 3.8889050538707632, 4.852161374345349, 5.785674604949924, 12.668028659372528, 13.635957249120331, 14.482495654247378, 15.494147968612635, 16.452283371390283, 16.615246068240094, 15.553693547982009, 14.544153546772113, 13.472980704183733, 12.544829521704704, 11.543787310080072, 10.620145182003235, 9.662067420864066, 8.697383606278226, 7.705265181635626, 6.759886102865851, 5.830492504543523, 4.900856194062217, 5.889901428389225, 6.799233765885906, 13.645303355550134, 14.646736337985892, 14.124137994204665, 15.039566286486021, 15.974250038347925, 16.776628383415776, 16.325973574392375, 15.387078267204675, 14.45003699395574, 13.51427041054777, 12.53261875634263, 11.610339044049473, 10.622730226769189, 9.723398896427266, 8.712492505483887, 7.693067684011325, 6.771157421644196, 5.886009068611382, 6.835034163901348, 7.788145951514027, 14.5813444396432, 13.876381604609904, 13.081172228315538, 13.978386806562986, 14.95673121611765, 15.839072650649939, 16.559262888916706, 16.351159850871678, 15.377615968558985, 14.434799823418379, 13.478936827094183, 12.586917138689667, 11.551433198063332, 10.609677943107227, 9.656058332887026, 8.667059313962024, 7.8074757432528745, 6.92237519741138, 7.806872198648964, 8.739831599050877], [8.888686104728766, 8.06049581100087, 8.879544533110302, 9.782246998490177, 10.629117805095454, 11.535555248600101, 12.502916763167704, 13.413193431708173, 14.432422921956775, 15.371137674608487, 16.299877149132435, 17.257309211891542, 17.434052036477496, 16.545824465761907, 15.75638303278187, 14.837832678175632, 13.786419223488545, 12.823690740035115, 11.945783281781338, 12.717764825028043, 7.886222777581483, 8.674869084564051, 9.64750966405639, 10.587855474318465, 11.558272018602054, 12.47575457485403, 13.425716002270434, 14.45410465343292, 15.372186871303342, 16.297974751197387, 17.29812251046709, 17.37440621144821, 16.441729472579315, 15.611789258540709, 14.748126872750543, 13.914076537843961, 12.874140069672723, 11.843238316329206, 10.918163575535676, 11.699115484296536, 6.928765638747278, 7.74183749109278, 8.684460357935555, 9.684851767913539, 10.682243707844224, 11.599319479471147, 12.463423994647385, 13.507535138967539, 14.46635337552743, 15.507040927725171, 16.546689887936804, 16.428026319417395, 15.403900227494825, 14.573361810659613, 13.773697254962668, 12.962685974510618, 11.962865324574338, 10.899180539642884, 9.959668082460718, 10.739847698889456, 5.916446530106716, 6.784083140198593, 7.747248994002341, 8.79965099844393, 9.677303408117519, 10.6216768764389, 11.523488949453236, 12.553122521477553, 13.536930492160447, 14.523058793497377, 15.480439864878754, 15.376798529314595, 14.418334044576062, 13.631025772899015, 12.738656383188514, 12.012997112698685, 10.963864867371143, 9.95178534612401, 9.031183999384416, 9.769103917669499, 4.871154929018554, 5.791637125550185, 6.769476204635993, 7.760974882740967, 8.691670016440312, 9.618852578766592, 10.548530468340111, 11.587369753159322, 12.541225381288283, 13.514694923814032, 14.579396334428203, 14.44125156946628, 13.474734837241469, 12.64645169118019, 11.689282186197513, 10.963010047610465, 9.968380502704484, 9.020041780988834, 7.988809624401314, 8.817830498126929, 3.809045197370228, 4.784458849232398, 5.808975384800754, 6.811493105739188, 7.739131118903204, 8.776523047319824, 9.744329777429469, 10.776720323790778, 11.837886509072337, 12.835062847408299, 13.838937850848218, 13.504316910888459, 12.509691045188445, 11.645238138793957, 10.668878027484473, 9.913185572249706, 8.92697804986021, 7.9840273421426, 6.987680000848551, 7.760273761493999, 2.8805057759570363, 3.8204626355658404, 4.791656650284535, 5.810198279359751, 6.773191643115094, 7.821877426846654, 8.803790746439397, 9.855071884993833, 10.824678206794013, 11.848889378921537, 12.920553193917423, 12.558928296833919, 11.564728931204645, 10.62160618878613, 9.690297668601675, 8.842673398604898, 7.852399877847366, 6.951061874334799, 5.946392376414579, 6.790560471767953, 1.9498771439766758, 3.0229990102907296, 3.9863317185943594, 5.03833683638288, 6.036284119572598, 6.976020380983396, 8.01549283211214, 9.043294114119687, 10.001578182555757, 11.061801923021351, 12.071552086823171, 11.57762029064542, 10.579465566360573, 9.64126093158546, 8.716729002633839, 7.772591022683852, 6.8856865945438965, 5.952022291812965, 4.9967764667673435, 5.8019075529829385, 2.8822957563690728, 3.9386013234082675, 4.918616048094515, 5.885466975320483, 6.8411251115800376, 7.823378719671762, 8.888478426658848, 9.824002331494277, 10.804270999061963, 11.82761942775922, 11.62201260062086, 10.583051597383307, 9.603478451741385, 8.67697767321895, 7.72223701820937, 6.794787132155787, 5.860773320741535, 4.979362078375532, 3.934171635913569, 4.833866825184228, 3.924745065534819, 4.98082105539857, 5.8660785398854, 6.860154733608884, 7.786096662463881, 8.76736767104225, 9.703656794851819, 10.734758243657904, 11.723984685089262, 11.801343759046608, 10.735634214323635, 9.789644024908068, 8.803420689111713, 7.733422975910307, 6.823835421263734, 5.896208451754527, 4.886283338699364, 4.0492820582301965, 2.9816171023730336, 3.839856885697312, 4.7941418840244605, 5.740889478010813, 6.7619920411589005, 7.792069167619822, 8.818109005586631, 9.74647447191645, 10.736426562209607, 11.695711075968864, 11.899361424639075, 10.854880261265016, 9.874937471699363, 8.824483537141814, 7.8468712172509925, 6.79863456690137, 5.806262635391289, 4.85651888622251, 3.8657417661045903, 3.0039268682891667, 2.0562466685615197, 2.8940122204338383, 5.725639494302255, 6.750742031580508, 7.74447005715324, 8.763574671906042, 9.790316766997533, 10.800360376948863, 11.73841485462264, 11.886249348026881, 10.833326728748396, 9.883686390656372, 8.863793196055983, 7.870264741635066, 6.838872531465209, 5.8308797732575375, 4.868333192222593, 3.9137084255872416, 2.9121987313023383, 1.9473859569643075, 1.017500390582697, 1.9232043163006363, 6.732891832234227, 7.786940465065414, 8.712955696587423, 9.6470674610098, 10.702709299940425, 11.666051978000114, 11.886277218810951, 10.891478065027137, 9.87606421526301, 8.860286060930628, 7.927484183270389, 6.887784481039275, 5.923825213240332, 4.969615781913673, 3.9236146688624185, 2.961366993802228, 1.9105253849562018, 0.9344182548330947, 0.0, 0.9978463338894442, 7.785264513475115, 8.75682853039024, 9.698114331288117, 10.57966606978179, 11.584509902937079, 12.6059731618088, 12.77579302065832, 11.707472052508653, 10.758236948493478, 9.817464941555233, 8.767063100264709, 7.839218150847069, 6.871139341793495, 5.833382109233593, 4.87919494189112, 3.8503028017763348, 2.8572837579482884, 1.8794645990761516, 1.0032973956419815, 1.9523303830376335, 8.764820895561561, 9.74444126919057, 10.728387985165057, 11.651159705006089, 12.554244887928181, 13.545423004623201, 13.71877516627137, 12.733315550203939, 11.785753803789014, 10.74742492244837, 9.684050995047885, 8.637608547310847, 7.678663074517616, 6.72161780017904, 5.785820612594964, 4.828122951988327, 3.788505068940605, 2.8113362489535785, 1.9299435811658656, 2.8627402859890454, 9.745087289438677, 10.691180689777438, 11.753194729989836, 12.609823653506163, 13.570854012520599, 14.540699880671044, 14.647413473400425, 13.698404071648886, 12.640277625004082, 11.631011592344931, 10.57984765207115, 9.61798368016991, 8.728938783923558, 7.7665460150351215, 6.752293592998312, 5.761171183983942, 4.802793048354249, 3.825959747124411, 2.892375713788791, 3.8508588248102686, 10.685887831741582, 11.650319806653798, 12.618275926009519, 13.573618843620274, 14.56760746125514, 15.594390861978914, 15.63338990303382, 14.604929166833072, 13.568605123350448, 12.591435074391438, 11.526391233784597, 10.585499232726542, 9.739563528118373, 8.757125456128218, 7.7470557156236985, 6.720025716486278, 5.814648556343744, 4.823323308703857, 3.955738939100926, 4.889252169705501, 11.733610404539434, 12.701538994287237, 13.548077399414282, 14.55972971377954, 15.517865116557187, 16.57746475968514, 16.4881118028151, 15.478571801605208, 14.407398959016827, 13.479247776537798, 12.478205564913166, 11.554563436836329, 10.59648567569716, 9.63180186111132, 8.63968343646872, 7.694304357698945, 6.764910759376617, 5.835274448895311, 5.00581672983355, 5.902811330641483, 12.71088510071704, 13.712318083152798, 14.499341577643813, 15.50616136774398, 16.518386205932433, 17.52123602309648, 17.26039182922547, 16.32149652203777, 15.384455248788834, 14.448688665380864, 13.467037011175725, 12.544757298882567, 11.557148481602283, 10.65781715126036, 9.646910760316981, 8.62748593884442, 7.70557567647729, 6.820427323444476, 6.022179363022696, 6.935957770695325, 13.646926184810106, 12.94196334977681, 13.814736126199843, 14.793447486915065, 15.778560035309354, 16.773490905483033, 17.4936811437498, 17.285578105704772, 16.31203422339208, 15.369218078251473, 14.413355081927277, 13.521335393522762, 12.485851452896426, 11.544096197940322, 10.59047658772012, 9.601477568795119, 8.741893998085969, 7.8567934522444745, 6.994017397770312, 7.887643418232175], [8.05538901656582, 8.62157856022452, 9.612660937990691, 10.557679183977491, 11.497196565575326, 12.507494045538134, 13.38264604326805, 14.348647534939955, 15.367877025188559, 16.30659177784027, 17.23533125236422, 18.192763315123326, 18.359566769920757, 17.442375783829217, 16.50955441545166, 15.517872122999327, 14.46645866831224, 13.50373018485881, 12.625822726605033, 11.719918491138598, 7.052925689418538, 7.677022750674607, 8.649663330166945, 9.59000914042902, 10.572391352170907, 11.567294719284206, 12.427869668380989, 13.456258319543474, 14.471095831958236, 15.475929628397555, 16.476077387667257, 17.468716850417923, 17.367244206022576, 16.52348833021758, 15.572842195584492, 14.594115982667656, 13.554179514496418, 12.523277761152901, 11.598203020359371, 10.701269150407091, 6.046572026923382, 6.743991157203337, 7.686614024046111, 8.687005434024096, 9.68439737395478, 10.601473145581702, 11.46557766075794, 12.509688805078094, 13.468507041637984, 14.509194593835726, 15.548843554047357, 16.561462114207483, 16.329414960938088, 15.498876544102874, 14.69921198840593, 13.706361669663892, 12.642904769398033, 11.57921998446658, 10.639707527284413, 9.74200136500001, 5.03425291828282, 5.78623680630915, 6.749402660112898, 7.801804664554488, 8.679457074228075, 9.623830542549454, 10.525642615563791, 11.555276187588108, 12.539084158271002, 13.525212459607932, 14.482593530989309, 15.510234324104681, 15.343848778019323, 14.556540506342277, 13.664171116631776, 12.794090928731983, 11.741405942581961, 10.727172936112469, 9.71122344420811, 8.771257583780054, 3.988961317194658, 4.793790791660742, 5.771629870746549, 6.7631285488515225, 7.693823682550868, 8.621006244877147, 9.550684134450666, 10.589523419269877, 11.543379047398838, 12.516848589924587, 13.581550000538758, 14.584833194027413, 14.40024957068473, 13.57196642462345, 12.614796919640774, 11.81327420386055, 10.785256429555236, 9.795429370977292, 8.764197214389775, 7.819984164237484, 2.9268515855463315, 3.786612515342954, 4.81112905091131, 5.8136467718497435, 6.741284785013761, 7.7786767134303805, 8.746483443540026, 9.778873989901335, 10.840040175182894, 11.837216513518857, 12.841091516958777, 13.785286595890595, 13.435205778631707, 12.570752872237218, 11.594392760927734, 10.76344972849979, 9.743853976710962, 8.75941493213106, 7.763067590837012, 6.762427427604554, 1.8826594420675922, 2.8226163016763963, 3.793810316395091, 4.812351945470308, 5.775345309225651, 6.8240310929572106, 7.8059444125499535, 8.85722555110439, 9.82683187290457, 10.851043045032096, 11.922706860027981, 12.889103742108915, 12.490243664647906, 11.547120922229391, 10.615812402044936, 9.692937554854982, 8.669275804698117, 7.72644946432326, 6.72177996640304, 5.792714137878508, 0.9520308100872317, 2.0251526764012855, 2.9884853847049153, 4.040490502493437, 5.038437785683155, 5.978174047093953, 7.017646498222696, 8.045447780230244, 9.003731848666314, 10.063955589131908, 11.073705752933728, 12.049902509151348, 11.504980299803835, 10.566775665028722, 9.6422437360771, 8.698105756127113, 7.753138600759686, 6.768853010204411, 5.813607185158789, 4.8040612190934935, 1.8844494224796287, 2.9407549895188234, 3.920769714205071, 4.887620641431039, 5.8432787776905935, 6.825532385782317, 7.890632092769402, 8.826155997604832, 9.806424665172518, 10.829773093869775, 11.8476869107039, 11.508566330826568, 10.528993185184646, 9.602492406662211, 8.647751751652631, 7.720301865599048, 6.786288054184795, 5.820691788112741, 4.775501345650778, 3.8360204912947835, 2.926898731645375, 3.9829747215091262, 4.868232205995956, 5.86230839971944, 6.788250328574437, 7.7695213371528045, 8.705810460962374, 9.736911909768459, 10.726138351199817, 11.655976186421025, 11.73348054821308, 10.787490358797513, 9.80126702300116, 8.731269309799753, 7.808925524687117, 6.88129855517791, 5.8713734421227475, 4.890611767967406, 3.822946812110243, 2.842010551807868, 3.7962955501350164, 4.743043144121369, 5.764145707269456, 6.794222833730378, 7.820262671697188, 8.748628138027007, 9.738580228320162, 10.69786474207942, 11.716863219901056, 11.852726595154461, 10.872783805588808, 9.82232987103126, 8.844717551140437, 7.796480900790815, 6.804108969280733, 5.854365220111954, 4.863588099994034, 3.9152463893411342, 2.897576378298729, 1.896165886544394, 4.727793160412811, 5.752895697691064, 6.746623723263796, 7.765728338016597, 8.792470433108088, 9.80251404305942, 10.740568520733195, 11.629236377554363, 11.831173062637841, 10.881532724545817, 9.861639529945426, 8.86811107552451, 7.836718865354653, 6.828726107146982, 5.866179526112037, 4.911554759476686, 3.9100450651917824, 2.9452322908537516, 1.9429237898989453, 0.925357982411192, 5.735045498344782, 6.78909413117597, 7.71510936269798, 8.649221127120358, 9.704862966050982, 10.668205644110671, 11.638339831579101, 11.889324398916582, 10.873910549152455, 9.858132394820073, 8.925330517159834, 7.885630814928719, 6.921671547129776, 5.967462115803117, 4.921461002751863, 3.959213327691672, 2.908371718845646, 1.932264588722539, 0.9978463338894442, 0.0, 6.78741817958567, 7.758982196500796, 8.700267997398674, 9.581819735892347, 10.586663569047635, 11.608126827919357, 12.58360804000128, 12.705318386398096, 11.75608328238292, 10.815311275444676, 9.764909434154152, 8.837064484736512, 7.868985675682939, 6.831228443123037, 5.877041275780564, 4.848149135665778, 3.8551300918377325, 2.877310932965596, 1.9789610885964057, 0.9544840491481893, 7.766974561672116, 8.746594935301125, 9.730541651275615, 10.653313371116646, 11.556398554038738, 12.547576670733758, 13.504955246812436, 13.731161884093382, 12.783600137678457, 11.745271256337814, 10.68189732893733, 9.635454881200292, 8.67650940840706, 7.719464134068483, 6.7836669464844075, 5.825969285877771, 4.786351402830049, 3.8091825828430226, 2.90560727412029, 2.012055618208709, 8.747240955549232, 9.693334355887993, 10.755348396100391, 11.61197731961672, 12.573007678631155, 13.5428535467816, 14.506055197479949, 14.69625040553833, 13.638123958893527, 12.628857926234376, 11.577693985960595, 10.615830014059355, 9.726785117813002, 8.764392348924565, 7.750139926887755, 6.759017517873386, 5.800639382243693, 4.8238060810138546, 3.8680394067432156, 3.0422738902956117, 9.688041497852137, 10.652473472764353, 11.620429592120074, 12.575772509730829, 13.569761127365695, 14.59654452808947, 15.520540023467658, 15.602775500722517, 14.566451457239893, 13.589281408280883, 12.524237567674042, 11.583345566615987, 10.737409862007816, 9.754971790017663, 8.744902049513144, 7.717872050375723, 6.812494890233188, 5.8211696425933015, 4.931402632055351, 4.080667235190845, 10.735764070649989, 11.703692660397792, 12.550231065524837, 13.561883379890094, 14.520018782667742, 15.579618425795694, 16.452516159572713, 16.47641813549465, 15.405245292906272, 14.477094110427243, 13.476051898802611, 12.552409770725774, 11.594332009586603, 10.629648195000764, 9.637529770358164, 8.692150691588388, 7.762757093266061, 6.833120782784755, 5.981480422787975, 5.094226396126826, 11.713038766827594, 12.714471749263353, 13.501495243754368, 14.508315033854535, 15.520539872042987, 16.523389689207033, 17.466342866481817, 17.319342855927218, 16.38230158267828, 15.446534999270309, 14.46488334506517, 13.54260363277201, 12.554994815491726, 11.655663485149804, 10.644757094206424, 9.625332272733862, 8.703422010366733, 7.81827365733392, 6.997843055977121, 6.127372836180668, 12.64907985092066, 13.622002794600505, 14.494775571023538, 15.47348693173876, 16.45859948013305, 17.46094542197287, 18.39023246181711, 18.28342443959422, 17.309880557281524, 16.36706441214092, 15.411201415816722, 14.519181727412203, 13.483697786785868, 12.541942531829765, 11.588322921609564, 10.599323902684562, 9.739740331975412, 8.85463978613392, 7.9696810907247375, 7.079058483717518], [13.149627365214235, 13.715816908872936, 14.706899286639107, 15.651917532625905, 16.59143491422374, 17.528541654741552, 18.403693652471468, 18.278849795286835, 17.259620305038233, 16.32090555238652, 15.392166077862573, 14.511670815473403, 13.515168967244366, 12.551993879606965, 11.619172511229408, 10.627490218777075, 9.576076764089988, 8.613348280636558, 7.735440822382778, 6.825145073196774, 12.147164038066952, 12.771261099323022, 13.74390167881536, 14.684247489077435, 15.6647817085855, 16.588342328487624, 17.448917277584407, 17.55386227175949, 16.58397679185576, 15.579142995416444, 14.578995236146742, 13.586355773396075, 12.63816142544976, 11.63310642599533, 10.682460291362238, 9.703734078445402, 8.663797610274164, 7.632895856930648, 6.707821116137116, 5.810887246184836, 11.140810375571796, 11.838229505851752, 12.780852372694527, 13.781243782672512, 14.719128483023301, 15.62252075478512, 16.48662526996136, 16.607292757294108, 15.648474520734219, 14.73206857591518, 13.795989550321833, 12.778054994921147, 11.753928902998576, 10.79345767203829, 9.863805742756293, 8.815979765441638, 7.752522865175779, 6.6888380802443255, 5.749325623062159, 4.851619460777756, 10.128491266931235, 10.880475154957566, 11.843641008761313, 12.851517319554729, 13.700504683431491, 14.644878151752872, 15.54669022476721, 15.657056870664986, 14.673248899982092, 13.687120598645162, 12.729739527263785, 11.726827204818346, 10.768362720079812, 9.851121634277693, 8.878618206115357, 7.907957200255043, 6.855272214105021, 5.841039207635529, 4.820841539985856, 3.880875679557799, 9.083199665843074, 9.888029140309158, 10.865868219394965, 11.812834612916706, 12.714871291754285, 13.642053854080565, 14.571731743654084, 14.713758927532101, 13.75990329940314, 12.786433756877392, 11.75707711410917, 10.79128024497003, 9.82476351274522, 8.897698598169358, 7.940529093186682, 6.997238768387206, 5.965444891200653, 4.917577035510678, 3.8750425085452678, 2.9296022600152285, 8.021089934194746, 8.88085086399137, 9.900659125643248, 10.863352835914927, 11.73732386018044, 12.68687806708837, 13.654684797198016, 13.949785395619871, 12.888619210338312, 11.81916402525625, 10.81528902181633, 9.871093942884512, 8.859719720692196, 7.896485045783126, 6.920124934473642, 5.976966888198754, 4.957371136409927, 3.9729320918300264, 2.9765847505359773, 1.9759445873035197, 6.9768977907160075, 7.916854650324812, 8.88334039112703, 9.855065228716104, 10.77138438439233, 11.719631742096771, 12.701545061689513, 12.968288911164324, 11.998682589364144, 10.974471417236618, 9.902807602240733, 8.936410720159799, 7.914757606708395, 6.890466060166085, 5.959157539981631, 4.906454714553947, 3.882792964397082, 2.939966624022226, 1.9352971261020055, 1.0062312975774734, 6.046269158735647, 6.9544069691363, 7.857888296333753, 8.846105275593898, 9.738158221356747, 10.677894482767545, 11.717366933896288, 12.709840097470067, 12.837521457536917, 11.777297717071324, 10.767547553269504, 9.791350797051884, 8.793196072767037, 7.854991437991924, 6.791647554366181, 5.771864370669006, 4.824444451350137, 3.8401588607948622, 2.884913035749241, 1.9833569604921761, 5.11385054634325, 6.000320421382121, 6.889825499455297, 7.856676426681265, 8.81233456294082, 9.794588171032544, 10.800954724370342, 11.736478629205772, 12.716747296773457, 12.594807546496268, 11.576893729662144, 10.537932726424591, 9.55835958078267, 8.631858802260234, 7.6771181472506544, 6.749668261197071, 5.849357725152499, 4.9069996741672135, 3.9475178666030155, 2.951397688290886, 4.0601086105089195, 4.941741106010773, 5.942363007664412, 6.936439201387896, 7.879308532060156, 8.860579540638524, 9.796868664448093, 10.827970113254178, 11.817196554685536, 12.747034389906744, 12.48759401019737, 11.541603820781802, 10.601304272859322, 9.624628511524588, 8.675650300966051, 7.748023331456844, 6.821059249865282, 5.84029757570994, 4.900072400143551, 3.9454076277778016, 3.0501853421522496, 3.9969329361386023, 5.01803549928669, 5.993210118426087, 6.986514819843247, 7.914880286173067, 8.950621005945079, 9.873881701920968, 10.892880179742605, 11.937604308649407, 12.91754709821506, 12.506764308548055, 11.623153032991384, 10.559416920533526, 9.712341470004729, 8.817625563442695, 7.841600822460056, 6.84311284499747, 5.825442833955065, 4.891252293041275, 2.118687731874455, 3.0580138001653943, 3.9981948002155296, 4.936757231183973, 5.963499326275464, 6.933033334877162, 7.948632713532045, 8.942510066446026, 9.920415146695793, 10.98596839597985, 11.928424949591289, 12.921953404012205, 12.538083138367577, 11.530090380159905, 10.751278318182564, 9.796653551547212, 8.795143857262309, 7.8834860080517295, 6.864189111933888, 5.862060197174477, 1.0523726812408878, 2.0218153666804883, 3.029709160781346, 3.9638209252037244, 5.0194627641343486, 5.982805442194038, 6.952939629662468, 7.947738783446281, 8.963152633210408, 9.97893078754279, 10.91173266520303, 11.951432367434144, 12.915391635233087, 12.518575367142263, 11.708879182337533, 10.746631507277343, 9.695789898431316, 8.719682768308209, 7.785264513475114, 6.78741817958567, 0.0, 0.9715640169151264, 2.0445505260806516, 3.1180066420912547, 4.122850475246542, 5.144313734118263, 6.213276047191493, 7.28159701534116, 8.230832119356336, 9.17160412629458, 10.222005967585105, 11.149850917002745, 12.167910764606253, 13.221238451541428, 12.664459455366234, 11.63556731525145, 10.642548271423403, 9.664729112551266, 8.766379268182074, 7.741902228733859, 0.9795563820864469, 1.9591767557154571, 2.9998135282711487, 4.073260772734523, 5.04017250159647, 6.07840480302526, 7.035783379103939, 8.065993377364947, 9.030746389177565, 10.071507600939643, 11.143410326387531, 12.12151966001771, 13.080465132810943, 14.03751040714952, 13.571085126070079, 12.613387465463441, 11.57376958241572, 10.596600762428693, 9.693025453705959, 8.799473797794379, 1.9598227759635638, 2.9059161763023247, 3.9679302165147226, 4.939171048778752, 5.966664646430342, 6.936510514580788, 7.917283515882901, 8.866292917634441, 9.934254817146751, 10.943520849805903, 11.994684790079685, 12.956548761980924, 13.99091132341454, 14.975501484835268, 14.537558106473426, 13.546435697459057, 12.588057561829364, 11.611224260599526, 10.655457586328884, 9.829692069881283, 2.9006233182664682, 3.8650552931786843, 4.833011412534405, 5.788354330145159, 6.782342947780026, 7.8481793159540905, 8.851428200006684, 9.86322903648048, 10.899553079963104, 11.876723128922114, 12.941228371793132, 13.924064314537556, 14.898409045979855, 15.938052627198463, 15.532320229098813, 14.505290229961393, 13.599913069818859, 12.608587822178972, 11.71882081164102, 10.868085414776516, 3.9731953272805836, 4.916274480812122, 5.762812885939169, 6.774465200304427, 7.732600603082075, 8.792200246210026, 9.783404336111738, 10.792944337321634, 11.864117179910014, 12.792268362389043, 13.793310574013676, 14.803181241670952, 15.783290074998238, 16.747973889584078, 16.424947949943835, 15.47956887117406, 14.550175272851732, 13.620538962370427, 12.768898602373644, 11.881644575712498, 4.950470023458189, 5.927053569677684, 6.7140770641687, 7.720896854268867, 8.733121692457319, 9.735971509621365, 10.67892468689615, 11.617819994083847, 12.554861267332782, 13.490627850740752, 14.563645775769043, 15.546567531997587, 16.53417634927787, 17.519913216658193, 17.432175273792094, 16.412750452319532, 15.490840189952404, 14.605691836919592, 13.78526123556279, 12.914791015766339, 5.886511107551256, 6.874444077615016, 7.757042830057827, 8.773172339947338, 9.750640514687595, 10.6735272423872, 11.732051687783322, 12.58190157775085, 13.482440241936027, 14.447438969283592, 15.403301965607788, 16.452643513411438, 17.462879320572014, 18.518785295562694, 18.375741101195235, 17.38674208227023, 16.527158511561083, 15.64205796571959, 14.757099270310407, 13.866476663303189], [13.83778276754682, 12.849818806762991, 13.840901184529162, 14.78591943051596, 15.69330532277346, 16.627911055422913, 17.50306305315283, 17.478288282040204, 16.459058791791602, 15.52034403913989, 14.591604564615942, 13.711109302226774, 12.714607453997736, 11.815310019404578, 10.882488651027021, 9.890806358574688, 8.910255186429357, 7.947526702975926, 7.115771565841424, 7.796709090111901, 12.835319440399537, 11.905262997213077, 12.877903576705416, 13.81824938696749, 14.76415110926686, 15.687711729168985, 16.548286678265768, 17.576675329428255, 17.39882274113817, 16.44718111572879, 15.550559253061868, 14.557919790311201, 13.609725442364885, 12.604670442910455, 11.654024308277364, 10.675298095360528, 9.63536162718929, 8.604459873845773, 7.679385133052242, 6.782451263099962, 11.972826034937158, 10.972231403741807, 11.90806279076451, 12.908454200742494, 13.818497883704662, 14.72189015546648, 15.58599467064272, 16.630105814962874, 16.620038537649346, 15.703632592830308, 14.767553567236959, 13.749619011836273, 12.725492919913702, 11.765021688953414, 10.83536975967142, 9.787543782356764, 8.724086882090905, 7.6604020971594515, 6.720889639977285, 5.823183477692882, 11.060232933942718, 10.01447705284762, 10.970851426831295, 11.950886720236086, 12.799874084112853, 13.744247552434233, 14.64605962544857, 15.675693197472887, 15.64481291689722, 14.65868461556029, 13.701303544178911, 12.698391221733472, 11.739926736994938, 10.822685651192817, 9.850182223030481, 8.879521217170169, 7.826836231020147, 6.812603224550655, 5.792405556900982, 4.852439696472925, 10.0547636827582, 9.022031038199213, 9.993078637464947, 10.912204013598064, 11.814240692435646, 12.741423254761926, 13.671101144335445, 14.709940429154656, 14.731467316318266, 13.757997773792518, 12.728641131024297, 11.762844261885157, 10.796327529660346, 9.869262615084484, 8.912093110101809, 7.968802785302332, 6.937008908115779, 5.889141052425804, 4.846606525460394, 3.9011662769303546, 8.992653951109872, 8.014852761881425, 9.00002852632461, 9.962722236596285, 10.836693260861802, 11.78624746776973, 12.754054197879375, 13.775147282599766, 13.860183227253438, 12.790728042171375, 11.786853038731456, 10.842657959799638, 9.831283737607322, 8.868049062698253, 7.891688951388769, 6.948530905113881, 5.928935153325053, 4.944496108745153, 3.948148767451104, 2.9475086042186462, 7.9484618076311335, 7.050856548214867, 7.98270979180839, 8.954434629397461, 9.870753785073692, 10.81900114277813, 11.800914462370873, 12.766022451018317, 12.970246606279268, 11.946035434151744, 10.874371619155859, 9.907974737074925, 8.886321623623521, 7.862030077081212, 6.930721556896758, 5.878018731469074, 4.8543569813122085, 3.9115306409373525, 2.906861143017132, 1.9777953144926, 7.0178331756507735, 6.053776369817659, 6.9572576970151125, 7.945474676275256, 8.837527622038106, 9.777263883448905, 10.816736334577648, 11.809209498151425, 12.767493566587495, 12.748861733986452, 11.739111570184631, 10.762914813967011, 9.764760089682165, 8.826555454907052, 7.763211571281308, 6.7434283875841325, 5.796008468265264, 4.811722877709989, 3.856477052664367, 2.9549209774073026, 6.085414563258377, 5.09968982206348, 5.989194900136656, 6.956045827362624, 7.911703963622179, 8.893957571713903, 9.900324125051702, 10.835848029887131, 11.816116697454817, 12.839465126152074, 12.54845774657727, 11.509496743339717, 10.529923597697795, 9.60342281917536, 8.64868216416578, 7.721232278112198, 6.820921742067627, 5.8785636910823404, 4.919081883518142, 3.9229617052060126, 5.031672627424046, 4.041110506692133, 5.041732408345771, 6.035808602069255, 6.978677932741515, 7.959948941319883, 8.896238065129452, 9.927339513935538, 10.916565955366895, 11.846403790588104, 12.912113335311076, 12.513167837696928, 11.572868289774448, 10.596192528439714, 9.64721431788118, 8.719587348371972, 7.792623266780408, 6.811861592625067, 5.871636417058677, 4.916971644692929, 4.0217493590673765, 3.0963023368199627, 4.082764692212025, 5.02164610151096, 6.014950802928119, 6.943316269257939, 7.979056989029951, 8.902317685005844, 9.92131616282748, 10.966040291734283, 11.945983081299936, 12.904608182603829, 12.59471704990651, 11.530980937448652, 10.683905486919857, 9.789189580357823, 8.813164839375183, 7.814676861912596, 6.797006850870191, 5.862816309956402, 3.0902517487895813, 2.086449783250268, 3.0266307833004027, 3.9651932142688464, 4.991935309360337, 5.961469317962035, 6.977068696616918, 7.9709460495309, 8.948851129780667, 10.014404379064723, 10.956860932676163, 11.95038938709708, 12.869045741660514, 12.501654397075031, 11.72284233509769, 10.768217568462338, 9.766707874177435, 8.855050024966856, 7.835753128849014, 6.833624214089604, 2.0239366981560143, 1.0502513497653618, 2.058145143866219, 2.9922569082885975, 4.047898747219222, 5.011241425278911, 5.981375612747341, 6.976174766531155, 7.991588616295282, 9.007366770627664, 9.940168648287903, 10.979868350519018, 11.943827618317961, 12.898037049644621, 12.68044319925266, 11.718195524192469, 10.667353915346443, 9.691246785223335, 8.75682853039024, 7.758982196500797, 0.9715640169151264, 0.0, 1.072986509165525, 2.146442625176128, 3.1512864583314153, 4.172749717203136, 5.241712030276365, 6.310032998426032, 7.259268102441208, 8.200040109379453, 9.250441950669977, 10.178286900087617, 11.196346747691125, 12.2496744346263, 13.203861601968773, 12.607131332166574, 11.614112288338529, 10.636293129466392, 9.737943285097202, 8.713466245648986, 1.9511203990015733, 0.9876127388003306, 2.028249511356022, 3.101696755819397, 4.068608484681344, 5.106840786110134, 6.064219362188813, 7.09442936044982, 8.059182372262438, 9.099943584024516, 10.171846309472404, 11.149955643102583, 12.108901115895815, 13.065946390234393, 14.001743577818468, 13.584951482378568, 12.545333599330846, 11.56816477934382, 10.664589470621086, 9.771037814709505, 2.93138679287869, 2.0599222231414305, 3.0991429368875822, 4.060360704319472, 5.085217609273762, 6.055063477424208, 7.0358364787263215, 7.98484588047786, 9.034892404613467, 10.044158437272618, 11.095322377546399, 12.057186349447639, 13.091548910881254, 14.076139072301983, 14.968216558221815, 14.517999714374183, 13.55962157874449, 12.582788277514652, 11.627021603244012, 10.801256086796407, 3.8721873351815947, 3.1102027134096195, 4.032449899287776, 4.987792816898531, 5.9817814345333975, 7.047617802707462, 8.05032130471403, 8.981781999323898, 10.018106042806522, 10.995276091765533, 12.041865959259846, 13.02470190200427, 13.99904663344657, 15.038690214665177, 15.980812449432575, 15.476854246876519, 14.571477086733987, 13.5801518390941, 12.690384828556148, 11.83964943169164, 4.9447593441957105, 4.161421901043058, 4.96225137269254, 5.973903687057797, 6.932039089835445, 7.991638732963396, 8.982297440819085, 9.97153199089265, 11.04270483348103, 11.97085601596006, 12.971898227584692, 13.981768895241968, 14.961877728569254, 15.926561543155094, 16.918679967797694, 16.451132888089187, 15.52173928976686, 14.592102979285555, 13.740462619288772, 12.853208592627622, 5.922034040373316, 5.172200989908619, 5.913515550922071, 6.920335341022238, 7.9325601792106895, 8.935409996374736, 9.87836317364952, 10.817258480837218, 11.754299754086153, 12.690066337494123, 13.763084262522414, 14.746006018750958, 15.733614836031242, 16.71935170341156, 17.777642175225278, 17.38431446923466, 16.462404206867532, 15.57725585383472, 14.738696234898375, 13.785584447285697, 6.858075124466383, 6.119591497845952, 6.956481316811198, 7.972610826700709, 8.950079001440965, 9.87296572914057, 10.931490174536693, 11.78134006450422, 12.681878728689398, 13.646877456036961, 14.602740452361157, 15.652082000164807, 16.662317807325383, 17.718223782316063, 17.572989716302892, 16.720945559073797, 15.826272430920168, 14.86365226539499, 13.916297219993549, 14.737270094822547], [14.698705284004163, 13.710741323220335, 13.000917979042752, 13.872628012193317, 14.657503305328385, 15.592109037977838, 16.467261035707754, 16.480312424561124, 15.461082934312522, 14.52236818166081, 13.593628707136862, 12.713133444747692, 11.716631596518654, 10.817334161925496, 9.88451279354794, 8.892830501095606, 7.912279328950277, 6.949550845496846, 7.796263582620036, 8.750359215913475, 13.69624195685688, 12.76618551367042, 11.964612158382772, 12.904957968644847, 13.728349091821785, 14.65190971172391, 15.512484660820693, 16.54087331198318, 16.40084688365909, 15.449205258249709, 14.64065637592491, 13.648016913174244, 12.708954160416836, 11.751369369146696, 10.836313337411056, 9.85758712449422, 8.872327104672667, 7.930003269202756, 8.752371642217769, 7.855437772265488, 12.833748551394502, 11.83315392019915, 10.912945228333887, 11.913336638311872, 12.782695866259587, 13.686088138021406, 14.550192653197644, 15.594303797517798, 16.55312203407769, 16.497877045108734, 15.631585627308706, 14.594396805205058, 13.721310941289657, 12.7520432999113, 11.810742955198931, 10.86053029152229, 9.797073391256431, 8.733388606324977, 7.793876149142811, 6.896169986858408, 11.921155450400061, 10.875399569304964, 9.975733864400674, 10.955769157805465, 11.764072066667778, 12.708445534989158, 13.610257608003495, 14.639891180027812, 15.623699150710706, 15.731671124725818, 14.774290053344439, 13.771377730899, 12.812913246160466, 11.895672160358343, 10.923168732196007, 9.952507726335694, 8.899822740185673, 7.885589733716181, 6.865392066066508, 5.925426205638451, 10.932152281991826, 9.882953554656556, 8.997961075034326, 9.917086451167442, 10.778438674990571, 11.705621237316851, 12.63529912689037, 13.674138411709581, 14.627994039838542, 14.830984282958045, 13.801627640189825, 12.835830771050684, 11.869314038825873, 10.942249124250008, 9.985079619267333, 9.041789294467858, 8.009995417281305, 6.96212756159133, 5.91959303462592, 4.97415278609588, 9.874877039306154, 8.875775278338768, 8.004910963893987, 8.967604674165663, 9.800891243416727, 10.750445450324655, 11.7182521804343, 12.727399745151514, 13.714968401929479, 13.863714551336903, 12.859839547896984, 11.915644468965166, 10.90427024677285, 9.941035571863777, 8.964675460554293, 8.021517414279405, 7.001921662490579, 6.017482617910678, 5.021135276616629, 4.020495113384171, 8.830684895827416, 7.91177906467221, 6.9875922293777695, 7.9593170669668405, 8.834951767628617, 9.783199125333056, 10.765112444925798, 11.718274913570065, 12.672689839896869, 13.019021943317272, 11.947358128321387, 10.980961246240453, 9.95930813278905, 8.93501658624674, 8.003708066062284, 6.951005240634599, 5.927343490477734, 4.984517150102878, 3.979847652182657, 3.050781823658125, 7.9000562638470555, 6.914698886275002, 5.962140134584492, 6.950357113844635, 7.801725604593031, 8.74146186600383, 9.780934317132573, 10.761461960703173, 11.719746029139243, 12.779969769604836, 12.812098079350156, 11.835901323132536, 10.837746598847689, 9.899541964072576, 8.836198080446833, 7.816414896749658, 6.8689949774307895, 5.884709386875514, 4.929463561829892, 4.027907486572828, 6.967637651454658, 5.960612338520823, 4.9940773377060355, 5.9609282649320035, 6.875901946177104, 7.858155554268828, 8.852576587603448, 9.788100492438877, 10.768369160006563, 11.791717588703822, 12.809631405537946, 12.582483252505243, 11.602910106863321, 10.676409328340887, 9.721668673331306, 8.794218787277723, 7.893908251233151, 6.9515502002478655, 5.992068392683667, 4.995948214371539, 5.913895715620328, 4.9020330231494755, 4.04661484591515, 4.988061064621, 5.93093039529326, 6.912201403871628, 7.848490527681197, 8.879591976487283, 9.868818417918641, 10.79865625313985, 11.860931098850509, 12.796782161204554, 12.645854798939974, 11.66917903760524, 10.720200827046703, 9.792573857537496, 8.865609775945934, 7.884848101790592, 6.888891008729004, 5.858257445590806, 4.903972447263658, 3.957224853277305, 3.0097781830464996, 3.948659592345435, 4.941964293762595, 5.870329760092415, 6.906070479864427, 7.829331175840317, 8.848329653661953, 9.893053782568755, 10.872996572134408, 11.8316216734383, 12.80405791828077, 12.603967446614178, 11.75689199608538, 10.862176089523347, 9.886151348540707, 8.82318261365102, 7.805512602608615, 6.80410211085428, 4.015672450573471, 2.9473722997076104, 1.9536442741348778, 2.8922067051033213, 3.918948800194812, 4.88848280879651, 5.904082187451394, 6.897959540365374, 7.8758646206151415, 8.941417869899198, 9.883874423510635, 10.877402877931551, 11.796059232494986, 12.804051990702659, 12.795828844263214, 11.841204077627863, 10.839694383342959, 9.811772718593078, 8.792475822475236, 7.774910014987482, 3.0969232073215394, 2.0309042947280984, 0.9851586347006942, 1.9192703991230724, 2.9749122380536965, 3.938254916113386, 4.908389103581816, 5.903188257365629, 6.918602107129756, 7.934380261462137, 8.867182139122376, 9.90688184135349, 10.870841109152433, 11.825050540479094, 12.871051653530348, 12.659481325090347, 11.608639716244321, 10.632532586121213, 9.698114331288119, 8.700267997398674, 2.0445505260806516, 1.072986509165525, 0.0, 1.073456116010603, 2.0782999491658902, 3.099763208037611, 4.168725521110841, 5.237046489260508, 6.186281593275684, 7.1270536002139275, 8.177455441504453, 9.105300390922093, 10.123360238525601, 11.176687925460776, 12.13087509280325, 13.182796729465277, 12.555398089236407, 11.57757893036427, 10.679229085995079, 9.654752046546863, 3.0241069081670986, 2.0605992479658557, 1.0302736538769404, 2.103720898340315, 3.048034934156992, 4.039213050852012, 4.99659162693069, 6.026801625191697, 6.991554637004315, 8.032315848766393, 9.104218574214281, 10.076969133937059, 11.035914606730291, 11.992959881068868, 12.928757068652944, 13.886454729259581, 13.486619400228724, 12.509450580241698, 11.605875271518963, 10.712323615607382, 4.004373302044216, 3.1329087323069555, 2.1011670794085004, 3.0623848468403905, 4.06464405874941, 5.034489926899856, 5.997691577598204, 6.9467009793497425, 7.967264669355345, 8.976530702014497, 10.027694642288278, 10.989558614189518, 12.023921175623133, 13.008511337043862, 13.895230049056291, 14.819502961255196, 14.500907379642369, 13.52407407841253, 12.568307404141889, 11.742541887694284, 4.94517384434712, 4.0024301611644155, 3.034474041808695, 3.9898169594194495, 4.983805577054316, 6.04964194522838, 7.012176403585912, 7.94363709819578, 8.959576695723076, 9.936746744682086, 10.974238224001725, 11.95707416674615, 12.931418898188449, 13.971062479407056, 14.90782594026705, 15.778357493757532, 15.512762887631864, 14.521437639991976, 13.631670629454025, 12.780935232589517, 6.017745853361236, 5.019933254157845, 3.9642755152134592, 4.9759278295787155, 5.934063232356364, 6.993662875484314, 7.944152539690967, 8.933387089764533, 10.004559932352914, 10.932711114831942, 11.926052555130294, 12.926138370855936, 13.906247204183222, 14.870931018769062, 15.84903360896879, 16.794412687738564, 16.463025090664736, 15.533388780183431, 14.681748420186649, 13.794494393525499, 6.87568416617489, 5.852693006687232, 4.91553969344299, 5.922359483543157, 6.934584321731608, 7.937434138895654, 8.880387316170438, 9.819282623358136, 10.756323896607071, 11.692090480015041, 12.765108405043332, 13.748030161271876, 14.73563897855216, 15.721375845932481, 16.779666317746198, 16.659135171579422, 15.949299334206204, 15.060035188708579, 15.599618751355719, 14.64650696374304, 7.8117252502679575, 6.800083514624564, 5.958505459332118, 6.974634969221629, 7.9521031439618834, 8.874989871661489, 9.933514317057611, 10.783364207025139, 11.683902871210316, 12.648901598557881, 13.604764594882077, 14.654106142685727, 15.664341949846303, 16.720247924836983, 16.537187698857817, 15.685143541628722, 14.912981012597525, 14.02366905990858, 14.777219736450892, 15.59819261127989], [15.580257022497836, 14.592293061714008, 13.882469717536425, 13.041669481587451, 13.6708315149773, 14.605437247626753, 15.480589245356668, 15.460742293829007, 14.441512803580405, 13.502798050928693, 12.574058576404745, 11.693563314015575, 10.697061465786538, 9.861740328893756, 8.9289189605162, 7.937236668063865, 7.08353363977319, 7.849782182076748, 8.696494919199939, 9.650590552493377, 14.577793695350554, 13.647737252164093, 12.846163896876446, 12.073999438038982, 12.7416773014707, 13.665237921372825, 14.525812870469608, 15.554201521632093, 15.381276752926972, 14.429635127517592, 13.621086245192794, 12.628446782442127, 11.68938402968472, 10.795775536114956, 9.880719504379314, 8.901993291462478, 8.04358141549558, 8.830234605782657, 9.694755950730707, 8.797822080778428, 13.715300289888175, 12.714705658692823, 11.79449696682756, 11.053544691070305, 11.796024075908502, 12.69941634767032, 13.56352086284656, 14.607632007166712, 15.566450243726603, 15.478306914376617, 14.61201549657659, 13.574826674472941, 12.727213274769207, 11.796449466879558, 10.85514912216719, 9.932420062031241, 9.014630962259407, 9.675772914837916, 8.73626045765575, 7.838554295371347, 12.802707188893734, 11.756951307798637, 10.857285602894347, 10.042972705694039, 10.777400276316692, 11.721773744638073, 12.62358581765241, 13.653219389676726, 14.637027360359621, 15.62315566169655, 15.653695257691115, 14.626054464575743, 13.71277945768797, 12.738785504640155, 11.852769929703488, 10.882108923843175, 9.842207048698612, 8.827974042229119, 7.807776374579447, 6.86781051415139, 11.813704020485499, 10.76450529315023, 9.879512813527999, 9.004289999056017, 9.791766884639486, 10.718949446965766, 11.648627336539285, 12.687466621358496, 13.641322249487457, 14.614791792013206, 14.875083756200427, 13.909286887061286, 12.942770154836476, 12.00535197459298, 11.010758708239429, 10.046921848963203, 9.01512797177665, 7.967260116086676, 6.924725589121266, 5.979285340591226, 10.756428777799828, 9.757327016832441, 8.88646270238766, 8.054808222054238, 8.814219453065641, 9.763773659973571, 10.731580390083217, 11.740727954800429, 12.728296611578394, 13.69640269016007, 13.933295663907586, 12.989100584975768, 11.977726362783452, 11.014491687874381, 10.038131576564897, 9.094973530290009, 8.075377778501181, 7.090938733921281, 6.0945913926272315, 5.093951229394774, 9.712236634321089, 8.793330803165883, 7.869143967871443, 7.046520614855414, 7.8482799772775325, 8.796527334981972, 9.778440654574714, 10.73160312321898, 11.686018049545783, 12.710229221673309, 13.020814244331989, 12.054417362251055, 11.032764248799651, 10.008472702257341, 9.077164182072886, 8.024461356645201, 7.000799606488336, 6.05797326611348, 5.05330376819326, 4.124237939668728, 8.781608002340729, 7.796250624768676, 6.843691873078165, 6.037560661733209, 6.8150538142419474, 7.754790075652745, 8.794262526781488, 9.774790170352087, 10.733074238788157, 11.793297979253751, 12.803048143055571, 12.82546010658162, 11.827305382296773, 10.88910074752166, 9.825756863895917, 8.805973680198742, 7.8585537608798735, 6.874268170324598, 5.919022345278976, 4.909476379213681, 7.849189389948332, 6.8421640770144965, 5.875629076199709, 5.048131812820577, 5.889230155826021, 6.871483763917745, 7.865904797252364, 8.801428702087794, 9.781697369655479, 10.805045798352737, 11.82295961518686, 12.813781465210683, 12.592468890312405, 11.66596811178997, 10.71122745678039, 9.783777570726807, 8.883467034682235, 7.9411089836969495, 6.918223564076228, 5.877517107012391, 6.795447454114002, 5.78358476164315, 4.928166584408824, 4.0013892742699175, 4.944258604942178, 5.9255296135205455, 6.861818737330115, 7.892920186136201, 8.88214662756756, 9.811984462788768, 10.874259308499425, 11.810110370853472, 12.817453249660122, 12.658737821054324, 11.709759610495787, 10.78213264098658, 9.818869377235183, 8.83810770307984, 7.7704427472226785, 6.73980918408448, 5.785524185757332, 4.838776591770979, 3.891329921540173, 2.961987801994352, 3.9552925034115116, 4.883657969741331, 5.9193986895133435, 6.842659385489235, 7.86165786331087, 8.906381992217671, 9.886324781783324, 10.844949883087219, 11.817386127929689, 12.788053659977956, 12.710173311774398, 11.760429562605617, 10.769652442487697, 9.704734352144694, 8.687064341102289, 7.685653849347954, 4.8972241890671455, 3.828924038201284, 2.8351960126285514, 1.905534914752238, 2.932277009843729, 3.901811018445427, 4.91741039710031, 5.911287750014291, 6.88919283026406, 7.954746079548116, 8.897202633159553, 9.89073108758047, 10.809387442143905, 11.817380200351577, 12.779926781386521, 12.724705171574852, 11.723195477289948, 10.693324457086751, 9.67402756096891, 8.656461753481157, 3.9784920999623923, 2.9124560332217717, 1.8667103731943675, 0.9325986087719893, 1.9882404477026137, 2.951583125762303, 3.9217173132307326, 4.916516467014547, 5.931930316778674, 6.9477084711110555, 7.880510348771294, 8.920210051002408, 9.884169318801352, 10.838378750128012, 11.884379863179266, 12.846627538239456, 12.490191454737996, 11.514084324614888, 10.579666069781794, 9.58181973589235, 3.1180066420912547, 2.146442625176128, 1.073456116010603, 0.0, 1.0048438331552874, 2.0263070920270083, 3.095269405100238, 4.163590373249905, 5.11282547726508, 6.0535974842033236, 7.103999325493849, 8.031844274911489, 9.049904122514997, 10.103231809450172, 11.057418976792645, 12.109340613454673, 13.102359657282719, 12.459130668857945, 11.560780824488754, 10.536303785040538, 4.097563024177702, 3.134055363976459, 2.1037297698875435, 1.0714936352242983, 1.9745788181463895, 2.9657569348414095, 3.9231355109200883, 4.953345509181096, 5.9180985209937145, 6.958859732755792, 8.03076245820368, 9.003513017926455, 9.962458490719687, 10.919503765058264, 11.85530095264234, 12.812998613248977, 13.852616496296699, 13.391002318735373, 12.487427010012638, 11.593875354101057, 5.009505856539562, 4.063412456200801, 3.001398415988403, 2.0301575837243737, 2.991187942738807, 3.961033810889253, 4.924235461587601, 5.87324486333914, 6.893808553344744, 7.903074586003895, 8.954238526277676, 9.916102498178915, 10.950465059612531, 11.93505522103326, 12.821773933045687, 13.746046845244592, 14.753152264201747, 14.405625816906205, 13.449859142635564, 12.62409362618796, 5.867093472656534, 4.902661497744318, 3.9347053783885975, 3.0031676527146134, 3.99715627034948, 5.014724792197123, 5.93872028757531, 6.870180982185178, 7.886120579712475, 8.863290628671486, 9.900782107991123, 10.883618050735548, 11.857962782177847, 12.897606363396454, 13.834369824256447, 14.704901377746928, 15.716399287395879, 15.402989378485653, 14.513222367947698, 13.662486971083194, 6.93966548167065, 5.920164590737747, 4.864506851793362, 4.0203339965469755, 4.978469399324624, 6.038069042452574, 6.870696423680365, 7.859930973753931, 8.931103816342311, 9.85925499882134, 10.852596439119692, 11.852682254845334, 12.83279108817262, 13.79747490275846, 14.775577492958186, 15.720956571727962, 16.05900572070101, 16.414940518677106, 15.563300158680322, 14.676046132019176, 7.775915502754793, 6.752924343267134, 5.815771030022892, 5.015325896423635, 5.978990488699868, 6.981840305863914, 7.891692654244578, 8.79971249262602, 9.736753765874955, 10.672520349282925, 11.745538274311215, 12.72846003053976, 13.716068847820043, 14.701805715200365, 15.760096187014081, 15.672463381228336, 15.118340803600338, 15.941586927202252, 16.48117048984939, 15.528058702236713, 8.71195658684786, 7.700314851204467, 6.858736795912019, 6.07650537634667, 6.9965093109301435, 7.919396038629749, 8.950922336591294, 9.763794076293022, 10.6643327404782, 11.629331467825764, 12.58519446414996, 13.63453601195361, 14.644771819114187, 15.700677794104864, 15.550515908506734, 14.698471751277637, 14.08202248199166, 14.905220798402253, 15.658771474944565, 16.47974434977356], [16.585100855653124, 15.597136894869296, 14.774186091819919, 13.71464050703522, 12.775123125437386, 13.709728858086837, 14.584880855816753, 14.455898460673719, 13.436668970425117, 12.497954217773405, 11.569214743249457, 10.68871948086029, 9.692217632631252, 8.893935181423899, 7.969158865799268, 7.024892481220081, 7.948686718401941, 8.714935260705499, 9.56164799782869, 10.515743631122128, 15.582637528505842, 14.652581085319381, 13.768696933934748, 12.828351123672673, 11.845968911930786, 12.769529531832909, 13.630104480929692, 14.658493132092177, 14.376432919771684, 13.424791294362304, 12.616242412037508, 11.623602949286841, 10.684540196529433, 9.827970388645099, 8.96837531753553, 7.989649104618694, 8.908734494124332, 9.695387684411408, 10.559909029359458, 9.662975159407178, 14.720144123043463, 13.719549491848111, 12.799340799982849, 11.821415076872668, 10.900315686368588, 11.803707958130405, 12.667812473306643, 13.711923617626796, 14.670741854186687, 14.473463081221329, 13.607171663421303, 12.569982841317655, 11.722369441613921, 10.866397836526195, 9.942804935323405, 9.020075875187457, 9.879784040888158, 10.540925993466667, 9.6014135362845, 8.703707374000098, 13.807551022049022, 12.761795140953925, 11.862129436049635, 10.810843091496402, 9.881691886776778, 10.826065355098157, 11.727877428112494, 12.75751100013681, 13.741318970819705, 14.727447272156635, 14.64885142453583, 13.621210631420457, 12.707935624532684, 11.808733874286792, 10.940425742859704, 9.969764736999391, 10.707360127327362, 9.69312712085787, 8.672929453208198, 7.732963592780141, 12.818547853640787, 11.769349126305517, 10.884356646683287, 9.826753628798919, 8.896058495099572, 9.82324105742585, 10.752918946999369, 11.79175823181858, 12.740908138341982, 13.714377680867731, 14.716508857674603, 14.556757591268772, 13.651534831867277, 12.793307956005618, 11.87591178686818, 10.912074927591954, 9.8802810504054, 8.832413194715427, 7.789878667750017, 6.844438419219977, 11.761272610955114, 10.76217084998773, 9.891306535542947, 8.923852558691786, 7.918511063525728, 8.868065270433657, 9.835872000543302, 10.815171026582203, 11.802739683360167, 12.770845761941843, 13.774720765381762, 13.993944418131056, 12.98257019593874, 12.019335521029669, 11.042975409720185, 10.099817363445297, 9.08022161165647, 8.095782567076567, 7.099435225782519, 6.098795062550061, 10.717080467476375, 9.798174636321171, 8.873987801026729, 7.9155649514929625, 6.952571587737618, 7.900818945442058, 8.8827322650348, 9.806046195000754, 10.760461121327557, 11.784672293455081, 12.856336108450966, 13.059261195406343, 12.03760808195494, 11.01331653541263, 10.082008015228174, 9.029305189800489, 8.005643439643624, 7.062817099268767, 6.058147601348547, 5.129081772824015, 9.786451835496015, 8.801094457923963, 7.848535706233452, 6.917292707891751, 5.919345424702033, 6.859081686112831, 7.898554137241574, 8.849233242133861, 9.807517310569931, 10.826477387586037, 11.836227551387857, 12.812424307605477, 12.832149215452059, 11.893944580676946, 10.830600697051203, 9.810817513354028, 8.86339759403516, 7.879112003479885, 6.923866178434263, 5.914320212368968, 8.854033223103619, 7.847007910169783, 6.880472909354996, 5.94917990254566, 4.993521766286106, 5.975775374377831, 6.941982946657517, 7.875871773869567, 8.856140441437251, 9.835082308562662, 10.852996125396785, 11.836271209872935, 12.815844355514857, 12.670811944945257, 11.716071289935677, 10.788621403882093, 9.888310867837522, 8.945952816852236, 7.923067397231515, 6.882360940167678, 7.800291287269288, 6.788428594798436, 5.933010417564111, 4.991419546074523, 4.048550215402263, 5.0016077629256985, 5.937896886735268, 6.921330247022805, 7.910556688454164, 8.840394523675373, 9.896749053161678, 10.832600115515724, 11.839942994322374, 12.745331813649145, 12.714603443651074, 11.786976474141866, 10.823713210390471, 9.842951536235129, 8.775286580377966, 7.7446530172397665, 6.790368018912618, 5.843620424926265, 4.89617375469546, 3.9668316351496395, 3.005372516285199, 3.9337379826150185, 4.941888434175595, 5.865149130151485, 6.88414760797312, 7.928871736879922, 8.908814526445576, 9.867439627749471, 10.83987587259194, 11.810543404640207, 12.802915336150289, 12.765273395760904, 11.774496275642983, 10.70957818529998, 9.691908174257575, 8.69049768250324, 5.902068022222432, 4.833767871356571, 3.8400398457838385, 2.9103787479075254, 1.9823570227174165, 2.924300763107678, 3.9399001417625614, 4.933777494676542, 5.91168257492631, 6.977235824210366, 7.9196923778218045, 8.913220832242722, 9.831877186806155, 10.839869945013827, 11.802416526048772, 12.757041292684123, 12.728039310445235, 11.69816829024204, 10.678871394124197, 9.661305586636443, 4.983335933117679, 3.9172998663770593, 2.871554206349655, 1.9374424419272767, 1.0107301923648644, 1.9740728704245538, 2.9442070578929833, 3.9390062116767974, 4.954420061440924, 5.970198215773306, 6.903000093433544, 7.942699795664658, 8.906659063463602, 9.860868494790262, 10.906869607841516, 11.869117282901707, 12.919958891747733, 12.518928157770175, 11.58450990293708, 10.586663569047635, 4.122850475246541, 3.1512864583314153, 2.0782999491658902, 1.0048438331552874, 0.0, 1.0214632588717207, 2.0904255719449507, 3.1587465400946177, 4.107981644109794, 5.048753651048037, 6.0991554923385625, 7.027000441756202, 8.04506028935971, 9.098387976294886, 10.052575143637359, 11.104496780299387, 12.097515824127434, 13.161596072664157, 12.56562465764404, 11.541147618195824, 5.095635630920612, 4.050730730872116, 3.0100939583164243, 1.9366467138530497, 0.9697349849911021, 1.9609131016861219, 2.9182916777648007, 3.948501676025808, 4.9132546878384264, 5.954015899600504, 7.0259186250483925, 7.9986691847711695, 8.9576146575644, 9.914659931902978, 10.850457119487054, 11.808154780093691, 12.847772663141413, 13.908157097612703, 13.492270843167924, 12.598719187256343, 5.874658935168313, 4.928565534829552, 3.866551494617154, 2.895310662353125, 1.98634410958352, 2.956189977733966, 3.9193916284323143, 4.868401030183853, 5.888964720189456, 6.898230752848607, 7.949394693122388, 8.911258665023627, 9.945621226457243, 10.930211387877971, 11.816930099890401, 12.741203012089306, 13.74830843104646, 14.786765612860332, 14.45470297579085, 13.628937459343245, 6.732246551285285, 5.767814576373069, 4.799858457017349, 3.8683207313433647, 3.0237749283395647, 4.009880959041837, 4.933876454420023, 5.865337149029891, 6.881276746557187, 7.858446795516198, 8.895938274835835, 9.87877421758026, 10.853118949022559, 11.892762530241166, 12.82952599110116, 13.700057544591642, 14.711555454240592, 15.70288070188048, 15.518066201102986, 14.667330804238478, 7.804818560299401, 6.785317669366498, 5.7296599304221125, 4.8854870751757264, 4.06612521248084, 5.062450821686745, 5.865852590525078, 6.855087140598644, 7.926259983187024, 8.854411165666054, 9.847752605964404, 10.847838421690046, 11.827947255017332, 12.792631069603171, 13.7707336598029, 14.716112738572676, 15.645506336895004, 16.57514264737631, 16.568143991835612, 15.68088996517446, 8.641068581383545, 7.618077421895885, 6.680924108651643, 5.880478975052386, 5.066646301856084, 6.014495260332268, 6.886848821089291, 7.794868659470733, 8.731909932719669, 9.667676516127639, 10.740694441155929, 11.723616197384473, 12.711225014664757, 13.696961882045079, 14.755252353858795, 14.77675499168842, 15.737934597748746, 16.70142013878645, 17.486014323004678, 16.532902535392, 9.57710966547661, 8.565467929833218, 7.72388987454077, 6.941658454975421, 6.0841651240863595, 6.952050993098103, 7.946078503436006, 8.758950243137736, 9.659488907322913, 10.624487634670476, 11.580350630994673, 12.629692178798322, 13.639927985958899, 14.695833960949578, 14.654807518966818, 13.802763361737721, 14.754993507439428, 15.73530109994847, 16.663615308099853, 17.48458818292885], [17.515864639895867, 16.52790067911204, 15.658617999032911, 14.599072414248212, 13.659555032650378, 12.952938453436078, 13.774382423933284, 13.434435201802, 12.415205711553398, 11.476490958901685, 10.547751484377738, 9.667256221988568, 8.67075437375953, 7.872471922552177, 6.950265250443388, 7.907619585852987, 8.95663387765403, 9.722882419957587, 10.569595157080778, 11.523690790374216, 16.513401312748584, 15.583344869562126, 14.65312884114774, 13.712783030885666, 12.730400819143778, 12.012739127182149, 12.819606049046223, 13.845679936748644, 13.354969660899965, 12.403328035490585, 11.594779153165787, 10.60213969041512, 9.663076937657712, 8.806507129773376, 7.958521410474714, 8.8723762092516, 9.912312677422838, 10.703334843663496, 11.567856188611547, 10.670922318659267, 15.650907907286207, 14.650313276090856, 13.684888367084197, 12.70584698408566, 11.78474759358158, 11.046917553479645, 11.857314041423175, 12.899110422283263, 13.727891840753216, 13.45199982234961, 12.585708404549582, 11.548519582445934, 10.7009061827422, 9.844934577654472, 8.932951028262588, 9.902802979820363, 10.883362224186664, 11.548873152718755, 10.609360695536589, 9.711654533252187, 14.738314806291767, 13.69255892519667, 12.747677003150983, 11.695274998709394, 10.76612379398977, 10.069274950447397, 10.917378996229026, 11.89732979255746, 12.752666220001089, 13.711121325207818, 13.627388165664108, 12.599747372548736, 11.686472365660963, 10.78727061541507, 9.967991900036742, 10.852491841632297, 11.715307286579451, 10.701074280109959, 9.680876612460287, 8.74091075203223, 13.749311637883531, 12.700112910548262, 11.774704973498263, 10.71118553601191, 9.780490402312564, 9.06645065277509, 9.9424205151159, 10.858108918599758, 11.724160427370265, 12.697629969896013, 13.699761146702885, 13.53529433239705, 12.630071572995556, 11.771844697133895, 11.017366097027743, 11.902478906720516, 10.88822820965749, 9.840360353967515, 8.797825827002105, 7.852385578472067, 12.71100966515015, 11.692934634230474, 10.810802186843212, 9.808284465904778, 8.80294297073872, 8.053104749611775, 8.980705164737673, 9.798423315610485, 10.78599197238845, 11.754098050970125, 12.757973054410044, 13.702168133341862, 13.59511536504858, 12.773058249520126, 12.037770255740783, 11.121280622317016, 10.10168487052819, 9.11724582594829, 8.12089848465424, 7.109463519989406, 11.66889528017272, 10.728938420563916, 9.793977628656354, 8.799996858705954, 7.83700349495061, 7.0858584246201755, 8.003916508908349, 8.789298484029036, 9.74371341035584, 10.767924582483364, 11.839588397479249, 12.776984602822258, 13.05907134082666, 12.03477979428435, 11.103471274099896, 10.05076844867221, 9.027106698515345, 8.08428035814049, 7.079610860220268, 6.150545031695736, 10.769201641102459, 9.731858242166707, 8.768525533863077, 7.801724615104743, 6.803777331915025, 6.0441211652909494, 6.941996674076339, 7.832485531162144, 8.790769599598214, 9.80972967661432, 10.81947984041614, 11.79567659663376, 12.793831320918606, 12.915407839548667, 11.852063955922924, 10.832280772225749, 9.88486085290688, 8.900575262351605, 7.945329437305984, 6.935783471240689, 9.836783028710062, 8.780477461670868, 7.8004627369846204, 6.8336118097586525, 5.877953673499098, 5.00755033652691, 5.961996550483913, 6.859124062897849, 7.839392730465534, 8.818334597590944, 9.836248414425068, 10.819523498901216, 11.799096644543138, 12.721353811941778, 12.737534548807398, 11.810084662753814, 10.909774126709243, 9.967416075723957, 8.944530656103236, 7.903824199039399, 8.821754546141008, 7.809891853670157, 6.869927647010999, 5.875851453287515, 4.932982122615255, 4.029308737479052, 4.957910490561663, 5.9045825360510875, 6.893808977482446, 7.823646812703655, 8.88000134218996, 9.815852404544005, 10.823195283350655, 11.728584102677425, 12.730004440806717, 12.808439733013588, 11.845176469262192, 10.86441479510685, 9.796749839249687, 8.766116276111488, 7.811831277784339, 6.8650836837979865, 5.917637013567181, 4.915844261465001, 3.889804423498191, 2.961438957168372, 3.925140723203876, 4.848401419179767, 5.867399897001403, 6.912124025908205, 7.892066815473859, 8.850691916777752, 9.82312816162022, 10.793795693668487, 11.78616762517857, 12.73591137434735, 12.795959534514704, 11.731041444171701, 10.713371433129296, 9.711960941374961, 6.923531281094153, 5.855231130228292, 4.86150310465556, 3.9190367629565683, 2.892294667865077, 1.9075530521359596, 2.923152430790843, 3.917029783704824, 4.8949348639545915, 5.9604881132386485, 6.902944666850087, 7.896473121271003, 8.815129475834436, 9.823122234042108, 10.785668815077052, 11.740293581712404, 12.741803275997308, 12.719631549113759, 11.700334652995917, 10.682768845508164, 6.004799191989401, 4.93876312524878, 3.8930174652213756, 2.9589057007989976, 1.920667837512525, 0.9573251594528356, 1.9274593469212653, 2.9222585007050794, 3.937672350469206, 4.953450504801588, 5.8862523824618265, 6.92595208469294, 7.889911352491883, 8.844120783818543, 9.890121896869797, 10.852369571929987, 11.903211180776013, 12.879318310899121, 12.605973161808802, 11.608126827919357, 5.1443137341182625, 4.1727497172031365, 3.0997632080376114, 2.0263070920270083, 1.0214632588717207, 0.0, 1.0689623130732298, 2.1372832812228966, 3.086518385238072, 4.027290392176316, 5.077692233466841, 6.005537182884481, 7.0235970304879904, 8.076924717423164, 9.031111884765638, 10.083033521427666, 11.076052565255711, 12.140132813792434, 13.193090415667182, 12.562610877067545, 6.103582790172701, 5.058677890124205, 4.018041117568513, 2.9445938731051386, 1.9776821442431913, 0.939449842814401, 1.8968284188930797, 2.927038417154087, 3.891791428966705, 4.932552640728782, 6.0044553661766695, 6.977205925899448, 7.9361513986926795, 8.893196673031257, 9.828993860615332, 10.78669152122197, 11.826309404269692, 12.886693838740982, 13.836141861030786, 13.620182446128064, 6.882606094420402, 5.9365126940816415, 4.874498653869243, 3.903257821605214, 2.907142230528532, 1.9372963623780863, 2.897928369560593, 3.8469377713121324, 4.867501461317735, 5.876767493976886, 6.927931434250667, 7.889795406151906, 8.924157967585522, 9.90874812900625, 10.79546684101868, 11.719739753217585, 12.72684517217474, 13.765302353988611, 14.798573993653712, 14.650400718214968, 7.7401937105373735, 6.775761735625157, 5.807805616269437, 4.876267890595454, 3.944573049284577, 2.9909873436859566, 3.912413195548302, 4.84387389015817, 5.859813487685466, 6.8369835366444764, 7.874475015964113, 8.857310958708538, 9.831655690150837, 10.871299271369445, 11.80806273222944, 12.678594285719921, 13.690092195368871, 14.681417443008758, 15.686783085947145, 15.688794063110201, 8.81276571955149, 7.793264828618587, 6.737607089674201, 5.893434234427815, 4.986923333425852, 4.043557206330865, 4.844389331653357, 5.833623881726923, 6.904796724315303, 7.832947906794332, 8.826289347092683, 9.826375162818325, 10.80648399614561, 11.77116781073145, 12.749270400931179, 13.694649479700955, 14.624043078023282, 15.553679388504587, 16.542724622831596, 16.70235322404618, 9.649015740635633, 8.626024581147973, 7.688871267903732, 6.888426134304474, 5.987444422801097, 4.995601644976388, 5.86538556221757, 6.773405400599012, 7.710446673847947, 8.646213257255917, 9.719231182284208, 10.702152938512752, 11.689761755793036, 12.675498623173358, 13.733789094987074, 14.627831060846429, 15.564707995123955, 16.52819353616166, 17.477218631451624, 17.463666319634743, 10.5850568247287, 9.573415089085307, 8.731837033792859, 7.94960561422751, 6.966892228719265, 5.933157377742223, 6.924615244564285, 7.737486984266015, 8.638025648451192, 9.603024375798757, 10.558887372122953, 11.608228919926603, 12.61846472708718, 13.674370702077857, 13.898017114316058, 14.687195268950713, 15.63942541465242, 16.61973300716146, 17.594379092342596, 18.415351967171592], [18.47394187633364, 17.485977915549814, 16.616695235470683, 15.557149650685984, 14.61763226908815, 13.828915984204391, 12.847840686487038, 12.480588928521971, 11.46135943827337, 10.522644685621657, 9.59390521109771, 8.71340994870854, 7.716908100479501, 6.9186256492721485, 7.809156071679326, 8.766510407088926, 9.817923861776013, 10.683793298834916, 11.530506035958107, 12.484601669251544, 17.471478549186358, 16.5414221059999, 15.611206077585512, 14.670860267323437, 13.68847805558155, 12.890691382881002, 11.893064311599977, 12.863488798249557, 12.401123387619936, 11.449481762210556, 10.640932879885758, 9.648293417135092, 8.709230664377682, 7.852660856493348, 8.803306991126439, 9.73126703048754, 10.771203498658778, 11.664245722540825, 12.528767067488873, 11.631833197536594, 16.608985143723977, 15.608390512528628, 14.64296560352197, 13.663924220523432, 12.742824830019352, 11.924869809178498, 10.930772303976928, 11.916919283784177, 12.745700702254126, 12.498153549069581, 11.631862131269553, 10.594673309165906, 9.74705990946217, 8.891088304374444, 9.777736608914314, 10.761693801056303, 11.742253045422604, 12.509784031596082, 11.570271574413916, 10.672565412129513, 15.696392042729538, 14.650636161634441, 13.705754239588757, 12.653352235147166, 11.724201030427542, 10.94722720614625, 9.99083725878278, 10.915138654058374, 11.770475081502, 12.72893018670873, 12.67354189238408, 11.645901099268707, 10.732626092380933, 9.833424342135041, 10.805927770297377, 11.711382662868237, 12.676218165456778, 11.661985158987285, 10.641787491337613, 9.701821630909556, 14.707388874321303, 13.658190146986033, 12.732782209936035, 11.669262772449683, 10.738567638750336, 9.945556667243173, 9.015878777669654, 9.875917780100671, 10.741969288871177, 11.715438831396925, 12.717570008203799, 12.581448059117022, 11.676225299715526, 10.817998423853867, 11.812591690207418, 12.761369727956456, 11.849139088534818, 10.801271232844844, 9.758736705879434, 8.813296457349395, 13.669086901587923, 12.651011870668246, 11.768879423280982, 10.766361702342548, 9.761020207176491, 8.991453889057707, 8.054163427291426, 8.816232177111399, 9.803800833889362, 10.771906912471039, 11.775781915910958, 12.719976994842776, 12.64126909176855, 11.819211976240098, 12.795572087549582, 12.190242935390245, 11.14584135644559, 10.08096711713407, 9.084619775840022, 8.070374398866734, 12.626972516610492, 11.687015657001687, 10.752054865094125, 9.758074095143725, 8.795080731388381, 8.024207564066108, 7.077374771462102, 7.807107345529949, 8.761522271856752, 9.785733443984277, 10.857397258980162, 11.794793464323172, 12.796903547263591, 12.875456912657857, 12.172433587173124, 11.119730761745439, 10.096069011588574, 9.153242671213718, 8.148573173293498, 7.2195073447689655, 11.72727887754023, 10.689935478604479, 9.726602770300849, 8.759801851542514, 7.761854568352797, 6.982470304736882, 6.015454936630092, 6.850294392663057, 7.808578461099127, 8.827538538115233, 9.837288701917053, 10.813485458134673, 11.81164018241952, 12.647693525234391, 12.82754516800485, 11.807761984307675, 10.860342064988806, 9.87605647443353, 8.92081064938791, 7.911264683322614, 10.794860265147834, 9.73855469810864, 8.758539973422392, 7.791689046196425, 6.836030909936871, 5.945899475972842, 5.035454813037665, 5.876932924398762, 6.857201591966447, 7.836143459091857, 8.854057275925982, 9.827391151901764, 10.806964297543686, 11.683410266867883, 12.638150921877463, 12.78556587483574, 11.885255338791168, 10.942897287805883, 9.92001186818516, 8.879305411121324, 9.797235758222932, 8.785373065752081, 7.828004883448772, 6.833928689725288, 5.891059359053028, 4.967657876924985, 4.031368753115416, 4.922391397552, 5.911617838983359, 6.841455674204568, 7.897810203690873, 8.823720057544554, 9.831062936351204, 10.69064055760353, 11.692060895732823, 12.61968786524203, 12.820657681344116, 11.839896007188774, 10.77223105133161, 9.741597488193412, 8.787312489866263, 7.84056489587991, 6.893118225649105, 5.873921497902774, 4.847881659935964, 3.9195161936061447, 2.9985989857576287, 3.8662102806806806, 4.8852087585023165, 5.929932887409119, 6.909875676974773, 7.8585595697783, 8.785184616546324, 9.755852148594592, 10.748224080104674, 11.697967829273452, 12.657402765725664, 12.706522656253625, 11.68885264521122, 10.687442153456885, 7.899012493176077, 6.830712342310216, 5.8369843167374835, 4.877113999394341, 3.85037190430285, 2.8656302885737324, 1.996610693344595, 2.9348386452057373, 3.9127437254555053, 4.978296974739562, 5.910812319850634, 6.90434077427155, 7.777185930760541, 8.785178688968212, 9.747725270003157, 10.702350036638508, 11.703859730923412, 12.73822411787599, 12.67581586507784, 11.658250057590088, 6.980280404071325, 5.914244337330705, 4.8684986773033, 3.934386912880922, 2.8787450739502978, 1.9154023958906083, 0.9452682084221787, 1.9400673622059927, 2.9554812119701195, 3.9613181578021353, 4.8941200354623735, 5.888008539619045, 6.851967807417988, 7.806177238744647, 8.852178351795901, 9.814426026856092, 10.865267635702118, 11.841374765825226, 12.77579302065832, 12.58360804000128, 6.213276047191492, 5.241712030276366, 4.168725521110841, 3.095269405100238, 2.0904255719449507, 1.0689623130732298, 0.0, 1.068320968149667, 2.0175560721648425, 2.9583280791030866, 4.008729920393611, 4.936574869811251, 5.95463471741476, 7.007962404349935, 7.962149571692408, 9.014071208354437, 10.007090252182483, 11.071170500719205, 12.124128102593954, 13.14860514204217, 7.064493669050029, 6.019588769001533, 4.978951996445842, 3.905504751982467, 2.9385930231205197, 1.9003607216917295, 0.9429821456130509, 1.9731921438740583, 2.937945155686676, 3.888288059996224, 4.938005449395318, 5.908243612826218, 6.867189085619449, 7.824234359958026, 8.760031547542102, 9.71772920814874, 10.757347091196461, 11.817731525667751, 12.767179547957555, 13.699976252780734, 7.843516973297731, 6.89742357295897, 5.835409532746572, 4.8641687004825425, 3.868053109405861, 2.898207241255415, 1.9440820962805643, 2.8930914980321036, 3.9136551880377057, 4.912397347095409, 5.963561287369189, 6.888618745685282, 7.917464795025391, 8.869162574814109, 9.72650452794545, 10.650777440144354, 11.657882859101509, 12.69634004091538, 13.729611680580481, 14.688094791601959, 8.701104589414701, 7.736672614502486, 6.768716495146766, 5.837178769472782, 4.905483928161906, 3.9518982225632855, 2.9585669222682736, 3.8900276168781414, 4.905967214405437, 5.883137263364447, 6.910104869082636, 7.856134298241914, 8.830479029684213, 9.87012261090282, 10.739100419156209, 11.60963197264669, 12.62112988229564, 13.612455129935528, 14.617820772873914, 15.645299311655908, 9.773676598428816, 8.754175707495914, 7.6985179685515295, 6.854345113305143, 5.9478342123031815, 4.952095578631413, 3.8905430583733285, 4.8797776084468945, 5.950950451035275, 6.879101633514304, 7.861919200211205, 8.8251985023517, 9.805307335678986, 10.769991150264826, 11.680308087857949, 12.625687166627724, 13.555080764950052, 14.484717075431357, 15.473762309758364, 16.40843673832423, 10.609926619512962, 9.586935460025302, 8.64978214678106, 7.8493370131818025, 6.857342283376372, 5.854492466212326, 4.911539288937542, 5.819559127318984, 6.756600400567919, 7.692366983975889, 8.76538490900418, 9.748306665232723, 10.735915482513008, 11.72165234989333, 12.691165449047714, 13.558868747773198, 14.495745682050725, 15.459231223088429, 16.408256318378395, 17.361368105991072, 11.545967703606028, 10.534325967962635, 9.692747912670187, 8.900591288356583, 7.825783049955204, 6.792048198978161, 5.970768971284256, 6.783640710985987, 7.684179375171163, 8.649178102518729, 9.605041098842925, 10.654382646646575, 11.664618453807151, 12.720524428797829, 13.67414403901803, 14.532860377723898, 15.532064003659404, 16.495597351888428, 17.38009435312601, 18.31305375352792], [18.245775471874847, 17.378251798206897, 16.450027464604588, 15.4316970274724, 14.492179645874565, 13.50077091292959, 12.519695615212237, 11.553694123540332, 10.559199959381498, 9.620485206729786, 8.691745732205838, 7.8112504698166685, 6.81474862158763, 7.8246060931508055, 8.753911738356596, 9.711266073766195, 10.762679528453281, 11.725408011906712, 12.584391223471485, 13.538486856764923, 17.243312144727565, 17.483287547890406, 16.553071519476017, 15.612725709213944, 14.630343497472056, 13.7247935058354, 12.727166434554375, 11.92058890500743, 11.498963908728065, 10.547322283318685, 9.738773400993887, 8.74613393824322, 7.807071185485811, 8.758641300372005, 9.709287435005097, 10.67602269716481, 11.715959165336047, 12.705860435612621, 13.582652255002253, 12.685718385049974, 16.412687434235444, 16.550255954419136, 15.584831045412477, 14.605789662413939, 13.684690271909858, 12.758971932132896, 11.764874426931327, 10.974019390542049, 11.802800809011998, 11.59599407017771, 10.729702652377682, 9.692513830274034, 8.8449004305703, 9.797068748253102, 10.683717052792971, 11.706449467733572, 12.687008712099873, 13.563669219109462, 12.624156761927296, 11.726450599642893, 15.616332403700223, 15.592501603524948, 14.647619681479263, 13.595217677037672, 12.666066472318048, 11.781329329100648, 10.824939381737178, 9.972238760816246, 10.827575188259871, 11.786030293466602, 11.771382413492208, 10.743741620376836, 9.830466613489063, 10.739404786013699, 11.711908214176034, 12.656138329545506, 13.697823320212073, 12.715870346500665, 11.695672678850993, 10.755706818422937, 14.640069927660576, 14.60005558887654, 13.674647651826541, 12.611128214340189, 11.680433080640842, 10.779658790197571, 9.849980900624052, 8.933017886858542, 9.799069395629049, 10.772538938154797, 11.77467011496167, 11.679288580225151, 10.774065820823656, 11.714799682406122, 12.709392948759673, 13.673229808035899, 12.903024276048198, 11.855156420358224, 10.812621893392814, 9.867181644862775, 13.57796019601225, 13.592877312558752, 12.710744865171488, 11.708227144233055, 10.702885649066998, 9.85607228035547, 8.888265550245825, 7.873332283869269, 8.860900940647234, 9.82900701922891, 10.83288202266883, 11.711891668337058, 11.73910961287668, 12.716013234792353, 13.692373346101837, 13.258563903539912, 12.214162324595257, 11.149288085283738, 10.152940743989689, 9.138695367016403, 13.046009809389336, 12.628881098892194, 11.693920306984632, 10.699939537034231, 9.736946173278888, 8.893390214009242, 7.9114768944165, 6.86420745228782, 7.818622378614624, 8.84283355074215, 9.914497365738034, 10.766503054282518, 11.760836474692317, 12.605612086237835, 13.240754555322791, 12.188051729895106, 11.16438997973824, 10.221563639363385, 9.216894141443165, 8.287828312918633, 12.669144319430737, 11.631800920494985, 10.668468212191355, 9.70166729343302, 8.703720010243304, 7.866466220177063, 6.84955705958449, 5.907394499420928, 6.865678567856998, 7.884638644873104, 8.894388808674924, 9.78519504809402, 10.775573109848246, 11.579372557084724, 12.564321938152265, 12.854460398633176, 11.907040479314308, 10.922754888759032, 9.967509063713411, 8.957963097648115, 11.73672570703834, 10.680420139999146, 9.700405415312899, 8.73355448808693, 7.777896351827376, 6.829895391413023, 5.869556935992064, 4.934033031156633, 5.914301698724318, 6.893243565849728, 7.908614712835358, 8.759070183752097, 9.73864332939402, 10.615089298718216, 11.569829953727796, 12.49727983978138, 12.93195375311667, 11.989595702131384, 10.966710282510661, 9.926003825446825, 10.826568216856668, 9.770492226992916, 8.769870325339278, 7.775794131615793, 6.832924800943533, 5.851653792365165, 4.915364668555596, 3.979491504309872, 4.96871794574123, 5.898555780962439, 6.855759761422418, 7.755399089394887, 8.762741968201537, 9.622319589453863, 10.623739927583156, 11.551366897092363, 12.561292010147525, 12.886594421514276, 11.818929465657114, 10.788295902518914, 9.834010904191766, 8.887263310205412, 7.939816639974606, 6.911826503238284, 5.885786665271474, 4.957421198941654, 3.882594901197809, 2.923310387438552, 3.9423088652601876, 4.901973616353851, 5.867825234706318, 6.790238601628633, 7.716863648396657, 8.687531180444925, 9.679903111955007, 10.629646861123785, 11.589081797575997, 12.653999887919, 12.735551059536723, 11.734140567782388, 8.945710907501578, 7.877410756635717, 6.883682731062985, 5.9238124137198405, 4.89707031862835, 3.9123287028992317, 3.0425455902935905, 1.9919387519636087, 2.969843832213377, 3.9163975193782123, 4.842491351700967, 5.836019806121883, 6.708864962610874, 7.716857720818545, 8.67940430185349, 9.634029068488841, 10.635538762773745, 11.669903149726323, 12.689200045844165, 12.704948471915591, 8.026978818396826, 6.960942751656205, 5.915197091628801, 4.981085327206422, 3.9254434882757976, 2.962100810216108, 1.9919666227476784, 0.9971674689638642, 2.012581318727991, 2.892997189652468, 3.8257990673127065, 4.819687571469378, 5.783646839268321, 6.73785627059498, 7.783857383646234, 8.746105058706425, 9.79694666755245, 10.773053797675558, 11.707472052508653, 12.705318386398098, 7.281597015341159, 6.310032998426033, 5.237046489260508, 4.163590373249905, 3.1587465400946173, 2.1372832812228966, 1.068320968149667, 0.0, 0.9492351040151754, 1.8900071109534196, 2.9404089522439443, 3.8682539016615842, 4.886313749265093, 5.939641436200268, 6.893828603542741, 7.94575024020477, 8.938769284032816, 10.002849532569538, 11.055807134444287, 12.080284173892503, 8.132814637199697, 7.0879097371512, 6.047272964595509, 4.973825720132134, 4.006913991270187, 2.968681689841397, 2.011303113762718, 1.0258434976952855, 1.9767519593107121, 2.819967091846557, 3.8696844812456517, 4.839922644676551, 5.798868117469782, 6.755913391808359, 7.691710579392434, 8.64940823999907, 9.689026123046792, 10.749410557518082, 11.698858579807887, 12.631655284631066, 8.89740216081111, 7.951308760472348, 6.88929472025995, 5.918053887995921, 4.890560290344331, 3.9207144221938846, 2.939941420891772, 1.9909320191402324, 2.952461991661742, 3.8440763789457417, 4.895240319219522, 5.820297777535615, 6.849143826875724, 7.800841606664441, 8.65818355979578, 9.582456471994686, 10.58956189095184, 11.628019072765712, 12.661290712430812, 13.61977382345229, 9.754989776928081, 8.790557802015865, 7.822601682660144, 6.8910639569861605, 5.927991109100375, 4.957675130932075, 3.954426246879481, 2.98786813798627, 3.9447740180294737, 4.894895147201099, 5.841783900932969, 6.787813330092247, 7.762158061534546, 8.801801642753153, 9.67077945100654, 10.541311004497022, 11.552808914145972, 12.544134161785859, 13.549499804724245, 14.576978343506239, 10.827561785942196, 9.808060895009294, 8.752403156064908, 7.908230300818522, 6.97034139324165, 5.94795490324262, 4.886402382984536, 3.9776181295550233, 5.013002982317802, 5.941154164796831, 6.793598232061538, 7.756877534202033, 8.736986367529319, 9.701670182115159, 10.61198711970828, 11.557366198478055, 12.486759796800383, 13.416396107281688, 14.405441341608695, 15.34011577017456, 11.66381180702634, 10.64082064753868, 9.703667334294439, 8.856775105471364, 7.802097950053643, 6.799248132889596, 5.856294955614811, 4.9173996484271125, 5.854440921676048, 6.790207505084018, 7.782429678324098, 8.76238122849217, 9.697649173434442, 10.683386040814764, 11.622844480898046, 12.49054777962353, 13.427424713901056, 14.39091025493876, 15.339935350228727, 16.293047137841405, 12.599852891119406, 11.588211155476014, 10.746633100183566, 9.845346955033852, 8.770538716632473, 7.736803865655431, 6.915524637961526, 5.881481232094115, 6.782019896279292, 7.747018623626857, 8.702881619951054, 9.752223167754703, 10.626352144728585, 11.682258119719263, 12.605956380685713, 13.464539409574229, 14.463743035509735, 15.427276383738759, 16.31177338497634, 17.244732785378254], [17.29654036785967, 16.429016694191724, 15.500792360589411, 14.482461923457226, 13.542944541859391, 12.551535808914414, 11.57046051119706, 10.604459019525155, 9.730352403922202, 8.79163765127049, 7.862898176746542, 7.012045870306332, 7.763983725602805, 8.77384119716598, 9.70314684237177, 10.660501177781372, 11.711914632468458, 12.674643115921889, 13.53362632748666, 14.487721960780098, 16.294077040712388, 17.224133483898846, 16.39047777726777, 15.450131967005696, 14.472098755365991, 13.491735135168343, 12.525236886084121, 11.673662217815803, 10.670116353268769, 9.718474727859387, 8.93278300579208, 7.946929338732884, 8.756306289500985, 9.70787640438718, 10.658522539020272, 11.625257801179986, 12.665194269351224, 13.655095539627798, 14.531887359017428, 13.634953489065149, 15.46345233022027, 16.464046961415622, 16.53406614942765, 15.555024766429115, 14.633925375925035, 13.708207036148071, 12.714109530946502, 11.923254494557222, 11.032354140707358, 10.767146514718412, 9.930498052867346, 8.893309230763698, 9.794135534585473, 10.746303852268277, 11.632952156808146, 12.655684571748749, 13.63624381611505, 14.512904323124637, 13.57339186594247, 12.675685703658068, 14.667097299685048, 15.646424413882947, 15.59685478549444, 14.544452781052849, 13.615301576333225, 12.730564433115823, 11.774174485752352, 10.92147386483142, 10.057128519955231, 10.901970318643066, 10.972177813981872, 9.9445370208665, 10.779701717504237, 11.688639890028874, 12.66114331819121, 13.605373433560683, 14.64705842422725, 13.66510545051584, 12.644907782866168, 11.704941922438111, 13.690834823645401, 14.65397839923454, 14.623882755841718, 13.560363318355366, 12.629668184656019, 11.728893894212746, 10.799216004639227, 9.882252990873717, 9.028622727324409, 9.888478963331261, 10.866872327442879, 10.880083980714815, 11.72330092483883, 12.664034786421295, 13.658628052774846, 14.622464912051072, 13.852259380063371, 12.804391524373397, 11.761856997407987, 10.816416748877948, 12.628725091997074, 13.646800122916751, 13.659979969186665, 12.657462248248232, 11.652120753082174, 10.805307384370645, 9.837500654261, 8.822567387884444, 8.090454272342594, 8.921209231710119, 9.925084235150038, 10.762656564321881, 11.75656348466094, 12.712621918640423, 13.566265861289915, 14.207799007555089, 13.16339742861043, 12.098523189298911, 11.102175848004862, 10.087930471031576, 12.096774705374163, 13.036731564982967, 12.643155410999809, 11.649174641049408, 10.686181277294065, 9.842625318024417, 8.860711998431675, 7.813442556302996, 7.048175710309983, 7.935035763223358, 9.006699578219242, 9.817267950267341, 10.81160137067714, 11.656376982222662, 12.587685502407117, 13.137286833910283, 12.113625083753417, 11.170798743378562, 10.166129245458341, 9.23706341693381, 12.708114092470154, 12.581036024510162, 11.617703316206532, 10.650902397448197, 9.65295511425848, 8.815701324192238, 7.798792163599665, 6.856629603436104, 6.095231899552357, 6.940399474359802, 7.950149638161623, 8.835959944078843, 9.826338005833069, 10.630137453069551, 11.61508683413709, 12.52584862629427, 12.85627558332948, 11.871989992774205, 10.916744167728584, 9.90719820166329, 12.685960811053517, 11.629655244014323, 10.649640519328075, 9.682789592102107, 8.727131455842553, 7.779130495428198, 6.818792040007239, 5.883268135171809, 5.093123649898986, 5.949004395336426, 6.959379608820182, 7.809835079736921, 8.789408225378843, 9.66585419470304, 10.62059484971262, 11.548044735766204, 12.482058547180456, 12.938830806146557, 11.915945386525836, 10.875238929462, 11.775803320871843, 10.719727331008091, 9.719105429354453, 8.725029235630968, 7.782159904958709, 6.800888896380341, 5.864599772570772, 4.928726608325047, 4.146739109428744, 4.954316610449137, 5.9065246574072425, 6.80616398537971, 7.813506864186361, 8.673084485438688, 9.674504823567979, 10.602131793077186, 11.612056906132349, 12.592818580287691, 12.768164569672289, 11.73753100653409, 10.783246008206941, 9.836498414220587, 8.889051743989782, 7.861061607253459, 6.835021769286649, 5.906656302956829, 4.831830005212985, 3.8725454914537276, 3.092717078425082, 3.9527385123386756, 4.918590130691142, 5.841003497613457, 6.767628544381482, 7.73829607642975, 8.730668007939832, 9.680411757108612, 10.639846693560822, 11.704764783903824, 12.72243479494623, 12.683375671797563, 9.894946011516753, 8.826645860650892, 7.83291783507816, 6.873047517735015, 5.846305422643525, 4.861563806914408, 3.991780694308766, 2.9411738559787843, 2.026682382534404, 2.9671624153630365, 3.893256247685791, 4.8867847021067075, 5.759629858595699, 6.76762261680337, 7.730169197838315, 8.684793964473666, 9.68630365875857, 10.720668045711149, 11.73996494182899, 12.681441264794115, 8.976213922412, 7.91017785567138, 6.8644321956439756, 5.930320431221597, 4.874678592290973, 3.9113359142312834, 2.941201726762854, 1.9464025729790397, 1.0694198690490182, 1.9437620856372924, 2.8765639632975306, 3.8704524674542022, 4.834411735253146, 5.788621166579805, 6.834622279631059, 7.79686995469125, 8.847711563537276, 9.823818693660384, 10.758236948493478, 11.756083282382923, 8.230832119356336, 7.259268102441209, 6.186281593275684, 5.112825477265081, 4.107981644109794, 3.0865183852380724, 2.0175560721648425, 0.9492351040151754, 0.0, 0.940772006938244, 1.9911738482287689, 2.919018797646409, 3.937078645249918, 4.990406332185093, 5.944593499527566, 6.996515136189595, 7.989534180017642, 9.053614428554365, 10.106572030429113, 11.13104906987733, 9.08204974121487, 8.037144841166375, 6.996508068610684, 5.923060824147309, 4.956149095285362, 3.917916793856572, 2.960538217777893, 1.975078601710461, 1.0275168552955367, 1.8707319878313817, 2.9204493772304763, 3.8906875406613755, 4.849633013454607, 5.806678287793184, 6.742475475377259, 7.700173135983896, 8.739791019031617, 9.800175453502908, 10.749623475792712, 11.68242018061589, 9.846637264826283, 8.900543864487522, 7.838529824275125, 6.867288992011096, 5.8397953943595065, 4.86994952620906, 3.889176524906947, 2.940167123155408, 2.0032268876465666, 2.8948412749305663, 3.946005215204347, 4.871062673520439, 5.899908722860549, 6.851606502649266, 7.7089484557806065, 8.63322136797951, 9.640326786936665, 10.678783968750537, 11.712055608415637, 12.670538719437115, 10.704224880943256, 9.73979290603104, 8.771836786675319, 7.8402990610013354, 6.877226213115551, 5.90691023494725, 4.903661350894656, 3.9371032420014456, 2.9955389140142983, 3.9456600431859234, 4.892548796917794, 5.838578226077072, 6.812922957519371, 7.852566538737978, 8.721544346991365, 9.592075900481847, 10.603573810130797, 11.594899057770684, 12.60026470070907, 13.627743239491064, 11.776796889957371, 10.757295999024468, 9.701638260080083, 8.857465404833697, 7.919576497256827, 6.897190007257795, 5.835637486999711, 4.926853233570198, 4.063767878302627, 4.991919060781656, 5.844363128046363, 6.807642430186858, 7.787751263514145, 8.752435078099984, 9.662752015693105, 10.60813109446288, 11.537524692785208, 12.467161003266513, 13.45620623759352, 14.390880666159385, 12.613046911041515, 11.590055751553855, 10.652902438309614, 9.80601020948654, 8.751333054068818, 7.748483236904771, 6.805530059629986, 5.8666347524422875, 5.055236322165712, 5.961359949624722, 6.833194574308923, 7.813146124476996, 8.748414069419267, 9.734150936799589, 10.67360937688287, 11.541312675608355, 12.47818960988588, 13.441675150923585, 14.390700246213552, 15.34381203382623, 13.549087995134581, 12.537446259491189, 11.69586820419874, 10.794582059049029, 9.71977382064765, 8.686038969670607, 7.864759741976701, 6.83071633610929, 5.982815296768956, 6.9181710681675606, 7.779512645060475, 8.828854192864124, 9.677117040713409, 10.733023015704088, 11.656721276670538, 12.515304305559054, 13.51450793149456, 14.478041279723584, 15.362538280961168, 16.29549768136308], [16.35576836092143, 15.488244687253482, 14.560020353651169, 13.541689916518983, 12.602172534921149, 11.610763801976171, 10.629688504258818, 9.663687012586912, 8.800575928420924, 7.861861175769211, 6.933121701245263, 7.89055376400437, 8.70475573254105, 9.714613204104227, 10.643918849310015, 11.601273184719616, 12.652686639406703, 13.615415122860133, 14.474398334424906, 15.428493967718344, 15.353305033774147, 16.283361476960607, 15.449705770329528, 14.509359960067453, 13.531326748427748, 12.5509631282301, 11.584464879145878, 10.73289021087756, 9.740339877767491, 8.78869825235811, 8.0030065302908, 8.825437232430922, 9.697078296439232, 10.648648411325427, 11.599294545958518, 12.56602980811823, 13.605966276289468, 14.595867546566042, 15.472659365955675, 14.575725496003395, 14.522680323282028, 15.52327495447738, 16.474763323898614, 15.474371913920631, 14.476979973989947, 13.516784701932604, 12.546756886768927, 11.67945972534294, 10.762517263323192, 9.837370039217134, 9.059868799905598, 9.771817124461736, 10.73490754152372, 11.687075859206523, 12.573724163746393, 13.596456578686993, 14.577015823053294, 15.453676330062883, 14.514163872880717, 13.616457710596315, 13.726325292746804, 14.705652406944703, 15.66881826074845, 15.485224787991092, 14.556073583271468, 13.671336440054066, 12.714946492690595, 11.81834255871443, 10.853771849258589, 9.961198311704823, 10.126118822963646, 10.823044914564537, 11.720473724442483, 12.62941189696712, 13.601915325129456, 14.546145440498927, 15.587830431165495, 14.605877457454087, 13.585679789804415, 12.645713929376358, 12.750062816707157, 13.713206392296295, 14.691045471382102, 14.501135325293609, 13.570440191594262, 12.669665901150989, 11.73998801157747, 10.779121684756728, 9.825266056627767, 8.947706956393018, 9.926100320504636, 10.83330739656375, 11.780835269775721, 12.721569131358187, 13.64589801306471, 14.609734872340935, 14.793031387001617, 13.745163531311643, 12.702629004346234, 11.757188755816195, 11.68795308505883, 12.706028115978507, 13.743459979783417, 13.598234255186474, 12.592892760020417, 11.746079391308887, 10.778272661199242, 9.763339394822689, 8.887097601645952, 7.980437224771876, 8.984312228211795, 9.821884557383639, 10.815791477722698, 11.771849911702176, 12.625493854351669, 13.568651900626557, 14.104169435548677, 13.039295196237157, 12.042947854943108, 11.028702477969823, 11.156002698435916, 12.09595955804472, 13.067153572763415, 12.58994664798765, 11.626953284232307, 10.78339732496266, 9.801484005369918, 8.75421456324124, 7.844819039613341, 6.994263756285115, 8.065927571281, 8.876495943329099, 9.870829363738897, 10.715604975284416, 11.646913495468871, 12.655158995277072, 13.054397090691658, 12.111570750316803, 11.106901252396582, 10.17783542387205, 11.76734208553191, 12.840463951845964, 12.558475323144775, 11.59167440438644, 10.593727121196723, 9.756473331130483, 8.739564170537909, 7.797401610374347, 6.8918752288557155, 5.999627467421559, 7.009377631223379, 7.8951879371406, 8.885565998894826, 9.689365446131305, 10.674314827198845, 11.585076619356025, 12.532496538674893, 12.812761999712452, 11.85751617466683, 10.847970208601534, 12.699760697924306, 12.570427250952566, 11.590412526266318, 10.62356159904035, 9.667903462780796, 8.719902502366443, 7.759564046945483, 6.824040142110053, 5.889766979202344, 5.0082323883981825, 6.018607601881938, 6.869063072798678, 7.848636218440599, 8.725082187764796, 9.679822842774376, 10.60727272882796, 11.541286540242211, 12.506882806314266, 12.85671739346408, 11.816010936400245, 12.716575327810087, 11.660499337946336, 10.659877436292698, 9.665801242569213, 8.722931911896953, 7.741660903318585, 6.805371779509016, 5.869498615263291, 4.943382438732102, 4.013544603510893, 4.965752650468999, 5.865391978441467, 6.872734857248118, 7.732312478500442, 8.733732816629734, 9.661359786138942, 10.671284899194104, 11.652046573349446, 12.707033221819499, 12.678303013472332, 11.724018015145184, 10.77727042115883, 9.829823750928025, 8.801833614191704, 7.775793776224893, 6.847428309895074, 5.7726020121512285, 4.813317498391972, 4.033489085363326, 3.011966505400432, 3.9778181237528987, 4.900231490675213, 5.826856537443238, 6.797524069491505, 7.789896001001587, 8.739639750170365, 9.699074686622577, 10.76399277696558, 11.781662788007985, 12.711477161989073, 10.835718018454996, 9.767417867589135, 8.773689842016402, 7.81381952467326, 6.787077429581769, 5.802335813852651, 4.93255270124701, 3.8819458629170285, 2.967454389472648, 2.026390408424793, 2.9524842407475473, 3.9460126951684638, 4.818857851657454, 5.826850609865126, 6.78939719090007, 7.744021957535422, 8.745531651820325, 9.779896038772904, 10.799192934890746, 11.74066925785587, 9.916985929350245, 8.850949862609625, 7.805204202582219, 6.871092438159841, 5.815450599229217, 4.8521079211695275, 3.881973733701098, 2.887174579917284, 2.010191875987262, 1.0029900786990484, 1.935791956359287, 2.929680460515958, 3.893639728314901, 4.8478491596415605, 5.893850272692815, 6.856097947753005, 7.906939556599031, 8.883046686722139, 9.817464941555233, 10.815311275444678, 9.171604126294577, 8.20004010937945, 7.127053600213927, 6.0535974842033236, 5.048753651048036, 4.027290392176316, 2.9583280791030866, 1.8900071109534196, 0.940772006938244, 0.0, 1.0504018412905247, 1.9782467907081647, 2.9963066383116734, 4.049634325246848, 5.003821492589322, 6.055743129251351, 7.048762173079397, 8.112842421616119, 9.165800023490867, 10.190277062939083, 10.022821748153117, 8.97791684810462, 7.937280075548928, 6.863832831085554, 5.896921102223606, 4.858688800794816, 3.9013102247161378, 2.915850608648705, 1.9682888622337806, 0.9299599808931377, 1.9796773702922321, 2.9499155337231313, 3.9088610065163625, 4.865906280854939, 5.8017034684390145, 6.759401129045651, 7.799019012093373, 8.859403446564663, 9.808851468854467, 10.741648173677646, 10.78740927176453, 9.841315871425769, 8.77930183121337, 7.80806099894934, 6.78056740129775, 5.810721533147304, 4.829948531845191, 3.880939130093652, 2.9439988945848103, 1.9540692679923222, 3.0052332082661026, 3.9302906665821946, 4.9591367159223045, 5.910834495711021, 6.768176448842362, 7.692449361041266, 8.69955477999842, 9.738011961812292, 10.771283601477393, 11.72976671249887, 11.644996887881502, 10.680564912969286, 9.712608793613565, 8.78107106793958, 7.817998220053795, 6.847682241885494, 5.8444333578329, 4.87787524893969, 3.936310920952542, 3.0048880362476793, 3.951776789979549, 4.897806219138827, 5.872150950581126, 6.911794531799734, 7.7807723400531215, 8.651303893543602, 9.662801803192552, 10.65412705083244, 11.659492693770826, 12.68697123255282, 12.717568896895617, 11.698068005962714, 10.64241026701833, 9.798237411771941, 8.86034850419507, 7.837962014196039, 6.776409493937955, 5.867625240508443, 4.990293767759406, 4.062142585280377, 4.903591121108119, 5.8668704232486135, 6.8469792565759, 7.81166307116174, 8.721980008754862, 9.667359087524638, 10.596752685846965, 11.52638899632827, 12.515434230655277, 13.450108659221142, 13.553818917979761, 12.530827758492102, 11.59367444524786, 10.746782216424783, 9.692105061007062, 8.689255243843016, 7.746302066568231, 6.807406759380532, 5.967350057531412, 5.031583474123442, 5.892422567370678, 6.872374117538752, 7.8076420624810225, 8.793378929861344, 9.732837369944628, 10.600540668670112, 11.537417602947638, 12.500903143985342, 13.449928239275309, 14.403040026887988, 14.489860002072827, 13.478218266429435, 12.636640211136987, 11.735354065987273, 10.660545827585894, 9.626810976608851, 8.805531748914945, 7.771488343047535, 6.894929032134656, 5.988394592666281, 6.83874063812223, 7.888082185925879, 8.736345033775166, 9.792251008765843, 10.715949269732295, 11.574532298620811, 12.573735924556317, 13.537269272785341, 14.421766274022925, 15.354725674424838], [15.305366519630905, 14.437842845962958, 13.509618512360644, 12.491288075228457, 11.551770693630623, 10.560361960685645, 9.579286662968292, 8.613285171296386, 7.800324708824187, 6.861609956172474, 7.7252331001879915, 8.6826651629471, 9.630133408555823, 10.639990880118999, 11.569296525324786, 12.526650860734387, 13.578064315421473, 14.540792798874904, 15.52480017571543, 16.47889580900887, 14.302903192483623, 15.232959635670083, 14.399303929039002, 13.458958118776927, 12.480924907137222, 11.500561286939574, 10.534063037855352, 9.682488369587034, 8.740088658170754, 7.788447032761373, 8.788594792031075, 9.617548631373651, 10.565742979319968, 11.570797978774397, 12.521444113407489, 13.491407484133001, 14.531343952304239, 15.521245222580813, 16.500548640251427, 15.62612733729392, 13.472278481991504, 14.472873113186855, 15.42436148260809, 14.423970072630105, 13.42657813269942, 12.466382860642078, 11.496355045478401, 10.629057884052415, 9.762266043726454, 8.837118819620398, 9.845457061645872, 10.563928523404465, 11.59569770349492, 12.564965344873277, 13.495873731195363, 14.521834254701764, 15.502393499068065, 16.465302999267134, 15.564565714171241, 14.666859551886839, 12.675923451456281, 13.65525056565418, 14.618416419457928, 15.291766384437064, 14.36261517971744, 13.392680038036021, 12.43629009067255, 11.630838513778217, 10.737491664478581, 9.882066796890417, 10.04722278967252, 10.7266063383509, 11.682186459049147, 12.657925963979597, 13.630429392141933, 14.601090398002246, 15.560272970211615, 15.65627929874461, 14.636081631094939, 13.696115770666882, 11.699660975416634, 12.662804551005772, 13.64064363009158, 14.645057636433107, 14.540549789380464, 13.613367227054184, 12.683689337480665, 11.676827505999945, 10.722971877870984, 9.845412777636236, 9.074560376517907, 9.791059378502585, 10.738587251714554, 11.67932111329702, 12.595496171774185, 13.55933303105041, 14.564788605544956, 14.795565372602168, 13.753030845636758, 12.807590597106719, 10.637551243768307, 11.655626274687984, 12.693058138492894, 13.695575859431328, 13.63760608414191, 12.689780717212082, 11.721973987102437, 10.707040720725884, 9.78480342288917, 8.878143046015094, 8.132772284225066, 8.779636539322473, 9.77354345966153, 10.72144807041165, 11.575092013061145, 12.518250059336033, 13.523386152700683, 14.08969703752768, 13.09334969623363, 12.079104319260345, 10.105600857145392, 11.045557716754196, 12.01675173147289, 13.035293360548106, 12.6716666083538, 11.727098650865855, 10.745185331273113, 9.697915889144435, 8.742524860856559, 7.891969577528333, 7.136696053883033, 7.834247925267932, 8.82858134567773, 9.665203133993892, 10.596511654178347, 11.604757153986547, 12.448807980687837, 13.161972591607329, 12.157303093687108, 11.228237265162576, 10.716940244241385, 11.79006211055544, 12.75339481885907, 12.636387728507932, 11.638440445318215, 10.722737947569847, 9.683265496441104, 8.741102936277542, 7.789581050098934, 6.897333288664777, 6.070547954628807, 6.852939919079432, 7.843317980833659, 8.63896360484078, 9.623912985908321, 10.5346747780655, 11.482094697384369, 12.466380287939645, 12.902229498788323, 11.892683532723026, 11.649358856633782, 12.705664423672976, 12.63512585038781, 11.668274923161842, 10.712616786902288, 9.764615826487933, 8.703265372848678, 7.767741468013248, 6.7874728004455624, 5.905938209641401, 5.05070966780468, 5.82681505473751, 6.806388200379431, 7.674680346474271, 8.629421001483852, 9.556870887537436, 10.490884698951687, 11.456480965023742, 12.501671407485706, 12.860724260521737, 12.691808165799529, 12.705212662067826, 11.704590760414188, 10.710514566690703, 9.767645236018444, 8.786374227440076, 7.850085103630508, 6.830314701406679, 5.84108825997532, 4.911250424754112, 3.997854716391741, 4.8231439603803, 5.822584130351862, 6.681910637209917, 7.683330975339209, 8.610957944848417, 9.62088305790358, 10.601644732058922, 11.656631380528975, 12.606919985962023, 12.768731339266676, 11.821983745280322, 10.874537075049517, 9.846546938313194, 8.820507100346385, 7.892141634016566, 6.817315336272721, 5.858030822513464, 4.939771263650713, 3.909672326643651, 3.0099201896756407, 3.8579834726140465, 4.776454696152713, 5.74712222820098, 6.739494159711061, 7.68923790887984, 8.648672845332053, 9.713590935675056, 10.73126094671746, 11.661075320698549, 11.880431342576488, 10.812131191710627, 9.818403166137895, 8.858532848794752, 7.831790753703261, 6.847049137974144, 5.977266025368502, 4.926659187038521, 3.8737365677600355, 2.9240962296680117, 1.9845863066702893, 2.903764677107297, 3.768456010366929, 4.776448768574601, 5.738995349609545, 6.6936201162448965, 7.6951298105298, 8.72949419748238, 9.748791093600222, 10.690267416565346, 10.961699253471737, 9.895663186731117, 8.849917526703711, 7.915805762281334, 6.86016392335071, 5.8968212452910205, 4.9266870578225905, 3.9318879040387764, 2.9164740542746497, 1.9006958999422676, 0.9678940222820293, 1.8792786192254334, 2.8432378870243764, 3.797447318351036, 4.84344843140229, 5.805696106462481, 6.856537715308507, 7.832644845431615, 8.767063100264709, 9.764909434154154, 10.222005967585103, 9.250441950669977, 8.177455441504451, 7.103999325493848, 6.099155492338561, 5.07769223346684, 4.008729920393611, 2.9404089522439443, 1.9911738482287689, 1.0504018412905247, 0.0, 0.9278449494176398, 1.9459047970211487, 2.999232483956323, 3.9534196512987965, 5.0053412879608254, 5.998360331788872, 7.062440580325594, 8.115398182200343, 9.139875221648559, 11.07322358944364, 10.028318689395144, 8.987681916839453, 7.914234672376078, 6.947322943514131, 5.90909064208534, 4.951712066006662, 3.9662524499392298, 3.018690703524306, 1.9803618221836623, 0.9292755290017074, 1.8995136924326066, 2.858459165225838, 3.8155044395644153, 4.751301627148491, 5.7089992877551285, 6.74861717080285, 7.80900160527414, 8.758449627563945, 9.691246332387124, 11.837811113055054, 10.891717712716293, 9.829703672503895, 8.858462840239865, 7.830969242588274, 6.861123374437828, 5.880350373135715, 4.931340971384176, 3.9944007358753355, 3.004471109282847, 1.9911355654286849, 2.87988882529167, 3.9087348746317803, 4.860432654420498, 5.7177746075518385, 6.642047519750744, 7.649152938707899, 8.68761012052177, 9.72088176018687, 10.679364871208348, 12.695398729172027, 11.73096675425981, 10.76301063490409, 9.831472909230104, 8.86840006134432, 7.898084083176018, 6.894835199123424, 5.928277090230214, 4.979893036707983, 4.002722987748973, 2.9376791471421315, 3.8474043778483025, 4.821749109290602, 5.861392690509209, 6.730370498762598, 7.60090205225308, 8.61239996190203, 9.603725209541917, 10.609090852480303, 11.636569391262297, 13.767970738186142, 12.74846984725324, 11.692812108308853, 10.848639253062466, 9.910750345485594, 8.888363855486563, 7.826811335228479, 6.889859714962743, 5.8186868723743626, 4.890535689895334, 3.889493478270701, 4.816468581958089, 5.796577415285376, 6.761261229871216, 7.671578167464338, 8.616957246234113, 9.546350844556441, 10.475987155037746, 11.465032389364753, 12.399706817930618, 14.604220759270286, 13.581229599782626, 12.644076286538384, 11.672159892439556, 10.617482737021833, 9.614632919857787, 8.671679742583002, 7.732784435395304, 6.795743162146369, 5.859976578738399, 4.878324924533261, 5.8219722762482276, 6.757240221190498, 7.742977088570819, 8.682435528654104, 9.550138827379588, 10.487015761657114, 11.450501302694818, 12.399526397984785, 13.352638185597463, 15.540261843363352, 14.52862010771996, 13.676861251891555, 12.660731742002044, 11.585923503600664, 10.552188652623622, 9.730909424929717, 8.696866019062307, 7.723322136749613, 6.78050599160901, 5.824642995284813, 6.873984543088461, 7.685943192484641, 8.74184916747532, 9.665547428441771, 10.524130457330287, 11.523334083265793, 12.486867431494817, 13.3713644327324, 14.304323833134314], [14.377521570213265, 13.509997896545318, 12.581773562943004, 11.563443125810817, 10.623925744212983, 9.632517011268005, 8.651441713550652, 7.685440221878746, 6.8961564167373455, 7.784382238519059, 8.648005382534576, 9.605437445293683, 10.552905690902406, 11.562763162465583, 12.49206880767137, 13.44942314308097, 14.500836597768057, 15.463565081221487, 16.45264512513307, 17.406740758426512, 13.375058243065983, 14.305114686252443, 13.471458979621362, 12.531113169359287, 11.553079957719582, 10.572716337521934, 9.606218088437712, 8.754643420169394, 7.835920366083912, 8.711219315107957, 9.711367074377659, 10.540320913720235, 11.488515261666551, 12.493570261120981, 13.444216395754072, 14.414179766479585, 15.454116234650822, 16.444017504927398, 17.423320922598013, 16.55397228671156, 12.544433532573864, 13.545028163769215, 14.49651653319045, 13.496125123212465, 12.49873318328178, 11.538537911224438, 10.568510096060761, 9.701212934634775, 8.858097751639612, 9.759891101966982, 10.768229343992456, 10.84998917903606, 11.73990769255027, 12.672417052322555, 13.613717397034923, 14.62293431039654, 15.643242628906176, 16.460473763536942, 16.49241066358888, 15.594704501304479, 11.748078502038641, 12.72740561623654, 13.690571470040288, 14.363921435019424, 13.4347702302998, 12.464835088618381, 11.50844514125491, 10.702993564360577, 9.833323372391739, 10.804839079237, 10.710437174284106, 9.798761388933258, 10.754341509631507, 11.730081014561957, 12.702584442724293, 13.673245448584606, 14.632428020793975, 15.484522397769974, 15.563926580512579, 14.623960720084522, 10.771816025998994, 11.734959601588132, 12.71279868067394, 13.717212687015467, 14.340264074267832, 13.413081511941554, 12.483403622368035, 11.742214438318282, 10.861829165022563, 10.767131403897713, 9.737774761129492, 8.863214429084943, 9.810742302296914, 10.75147616387938, 11.667651222356545, 12.63148808163277, 13.636943656127317, 14.552778832634797, 14.680875795054398, 13.735435546524359, 9.709706294350667, 10.727781325270344, 11.765213189075254, 12.767730910013688, 13.839885677772545, 13.61762566662972, 12.649818936520075, 11.634885670143523, 10.71264837230681, 9.79986167227657, 8.795986668836651, 7.851791589904832, 8.84569851024389, 9.79360312099401, 10.647247063643505, 11.590405109918393, 12.595541203283043, 13.516764393788563, 14.02119464565127, 13.006949268677985, 9.177755907727752, 10.117712767336556, 11.08890678205525, 12.107448411130466, 13.07044177488581, 12.654943600283493, 11.673030280690751, 10.625760838562075, 9.6703698102742, 8.819814526945972, 7.872799857931226, 6.906402975850292, 7.900736396260089, 8.737358184576252, 9.668666704760707, 10.676912204568907, 11.520963031270197, 12.463789371645053, 13.085148043104748, 12.156082214580216, 9.789095294823746, 10.8622171611378, 11.82554986944143, 12.877554987229951, 12.566285394735855, 11.650582896987485, 10.611110445858742, 9.668947885695182, 8.717425999516575, 7.825178238082417, 6.901291725879411, 5.925094969661792, 6.915473031416019, 7.7111186554231415, 8.696068036490683, 9.60682982864786, 10.554249747966729, 11.538535338522005, 12.493781163567625, 12.820528482140666, 10.721513907216142, 11.777819474255336, 12.757834198941584, 12.596119872579482, 11.640461736319928, 10.692460775905575, 9.631110322266316, 8.695586417430887, 7.715317749863202, 6.833783159059041, 5.894144151791168, 4.89897010531987, 5.878543250961791, 6.746835397056632, 7.701576052066213, 8.629025938119796, 9.563039749534047, 10.528636015606102, 11.573826458068066, 12.614532915131901, 11.763963216381889, 12.82003920624564, 12.63243570983183, 11.638359516108345, 10.695490185436086, 9.714219176857718, 8.777930053048149, 7.758159650824319, 6.76893320939296, 5.839095374171752, 4.841289200378228, 3.89529901096266, 4.894739180934222, 5.754065687792278, 6.75548602592157, 7.683112995430777, 8.69303810848594, 9.673799782641282, 10.728786431111336, 11.679075036544383, 12.633360034871531, 12.749828694697962, 11.802382024467157, 10.774391887730834, 9.748352049764025, 8.819986583434206, 7.7451602856903605, 6.785875771931104, 5.867616213068353, 4.83751727606129, 3.9377651390932806, 2.9301385231964066, 3.8486097467350735, 4.819277278783341, 5.811649210293423, 6.761392959462202, 7.720827895914414, 8.785745986257417, 9.803415997299822, 10.733230371280909, 12.808276291994128, 11.739976141128267, 10.746248115555534, 9.786377798212392, 8.759635703120901, 7.774894087391784, 6.905110974786142, 5.8545041364561605, 4.8015815171776755, 3.8519411790856517, 2.9124312560879293, 1.9759197276896572, 2.8406110609492896, 3.8486038191569616, 4.811150400191906, 5.765775166827257, 6.767284861112161, 7.80164924806474, 8.820946144182582, 9.762422467147706, 11.889544202889377, 10.823508136148757, 9.777762476121351, 8.843650711698974, 7.78800887276835, 6.82466619470866, 5.8545320072402305, 4.859732853456416, 3.8443190036922896, 2.8285408493599076, 1.895738971699669, 0.9514336698077935, 1.9153929376067367, 2.8696023689333963, 3.9156034819846504, 4.877851157044841, 5.928692765890867, 6.904799896013975, 7.83921815084707, 8.837064484736514, 11.149850917002743, 10.178286900087617, 9.105300390922093, 8.031844274911489, 7.027000441756201, 6.00553718288448, 4.936574869811251, 3.8682539016615842, 2.919018797646409, 1.9782467907081647, 0.9278449494176398, 0.0, 1.018059847603509, 2.0713875345386836, 3.025574701881157, 4.0774963385431855, 5.070515382371232, 6.134595630907954, 7.187553232782703, 8.212030272230919, 12.00106853886128, 10.956163638812784, 9.915526866257093, 8.842079621793719, 7.8751678929317706, 6.83693559150298, 5.879557015424302, 4.89409739935687, 3.9465356529419457, 2.9082067716013023, 1.8571204784193474, 0.9716687430149668, 1.9306142158081983, 2.8876594901467754, 3.823456677730851, 4.781154338337489, 5.82077222138521, 6.8811566558565, 7.830604678146305, 8.763401382969484, 12.765656062472694, 11.819562662133933, 10.757548621921535, 9.786307789657505, 8.758814192005914, 7.788968323855468, 6.808195322553355, 5.859185920801816, 4.9222456852929755, 3.932316058700487, 2.9139078477752696, 1.9520438758740302, 2.9808899252141403, 3.9325877050028573, 4.789929658134199, 5.714202570333104, 6.721307989290259, 7.75976517110413, 8.79303681076923, 9.751519921790708, 13.623243678589667, 12.65881170367745, 11.69085558432173, 10.759317858647744, 9.79624501076196, 8.825929032593658, 7.822680148541064, 6.856122039647854, 5.9026653190545675, 4.925495270095557, 3.860451429488716, 2.919559428430663, 3.893904159872962, 4.933547741091569, 5.802525549344958, 6.67305710283544, 7.68455501248439, 8.675880260124277, 9.681245903062663, 10.708724441844657, 14.695815687603782, 13.67631479667088, 12.620657057726493, 11.776484202480106, 10.838595294903234, 9.816208804904203, 8.754656284646119, 7.812631997309326, 6.741459154720946, 5.813307972241917, 4.812265760617286, 3.8886236325404493, 4.868732465867736, 5.833416280453576, 6.743733218046698, 7.689112296816473, 8.618505895138801, 9.548142205620106, 10.537187439947113, 11.471861868512978, 15.532065708687925, 14.509074549200266, 13.571921235956024, 12.594932174786138, 11.540255019368416, 10.53740520220437, 9.594452024929586, 8.655556717741888, 7.718515444492953, 6.782748861084983, 5.801097206879845, 4.894127326830588, 5.829395271772858, 6.815132139153179, 7.7545905792364636, 8.622293877961948, 9.559170812239474, 10.522656353277178, 11.471681448567145, 12.424793236179823, 16.468106792780993, 15.4564650571376, 14.599633534238139, 13.583504024348628, 12.508695785947248, 11.474960934970206, 10.6536817072763, 9.61963830140889, 8.646094419096197, 7.703278273955594, 6.747415277631397, 5.963834683047287, 6.758098243067001, 7.814004218057679, 8.737702479024131, 9.596285507912647, 10.595489133848153, 11.559022482077177, 12.44351948331476, 13.376478883716674], [13.417411733295205, 12.549888059627259, 11.621663726024945, 10.60333328889276, 9.663815907294925, 8.722671302986052, 7.875558500989942, 6.9095570093180365, 7.85393752540575, 8.742163347187462, 9.605786491202979, 10.563218553962086, 11.510686799570811, 12.520544271133987, 13.449849916339774, 14.407204251749375, 15.458617706436462, 16.421346189889892, 17.440256962731755, 18.394352596025197, 12.414948406147923, 13.345004849334384, 12.511349142703304, 11.57100333244123, 10.592970120801525, 9.66287062923998, 8.830334875877002, 7.978760207608683, 8.793701474752316, 9.66900042377636, 10.669148183046062, 11.498102022388638, 11.868798750630267, 12.79207543168719, 13.669377946306337, 14.648104159223173, 15.64621336661643, 16.43645273116969, 17.390402904740494, 17.565619163789503, 11.584323695655804, 12.584918326851156, 13.536406696272392, 12.536015286294408, 11.538623346363723, 10.628692202942485, 9.79262688350005, 8.925329722074064, 9.815878860308016, 10.717672210635385, 11.726010452660859, 11.777993913411978, 10.830969505545779, 11.753647983806093, 12.694948328518462, 13.663085199479351, 14.675163819852603, 15.49239495448337, 16.431907411665538, 16.612764348907984, 10.787968665120582, 11.76729577931848, 12.730461633122228, 13.486398350675156, 12.557247145955532, 11.606334805974733, 10.7325619286942, 9.927110351799866, 10.791104481060144, 11.762620187905403, 11.638441908660022, 10.726766123309176, 9.845403322627016, 10.811311946045496, 11.748946610293974, 12.713396337667417, 13.664349211740403, 14.5164435887164, 15.536641256366073, 15.642020567688029, 9.811706189080935, 10.774849764670073, 11.75268884375588, 12.757102850097407, 13.536341665973318, 12.60915910364704, 11.707520409807325, 10.966331225757571, 11.819610273690966, 11.695136138273629, 10.665779495505408, 9.79121916346086, 8.901804115292423, 9.82673786432667, 10.699572413302972, 11.663409272579198, 12.668864847073744, 13.584700023581224, 14.517735512148024, 14.753495394127865, 8.749596457432608, 9.767671488352285, 10.805103352157195, 11.807621073095628, 12.879775840854485, 13.622505006810355, 12.669235760185552, 12.026016828746844, 11.708556477612175, 10.727866406652486, 9.723991403212567, 8.779796324280749, 7.9367603232394, 8.825524311940438, 9.679168254589932, 10.62232630086482, 11.62746239422947, 12.54868558473499, 13.51660588859526, 14.025009116281495, 8.159696060124244, 9.099652919733048, 10.070846934451742, 11.089388563526958, 12.052381927282301, 13.101067711013862, 12.668938385996118, 11.621668943867439, 10.666277915579565, 9.815722632251337, 8.800804592307143, 7.834407710226208, 6.991798209255599, 7.769279375522679, 8.700587895707134, 9.708833395515335, 10.552884222216624, 11.49571056259148, 12.475318264161288, 13.174142062183726, 8.821016485770171, 9.894138352084225, 10.857471060387855, 11.909476178176376, 12.907423461366093, 12.646491002292851, 11.607018551164108, 10.664855991000547, 9.71333410482194, 8.821086343387782, 7.829296460255327, 6.853099704037708, 6.0065348444115285, 6.743039846369568, 7.727989227437108, 8.638751019594288, 9.586170938913156, 10.570456529468432, 11.525702354514053, 12.535248320579349, 9.753435098162567, 10.809740665201762, 11.78975538988801, 12.756606317113977, 12.647700888207549, 11.692118134558768, 10.627018427571683, 9.691494522736253, 8.711225855168568, 7.829691264364406, 6.822148886167084, 5.826974839695787, 4.969605063957301, 5.778756588003058, 6.733497243012639, 7.660947129066223, 8.594960940480474, 9.560557206552529, 10.605747649014493, 11.646454106078329, 10.795884407328316, 11.851960397192068, 12.737217881678895, 12.645598667995966, 11.702729337323706, 10.721458328745339, 9.78516920493577, 8.754067756129684, 7.764841314698326, 6.835003479477117, 5.7692939347541445, 4.823303745338576, 3.9266603718806485, 4.785986878738704, 5.787407216867996, 6.715034186377204, 7.724959299432366, 8.705720973587708, 9.760707622057764, 10.710996227490808, 11.665281225817957, 12.61202881980431, 12.820441872070665, 11.792451735334343, 10.766411897367533, 9.838046431037714, 8.763220133293869, 7.803935619534612, 6.885676060671861, 5.8555771236647995, 4.908597192129871, 3.858143257572322, 2.8805309376815, 3.851198469729767, 4.843570401239848, 5.793314150408627, 6.752749086860841, 7.817667177203845, 8.83533718824625, 9.765151562227334, 12.596778836095751, 12.758035988731775, 11.764307963159043, 10.8044376458159, 9.77769555072441, 8.792953934995293, 7.92317082238965, 6.872563984059669, 5.819641364781184, 4.8700010266891605, 3.8974529164864897, 2.903924462065573, 1.872532251895716, 2.880525010103388, 3.8430715911383326, 4.797696357773685, 5.799206052058588, 6.833570439011167, 7.852867335129009, 8.794343658094132, 12.907604050492884, 11.841567983752263, 10.79582232372486, 9.861710559302482, 8.806068720371858, 7.842726042312169, 6.872591854843739, 5.877792701059924, 4.862378851295798, 3.8466006969634163, 2.913798819303178, 1.911273396352106, 0.9473141285531629, 1.9015235598798226, 2.9475246729310767, 3.909772347991267, 4.960613956837293, 5.9367210869604, 6.871139341793495, 7.868985675682939, 12.167910764606253, 11.196346747691127, 10.123360238525603, 9.049904122514999, 8.04506028935971, 7.02359703048799, 5.95463471741476, 4.886313749265093, 3.9370786452499176, 2.9963066383116734, 1.9459047970211487, 1.018059847603509, 0.0, 1.0533276869351746, 2.007514854277648, 3.059436490939677, 4.052455534767724, 5.116535783304446, 6.169493385179194, 7.193970424627411, 13.01912838646479, 11.974223486416294, 10.933586713860603, 9.860139469397229, 8.89322774053528, 7.85499543910649, 6.897616863027811, 5.912157246960378, 4.964595500545454, 3.926266619204811, 2.875180326022856, 1.9294498516833707, 0.9705043788901393, 1.9275496532287164, 2.863346840812792, 3.8210445014194288, 4.860662384467151, 5.92104681893844, 6.870494841228245, 7.803291546051424, 13.7837159100762, 12.83762250973744, 11.775608469525041, 10.804367637261011, 9.776874039609421, 8.807028171458976, 7.8262551701568634, 6.8772457684053245, 5.932118929376605, 4.922852896717454, 3.8716889564436734, 2.909824984542434, 2.0207800882960814, 2.9724778680847983, 3.829819821216139, 4.754092733415043, 5.761198152372199, 6.79965533418607, 7.832926973851171, 8.791410084872648, 14.641303526193173, 13.676871551280957, 12.708915431925236, 11.77737770625125, 10.814304858365466, 9.843988880197166, 8.840739996144572, 7.874181887251362, 6.860446427722971, 5.883276378763961, 4.81823253815712, 3.877340537099067, 3.031404832490896, 3.9922887043695052, 4.842415712426899, 5.71294726591738, 6.724445175566331, 7.715770423206217, 8.721136066144604, 9.748614604926598, 15.713875535207288, 14.694374644274387, 13.63871690533, 12.794544050083612, 11.85665514250674, 10.834268652507712, 9.772716132249627, 8.770413105977731, 7.699240263389351, 6.771089080910322, 5.770046869285689, 4.846404741208853, 4.092849253307026, 4.946908909405023, 5.783623381128638, 6.729002459898414, 7.658396058220742, 8.588032368702047, 9.577077603029053, 10.511752031594918, 16.519677546286612, 15.496686386798952, 14.55953307355471, 13.552713283454544, 12.498036128036821, 11.495186310872775, 10.55223313359799, 9.613337826410293, 8.676296553161357, 7.740529969753387, 6.758878315548249, 5.851908435498991, 5.0535120592121485, 5.972924199554062, 6.794480742318404, 7.662184041043888, 8.599060975321414, 9.562546516359118, 10.511571611649085, 11.464683399261764, 17.45571863037968, 16.444076894736284, 15.557414642906544, 14.541285133017032, 13.466476894615653, 12.43274204363861, 11.611462815944705, 10.577419410077296, 9.603875527764602, 8.661059382623998, 7.705196386299801, 6.921615791715691, 5.982215030506291, 6.971796278458562, 7.777592642106072, 8.636175670994588, 9.635379296930093, 10.598912645159118, 11.483409646396701, 12.416369046798614], [12.49376449504859, 11.626240821380643, 10.698016487778329, 9.679686050646142, 8.740168669048307, 7.799024064739436, 7.053733829875401, 7.851417466191329, 8.87064695643993, 9.77937088205407, 10.642994026069587, 11.600426088828694, 12.547894334437421, 12.767310591383215, 13.700131959760771, 14.654060735096612, 15.647461094813645, 16.458105107350423, 17.45922256346098, 18.37278839842073, 11.491301167901307, 12.421357611087767, 11.587701904456688, 10.647356094194613, 9.669322882554907, 8.739223390993365, 8.00851020476246, 8.920620664481977, 9.810410905786497, 10.70620795864297, 11.706355717912672, 12.535309557255246, 12.584708339838246, 11.833275384162015, 12.710577898781162, 13.689304111697998, 14.687413319091254, 15.477652683644514, 16.431602857215317, 17.354139057689224, 10.66067645740919, 11.661271088604542, 12.612759458025774, 11.61236804804779, 10.614976108117105, 9.705044964695869, 8.97080221238551, 9.867190178947357, 10.826008415507248, 11.754879745501995, 12.763217987527469, 12.571005186676329, 11.546879094753757, 10.794847936280918, 11.736148280993287, 12.704285151954176, 13.716363772327428, 14.533594906958193, 15.47310736414036, 16.394871272282145, 9.864321426873966, 10.836982553676194, 11.800148407479941, 12.562751112428538, 11.633599907708915, 10.682687567728117, 9.910737257579658, 10.86897080867316, 11.801234036259375, 12.787362337596305, 12.505941362526665, 11.519777396573527, 10.561312911834994, 9.852511898520321, 10.790146562768799, 11.754596290142242, 12.705549164215228, 13.557643541191224, 14.577841208840896, 15.42412749106219, 8.881392963438648, 9.844536539027786, 10.822375618113593, 11.82678962445512, 12.612694427726701, 11.685511865400423, 10.885695738692784, 11.908191682630864, 12.829739828890197, 12.562635592140271, 11.53327894937205, 10.584230436725212, 9.617713704500401, 8.867937816801495, 9.740772365777797, 10.704609225054023, 11.710064799548569, 12.625899976056047, 13.558935464622849, 14.47285407151962, 7.819283231790322, 8.837358262709998, 9.874790126514908, 10.877307847453341, 11.949462615212198, 12.69885776856374, 11.847411089071011, 12.87980163543232, 12.648691755981528, 11.595365860519129, 10.59149085707921, 9.647295778147392, 8.652669912447378, 7.8667242644152635, 8.720368207064757, 9.663526253339645, 10.668662346704295, 11.589885537209813, 12.557805841070085, 13.415297334886692, 7.106368373189068, 8.046325232797873, 9.017519247516567, 10.036060876591783, 10.999054240347126, 12.047740024078687, 12.824199744900335, 12.561804222236793, 11.606413193948917, 10.701182366787348, 9.668304046173786, 8.701907164092852, 7.707707798463576, 6.810479327997504, 7.741787848181958, 8.75003334799016, 9.59408417469145, 10.536910515066305, 11.516518216636113, 12.445584045160645, 7.78325925321027, 8.856381119524324, 9.819713827827954, 10.871718945616475, 11.869666228806192, 12.809402490216991, 12.54715382953346, 11.6049912693699, 10.653469383191291, 9.706546077923793, 8.696795914121973, 7.720599157904353, 6.722444433619506, 5.784239798844393, 6.769189179911933, 7.679950972069113, 8.627370891387981, 9.611656481943257, 10.566902306988878, 11.576448273054172, 8.715677865602666, 9.77198343264186, 10.751998157328108, 11.718849084554076, 12.67450722081363, 12.63225341292812, 11.567153705941035, 10.631629801105605, 9.65136113353792, 8.769826542733759, 7.762284164536436, 6.726030464642239, 5.746457319000318, 4.819956540477883, 5.774697195487464, 6.702147081541048, 7.6361608929553, 8.601757159027354, 9.646947601489318, 10.667248934417822, 9.758127174768415, 10.814203164632167, 11.699460649118993, 12.693536842842478, 12.642864615693059, 11.66159360711469, 10.725304483305122, 9.694203034499036, 8.704976593067679, 7.775138757846469, 6.709429213123497, 5.763439023707928, 4.866795650249999, 3.8271868312135298, 4.828607169342822, 5.7562341388520295, 6.766159251907192, 7.7469209260625345, 8.790720543752204, 9.673238994930907, 10.627523993258055, 11.574271587244409, 12.595374150392496, 12.769761292983736, 11.743721455016926, 10.815355988687108, 9.740529690943262, 8.781245177184005, 7.862985618321255, 6.828675260064877, 5.848732470499223, 4.798278535941674, 3.820666216050851, 2.8923984222045926, 3.884770353714674, 4.834514102883453, 5.782762008555282, 6.8476800988982856, 7.865350109940691, 8.727394329667433, 11.55902160353585, 12.584124140814104, 12.741617520808436, 11.781747203465294, 10.755005108373803, 9.770263492644686, 8.900480380039044, 7.849873541709062, 6.796950922430577, 5.847310584338554, 4.837588194855841, 3.8440597404349246, 2.8126675302650677, 1.9217249625782133, 2.87315484379028, 3.8277092794681256, 4.829218973753029, 5.863583360705608, 6.850882499816291, 7.7565864255342305, 12.507432552305461, 12.818877541401658, 11.773131881374253, 10.839020116951875, 9.783378278021251, 8.820035599961562, 7.849901412493132, 6.8551022587093176, 5.839688408945191, 4.82391025461281, 3.8911083769525714, 2.8514086747214575, 1.8874494069225145, 0.9332399755958547, 1.909767440371175, 2.8720151154313656, 3.9228567242773917, 4.898963854400499, 5.833382109233594, 6.831228443123038, 13.221238451541426, 12.2496744346263, 11.176687925460776, 10.103231809450174, 9.098387976294886, 8.076924717423164, 7.007962404349934, 5.939641436200267, 4.990406332185092, 4.049634325246848, 2.9992324839563236, 2.0713875345386836, 1.0533276869351746, 0.0, 0.9541871673424734, 2.0061088040045023, 2.9991278478325487, 4.063208096369271, 5.11616569824402, 6.140642737692236, 14.072456073399962, 13.027551173351467, 11.986914400795776, 10.913467156332402, 9.946555427470454, 8.908323126041664, 7.950944549962985, 6.965484933895553, 6.017923187480629, 4.979594306139986, 3.928508012958031, 2.966657386549981, 2.0077119137567494, 1.0506666394181725, 1.9396996025661761, 2.897397263172813, 3.9303491588248654, 4.990733593296155, 5.94018161558596, 6.872978320409139, 14.837043597011377, 13.890950196672616, 12.828936156460218, 11.857695324196188, 10.830201726544598, 9.860355858394152, 8.87958285709204, 7.930573455340499, 6.969326464243215, 5.960060431584064, 4.9088964913102835, 3.9470325194090443, 3.0579876231626915, 2.095594854274254, 2.9061725829695235, 3.8304454951684277, 4.837550914125583, 5.876008095939454, 6.902613748208886, 7.861096859230363, 15.69463121312835, 14.730199238216134, 13.762243118860413, 12.830705393186427, 11.867632545300642, 10.897316567132343, 9.894067683079749, 8.927509574186537, 7.897653962589581, 6.920483913630571, 5.85544007302373, 4.914548071965677, 4.068612367357506, 3.115405690558961, 3.918768474180283, 4.789300027670764, 5.8007979373197145, 6.792123184959601, 7.797488827897988, 8.824967366679981, 16.767203222142467, 15.747702331209563, 14.692044592265177, 13.847871737018789, 12.909982829441917, 11.878713162312321, 10.817160642054237, 9.807620640844341, 8.736447798255961, 7.808296615776932, 6.8072544041522995, 5.883612276075463, 5.034709710180318, 4.070025895594479, 4.859976142882022, 5.805355221651798, 6.734748819974126, 7.664385130455432, 8.653430364782439, 9.588104793348304, 17.556885081153222, 16.533893921665562, 15.596740608421321, 14.589920818321154, 13.535243662903431, 12.532393845739385, 11.5894406684646, 10.650545361276903, 9.713504088027967, 8.777737504619997, 7.796085850414859, 6.8891159703656015, 5.995372516085441, 5.096041185743518, 5.870833504071788, 6.738536802797272, 7.675413737074798, 8.638899278112502, 9.587924373402469, 10.541036161015148, 18.49292616524629, 17.481284429602894, 16.594622177773154, 15.578492667883642, 14.503684429482263, 13.46994957850522, 12.648670350811315, 11.614626944943906, 10.641083062631212, 9.698266917490606, 8.74240392116641, 7.958823326582301, 6.924075487379583, 6.094913264648018, 6.853945403859456, 7.712528432747971, 8.711732058683477, 9.675265406912501, 10.559762408150085, 11.492721808551998], [11.539577327706116, 10.67205365403817, 9.743829320435855, 8.725498883303668, 7.785981501705834, 6.844836897396963, 7.812198411964566, 8.679298970778998, 9.6985284610276, 10.637243213679312, 11.513637009459194, 12.4710690722183, 13.418537317827028, 13.721497758725688, 13.06784377654495, 13.95943911010435, 14.867731486286594, 15.678375498823375, 16.67949295493393, 17.59114871935548, 10.537114000558834, 11.467170443745294, 10.633514737114213, 9.693168926852138, 8.715135715212433, 7.785036223650891, 8.766974786851627, 9.748502169069646, 10.638292410374167, 11.564080290268212, 12.564228049537913, 13.405952540644853, 13.53889550718072, 12.787462551504488, 12.059587616513625, 12.994682486705736, 13.907683710564203, 14.697923075117465, 15.651873248688268, 16.572499378623974, 9.706489290066717, 10.707083921262068, 11.658572290683301, 10.658180880705316, 9.660788940774632, 8.750857797353396, 9.729266794474675, 10.695071683535026, 11.653889920094917, 12.612752077127237, 13.62109031915271, 13.525192354018804, 12.501066262096233, 11.749035103623392, 11.08515799872575, 11.964255716136973, 12.936634163800377, 13.753865298431144, 14.69337775561331, 15.613231593216891, 8.91013425953149, 9.88279538633372, 10.845961240137468, 11.608563945086065, 10.679412740366441, 9.728500400385643, 10.669201839668824, 11.696852313260829, 12.629115540847044, 13.615243842183974, 13.46012852986914, 12.473964563916002, 11.51550007917747, 10.806699065862794, 10.050117126951596, 11.01456685432504, 11.925819555688177, 12.777913932664175, 13.798111600313847, 14.642487811996935, 7.927205796096175, 8.890349371685312, 9.86818845077112, 10.872602457112647, 11.65850726038423, 10.73132469805795, 11.64416032078195, 12.682999605601161, 13.636855233730122, 13.516822759482746, 12.487466116714526, 11.538417604067687, 10.571900871842876, 9.822124984143969, 9.000742929960595, 9.96457978923682, 10.930335191021518, 11.846170367528998, 12.777295785557593, 13.691214392454365, 6.865096064447848, 7.883171095367525, 8.920602959172435, 9.923120680110868, 10.995275447869725, 11.744670601221266, 12.605875671160177, 13.638266217521487, 13.602878923323999, 12.549553027861604, 11.545678024421685, 10.601482945489867, 9.606857079789853, 8.820911431757738, 7.980338771247555, 8.923496817522445, 9.888932738177244, 10.810155928682764, 11.776166162004829, 12.633657655821436, 6.152181205846595, 7.092138065455399, 8.063332080174094, 9.08187370924931, 10.044867073004653, 11.093552856736213, 12.075466176328955, 13.126747314883392, 12.560600361291389, 11.655369534129823, 10.62249121351626, 9.656094331435327, 8.661894965806052, 7.764666495339978, 7.001758412364757, 7.970303739463109, 8.814354566164399, 9.757180906539254, 10.734878537570857, 11.66394436609539, 6.829072085867796, 7.902193952181849, 8.865526660485479, 9.917531778274, 10.915479061463717, 11.855215322874516, 12.894687774003259, 12.559178436712372, 11.607656550533763, 10.660733245266268, 9.650983081464448, 8.674786325246828, 7.676631600961981, 6.738426966186867, 6.028189746396921, 6.900221363542062, 7.8476412828609305, 8.830016802878001, 9.785262627923622, 10.681102494874057, 7.761490698260193, 8.817796265299387, 9.797810989985635, 10.764661917211603, 11.720320053471157, 12.702573661562882, 12.521340873283506, 11.585816968448077, 10.605548300880391, 9.72401371007623, 8.71647133187891, 7.680217631984713, 6.700644486342792, 5.7741437078203575, 5.033697761972452, 5.922417473013997, 6.823606395849753, 7.763175989505649, 8.789087909950265, 9.713061767075347, 8.80394000742594, 9.860015997289691, 10.74527348177652, 11.739349675500005, 12.665291604355001, 12.615780774457162, 11.679491650647593, 10.648390201841508, 9.65916376041015, 8.729325925188942, 7.66361638046597, 6.717626191050401, 5.820982817592473, 4.7813739985560035, 3.9964354332450163, 4.924062402754224, 5.8491164138075815, 6.829878087962923, 7.83653337640973, 8.719051827588432, 9.67333682591558, 10.620084419901934, 11.641186983050021, 12.671264109510942, 12.697908622359401, 11.769543156029583, 10.694716858285737, 9.73543234452648, 8.817172785663729, 7.78286242740735, 6.802919637841696, 5.752465703284147, 4.774853383393324, 3.846585589547066, 2.959744264206339, 3.894578814264995, 4.8285748412128076, 5.893492931555811, 6.911162942598216, 7.773207162324958, 10.604834436193375, 11.62993697347163, 12.623664999044362, 12.735934370807767, 11.709192275716276, 10.72445065998716, 9.854667547381517, 8.804060709051535, 7.75113808977305, 6.801497751681027, 5.791775362198314, 4.798246907777398, 3.766854697607541, 2.8759121299206867, 1.9189676764478065, 2.873522112125652, 3.875031806410555, 4.9093961933631345, 5.896695332473817, 6.802399258191756, 11.612086774125347, 12.666135406956535, 12.727319048716726, 11.793207284294349, 10.737565445363725, 9.774222767304035, 8.804088579835605, 7.809289426051791, 6.793875576287665, 5.778097421955283, 4.845295544295045, 3.805595842063931, 2.841636574264988, 1.887427142938328, 0.9555802730287015, 1.917827948088892, 2.968669556934918, 3.944776687058025, 4.87919494189112, 5.877041275780564, 12.664459455366234, 13.203861601968775, 12.130875092803251, 11.057418976792649, 10.05257514363736, 9.03111188476564, 7.962149571692409, 6.893828603542742, 5.944593499527566, 5.0038214925893225, 3.9534196512987974, 3.0255747018811574, 2.007514854277648, 0.9541871673424734, 0.0, 1.0519216366620288, 2.0449406804900754, 3.109020929026798, 4.161978530901546, 5.186455570349763, 13.63953838563814, 13.981738340693942, 12.94110156813825, 11.867654323674877, 10.900742594812929, 9.862510293384139, 8.90513171730546, 7.919672101238028, 6.972110354823103, 5.93378147348246, 4.882695180300505, 3.8373003699395865, 2.8783548971463553, 1.9213096228077782, 0.9855124352237026, 1.9432100958303395, 2.976161991482392, 4.036546425953682, 4.985994448243487, 5.918791153066666, 14.619804779515256, 14.845137364015091, 13.783123323802693, 12.811882491538663, 11.784388893887073, 10.814543025736628, 9.833770024434514, 8.884760622682975, 7.839969447632821, 6.83070341497367, 5.77953947469989, 4.81767550279865, 3.9286306065522973, 2.96623783766386, 1.95198541562705, 2.8762583278259544, 3.8833637467831092, 4.921820928596981, 5.948426580866412, 6.90690969188789, 15.56060532181816, 15.684386405558609, 14.716430286202888, 13.784892560528903, 12.821819712643117, 11.836330609715153, 10.83308172566256, 9.804620989461812, 8.768296945979188, 7.7911268970201775, 6.726083056413336, 5.785191055355282, 4.939255350747112, 3.974651047342328, 2.9645813068378093, 3.835112860328291, 4.846610769977241, 5.837936017617127, 6.843301660555515, 7.870780199337507, 16.60699429886687, 16.70188949855204, 15.646231759607652, 14.767091191607525, 13.808955788829877, 12.749356145701928, 11.687803625443843, 10.678263624233947, 9.607090781645567, 8.678939599166538, 7.677897387541906, 6.754255259465069, 5.8625912147679875, 4.897907400182148, 3.905788975539549, 4.8511680543093245, 5.780561652631652, 6.710197963112958, 7.699243197439966, 8.63391762600583, 17.584268995044475, 17.404536905055167, 16.467383591810925, 15.460563801710759, 14.405886646293038, 13.403036829128991, 12.460083651854207, 11.521188344666509, 10.584147071417574, 9.648380488009604, 8.666728833804465, 7.759758953755207, 6.82325402067311, 5.923922690331187, 4.916646336729315, 5.784349635454799, 6.721226569732325, 7.68471211077003, 8.633737206059996, 9.586848993672675, 18.52031007913754, 17.675673022929402, 16.669420884988103, 15.874759749713114, 14.900166467238073, 14.084951649246115, 13.519313334200922, 12.485269928333512, 11.511726046020819, 10.568909900880213, 9.613046904556017, 8.787440932593586, 7.751956991967252, 6.8533778467371835, 5.899758236516982, 6.758341265405497, 7.757544891341004, 8.721078239570028, 9.605575240807612, 10.538534641209525], [10.684196277196586, 9.81667260352864, 8.888448269926325, 7.870117832794139, 6.930600451196304, 7.83703789470095, 8.804399409268553, 9.68709396701593, 10.706323457264531, 11.645038209916244, 12.539265774281498, 13.496697837040605, 14.444166082649332, 14.64353319770021, 13.931386126235962, 13.132872461932086, 13.875863982177036, 14.686507994713818, 15.687625450824374, 16.56806762680438, 9.681732950049303, 10.611789393235764, 9.778133686604685, 8.83778787634261, 7.859754664702903, 8.777237220954879, 9.759175784155614, 10.756297165306577, 11.646087406611098, 12.571875286505144, 13.572023045774845, 14.431581305467157, 14.46093094615524, 13.70949799047901, 12.923129966204636, 12.168115838533472, 12.915816206454645, 13.706055571007909, 14.660005744578712, 15.54941828607287, 8.851108239557188, 9.788628100565878, 10.731250967408654, 9.802799830195786, 8.805407890265101, 9.743058794657383, 10.721467791778663, 11.702866679771958, 12.661684916331849, 13.620547073364168, 14.628885315389642, 14.447227792993324, 13.423101701070753, 12.671070542597914, 11.94870034841676, 11.13768906796471, 11.944766659690819, 12.761997794321587, 13.701510251503754, 14.59015050066579, 7.920575760522308, 8.830873749671692, 9.79403960347544, 10.753182894576534, 9.82403168985691, 10.72070139768963, 11.661402836972812, 12.691036408997128, 13.636910537083976, 14.623038838420905, 14.38216396884366, 13.396000002890522, 12.43753551815199, 11.728734504837316, 10.913659476642607, 10.188000206152775, 10.933952051578618, 11.786046428554618, 12.80624409620429, 13.619406719445832, 6.875284159434146, 7.838427735023284, 8.816266814109092, 9.820680820450619, 10.751375954149966, 11.678558516476244, 12.608236406049762, 13.647075690868974, 14.600931318997935, 14.438858198457266, 13.409501555689046, 12.460453043042207, 11.493936310817396, 10.74416042311849, 9.864285279651606, 9.138013141064556, 9.93846768691196, 10.854302863419441, 11.784549894656852, 12.668133299903262, 5.813174427785819, 6.831249458705496, 7.868681322510406, 8.87119904344884, 9.943353811207697, 10.980745739624316, 11.948552469733961, 12.98094301609527, 14.04210920137683, 13.471588466836124, 12.467713463396205, 11.523518384464387, 10.528892518764373, 9.742946870732258, 8.843881120938565, 8.088188665703797, 8.897065234067686, 9.818288424573208, 10.783420271104088, 11.610576563270333, 5.100259569184566, 6.04021642879337, 7.011410443512065, 8.029952072587282, 8.992945436342625, 10.041631220074185, 11.023544539666927, 12.074825678221364, 13.044432000021544, 12.577404973104343, 11.54452665249078, 10.578129770409847, 9.583930404780572, 8.686701934314499, 7.865300762055767, 7.017676492058991, 7.822487062054841, 8.765313402429697, 9.742132646670116, 10.640863273544287, 5.800179945753011, 6.873301812067065, 7.836634520370694, 8.888639638159216, 9.886586921348933, 10.826323182759731, 11.865795633888474, 12.893596915896023, 12.642992424706382, 11.582768684240788, 10.573018520438968, 9.596821764221348, 8.598667039936501, 7.660462405161387, 6.891732096087932, 5.947594116137944, 6.855773778751372, 7.83727091197726, 8.792516737022881, 9.652210354759273, 6.732598558145408, 7.788904125184603, 8.76891884987085, 9.735769777096818, 10.691427913356373, 11.673681521448097, 12.738781228435183, 12.624902597943414, 11.64463393037573, 10.659127891030911, 9.641214074196787, 8.602253070959234, 7.622679925317312, 6.6961791467948775, 5.8972401116634625, 4.969790225609879, 5.83086050494901, 6.770430098604908, 7.784474437689904, 8.684169626960562, 7.775047867311154, 8.831123857174905, 9.716381341661736, 10.71045753538522, 11.636399464240217, 12.617670472818585, 12.71857728014293, 11.687475831336846, 10.698249389905488, 9.76841155468428, 8.702702009961307, 7.756711820545739, 6.773407150731929, 5.7034094375305235, 4.888267841571711, 3.971435155350105, 4.85637052290684, 5.837132197062182, 6.831919904149369, 7.690159687473647, 8.644444685800796, 9.59119227978715, 10.612294842935237, 11.642371969396157, 12.668411807362967, 12.815446858390851, 11.740620560647006, 10.781336046887748, 9.863076488024996, 8.821948056902688, 7.842005267337034, 6.791551332779485, 5.813939012888662, 4.768621028521586, 3.8515766725330334, 2.901832923364254, 3.835828950312066, 4.9007470406550695, 5.906549470337855, 6.7443150222101735, 9.57594229607859, 10.601044833356845, 11.594772858929577, 12.613877473682379, 12.755095978077545, 11.770354362348428, 10.900571249742786, 9.849964411412804, 8.797041792134317, 7.847401454042295, 6.830860991693652, 5.837332537272736, 4.805940327102879, 3.797947568895207, 2.8354009878602624, 1.8807762212249108, 2.882285915509814, 3.916650302462393, 4.867803192359032, 5.773507118076972, 10.583194634010562, 11.63724326684175, 12.56325849836376, 12.839110986655617, 11.783469147724993, 10.820126469665304, 9.849992282196874, 8.85519312841306, 7.839779278648932, 6.824001124316551, 5.891199246656313, 4.851499544425199, 3.8875402766262552, 2.9333308452995954, 1.8873297322483413, 0.925082057188151, 1.939777416820133, 2.91588454694324, 3.8503028017763348, 4.848149135665779, 11.63556731525145, 12.607131332166576, 13.18279672946528, 12.109340613454677, 11.104496780299389, 10.083033521427668, 9.014071208354437, 7.94575024020477, 6.996515136189594, 6.055743129251351, 5.005341287960826, 4.077496338543186, 3.059436490939677, 2.0061088040045023, 1.0519216366620288, 0.0, 0.9930190438280464, 2.057099292364769, 3.1100568942395173, 4.134533933687734, 12.615123697337896, 13.594744070966907, 13.99302320480028, 12.919575960336905, 11.952664231474957, 10.914431930046167, 9.957053353967488, 8.971593737900056, 8.022035519708894, 6.981274307946816, 5.909371582498928, 4.862929134761891, 3.903983661968659, 2.946938387630082, 2.0111412000460063, 1.0534435394393693, 1.924240354820363, 2.9846247892916526, 3.934072811581457, 4.866869516404637, 13.595390091215013, 14.541483491553773, 14.831922813087154, 13.860681980823124, 12.833188383171533, 11.863342515021088, 10.882569513718975, 9.933560111967436, 8.865598212455126, 7.856332179795975, 6.805168239522194, 5.843304267620955, 4.954259371374601, 3.991866602486164, 2.9776141804493537, 1.986491771434984, 2.9385283342340074, 3.9769855160478786, 4.896504944204382, 5.85498805522586, 14.536190633517917, 15.500622608430133, 15.765229775487349, 14.833692049813363, 13.870619201927578, 12.861959374537458, 11.858710490484864, 10.830249754284116, 9.793925710801492, 8.816755661842482, 7.751711821235641, 6.810819820177587, 5.964884115569415, 4.98244604357926, 3.972376303074741, 2.9453463039373204, 3.956844213586271, 4.948169461226158, 5.953535104164545, 6.8933814001210925, 15.583913206315767, 16.55184179606357, 16.695031248892114, 15.79271995642983, 14.834584553652181, 13.774984910524232, 12.713432390266147, 11.703892389056252, 10.632719546467872, 9.704568363988843, 8.70352615236421, 7.779884024287373, 6.870386211004919, 5.90570239641908, 4.913583971776481, 3.995787003799795, 4.925180602122122, 5.854816912603428, 6.8438621469304355, 7.778536575496301, 16.561187902493373, 17.56262088492913, 16.720519146767675, 15.944071725526591, 15.091118641296084, 14.428665593951296, 13.485712416676511, 12.546817109488813, 11.609775836239878, 10.674009252831908, 9.692357598626769, 8.78538771857751, 7.8310490169100415, 6.931717686568119, 5.924441332966246, 4.928968584945269, 5.865845519222795, 6.8293310602604995, 7.7783561555504654, 8.731467943163144, 17.49722898658644, 16.683805518819845, 15.677553380878546, 14.882892245603555, 14.073599819065809, 14.948493998937126, 14.544942099023226, 13.510898693155816, 12.537354810843123, 11.594538665702517, 10.63867566937832, 9.795235928830518, 8.759751988204183, 7.845578844041171, 6.89195923382097, 5.902960214895968, 6.902163840831474, 7.865697189060498, 8.750194190298082, 9.683153590699995], [9.739417551930973, 8.871893878263027, 7.943669544660714, 6.997738115970071, 7.844608922575347, 8.751046366079994, 9.718407880647597, 10.604489621616601, 11.623719111865203, 12.562433864516915, 13.456661428882166, 14.414093491641273, 15.36156173725, 15.582057453797793, 14.792616020817755, 13.986655101852907, 12.942009786005446, 13.752653798542227, 14.753771254652783, 15.57504858297633, 8.736954224783691, 9.667010667970152, 8.905753969780616, 7.9654081595185415, 8.773763136081946, 9.691245692333922, 10.673184255534657, 11.673692819907249, 12.56348306121177, 13.489270941105815, 14.489418700375516, 15.348976960067825, 15.453949989983286, 14.648022246576593, 13.784359860786429, 13.021898478454293, 11.981962010283056, 12.772201374836317, 13.72615154840712, 14.556399242244822, 7.906329514291575, 8.795609056737831, 9.738231923580607, 8.985862906487219, 9.719416361644145, 10.657067266036426, 11.635476263157706, 12.62026233437263, 13.57908057093252, 14.53794272796484, 15.546280969990313, 15.44024683682137, 14.416120744898798, 13.609594798695497, 12.809930242998554, 11.998918962546503, 11.01091246351923, 11.828143598149996, 12.767656055332163, 13.597131456837742, 6.927556716694261, 7.837854705843645, 8.801020559647393, 9.853422564088984, 10.738040161235954, 11.634709869068674, 12.575411308351855, 13.605044880376171, 14.554306191684647, 15.540434493021577, 15.375183012671705, 14.389019046718568, 13.430554561980035, 12.6672587609349, 11.7748893712244, 11.049230100734569, 10.000097855407029, 10.852192232383027, 11.8723899000327, 12.626387675617785, 5.882265115606099, 6.845408691195237, 7.823247770281045, 8.827661776622572, 9.758356910321918, 10.685539472648198, 11.615217362221717, 12.654056647040928, 13.60791227516989, 14.581381817695638, 14.402520599517091, 13.453472086870253, 12.486955354645442, 11.682684679216074, 10.725515174233399, 9.99924303564635, 9.00461349074037, 9.92044866724785, 10.846093382349602, 11.675114256075215, 4.820155383957773, 5.83823041487745, 6.875662278682359, 7.878179999620793, 8.95033476737965, 9.987726695796269, 10.955533425905914, 11.987923972267224, 13.049090157548783, 14.061797596807782, 13.46073250722425, 12.516537428292432, 11.521911562592418, 10.681471126829843, 9.705111015520359, 8.94941856028559, 7.963211037896096, 8.884434228401616, 9.844963758796839, 10.617557519442286, 4.107240525356519, 5.047197384965323, 6.018391399684019, 7.036933028759234, 7.999926392514578, 9.048612176246138, 10.03052549583888, 11.081806634393317, 12.051412956193497, 13.07562412832102, 12.537545696318826, 11.571148814237892, 10.576949448608618, 9.657839176822016, 8.72653065663756, 7.878906386640784, 6.888632865883252, 7.831459206258108, 8.803676134362867, 9.64784422971624, 4.807160901924965, 5.880282768239018, 6.843615476542649, 7.89562059433117, 8.893567877520887, 9.833304138931686, 10.872776590060429, 11.900577872067977, 12.858861940504047, 12.575787728068834, 11.566037564267013, 10.589840808049393, 9.591686083764547, 8.653481448989433, 7.752961990669725, 6.8088240107197375, 5.921919582579783, 6.903416715805669, 7.854060224715632, 8.659191310931226, 5.739579514317361, 6.7958850813565554, 7.775899806042803, 8.742750733268771, 9.698408869528325, 10.68066247762005, 11.745762184607136, 12.681286089442565, 12.637652974203775, 11.652146934858958, 10.634233118024834, 9.595272114787281, 8.61569896914536, 7.689198190622924, 6.758470006245256, 5.831020120191672, 4.89700630877742, 5.836575902433317, 6.791455393861858, 7.691150583132516, 6.782028823483107, 7.838104813346858, 8.723362297833688, 9.717438491557173, 10.643380420412168, 11.624651428990536, 12.560940552800105, 12.680494875164891, 11.691268433733534, 10.761430598512325, 9.695721053789352, 8.749730864373785, 7.766426194559975, 6.69642848135857, 5.860068409299618, 4.932441439790411, 3.922516326735249, 4.903278000890591, 5.838900860321322, 6.6971406436456, 7.651425641972748, 8.598173235959102, 9.61927579910719, 10.64935292556811, 11.67539276353492, 12.603758229864738, 12.733639604475051, 11.774355090715794, 10.856095531853043, 9.814967100730733, 8.83502431116508, 7.784570376607531, 6.8069580567167085, 5.761640072349633, 4.842495623427174, 3.892751874258395, 2.901974754140475, 3.9668928444834783, 4.9135304265098085, 5.751295978382126, 8.582923252250543, 9.608025789528797, 10.60175381510153, 11.620858429854332, 12.647600524945823, 12.763373406176473, 11.893590293570831, 10.84298345524085, 9.790060835962365, 8.84042049787034, 7.823880035521698, 6.830351581100782, 5.798959370930925, 4.7909666127232535, 3.828420031688309, 2.8737952650529572, 1.948431719338223, 2.9358332052464067, 3.8747841485309853, 4.780488074248924, 9.590175590182515, 10.644224223013703, 11.570239454535713, 12.50435121895809, 12.776488191553039, 11.81314551349335, 10.84301132602492, 9.848212172241105, 8.832798322476979, 7.817020168144596, 6.884218290484358, 5.844518588253244, 4.880559320454301, 3.926349889127642, 2.8803487760763877, 1.9181011010161972, 0.9467583729920865, 1.9228655031151938, 2.8572837579482884, 3.8551300918377325, 10.642548271423403, 11.614112288338529, 12.555398089236407, 13.102359657282724, 12.097515824127436, 11.076052565255715, 10.007090252182484, 8.938769284032817, 7.989534180017642, 7.048762173079398, 5.998360331788873, 5.070515382371233, 4.052455534767724, 2.9991278478325487, 2.0449406804900754, 0.9930190438280464, 0.0, 1.0640802485367225, 2.117037850411471, 3.141514889859687, 11.62210465350985, 12.601725027138858, 13.585671743113348, 13.896916790752604, 12.930005061890656, 11.891772760461865, 10.934394184383187, 9.90418418612218, 8.939431174309561, 7.898669962547483, 6.826767237099596, 5.780324789362559, 4.8213793165693275, 3.864334042230751, 2.9285368546466755, 1.9708391940400385, 0.9312213109923165, 1.9916057454636058, 2.9410537677534103, 3.87385047257659, 12.602371047386965, 13.548464447725726, 14.610478487938124, 14.778077635423791, 13.750584037772201, 12.780738169621756, 11.799965168319643, 10.850955766568104, 9.782993867055794, 8.773727834396643, 7.722563894122862, 6.760699922221622, 5.87165502597527, 4.909262257086833, 3.895009835050023, 2.903887426035653, 1.9455092904059605, 2.983966472219832, 3.903485900376336, 4.861969011397814, 13.54317158968987, 14.507603564602086, 15.475559683957806, 15.751087704414031, 14.788014856528246, 13.779355029138125, 12.776106145085532, 11.747645408884784, 10.71132136540216, 9.73415131644315, 8.66910747583631, 7.7282154747782545, 6.882279770170085, 5.899841698179929, 4.889771957675411, 3.8627419585379896, 2.981115182615091, 3.972440430254977, 4.966849125688471, 5.900362356293046, 14.590894162487718, 15.558822752235525, 16.40536115736257, 16.005209429231662, 15.75198020825285, 14.6923805651249, 13.630828044866815, 12.62128804365692, 11.55011520106854, 10.62196401858951, 9.620921806964878, 8.69727967888804, 7.787781865605589, 6.823098051019749, 5.83097962637715, 4.9097954751788375, 3.9804018768565106, 4.9100381873378165, 5.899083421664823, 6.833757850230689, 15.568168858665324, 16.569601841101086, 15.786664950596082, 15.010217529355002, 15.944901281216906, 15.346061248551964, 14.40310807127718, 13.464212764089481, 12.527171490840546, 11.591404907432576, 10.609753253227437, 9.702783373178178, 8.748444671510711, 7.849113341168788, 6.841836987566916, 5.842977056324312, 4.921066793957183, 5.884552334994888, 6.833577430284854, 7.786689217897533, 16.50420994275839, 15.749951322648254, 14.743699184706955, 13.949038049431966, 14.92738245898663, 15.80972389351892, 15.462337753623894, 14.428294347756484, 13.45475046544379, 12.511934320303185, 11.556071323978989, 10.71263158343119, 9.677147642804854, 8.759587315420214, 7.805967705200013, 6.81696868627501, 5.957385115565862, 6.920918463794886, 7.80541546503247, 8.738374865434382], [8.79582794130441, 7.928304267636465, 7.000079934034151, 7.9027823994140265, 8.749653206019303, 9.65609064952395, 10.623452164091553, 11.533728832632018, 12.55295832288062, 13.491673075532333, 14.42041255005628, 15.377844612815387, 16.4225965106064, 16.55645255517187, 15.767011122191832, 14.961050203226984, 13.916404887379523, 13.035173186393866, 13.825247880857491, 14.597229424104194, 7.793364614157128, 8.668906554622923, 8.03638575469413, 8.870452442962497, 9.678807419525903, 10.596289975777879, 11.578228538978614, 12.602932030922666, 13.492722272227187, 14.418510152121232, 15.418657911390934, 16.31272808124194, 16.452357561989277, 15.622417347950671, 14.758754962160506, 13.99629357982837, 12.956357111657132, 12.054720762687957, 12.797628174611829, 13.578580083372687, 6.880141729748644, 7.735874961151652, 8.678497827994427, 9.678889237972411, 10.624460645088101, 11.562111549480383, 12.470376792942812, 13.514487937262965, 14.473306173822856, 15.467181938980257, 16.47552018100573, 16.438654408827357, 15.414528316904788, 14.583989900069575, 13.78432534437263, 12.973314063920581, 11.985307564893306, 11.110662986001635, 11.83913268153687, 12.619312297965607, 5.867822621108082, 6.778120610257465, 7.741286464061213, 8.793688468502804, 9.684256206412945, 10.628629674734325, 11.530441747748663, 12.560075319772979, 13.543883290455874, 14.530011591792803, 15.48739266317418, 15.387426618724557, 14.428962133986024, 13.641653862308978, 12.749284472598477, 12.023625202108647, 10.974492956781106, 10.134711620234667, 10.910648598460568, 11.64856851674565, 4.82253102001992, 5.785674595609057, 6.763513674694865, 7.767927681036392, 8.698622814735739, 9.625805377062019, 10.555483266635537, 11.594322551454749, 12.54817817958371, 13.521647722109458, 14.58634913272363, 14.451879658876242, 13.485362926651431, 12.657079780590152, 11.699910275607476, 10.973638137020428, 9.979008592114447, 9.20296805509949, 9.868274223477467, 10.69729509720308, 3.7604212883715933, 4.77849631929127, 5.8159281830961795, 6.818445904034613, 7.89060067179347, 8.92799260021009, 9.895799330319734, 10.928189876681044, 11.989356061962603, 12.99771734827106, 14.001592351710979, 13.514945000298422, 12.520319134598408, 11.65586622820392, 10.679506116894435, 9.923813661659668, 8.937606139270173, 8.166953616253256, 8.867144599924703, 9.639738360570151, 3.0431602768197967, 3.983117136428601, 4.954311151147296, 5.972852780222512, 6.935846143977855, 7.984531927709415, 8.966445247302158, 10.017726385856594, 10.987332707656774, 12.011543879784298, 13.083207694780183, 12.569556386243882, 11.575357020614607, 10.632234278196092, 9.700925758011637, 8.85330148801486, 7.863027967257328, 7.113978594109746, 7.825856975490731, 8.670025070844105, 3.8293417430528276, 4.902463609366881, 5.865796317670512, 6.917801435459033, 7.915748718648751, 8.855484980059549, 9.894957431188292, 10.92275871319584, 11.88104278163191, 12.941266522097504, 12.564445136273003, 11.588248380055383, 10.590093655770536, 9.651889020995423, 8.727357092043802, 7.783219112093815, 6.896314683953859, 6.075178669071294, 6.876241065843495, 7.68137215205909, 4.761760355445224, 5.8180659224844185, 6.798080647170666, 7.764931574396634, 8.720589710656188, 9.702843318747913, 10.767943025734999, 11.703466930570428, 12.683735598138114, 12.650554506864946, 11.632640690030822, 10.59367968679327, 9.614106541151347, 8.687605762628912, 7.732865107619332, 6.80541522156575, 5.871401410151497, 5.008337855698942, 5.813636234989721, 6.71333142426038, 5.804209664610971, 6.860285654474723, 7.745543138961551, 8.739619332685036, 9.66556126154003, 10.646832270118399, 11.583121393927968, 12.614222842734053, 12.74180968367778, 11.81197184845657, 10.746262303733598, 9.80027211431803, 8.814048778521675, 7.74405106532027, 6.834463510673697, 5.906836541164489, 4.896911428109327, 4.075039954156216, 4.861081701449185, 5.719321484773464, 6.673606483100612, 7.620354077086965, 8.641456640235052, 9.671533766695973, 10.697573604662782, 11.625939070992601, 12.615891161285756, 12.828249072911785, 11.909989514049036, 10.865508350674979, 9.885565561109326, 8.835111626551777, 7.857499306660955, 6.809262656311333, 5.816890724801252, 4.867146975632473, 3.8763698555145525, 3.014554957699129, 3.9357112676376715, 4.77347681950999, 7.605104093378407, 8.63020663065666, 9.623934656229393, 10.643039270982195, 11.669781366073686, 12.679824976025014, 12.947484275766824, 11.896877437436842, 10.843954818158357, 9.894314480066333, 8.874421285465946, 7.880892831045029, 6.849500620875172, 5.8415078626675, 4.878961281632556, 3.9243365149972043, 2.9228268207123005, 1.9580140463742697, 2.8969649896588487, 3.802668915376788, 8.61235643131038, 9.666405064141566, 10.592420295663576, 11.526532060085954, 12.582173899016578, 12.867039495689342, 11.896905308220912, 10.902106154437098, 9.886692304672971, 8.870914150340589, 7.938112272680351, 6.898412570449237, 5.934453302650294, 4.980243871323634, 3.9342427582723807, 2.97199508321219, 1.921153474366164, 0.9450463442430569, 1.8794645990761516, 2.877310932965596, 9.664729112551267, 10.636293129466393, 11.57757893036427, 12.459130668857943, 13.161596072664159, 12.140132813792437, 11.071170500719207, 10.00284953256954, 9.053614428554365, 8.11284242161612, 7.062440580325595, 6.134595630907955, 5.116535783304446, 4.063208096369271, 3.109020929026798, 2.057099292364769, 1.0640802485367225, 0.0, 1.0529576018747482, 2.0774346413229647, 10.644285494637714, 11.623905868266725, 12.607852584241211, 13.530624304082242, 13.991039835247056, 12.952807533818266, 11.995428957739588, 10.96521895947858, 10.000465947665962, 8.959704735903884, 7.887802010455997, 6.841359562718959, 5.882414089925728, 4.925368815587151, 3.9895716280030755, 3.0318739673964386, 1.9922560843487163, 0.9318716498774269, 1.8813196721672314, 2.8141163769904107, 11.62455188851483, 12.57064528885359, 13.632659329065989, 14.489288252582316, 14.811618811128602, 13.841772942978157, 12.860999941676043, 11.911990539924505, 10.844028640412194, 9.834762607753044, 8.783598667479263, 7.821734695578023, 6.93268979933167, 5.970297030443233, 4.9560446084064225, 3.964922199392053, 2.9849523298621303, 1.9464951480482593, 2.8437518047901573, 3.802234915811635, 12.565352430817734, 13.52978440572995, 14.497740525085671, 15.453083442696427, 15.849049629884647, 14.840389802494526, 13.837140918441932, 12.808680182241185, 11.77235613875856, 10.79518608979955, 9.73014224919271, 8.789250248134655, 7.943314543526485, 6.960876471536329, 5.95080673103181, 4.92377673189439, 3.9351839572675926, 2.9438587096277065, 3.9071150301022923, 4.840628260706867, 13.613075003615585, 14.581003593363388, 15.427541998490435, 16.43919431285569, 16.81301498160925, 15.7534153384813, 14.691862818223216, 13.68232281701332, 12.61114997442494, 11.682998791945911, 10.681956580321279, 9.697129909948293, 8.717021076621007, 7.7523372620351685, 6.76021883739257, 5.814839758622794, 4.885446160300466, 3.9558098498191603, 4.944855084146168, 5.854187421642849, 14.59034969979319, 15.59178268222895, 15.069184338447721, 15.984612630729078, 16.919296382590982, 16.407096021908366, 15.46414284463358, 14.525247537445882, 13.588206264196947, 12.652439680788977, 11.648214456034959, 10.665292699806415, 9.67768388252613, 8.778352552184208, 7.76744616124083, 6.748021339768268, 5.826111077401139, 4.940962724368325, 5.889987819658291, 6.84309960727097, 15.526390783886256, 14.821427948852962, 14.026218572558594, 14.923433150806042, 15.901777560360706, 16.784118994892996, 16.523372526980296, 15.489329121112885, 14.515785238800191, 13.550395523110707, 12.59453252678651, 11.641870794446607, 10.606386853820272, 9.66463159886417, 8.71101198864397, 7.722012969718967, 6.862429399009818, 5.9773288531683235, 6.861825854405907, 7.79478525480782], [7.885388709086784, 7.057198415358888, 7.944302491970412, 8.847004957350288, 9.693875763955564, 10.60031320746021, 11.567674722027814, 12.477951390568283, 13.497180880816884, 14.435895633468597, 15.364635107992545, 16.32206717075165, 17.36681906854266, 17.54912186140389, 16.759680428423852, 15.841130073817613, 14.789716619130527, 13.826988135677096, 12.94908067742332, 13.698879579735003, 6.8829253819395015, 7.714233067979575, 8.686873647471913, 9.627219457733988, 10.609601669475875, 11.54051253371414, 12.477995313922511, 13.506383965084996, 14.436944830163451, 15.362732710057497, 16.362880469327198, 17.256950639178203, 17.445026868221298, 16.61508665418269, 15.751424268392526, 14.91737393348594, 13.877437465314703, 12.846535711971187, 11.921460971177657, 12.680230239003496, 5.925468243105296, 6.781201474508305, 7.723824341351079, 8.724215751329064, 9.721607691259749, 10.651598791123224, 11.515703306299462, 12.559814450619616, 13.518632687179506, 14.559320239377248, 15.59896919958888, 16.611587759749007, 16.40719762313681, 15.576659206301596, 14.776994650604651, 13.965983370152601, 12.96616272021632, 11.902477935284866, 10.9629654781027, 11.720962453596416, 4.913149134464735, 5.823447123614118, 6.786612977417866, 7.839014981859456, 8.729582719769597, 9.673956188090976, 10.575768261105313, 11.60540183312963, 12.589209803812524, 13.575338105149454, 14.532719176530833, 15.560359969646205, 15.421631440218045, 14.634323168540998, 13.741953778830498, 13.016294508340668, 11.967162263013126, 10.95508274176599, 10.034481395026397, 10.750218672376459, 3.867857533376573, 4.83100110896571, 5.8088401880515175, 6.8132541943930445, 7.74394932809239, 8.67113189041867, 9.600809779992188, 10.6396490648114, 11.59350469294036, 12.566974235466109, 13.63167564608028, 14.634958839568935, 14.478032232883452, 13.649749086822172, 12.692579581839496, 11.966307443252449, 10.971677898346467, 10.023339176630813, 8.992107020043296, 9.798945252833889, 2.8057478017282462, 3.823822832647923, 4.861254696452832, 5.8637724173912655, 6.848828017891217, 7.886219946307836, 8.854026676417481, 9.88641722277879, 10.94758340806035, 11.944759746396311, 12.94863474983623, 13.892829828768049, 13.512988440830428, 12.64853553443594, 11.672175423126456, 10.916482967891689, 9.930275445502193, 8.987324737784581, 7.990977396490532, 8.74138851620096, 1.9902026749450483, 2.9301595345538525, 3.9013535492725473, 4.919895178347764, 5.882888542103107, 6.931574325834666, 7.913487645427409, 8.964768783981846, 9.934375105782026, 10.95858627790955, 12.030250092905435, 12.99664697498637, 12.568026326846628, 11.624903584428113, 10.693595064243658, 9.845970794246883, 8.855697273489348, 7.954359269976781, 6.94968977205656, 7.7716752264749145, 2.920831306925409, 3.9272397129510606, 4.89057242125469, 5.928855131469969, 6.916114705138692, 7.8558509665494896, 8.895323417678233, 9.921581736848738, 10.879865805284808, 11.940089545750402, 12.949839709552222, 12.580917686287403, 11.582762962002557, 10.644558327227443, 9.720026398275822, 8.775888418325836, 7.88898399018588, 6.9553196874549466, 6.000073862409325, 6.7830223076899, 3.853249919317806, 4.88132626070524, 5.858635218133147, 6.825486145359115, 7.781144281618669, 8.763397889710394, 9.82849759669748, 10.764021501532909, 11.744290169100594, 12.767638597797852, 12.625309996262843, 11.58634899302529, 10.606775847383368, 9.680275068860933, 8.725534413851353, 7.79808452779777, 6.864070716383518, 5.982659474017513, 4.93746903155555, 5.81498157989119, 4.90585982024178, 5.939905576076587, 6.806097709924032, 7.800173903647516, 8.726115832502511, 9.70738684108088, 10.643675964890448, 11.674777413696534, 12.664003855127891, 12.804641154688591, 11.738931609965618, 10.79294142055005, 9.806718084753697, 8.736720371552291, 7.827132816905716, 6.899505847396509, 5.889580734341346, 5.052579453872178, 3.984914498015015, 4.820971640404274, 5.775256638731422, 6.722004232717775, 7.743106795865862, 8.773183922326783, 9.769293531619574, 10.697658997949393, 11.676445732248236, 12.635730246007494, 12.902658820281056, 11.858177656907, 10.878234867341346, 9.827780932783797, 8.850168612892976, 7.801931962543353, 6.809560031033271, 5.859816281864492, 4.8690391617465725, 4.007224263931148, 3.059544064203501, 3.8751269751407995, 6.706754249009217, 7.731856786287469, 8.725584811860202, 9.744689426613004, 10.771431521704494, 11.751544902981806, 12.67843402466127, 12.889546743668863, 11.836624124390378, 10.886983786298353, 9.867090591697965, 8.873562137277048, 7.842169927107191, 6.83417716889952, 5.871630587864575, 4.917005821229224, 3.91549612694432, 2.9506833526062892, 2.020797786224678, 2.9043190710075977, 7.7140065869411885, 8.768055219772375, 9.694070451294385, 10.628182215716762, 11.683824054647387, 12.647166732707076, 12.889574614452933, 11.894775460669118, 10.879361610904992, 9.86358345657261, 8.93078157891237, 7.891081876681256, 6.927122608882313, 5.972913177555654, 4.9269120645044, 3.9646643894442097, 2.9138227805981836, 1.9377156504750763, 1.0032973956419815, 1.9789610885964057, 8.766379268182076, 9.737943285097202, 10.679229085995079, 11.560780824488752, 12.56562465764404, 13.193090415667184, 12.124128102593954, 11.055807134444287, 10.106572030429112, 9.165800023490867, 8.115398182200343, 7.187553232782704, 6.169493385179194, 5.11616569824402, 4.161978530901546, 3.1100568942395173, 2.117037850411471, 1.0529576018747482, 0.0, 1.0244770394482163, 9.745935650268523, 10.725556023897532, 11.709502739872018, 12.63227445971305, 13.535359642635143, 13.897030091754528, 12.93965151567585, 11.909441517414843, 10.944688505602224, 9.903927293840146, 8.832024568392258, 7.785582120655221, 6.8266366478619895, 5.869591373523413, 4.9337941859393375, 3.9760965253327, 2.9364786422849782, 1.8760942078136886, 0.9266461855238841, 1.8594428903470637, 10.726202044145639, 11.6722954444844, 12.734309484696798, 13.590938408213125, 14.55196876722756, 14.785995500914417, 13.805222499612304, 12.856213097860765, 11.788251198348455, 10.778985165689305, 9.727821225415523, 8.765957253514284, 7.876912357267932, 6.914519588379495, 5.900267166342685, 4.909144757328315, 3.9291748877983923, 2.890717705984521, 1.8890783181468098, 2.8475614291682874, 11.667002586448543, 12.63143456136076, 13.59939068071648, 14.554733598327235, 15.548722215962101, 15.784612360430787, 14.781363476378193, 13.752902740177445, 12.716578696694821, 11.73940864773581, 10.67436480712897, 9.733472806070916, 8.887537101462746, 7.9050990294725905, 6.895029288968072, 5.867999289830651, 4.879406515203854, 3.888081267563968, 2.952441543458945, 3.88595477406352, 12.714725159246392, 13.682653748994198, 14.529192154121244, 15.540844468486501, 16.498979871264147, 16.69763789641756, 15.636085376159476, 14.62654537494958, 13.5553725323612, 12.627221349882172, 11.62617913825754, 10.641352467884555, 9.66124363455727, 8.69655981997143, 7.70444139532883, 6.759062316559055, 5.829668718236728, 4.900032407755422, 4.002519334191569, 4.899513934999502, 13.691999855423997, 14.69343283785976, 15.480456332350775, 16.487276122450943, 17.49950096063939, 17.351318579844627, 16.408365402569842, 15.469470095382142, 14.532428822133207, 13.596662238725237, 12.592437013971221, 11.609515257742677, 10.621906440462393, 9.72257511012047, 8.71166871917709, 7.692243897704529, 6.7703336353374, 5.885185282304587, 5.018881967380715, 5.932660375053343, 14.628040939517064, 13.945260745418791, 14.818033521841825, 15.796744882557046, 16.781857430951334, 17.776788301125016, 17.467595084916557, 16.433551679049145, 15.460007796736452, 14.49461808104697, 13.538755084722773, 12.586093352382871, 11.550609411756536, 10.608854156800431, 9.65523454658023, 8.666235527655228, 7.806651956946079, 6.921551411104585, 5.990720002128331, 6.884346022590194], [7.125617121065918, 7.70464475365376, 8.69572713141993, 9.64074537740673, 10.580262759004565, 11.590560238967376, 12.46571223669729, 13.431713728369195, 14.450943218617798, 15.38965797126951, 16.318397445793458, 17.275829508552565, 18.348773984706117, 18.39685983297741, 17.464038464599852, 16.472356172147517, 15.42094271746043, 14.458214234007, 13.580306775753224, 12.674402540286788, 6.123153793918636, 6.760088944103846, 7.732729523596184, 8.67307533385826, 9.655457545600147, 10.650360912713447, 11.510935861810228, 12.539324512972714, 13.554162025387475, 14.558995821826795, 15.559143581096496, 16.551783043847163, 17.49997739179348, 17.47797237936577, 16.52732624473268, 15.548600031815845, 14.508663563644607, 13.477761810301091, 12.552687069507561, 11.655753199555281, 5.123596921818752, 5.827057350632576, 6.769680217475351, 7.770071627453334, 8.767463567384018, 9.684539339010943, 10.54864385418718, 11.592754998507333, 12.551573235067224, 13.592260787264966, 14.631909747476596, 15.644528307636723, 16.56358150993482, 16.453360593251062, 15.653696037554118, 14.660845718812082, 13.597388818546223, 12.53370403361477, 11.594191576432603, 10.696485414148201, 4.111277813178191, 4.869302999738389, 5.832468853542137, 6.884870857983727, 7.762523267657315, 8.706896735978695, 9.60870880899303, 10.638342381017347, 11.622150351700242, 12.608278653037171, 13.565659724418548, 14.59330051753392, 15.578015327016056, 15.511024555490465, 14.618655165779964, 13.748574977880175, 12.695889991730153, 11.68165698526066, 10.665707493356301, 9.725741632928244, 3.0659862120900288, 3.8768569850899812, 4.854696064175789, 5.846194742280763, 6.776889875980109, 7.704072438306388, 8.633750327879905, 9.672589612699117, 10.626445240828078, 11.599914783353826, 12.664616193967998, 13.667899387456652, 14.634416119681463, 14.52645047377164, 13.569280968788963, 12.767758253008738, 11.739740478703427, 10.749913420125484, 9.718681263537967, 8.774468213385674, 2.003876480441702, 2.8696787087721938, 3.8941952443405503, 4.896712965278984, 5.824350978443001, 6.861742906859621, 7.829549636969265, 8.861940183330574, 9.923106368612133, 10.920282706948097, 11.924157710388016, 12.868352789319834, 13.87972701151215, 13.525236921385407, 12.548876810075923, 11.717933777647978, 10.698338025859153, 9.713898981279252, 8.717551639985203, 7.7169114767527445, 0.9657256354968321, 1.9056824951056364, 2.8768765098243314, 3.8954181388995477, 4.858411502654891, 5.907097286386451, 6.889010605979193, 7.94029174453363, 8.90989806633381, 9.934109238461335, 11.00577305345722, 11.972169935538155, 12.993823048989558, 12.50160497137758, 11.570296451193125, 10.647421604003172, 9.623759853846307, 8.680933513471452, 7.67626401555123, 6.747198187026698, 1.8963542674771925, 2.9027626735028447, 3.8660953818064745, 4.904378092021753, 5.891637665690476, 6.831373927101274, 7.870846378230017, 8.897104697400522, 9.855388765836592, 10.915612506302185, 11.925362670104006, 12.901559426321626, 12.459464348952023, 11.52125971417691, 10.596727785225289, 9.652589805275301, 8.707622649907876, 7.723337059352601, 6.768091234306979, 5.758545268241684, 2.8287728798695895, 3.856849221257024, 4.83415817868493, 5.801009105910898, 6.756667242170453, 7.738920850262177, 8.804020557249263, 9.739544462084693, 10.719813129652378, 11.743161558349637, 12.761075375183761, 12.463050379974757, 11.483477234332835, 10.5569764558104, 9.60223580080082, 8.674785914747236, 7.740772103332985, 6.775175837260931, 5.729985394798968, 4.790504540442973, 3.881382780793564, 4.9154285366283705, 5.7816206704758155, 6.7756968641993, 7.701638793054296, 8.682909801632665, 9.619198925442234, 10.650300374248319, 11.639526815679677, 12.569364650900885, 12.68796459736127, 11.741974407945703, 10.755751072149348, 9.685753358947942, 8.763409573835307, 7.8357826043261, 6.825857491270938, 5.845095817115595, 4.777430861258432, 3.7964946009560574, 4.750779599283206, 5.697527193269559, 6.718629756417646, 7.748706882878567, 8.74481649217136, 9.673181958501178, 10.651968692800022, 11.61125320655928, 12.630251684380916, 12.807210644302652, 11.827267854736998, 10.77681392017945, 9.799201600288628, 8.750964949939004, 7.758593018428923, 6.8088492692601434, 5.818072149142224, 4.869730438489324, 3.852060427446918, 2.850649935692583, 5.682277209561001, 6.707379746839253, 7.701107772411985, 8.720212387164787, 9.746954482256278, 10.727067863533591, 11.653956985213055, 12.542624842034222, 12.785657111786032, 11.836016773694007, 10.816123579093617, 9.8225951246727, 8.791202914502843, 7.783210156295171, 6.820663575260227, 5.866038808624875, 4.864529114339971, 3.899716340001941, 2.8974078390471347, 1.8798420315593813, 6.689529547492972, 7.7435781803241595, 8.669593411846169, 9.603705176268546, 10.65934701519917, 11.62268969325886, 12.59282388072729, 12.843808448064772, 11.828394598300646, 10.812616443968263, 9.879814566308024, 8.84011486407691, 7.8761555962779655, 6.921946164951306, 5.875945051900052, 4.9136973768398615, 3.8628557679938353, 2.886748637870728, 1.9523303830376335, 0.9544840491481893, 7.74190222873386, 8.713466245648986, 9.654752046546863, 10.536303785040536, 11.541147618195824, 12.562610877067545, 13.14860514204217, 12.080284173892503, 11.131049069877328, 10.190277062939083, 9.139875221648559, 8.212030272230919, 7.193970424627411, 6.140642737692236, 5.186455570349763, 4.134533933687734, 3.141514889859687, 2.0774346413229647, 1.0244770394482163, 0.0, 8.721458610820306, 9.701078984449317, 10.685025700423804, 11.607797420264834, 12.510882603186927, 13.502060719881946, 13.964128555124066, 12.933918556863059, 11.96916554505044, 10.928404333288363, 9.856501607840475, 8.810059160103437, 7.851113687310206, 6.894068412971629, 5.958271225387554, 5.000573564780916, 3.9609556817331946, 2.900571247261905, 1.9511232249721004, 1.0575715690605194, 9.701725004697423, 10.647818405036183, 11.709832445248582, 12.566461368764909, 13.527491727779344, 14.497337595929789, 14.829699539060522, 13.880690137308983, 12.812728237796673, 11.80346220513752, 10.75229826486374, 9.7904342929625, 8.901389396716148, 7.938996627827711, 6.924744205790901, 5.9336217967765315, 4.953651927246609, 3.9151947454327374, 2.913555357595026, 2.0877898411474223, 10.642525547000327, 11.606957521912543, 12.574913641268264, 13.53025655887902, 14.524245176513887, 15.551028577237659, 15.80584051582641, 14.777379779625663, 13.74105573614304, 12.763885687184029, 11.698841846577187, 10.757949845519132, 9.912014140910962, 8.929576068920808, 7.919506328416288, 6.8924763292788676, 5.9038835546520705, 4.912558307012184, 3.976918582907161, 3.1261831860426548, 11.690248119798177, 12.65817670954598, 13.504715114673028, 14.516367429038285, 15.474502831815933, 16.534102474943882, 16.660562415607693, 15.651022414397797, 14.579849571809417, 13.651698389330388, 12.650656177705756, 11.665829507332772, 10.685720674005486, 9.721036859419646, 8.728918434777047, 7.783539356007271, 6.854145757684944, 5.924509447203638, 5.026996373639785, 4.139742346978636, 12.667522815975783, 13.668955798411542, 14.455979292902558, 15.462799083002725, 16.475023921191177, 17.477873738355225, 17.43284244201806, 16.49394713483036, 15.556905861581424, 14.621139278173453, 13.616914053419437, 12.633992297190893, 11.64638347991061, 10.747052149568686, 9.736145758625307, 8.716720937152745, 7.794810674785617, 6.909662321752803, 6.043359006828931, 5.172888787032478, 13.603563900068849, 14.576486843748695, 15.449259620171729, 16.42797098088695, 17.413083529281238, 18.41542947112106, 18.492072124364775, 17.458028718497363, 16.484484836184667, 15.519095120495185, 14.56323212417099, 13.610570391831086, 12.57508645120475, 11.633331196248648, 10.679711586028446, 9.690712567103445, 8.831128996394296, 7.946028450552801, 7.015197041576547, 6.124574434569328], [14.129183747300681, 14.695373290959383, 15.686455668725554, 16.631473914712352, 17.570991296310186, 18.508098036827995, 18.26529490487229, 17.299293413200385, 16.280063922951783, 15.34134917030007, 14.412609695776123, 13.532114433386955, 12.535612585157917, 11.572437497520518, 10.639616129142961, 9.647933836690628, 8.596520382003542, 7.633791898550111, 6.755884440296332, 5.8455886911103265, 13.126720420153399, 13.750817481409468, 14.723458060901807, 15.663803871163882, 16.644338090671948, 17.567898710574067, 17.660678980942624, 16.619257922184076, 15.604420409769316, 14.599586613329997, 13.599438854060296, 12.606799391309629, 11.658605043363313, 10.653550043908883, 9.702903909275792, 8.724177696358955, 7.684241228187718, 6.653339474844201, 5.728264734050669, 4.831330864098389, 12.120366757658243, 12.817785887938198, 13.760408754780974, 14.760800164758958, 15.698684865109747, 16.602077136871564, 16.74343681932117, 15.724104088731826, 14.765285852171935, 13.848879907352897, 12.852126933524303, 11.814938111420656, 10.7831689313302, 9.813901289951843, 8.884249360669846, 7.836423383355191, 6.772966483089332, 5.709281698157879, 4.769769240975712, 3.872063078691309, 11.108047649017681, 11.860031537044012, 12.82319739084776, 13.831073701641175, 14.680061065517938, 15.624434533839318, 15.80350177412702, 14.773868202102703, 13.790060231419808, 12.803931930082879, 11.8465508587015, 10.818910065586127, 9.847304757121696, 8.871565252191246, 7.8990618240289106, 6.928400818168597, 5.8757158320185745, 4.861482825549082, 3.841285157899409, 2.9013192974713524, 10.06275604792952, 10.867585522395604, 11.845424601481412, 12.792390995003153, 13.694427673840732, 14.621610236167012, 14.917512165314559, 13.878672880495348, 12.924817252366386, 11.951347709840638, 10.886646299226467, 9.883363105737812, 8.916846373513001, 7.976112511930536, 6.981519245576985, 6.017682386300759, 4.985888509114206, 3.938020653424231, 2.895486126458821, 1.9500458779287815, 9.000646316281193, 9.860407246077816, 10.880215507729694, 11.842909218001374, 12.716880242266887, 13.666434449174817, 14.166767404328505, 13.134376857967196, 12.073210672685637, 11.003755487603573, 9.999880484163654, 9.055685405231836, 8.04431118303952, 7.059713646801031, 6.083353535491547, 5.140195489216659, 4.081347687395559, 3.0164734480840405, 2.0201261067899914, 1.0058807298167052, 7.956454172802454, 8.896411032411258, 9.862896773213476, 10.83462161080255, 11.750940766478777, 12.699188124183218, 13.68110144377596, 13.937651633129603, 12.968045311329423, 11.943834139201897, 10.872170324206012, 9.905773442125078, 8.884120328673674, 7.859828782131364, 6.92852026194691, 5.875817436519226, 4.8521556863623605, 3.909329345987504, 2.9046598480672836, 1.9755940195427515, 7.025825540822094, 7.933963351222746, 8.8374446784202, 9.825661657680344, 10.717714603443193, 11.657450864853992, 12.696923315982735, 13.689396479556514, 13.806884179502196, 12.746660439036603, 11.736910275234782, 10.760713519017163, 9.762558794732316, 8.824354159957203, 7.76101027633146, 6.7412270926342845, 5.793807173315416, 4.809521582760141, 3.854275757714519, 2.962913342578623, 6.0934069284296974, 6.979876803468567, 7.869381881541743, 8.836232808767711, 9.791890945027266, 10.77414455311899, 11.780511106456789, 12.716035011292218, 13.696303678859904, 13.564170268461547, 12.546256451627423, 11.50729544838987, 10.527722302747948, 9.601221524225513, 8.646480869215933, 7.71903098316235, 6.818720447117778, 5.8763623961324924, 4.916880588568294, 3.930954070377333, 5.039664992595367, 5.9212974880972205, 6.921919389750858, 7.915995583474342, 8.858864914146602, 9.84013592272497, 10.77642504653454, 11.807526495340625, 12.796752936771982, 13.726590771993191, 13.456956732162649, 12.51096654274708, 11.5706669948246, 10.593991233489866, 9.64501302293133, 8.717386053422123, 7.790421971830561, 6.809660297675219, 5.869435122108829, 4.924964009864249, 4.029741724238697, 4.97648931822505, 5.997591881373137, 6.972766500512534, 7.966071201929694, 8.894436668259512, 9.930177388031526, 10.853438084007415, 11.872436561829051, 12.917160690735853, 13.897103480301507, 13.476127030513334, 12.592515754956663, 11.528779642498804, 10.681704191970008, 9.786988285407974, 8.810963544425334, 7.812475566962748, 6.794805555920343, 5.870808675127723, 3.098244113960902, 4.037570182251842, 4.977751182301976, 5.91631361327042, 6.943055708361911, 7.912589716963608, 8.928189095618492, 9.922066448532473, 10.89997152878224, 11.965524778066296, 12.907981331677735, 13.901509786098652, 13.507445860332856, 12.499453102125184, 11.720641040147841, 10.76601627351249, 9.764506579227586, 8.852848730017008, 7.833551833899166, 6.841616579260925, 2.031929063327335, 3.0013717487669354, 4.009265542867793, 4.943377307290171, 5.999019146220795, 6.962361824280484, 7.932496011748914, 8.927295165532728, 9.942709015296854, 10.958487169629237, 11.891289047289476, 12.93098874952059, 13.894948017319534, 13.487938089107542, 12.68395811260944, 11.72171043754925, 10.675346280517763, 9.699239150394655, 8.764820895561561, 7.766974561672117, 0.9795563820864469, 1.9511203990015733, 3.0241069081670986, 4.097563024177702, 5.0956356309206114, 6.103582790172701, 7.064493669050029, 8.132814637199697, 9.082049741214872, 10.022821748153117, 11.073223589443641, 12.001068538861281, 13.01912838646479, 14.072456073399964, 13.639538385638142, 12.615123697337896, 11.62210465350985, 10.644285494637712, 9.745935650268523, 8.721458610820306, 0.0, 1.044904900048496, 2.0855416726041875, 3.1589889170675622, 4.12590064592951, 5.1641329473583, 6.121511523436978, 7.1517215216979855, 8.116474533510603, 9.157235745272681, 10.229138470720569, 11.275580918457607, 12.234526391250839, 13.191571665589416, 14.127368853173492, 13.592943847549888, 12.553325964502166, 11.57615714451514, 10.672581835792407, 9.779030179880825, 0.9802663938771169, 1.9263597942158777, 2.988373834428276, 3.959614666692305, 4.987108264343895, 5.956954132494341, 6.937727133796455, 7.8867365355479935, 8.954698435060303, 9.963964467719453, 11.015128407993235, 11.976992379894474, 13.01135494132809, 13.995945102748818, 15.05919130423356, 14.525992079545503, 13.567613943915811, 12.590780642685973, 11.635013968415333, 10.80924845196773, 1.9210669361800212, 2.8854989110922373, 3.853455030447958, 4.808797948058713, 5.802786565693579, 6.868622933867644, 7.871871817920238, 8.883672654394031, 9.919996697876655, 10.897166746835666, 11.961671989706682, 12.944507932451106, 13.918852663893405, 14.958496245112013, 15.968565985616532, 15.48484661204784, 14.579469451905306, 13.588144204265419, 12.698377193727467, 11.847641796862963, 2.993638945194137, 3.9367180987256756, 4.783256503852722, 5.794908818217978, 6.753044220995626, 7.812643864123577, 8.803847954025294, 9.81338795523519, 10.88456079782357, 11.812711980302598, 12.81375419192723, 13.823624859584507, 14.803733692911793, 15.768417507497633, 16.760535932140233, 16.459125253260506, 15.529731654938178, 14.600095344456873, 13.748454984460091, 12.861200957798944, 3.9709136413717423, 4.947497187591237, 5.734520682082253, 6.7413404721824195, 7.75356531037087, 8.756415127534916, 9.6993683048097, 10.638263611997399, 11.575304885246334, 12.511071468654304, 13.584089393682595, 14.567011149911139, 15.554619967191423, 16.540356834571742, 17.59864730638546, 17.39230683440598, 16.47039657203885, 15.585248219006038, 14.764817617649237, 13.894347397852785, 4.906954725464809, 5.89488769552857, 6.777486447971381, 7.793615957860892, 8.771084132601146, 9.693970860300752, 10.752495305696874, 11.602345195664402, 12.502883859849579, 13.467882587197142, 14.423745583521338, 15.473087131324988, 16.483322938485564, 17.539228913476244, 18.492848523696445, 18.366298464356678, 17.50671489364753, 16.621614347806037, 15.736655652396854, 14.846033045389635], [14.825395506347151, 13.837431545563323, 14.828513923329494, 15.773532169316294, 16.680918061573788, 17.615523794223243, 17.45667703491178, 16.490675543239874, 15.471446052991272, 14.53273130033956, 13.603991825815612, 12.723496563426444, 11.726994715197407, 10.827697280604248, 9.894875912226691, 8.903193619774358, 7.922642447629027, 6.9599139641755965, 6.1281588270410925, 6.883725181913071, 13.822932179199869, 12.892875736013409, 13.865516315505747, 14.805862125767822, 15.75176384806719, 16.675324467969315, 17.535899417066098, 17.4260475147526, 16.41121000233784, 15.459568376928459, 14.63757534486304, 13.644935882112373, 12.696741534166057, 11.691686534711627, 10.741040400078536, 9.7623141871617, 8.722377718990462, 7.691475965646945, 6.766401224853413, 5.869467354901134, 12.96043877373749, 11.959844142542138, 12.895675529564839, 13.896066939542823, 14.806110622504992, 15.70950289426681, 16.57360740944305, 16.762240579534566, 15.803422342974677, 14.88701639815564, 13.890263424327047, 12.8530746022234, 11.821305422132944, 10.852037780754587, 9.92238585147259, 8.874559874157935, 7.811102973892076, 6.747418188960623, 5.807905731778456, 4.910199569494053, 12.04784567274305, 11.002089791647952, 11.958464165631625, 12.93849945903642, 13.787486822913182, 14.731860291234563, 15.6336723642489, 15.812004692905445, 14.82819672222255, 13.84206842088562, 12.884687349504244, 11.857046556388871, 10.88544124792444, 9.90970174299399, 8.937198314831654, 7.966537308971341, 6.9138523228213185, 5.899619316351826, 4.879421648702153, 3.9394557882740964, 11.04237642155853, 10.009643776999544, 10.980691376265277, 11.899816752398397, 12.801853431235976, 13.729035993562256, 14.658713883135775, 14.916809371298092, 13.96295374316913, 12.989484200643382, 11.92478279002921, 10.921499596540556, 9.954982864315745, 9.01424900273328, 8.019655736379729, 7.055818877103503, 6.02402499991695, 4.976157144226975, 3.933622617261565, 2.9881823687315254, 9.980266689910202, 9.002465500681756, 9.987641265124939, 10.950334975396618, 11.824305999662132, 12.773860206570061, 13.741666936679707, 14.179281758015692, 13.118115572734133, 12.04866038765207, 11.044785384212151, 10.100590305280333, 9.089216083088017, 8.104618546849528, 7.128258435540044, 6.1851003892651555, 5.126252587444055, 4.0613783481325365, 3.0650310068384874, 2.050785629865201, 8.936074546431463, 8.038469287015198, 8.97032253060872, 9.942047368197795, 10.858366523874022, 11.806613881578462, 12.788527201171204, 13.75363518981865, 13.957859345079601, 12.933648172952076, 11.86198435795619, 10.895587475875256, 9.873934362423853, 8.849642815881543, 7.918334295697089, 6.865631470269404, 5.841969720112539, 4.8991433797376835, 3.8944738818174627, 2.9654080532929306, 8.005445914451103, 7.041389108617991, 7.944870435815444, 8.933087415075589, 9.825140360838438, 10.764876622249236, 11.80434907337798, 12.796822236951758, 13.755106305387828, 13.736474472786782, 12.726724308984961, 11.750527552767341, 10.752372828482494, 9.814168193707381, 8.750824310081638, 7.731041126384463, 6.783621207065595, 5.799335616510319, 4.844089791464698, 3.9425337162076333, 7.073027302058707, 6.087302560863812, 6.976807638936988, 7.943658566162956, 8.89931670242251, 9.881570310514235, 10.887936863852033, 11.823460768687463, 12.803729436255148, 13.827077864952408, 13.536070485377602, 12.497109482140049, 11.517536336498127, 10.591035557975692, 9.636294902966112, 8.708845016912528, 7.808534480867957, 6.866176429882671, 5.906694622318472, 4.910574444006343, 6.019285366224376, 5.028723245492464, 6.029345147146103, 7.023421340869587, 7.966290671541847, 8.947561680120215, 9.883850803929784, 10.914952252735869, 11.904178694167227, 12.834016529388435, 13.899726074111408, 13.50078057649726, 12.56048102857478, 11.583805267240045, 10.634827056681509, 9.707200087172302, 8.78023600558074, 7.799474331425397, 6.859249155859008, 5.904584383493259, 5.009362097867706, 4.083915075620293, 5.070377431012354, 6.009258840311291, 7.002563541728451, 7.93092900805827, 8.966669727830283, 9.885799049682213, 10.904797527503849, 11.949521656410651, 12.929464445976304, 13.878148338779832, 13.582329788706842, 12.518593676248983, 11.671518225720186, 10.776802319158152, 9.800777578175513, 8.802289600712927, 7.7846195896705215, 6.850429048756733, 4.0778644875899115, 3.074062522050599, 4.014243522100733, 4.952805953069177, 5.979548048160668, 6.949082056762365, 7.964681435417249, 8.95442741420727, 9.932332494457038, 10.997885743741094, 11.930401088852166, 12.923929543273083, 13.796774699762073, 13.489267135875362, 12.71045507389802, 11.755830307262668, 10.754320612977764, 9.842662763767185, 8.823365867649343, 7.821236952889935, 3.011549436956345, 2.0378640885656925, 3.0457578826665497, 3.979869647088928, 5.035511486019552, 5.998854164079241, 6.964856977423712, 7.959656131207526, 8.975069980971652, 9.980906926803668, 10.913708804463907, 11.907597308620577, 12.87155657641952, 13.82576600774618, 13.66805593805299, 12.7058082629928, 11.654966654146774, 10.678859524023666, 9.744441269190572, 8.746594935301127, 1.9591767557154571, 0.9876127388003306, 2.0605992479658557, 3.134055363976459, 4.050730730872115, 5.058677890124205, 6.019588769001533, 7.0879097371512, 8.037144841166375, 8.97791684810462, 10.028318689395144, 10.956163638812784, 11.974223486416292, 13.027551173351467, 13.98173834069394, 13.594744070966907, 12.60172502713886, 11.623905868266723, 10.725556023897532, 9.701078984449316, 1.044904900048496, 0.0, 1.0406367725556915, 2.1140840170190662, 3.0809957458810135, 4.119228047309804, 5.076606623388482, 6.1068166216494895, 7.071569633462108, 8.112330845224186, 9.184233570672074, 10.230676018409111, 11.189621491202344, 12.146666765540921, 13.082463953124996, 14.040161613731634, 13.532946338131177, 12.55577751814415, 11.652202209421416, 10.758650553509835, 2.018402884679861, 1.0723094843410999, 2.1115301980872516, 3.0727479655191416, 4.097604870473432, 5.067450738623878, 6.048223739925991, 6.99723314167753, 8.047279665813138, 9.056545698472288, 10.10770963874607, 11.069573610647309, 12.103936172080925, 13.088526333501653, 14.048936933528344, 14.973209845727249, 14.547234317544822, 13.570401016314984, 12.614634342044342, 11.788868825596737, 2.959203426982765, 2.122589974609289, 3.0448371604874462, 4.000180078098201, 4.994168695733068, 6.060005063907132, 7.0627085659137, 7.9941692605235675, 9.03049330400619, 10.007663352965201, 11.054253220459517, 12.037089163203941, 13.01143389464624, 14.051077475864847, 15.061147216369367, 15.932064378229585, 15.559089825534317, 14.56776457789443, 13.677997567356478, 12.82726217049197, 4.031775435996881, 3.173809162242727, 3.9746386338922104, 4.9862909482574675, 5.944426351035116, 7.004025994163066, 7.994684702018755, 8.98391925209232, 10.0550920946807, 10.98324327715973, 11.984285488784362, 12.994156156441639, 13.974264989768924, 14.938948804354764, 15.931067228997364, 16.87644630776714, 16.50935202856719, 15.579715718085884, 14.728075358089102, 13.840821331427952, 5.009050132174487, 4.184588251108288, 4.925902812121741, 5.932722602221908, 6.94494744041036, 7.947797257574406, 8.89075043484919, 9.829645742036888, 10.766687015285823, 11.702453598693793, 12.775471523722084, 13.758393279950628, 14.746002097230912, 15.731738964611234, 16.790029436424952, 17.809454257897514, 17.450016945667862, 16.56486859263505, 15.726308973698707, 14.773197186086028, 5.945091216267554, 5.13197875904562, 5.968868578010868, 6.9849980879003795, 7.9624662626406355, 8.885352990340241, 9.943877435736363, 10.793727325703891, 11.694265989889068, 12.659264717236631, 13.615127713560828, 14.664469261364477, 15.674705068525054, 16.730611043515733, 17.684230653735934, 17.708558297874124, 16.813885169720503, 15.851265004195321, 14.90390995879388, 15.724882833622878], [15.728978937881102, 14.741014977097274, 14.031191632919692, 14.902901666070257, 15.687776959205324, 16.622382691854778, 16.41604026235609, 15.450038770684184, 14.430809280435582, 13.49209452778387, 12.563355053259922, 11.682859790870753, 10.686357942641715, 9.787060508048555, 8.854239139670998, 7.8625568472186655, 6.882005675073335, 5.919277191619905, 6.765989928743096, 7.720085562036535, 14.72651561073382, 13.79645916754736, 12.994885812259712, 13.935231622521787, 14.758622745698725, 15.68218336560085, 16.542758314697632, 16.38541074219691, 15.37057322978215, 14.41893160437277, 13.610382722047971, 12.617743259297304, 11.678680506539896, 10.721095715269755, 9.806039683534115, 8.827313470617279, 7.842053450795726, 6.899729615325815, 7.7642509602738645, 6.867317090321585, 13.864022205271441, 12.86342757407609, 11.943218882210827, 12.943610292188811, 13.812969520136527, 14.716361791898345, 15.580466307074584, 16.62457745139474, 16.39275061533785, 15.467603391231794, 14.601311973431766, 13.564123151328118, 12.691037287412716, 11.721769646034359, 10.78046930132199, 9.857740241186042, 8.808952709312528, 7.745267924381074, 6.805755467198908, 5.908049304914504, 12.951429104277, 11.905673223181903, 11.006007518277613, 11.986042811682406, 12.794345720544717, 13.738719188866098, 14.640531261880435, 15.670164833904751, 15.868833494778244, 14.882705193441314, 13.925324122059935, 12.897683328944563, 11.883290983344889, 10.907551478414439, 9.935048050252103, 8.96438704439179, 7.911702058241769, 6.897469051772276, 5.877271384122604, 4.937305523694548, 11.962425935868765, 10.913227208533495, 10.028234728911265, 10.947360105044384, 11.80871232886751, 12.73589489119379, 13.66557278076731, 14.70441206558652, 15.003590515724822, 14.030120973199073, 12.965419562584902, 11.962136369096248, 10.995619636871437, 10.054885775288971, 9.06029250893542, 8.096455649659195, 7.0646617724726415, 6.0167939167826665, 4.974259389817257, 4.028819141287217, 10.905150693183094, 9.906048932215707, 9.035184617770927, 9.997878328042605, 10.831164897293666, 11.780719104201596, 12.748525834311241, 13.757673399028453, 14.158752345289825, 13.089297160207762, 12.085422156767843, 11.141227077836025, 10.129852855643708, 9.14525531940522, 8.168895208095735, 7.225737161820847, 6.166889359999747, 5.102015120688228, 4.105667779394179, 3.0914224024208927, 9.860958549704355, 8.94205271854915, 8.017865883254709, 8.98959072084378, 9.865225421505556, 10.813472779209997, 11.795386098802739, 12.748548567447004, 13.702963493773808, 13.974284945507769, 12.902621130511884, 11.93622424843095, 10.914571134979546, 9.890279588437236, 8.958971068252781, 7.906268242825096, 6.882606492668231, 5.939780152293375, 4.935110654373155, 4.0060448258486225, 8.930329917723995, 7.944972540151942, 6.992413788461432, 7.980630767721576, 8.831999258469972, 9.771735519880771, 10.811207971009514, 11.791735614580112, 12.750019683016182, 13.806490534561073, 13.767361081540653, 12.791164325323033, 11.793009601038186, 10.854804966263073, 9.79146108263733, 8.771677898940155, 7.824257979621287, 6.839972389066012, 5.88472656402039, 4.983170488763325, 7.997911305331598, 6.990885992397763, 6.024350991582976, 6.991201918808944, 7.906175600054045, 8.88842920814577, 9.882850241480387, 10.818374146315817, 11.798642813883502, 12.815095455537698, 13.833009272371822, 13.53774625469574, 12.558173109053818, 11.631672330531384, 10.676931675521804, 9.74948178946822, 8.84917125342365, 7.9068132024383635, 6.947331394874165, 5.951211216562036, 6.944169369497268, 5.932306677026416, 5.076888499792091, 6.018334718497941, 6.961204049170202, 7.942475057748569, 8.878764181558138, 9.901343393997843, 10.8905698354292, 11.82040767065041, 12.876762200136715, 13.802672053990394, 13.60111780113047, 12.624442039795737, 11.6754638292372, 10.747836859727993, 9.820872778136433, 8.84011110398109, 7.8998859284147, 6.888531099467746, 5.934246101140598, 4.987498507154245, 4.04005183692344, 4.978933246222375, 5.972237947639535, 6.900603413969354, 7.9363441337413665, 8.845162277126523, 9.86416075494816, 10.908884883854961, 11.888827673420614, 12.83751156622414, 13.764136612992166, 13.559230448804675, 12.712154998275878, 11.817439091713844, 10.841414350731206, 9.84292637326862, 8.825256362226215, 7.83437576473122, 5.045946104450412, 3.9776459535845508, 2.983917928011818, 3.9224803589802617, 4.949222454071752, 5.91875646267345, 6.934355841328333, 7.913790641651579, 8.891695721901346, 9.957248971185402, 10.889764316296475, 11.883292770717391, 12.756137927206382, 13.764130685414054, 13.751091846453713, 12.796467079818362, 11.794957385533458, 10.842046372470017, 9.822749476352175, 8.805183668864423, 4.052186209512037, 3.061177948605039, 2.0154322885776343, 2.9495440530000128, 4.005185891930637, 4.968528569990326, 5.92422020486802, 6.919019358651834, 7.93443320841596, 8.940270154247976, 9.873072031908215, 10.866960536064886, 11.830919803863829, 12.785129235190489, 13.831130348241743, 13.689754978967288, 12.638913370121262, 11.662806239998154, 10.72838798516506, 9.730541651275615, 2.9998135282711487, 2.028249511356022, 1.0302736538769404, 2.1037297698875435, 3.010093958316424, 4.018041117568513, 4.978951996445842, 6.047272964595509, 6.996508068610684, 7.9372800755489274, 8.987681916839453, 9.915526866257093, 10.9335867138606, 11.986914400795776, 12.941101568138249, 13.993023204800277, 13.585671743113348, 12.607852584241211, 11.70950273987202, 10.685025700423804, 2.0855416726041875, 1.0406367725556915, 0.0, 1.0734472444633747, 2.040358973325322, 3.078591274754112, 4.035969850832791, 5.066179849093798, 6.030932860906416, 7.071694072668494, 8.143596798116382, 9.19003924585342, 10.148984718646652, 11.10602999298523, 12.041827180569305, 12.999524841175942, 14.039142724223664, 13.539724234118639, 12.636148925395904, 11.742597269484323, 3.0590396572355525, 2.1129462568967914, 1.07089342553156, 2.03211119296345, 3.05696809791774, 4.026813966068186, 5.007586967370299, 5.956596369121838, 7.006642893257446, 8.015908925916598, 9.06707286619038, 10.028936838091619, 11.063299399525235, 12.047889560945963, 13.008300160972652, 13.932573073171557, 14.939678492128712, 14.554347732289472, 13.59858105801883, 12.772815541571227, 3.9365884821996913, 2.972156507287475, 2.0042003879317547, 2.959543305542509, 3.953531923177376, 5.019368291351441, 6.022071793358008, 6.953532487967876, 7.989856531450499, 8.96702658040951, 10.013616447903827, 10.996452390648251, 11.97079712209055, 13.010440703309158, 14.020510443813677, 14.891427605673893, 15.902925515322844, 15.55171129386892, 14.661944283330964, 13.81120888646646, 5.009160491213807, 3.9896596002809046, 2.934001861336519, 3.9456541757017756, 4.903789578479424, 5.9633892216073745, 6.954047929463063, 7.943282479536629, 9.01445532212501, 9.942606504604038, 10.94364871622867, 11.953519383885947, 12.933628217213233, 13.898312031799072, 14.890430456441672, 15.835809535211448, 16.765203133533774, 16.563662434060372, 15.712022074063588, 14.824768047402442, 5.84541051229795, 4.822419352810291, 3.885266039566049, 4.892085829666216, 5.904310667854668, 6.907160485018714, 7.850113662293499, 8.789008969481197, 9.726050242730132, 10.661816826138102, 11.734834751166392, 12.717756507394936, 13.70536532467522, 14.691102192055542, 15.749392663869259, 16.76881748534182, 16.979572988083145, 16.090308842585518, 16.629892405232656, 15.676780617619979, 6.781451596391017, 5.769809860747624, 4.928231805455177, 5.944361315344688, 6.921829490084944, 7.8447162177845495, 8.903240663180672, 9.7530905531482, 10.653629217333377, 11.618627944680942, 12.574490941005138, 13.623832488808787, 14.634068295969364, 15.689974270960041, 16.64359388118024, 16.715417195505662, 15.943254666474465, 15.053942713785519, 15.807493390327831, 16.628466265156828], [16.651750657722136, 15.663786696938308, 14.953963352760725, 14.113163116811752, 14.711769839290435, 15.646375571939888, 15.41922644797699, 14.453224956305085, 13.433995466056484, 12.495280713404771, 11.566541238880824, 10.686045976491656, 9.689544128262618, 8.790246693669456, 7.8574253252919, 6.865743032839567, 6.012040004548891, 6.778288546852449, 7.6250012839756405, 8.579096917269078, 15.649287330574854, 14.719230887388393, 13.917657532100746, 13.14549307326328, 13.782615625783835, 14.70617624568596, 15.566751194782743, 15.388596927817812, 14.37375941540305, 13.42211778999367, 12.613568907668874, 11.620929444918207, 10.6818666921608, 9.724281900890656, 8.809225869155016, 7.83049965623818, 6.972087780271282, 7.758740970558359, 8.623262315506409, 7.726328445554129, 14.786793925112475, 13.786199293917123, 12.86599060205186, 12.125038326294604, 12.836962400221637, 13.740354671983456, 14.604459187159694, 15.648570331479847, 15.39593680095875, 14.470789576852695, 13.60449815905267, 12.567309336949021, 11.694223473033617, 10.72495583165526, 9.783655486942891, 8.860926426806943, 7.943137327035108, 8.60427927961362, 7.664766822431452, 6.767060660147049, 13.874200824118034, 12.828444943022937, 11.928779238118647, 11.114466340918337, 11.818338600629827, 12.762712068951208, 13.664524141965545, 14.694157713989862, 15.675979833484465, 15.515737554122714, 14.646177920167196, 13.618537127051823, 12.643031374346307, 11.667291869415857, 10.78127629447919, 9.810615288618877, 8.770713413474313, 7.756480407004821, 6.736282739355149, 5.796316878927092, 12.8851976557098, 11.83599892837453, 10.951006448752299, 10.075783634280315, 10.832705208952621, 11.759887771278901, 12.68956566085242, 13.728404945671631, 14.647474040853643, 14.909093537278784, 13.844392126664612, 12.841108933175958, 11.874592200951147, 10.933858339368681, 9.93926507301513, 8.975428213738905, 7.943634336552352, 6.8957664808623775, 5.853231953896968, 4.907791705366928, 11.827922413024126, 10.828820652056741, 9.957956337611959, 9.126301857278536, 9.855157777378777, 10.804711984286707, 11.772518714396352, 12.721736929093863, 13.709305585871828, 14.162744404671136, 13.158869401231216, 12.214674322299398, 11.203300100107082, 10.218702563868593, 9.24234245255911, 8.29918440628422, 7.240336604463121, 6.175462365151603, 5.179115023857554, 4.164869646884267, 10.783730269545387, 9.864824438390183, 8.940637603095741, 8.118014250079712, 8.889218301590667, 9.837465659295107, 10.81937897888785, 11.712612097512414, 12.667027023839218, 13.691238195966744, 13.976068374975258, 13.009671492894324, 11.98801837944292, 10.96372683290061, 10.032418312716155, 8.97971548728847, 7.9560537371316045, 7.013227396756749, 6.0085578988365285, 5.079492070311996, 9.853101637565027, 8.867744259992975, 7.915185508302463, 7.109054296957506, 7.855992138555083, 8.795728399965881, 9.835200851094624, 10.755799144645522, 11.714083213081592, 12.733043290097697, 13.742793453899518, 13.864611569786407, 12.86645684550156, 11.928252210726447, 10.864908327100704, 9.845125143403529, 8.89770522408466, 7.913419633529386, 6.958173808483764, 5.980970014437979, 8.92068302517263, 7.913657712238795, 6.947122711424007, 6.119625448044874, 6.930168480139156, 7.91242208823088, 8.878629660510567, 9.782437676381228, 10.762706343948913, 11.741648211074322, 12.759562027908446, 13.73289590388423, 13.631620353517192, 12.705119574994757, 11.750378919985177, 10.822929033931594, 9.922618497887022, 8.980260446901736, 7.989717199300526, 6.949010742236689, 7.866941089338299, 6.855078396867447, 5.999660219633122, 5.072882909494215, 5.985196929255313, 6.938254476778749, 7.874543600588318, 8.827896149534467, 9.817122590965825, 10.746960426187034, 11.80331495567334, 12.72922480952702, 13.73656768833367, 13.69788928425911, 12.748911073700574, 11.821284104191367, 10.890363012459481, 9.909601338304139, 8.841936382446976, 7.811302819308778, 6.857017820981629, 5.9102702269952765, 4.962823556764471, 4.03348143721865, 4.942019230138249, 5.870384696468069, 6.869734596309015, 7.771715032663148, 8.790713510484784, 9.835437639391586, 10.815380428957239, 11.764064321760767, 12.690689368528792, 13.66135690057706, 13.781666946998694, 12.831923197829916, 11.841146077711995, 10.776227987368992, 9.758557976326587, 8.757147484572252, 5.968717824291443, 4.900417673425582, 3.9066896478528492, 2.977028549976536, 3.9190037365704664, 4.852146925241098, 5.867746303895982, 6.840343397188205, 7.818248477437972, 8.883801726722028, 9.816317071833101, 10.809845526254017, 11.682690682743008, 12.69068344095068, 13.653230021985625, 13.79619880679915, 12.794689112514247, 11.764818092311051, 10.74552119619321, 9.727955388705455, 5.049985735186691, 3.98394966844607, 2.9382040084186656, 2.0040922439962876, 2.9473769062179143, 3.9019190325579745, 4.850772960404646, 5.84557211418846, 6.8609859639525865, 7.866822909784602, 8.799624787444841, 9.793513291601512, 10.757472559400455, 11.711681990727115, 12.75768310377837, 13.71993077883856, 13.561685089962294, 12.585577959839187, 11.651159705006092, 10.653313371116647, 4.073260772734523, 3.101696755819397, 2.103720898340315, 1.0714936352242983, 1.9366467138530497, 2.9445938731051386, 3.905504751982467, 4.973825720132134, 5.92306082414731, 6.863832831085554, 7.914234672376079, 8.842079621793719, 9.860139469397227, 10.913467156332402, 11.867654323674875, 12.919575960336903, 13.896916790752606, 13.530624304082243, 12.632274459713052, 11.607797420264836, 3.1589889170675622, 2.1140840170190662, 1.0734472444633747, 0.0, 0.9669117288619475, 2.0051440302907375, 2.9625226063694163, 3.9927326046304237, 4.957485616443042, 5.998246828205119, 7.070149553653007, 8.116592001390044, 9.075537474183276, 10.032582748521854, 10.96837993610593, 11.926077596712567, 12.965695479760289, 14.026079914231579, 13.558920645236936, 12.665368989325355, 3.9380122213152635, 2.991918820976503, 1.9299047807641045, 0.9586639485000753, 1.9835208534543654, 2.9533667216048114, 3.9341397229069246, 4.8831491246584635, 5.933195648794071, 6.9424616814532225, 7.993625621727003, 8.955489593628242, 9.989852155061858, 10.974442316482586, 11.934852916509277, 12.859125828708182, 13.866231247665336, 14.904688429479208, 14.521352777859862, 13.695587261412257, 4.795599837432236, 3.8311678625200196, 2.863211743164299, 1.9316740174903149, 2.9256626351251818, 3.9914990032992463, 4.948624548894633, 5.880085243504501, 6.916409286987125, 7.893579335946136, 8.94016920344045, 9.923005146184874, 10.897349877627173, 11.93699345884578, 12.9470631993503, 13.817980361210518, 14.829478270859468, 15.820803518499355, 15.584716003171998, 14.73398060630749, 5.8681718464463515, 4.848670955513449, 3.7930132165690633, 2.9488403613226764, 3.9069757641003244, 4.966575407228275, 5.880600684999688, 6.869835235073254, 7.9410080776616345, 8.869159260140664, 9.870201471765297, 10.880072139422573, 11.860180972749859, 12.824864787335699, 13.816983211978298, 14.762362290748074, 15.691755889070402, 16.621392199551707, 16.634793793904624, 15.747539767243472, 6.7044218675304945, 5.681430708042836, 4.744277394798594, 3.9438322611993355, 4.907496853475569, 5.9103466706396155, 6.8532998479144, 7.792195155102099, 8.729236428351035, 9.665003011759005, 10.738020936787295, 11.72094269301584, 12.708551510296124, 13.694288377676445, 14.752578849490162, 15.695543871893548, 16.18983443882464, 17.013080562426552, 17.55266412507369, 16.599552337461013, 7.640462951623562, 6.628821215980168, 5.787243160687721, 5.005011741122371, 5.925015675705845, 6.847902403405451, 7.906426848801573, 8.756276738769103, 9.65681540295428, 10.621814130301843, 11.577677126626039, 12.627018674429689, 13.637254481590265, 14.693160456580944, 15.646780066801146, 15.739410075590772, 15.15351611721596, 15.976714433626553, 16.730265110168865, 17.55123798499786], [17.554835840644227, 16.566871879860397, 15.74392107681102, 14.684375492026321, 13.744858110428487, 14.67946384307794, 14.469736317958288, 13.503734826286383, 12.484505336037781, 11.545790583386069, 10.617051108862121, 9.736555846472951, 8.740053998243914, 7.932245249185722, 6.999423880808165, 6.05515749622898, 6.978951733410839, 7.745200275714398, 8.591913012837587, 9.546008646131025, 16.552372513496945, 15.622316070310484, 14.73843191892585, 13.798086108663774, 12.815703896921887, 13.739264516824012, 14.599839465920795, 14.43910679779911, 13.424269285384348, 12.472627659974968, 11.66407877765017, 10.671439314899503, 9.732376562142095, 8.86628045640692, 7.998640332544429, 7.019914119627593, 7.938999509133231, 8.725652699420307, 9.590174044368355, 8.693240174416076, 15.689879108034566, 14.689284476839214, 13.769075784973952, 12.79115006186377, 11.870050671359689, 12.773442943121507, 13.637547458297746, 14.6816586026179, 14.446446670940048, 13.521299446833993, 12.655008029033965, 11.617819206930317, 10.770205807226583, 9.904707904288017, 8.973069950332304, 8.050340890196356, 8.910049055897057, 9.571191008475564, 8.631678551293398, 7.733972389008995, 14.777286007040125, 13.731530125945028, 12.831864421040738, 11.780578076487503, 10.85142687176788, 11.79580034008926, 12.697612413103597, 13.727245985127913, 14.709068104622517, 14.566247424104011, 13.696687790148491, 12.669046997033119, 11.755771990145346, 10.847043942048614, 9.970690757868603, 9.00002975200829, 9.73762514233626, 8.723392135866767, 7.703194468217095, 6.7632286077890384, 13.78828283863189, 12.73908411129662, 11.85409163167439, 10.79648861379002, 9.865793480090673, 10.792976042416953, 11.722653931990472, 12.761493216809683, 13.680562311991695, 14.654031854517443, 14.607877150370088, 13.604593956881434, 12.69937119747994, 11.83161802376744, 10.906176801877079, 9.942339942600853, 8.9105460654143, 7.862678209724325, 6.820143682758915, 5.874703434228875, 12.731007595946217, 11.731905834978832, 10.86104152053405, 9.893587543682887, 8.888246048516828, 9.837800255424758, 10.805606985534403, 11.754825200231915, 12.74239385700988, 13.710499935591557, 14.125781130093165, 13.181586051161347, 12.17021182896903, 11.185614292730541, 10.209254181421057, 9.266096135146169, 8.207248333325069, 7.14237409401355, 6.146026752719501, 5.131781375746215, 11.686815452467478, 10.767909621312274, 9.843722786017832, 8.885299936484063, 7.922306572728719, 8.870553930433159, 9.852467250025901, 10.745700368650466, 11.70011529497727, 12.724326467104795, 13.79599028210068, 13.976583221756272, 12.954930108304868, 11.930638561762558, 10.999330041578103, 9.946627216150418, 8.922965465993553, 7.980139125618696, 6.975469627698476, 6.046403799173944, 10.756186820487118, 9.770829442915065, 8.818270691224555, 7.887027692882852, 6.889080409693134, 7.828816671103932, 8.868289122232675, 9.788887415783574, 10.747171484219644, 11.766131561235749, 12.77588172503757, 13.75207848125519, 13.801884200443162, 12.863679565668049, 11.800335682042306, 10.78055249834513, 9.833132579026262, 8.848846988470987, 7.893601163425366, 6.8840551973600705, 9.823768208094721, 8.816742895160885, 7.850207894346099, 6.918914887536762, 5.963256751277208, 6.945510359368932, 7.911717931648619, 8.81552594751928, 9.795794615086965, 10.774736482212374, 11.792650299046498, 12.765984175022282, 13.745557320664204, 13.64054692993636, 12.68580627492678, 11.758356388873196, 10.858045852828624, 9.915687801843339, 8.892802382222618, 7.852095925158781, 8.77002627226039, 7.758163579789539, 6.9027454025552135, 5.961154531065625, 5.018285200393365, 5.9713427479168, 6.90763187172637, 7.860984420672519, 8.850210862103877, 9.780048697325086, 10.836403226811392, 11.762313080665072, 12.769655959471722, 13.62923358072405, 13.684338428642176, 12.756711459132969, 11.793448195381574, 10.812686521226231, 9.745021565369068, 8.71438800223087, 7.760103003903721, 6.813355409917368, 5.865908739686563, 4.936566620140741, 3.9751075012763013, 4.90347296760612, 5.9028228674470675, 6.8048033038012, 7.823801781622835, 8.868525910529637, 9.84846870009529, 10.797152592898819, 11.723777639666844, 12.694445171715111, 13.686817103225193, 13.735008380752006, 12.744231260634086, 11.679313170291083, 10.661643159248678, 9.660232667494343, 6.8718030072135345, 5.803502856347674, 4.809774830774941, 3.8801137328986277, 2.9520920077085187, 3.885235196379151, 4.900834575034034, 5.873431668326257, 6.851336748576024, 7.91688999786008, 8.849405342971153, 9.84293379739207, 10.71577895388106, 11.723771712088732, 12.686318293123676, 13.640943059759028, 13.697774295436338, 12.667903275233142, 11.6486063791153, 10.631040571627546, 5.953070918108782, 4.887034851368162, 3.841289191340757, 2.9071774269183788, 1.9804651773559665, 2.935007303696027, 3.8838612315426984, 4.878660385326512, 5.894074235090638, 6.899911180922654, 7.832713058582892, 8.826601562739564, 9.790560830538507, 10.744770261865167, 11.790771374916421, 12.753019049976611, 13.803860658822638, 13.488663142761277, 12.554244887928183, 11.556398554038738, 5.04017250159647, 4.068608484681344, 3.0480349341569926, 1.9745788181463895, 0.9697349849911021, 1.9776821442431913, 2.9385930231205197, 4.006913991270187, 4.956149095285362, 5.896921102223605, 6.947322943514131, 7.8751678929317706, 8.893227740535279, 9.946555427470454, 10.900742594812927, 11.952664231474955, 12.93000506189066, 13.99103983524706, 13.535359642635143, 12.510882603186927, 4.12590064592951, 3.0809957458810135, 2.040358973325322, 0.9669117288619475, 0.0, 1.0382323014287902, 1.995610877507469, 3.0258208757684764, 3.9905738875810943, 5.031335099343172, 6.10323782479106, 7.149680272528098, 8.10862574532133, 9.065671019659908, 10.001468207243983, 10.95916586785062, 11.998783750898342, 13.059168185369632, 14.008616207659436, 13.568454172247446, 4.904923950177211, 3.95883054983845, 2.896816509626052, 1.9255756773620227, 1.0166091245924178, 1.9864549927428636, 2.9672279940449764, 3.9162373957965158, 4.966283919932124, 5.975549952591275, 7.026713892865056, 7.988577864766295, 9.022940426199911, 10.00753058762064, 10.96794118764733, 11.892214099846235, 12.89931951880339, 13.937776700617261, 14.971048340282362, 14.598672444334348, 5.762511566294183, 4.798079591381967, 3.8301234720262465, 2.8985857463522624, 2.054039943348463, 3.040145974050734, 3.9817128200326852, 4.913173514642553, 5.949497558125177, 6.9266676070841875, 7.973257474578502, 8.956093417322927, 9.930438148765226, 10.970081729983834, 11.980151470488353, 12.851068632348571, 13.862566541997522, 14.853891789637409, 15.859257432575795, 15.637065789229581, 6.835083575308299, 5.815582684375396, 4.759924945431011, 3.915752090184624, 3.096390227489738, 4.092715836695643, 4.91368895613774, 5.902923506211306, 6.974096348799686, 7.902247531278715, 8.903289742903347, 9.913160410560623, 10.893269243887909, 11.857953058473749, 12.850071483116349, 13.795450561886124, 14.724844160208452, 15.654480470689757, 16.643525705016764, 16.65062495016556, 7.671333596392442, 6.648342436904783, 5.711189123660541, 4.910743990061284, 4.096911316864983, 5.044760275341165, 5.934685186701953, 6.842705025083395, 7.779746298332331, 8.7155128817403, 9.788530806768591, 10.771452562997135, 11.75906138027742, 12.74479824765774, 13.803088719471457, 14.728632143031598, 15.665509077309125, 16.62899461834683, 17.578019713636795, 17.502637520383104, 8.607374680485508, 7.595732944842116, 6.754154889549669, 5.971923469984319, 5.1144301390952585, 5.982316008107, 6.993914869048668, 7.806786608750398, 8.707325272935575, 9.67232400028314, 10.628186996607337, 11.677528544410986, 12.687764351571563, 13.74367032656224, 14.697289936782441, 14.772498346728824, 15.724728492430529, 16.70503608493957, 17.633350293090952, 18.454323167919952], [18.455314482710268, 17.46735052192644, 16.598067841847314, 15.538522257062615, 14.59900487546478, 13.892388296250479, 13.460986850659504, 12.494985358987599, 11.475755868738997, 10.537041116087284, 9.608301641563337, 8.727806379174167, 7.7313045309451285, 6.933022079737776, 6.010815407628987, 6.968169743038586, 8.017184034839628, 8.783432577143186, 9.630145314266377, 10.584240947559815, 17.452851155562985, 16.522794712376527, 15.592578683962143, 14.652232873700068, 13.669850661958181, 12.95218896999655, 13.759055891860624, 13.430357330500325, 12.415519818085563, 11.463878192676184, 10.655329310351386, 9.662689847600719, 8.723627094843309, 7.867057286958976, 7.019071567660313, 7.932926366437199, 8.972862834608437, 9.763885000849095, 10.628406345797146, 9.731472475844866, 16.59035775010061, 15.589763118905257, 14.624338209898601, 13.645296826900063, 12.724197436395983, 11.986367396294046, 12.796763884237576, 13.817280005475906, 13.437697203641264, 12.512549979535208, 11.64625856173518, 10.609069739631533, 9.761456339927797, 8.905484734840071, 7.993501185448188, 8.963353137005962, 9.943912381372263, 10.609423309904354, 9.669910852722188, 8.772204690437786, 15.677764649106168, 14.63200876801107, 13.687126845965388, 12.634724841523797, 11.705573636804173, 11.008724793261798, 11.856828839043427, 12.815499375750104, 13.670835803193729, 13.557497956805227, 12.687938322849707, 11.660297529734335, 10.74702252284656, 9.847820772600668, 9.02854205722234, 9.913041998817896, 10.77585744376505, 9.761624437295557, 8.741426769645885, 7.801460909217829, 14.688761480697933, 13.639562753362663, 12.714154816312666, 11.650635378826314, 10.719940245126967, 10.005900495589492, 10.881870357930302, 11.7762785017924, 12.642330010562906, 13.615799553088655, 13.599127683071304, 12.59584448958265, 11.690621730181153, 10.832394854319494, 10.077916254213342, 10.963029063906115, 9.948778366843088, 8.900910511153114, 7.858375984187705, 6.9129357356576655, 13.650459507964552, 12.632384477044875, 11.750252029657613, 10.74773430871918, 9.742392813553122, 8.992554592426176, 9.920155007552074, 10.716592898803126, 11.704161555581091, 12.672267634162768, 13.676142637602688, 13.607267328762761, 12.655665522234177, 11.833608406705725, 11.098320412926382, 10.304328436574957, 9.245480634753857, 8.18060639544234, 7.184259054148291, 6.170013677175005, 12.60834512298712, 11.668388263378317, 10.733427471470755, 9.739446701520356, 8.776453337765012, 8.025308267434577, 8.94336635172275, 9.707468067221678, 10.661882993548481, 11.686094165676007, 12.757757980671892, 13.6951541860149, 13.600627636217977, 12.889853343123484, 12.037562343006892, 10.984859517579206, 9.961197767422341, 9.018371427047486, 8.013701929127265, 7.084636100602734, 11.70865148391686, 10.671308084981108, 9.707975376677478, 8.741174457919143, 7.743227174729427, 6.983571008105351, 7.88144651689074, 8.750655114354785, 9.708939182790855, 10.72789925980696, 11.737649423608781, 12.713846179826401, 13.712000904111248, 13.854857682363068, 12.791513798737325, 11.77173061504015, 10.824310695721282, 9.840025105166006, 8.884779280120386, 7.87523331405509, 10.776232871524464, 9.71992730448527, 8.739912579799022, 7.773061652573054, 6.817403516313499, 5.947000179341311, 6.901446393298314, 7.777293646090491, 8.757562313658175, 9.736504180783585, 10.75441799761771, 11.727751873593494, 12.707325019235416, 13.583770988559614, 13.676984391621799, 12.749534505568215, 11.849223969523644, 10.906865918538358, 9.883980498917635, 8.8432740418538, 9.76120438895541, 8.749341696484558, 7.8093774898254, 6.815301296101916, 5.872431965429656, 4.9687585802934535, 5.8973603333760645, 6.822752119243729, 7.811978560675088, 8.741816395896297, 9.798170925382601, 10.724080779236283, 11.731423658042933, 12.591001279295261, 13.592421617424552, 13.747889575827989, 12.784626312076593, 11.80386463792125, 10.736199682064088, 9.705566118925889, 8.75128112059874, 7.804533526612388, 6.857086856381582, 5.855294104279402, 4.829254266312592, 3.900888799982773, 4.864590566018277, 5.76657100237241, 6.785569480194045, 7.830293609100847, 8.8102363986665, 9.75892029147003, 10.685545338238056, 11.656212870286323, 12.648584801796405, 13.598328550965185, 13.735409377329105, 12.670491286986103, 11.652821275943698, 10.651410784189363, 7.862981123908554, 6.794680973042693, 5.800952947469961, 4.8584866057709695, 3.8317445106794783, 2.8470028949503607, 3.862602273605244, 4.835199366897466, 5.813104447147235, 6.878657696431292, 7.8111730415423635, 8.80470149596328, 9.677546652452271, 10.685539410659944, 11.648085991694888, 12.60271075833024, 13.604220452615143, 13.65908139192816, 12.639784495810318, 11.622218688322565, 6.944249034803802, 5.878212968063181, 4.832467308035777, 3.8983555436133988, 2.860117680326926, 1.8967750022672365, 2.845628930113908, 3.8404280838977223, 4.855841933661849, 5.861678879493865, 6.794480757154103, 7.788369261310774, 8.752328529109718, 9.706537960436378, 10.752539073487632, 11.714786748547823, 12.76562835739385, 13.741735487516957, 13.545423004623203, 12.547576670733758, 6.07840480302526, 5.106840786110134, 4.0392130508520125, 2.9657569348414095, 1.9609131016861219, 0.939449842814401, 1.9003607216917295, 2.9686816898413966, 3.917916793856572, 4.858688800794816, 5.90909064208534, 6.83693559150298, 7.85499543910649, 8.908323126041664, 9.862510293384137, 10.914431930046165, 11.891772760461867, 12.952807533818268, 13.897030091754528, 13.502060719881946, 5.1641329473583, 4.119228047309804, 3.078591274754112, 2.0051440302907375, 1.0382323014287902, 0.0, 0.9573785760786787, 1.9875885743396862, 2.952341586152304, 3.9931027979143816, 5.065005523362269, 6.111447971099307, 7.070393443892538, 8.027438718231116, 8.963235905815191, 9.920933566421828, 10.96055144946955, 12.02093588394084, 12.970383906230644, 13.903180611053823, 5.943156251606001, 4.99706285126724, 3.935048811054842, 2.963807978790813, 1.967692387714131, 0.9978465195636853, 1.958478526746192, 2.9074879284977313, 3.928051618503334, 4.937317651162485, 5.9884815914362655, 6.950345563337505, 7.984708124771121, 8.969298286191849, 9.929708886218538, 10.853981798417443, 11.861087217374598, 12.89954439918847, 13.93281603885357, 14.891299149875048, 6.800743867722972, 5.836311892810756, 4.868355773455036, 3.9368180477810526, 3.005123206470176, 2.051537500871556, 2.9729633527339008, 3.904424047343769, 4.920363644871065, 5.897533693830075, 6.935025173149712, 7.917861115894137, 8.892205847336436, 9.931849428555044, 10.941919169059563, 11.81283633091978, 12.82433424056873, 13.815659488208617, 14.821025131147003, 15.848503669928997, 7.873315876737088, 6.853814985804186, 5.7981572468598, 4.953984391613414, 4.047473490611451, 3.104107363516464, 3.9049394888389557, 4.894174038912522, 5.965346881500902, 6.893498063979931, 7.8868395042782815, 8.886925320003924, 9.86703415333121, 10.831717967917049, 11.823836392559649, 12.769215471329424, 13.698609069651752, 14.628245380133057, 15.617290614460064, 16.55196504302593, 8.709565897821232, 7.686574738333572, 6.749421425089331, 5.948976291490073, 5.047994579986696, 4.0561518021619865, 4.925935719403169, 5.833955557784611, 6.770996831033546, 7.706763414441516, 8.779781339469807, 9.76270309569835, 10.750311912978635, 11.736048780358956, 12.794339252172673, 13.702397052474899, 14.639273986752425, 15.602759527790129, 16.551784623080096, 17.504896410692773, 9.645606981914298, 8.633965246270906, 7.792387190978458, 7.010155771413109, 6.027442385904864, 4.993707534927822, 5.985165401749883, 6.798037141451614, 7.69857580563679, 8.663574532984356, 9.619437529308552, 10.668779077112202, 11.679014884272778, 12.734920859263456, 13.688540469483657, 14.676388682425598, 15.675592308361104, 16.639125656590128, 17.523622657827712, 18.45658205822962], [18.500246168647536, 17.525287074450617, 16.534204696684448, 15.474659111899747, 14.535141730301913, 13.484683572298179, 12.503608274580825, 11.53760678290892, 10.518377292660318, 9.579662540008606, 8.650923065484658, 7.7704278030954885, 6.77392595486645, 5.975643503659097, 6.866173926066275, 7.823528261475874, 8.874941716162962, 9.740811153221866, 10.587523890345057, 11.541619523638495, 17.497782841500253, 17.480173288455205, 16.54995726004082, 15.609611449778747, 14.62722923803686, 13.833673528494051, 12.836046457213026, 12.472978754421646, 11.458141242006885, 10.506499616597505, 9.697950734272707, 8.70531127152204, 7.766248518764631, 6.909678710880297, 7.860324845513388, 8.788284884874487, 9.828221353045725, 10.721263576927775, 11.585784921875826, 10.688851051923546, 16.667158131008136, 16.547141694983935, 15.58171678597728, 14.602675402978742, 13.681576012474661, 12.867851954791547, 11.873754449589978, 12.859901429397228, 12.480318627562585, 11.55517140345653, 10.688879985656502, 9.651691163552854, 8.80407776384912, 7.948106158761393, 8.834754463301262, 9.81871165544325, 10.799270899809551, 11.566801885983034, 10.627289428800868, 9.729583266516466, 15.930479154044301, 15.589387344089749, 14.644505422044066, 13.592103417602475, 12.662952212882852, 11.8902093517593, 10.933819404395829, 11.858120799671426, 12.713457227115054, 12.600119380726548, 11.730559746771029, 10.702918953655656, 9.789643946767884, 8.89044219652199, 9.862945624684325, 10.768400517255184, 11.73323601984373, 10.719003013374238, 9.698805345724566, 8.758839485296509, 14.954216678004654, 14.596941329441341, 13.671533392391344, 12.608013954904992, 11.677318821205645, 10.888538812856222, 9.958860923282703, 10.818899925713723, 11.68495143448423, 12.658420977009978, 12.641749106992625, 11.638465913503971, 10.733243154102476, 9.875016278240816, 10.869609544594367, 11.818387582343403, 10.906156942921768, 9.858289087231794, 8.815754560266384, 7.870314311736345, 13.892106946356327, 13.589763053123553, 12.707630605736291, 11.705112884797858, 10.6997713896318, 9.934436034670759, 8.997145572904476, 9.75921432272445, 10.746782979502415, 11.71488905808409, 12.71876406152401, 12.649888752684083, 11.6982869461555, 10.876229830627047, 11.85258994193653, 11.26170701265364, 10.202859210832539, 9.13798497152102, 8.14163763022697, 7.127392253253684, 13.5657236990658, 12.625766839456995, 11.690806047549433, 10.696825277599034, 9.73383191384369, 8.96718970967916, 8.020356917075151, 8.750089491143001, 9.704504417469805, 10.728715589597329, 11.800379404593214, 12.737775609936223, 12.6432490601393, 11.932474767044805, 12.831170300819329, 11.942238093657886, 10.918576343501021, 9.975750003126166, 8.971080505205945, 8.042014676681413, 12.666030059995538, 11.628686661059787, 10.665353952756156, 9.698553033997822, 8.700605750808105, 7.925452450349933, 6.958437082243142, 7.793276538276109, 8.751560606712179, 9.770520683728284, 10.780270847530105, 11.756467603747724, 12.754622328032571, 12.958714296197916, 13.748892374816005, 12.72910919111883, 11.781689271799962, 10.797403681244687, 9.842157856199066, 8.83261189013377, 11.733611447603142, 10.677305880563948, 9.6972911558777, 8.730440228651732, 7.774782092392178, 6.8888816215858935, 5.978436958650716, 6.819915070011814, 7.800183737579499, 8.779125604704909, 9.797039421539033, 10.770373297514814, 11.749946443156736, 12.626392412480934, 13.581133067490514, 13.706913081646896, 12.806602545602324, 11.864244494617038, 10.841359074996316, 9.80065261793248, 10.71858296503409, 9.706720272563237, 8.76675606590408, 7.772679872180595, 6.829810541508335, 5.910640022538035, 4.974350898728466, 5.865373543165052, 6.854599984596411, 7.78443781981762, 8.840792349303925, 9.766702203157603, 10.774045081964253, 11.63362270321658, 12.635043041345874, 13.562670010855081, 13.742004888155273, 12.761243213999931, 11.693578258142768, 10.662944695004569, 9.70865969667742, 8.761912102691067, 7.814465432460261, 6.812672680358082, 5.786632842391271, 4.858267376061452, 3.941581131370679, 4.809192426293732, 5.828190904115368, 6.87291503302217, 7.852857822587824, 8.80154171539135, 9.728166762159375, 10.698834294207643, 11.691206225717725, 12.640949974886503, 13.600384911338715, 13.627869863064783, 12.610199852022378, 11.608789360268043, 8.820359699987232, 7.7520595491213715, 6.758331523548639, 5.815865181849648, 4.789123086758157, 3.804381471029039, 2.939592838957646, 3.8778207908187885, 4.8557258710685565, 5.921279120352613, 6.853794465463685, 7.8473229198846015, 8.720168076373591, 9.728160834581264, 10.690707415616208, 11.64533218225156, 12.646841876536463, 13.681206263489042, 13.597163071889, 12.579597264401245, 7.90162761088248, 6.8355915441418595, 5.789845884114455, 4.855734119692077, 3.817496256405605, 2.8541535783459153, 1.8882503540352298, 2.883049507819044, 3.8984633575831706, 4.904300303415186, 5.837102181075425, 6.830990685232096, 7.794949953031039, 8.749159384357698, 9.795160497408952, 10.757408172469143, 11.808249781315169, 12.784356911438277, 13.71877516627137, 13.504955246812438, 7.03578337910394, 6.064219362188814, 4.996591626930691, 3.923135510920088, 2.9182916777648007, 1.8968284188930797, 0.9429821456130509, 2.011303113762718, 2.9605382177778936, 3.9013102247161378, 4.951712066006662, 5.879557015424302, 6.897616863027811, 7.950944549962986, 8.90513171730546, 9.957053353967488, 10.934394184383187, 11.995428957739588, 12.939651515675848, 13.964128555124065, 6.121511523436979, 5.076606623388483, 4.0359698508327915, 2.9625226063694168, 1.995610877507469, 0.9573785760786787, 0.0, 1.0302099982610073, 1.9949630100736253, 3.035724221835703, 4.10762694728359, 5.1540693950206276, 6.113014867813859, 7.070060142152435, 8.00585732973651, 8.963554990343148, 10.00317287339087, 11.06355730786216, 12.013005330151964, 12.945802034975143, 6.90053482768468, 5.95444142734592, 4.892427387133521, 3.921186554869492, 2.92507096379281, 1.955225095642364, 1.0010999506675133, 1.9501093524190525, 2.970673042424655, 3.979939075083806, 5.031103015357587, 5.992966987258827, 7.0273295486924425, 8.01191971011317, 8.972330310139858, 9.896603222338763, 10.903708641295918, 11.94216582310979, 12.97543746277489, 13.933920573796367, 7.7581224438016525, 6.793690468889436, 5.825734349533716, 4.894196623859732, 3.9625017825488547, 3.0089160769502348, 2.0155847766552224, 2.94704547126509, 3.9629850687923867, 4.940155117751397, 5.9776465970710335, 6.960482539815459, 7.934827271257758, 8.974470852476365, 9.984540592980885, 10.8554577548411, 11.86695566449005, 12.858280912129937, 13.863646555068323, 14.891125093850317, 8.830694452815768, 7.811193561882866, 6.75553582293848, 5.911362967692094, 5.00485206669013, 4.009113433018362, 2.9475609127602773, 3.9367954628338433, 5.0079683054222235, 5.936119487901252, 6.929460928199603, 7.929546743925245, 8.909655577252531, 9.87433939183837, 10.86645781648097, 11.811836895250746, 12.741230493573074, 13.670866804054379, 14.659912038381385, 15.59458646694725, 9.666944473899912, 8.643953314412252, 7.706800001168011, 6.906354867568753, 5.914360137763321, 4.911510320599275, 3.9685571433244906, 4.876576981705933, 5.813618254954868, 6.749384838362838, 7.822402763391128, 8.805324519619672, 9.792933336899956, 10.778670204280278, 11.836960676093994, 12.74501847639622, 13.681895410673746, 14.64538095171145, 15.594406047001417, 16.547517834614094, 10.602985557992978, 9.591343822349586, 8.749765767057138, 7.957609142743532, 6.882800904342153, 5.84906605336511, 5.027786825671205, 5.8406585653729355, 6.741197229558112, 7.706195956905677, 8.662058953229874, 9.711400501033523, 10.7216363081941, 11.777542283184777, 12.731161893404979, 13.71901010634692, 14.718213732282425, 15.68174708051145, 16.566244081749034, 17.499203482150943], [17.47003617038653, 16.540266243476513, 15.549183865710342, 14.489638280925643, 13.550120899327808, 12.499662741324075, 11.518587443606721, 10.552585951934816, 9.533356461686214, 8.594641709034502, 7.665902234510553, 6.7854069721213826, 5.788905123892345, 6.79876259545552, 7.72806824066131, 8.68542257607091, 9.736836030757996, 10.699564514211426, 11.558547725776199, 12.512643359069637, 16.467572843239246, 17.33820170980632, 16.36556113031398, 15.425215320051906, 14.442833108310019, 13.439862067578003, 12.473363818493782, 11.487957923447542, 10.473120411032781, 9.521478785623401, 8.712929903298601, 7.7202904405479345, 6.781227687790526, 7.73279780267672, 8.68344393730981, 9.650179199469523, 10.690115667640761, 11.680016937917335, 12.556808757306966, 11.659874887354686, 15.63694813274713, 16.63754276394248, 16.610674543107763, 15.631633160109226, 14.710533769605146, 13.784815429828182, 12.790717924626613, 11.999862888237333, 11.495297796588481, 10.570150572482426, 9.703859154682396, 8.666670332578748, 7.819056932875014, 8.771225250557816, 9.657873555097686, 10.680605970038286, 11.661165214404587, 12.537825721414174, 11.598313264232008, 10.700607101947606, 14.900269155783294, 15.879596269981192, 15.67346317917455, 14.62106117473296, 13.691909970013336, 12.807172826795934, 11.850782879432463, 10.99808225851153, 11.853418685955159, 11.615098549752444, 10.745538915796923, 9.71789812268155, 8.804623115793778, 9.713561288318413, 10.686064716480749, 11.63029483185022, 12.671979822516787, 11.690026848805378, 10.669829181155706, 9.729863320727649, 13.924006679743647, 14.887150255332784, 14.70049114952183, 13.636971712035477, 12.70627657833613, 11.805502287892857, 10.875824398319338, 9.958861384553828, 10.824912893324335, 11.798382435850083, 11.65672827601852, 10.653445082529865, 9.74822232312837, 10.688956184710836, 11.683549451064387, 12.647386310340613, 11.87718077835291, 10.829312922662936, 9.786778395697526, 8.841338147167487, 12.86189694809532, 13.879971979014996, 13.736588362866776, 12.734070641928342, 11.728729146762285, 10.881915778050756, 9.91410904794111, 8.899175781564555, 9.88674443834252, 10.854850516924195, 11.858725520364114, 11.664867921709977, 10.713266115181394, 11.690169737097069, 12.666529848406553, 12.291917010914647, 11.233069209093546, 10.168194969782027, 9.171847628487978, 8.157602251514692, 13.89964419235989, 13.65472459658748, 12.719763804679918, 11.725783034729519, 10.762789670974175, 9.919233711704528, 8.937320392111786, 7.890050949983106, 8.84446587630991, 9.868677048437434, 10.940340863433319, 11.792346551977802, 11.658228229165195, 12.682519775707505, 13.61382829589196, 12.972448091918894, 11.948786341762029, 11.005960001387173, 10.001290503466953, 9.07222467494242, 13.694987817126023, 12.657644418190271, 11.694311709886641, 10.727510791128307, 9.72956350793859, 8.89230971787235, 7.875400557279776, 6.933237997116214, 7.891522065552284, 8.910482142568389, 9.92023230637021, 10.811038545789303, 11.80141660754353, 12.605216054780012, 13.59016543584755, 13.759319189379838, 12.81189927006097, 11.827613679505694, 10.872367854460073, 9.862821888394777, 12.762569204733627, 11.706263637694432, 10.726248913008185, 9.759397985782217, 8.803739849522662, 7.855738889108309, 6.89540043368735, 5.959876528851919, 6.940145196419604, 7.919087063545014, 8.934458210530643, 9.784913681447382, 10.764486827089303, 11.640932796413502, 12.595673451423082, 13.523123337476665, 13.836812543863331, 12.894454492878046, 11.871569073257323, 10.830862616193487, 11.748792963295097, 10.736930270824244, 9.795713823034564, 8.80163762931108, 7.858768298638819, 6.877497290060451, 5.941208166250882, 5.0053350020051575, 5.994561443436516, 6.924399278657725, 7.881603259117703, 8.781242587090171, 9.788585465896821, 10.648163087149149, 11.64958342527844, 12.577210394787647, 13.58713550784281, 13.791453212260938, 12.723788256403775, 11.693154693265576, 10.738869694938428, 9.792122100952074, 8.844675430721269, 7.842882678619089, 6.816842840652279, 5.888477374322459, 4.908438398893095, 3.9491538851338377, 4.968152362955474, 5.9278171140491365, 6.893668732401603, 7.816082099323918, 8.742707146091943, 9.71337467814021, 10.705746609650292, 11.655490358819073, 12.614925295271282, 13.679843385614285, 13.640409850283385, 12.63899935852905, 9.85056969824824, 8.782269547382379, 7.7885415218096465, 6.846075180110654, 5.819333085019164, 4.8345914692900465, 3.969802837218653, 3.0177822496588944, 3.9956873299086624, 4.942241017073497, 5.868334849396252, 6.861863303817168, 7.73470846030616, 8.742701218513831, 9.705247799548776, 10.659872566184127, 11.661382260469031, 12.69574664742161, 13.715043543539451, 13.609807262662253, 8.931837609143487, 7.865801542402867, 6.8200558823754625, 5.885944117953084, 4.847706254666612, 3.8843635766069227, 2.918460352296237, 2.02301096665915, 3.0384248164232766, 3.9188406873477533, 4.8516425650079915, 5.845531069164664, 6.809490336963607, 7.763699768290266, 8.80970088134152, 9.77194855640171, 10.822790165247737, 11.798897295370844, 12.733315550203939, 13.731161884093384, 8.065993377364947, 7.094429360449821, 6.026801625191698, 4.953345509181095, 3.948501676025808, 2.9270384171540873, 1.9731921438740583, 1.0258434976952855, 1.975078601710461, 2.915850608648705, 3.9662524499392298, 4.89409739935687, 5.912157246960379, 6.965484933895554, 7.919672101238027, 8.971593737900056, 9.90418418612218, 10.96521895947858, 11.909441517414841, 12.933918556863057, 7.151721521697986, 6.10681662164949, 5.066179849093799, 3.992732604630424, 3.0258208757684764, 1.9875885743396862, 1.0302099982610073, 0.0, 0.964753011812618, 2.0055142235746954, 3.077416949022583, 4.123859396759621, 5.082804869552852, 6.039850143891429, 6.975647331475504, 7.933344992082141, 8.972962875129863, 10.033347309601153, 10.982795331890957, 11.915592036714136, 7.871558663115823, 6.925465262777062, 5.863451222564664, 4.892210390300635, 3.8647167926490447, 2.894870924498599, 1.914097923196486, 0.9650885214449468, 1.9404630441636477, 2.949729076822799, 4.00089301709658, 4.962756988997819, 5.997119550431435, 6.981709711852163, 7.942120311878852, 8.866393224077756, 9.87349864303491, 10.911955824848782, 11.945227464513883, 12.90371057553536, 8.729146279232793, 7.764714304320578, 6.796758184964858, 5.8652204592908745, 4.9021476114050895, 3.931831633236789, 2.928582749184195, 1.9620246402909847, 2.9327750705313793, 3.9099451194903896, 4.947436598810026, 5.9302725415544515, 6.9046172729967505, 7.944260854215358, 8.954330594719877, 9.825247756580092, 10.836745666229042, 11.82807091386893, 12.833436556807316, 13.86091509558931, 9.801718288246908, 8.782217397314007, 7.726559658369622, 6.882386803123236, 5.944497895546364, 4.9221114055473345, 3.86055888528925, 2.9517746318597378, 4.001004034819708, 4.929155217298737, 5.899250929938596, 6.899336745664238, 7.8794455789915245, 8.844129393577363, 9.836247818219963, 10.781626896989739, 11.711020495312066, 12.640656805793371, 13.629702040120378, 14.564376468686243, 10.637968309331054, 9.614977149843394, 8.677823836599153, 7.830931607776079, 6.776254452358357, 5.77340463519431, 4.8304514579195255, 3.891556150731827, 4.828597423980763, 5.764364007388733, 6.837381932417024, 7.820303688645569, 8.807912505925852, 9.793649373306174, 10.847105179409729, 11.714808478135213, 12.65168541241274, 13.615170953450443, 14.56419604874041, 15.517307836353089, 11.57400939342412, 10.562367657780728, 9.72078960248828, 8.819503457338566, 7.744695218937188, 6.710960367960145, 5.88968114026624, 4.85563773439883, 5.756176398584007, 6.7211751259315715, 7.677038122255769, 8.726379670059417, 9.736615477219996, 10.792521452210673, 11.746141062430874, 12.688800108085912, 13.688003734021418, 14.651537082250442, 15.536034083488026, 16.46899348388994], [16.50528315857391, 15.637759484905965, 14.709535151303651, 13.659117367866099, 12.719599986268264, 11.66914182826453, 10.688066530547177, 9.722065038875272, 8.702835548626668, 7.7641207959749545, 6.835381321451006, 5.984529015010795, 6.7536581357049625, 7.763515607268138, 8.692821252473928, 9.65017558788353, 10.701589042570616, 11.664317526024046, 12.523300737588817, 13.477396370882255, 15.50281983142663, 16.43287627461309, 15.535040217254437, 14.594694406992362, 13.612312195250475, 12.609341154518459, 11.642842905434238, 10.657437010387996, 9.642599497973235, 8.690957872563853, 7.905266150496544, 6.9194124834373465, 7.745980699603144, 8.697550814489338, 9.648196949122429, 10.614932211282143, 11.654868679453381, 12.644769949729955, 13.521561769119586, 12.624627899167306, 14.67219512093451, 15.672789752129862, 16.54414501265439, 15.543753602676405, 14.54636166274572, 13.575162728220963, 12.605134913057286, 11.604006524853377, 10.664776883528935, 9.739629659422878, 8.90298119757181, 7.865792375468161, 8.783809944687633, 9.735978262370434, 10.622626566910304, 11.645358981850906, 12.625918226217207, 13.502578733226795, 12.563066276044628, 11.665360113760226, 13.935516143970675, 14.914843258168574, 15.878009111972322, 15.571969636348383, 14.64281843162876, 13.75808128841136, 12.801691341047889, 11.948990720126957, 11.084645375250766, 10.784577636692896, 9.944660958686335, 8.917020165570962, 9.769376127606396, 10.678314300131031, 11.650817728293367, 12.59504784366284, 13.636732834329408, 12.654779860617998, 11.634582192968326, 10.694616332540269, 12.959253667931028, 13.922397243520166, 14.900236322605974, 14.5878801736509, 13.657185039951553, 12.756410749508282, 11.826732859934763, 10.909769846169254, 10.056139582619943, 10.915995818626799, 10.855850318907931, 9.852567125419277, 10.712975334940989, 11.653709196523454, 12.648302462877005, 13.612139322153231, 12.84193379016553, 11.794065934475556, 10.751531407510146, 9.806091158980108, 11.897143936282701, 12.915218967202378, 13.952650831007288, 13.684979103543766, 12.679637608377709, 11.83282423966618, 10.865017509556536, 9.850084243179982, 9.117971127638128, 9.948726087005657, 10.952601090445576, 10.863989964599389, 11.678019126994013, 12.654922748909687, 13.631282860219171, 13.256670022727265, 12.197822220906165, 11.132947981594645, 10.136600640300596, 9.12235526332731, 12.934891180547272, 13.874848040156076, 13.670672266295343, 12.676691496344942, 11.713698132589599, 10.870142173319953, 9.888228853727211, 8.840959411598533, 8.075692565605518, 8.962552618518895, 10.03421643351478, 10.84478480556288, 11.839118225972678, 12.683893837518196, 13.615202357702652, 13.93720110373151, 12.913539353574645, 11.97071301319979, 10.96604351527957, 10.036977686755037, 13.73563094776569, 13.608552879805696, 12.645220171502066, 11.678419252743732, 10.680471969554015, 9.843218179487774, 8.826309018895202, 7.8841464587316405, 7.122748754847893, 7.967916329655339, 8.977666493457159, 9.86347679937438, 10.853854861128607, 11.657654308365085, 12.642603689432626, 13.553365481589806, 13.776652281873588, 12.792366691318312, 11.837120866272691, 10.827574900207395, 13.713477666349052, 12.657172099309857, 11.67715737462361, 10.710306447397642, 9.754648311138087, 8.806647350723734, 7.846308895302776, 6.910784990467346, 6.120640505194522, 6.976521250631963, 7.986896464115719, 8.837351935032459, 9.81692508067438, 10.693371049998577, 11.648111705008157, 12.57556159106174, 13.509575402475992, 13.859207504690664, 12.836322085069941, 11.795615628006106, 12.713545975107715, 11.701683282636862, 10.74662228464999, 9.752546090926504, 8.809676760254245, 7.828405751675877, 6.892116627866308, 5.956243463620584, 5.17425596472428, 5.981833465744674, 6.9340415127027795, 7.833680840675248, 8.841023719481898, 9.700601340734224, 10.702021678863517, 11.629648648372724, 12.639573761427886, 13.620335435583229, 13.688541268216394, 12.657907705078195, 11.703622706751046, 10.756875112764693, 9.809428442533887, 8.807635690431708, 7.781595852464897, 6.853230386135078, 5.859346860508521, 4.900062346749264, 4.120233933720619, 4.9802553676342125, 5.946106985986679, 6.868520352908994, 7.795145399677018, 8.765812931725286, 9.758184863235368, 10.707928612404146, 11.667363548856358, 12.73228163919936, 13.749951650241766, 13.603752370341669, 10.815322710060858, 9.747022559194997, 8.753294533622265, 7.810828191923273, 6.784086096831782, 5.799344481102665, 4.934555849031271, 3.968690711274321, 3.0541992378299407, 3.9946792706585734, 4.920773102981328, 5.914301557402244, 6.787146713891235, 7.7951394720989065, 8.75768605313385, 9.712310819769202, 10.713820514054106, 11.748184901006685, 12.767481797124526, 13.708958120089651, 9.896590620956106, 8.830554554215485, 7.784808894188081, 6.850697129765702, 5.81245926647923, 4.849116588419541, 3.8832133641088546, 2.9739194282745762, 2.096936724344555, 2.9712789409328293, 3.9040808185930675, 4.897969322749739, 5.861928590548682, 6.816138021875341, 7.862139134926595, 8.824386809986786, 9.875228418832812, 10.85133554895592, 11.785753803789014, 12.783600137678459, 9.030746389177564, 8.059182372262438, 6.991554637004317, 5.918098520993714, 4.9132546878384264, 3.8917914289667053, 2.937945155686676, 1.9767519593107121, 1.0275168552955367, 1.9682888622337806, 3.0186907035243054, 3.9465356529419453, 4.964595500545454, 6.017923187480629, 6.972110354823102, 8.022035519708892, 8.939431174309561, 10.000465947665962, 10.944688505602223, 11.969165545050439, 8.116474533510605, 7.071569633462108, 6.030932860906416, 4.957485616443042, 3.9905738875810943, 2.952341586152304, 1.9949630100736253, 0.964753011812618, 0.0, 1.0407612117620775, 2.112663937209965, 3.1591063849470027, 4.118051857740234, 5.0750971320788105, 6.010894319662886, 6.968591980269522, 8.008209863317244, 9.068594297788534, 10.018042320078338, 10.950839024901518, 8.836311674928442, 7.890218274589681, 6.828204234377282, 5.856963402113253, 4.829469804461663, 3.859623936311217, 2.8788509350091043, 1.929841533257565, 0.9757100323510298, 1.9849760650101809, 3.0361400052839613, 3.9980039771852005, 5.032366538618817, 6.016956700039545, 6.977367300066233, 7.9016402122651375, 8.908745631222292, 9.947202813036164, 10.980474452701264, 11.938957563722742, 9.693899291045414, 8.729467316133197, 7.761511196777477, 6.829973471103493, 5.866900623217708, 4.8965846450494075, 3.8933357609968136, 2.9267776521036026, 1.9680220587187613, 2.9451921076777716, 3.9826835869974078, 4.965519529741833, 5.939864261184132, 6.9795078424027395, 7.989577582907258, 8.860494744767474, 9.871992654416424, 10.86331790205631, 11.868683544994697, 12.89616208377669, 10.766471300059528, 9.746970409126625, 8.69131267018224, 7.847139814935854, 6.909250907358983, 5.886864417359953, 4.8253118971018685, 3.9165276436723557, 3.0362510230070905, 3.9644022054861194, 4.934497918125977, 5.934583733851619, 6.914692567178906, 7.879376381764746, 8.871494806407345, 9.81687388517712, 10.746267483499448, 11.675903793980753, 12.66494902830776, 13.599623456873625, 11.602721321143672, 10.579730161656013, 9.642576848411771, 8.795684619588698, 7.741007464170975, 6.738157647006928, 5.795204469732144, 4.856309162544445, 4.027719466870174, 4.933843094329186, 5.923329364388537, 6.906251120617082, 7.875355373084028, 8.86109224046435, 9.88235216759711, 10.750055466322594, 11.68693240060012, 12.650417941637825, 13.599443036927791, 14.55255482454047, 12.538762405236739, 11.527120669593346, 10.685542614300898, 9.784256469151186, 8.709448230749807, 7.6757133797727635, 6.854434152078858, 5.820390746211448, 4.955298441473418, 5.8906542128720245, 6.846517209196222, 7.89585875699987, 8.80405834437817, 9.85996431936885, 10.81358392958905, 11.724047096273294, 12.7232507222088, 13.686784070437824, 14.571281071675408, 15.50424047207732], [15.524198000383223, 14.656674326715276, 13.728449993112962, 12.707585874269748, 11.768068492671913, 10.71761033466818, 9.736535036950826, 8.770533545278921, 7.870615947527786, 6.931901194876073, 6.003161720352125, 6.960593783111232, 7.7944193474670405, 8.804276819030216, 9.733582464236004, 10.690936799645606, 11.742350254332692, 12.705078737786122, 13.564061949350895, 14.518157582644333, 14.52173467323594, 15.4517911164224, 14.583508723658086, 13.643162913396012, 12.660780701654124, 11.657809660922108, 10.691311411837887, 9.825217409289113, 8.810379896874352, 7.858738271464972, 7.073046549397663, 7.895477251537784, 8.78674191136522, 9.738312026251416, 10.688958160884507, 11.65569342304422, 12.695629891215457, 13.685531161492031, 14.562322980881664, 13.665389110929384, 13.691109962743822, 14.691704593939173, 15.59261351905804, 14.592222109080055, 13.59483016914937, 12.623631234624613, 11.653603419460936, 10.771786923754494, 9.832557282430052, 8.907410058323997, 8.12990881901246, 8.841857143568598, 9.824571156449709, 10.776739474132512, 11.663387778672382, 12.686120193612982, 13.666679437979283, 14.543339944988873, 13.603827487806706, 12.706121325522304, 12.894754932208599, 13.874082046406498, 14.837247900210246, 15.4490147584196, 14.519863553699976, 13.549928412018556, 12.593538464655085, 11.773567553480296, 10.80778290318218, 9.952358035594015, 9.196158842070508, 9.8930849336714, 10.810137339368472, 11.71907551189311, 12.691578940055445, 13.635809055424916, 14.677494046091484, 13.695541072380076, 12.675343404730404, 11.735377544302347, 11.918492456168952, 12.88163603175809, 13.859475110843897, 14.863889117185424, 14.5004001724874, 13.599625882044126, 12.669947992470608, 11.709081665649865, 10.755226037520904, 9.877666937286156, 10.168821255225122, 10.828631893519715, 11.753736546703065, 12.69447040828553, 13.689063674639081, 14.652900533915307, 13.882695001927607, 12.834827146237632, 11.792292619272223, 10.846852370742184, 10.856382724520625, 11.874457755440302, 12.911889619245212, 13.914407340183645, 13.522852740913555, 12.676039372202025, 11.70823264209238, 10.693299375715826, 9.817057582539089, 8.910397205665014, 9.914272209104933, 10.751844538276776, 11.745751458615835, 12.701809892595314, 13.555453835244807, 14.297431234489343, 13.238583432668243, 12.173709193356723, 11.177361852062674, 10.163116475089389, 11.894129968785196, 12.834086828394, 13.805280843112694, 13.519906628880788, 12.556913265125445, 11.713357305855798, 10.731443986263056, 9.684174544134377, 8.774779020506479, 7.924223737178252, 8.995887552174137, 9.806455924222236, 10.800789344632035, 11.645564956177553, 12.576873476362008, 13.58511897617021, 13.954300565336723, 13.011474224961868, 12.006804727041647, 11.077738898517115, 12.697302066425047, 13.770423932739101, 13.488435304037912, 12.521634385279578, 11.52368710208986, 10.686433312023619, 9.669524151431046, 8.727361591267485, 7.821835209748853, 6.929587448314696, 7.939337612116517, 8.825147918033737, 9.815525979787964, 10.619325427024442, 11.604274808091983, 12.515036600249163, 13.46245651956803, 13.74272198060559, 12.787476155559968, 11.777930189494672, 13.629720678817444, 13.500387231845703, 12.520372507159456, 11.553521579933488, 10.597863443673933, 9.649862483259579, 8.68952402783862, 7.75400012300319, 6.8197269600954815, 5.93819236929132, 6.948567582775076, 7.7990230536918155, 8.778596199333737, 9.655042168657934, 10.609782823667514, 11.537232709721097, 12.471246521135349, 13.436842787207404, 13.786677374357218, 12.745970917293382, 13.646535308703223, 12.590459318839471, 11.589837417185834, 10.595761223462349, 9.65289189279009, 8.671620884211722, 7.735331760402153, 6.799458596156429, 5.8733424196252395, 4.943504584404031, 5.895712631362136, 6.795351959334605, 7.802694838141256, 8.66227245939358, 9.663692797522874, 10.591319767032081, 11.601244880087243, 12.582006554242586, 13.636993202712636, 13.60826299436547, 12.653977996038321, 11.707230402051968, 10.759783731821162, 9.73179359508484, 8.70575375711803, 7.7773882907882115, 6.702561993044366, 5.743277479285109, 4.963449066256463, 3.9419264862935695, 4.907778104646036, 5.830191471568351, 6.756816518336375, 7.727484050384643, 8.719855981894725, 9.669599731063503, 10.629034667515715, 11.693952757858717, 12.711622768901123, 13.64143714288221, 11.765677999348133, 10.697377848482272, 9.70364982290954, 8.743779505566398, 7.717037410474907, 6.73229579474579, 5.862512682140148, 4.811905843810166, 3.8974143703657855, 2.9563503893179304, 3.882444221640685, 4.875972676061601, 5.748817832550592, 6.756810590758263, 7.719357171793208, 8.67398193842856, 9.675491632713463, 10.709856019666042, 11.729152915783883, 12.670629238749008, 10.846945910243383, 9.780909843502762, 8.735164183475357, 7.801052419052979, 6.745410580122355, 5.782067902062666, 4.811933714594236, 3.8171345608104215, 2.9401518568803997, 1.9329500595921862, 2.8657519372524245, 3.8596404414090957, 4.823599709208039, 5.777809140534698, 6.823810253585952, 7.786057928646143, 8.836899537492169, 9.813006667615277, 10.74742492244837, 11.745271256337816, 10.071507600939642, 9.099943584024516, 8.032315848766393, 6.95885973275579, 5.954015899600503, 4.932552640728782, 3.888288059996224, 2.819967091846557, 1.8707319878313817, 0.9299599808931377, 1.9803618221836623, 2.9082067716013023, 3.926266619204811, 4.979594306139986, 5.933781473482459, 6.981274307946816, 7.898669962547484, 8.959704735903886, 9.903927293840146, 10.928404333288363, 9.157235745272683, 8.112330845224186, 7.071694072668494, 5.99824682820512, 5.031335099343172, 3.9931027979143816, 3.035724221835703, 2.0055142235746954, 1.0407612117620775, 0.0, 1.0719027254478877, 2.1183451731849257, 3.077290645978157, 4.0343359203167335, 4.970133107900809, 5.927830768507446, 6.967448651555168, 8.027833086026458, 8.977281108316262, 9.910077813139441, 9.877072886690518, 8.930979486351758, 7.86896544613936, 6.897724613875331, 5.870231016223741, 4.900385148073295, 3.9196121467711817, 2.9706027450196424, 2.016471244113107, 1.0241092870991846, 2.075273227372965, 3.0371371992742042, 4.0714997607078205, 5.056089922128549, 5.936606088304156, 6.860879000503061, 7.867984419460217, 8.906441601274087, 9.939713240939188, 10.898196351960665, 10.734660502807492, 9.770228527895275, 8.802272408539555, 7.870734682865571, 6.907661834979786, 5.9373458568114845, 4.934096972758891, 3.96753886386568, 3.008783270480839, 2.0749280553545417, 3.0218168090864115, 4.004652751830837, 4.978997483273136, 6.018641064491742, 6.949201979514916, 7.819733533005397, 8.831231442654348, 9.822556690294235, 10.827922333232621, 11.855400872014615, 11.807232511821606, 10.787731620888703, 9.732073881944318, 8.887901026697932, 7.950012119121061, 6.92762562912203, 5.8660731088639455, 4.957288855434433, 4.060333786866268, 3.1321826043872387, 3.973631140214981, 4.973716955940623, 5.95382578926791, 6.9185096038537495, 7.8904096482166555, 8.835788726986431, 9.765182325308759, 10.694818635790064, 11.68386387011707, 12.618538298682935, 12.64348253290575, 11.62049137341809, 10.683338060173849, 9.836445831350773, 8.781768675933051, 7.778918858769005, 6.835965681494221, 5.897070374306522, 5.037390076638275, 4.101623493230305, 4.962462586477541, 5.9453843427060855, 6.914488595173032, 7.900225462553353, 8.901267009406421, 9.768970308131905, 10.705847242409432, 11.669332783447135, 12.618357878737102, 13.571469666349781, 13.579523616998816, 12.567881881355424, 11.726303826062976, 10.825017680913263, 9.750209442511883, 8.71647459153484, 7.895195363840935, 6.861151957973526, 5.9649690512415185, 5.058434611773143, 5.908780657229093, 6.958122205032741, 7.8431915664671745, 8.899097541457852, 9.852717151678053, 10.742961938082605, 11.74216556401811, 12.705698912247135, 13.590195913484719, 14.523155313886631], [14.452295274935334, 13.584771601267388, 12.656547267665074, 11.638216830532887, 10.698699448935052, 9.704197143722192, 8.723121846004839, 7.757120354332932, 6.871049179822479, 5.932334427170766, 6.795957571186284, 7.753389633945391, 8.700857879554116, 9.710715351117292, 10.64002099632308, 11.597375331732682, 12.648788786419768, 13.611517269873199, 14.630428042715062, 15.5845236760085, 13.449831947788052, 14.379888390974513, 13.546232684343432, 12.605886874081357, 11.627853662441652, 10.64439646997612, 9.6778982208919, 8.825650641583806, 7.810813129169046, 6.859171503759665, 7.859319263029367, 8.688273102371943, 9.636467450318259, 10.641522449772689, 11.59216858440578, 12.562131955131296, 13.602068423302534, 14.591969693579108, 15.571273111249724, 14.737291836377272, 12.619207237295933, 13.619801868491285, 14.57129023791252, 13.570898827934535, 12.57350688800385, 11.610218043678625, 10.640190228514948, 9.772220156049187, 8.832990514724745, 7.90784329061869, 8.916181532644165, 9.634652994402757, 10.666422174493212, 11.635689815871569, 12.566598202193655, 13.592558725700059, 14.57311797006636, 15.536027470265429, 14.675730213254594, 13.778024050970192, 11.822852206760711, 12.80217932095861, 13.765345174762357, 14.435601567473611, 13.506450362753988, 12.536515221072568, 11.580125273709097, 10.774000785774989, 9.808216135476872, 8.952791267888708, 9.910172339270087, 10.685880784505558, 11.651988357411975, 12.578025853632166, 13.550529281794502, 14.521190287654814, 15.573875273804836, 14.767443797827964, 13.747246130178292, 12.807280269750235, 10.846589730721064, 11.809733306310202, 12.78757238539601, 13.791986391737536, 14.41194420672202, 13.484761644395741, 12.555083754822222, 11.790577556236657, 10.836721928107696, 9.966282623200513, 10.003835905519614, 10.72033490750429, 11.667862780716261, 12.608596642298727, 13.524771700775894, 14.48860856005212, 14.954597727375495, 13.90672987168552, 12.86419534472011, 11.918755096190072, 9.784479999072737, 10.802555029992414, 11.839986893797324, 12.842504614735757, 13.914659382494614, 13.61905624621379, 12.651249516104144, 11.63631624972759, 10.714078951890878, 9.807418575016802, 9.062047813226773, 9.708912068324178, 10.702818988663237, 11.65072359941336, 12.504367542062854, 13.447525588337742, 14.310486158116127, 13.245611918804608, 12.249264577510559, 11.235019200537273, 10.822227243337307, 11.762184102946112, 12.733378117664806, 13.751919746740022, 13.600942137355506, 12.656374179867562, 11.67446086027482, 10.627191418146142, 9.671800389858268, 8.821245106530041, 8.06597158288474, 8.763523454269638, 9.757856874679437, 10.5944786629956, 11.525787183180055, 12.534032682988254, 13.378083509689544, 14.083376950409756, 13.078707452489535, 12.149641623965003, 11.633928139024562, 12.707050005338616, 13.670382713642246, 13.56566325750964, 12.567715974319922, 11.652013476571554, 10.61254102544281, 9.67037846527925, 8.718856579100642, 7.826608817666485, 6.999823483630514, 7.782215448081139, 8.772593509835366, 9.56823913384249, 10.553188514910028, 11.463950307067208, 12.411370226386076, 13.395655816941352, 13.83150502779003, 12.821959061724733, 12.566346751416958, 13.622652318456153, 13.564401379389517, 12.59755045216355, 11.641892315903995, 10.693891355489642, 9.632540901850385, 8.697016997014956, 7.71674832944727, 6.835213738643109, 5.979985196806388, 6.756090583739217, 7.735663729381138, 8.603955875475979, 9.558696530485559, 10.486146416539142, 11.420160227953394, 12.385756494025449, 13.430946936487413, 13.789999789523444, 13.608796060582705, 13.634488191069535, 12.633866289415897, 11.639790095692412, 10.696920765020153, 9.715649756441785, 8.779360632632216, 7.759590230408387, 6.770363788977028, 5.84052595375582, 4.927130245393449, 5.752419489382007, 6.751859659353569, 7.611186166211625, 8.612606504340917, 9.540233473850124, 10.550158586905287, 11.53092026106063, 12.585906909530681, 13.523907880745199, 13.698006868268383, 12.75125927428203, 11.803812604051224, 10.775822467314901, 9.749782629348092, 8.821417163018273, 7.7465908652744275, 6.787306351515171, 5.86904679265242, 4.838947855645358, 3.9391957186773485, 4.7872590016157535, 5.70573022515442, 6.676397757202688, 7.66876968871277, 8.61851343788155, 9.57794837433376, 10.642866464676763, 11.660536475719168, 12.578063215481725, 12.809706871578195, 11.741406720712334, 10.747678695139602, 9.787808377796459, 8.761066282704968, 7.776324666975851, 6.906541554370209, 5.8559347160402275, 4.8030120967617425, 3.853371758669719, 2.913861835671997, 3.8330402061090045, 4.697731539368637, 5.7057242975763085, 6.668270878611253, 7.622895645246604, 8.624405339531508, 9.658769726484087, 10.678066622601929, 11.607255311348522, 11.890974782473444, 10.824938715732824, 9.779193055705418, 8.84508129128304, 7.789439452352417, 6.826096774292727, 5.8559625868242975, 4.861163433040483, 3.8457495832763566, 2.829971428943975, 1.8971695512837368, 2.808554148227141, 3.772513416026084, 4.726722847352743, 5.772723960403997, 6.734971635464188, 7.773525610091683, 8.74963274021479, 9.684050995047885, 10.68189732893733, 11.14341032638753, 10.171846309472404, 9.104218574214283, 8.030762458203679, 7.025918625048391, 6.0044553661766695, 4.938005449395319, 3.8696844812456517, 2.9204493772304763, 1.9796773702922321, 0.9292755290017074, 1.8571204784193474, 2.875180326022856, 3.928508012958031, 4.882695180300504, 5.9093715824989275, 6.826767237099596, 7.887802010455996, 8.832024568392258, 9.856501607840475, 10.229138470720567, 9.184233570672072, 8.14359679811638, 7.070149553653006, 6.103237824791059, 5.065005523362268, 4.10762694728359, 3.077416949022583, 2.112663937209965, 1.0719027254478877, 0.0, 1.0464424477370378, 2.005387920530269, 2.9624331948688463, 3.8982303824529216, 4.855928043059558, 5.89554592610728, 6.955930360578569, 7.905378382868374, 8.838175087691553, 10.948975612138407, 10.002882211799646, 8.940868171587248, 7.9696273393232175, 6.942133741671628, 5.972287873521182, 4.991514872219069, 4.04250547046753, 3.088373969560995, 2.0960120125470723, 1.0618600364269775, 2.023724008328217, 3.055663629936211, 4.007361409724928, 4.864703362856269, 5.788976275055173, 6.7960816940123285, 7.834538875826199, 8.8678105154913, 9.826293626512777, 11.80656322825538, 10.842131253343164, 9.874175133987443, 8.942637408313457, 7.979564560427673, 7.009248582259372, 6.005999698206778, 5.039441589313568, 4.050617507706276, 3.0734474587472653, 2.008403618140424, 2.9912395608848494, 3.9655842923271485, 5.005227873545755, 5.877299254067029, 6.747830807557509, 7.75932871720646, 8.750653964846347, 9.756019607784733, 10.783498146566727, 12.879135237269494, 11.859634346336591, 10.803976607392206, 9.959803752145818, 9.021914844568949, 7.999528354569917, 6.937975834311833, 5.960584185961035, 4.889411343372655, 3.9612601608936258, 2.9602179492689937, 3.9603037649946358, 4.940412598321922, 5.905096412907762, 6.818506922768768, 7.763886001538544, 8.69327959986087, 9.622915910342176, 10.611961144669182, 11.546635573235047, 13.709848626269917, 12.686857466782257, 11.749704153538016, 10.742884363437849, 9.688207208020128, 8.685357390856081, 7.742404213581296, 6.803508906393597, 5.866467633144662, 4.930701049736692, 3.9490493955315533, 4.931971151760098, 5.901075404227044, 6.886812271607365, 7.829364283958534, 8.697067582684017, 9.633944516961543, 10.597430057999247, 11.546455153289214, 12.499566940901893, 14.645889710362983, 13.63424797471959, 12.74758572288985, 11.731456213000339, 10.65664797459896, 9.622913123621917, 8.80163389592801, 7.7675904900606, 6.794046607747906, 5.851230462607302, 4.895367466283105, 5.944709014086754, 6.829778375521187, 7.885684350511865, 8.8124761837462, 9.671059212634717, 10.670262838570222, 11.633796186799247, 12.51829318803683, 13.451252588438743], [13.405852827198297, 12.53832915353035, 11.610104819928036, 10.591774382795851, 9.652257001198016, 8.660848268253039, 7.6797729705356845, 6.713771478863779, 5.924487673722379, 6.8127134955040916, 7.676336639519609, 8.633768702278717, 9.58123694788744, 10.591094419450616, 11.520400064656403, 12.477754400066004, 13.52916785475309, 14.491896338206521, 15.510807111048384, 16.464902744341824, 12.403389500051015, 13.333445943237475, 12.499790236606396, 11.55944442634432, 10.581411214704616, 9.601047594506968, 8.634549345422744, 7.782974677154426, 6.864251623068946, 7.73955057209299, 8.739698331362693, 9.568652170705269, 10.516846518651585, 11.521901518106015, 12.472547652739106, 13.442511023464618, 14.482447491635856, 15.47234876191243, 16.451652179583046, 15.63616931210613, 11.572764789558896, 12.573359420754247, 13.524847790175484, 12.524456380197499, 11.527064440266814, 10.566869168209472, 9.596841353045793, 8.729544191619807, 7.8864290086246465, 8.788222358952016, 9.79656060097749, 10.515032062736083, 11.546801242826538, 12.516068884204895, 13.44697727052698, 14.472937794033381, 15.453497038399682, 16.416406538598753, 15.703855719992609, 14.806149557708206, 10.776409759023673, 11.755736873221572, 12.71890272702532, 13.392252692004456, 12.463101487284833, 11.493166345603413, 10.536776398239942, 9.73132482134561, 8.861654629376773, 9.833170336222034, 10.790551407603413, 10.770430131948228, 11.726010252646475, 12.701749757576925, 13.67425318573926, 14.642846189350788, 15.593799063423772, 15.795569304565978, 14.775371636916306, 13.83540577648825, 9.800147282984026, 10.763290858573164, 11.741129937658972, 12.745543944000499, 13.368595331252866, 12.441412768926586, 11.511734879353067, 10.770545695303312, 9.890160422007597, 10.84666169153384, 10.70944350414446, 9.834883172099913, 10.782411045311882, 11.723144906894348, 12.629022264986343, 13.592859124262569, 14.598314698757113, 14.934855378423535, 13.892320851458125, 12.946880602928086, 8.7380375513357, 9.756112582255376, 10.793544446060286, 11.79606216699872, 12.868216934757577, 13.44125695984094, 12.473450229731295, 11.830231298292585, 10.828328876989412, 10.771530415291538, 9.767655411851619, 8.823460332919801, 9.817367253258858, 10.75497416362381, 11.608618106273303, 12.551776152548191, 13.556912245912839, 14.292054366541647, 13.295707025247598, 12.281461648274313, 9.77578479560027, 10.715741655209074, 11.686935669927768, 12.705477299002984, 13.668470662758327, 13.626612343298461, 12.64469902370572, 11.59742958157704, 10.642038553289167, 9.791483269960938, 8.844468600946195, 7.87807171886526, 8.872405139275058, 9.69872922720605, 10.630037747390505, 11.638283247198704, 12.482334073899993, 13.425160414274849, 14.056816786119715, 13.127750957595183, 10.587485691287524, 11.660607557601578, 12.623940265905208, 13.67594538369373, 13.537954137750821, 12.622251640002453, 11.58277918887371, 10.640616628710148, 9.689094742531541, 8.796846981097383, 7.872960468894379, 6.89676371267676, 7.887141774430987, 8.672489698052939, 9.657439079120477, 10.568200871277657, 11.515620790596525, 12.499906381151801, 13.455152206197422, 13.792197225155633, 11.51990430367992, 12.576209870719115, 13.556224595405363, 13.567788615594448, 12.612130479334894, 11.664129518920541, 10.602779065281284, 9.667255160445855, 8.68698649287817, 7.805451902074008, 6.865812894806136, 5.870638848334838, 6.850211993976759, 7.708206439686428, 8.662947094696008, 9.590396980749592, 10.524410792163843, 11.490007058235898, 12.535197500697862, 13.471475372495076, 12.56235361284567, 13.618429602709421, 13.604104452846796, 12.610028259123311, 11.667158928451052, 10.685887919872684, 9.749598796063115, 8.729828393839286, 7.7406019524079275, 6.810764117186719, 5.812957943393196, 4.866967753977628, 5.856110223564018, 6.715436730422074, 7.716857068551366, 8.644484038060574, 9.654409151115736, 10.635170825271079, 11.619225649683882, 12.477465433008161, 13.43175043133531, 13.721497437712928, 12.774050767482123, 11.7460606307458, 10.72002079277899, 9.791655326449172, 8.716829028705327, 7.75754451494607, 6.839284956083319, 5.809186019076257, 4.909433882108248, 3.9018072662113736, 4.80998078936487, 5.780648321413137, 6.773020252923219, 7.722764002091998, 8.665875211152393, 9.730793301495396, 10.693855215872368, 11.531620767744688, 13.779945035009094, 12.711644884143233, 11.7179168585705, 10.758046541227358, 9.731304446135868, 8.74656283040675, 7.876779717801108, 6.826172879471127, 5.773250260192642, 4.823609922100618, 3.8840999991028964, 2.9475884707046243, 3.8019821035790864, 4.809974861786758, 5.756268046387393, 6.710822482065238, 7.712332176350142, 8.716157994608967, 9.655108937893544, 10.560812863611485, 12.861212945904343, 11.795176879163723, 10.749431219136317, 9.81531945471394, 8.759677615783316, 7.796334937723627, 6.826200750255197, 5.831401596471382, 4.815987746707256, 3.800209592374874, 2.867407714714636, 1.9231024128227603, 2.8767639802365337, 3.8309734115631935, 4.792880642968288, 5.755128318028478, 6.727083162354646, 7.703190292477753, 8.637608547310847, 9.635454881200292, 12.121519660017709, 11.149955643102583, 10.076969133937059, 9.003513017926457, 7.998669184771169, 6.977205925899447, 5.908243612826218, 4.839922644676551, 3.8906875406613755, 2.9499155337231313, 1.8995136924326066, 0.9716687430149668, 1.9294498516833707, 2.966657386549981, 3.8373003699395865, 4.86292913476189, 5.78032478936256, 6.841359562718959, 7.785582120655221, 8.810059160103437, 11.275580918457607, 10.230676018409111, 9.19003924585342, 8.116592001390044, 7.149680272528097, 6.111447971099307, 5.154069395020628, 4.123859396759621, 3.159106384947003, 2.1183451731849257, 1.0464424477370378, 0.0, 0.9589454727932314, 1.9159907471318083, 2.851787934715884, 3.809485595322521, 4.849103478370243, 5.9094879128415325, 6.858935935131337, 7.791732639954516, 11.977101118876421, 11.03100771853766, 9.968993678325262, 8.997752846061232, 7.970259248409643, 7.000413380259197, 6.019640378957083, 5.0706309772055445, 4.002669077693234, 2.993403045034083, 1.9422391047603025, 0.9803751328590634, 2.0092211821991732, 2.96091896198789, 3.8182609151192315, 4.742533827318136, 5.749639246275291, 6.788096428089162, 7.821368067754262, 8.77985117877574, 12.834688734993394, 11.870256760081178, 10.902300640725457, 9.970762915051472, 9.007690067165687, 7.999030239775566, 6.995781355722972, 5.967320619522225, 4.9309965760396, 3.95382652708059, 2.888782686473749, 1.9478906854156959, 2.922235416857995, 3.961878998076602, 4.830856806329991, 5.701388359820472, 6.712886269469422, 7.704211517109308, 8.709577160047695, 9.737055698829689, 13.907260744007509, 12.887759853074606, 11.83210211413022, 10.929790821667938, 9.97165541889029, 8.91205577576234, 7.850503255504256, 6.84096325429436, 5.76979041170598, 4.841639229226951, 3.8405970176023185, 2.916954889525482, 3.897063722852769, 4.8617475374386085, 5.772064475031731, 6.717443553801506, 7.646837152123833, 8.576473462605138, 9.565518696932145, 10.50019312549801, 14.59022769460324, 13.56723653511558, 12.630083221871338, 11.623263431771171, 10.56858627635345, 9.565736459189404, 8.62278328191462, 7.683887974726922, 6.7468467014779865, 5.8110801180700165, 4.829428463864878, 3.9224585838156205, 4.857726528757891, 5.843463396138212, 6.7829218362214965, 7.6506251349469805, 8.587502069224506, 9.55098761026221, 10.500012705552177, 11.453124493164855, 15.526268778696306, 14.514627043052913, 13.627964791223173, 12.611835281333661, 11.537027042932282, 10.50329219195524, 9.682012964261334, 8.647969558393925, 7.67442567608123, 6.731609530940627, 5.77574653461643, 4.99216594003232, 5.786429500052034, 6.842335475042712, 7.766033736009163, 8.624616764897679, 9.623820390833185, 10.587353739062209, 11.471850740299793, 12.404810140701706], [12.446907354405067, 11.57938368073712, 10.651159347134806, 9.632828910002619, 8.693311528404784, 7.7521669240959135, 6.905054122099802, 5.939052630427897, 6.883433146515611, 7.771658968297324, 8.63528211231284, 9.592714175071947, 10.540182420680672, 11.550039892243849, 12.479345537449635, 13.436699872859236, 14.488113327546323, 15.450841810999753, 16.46975258384162, 17.423848217135056, 11.444444027257784, 12.374500470444245, 11.540844763813164, 10.600498953551089, 9.622465741911384, 8.692366250349842, 7.859830496986863, 7.008255828718544, 7.823197095862178, 8.698496044886223, 9.698643804155925, 10.527597643498499, 11.475791991444815, 12.480846990899245, 13.431493125532336, 14.40145649625785, 15.441392964429088, 16.431294234705664, 17.41059765237628, 16.595114784899362, 10.613819316765667, 11.614413947961019, 12.565902317382251, 11.565510907404267, 10.568118967473582, 9.658187824052346, 8.822122504609911, 7.954825343183924, 8.845374481417878, 9.747167831745248, 10.755506073770722, 11.473977535529313, 11.80147388443592, 12.724152362696234, 13.665452707408603, 14.63358957836949, 15.645668198742742, 16.462899333373507, 16.662801192785842, 15.765095030501438, 9.817464286230443, 10.796791400428338, 11.759957254232086, 12.515893971785015, 11.586742767065392, 10.635830427084594, 9.76205754980406, 8.956605972909726, 9.820600102170005, 10.792115809015266, 11.749496880396645, 11.697270502199313, 10.815907701517157, 11.781816324935637, 12.719450989184113, 13.683900716557556, 14.634853590630541, 15.486947967606538, 15.734317109709538, 14.794351249281481, 8.841201810190793, 9.80434538577993, 10.782184464865738, 11.786598471207265, 12.56583728708318, 11.6386547247569, 10.737016030917186, 9.99582684686743, 10.849105894800829, 11.805607164327071, 11.636283874395545, 10.761723542350998, 9.872308494182564, 10.797242243216811, 11.670076792193111, 12.633913651469337, 13.639369225963883, 14.555204402471361, 14.851266324251357, 13.905826075721318, 7.779092078542466, 8.797167109462142, 9.834598973267052, 10.837116694205486, 11.909271461964343, 12.652000627920216, 11.698731381295413, 11.055512449856703, 11.787274349782644, 11.698370785542624, 10.694495782102704, 9.750300703170886, 8.90726470212954, 9.796028690830578, 10.64967263348007, 11.59283067975496, 12.597966773119609, 13.519189963625127, 14.25465249804083, 13.240407121067545, 8.816839322807038, 9.756796182415842, 10.727990197134536, 11.746531826209752, 12.709525189965095, 13.619246952911816, 12.675520037124738, 12.064637281438152, 11.600984026082399, 10.75042874275417, 9.77130897119728, 8.804912089116346, 7.9623025881457385, 8.739783754412818, 9.671092274597273, 10.679337774405473, 11.523388601106763, 12.466214941481619, 13.445822643051427, 14.086696430388415, 9.628540218494292, 10.701662084808346, 11.664994793111976, 12.716999910900498, 13.714947194090215, 13.581197112795685, 12.541724661666942, 11.59956210150338, 10.648040215324773, 9.755792453890615, 8.799800839145467, 7.823604082927847, 6.977039223301668, 7.713544225259707, 8.698493606327247, 9.609255398484427, 10.556675317803295, 11.54096090835857, 12.496206733404192, 13.480570627500555, 10.560958830886689, 11.617264397925883, 12.59727912261213, 13.564130049838099, 13.571075952128126, 12.623074991713773, 11.561724538074516, 10.626200633239087, 9.645931965671402, 8.76439737486724, 7.792653265057223, 6.797479218585925, 5.940109442847441, 6.749260966893197, 7.704001621902778, 8.631451507956362, 9.565465319370613, 10.531061585442668, 11.576252027904632, 12.512529899701844, 11.603408140052437, 12.659484129916189, 13.544741614403016, 13.568973731916543, 12.626104401244284, 11.644833392665916, 10.708544268856347, 9.688773866632518, 8.69954742520116, 7.769709589979951, 6.739798313644283, 5.793808124228715, 4.897164750770788, 5.756491257628843, 6.757911595758135, 7.6855385652673425, 8.695463678322504, 9.676225352477847, 10.66028017689065, 11.51851996021493, 12.472804958542078, 13.419552552528431, 13.732996240275355, 12.705006103539032, 11.678966265572223, 10.750600799242404, 9.675774501498559, 8.716489987739301, 7.798230428876551, 6.7681314918694895, 5.868379354901479, 4.8286476364624615, 3.8510353165716387, 4.821702848619906, 5.814074780129987, 6.763818529298766, 7.706929738359163, 8.771847828702166, 9.734909743079136, 10.572675294951456, 13.404302568819872, 13.670590356936465, 12.676862331363733, 11.71699201402059, 10.6902499189291, 9.705508303199982, 8.83572519059434, 7.785118352264359, 6.732195732985874, 5.78255539489385, 4.8430454718961276, 3.874428840955712, 2.8430366307858552, 3.8510293889935268, 4.797322573594162, 5.751877009272007, 6.75338670355691, 7.757212521815735, 8.696163465100312, 9.601867390818253, 13.820158418697575, 12.754122351956955, 11.70837669192955, 10.774264927507172, 9.718623088576548, 8.755280410516859, 7.785146223048429, 6.790347069264614, 5.774933219500488, 4.759155065168106, 3.8263531875078676, 2.881777775242245, 1.917818507443302, 2.872027938769962, 3.8339351701750566, 4.796182845235247, 5.768137689561414, 6.744244819684521, 7.678663074517616, 8.67650940840706, 13.080465132810941, 12.108901115895815, 11.035914606730291, 9.962458490719687, 8.957614657564399, 7.936151398692679, 6.867189085619449, 5.798868117469782, 4.849633013454607, 3.908861006516363, 2.858459165225838, 1.9306142158081983, 0.9705043788901393, 2.0077119137567494, 2.8783548971463553, 3.9039836619686588, 4.8213793165693275, 5.882414089925727, 6.826636647861989, 7.851113687310205, 12.234526391250839, 11.189621491202344, 10.148984718646652, 9.075537474183276, 8.108625745321328, 7.070393443892538, 6.11301486781386, 5.082804869552852, 4.118051857740234, 3.077290645978157, 2.005387920530269, 0.9589454727932314, 0.0, 0.957045274338577, 1.8928424619226525, 2.8505401225292895, 3.8901580055770113, 4.9505424400483005, 5.8999904623381045, 6.832787167161284, 12.936046591669653, 11.989953191330892, 10.927939151118494, 9.956698318854464, 8.929204721202874, 7.959358853052429, 6.978585851750315, 6.0295764499987765, 4.961614550486466, 3.952348517827315, 2.901184577553534, 1.939320605652295, 1.050275709405942, 2.001973489194659, 2.859315442326, 3.783588354524904, 4.790693773482059, 5.82915095529593, 6.86242259496103, 7.820905705982508, 13.793634207786626, 12.82920223287441, 11.861246113518689, 10.929708387844704, 9.966635539958919, 8.957975712568798, 7.954726828516204, 6.926266092315457, 5.8899420488328325, 4.912771999873822, 3.847728159266981, 2.9068361582089275, 2.0609004536007567, 3.021784325479366, 3.8719113335367594, 4.742442887027241, 5.753940796676192, 6.745266044316078, 7.750631687254465, 8.778110226036459, 14.866206216800741, 13.846705325867838, 12.791047586923453, 11.88873629446117, 10.930600891683522, 9.871001248555572, 8.809448728297488, 7.799908727087592, 6.728735884499212, 5.800584702020183, 4.799542490395551, 3.875900362318714, 3.1223448744168865, 3.976404530514884, 4.8131190022384995, 5.758498081008275, 6.687891679330603, 7.617527989811909, 8.606573224138916, 9.541247652704781, 15.549173167396471, 14.526182007908812, 13.58902869466457, 12.582208904564403, 11.527531749146682, 10.524681931982636, 9.581728754707852, 8.642833447520154, 7.7057921742712185, 6.7700255908632485, 5.78837393665811, 4.881404056608853, 4.083007680322009, 5.002419820663923, 5.823976363428265, 6.691679662153749, 7.628556596431276, 8.59204213746898, 9.541067232758946, 10.494179020371625, 16.485214251489538, 15.473572515846145, 14.586910264016405, 13.570780754126893, 12.495972515725514, 11.462237664748471, 10.640958437054566, 9.606915031187157, 8.633371148874463, 7.690555003733859, 6.734692007409662, 5.9511114128255524, 5.011710651616151, 6.0012918995684235, 6.807088263215933, 7.665671292104448, 8.664874918039954, 9.628408266268979, 10.512905267506563, 11.445864667908475], [11.489862080066489, 10.622338406398542, 9.694114072796228, 8.675783635664041, 7.736266254066207, 6.795121649757336, 6.003067190457229, 6.8007508267731565, 7.819980317021759, 8.7287042426359, 9.592327386651416, 10.549759449410523, 11.497227695019248, 12.507085166582424, 13.436390811788211, 14.393745147197812, 15.445158601884899, 16.40788708533833, 17.42679785818019, 18.380893491473632, 10.487398752919207, 11.417455196105667, 10.583799489474588, 9.643453679212513, 8.665420467572806, 7.7353209760112644, 6.957843565344289, 7.869954025063803, 8.759744266368326, 9.655541319224799, 10.6556890784945, 11.484642917837075, 12.432837265783391, 12.883942023580188, 13.761244538199335, 14.739970751116171, 15.738079958509427, 16.52831932306269, 17.482269496633492, 17.552160059237938, 9.65677404242709, 10.657368673622441, 11.608857043043674, 10.60846563306569, 9.611073693135005, 8.701142549713769, 7.920135572967338, 8.816523539529184, 9.775341776089075, 10.704213106083824, 11.712551348109297, 12.431022809867889, 12.59754573417193, 11.845514575699092, 12.78681492041146, 13.75495179137235, 14.767030411745601, 15.584261546376368, 16.523774003558536, 16.722140304840014, 8.860419011891864, 9.839746126089763, 10.80291197989351, 11.558848697446438, 10.629697492726814, 9.678785152746016, 8.860070618161487, 9.818304169254986, 10.750567396841202, 11.736695698178131, 12.694076769559508, 12.5704440359917, 11.611979551253167, 10.903178537938494, 11.840813202186972, 12.805262929560415, 13.7562158036334, 14.608310180609399, 15.628507848259071, 15.751396523620057, 7.884156535852217, 8.847300111441355, 9.825139190527162, 10.82955319686869, 11.608792012744601, 10.681609450418323, 9.835029099274612, 10.85752504321269, 11.779073189472026, 12.750187053489936, 12.583945588790224, 11.634897076143385, 10.668380343918574, 9.918604456219668, 10.79143900519597, 11.755275864472196, 12.760731438966742, 13.676566615474222, 14.609602104041022, 14.862871350059894, 6.82204680420389, 7.8401218351235675, 8.877553698928477, 9.88007141986691, 10.952226187625767, 11.694955353581639, 10.79674444965284, 11.82913499601415, 12.717241644453841, 12.646032499937302, 11.642157496497383, 10.697962417565565, 9.70333655186555, 8.917390903833436, 9.77103484648293, 10.714192892757818, 11.719328986122468, 12.640552176627988, 13.608472480488258, 14.19745239540612, 7.859794048468461, 8.799750908077266, 9.77094492279596, 10.789486551871176, 11.75247991562652, 12.662201678573238, 11.773533105482164, 12.8248142440366, 12.558029300420973, 11.707474017092744, 10.718970685591959, 9.752573803511025, 8.75837443788175, 7.861145967415677, 8.792454487600132, 9.800699987408333, 10.644750814109623, 11.587577154484478, 12.567184856054286, 13.496250684578818, 8.671494944155716, 9.74461681046977, 10.7079495187734, 11.759954636561922, 12.757901919751639, 13.697638181162437, 12.835452940314173, 12.556607375841956, 11.605085489663347, 10.71283772822919, 9.747462553540146, 8.771265797322526, 7.773111073037679, 6.834906438262566, 7.819855819330106, 8.730617611487286, 9.678037530806154, 10.66232312136143, 11.61756894640705, 12.523525353161979, 9.603913556548113, 10.660219123587307, 11.640233848273555, 12.607084775499523, 13.562742911759077, 13.580120266052349, 12.51876981241309, 11.58324590757766, 10.602977240009976, 9.721442649205814, 8.749698539395801, 7.754524492924503, 6.797123958418491, 5.870623179896056, 6.825363834905637, 7.752813720959221, 8.686827532373472, 9.652423798445527, 10.65578943609261, 11.555484625363269, 10.646362865713861, 11.702438855577613, 12.58769634006444, 13.581772533787925, 13.58314967558286, 12.601878667004492, 11.665589543194923, 10.645819140971092, 9.656592699539734, 8.726754864318526, 7.696843587982861, 6.750853398567292, 5.854210025109364, 4.8778534706317025, 5.879273808760995, 6.806900778270202, 7.77042603661536, 8.751187710770703, 9.703234902552074, 10.561474685876354, 11.515759684203502, 12.462507278189856, 13.483609841337943, 13.662051377877608, 12.636011539910799, 11.70764607358098, 10.632819775837135, 9.673535262077877, 8.755275703215128, 7.725176766208065, 6.8254246292400556, 5.785692910801038, 4.808080590910215, 3.9430650616227654, 4.881053887014118, 5.815888437072774, 6.749884464020586, 7.81480255436359, 8.77786446874056, 9.61563002061288, 12.447257294481297, 13.472359831759551, 13.633907605702309, 12.674037288359166, 11.647295193267675, 10.662553577538558, 9.792770464932916, 8.742163626602935, 7.6892410073244495, 6.739600669232426, 5.800090746234704, 4.831474115294289, 3.800081905124432, 2.972391601996386, 3.840277299255585, 4.79483173493343, 5.796341429218334, 6.800167247477159, 7.7391181907617375, 8.644822116479677, 13.454509632413268, 13.71116762629553, 12.665421966268125, 11.731310201845748, 10.675668362915124, 9.712325684855434, 8.742191497387005, 7.74739234360319, 6.731978493839064, 5.716200339506682, 4.783398461846444, 3.838823049580822, 2.874863781781879, 1.9839066150140272, 2.87688989583648, 3.8391375708966704, 4.811092415222838, 5.7871995453459455, 6.7216178001790405, 7.719464134068485, 14.03751040714952, 13.065946390234394, 11.99295988106887, 10.919503765058266, 9.914659931902978, 8.893196673031257, 7.824234359958027, 6.75591339180836, 5.806678287793184, 4.86590628085494, 3.815504439564415, 2.887659490146775, 1.9275496532287164, 1.0506666394181725, 1.9213096228077782, 2.946938387630082, 3.8643340422307513, 4.9253688155871505, 5.869591373523413, 6.894068412971629, 13.191571665589414, 12.14666676554092, 11.106029992985228, 10.032582748521854, 9.065671019659906, 8.027438718231116, 7.070060142152437, 6.03985014389143, 5.075097132078811, 4.0343359203167335, 2.9624331948688463, 1.9159907471318083, 0.957045274338577, 0.0, 0.9357971875840756, 1.8934948481907126, 2.9331127312384346, 3.993497165709724, 4.942945187999529, 5.875741892822708, 13.893091866008229, 12.946998465669468, 11.88498442545707, 10.91374359319304, 9.88624999554145, 8.916404127391004, 7.935631126088892, 6.986621724337353, 5.918659824825043, 4.909393792165892, 3.8582298518921108, 2.8963658799908716, 2.007320983744519, 1.044928214856082, 1.902270167987423, 2.8265430801863274, 3.8336484991434823, 4.872105680957354, 5.9053773206224545, 6.863860431643932, 14.750679482125202, 13.786247507212986, 12.818291387857265, 11.88675366218328, 10.923680814297494, 9.915020986907374, 8.91177210285478, 7.883311366654032, 6.846987323171409, 5.869817274212399, 4.804773433605558, 3.863881432547504, 3.017945727939334, 2.064739051140789, 2.9148660591981823, 3.785397612688664, 4.796895522337614, 5.7882207699775, 6.793586412915888, 7.82106495169788, 15.823251491139317, 14.803750600206413, 13.748092861262029, 12.845781568799746, 11.887646166022098, 10.828046522894148, 9.766494002636064, 8.756954001426168, 7.685781158837788, 6.757629976358759, 5.756587764734127, 4.832945636657291, 3.984043070762146, 3.019359256176307, 3.856073727899922, 4.8014528066696975, 5.730846404992025, 6.660482715473331, 7.649527949800339, 8.584202378366204, 16.506218441735047, 15.483227282247388, 14.546073969003146, 13.53925417890298, 12.484577023485258, 11.481727206321212, 10.538774029046428, 9.59987872185873, 8.662837448609794, 7.727070865201824, 6.745419210996687, 5.838449330947429, 4.9447058766672685, 4.0453745463253465, 4.866931089089688, 5.734634387815172, 6.671511322092698, 7.634996863130403, 8.584021958420369, 9.537133746033048, 17.442259525828113, 16.43061779018472, 15.54395553835498, 14.52782602846547, 13.45301779006409, 12.419282939087047, 11.598003711393142, 10.563960305525733, 9.590416423213039, 8.647600278072435, 7.691737281748239, 6.908156687164128, 5.873408847961411, 5.044246625229847, 5.850042988877355, 6.70862601776587, 7.707829643701377, 8.671362991930401, 9.555859993167985, 10.488819393569898], [10.554064892482414, 9.686541218814467, 8.758316885212153, 7.739986448079966, 6.8004690664821315, 5.8593244621732605, 6.826685976740864, 7.6937865355552955, 8.713016025803899, 9.651730778455612, 10.528124574235491, 11.485556636994598, 12.433024882603323, 13.4428823541665, 14.053356211768655, 14.944951545328054, 15.853243921510296, 16.663887934047075, 17.66500539015763, 18.503585437623002, 9.551601565335131, 10.481658008521592, 9.648002301890513, 8.707656491628438, 7.72962327998873, 6.799523788427189, 7.781462351627924, 8.762989733845941, 9.652779975150466, 10.578567855044511, 11.578715614314213, 12.42044010542115, 13.368634453367466, 13.772974986728192, 13.045100051737329, 13.98019492192944, 14.893196145787906, 15.683435510341166, 16.63738568391197, 17.484936096891495, 8.720976854843016, 9.721571486038368, 10.673059855459599, 9.672668445481614, 8.67527650555093, 7.765345362129693, 8.743754359250973, 9.709559248311322, 10.668377484871213, 11.627239641903536, 12.63557788392901, 13.366819997451964, 13.486578697319935, 12.734547538847096, 12.070670433949454, 12.949768151360677, 13.92214659902408, 14.739377733654845, 15.678890190837011, 16.525668311484417, 7.924621824307788, 8.903948938505687, 9.867114792309435, 10.623051509862362, 9.693900305142739, 8.74298796516194, 9.683689404445122, 10.711339878037125, 11.64360310562334, 12.62973140696027, 13.587112478341648, 13.459476999139705, 12.501012514401172, 11.792211501086499, 11.0356295621753, 12.000079289548744, 12.91133199091188, 13.763426367887876, 14.783624035537548, 15.554924530264461, 6.948359348268141, 7.911502923857279, 8.889342002943087, 9.893756009284614, 10.672994825160526, 9.745812262834248, 10.658647885558247, 11.697487170377459, 12.65134279850642, 13.624812341032168, 13.472978551938228, 12.52393003929139, 11.557413307066579, 10.807637419367673, 9.986255365184299, 10.950092224460525, 11.91584762624522, 12.831682802752699, 13.762808220781297, 14.603651110721891, 5.886249616619815, 6.904324647539492, 7.941756511344401, 8.944274232282835, 10.016429000041692, 10.759158165997563, 11.620363235936475, 12.652753782297784, 13.589511253488235, 13.535065463085306, 12.531190459645387, 11.586995380713569, 10.592369515013555, 9.80642386698144, 8.965851206471259, 9.909009252746147, 10.874445173400947, 11.795668363906465, 12.761678597228533, 13.546094374088963, 6.923996860884386, 7.86395372049319, 8.835147735211885, 9.853689364287101, 10.816682728042444, 11.726404490989163, 12.5971518917658, 13.648433030320236, 13.493826488005048, 12.640881969353526, 11.608003648739963, 10.641606766659029, 9.647407401029755, 8.750178930563681, 7.98727084758846, 8.955816174686811, 9.799867001388101, 10.742693341762957, 11.720390972794561, 12.576381084362916, 7.73569775657164, 8.808819622885695, 9.772152331189325, 10.824157448977846, 11.822104732167563, 12.761840993578362, 13.659071726597809, 13.492404563426032, 12.540882677247422, 11.64624568048997, 10.63649551668815, 9.66029876047053, 8.662144036185683, 7.723939401410569, 7.013702181620625, 7.885733798765765, 8.833153718084633, 9.815529238101705, 10.770775063147326, 11.587728165577902, 8.668116368964037, 9.724421936003232, 10.70443666068948, 11.671287587915447, 12.626945724175002, 13.609199332266726, 13.454566999997166, 12.519043095161736, 11.538774427594051, 10.65723983678989, 9.685495726979875, 8.665730067208417, 7.686156921566495, 6.75965614304406, 6.019210197196156, 6.9079299082376995, 7.809118831073455, 8.748688424729353, 9.719992248508534, 10.619687437779191, 9.710565678129782, 10.766641667993534, 11.651899152480365, 12.64597534620385, 13.571917275058844, 13.537675854588567, 12.601386730778998, 11.581616328555167, 10.59238988712381, 9.662552051902601, 8.632640775566935, 7.686650586151368, 6.790007212693439, 5.766886433779706, 4.981947868468719, 5.909574837977926, 6.834628849031285, 7.815390523186627, 8.767437714967999, 9.625677498292276, 10.579962496619425, 11.526710090605778, 12.547812653753866, 13.577889780214786, 13.571808727494874, 12.643443261165055, 11.56861696342121, 10.609332449661952, 9.691072890799203, 8.66097395379214, 7.761221816824131, 6.721490098385114, 5.743877778494291, 4.832098024770769, 3.9452566994300415, 4.880091249488698, 5.814087276436511, 6.879005366779515, 7.842067281156484, 8.679832833028803, 11.51146010689722, 12.536562644175474, 13.530290669748206, 13.609834475943241, 12.58309238085175, 11.598350765122634, 10.728567652516992, 9.67796081418701, 8.625038194908525, 7.6753978568165016, 6.73588793381878, 5.767271302878364, 4.735879092708507, 3.8614245651443895, 2.904480111671509, 3.8590345473493546, 4.860544241634258, 5.864370059893082, 6.803321003177661, 7.709024928895601, 12.518712444829191, 13.57276107766038, 13.6012191538522, 12.667107389429823, 11.611465550499199, 10.64812287243951, 9.67798868497108, 8.683189531187265, 7.667775681423139, 6.651997527090757, 5.719195649430519, 4.774620237164898, 3.8106609693659546, 2.872939578162031, 1.941092708252404, 2.9033403833125946, 3.875295227638762, 4.851402357761869, 5.785820612594964, 6.783666946484408, 13.571085126070079, 14.00174357781847, 12.928757068652946, 11.855300952642342, 10.850457119487054, 9.828993860615332, 8.760031547542102, 7.691710579392435, 6.742475475377259, 5.801703468439015, 4.75130162714849, 3.8234566777308507, 2.863346840812792, 1.9396996025661761, 0.9855124352237026, 2.0111412000460063, 2.9285368546466755, 3.989571628003075, 4.9337941859393375, 5.958271225387554, 14.12736885317349, 13.082463953124995, 12.041827180569303, 10.96837993610593, 10.001468207243981, 8.963235905815191, 8.005857329736513, 6.975647331475505, 6.010894319662887, 4.970133107900809, 3.8982303824529216, 2.851787934715884, 1.8928424619226525, 0.9357971875840756, 0.0, 0.957697660606637, 1.997315543654359, 3.0576999781256484, 4.007148000415453, 4.9399447052386325, 14.828889053592306, 13.882795653253545, 12.820781613041147, 11.849540780777117, 10.822047183125527, 9.852201314975082, 8.871428313672968, 7.9224189119214286, 6.854457012409118, 5.845190979749967, 4.794027039476187, 3.8321630675749474, 2.9431181713285945, 1.9807254024401575, 0.9664729804033474, 1.8907458926022516, 2.897851311559407, 3.936308493373278, 4.969580133038379, 5.928063244059857, 15.686476669709279, 14.722044694797063, 13.754088575441342, 12.822550849767357, 11.859478001881572, 10.85081817449145, 9.847569290438855, 8.819108554238108, 7.7827845107554845, 6.805614461796474, 5.740570621189633, 4.79967862013158, 3.953742915523409, 2.9891386121186256, 1.979068871614107, 2.849600425104588, 3.861098334753539, 4.852423582393425, 5.857789225331812, 6.885267764113805, 16.759048678723396, 15.739547787790492, 14.683890048846106, 13.781578756383821, 12.823443353606173, 11.763843710478223, 10.702291190220139, 9.692751189010243, 8.621578346421863, 7.693427163942834, 6.692384952318203, 5.768742824241366, 4.877078779544285, 3.9123949649584455, 2.9202765403158466, 3.865655619085622, 4.79504921740795, 5.724685527889256, 6.713730762216263, 7.648405190782129, 17.442015629319123, 16.419024469831463, 15.481871156587221, 14.475051366487055, 13.420374211069333, 12.417524393905287, 11.474571216630503, 10.535675909442805, 9.59863463619387, 8.6628680527859, 7.681216398580762, 6.774246518531505, 5.8377415854494075, 4.938410255107485, 3.9311339015056124, 4.798837200231096, 5.735714134508623, 6.6991996755463274, 7.648224770836293, 8.601336558448972, 18.37805671341219, 17.366414977768795, 16.479752725939054, 15.463623216049545, 14.388814977648165, 13.355080126671123, 12.533800898977217, 11.499757493109808, 10.526213610797114, 9.58339746565651, 8.627534469332314, 7.801928497369885, 6.76644455674355, 5.867865411513481, 4.91424580129328, 5.772828830181795, 6.7720324561173015, 7.735565804346326, 8.62006280558391, 9.553022205985823], [9.630752737757216, 8.76322906408927, 7.835004730486956, 6.81667429335477, 5.877156911756935, 6.783594355261581, 7.750955869829184, 8.63365042757656, 9.652879917825164, 10.591594670476876, 11.485822234842127, 12.443254297601234, 13.39072254320996, 14.400580014773137, 14.984829665675331, 14.186316001371457, 14.912848980045483, 15.723492992582262, 16.724610448692818, 17.545887777016368, 8.628289410609934, 9.558345853796395, 8.724690147165315, 7.78434433690324, 6.806311125263534, 7.7237936815155095, 8.705732244716245, 9.702853625867206, 10.59264386717173, 11.518431747065776, 12.518579506335477, 13.378137766027786, 14.326332113974102, 14.73067264733483, 13.976573505644005, 13.221559377972843, 13.952801204323093, 14.743040568876353, 15.696990742447156, 16.52723843628486, 7.797664700117818, 8.798259331313169, 9.749747700734401, 8.749356290756417, 7.751964350825733, 8.689615255218014, 9.668024252339293, 10.649423140332587, 11.608241376892478, 12.5671035339248, 13.575441775950274, 14.3245176580586, 14.44427635792657, 13.692245199453733, 13.00214388785613, 12.19113260740408, 12.981751657559267, 13.798982792190031, 14.738495249372198, 15.56797065087778, 6.966924163701153, 7.9462512778990515, 8.9094171317028, 9.699739355137167, 8.770588150417543, 9.667257858250261, 10.607959297533442, 11.637592869557759, 12.583466997644605, 13.569595298981534, 14.526976370362913, 14.41717465974634, 13.458710175007807, 12.749909161693136, 11.967103016081976, 11.241443745592147, 11.970937049447066, 12.823031426423062, 13.843229094072734, 14.597226869657824, 5.990661687661505, 6.9538052632506435, 7.931644342336451, 8.936058348677978, 9.75622154209475, 10.670082155922568, 11.582917778646568, 12.621757063465779, 13.57561269159474, 14.549082234120489, 14.430676212544864, 13.481627699898025, 12.515110967673214, 11.76533507997431, 10.917728819090975, 10.191456680503928, 10.975452684780407, 11.891287861287886, 12.816932576389641, 13.645953450115254, 4.9285519560131785, 5.946626986932856, 6.984058850737766, 7.986576571676199, 9.058731339435056, 10.096123267851675, 11.06392999796132, 12.09632054432263, 13.157486729604189, 14.226941914686252, 13.488888120252023, 12.544693041320205, 11.55006717562019, 10.764121527588077, 9.897324660377935, 9.141632205143168, 9.934050231936133, 10.855273422441652, 11.815802952836878, 12.588396713482325, 5.966299200277748, 6.906256059886553, 7.877450074605248, 8.895991703680464, 9.858985067435807, 10.907670851167367, 11.88958417076011, 12.940865309314546, 13.910471631114726, 13.598579629960161, 12.565701309346599, 11.599304427265665, 10.60510506163639, 9.707876591170317, 8.918744301495137, 8.07112003149836, 8.859472059923288, 9.802298400298143, 10.774515328402906, 11.618683423756279, 6.778000095965003, 7.8511219622790565, 8.814454670582686, 9.866459788371207, 10.864407071560924, 11.804143332971723, 12.843615784100466, 13.871417066108014, 13.49858033785406, 12.603943341096606, 11.594193177294786, 10.617996421077166, 9.619841696792319, 8.681637062017206, 7.945175635527301, 7.0010376555773135, 7.89275877661982, 8.874255909845708, 9.82489941875567, 10.630030504971264, 7.7104187083574, 8.766724275396594, 9.746739000082842, 10.71358992730881, 11.669248063568364, 12.651501671660089, 13.716601378647175, 13.476740755768374, 12.496472088200688, 11.614937497396527, 10.643193387586512, 9.623427727815054, 8.643854582173132, 7.717353803650697, 6.950683651102832, 6.023233765049248, 6.867845502817458, 7.807415096473356, 8.762294587901895, 9.661989777172554, 8.752868017523145, 9.808944007386897, 10.694201491873727, 11.688277685597212, 12.614219614452207, 13.595490623030575, 13.559084391385635, 12.539313989161805, 11.550087547730447, 10.620249712509239, 9.590338436173573, 8.644348246758005, 7.747704873300076, 6.724584094386343, 5.9396455290753565, 5.024878694789474, 5.8933555207752875, 6.87411719493063, 7.80974005436136, 8.667979837685639, 9.622264836012787, 10.569012429999141, 11.590114993147228, 12.620192119608149, 13.646231957574958, 13.601140921771693, 12.526314624027847, 11.56703011026859, 10.64877055140584, 9.618671614398778, 8.718919477430768, 7.679187758991751, 6.701575439100928, 5.789795685377406, 4.902954360036679, 3.9552764628036234, 4.8728139481805135, 5.937732038523517, 6.884369620549847, 7.722135172422165, 10.553762446290582, 11.578864983568836, 12.572593009141569, 13.59169762389437, 13.540790041458388, 12.556048425729271, 11.686265313123629, 10.635658474793647, 9.582735855515162, 8.63309551742314, 7.693585594425417, 6.724968963485002, 5.693576753315145, 4.819122225751027, 3.8621777722781463, 2.93421976066428, 3.9192709133782615, 4.906672399286445, 5.845623342571024, 6.751327268288963, 11.561014784222554, 12.615063417053742, 13.541078648575752, 13.62480505003646, 12.569163211105836, 11.605820533046147, 10.635686345577717, 9.640887191793903, 8.625473342029776, 7.609695187697395, 6.676893310037157, 5.7323178977715346, 4.7683586299725915, 3.830637238768668, 2.898790368859041, 1.9785255966275201, 2.917597567032125, 3.8937046971552323, 4.828122951988327, 5.825969285877771, 12.613387465463441, 13.584951482378568, 13.886454729259583, 12.812998613248979, 11.808154780093691, 10.78669152122197, 9.71772920814874, 8.649408239999072, 7.7001731359838965, 6.759401129045653, 5.708999287755128, 4.781154338337488, 3.8210445014194288, 2.897397263172813, 1.9432100958303395, 1.0534435394393693, 1.9708391940400385, 3.0318739673964386, 3.9760965253327, 5.000573564780916, 13.592943847549888, 14.040161613731632, 12.99952484117594, 11.926077596712567, 10.959165867850619, 9.920933566421828, 8.96355499034315, 7.933344992082143, 6.968591980269524, 5.927830768507446, 4.855928043059558, 3.8094855953225206, 2.8505401225292895, 1.8934948481907126, 0.957697660606637, 0.0, 1.039617883047722, 2.1000023175190115, 3.049450339808816, 3.9822470446319955, 14.573210241427004, 14.840493313860181, 13.778479273647783, 12.807238441383753, 11.779744843732162, 10.809898975581717, 9.829125974279604, 8.880116572528065, 7.812154673015755, 6.802888640356604, 5.751724700082823, 4.789860728181584, 3.9008158319352315, 2.9384230630467947, 1.9241706410099844, 0.9330482319956147, 1.94015365095277, 2.978610832766641, 4.011882472431742, 4.970365583453219, 15.514010783729908, 15.679742355403699, 14.711786236047978, 13.780248510373992, 12.817175662488207, 11.808515835098087, 10.805266951045493, 9.776806214844745, 8.740482171362121, 7.763312122403111, 6.6982682817962695, 5.757376280738217, 4.911440576130046, 3.9290025041398904, 2.9189327636353717, 1.8919027644979511, 2.903400674146902, 3.8947259217867884, 4.900091564725176, 5.927570103507168, 16.561733356527757, 16.697245448397126, 15.641587709452741, 14.739276416990458, 13.78114101421281, 12.72154137108486, 11.659988850826776, 10.65044884961688, 9.5792760070285, 8.651124824549472, 7.650082612924839, 6.726440484848004, 5.81694267156555, 4.85225885697971, 3.8601404323371113, 2.942343464360426, 3.871737062682753, 4.801373373164059, 5.790418607491066, 6.725093036056932, 17.539008052705363, 17.3767221304381, 16.43956881719386, 15.432749027093692, 14.37807187167597, 13.375222054511925, 12.43226887723714, 11.493373570049442, 10.556332296800507, 9.620565713392537, 8.638914059187398, 7.731944179138142, 6.777605477470672, 5.878274147128749, 4.870997793526877, 3.8755250455059, 4.812401979783425, 5.77588752082113, 6.724912616111096, 7.678024403723775, 18.47504913679843, 17.72079051668829, 16.71453837874699, 15.919877243472003, 15.12704335850518, 14.31277778727776, 13.491498559583855, 12.457455153716445, 11.483911271403752, 10.541095126263146, 9.58523212993895, 8.741792389391149, 7.706308448764815, 6.792135304601802, 5.8385156943816, 4.849516675456599, 5.848720301392104, 6.812253649621129, 7.6967506508587125, 8.629710051260625], [8.808196240938656, 7.9406725672707115, 7.0124482336683975, 6.066516804977755, 6.913387611583031, 7.8198250550876764, 8.78718656965528, 9.673268310624284, 10.692497800872886, 11.631212553524598, 12.52544011788985, 13.482872180648958, 14.430340426257684, 15.44019789782086, 15.72383733181007, 14.917876412845223, 13.873231096997761, 14.683875109534544, 15.6849925656451, 16.506269893968646, 7.805732913791375, 8.735789356977834, 7.974532658788299, 7.034186848526225, 7.842541825089629, 8.760024381341605, 9.74196294454234, 10.742471508914932, 11.632261750219453, 12.558049630113498, 13.5581973893832, 14.41775564907551, 15.365949997021826, 15.57924355756891, 14.715581171778744, 13.953119789446609, 12.91318332127537, 13.703422685828635, 14.657372859399437, 15.48762055323714, 6.975108203299259, 7.864387745745515, 8.80701061258829, 8.054641595494902, 8.788195050651828, 9.72584595504411, 10.704254952165389, 11.689041023380312, 12.647859259940203, 13.606721416972523, 14.615059658997996, 15.364135541106323, 15.347342055891113, 14.540816109687814, 13.74115155399087, 12.93014027353882, 11.942133774511545, 12.759364909142313, 13.69887736632448, 14.528352767830059, 5.996335405701945, 6.906633394851328, 7.869799248655076, 8.922201253096667, 9.806818850243637, 10.703488558076357, 11.644189997359538, 12.673823569383854, 13.62308488069233, 14.60921318202926, 15.566594253410639, 15.320240357710883, 14.36177587297235, 13.598480071927217, 12.706110682216716, 11.980451411726886, 10.931319166399344, 11.783413543375344, 12.803611211025016, 13.557608986610102, 4.951043804613783, 5.91418738020292, 6.8920264592887275, 7.8964404656302545, 8.827135599329601, 9.754318161655881, 10.6839960512294, 11.722835336048611, 12.676690964177572, 13.65016050670332, 14.714861917317492, 14.384693397862568, 13.418176665637757, 12.61390599020839, 11.656736485225714, 10.930464346638667, 9.935834801732685, 10.851669978240167, 11.77731469334192, 12.606335567067532, 3.8889340729654562, 4.907009103885133, 5.944440967690042, 6.9469586886284755, 8.019113456387332, 9.056505384803952, 10.024312114913597, 11.056702661274906, 12.117868846556465, 13.187324031638529, 14.191199035078448, 13.447758739284748, 12.453132873584734, 11.612692437822158, 10.636332326512674, 9.880639871277907, 8.894432348888412, 9.815655539393934, 10.776185069789156, 11.548778830434603, 4.926681317230027, 5.866638176838831, 6.837832191557526, 7.856373820632742, 8.819367184388085, 9.868052968119645, 10.849966287712387, 11.901247426266824, 12.870853748067004, 13.895064920194528, 13.468767007311142, 12.502370125230208, 11.508170759600933, 10.589060487814331, 9.657751967629876, 8.8101276976331, 7.819854176875567, 8.762680517250423, 9.734897445355184, 10.579065540708557, 5.738382212917281, 6.811504079231335, 7.774836787534964, 8.826841905323485, 9.824789188513202, 10.764525449924001, 11.803997901052744, 12.831799183060292, 13.790083251496362, 13.507009039061149, 12.497258875259329, 11.521062119041709, 10.522907394756862, 9.584702759981749, 8.68418330166204, 7.740045321712054, 6.853140893572098, 7.834638026797986, 8.785281535707949, 9.590412621923543, 6.670800825309678, 7.7271063923488725, 8.70712111703512, 9.673972044261088, 10.629630180520643, 11.611883788612367, 12.676983495599453, 13.612507400434882, 13.53608997124841, 12.583368245851274, 11.56545442901715, 10.526493425779597, 9.546920280137675, 8.62041950161524, 7.689691317237571, 6.7622414311839885, 5.828227619769736, 6.767797213425634, 7.722676704854174, 8.622371894124832, 7.713250134475424, 8.769326124339175, 9.654583608826005, 10.64865980254949, 11.574601731404485, 12.555872739982853, 13.492161863792422, 13.578931872209527, 12.589705430778169, 11.65986759555696, 10.626942364781668, 9.6809521753661, 8.697647505552291, 7.627649792350886, 6.791289720291935, 5.863662750782728, 4.853737637727566, 5.834499311882908, 6.770122171313639, 7.628361954637917, 8.582646952965066, 9.52939454695142, 10.550497110099506, 11.580574236560427, 12.606614074527236, 13.534979540857055, 13.565932507075573, 12.606647993316315, 11.688388434453564, 10.6582894974465, 9.75853736047849, 8.715791687599847, 7.738179367709025, 6.692861383341949, 5.7737169344194905, 4.823973185250711, 3.8331960651327917, 4.898114155475795, 5.844751737502125, 6.682517289374443, 9.51414456324286, 10.539247100521115, 11.532975126093847, 12.552079740846649, 13.57882183593814, 13.595666308776995, 12.725883196171353, 11.675276357841371, 10.622353738562886, 9.672713400470862, 8.73320347747314, 7.761572892093098, 6.730180681923241, 5.72218792371557, 4.759641342680625, 3.805016576045274, 2.8796530303305397, 3.8670545162387233, 4.806005459523302, 5.7117093852412415, 10.521396901174832, 11.57544553400602, 12.50146076552803, 13.435572529950408, 13.60878109415356, 12.64543841609387, 11.675304228625441, 10.680505074841626, 9.6650912250775, 8.649313070745118, 7.716511193084879, 6.771935780819257, 5.807976513020314, 4.857571200119958, 3.8115700870687044, 2.849322412008514, 1.8779796839844032, 2.8540868141075104, 3.788505068940605, 4.786351402830049, 11.57376958241572, 12.545333599330846, 13.486619400228724, 13.8526164962967, 12.847772663141413, 11.826309404269692, 10.757347091196461, 9.689026123046794, 8.73979101903162, 7.799019012093375, 6.74861717080285, 5.82077222138521, 4.860662384467151, 3.930349158824865, 2.9761619914823916, 1.924240354820363, 0.9312213109923165, 1.9922560843487163, 2.9364786422849782, 3.9609556817331946, 12.553325964502166, 13.532946338131175, 14.039142724223662, 12.965695479760289, 11.99878375089834, 10.96055144946955, 10.003172873390872, 8.972962875129864, 8.008209863317246, 6.967448651555168, 5.895545926107281, 4.849103478370243, 3.8901580055770117, 2.9331127312384346, 1.997315543654359, 1.039617883047722, 0.0, 1.0603844344712894, 2.009832456761094, 2.9426291615842737, 13.533592358379282, 14.479685758718043, 14.818097156695506, 13.846856324431476, 12.819362726779886, 11.84951685862944, 10.868743857327328, 9.919734455575789, 8.851772556063478, 7.842506523404327, 6.791342583130547, 5.829478611229307, 4.940433714982953, 3.9780409460945165, 2.9637885240577067, 1.9726661150433369, 1.0142879794136441, 2.0527451612275156, 2.97226458938402, 3.9307477004054974, 14.474392900682187, 15.438824875594403, 15.751404119095701, 14.819866393421716, 13.85679354553593, 12.84813371814581, 11.844884834093216, 10.816424097892469, 9.780100054409845, 8.802930005450834, 7.737886164843993, 6.796994163785939, 5.9510584591777675, 4.968620387187613, 3.958550646683094, 2.9315206475456734, 2.049893871622775, 3.041219119262661, 4.035627814696155, 4.96914104530073, 15.522115473480035, 16.49004406322784, 16.681205592500465, 15.778894300038184, 14.820758897260536, 13.761159254132584, 12.6996067338745, 11.690066732664604, 10.618893890076224, 9.690742707597195, 8.689700495972563, 7.766058367895726, 6.856560554613272, 5.891876740027432, 4.899758315384833, 3.9785741641865218, 3.0491805658641944, 3.9788168763455, 4.967862110672507, 5.902536539238373, 16.49939016965764, 17.500823152093403, 16.7178862615884, 15.941438840347317, 15.417689754723694, 14.414839937559648, 13.471886760284864, 12.532991453097166, 11.59595017984823, 10.66018359644026, 9.678531942235121, 8.771562062185865, 7.817223360518394, 6.917892030176471, 5.910615676574599, 4.9117557453319955, 3.989845482964867, 4.953331024002572, 5.902356119292538, 6.855467906905217, 17.435431253750707, 16.68117263364057, 15.674920495699272, 14.880259360424281, 15.858603769978945, 15.352395670325484, 14.531116442631578, 13.497073036764169, 12.523529154451476, 11.58071300931087, 10.624850012986673, 9.781410272438873, 8.745926331812537, 7.828366004427897, 6.874746394207696, 5.885747375282694, 5.026163804573546, 5.98969715280257, 6.874194154040154, 7.807153554442067], [7.863956291426984, 6.996432617759038, 6.068208284156724, 6.970910749536599, 7.817781556141876, 8.724218999646522, 9.691580514214126, 10.601857182754593, 11.621086673003195, 12.559801425654907, 13.488540900178855, 14.445972962937962, 15.490724860728973, 16.500582332292147, 16.69888277206926, 15.892921853104411, 14.84827653725695, 13.967044836271292, 14.757119530734917, 15.52910107398162, 6.861492964279702, 7.737034904745497, 7.104514104816704, 7.93858079308507, 8.746935769648475, 9.664418325900451, 10.646356889101186, 11.67106038104524, 12.560850622349761, 13.486638502243807, 14.486786261513508, 15.380856431364514, 16.32905077931083, 16.554288997828095, 15.690626612037933, 14.928165229705797, 13.88822876153456, 12.986592412565383, 13.729499824489254, 14.510451733250113, 5.948270079871216, 6.804003311274227, 7.746626178117001, 8.747017588094986, 9.692588995210674, 10.630239899602955, 11.538505143065384, 12.582616287385537, 13.541434523945428, 14.535310289102831, 15.543648531128305, 16.32723632339533, 16.346399966782215, 15.515861549947001, 14.716196994250058, 13.90518571379801, 12.917179214770734, 12.042534635879061, 12.771004331414296, 13.551183947843032, 4.935950971230655, 5.84624896038004, 6.809414814183787, 7.861816818625377, 8.75238455653552, 9.696758024856898, 10.598570097871235, 11.628203669895552, 12.612011640578446, 13.598139941915376, 14.555521013296755, 15.583161806412127, 15.36083378386345, 14.573525512186404, 13.681156122475905, 12.955496851986076, 11.906364606658533, 11.066583270112092, 11.842520248337994, 12.580440166623076, 3.890659370142493, 4.853802945731632, 5.831642024817439, 6.836056031158966, 7.766751164858312, 8.693933727184591, 9.62361161675811, 10.662450901577321, 11.616306529706282, 12.58977607223203, 13.654477482846202, 14.657760676334856, 14.417234576528857, 13.588951430467578, 12.631781925484903, 11.905509786897857, 10.910880241991874, 10.134839704976915, 10.800145873354893, 11.629166747080506, 2.8285496384941666, 3.8466246694138437, 4.884056533218754, 5.886574254157187, 6.958729021916044, 7.996120950332664, 8.963927680442309, 9.996318226803618, 11.057484412085177, 12.12693959716724, 13.13081460060716, 14.075009679538978, 13.452190784475833, 12.587737878081347, 11.611377766771863, 10.855685311537098, 9.8694777891476, 9.098825266130682, 9.79901624980213, 10.571610010447577, 3.866296882758737, 4.8062537423675415, 5.777447757086237, 6.7959893861614535, 7.758982749916797, 8.807668533648357, 9.7895818532411, 10.840862991795536, 11.810469313595716, 12.83468048572324, 13.906344300719125, 13.501428036121307, 12.507228670492033, 11.56410592807352, 10.632797407889065, 9.78517313789229, 8.794899617134755, 8.045850243987173, 8.757728625368157, 9.60189672072153, 4.761213392930254, 5.80333392076475, 6.76666662906838, 7.804949339283659, 8.792208912952383, 9.731945174363181, 10.771417625491924, 11.797675944662428, 12.755960013098498, 13.816183753564092, 13.496316786150429, 12.520120029932809, 11.521965305647962, 10.583760670872849, 9.659228741921229, 8.715090761971243, 7.828186333831287, 7.007050318948721, 7.808112715720922, 8.613243801936516, 5.693632005322652, 6.749937572361846, 7.729952297048094, 8.696803224274062, 9.652461360533616, 10.63471496862534, 11.699814675612426, 12.635338580447856, 13.615607248015541, 13.582426156742374, 12.56451233990825, 11.525551336670697, 10.545978191028775, 9.61947741250634, 8.66473675749676, 7.737286871443177, 6.803273060028925, 5.9402095055763695, 6.7455078848671475, 7.6452030741378065, 6.7360813144883975, 7.792157304352148, 8.677414788838979, 9.671490982562464, 10.59743291141746, 11.578703919995828, 12.514993043805397, 13.546094492611482, 13.650089865249459, 12.72025203002825, 11.678133953611026, 10.732143764195458, 9.745920428399103, 8.675922715197698, 7.766335160551123, 6.838708191041916, 5.8287830779867535, 5.006911604033643, 5.792953351326612, 6.651193134650891, 7.605478132978039, 8.552225726964393, 9.57332829011248, 10.6034054165734, 11.62944525454021, 12.557810720870028, 13.547762811163185, 13.667032427787603, 12.748772868924855, 11.71867393191779, 10.817437210986753, 9.766983276429205, 8.789370956538383, 7.74113430618876, 6.7487623746786785, 5.799018625509899, 4.80824150539198, 3.946426607576556, 4.867582917515098, 5.705348469387417, 8.536975743255834, 9.562078280534088, 10.55580630610682, 11.574910920859622, 12.601653015951113, 13.611696625902441, 13.786267630642643, 12.735660792312661, 11.682738173034176, 10.733097834942152, 9.793587911944428, 8.812764480922455, 7.781372270752598, 6.773379512544927, 5.8108329315099825, 4.856208164874631, 3.8546984705897276, 2.889885696251697, 3.8288366395362754, 4.734540565254215, 9.544228081187805, 10.598276714018994, 11.524291945541004, 12.458403709963381, 13.514045548894005, 13.705822850565161, 12.735688663096731, 11.740889509312916, 10.72547565954879, 9.709697505216408, 8.776895627556168, 7.830284220326664, 6.866324952527721, 5.912115521201062, 4.866114408149808, 3.9038667330896173, 2.853025124243591, 1.8769179941204839, 2.8113362489535785, 3.8091825828430226, 10.596600762428693, 11.56816477934382, 12.509450580241698, 13.39100231873537, 13.908157097612701, 12.88669383874098, 11.81773152566775, 10.749410557518082, 9.800175453502908, 8.859403446564663, 7.809001605274139, 6.881156655856499, 5.921046818938439, 4.990733593296154, 4.036546425953681, 2.984624789291652, 1.9916057454636058, 0.9318716498774269, 1.8760942078136886, 2.900571247261905, 11.57615714451514, 12.55577751814415, 13.539724234118637, 14.026079914231577, 13.059168185369629, 12.020935883940838, 11.06355730786216, 10.033347309601153, 9.068594297788534, 8.027833086026456, 6.955930360578569, 5.909487912841532, 4.9505424400483005, 3.993497165709724, 3.0576999781256484, 2.1000023175190115, 1.0603844344712894, 0.0, 0.9494480222898045, 1.882244727112984, 12.556423538392256, 13.502516938731016, 14.564530978943415, 14.907240758902766, 13.879747161251176, 12.90990129310073, 11.929128291798618, 10.980118890047079, 9.912156990534768, 8.902890957875616, 7.851727017601835, 6.889863045700595, 6.0008181494542425, 5.038425380565806, 4.024172958528996, 3.033050549514626, 2.0530806799847037, 1.0146234981708324, 1.9118801549127302, 2.8703632659342078, 13.49722408069516, 14.461656055607376, 15.429612174963097, 15.880250827893006, 14.91717798000722, 13.9085181526171, 12.905269268564506, 11.876808532363759, 10.840484488881135, 9.863314439922124, 8.798270599315282, 7.8573785982572275, 7.011442893649058, 6.029004821658902, 5.018935081154384, 3.9919050820169626, 3.003312307390166, 2.0119870597502794, 2.9752433802248652, 3.9087566108294403, 14.54494665349301, 15.512875243240813, 16.359413648367862, 16.83927873450947, 15.881143331731824, 14.821543688603873, 13.759991168345788, 12.750451167135893, 11.679278324547512, 10.751127142068484, 9.750084930443851, 8.765258260070867, 7.785149426743581, 6.820465612157741, 5.828347187515142, 4.8829681087453665, 3.953574510423039, 3.0239381999417336, 4.01298343426874, 4.922315771765422, 15.522221349670616, 16.523654332106375, 16.00105598832515, 16.916484280606507, 16.478074189194984, 15.475224372030937, 14.532271194756152, 13.593375887568454, 12.656334614319519, 11.720568030911549, 10.716342806157531, 9.733421049928987, 8.745812232648703, 7.84648090230678, 6.8355745113634026, 5.816149689890841, 4.894239427523711, 4.0090910744908985, 4.9581161697808644, 5.911227957393543, 16.458262433763682, 15.753299598730388, 14.95809022243602, 15.85530480068347, 16.833649210238132, 16.412780104796774, 15.591500877102867, 14.557457471235457, 13.583913588922764, 12.61852387323328, 11.662660876909083, 10.709999144569181, 9.674515203942846, 8.732759948986743, 7.779140338766542, 6.790141319841539, 5.93055774913239, 5.045457203290897, 5.929954204528481, 6.862913604930394], [6.9587425235629, 6.130552229835004, 7.017656306446528, 7.920358771826404, 8.76722957843168, 9.673667021936327, 10.64102853650393, 11.551305205044397, 12.570534695292999, 13.509249447944711, 14.437988922468659, 15.395420985227766, 16.440172883018775, 17.45003035458195, 17.64833079435906, 16.7677762593415, 15.71636280465441, 14.75363432120098, 13.875726862947204, 14.625525765258889, 5.956279196415617, 6.787586882455692, 7.76022746194803, 8.700573272210104, 9.682955483951991, 10.613866348190255, 11.551349128398627, 12.579737779561112, 13.510298644639565, 14.43608652453361, 15.436234283803312, 16.330304453654318, 17.278498801600634, 17.5037370201179, 16.640074634327735, 15.844020119009826, 14.804083650838589, 13.773181897495071, 12.848107156701541, 13.606876424527382, 4.998822057581412, 5.854555288984422, 6.797178155827195, 7.797569565805179, 8.794961505735863, 9.72495260559934, 10.589057120775578, 11.633168265095732, 12.591986501655622, 13.632674053853364, 14.672323014064995, 15.684941574225121, 16.603994776523216, 16.465309572236805, 15.665645016539862, 14.854633736087811, 13.866627237060538, 12.82912412080875, 11.889611663626583, 12.647608639120302, 3.986502948940851, 4.896800938090235, 5.859966791893982, 6.912368796335572, 7.802936534245713, 8.747310002567092, 9.64912207558143, 10.678755647605746, 11.66256361828864, 12.64869191962557, 13.606072991006947, 14.63371378412232, 15.618428593604454, 15.522973534476208, 14.630604144765709, 13.904944874275877, 12.855812628948337, 11.881728927289876, 10.961127580550281, 11.676864857900345, 2.941211347852689, 3.904354923441826, 4.882194002527634, 5.88660800886916, 6.817303142568506, 7.744485704894785, 8.674163594468304, 9.713002879287515, 10.666858507416476, 11.640328049942225, 12.705029460556396, 13.70831265404505, 14.674829386269861, 14.538399452757382, 13.581229947774707, 12.854957809187658, 11.860328264281678, 10.949985362154699, 9.91875320556718, 10.725591438357775, 1.8791016162043621, 2.8971766471240388, 3.9346085109289484, 4.937126231867381, 6.009280999626238, 7.046672928042858, 8.014479658152503, 9.046870204513812, 10.108036389795371, 11.177491574877434, 12.181366578317354, 13.125561657249172, 14.136935879441488, 13.537185900371151, 12.560825789061667, 11.805133333826898, 10.818925811437405, 9.913970923308465, 8.917623582014416, 9.668034701724846, 2.9168488604689324, 3.8568057200777366, 4.827999734796432, 5.846541363871648, 6.809534727626991, 7.85822051135855, 8.840133830951293, 9.89141496950573, 10.86102129130591, 11.885232463433436, 12.956896278429321, 13.923293160510255, 13.456676692781837, 12.513553950363324, 11.582245430178869, 10.734621160182092, 9.744347639424559, 8.881005455500665, 7.876335957580444, 8.6983214119988, 3.847477492449293, 4.853885898474944, 5.8172186067785745, 6.855501316993853, 7.842760890662576, 8.782497152073374, 9.821969603202117, 10.848227922372622, 11.806511990808692, 12.866735731274286, 13.876485895076106, 13.469568052222613, 12.471413327937766, 11.533208693162653, 10.608676764211033, 9.664538784261046, 8.77763435612109, 7.881965872978831, 6.926720047933209, 7.709668493213784, 4.77989610484169, 5.807972446229123, 6.785281403657031, 7.752132330882999, 8.707790467142553, 9.690044075234278, 10.755143782221364, 11.690667687056793, 12.670936354624478, 13.694284783321738, 13.513960362198054, 12.4749993589605, 11.495426213318579, 10.568925434796144, 9.614184779786564, 8.68673489373298, 7.752721082318729, 6.8896575278661745, 5.864115217079434, 6.741627765415074, 5.832506005765665, 6.866551761600471, 7.732743895447916, 8.726820089171401, 9.652762018026397, 10.634033026604765, 11.570322150414334, 12.60142359922042, 13.590650040651777, 13.669700052318055, 12.627581975900831, 11.681591786485264, 10.695368450688907, 9.625370737487502, 8.715783182840928, 7.788156213331721, 6.7782311002765585, 5.956359626323448, 4.911560683538899, 5.747617825928158, 6.701902824255306, 7.648650418241659, 8.669752981389745, 9.699830107850666, 10.69593971714346, 11.624305183473279, 12.603091917772122, 13.56237643153138, 13.698220891214659, 12.668121954207594, 11.76688523327656, 10.71643129871901, 9.738818978828188, 8.690582328478564, 7.698210396968483, 6.748466647799704, 5.7576895276817845, 4.895874629866361, 3.986190249727385, 4.801773160664684, 7.633400434533101, 8.658502971811354, 9.652230997384086, 10.671335612136888, 11.698077707228379, 12.678191088505692, 13.605080210185156, 13.685108814602465, 12.63218619532398, 11.682545857231956, 10.743035934234232, 9.762212503212261, 8.730820293042404, 7.722827534834732, 6.760280953799787, 5.805656187164436, 4.804146492879532, 3.8393337185415013, 2.9474439717485623, 3.830965256531482, 8.640652772465073, 9.694701405296259, 10.620716636818269, 11.554828401240647, 12.61047024017127, 13.57381291823096, 13.685136685386535, 12.69033753160272, 11.674923681838594, 10.659145527506212, 9.726343649845973, 8.77973224261647, 7.815772974817526, 6.861563543490867, 5.815562430439613, 4.853314755379422, 3.8024731465333956, 2.8263660164102884, 1.9299435811658656, 2.90560727412029, 9.69302545370596, 10.664589470621086, 11.605875271518963, 12.487427010012636, 13.492270843167924, 13.836141861030784, 12.767179547957554, 11.698858579807887, 10.749623475792712, 9.808851468854467, 8.758449627563943, 7.830604678146304, 6.870494841228245, 5.940181615585959, 4.985994448243486, 3.934072811581457, 2.9410537677534108, 1.8813196721672314, 0.9266461855238841, 1.9511232249721004, 10.672581835792407, 11.652202209421418, 12.636148925395904, 13.558920645236935, 14.008616207659434, 12.970383906230644, 12.013005330151966, 10.982795331890959, 10.01804232007834, 8.977281108316262, 7.905378382868374, 6.858935935131337, 5.899990462338105, 4.942945187999529, 4.007148000415453, 3.049450339808816, 2.009832456761094, 0.9494480222898045, 0.0, 0.9327967048231796, 11.652848229669523, 12.598941630008284, 13.660955670220682, 14.51758459373701, 14.82919518354098, 13.859349315390535, 12.878576314088422, 11.929566912336883, 10.861605012824572, 9.85233898016542, 8.801175039891639, 7.8393110679904, 6.9502661717440475, 5.987873402855611, 4.973620980818801, 3.9824985718044306, 3.002528702274508, 1.964071520460637, 0.9624321326229257, 1.9209152436444032, 12.593648771972427, 13.558080746884643, 14.526036866240364, 15.48137978385112, 15.866626002297025, 14.857966174906904, 13.85471729085431, 12.826256554653563, 11.789932511170939, 10.812762462211928, 9.747718621605086, 8.806826620547033, 7.960890915938862, 6.978452843948706, 5.968383103444188, 4.941353104306767, 3.95276032967997, 2.961435082040084, 2.0257953579350607, 2.9593085885396357, 13.641371344770278, 14.60929993451808, 15.455838339645128, 16.467490654010383, 16.830591354021628, 15.770991710893677, 14.709439190635592, 13.699899189425697, 12.628726346837317, 11.700575164358288, 10.699532952733655, 9.71470628236067, 8.734597449033384, 7.769913634447545, 6.777795209804946, 5.8324161310351705, 4.903022532712844, 3.9733862222315377, 3.075873148667685, 3.9728677494756175, 14.618646040947883, 15.620079023383642, 16.40710251787466, 17.413922307974826, 17.42752221148479, 16.42467239432074, 15.481719217045956, 14.542823909858258, 13.605782636609323, 12.670016053201353, 11.665790828447335, 10.682869072218791, 9.695260254938507, 8.795928924596584, 7.785022533653207, 6.765597712180645, 5.843687449813516, 4.958539096780703, 4.0922357818568305, 5.006014189529459, 15.55468712504095, 14.871906930942675, 15.744679707365709, 16.723391068080932, 17.70850361647522, 17.362228127086578, 16.54094889939267, 15.506905493525261, 14.533361611212568, 13.567971895523083, 12.612108899198887, 11.659447166858985, 10.62396322623265, 9.682207971276547, 8.728588361056346, 7.739589342131343, 6.880005771422195, 5.994905225580701, 5.064073816604447, 5.9576998370663095], [6.068045552005399, 6.799345987182425, 7.790428364948596, 8.735446610935394, 9.674963992533229, 10.606463726759507, 11.573328798462509, 12.48410190986758, 13.503331400116181, 14.442046152767894, 15.370785627291841, 16.32821769005095, 17.372969587841958, 18.382827059405134, 18.521610033660366, 17.529927741208034, 16.478514286520948, 15.515785803067518, 14.63787834481374, 13.731974109347306, 5.065582224858117, 5.854790177632512, 6.82743075712485, 7.767776567386924, 8.750158779128812, 9.753129819860828, 10.618552423575448, 11.646941074737933, 12.661778587152694, 13.666612383592014, 14.666760142861715, 15.659399605612382, 16.6075939535587, 17.612648953013128, 17.572871339150915, 16.606171600876362, 15.566235132705124, 14.535333379361608, 13.610258638568078, 12.713324768615799, 4.066025352758233, 4.921758584161242, 5.864381451004016, 6.864772860982, 7.8621648009126845, 8.792155900776162, 9.6562604159524, 10.700371560272552, 11.659189796832443, 12.699877349030185, 13.739526309241816, 14.752144869401942, 15.671198071700038, 16.603707431472323, 16.59844172136304, 15.7184172878726, 14.65496038760674, 13.591275602675287, 12.65176314549312, 11.754056983208718, 3.053706244117671, 3.964004233267055, 4.927170087070803, 5.979572091512393, 6.870139829422534, 7.814513297743914, 8.71632537075825, 9.745958942782567, 10.729766913465461, 11.71589521480239, 12.673276286183768, 13.70091707929914, 14.685631888781275, 15.661371393711725, 15.563400849588888, 14.806146546940692, 13.75346156079067, 12.739228554321178, 11.723279062416818, 10.783313201988761, 2.0084146430295093, 2.971558218618647, 3.949397297704455, 4.953811304045981, 5.884506437745327, 6.811689000071606, 7.741366889645125, 8.780206174464336, 9.734061802593297, 10.707531345119046, 11.772232755733217, 12.775515949221871, 13.742032681446682, 14.682766543029148, 14.514026652597886, 13.787754514010837, 12.793124969104857, 11.807484989186001, 10.776252832598484, 9.832039782446191, 0.9463049113811827, 1.9643799423008597, 3.0018118061057693, 4.004329527044202, 5.076484294803059, 6.113876223219679, 7.081682953329323, 8.114073499690633, 9.175239684972192, 10.244694870054255, 11.248569873494175, 12.192764952425993, 13.204139174618309, 14.188736710856798, 13.493622493884846, 12.737930038650077, 11.751722516260584, 10.77147055033977, 9.77512320904572, 8.774483045813263, 1.990497054859922, 2.9283761559674173, 3.899570170686112, 4.918111799761329, 5.881105163516672, 6.9297909472482315, 7.9117042668409745, 8.962985405395411, 9.932591727195591, 10.956802899323115, 12.028466714319, 12.994863596399934, 14.016516709851338, 13.446350655186503, 12.515042135002048, 11.667417865005271, 10.677144344247738, 9.738505082531969, 8.733835584611748, 7.804769756087217, 2.9211256868402824, 3.9254563343646254, 4.888789042668256, 5.927071752883534, 6.914331326552257, 7.854067587963055, 8.893540039091798, 9.919798358262303, 10.878082426698374, 11.938306167163967, 12.948056330965787, 13.924253087183407, 13.404210032760945, 12.466005397985832, 11.541473469034212, 10.597335489084225, 9.71043106094427, 8.780908628413119, 7.825662803367498, 6.816116837302203, 3.8535442992326794, 4.8795428821188045, 5.856851839546712, 6.82370276677268, 7.779360903032234, 8.761614511123959, 9.826714218111045, 10.762238122946474, 11.74250679051416, 12.765855219211417, 13.783769036045541, 13.40779606378368, 12.428222918141758, 11.501722139619323, 10.546981484609743, 9.61953159855616, 8.685517787141908, 7.822454232689354, 6.787556963859487, 5.848076109503492, 4.90728623506701, 5.938122197490152, 6.804314331337597, 7.798390525061081, 8.724332453916077, 9.705603462494444, 10.641892586304014, 11.672994035110099, 12.662220476541457, 13.592058311762665, 13.56037868072401, 12.614388491308443, 11.62816515551209, 10.558167442310683, 9.648579887664107, 8.7209529181549, 7.711027805099738, 6.889156331146627, 5.835002430318951, 4.854066170016576, 5.808351168343725, 6.7550987623300776, 7.776201325478165, 8.806278451939086, 9.76751015303314, 10.695875619362958, 11.674662353661802, 12.63394686742106, 13.652945345242696, 13.600918659030773, 12.699681938099738, 11.64922800354219, 10.671615683651368, 9.623379033301745, 8.631007101791663, 7.681263352622883, 6.690486232504964, 5.82867133468954, 4.9096319965074375, 3.9082215047531026, 6.7398487786215195, 7.764951315899772, 8.758679341472504, 9.777783956225306, 10.790525646600923, 11.749761524395371, 12.676650646074835, 13.565318502896002, 13.56498290014716, 12.615342562055135, 11.675832639057411, 10.69500920803544, 9.663616997865583, 8.65562423965791, 7.6930776586229666, 6.738452891987615, 5.736943197702711, 4.772130423364681, 3.8802406765717423, 2.9374136006199008, 7.747101116553491, 8.801149749384678, 9.727164980906688, 10.661276745329065, 11.71691858425969, 12.680261262319378, 13.650395449787808, 13.6231342364259, 12.607720386661773, 11.59194223232939, 10.659140354669152, 9.71252894743965, 8.748569679640706, 7.794360248314046, 6.748359135262792, 5.786111460202601, 4.735269851356575, 3.7591627212334675, 2.8627402859890454, 2.012055618208709, 8.799473797794379, 9.771037814709505, 10.712323615607382, 11.593875354101055, 12.598719187256343, 13.620182446128064, 13.699976252780733, 12.631655284631066, 11.68242018061589, 10.741648173677646, 9.691246332387122, 8.763401382969482, 7.803291546051424, 6.872978320409138, 5.918791153066665, 4.866869516404636, 3.87385047257659, 2.8141163769904107, 1.8594428903470637, 1.0575715690605194, 9.779030179880825, 10.758650553509835, 11.742597269484321, 12.665368989325353, 13.568454172247446, 13.903180611053823, 12.945802034975145, 11.915592036714138, 10.95083902490152, 9.910077813139441, 8.838175087691553, 7.791732639954516, 6.8327871671612845, 5.875741892822708, 4.9399447052386325, 3.982247044631995, 2.9426291615842732, 1.882244727112984, 0.9327967048231796, 0.0, 10.759296573757942, 11.705389974096702, 12.7674040143091, 13.624032937825428, 14.585063296839863, 14.792146020213714, 13.8113730189116, 12.862363617160062, 11.794401717647752, 10.7851356849886, 9.733971744714818, 8.772107772813579, 7.883062876567227, 6.92067010767879, 5.90641768564198, 4.91529527662761, 3.9353254070976877, 2.8968682252838165, 1.8952288374461053, 1.0302182720869029, 11.700097116060846, 12.664529090973062, 13.632485210328783, 14.587828127939538, 15.581816745574404, 15.790762879730083, 14.78751399567749, 13.759053259476742, 12.722729215994118, 11.745559167035108, 10.680515326428266, 9.73962332537021, 8.89368762076204, 7.9112495487718855, 6.901179808267367, 5.874149809129946, 4.88555703450315, 3.8942317868632634, 2.9585920627582403, 2.0686116169821354, 12.747819688858694, 13.715748278606501, 14.562286683733547, 15.573938998098804, 16.532074400876454, 16.703788415716854, 15.642235895458771, 14.632695894248876, 13.561523051660496, 12.633371869181467, 11.632329657556834, 10.647502987183852, 9.667394153856566, 8.702710339270727, 7.710591914628127, 6.765212835858351, 5.835819237536024, 4.906182927054718, 4.008669853490865, 3.082170777918117, 13.7250943850363, 14.726527367472062, 15.513550861963077, 16.520370652063246, 17.532595490251698, 17.35746909914392, 16.414515921869135, 15.475620614681437, 14.538579341432502, 13.602812758024532, 12.598587533270518, 11.615665777041974, 10.62805695976169, 9.728725629419767, 8.717819238476388, 7.698394417003826, 6.776484154636696, 5.891335801603883, 5.025032486680011, 4.115317217971959, 14.661135469129366, 15.634058412809212, 16.506831189232248, 17.485542549947468, 18.470655098341755, 18.295024831909757, 17.47374560421585, 16.439702198348442, 15.466158316035747, 14.500768600346266, 13.54490560402207, 12.592243871682168, 11.556759931055833, 10.615004676099728, 9.661385065879527, 8.672386046954525, 7.812802476245375, 6.927701930403881, 5.996870521427628, 5.067002865508809], [15.109450141177797, 15.675639684836499, 16.66672206260267, 17.611740308589468, 18.551257690187303, 18.26610380871253, 17.285028510995176, 16.31902701932327, 15.299797529074667, 14.361082776422954, 13.432343301899007, 12.551848039509839, 11.555346191280801, 10.592171103643402, 9.659349735265845, 8.667667442813512, 7.616253988126425, 6.653525504672994, 5.775618046419215, 4.8653222972332095, 14.106986814030515, 14.731083875286584, 15.703724454778923, 16.644070265040998, 17.624604484549064, 17.72308950434812, 16.680412587065508, 15.638991528306962, 14.6241540158922, 13.61932021945288, 12.61917246018318, 11.626532997432513, 10.678338649486196, 9.673283650031767, 8.722637515398675, 7.743911302481839, 6.703974834310601, 5.673073080967084, 4.747998340173552, 3.851064470221272, 13.100633151535359, 13.798052281815314, 14.74067514865809, 15.741066558636074, 16.678951258986864, 16.757267930645618, 15.763170425444049, 14.743837694854706, 13.785019458294816, 12.868613513475777, 11.871860539647187, 10.83467171754354, 9.802902537453084, 8.833634896074727, 7.90398296679273, 6.856156989478075, 5.792700089212216, 4.729015304280762, 3.7895028470985954, 2.891796684814192, 12.088314042894797, 12.840297930921128, 13.803463784724876, 14.811340095518291, 15.660327459395054, 15.77962532761337, 14.8232353802499, 13.793601808225583, 12.809793837542689, 11.823665536205759, 10.866284464824382, 9.83864367170901, 8.86703836324458, 7.89129885831413, 6.9187954301517935, 5.94813442429148, 4.8954494381414575, 3.8812164316719646, 2.861018764022292, 1.9210529035942354, 11.043022441806636, 11.84785191627272, 12.825690995358528, 13.772657388880269, 14.674694067717848, 14.86692366101096, 13.937245771437441, 12.89840648661823, 11.944550858489269, 10.97108131596352, 9.906379905349349, 8.903096711860695, 7.9365799796358845, 6.995846118053418, 6.001252851699867, 5.037415992423641, 4.005622115237088, 2.957754259547114, 1.9152197325817042, 0.9697794840516646, 9.980912710158309, 10.840673639954932, 11.86048190160681, 12.82317561187849, 13.697146636144003, 14.646700843051933, 14.898961121815669, 13.943885498752643, 12.882719313471084, 11.852043001082109, 10.84816799764219, 9.912997993881223, 8.901623771688907, 7.9559368961455075, 6.9795767848360235, 6.036418738561135, 4.977570936740035, 3.9126966974285162, 2.916349356134467, 1.9861471236938222, 8.93672056667957, 9.876677426288374, 10.843163167090593, 11.814888004679666, 12.731207160355893, 13.679454518060334, 14.661367837653076, 14.832033963496576, 13.862427641696396, 12.83821646956887, 11.824783490016697, 10.858386607935763, 9.846585885672708, 8.84009517600848, 7.908786655824026, 6.856083830396342, 5.832422080239477, 4.889595739864621, 3.8849262419444006, 2.9558604134198685, 8.00609193469921, 8.914229745099863, 9.817711072297316, 10.80592805155746, 11.69798099732031, 12.637717258731108, 13.677189709859851, 14.66966287343363, 14.787150573379314, 13.72692683291372, 12.7171766691119, 11.74097991289428, 10.742825188609434, 9.80462055383432, 8.741276670208578, 7.7214934865114015, 6.774073567192533, 5.789787976637258, 4.834542151591636, 3.9431797364557397, 7.073673322306814, 7.960143197345683, 8.84964827541886, 9.816499202644827, 10.772157338904382, 11.754410946996106, 12.760777500333905, 13.696301405169335, 14.67657007273702, 14.544436662338665, 13.526522845504541, 12.487561842266988, 11.507988696625066, 10.581487918102631, 9.626747263093051, 8.699297377039468, 7.798986840994896, 6.8566287900096095, 5.897146982445411, 4.91122046425445, 6.019931386472483, 6.901563881974337, 7.902185783627974, 8.89626197735146, 9.839131308023719, 10.820402316602086, 11.756691440411656, 12.765908370849731, 13.755134812281089, 14.684972647502297, 14.437223126039767, 13.491232936624199, 12.550933388701718, 11.574257627366984, 10.625279416808448, 9.697652447299241, 8.770688365707677, 7.789926691552336, 6.849701515985946, 5.905230403741366, 5.010008118115813, 5.956755712102166, 6.977858275250253, 7.95303289438965, 8.880031451453512, 9.80839691778333, 10.80774681762428, 11.70972725397841, 12.728725731800047, 13.77344986070685, 14.753392650272502, 14.456393424390452, 13.572782148833781, 12.509046036375922, 11.661970585847126, 10.767254679285092, 9.79122993830245, 8.792741960839866, 7.77507194979746, 6.85107506900484, 4.078510507838018, 5.017836576128958, 5.958017576179092, 6.896580007147536, 7.857015957885729, 8.790159146556363, 9.805758525211246, 10.778355618503468, 11.756260698753236, 12.81379968018932, 13.739893512512074, 14.73342196693299, 14.487712254209974, 13.479719496002302, 12.700907434024957, 11.746282667389606, 10.744772973104702, 9.833115123894125, 8.813818227776283, 7.821882973138042, 3.0121954572044514, 3.981638142644052, 4.989531936744909, 5.923643701167287, 6.885389127533177, 7.839931253873238, 8.78878518171991, 9.783584335503724, 10.79899818526785, 11.790399350463575, 12.723201228123814, 13.717089732280485, 14.681049000079428, 14.46820448298466, 13.664224506486557, 12.701976831426366, 11.655612674394881, 10.679505544271773, 9.745087289438679, 8.747240955549234, 1.9598227759635638, 2.93138679287869, 4.004373302044215, 5.009505856539562, 5.874658935168313, 6.882606094420402, 7.843516973297731, 8.897402160811108, 9.846637264826283, 10.787409271764528, 11.837811113055052, 12.765656062472692, 13.7837159100762, 14.837043597011375, 14.619804779515258, 13.595390091215013, 12.602371047386967, 11.62455188851483, 10.726202044145639, 9.701725004697423, 0.9802663938771169, 2.018402884679861, 3.0590396572355525, 3.9380122213152635, 4.904923950177211, 5.943156251606001, 6.900534827684679, 7.871558663115822, 8.83631167492844, 9.877072886690518, 10.948975612138407, 11.977101118876421, 12.936046591669653, 13.89309186600823, 14.828889053592306, 14.573210241427006, 13.533592358379284, 12.556423538392258, 11.652848229669523, 10.759296573757942, 0.0, 0.9460934003387609, 2.008107440551159, 2.979348272815188, 4.006841870466777, 4.9766877386172235, 5.957460739919337, 6.906470141670876, 7.974432041183186, 8.983698073842337, 10.034862014116118, 10.996725986017358, 12.031088547450974, 13.015678708871702, 14.078924910356443, 15.124039731797064, 14.547880337792929, 13.57104703656309, 12.615280362292449, 11.789514845844845, 0.9408005423029044, 1.9052325172151205, 2.873188636570841, 3.828531554181595, 4.822520171816462, 5.888356539990527, 6.891605424043121, 7.903406260516913, 8.939730303999537, 9.916900352958548, 10.981405595829566, 11.96424153857399, 12.93858627001629, 13.978229851234897, 14.988299591739416, 16.01532959087684, 15.559735845782425, 14.568410598142538, 13.678643587604583, 12.827908190740079, 2.01337255131702, 2.9564517048485586, 3.802990109975605, 4.814642424340862, 5.77277782711851, 6.832377470246461, 7.823581560148176, 8.833121561358071, 9.904294403946452, 10.83244558642548, 11.833487798050113, 12.84335846570739, 13.823467299034675, 14.788151113620515, 15.780269538263115, 16.72564861703289, 16.509998048815298, 15.580361738333993, 14.728721378337207, 13.84146735167606, 2.9906472474946253, 3.9672307937141196, 4.754254288205136, 5.7610740783053025, 6.773298916493754, 7.7761487336578, 8.719101910932585, 9.657997218120283, 10.595038491369218, 11.530805074777188, 12.603822999805478, 13.586744756034022, 14.574353573314307, 15.560090440694628, 16.618380912508346, 17.63780573398091, 17.45066296591597, 16.565514612883156, 15.745084011526354, 14.874613791729901, 3.926688331587692, 4.914621301651453, 5.797220054094263, 6.813349563983774, 7.79081773872403, 8.713704466423636, 9.772228911819758, 10.622078801787286, 11.522617465972463, 12.487616193320026, 13.443479189644222, 14.492820737447872, 15.503056544608448, 16.558962519599127, 17.51258212981933, 18.501581148744332, 18.48698128752465, 17.601880741683154, 16.71692204627397, 15.826299439266752], [15.897704990688252, 14.909741029904424, 15.900823407670595, 16.845841653657395, 17.703688660266938, 17.388236174754283, 16.40716087703693, 15.441159385365022, 14.42192989511642, 13.483215142464708, 12.55447566794076, 11.67398040555159, 10.677478557322553, 9.778181122729393, 8.845359754351836, 7.853677461899504, 6.873126289754174, 5.910397806300743, 5.055849342699993, 5.81141569757197, 14.89524166354097, 13.96518522035451, 14.937825799846848, 15.878171610108923, 16.774534446760338, 17.698095066662457, 17.36193725192399, 16.37653135687775, 15.361693844462987, 14.410052219053608, 13.56526586052194, 12.572626397771273, 11.624432049824957, 10.619377050370527, 9.668730915737436, 8.6900047028206, 7.650068234649361, 6.619166481305845, 5.694091740512313, 4.797157870560033, 14.032748258078591, 13.03215362688324, 13.96798501390594, 14.968376423883925, 15.828881221198138, 16.732273492959955, 16.70926382578281, 15.689931095193467, 14.731112858633576, 13.814706913814538, 12.817953939985946, 11.780765117882298, 10.748995937791843, 9.779728296413486, 8.850076367131491, 7.802250389816836, 6.738793489550977, 5.6751087046195225, 4.735596247437356, 3.8378900851529525, 13.034407443233558, 12.074399275989053, 13.030773649972726, 14.01080894337752, 14.810257421606329, 15.754630889927709, 15.76932878058866, 14.739695208564344, 13.75588723788145, 12.76975893654452, 11.812377865163143, 10.78473707204777, 9.813131763583339, 8.837392258652889, 7.864888830490553, 6.8942278246302395, 5.841542838480217, 4.827309832010725, 3.807112164361053, 2.867146303932996, 11.989115842145397, 11.081953261340646, 12.053000860606378, 12.972126236739497, 13.824624029929122, 14.751806592255402, 14.883339171776202, 13.84449988695699, 12.89064425882803, 11.91717471630228, 10.85247330568811, 9.849190112199455, 8.882673379974644, 7.941939518392179, 6.947346252038628, 5.983509392762402, 4.951715515575849, 3.9038476598858747, 2.861313132920465, 1.9158728843904256, 10.92700611049707, 10.074774985022858, 11.059950749466038, 12.022644459737718, 12.847076598355278, 13.796630805263208, 14.764437535372853, 14.889978899091403, 13.828812713809844, 12.79813640142087, 11.79426139798095, 10.859091394219984, 9.847717172027668, 8.902030296484268, 7.925670185174784, 6.982512138899896, 5.923664337078796, 4.858790097767277, 3.8624427564732278, 2.932240524032583, 9.88281396701833, 9.1107787713563, 10.04263201494982, 11.014356852538894, 11.881137122567168, 12.829384480271608, 13.81129779986435, 14.704530918488919, 14.808521042035157, 13.78430986990763, 12.770876890355458, 11.804480008274524, 10.792679286011468, 9.786188576347243, 8.854880056162788, 7.8021772307351025, 6.778515480578237, 5.835689140203382, 4.831019642283161, 3.901953813758629, 8.95218533503797, 8.113698592959091, 9.017179920156543, 10.005396899416688, 10.847910959531584, 11.787647220942382, 12.827119672071126, 13.747717965622027, 14.706002034058097, 14.67302023325248, 13.66327006945066, 12.68707331323304, 11.688918588948193, 10.75071395417308, 9.687370070547336, 8.667586886850161, 7.720166967531294, 6.735881376976018, 5.780635551930397, 4.889273136794501, 8.019766722645574, 7.159612045204911, 8.049117123278087, 9.015968050504055, 9.922087301115656, 10.90434090920738, 11.870548481487068, 12.774356497357731, 13.754625164925416, 14.733567032050825, 14.4726162458433, 13.433655242605747, 12.454082096963825, 11.52758131844139, 10.57284066343181, 9.645390777378227, 8.745080241333657, 7.80272219034837, 6.843240382784171, 5.857313864593212, 6.966024786811244, 6.101032729833563, 7.101654631487202, 8.06480173047072, 8.977115750231814, 9.93017329775525, 10.866462421564819, 11.81981497051097, 12.809041411942328, 13.738879247163537, 14.795233776649843, 14.437326336962958, 13.497026789040477, 12.520351027705743, 11.571372817147207, 10.643745847638, 9.71678176604644, 8.736020091891097, 7.795794916324707, 6.851323804080128, 5.956101518454574, 5.156224559961393, 6.142686915353456, 7.025400258195154, 7.933938051114751, 8.86230351744457, 9.861653417285519, 10.76363385363965, 11.782632331461286, 12.827356460368089, 13.807299249933742, 14.74154736210098, 14.51887554917254, 13.455139436714681, 12.608063986185885, 11.71334807962385, 10.737323338641215, 9.738835361178626, 8.721165350136221, 7.797168469343601, 5.024603908176779, 4.146372006391698, 5.086553006441834, 5.96894737095304, 6.910922557546968, 7.844065746217601, 8.859665124872485, 9.832262218164708, 10.810167298414475, 11.867706279850559, 12.793800112173313, 13.78732856659423, 14.66017372308322, 14.42581289634106, 13.647000834363721, 12.69237606772837, 11.690866373443466, 10.779208524232887, 9.759911628115045, 8.767976373476804, 3.9582888575432125, 3.1101735729067923, 4.11806736700765, 4.996011064972791, 5.939295727194416, 6.893837853534477, 7.8426917813811485, 8.837490935164963, 9.85290478492909, 10.844305950124815, 11.777107827785054, 12.770996331941724, 13.734955599740667, 14.689165031067327, 14.61031790682532, 13.64807023176513, 12.601706074733643, 11.625598944610536, 10.691180689777442, 9.693334355887997, 2.9059161763023247, 2.0599222231414305, 3.1329087323069555, 4.063412456200801, 4.928565534829552, 5.9365126940816415, 6.89742357295897, 7.951308760472347, 8.900543864487522, 9.841315871425767, 10.891717712716291, 11.819562662133931, 12.83762250973744, 13.890950196672614, 14.845137364015088, 14.541483491553777, 13.54846444772573, 12.570645288853592, 11.672295444484401, 10.647818405036185, 1.9263597942158777, 1.0723094843410999, 2.1129462568967914, 2.991918820976503, 3.95883054983845, 4.99706285126724, 5.954441427345919, 6.925465262777061, 7.89021827458968, 8.930979486351758, 10.002882211799646, 11.03100771853766, 11.989953191330892, 12.94699846566947, 13.882795653253545, 14.840493313860183, 14.479685758718047, 13.50251693873102, 12.598941630008285, 11.705389974096704, 0.9460934003387609, 0.0, 1.062014040212398, 2.0332548724764274, 3.060748470128017, 4.030594338278463, 5.011367339580576, 5.960376741332115, 7.028338640844425, 8.037604673503576, 9.088768613777358, 10.050632585678597, 11.084995147112213, 12.069585308532941, 13.132831510017683, 14.177946331458303, 15.185051750415457, 14.517140436901853, 13.561373762631211, 12.735608246183606, 1.8868939426416653, 1.0502804902681888, 1.9953210026125927, 2.9506639202233473, 3.944652537858214, 5.010488906032279, 6.013737790084873, 6.957312860178153, 7.993636903660777, 8.970806952619787, 10.035312195490805, 11.01814813823523, 11.992492869677529, 13.032136450896136, 14.042206191400656, 15.069236190538076, 16.080734100187026, 15.514503998481299, 14.624736987943347, 13.77400159107884, 2.9594659516557806, 2.101499677901627, 2.925122476017357, 3.936774790382614, 4.894910193160262, 5.954509836288213, 6.945713926189928, 7.947062851746906, 9.018235694335285, 9.946386876814314, 10.947429088438946, 11.957299756096223, 12.937408589423509, 13.902092404009348, 14.894210828651948, 15.839589907421724, 16.76898350574405, 16.526455138672752, 15.674814778675971, 14.787560752014821, 3.936740647833386, 3.112278766767188, 3.8763866542468874, 4.883206444347055, 5.895431282535506, 6.8982810996995525, 7.841234276974337, 8.780129584162035, 9.71717085741097, 10.65293744081894, 11.72595536584723, 12.708877122075775, 13.696485939356059, 14.68222280673638, 15.740513278550097, 16.75993810002266, 17.709648422844722, 17.511608013221917, 16.691177411865116, 15.820707192068662, 4.872781731926453, 4.059669274704521, 4.919352420136015, 5.935481930025526, 6.912950104765782, 7.835836832465388, 8.89436127786151, 9.744211167829038, 10.644749832014215, 11.60974855936178, 12.565611555685976, 13.614953103489626, 14.625188910650202, 15.68109488564088, 16.63471449586108, 17.623713514786083, 17.886194654061605, 16.923574488536424, 15.976219443134982, 16.772392839605512], [16.799872363412664, 15.811908402628836, 15.102085058451253, 15.973795091601819, 16.641674620054538, 16.326222134541887, 15.345146836824531, 14.379145345152626, 13.359915854904024, 12.421201102252311, 11.492461627728364, 10.611966365339194, 9.615464517110157, 8.716167082516996, 7.783345714139439, 6.7916634216871055, 5.811112249541775, 4.848383766088345, 5.695096503211536, 6.649192136504975, 15.797409036265382, 14.867352593078921, 14.065779237791274, 15.006125048053349, 15.71252040654794, 16.636081026450064, 16.29992321171159, 15.314517316665352, 14.29967980425059, 13.348038178841211, 12.539489296516413, 11.546849833765746, 10.607787081008338, 9.650202289738196, 8.735146258002555, 7.756420045085719, 6.771160025264166, 5.828836189794255, 6.693357534742304, 5.796423664790024, 14.934915630803003, 13.934320999607651, 13.014112307742389, 14.014503717720373, 14.766867180985741, 15.67025945274756, 16.5343639679238, 16.261086831130733, 15.321857189806291, 14.396709965700236, 13.530418547900208, 12.49322972579656, 11.620143861881155, 10.650876220502798, 9.70957587579043, 8.786846815654481, 7.738059283780968, 6.674374498849514, 5.7348620416673475, 4.8371558793829434, 14.022322529808562, 12.976566648713465, 12.076900943809175, 13.044371121682444, 13.748243381393932, 14.692616849715312, 15.59442892272965, 15.790626160814147, 14.806818190131253, 13.820689888794323, 12.863308817412946, 11.835668024297574, 10.81239755781333, 9.83665805288288, 8.864154624720545, 7.893493618860231, 6.840808632710209, 5.826575626240716, 4.806377958591044, 3.866412098162987, 13.033319361400327, 11.984120634065057, 11.099128154442827, 12.005688415044421, 12.762609989716726, 13.689792552043006, 14.619470441616524, 14.906513927169389, 13.952658299040428, 12.979188756514679, 11.914487345900508, 10.911204152411853, 9.944687420187043, 9.003953558604577, 8.009360292251026, 7.0455234329748, 6.013729555788247, 4.965861700098273, 3.923327173132863, 2.9778869246028234, 11.976044118714654, 10.97694235774727, 10.106078043302487, 11.056206638042642, 11.785062558142881, 12.734616765050811, 13.702423495160456, 14.651641709857971, 14.890826754022243, 13.860150441633268, 12.856275438193348, 11.921105434432382, 10.909731212240066, 9.964044336696666, 8.987684225387182, 8.044526179112294, 6.985678377291194, 5.920804137979675, 4.924456796685626, 3.994254564244981, 10.931851975235915, 10.012946144080711, 9.088759308786269, 10.047919030843818, 10.819123082354771, 11.767370440059212, 12.749283759651954, 13.642516878276522, 14.596931804603326, 14.846323910120029, 13.832890930567856, 12.866494048486922, 11.854693326223867, 10.848202616559641, 9.916894096375186, 8.8641912709475, 7.840529520790636, 6.89770318041578, 5.89303368249556, 4.9639678539710275, 10.001223343255555, 9.015865965683503, 8.063307213992992, 9.038959077721612, 9.785896919319187, 10.725633180729986, 11.765105631858729, 12.68570392540963, 13.6439879938457, 14.662948070861804, 14.725284109663058, 13.749087353445438, 12.750932629160591, 11.812727994385478, 10.749384110759735, 9.72960092706256, 8.782181007743691, 7.797895417188417, 6.842649592142795, 5.9512871770069, 9.068804730863159, 8.061779417929323, 7.095244417114536, 8.04953022880898, 8.86007326090326, 9.842326868994984, 10.808534441274672, 11.712342457145335, 12.69261112471302, 13.671552991838428, 14.689466808672552, 14.495669282818145, 13.516096137176223, 12.589595358653789, 11.634854703644208, 10.707404817590625, 9.807094281546053, 8.864736230560768, 7.9052544229965696, 6.91932790480561, 8.015062795028827, 7.003200102557976, 6.147781925323651, 7.0027876902583195, 7.9151017100194165, 8.868159257542853, 9.804448381352422, 10.757800930298574, 11.747027371729931, 12.67686520695114, 13.733219736437446, 14.644693809654834, 14.559040829252876, 13.582365067918142, 12.633386857359605, 11.705759887850398, 10.778795806258836, 9.798034132103494, 8.857808956537106, 7.913337844292526, 7.005139526672158, 6.058391932685805, 5.110945262455, 5.963386217982754, 6.871924010902353, 7.800289477232172, 8.79963937707312, 9.701619813427254, 10.72061829124889, 11.765342420155692, 12.745285209721345, 13.67953332188858, 14.606158368656606, 14.51715347692708, 13.670078026398283, 12.775362119836249, 11.799337378853611, 10.800849401391025, 9.78317939034862, 8.859182509556, 6.086617948389178, 5.048539379116111, 4.0548113535433785, 4.906933330740641, 5.84890851733457, 6.782051706005203, 7.797651084660086, 8.77024817795231, 9.748153258202077, 10.80569223963816, 11.731786071960915, 12.725314526381831, 13.598159682870822, 14.606152441078494, 14.709014874576118, 13.754390107940766, 12.752880413655863, 11.841222564445284, 10.821925668327442, 9.829990413689202, 5.020302897755611, 4.132071374136599, 3.0863257141091944, 3.933997024760392, 4.877281686982018, 5.831823813322079, 6.78067774116875, 7.775476894952565, 8.790890744716691, 9.782291909912416, 10.715093787572656, 11.708982291729326, 12.672941559528269, 13.627150990854929, 14.673152103906183, 14.710084271977527, 13.663720114946042, 12.687612984822934, 11.75319472998984, 10.755348396100395, 3.967930216514723, 3.0991429368875822, 2.1011670794085004, 3.001398415988403, 3.8665514946171538, 4.874498653869243, 5.835409532746572, 6.889294720259949, 7.838529824275124, 8.779301831213369, 9.829703672503893, 10.757548621921533, 11.775608469525041, 12.828936156460216, 13.78312332380269, 14.831922813087154, 14.610478487938128, 13.63265932906599, 12.7343094846968, 11.709832445248583, 2.988373834428276, 2.1115301980872516, 1.07089342553156, 1.9299047807641045, 2.896816509626052, 3.935048811054842, 4.89242738713352, 5.863451222564663, 6.8282042343772815, 7.868965446139359, 8.940868171587248, 9.968993678325262, 10.927939151118494, 11.884984425457072, 12.820781613041147, 13.778479273647784, 14.818097156695506, 14.564530978943418, 13.660955670220684, 12.767404014309102, 2.008107440551159, 1.062014040212398, 0.0, 0.9712408322640292, 1.998734429915619, 2.9685802980660645, 3.9493532993681777, 4.898362701119717, 5.966324600632027, 6.975590633291178, 8.02675457356496, 8.988618545466199, 10.022981106899815, 11.007571268320543, 12.070817469805284, 13.115932291245905, 14.123037710203059, 15.16149489201693, 14.62338780284361, 13.797622286396006, 2.865695056668131, 1.901263081755915, 0.9333069624001946, 1.888649880010949, 2.8826384976458157, 3.9484748658198803, 4.951723749872475, 5.895298819965754, 6.9316228634483785, 7.908792912407389, 8.973298155278407, 9.956134098022831, 10.93047882946513, 11.970122410683738, 12.980192151188257, 14.007222150325678, 15.018720059974628, 16.010045307614515, 15.686751028155744, 14.83601563129124, 3.938267065682247, 2.9187661747493445, 1.8631084358049588, 2.8747607501702155, 3.8328961529478636, 4.8924957960758135, 5.88369988597753, 6.885048811534507, 7.956221654122888, 8.884372836601917, 9.88541504822655, 10.895285715883826, 11.875394549211112, 12.840078363796952, 13.832196788439552, 14.777575867209327, 15.706969465531655, 16.63660577601296, 16.73682881888837, 15.849574792227221, 4.77451708676639, 3.751525927278731, 2.814372614034489, 3.8211924041346563, 4.833417242323108, 5.836267059487154, 6.7792202367619385, 7.718115543949637, 8.655156817198574, 9.590923400606544, 10.663941325634834, 11.646863081863378, 12.634471899143662, 13.620208766523984, 14.6784992383377, 15.697924059810262, 16.647634382632326, 17.16120226811708, 17.700785830764218, 16.74767404315154, 5.710558170859457, 4.698916435216064, 3.8573383799236165, 4.873467889813128, 5.850936064553384, 6.7738227922529894, 7.8323472376491114, 8.682197127616641, 9.582735791801818, 10.547734519149383, 11.50359751547358, 12.552939063277229, 13.563174870437805, 14.619080845428483, 15.572700455648684, 16.561699474573686, 17.014148092006028, 16.124836139317082, 16.878386815859393, 17.69935969068839], [17.61041460622221, 16.62245064543838, 15.9126273012608, 15.071827065311826, 15.670433787790513, 15.44163779719427, 14.460562499476916, 13.494561007805011, 12.475331517556409, 11.536616764904696, 10.607877290380749, 9.727382027991581, 8.730880179762543, 7.831582745169381, 6.898761376791825, 5.907079084339491, 5.053376056048816, 5.819624598352374, 6.666337335475565, 7.620432968769004, 16.60795127907493, 15.677894835888468, 14.87632148060082, 14.104157021763356, 14.741279574283913, 15.664840194186038, 15.415338874363977, 14.429932979317737, 13.415095466902976, 12.463453841493596, 11.6549049591688, 10.662265496418133, 9.723202743660725, 8.765617952390581, 7.8505619206549415, 6.8718357077381045, 6.013423831771208, 6.800077022058284, 7.664598367006333, 6.767664497054053, 15.74545787361255, 14.744863242417198, 13.824654550551935, 13.08370227479468, 13.795626348721715, 14.699018620483534, 15.563123135659772, 15.376502493783118, 14.437272852458676, 13.51212562835262, 12.645834210552595, 11.608645388448947, 10.735559524533542, 9.766291883155185, 8.824991538442816, 7.9022624783068665, 6.984473378535034, 7.645615331113542, 6.706102873931376, 5.808396711646973, 14.832864772618109, 13.787108891523012, 12.887443186618722, 12.073130289418414, 12.777002549129906, 13.721376017451286, 14.623188090465623, 15.65282166248994, 15.412498473210803, 14.557073605622639, 13.687513971667121, 12.659873178551749, 11.684367425846233, 10.708627920915783, 9.822612345979113, 8.8519513401188, 7.812049464974237, 6.7978164585047445, 5.7776187908550725, 4.837652930427016, 13.843861604209874, 12.794662876874604, 11.909670397252373, 11.034447582780391, 11.7913691574527, 12.71855171977898, 13.648229609352498, 14.68706889417171, 14.923899131304458, 13.950429588778709, 12.885728178164538, 11.882444984675884, 10.915928252451073, 9.975194390868607, 8.980601124515056, 8.01676426523883, 6.984970388052277, 5.937102532362302, 4.894568005396892, 3.9491277568668526, 12.7865863615242, 11.787484600556816, 10.916620286112034, 10.084965805778612, 10.813821725878855, 11.763375932786783, 12.731182662896428, 13.680400877593941, 14.667969534371906, 14.831391273897298, 13.827516270457378, 12.892346266696412, 11.880972044504096, 10.935285168960695, 9.95892505765121, 9.015767011376322, 7.956919209555223, 6.892044970243704, 5.895697628949655, 4.96549539650901, 11.742394218045462, 10.823488386890258, 9.899301551595816, 9.076678198579788, 9.847882250090745, 10.796129607795184, 11.778042927387926, 12.671276046012492, 13.625690972339296, 14.649902144466822, 14.804131762831886, 13.837734880750952, 12.825934158487897, 11.819443448823671, 10.888134928639216, 9.83543210321153, 8.811770353054666, 7.868944012679809, 6.864274514759589, 5.935208686235057, 10.811765586065102, 9.82640820849305, 8.873849456802539, 8.067718245457582, 8.814656087055159, 9.754392348465958, 10.7938647995947, 11.7144630931456, 12.67274716158167, 13.691707238597774, 14.701457402399594, 14.720328185709468, 13.722173461424621, 12.783968826649508, 11.720624943023765, 10.70084175932659, 9.753421840007721, 8.769136249452446, 7.813890424406824, 6.922528009270928, 9.879346973672705, 8.87232166073887, 7.9057866599240825, 7.0782893965449505, 7.8888324286392315, 8.871086036730956, 9.837293609010642, 10.741101624881304, 11.72137029244899, 12.700312159574398, 13.718225976408522, 14.677124071748016, 14.487336969440253, 13.560836190917819, 12.606095535908239, 11.678645649854655, 10.778335113810083, 9.835977062824798, 8.876495255260599, 7.890568737069638, 8.825605037838374, 7.8137423453675225, 6.958324168133197, 6.031546857994291, 6.943860877755388, 7.896918425278824, 8.833207549088392, 9.786560098034544, 10.775786539465901, 11.70562437468711, 12.761978904173416, 13.673452977390806, 14.680795856197456, 14.553605900182172, 13.604627689623635, 12.677000720114428, 11.750036638522866, 10.769274964367524, 9.800600330947052, 8.769966767808853, 7.815681769481705, 6.868934175495352, 5.921487505264547, 4.992145385718725, 5.9006831786383245, 6.829048644968144, 7.82839854480909, 8.730378981163224, 9.74937745898486, 10.794101587891662, 11.774044377457315, 12.708292489624553, 13.634917536392578, 14.605585068440845, 14.641318858662313, 13.746602952100279, 12.770578211117641, 11.734891935869067, 10.717221924826662, 9.715811433072327, 6.927381772791518, 5.859081621925657, 4.865353596352925, 3.9356924984766115, 4.877667685070541, 5.810810873741174, 6.826410252396057, 7.799007345688279, 8.776912425938047, 9.834451407374132, 10.760545239696887, 11.754073694117803, 12.626918850606794, 13.634911608814466, 14.59745818984941, 14.725630940204796, 13.724121245919893, 12.723482040811126, 11.704185144693284, 10.68661933720553, 5.9915437300196395, 4.942613616946145, 3.896867956918741, 2.962756192496363, 3.906040854717989, 4.86058298105805, 5.809436908904721, 6.804236062688535, 7.819649912452661, 8.811051077648388, 9.743852955308627, 10.737741459465298, 11.70170072726424, 12.6559101585909, 13.701911271642155, 14.664158946702345, 14.520349038462369, 13.544241908339261, 12.609823653506167, 11.611977319616722, 4.939171048778752, 4.060360704319472, 3.0623848468403905, 2.0301575837243737, 2.8953106623531246, 3.903257821605214, 4.8641687004825425, 5.918053887995921, 6.867288992011096, 7.8080609989493395, 8.858462840239865, 9.786307789657505, 10.804367637261013, 11.857695324196188, 12.811882491538661, 13.860681980823124, 14.778077635423793, 14.489288252582318, 13.590938408213127, 12.56646136876491, 3.959614666692305, 3.0727479655191416, 2.03211119296345, 0.9586639485000753, 1.9255756773620227, 2.963807978790813, 3.9211865548694917, 4.892210390300635, 5.856963402113253, 6.897724613875331, 7.969627339323219, 8.997752846061232, 9.956698318854464, 10.913743593193042, 11.849540780777117, 12.807238441383754, 13.846856324431476, 14.907240758902766, 14.517584593737011, 13.62403293782543, 2.979348272815188, 2.0332548724764274, 0.9712408322640292, 0.0, 1.0274935976515898, 1.9973394658020356, 2.9781124671041486, 3.927121868855688, 4.995083768367998, 6.004349801027149, 7.0555137413009295, 8.017377713202169, 9.051740274635785, 10.036330436056513, 11.099576637541254, 12.144691458981875, 13.151796877939029, 14.1902540597529, 15.255315108537882, 14.654251209912331, 3.8369358889321603, 2.872503914019944, 1.9045477946642237, 0.9730100689902396, 1.9669986866251064, 3.032835054799171, 3.9925972930918574, 4.924057987701726, 5.96038203118435, 6.9375520801433606, 8.002057323014377, 8.984893265758801, 9.9592379972011, 10.998881578419708, 12.008951318924227, 13.035981318061648, 14.047479227710598, 15.038804475350485, 16.04417011828887, 15.692644554807565, 4.909507897946276, 3.8900070070133737, 2.834349268068988, 1.9901764128226014, 2.9483118156002495, 4.0079114587282, 4.924573429196912, 5.913807979270479, 6.984980821858859, 7.913132004337888, 8.91417421596252, 9.924044883619796, 10.904153716947082, 11.868837531532922, 12.860955956175522, 13.806335034945297, 14.735728633267625, 15.66536494374893, 16.65441017807594, 16.706203715743545, 5.745757919030419, 4.72276675954276, 3.7856134462985183, 2.985168312699261, 3.948832904975494, 4.951682722139541, 5.894635899414325, 6.833531206602024, 7.77057247985096, 8.70633906325893, 9.77935698828722, 10.762278744515765, 11.749887561796049, 12.73562442917637, 13.793914900990087, 14.739516616090771, 15.676393550368298, 16.639879091406, 17.588904186695967, 17.558216285961088, 6.681799003123486, 5.670157267480093, 4.828579212187646, 4.046347792622297, 4.96635172720577, 5.889238454905376, 6.947762900301498, 7.797612790269028, 8.698151454454205, 9.663150181801768, 10.619013178125964, 11.668354725929614, 12.67859053309019, 13.73449650808087, 14.688116118301071, 15.677115137226073, 16.112180065716036, 16.93537838212663, 17.688929058668936, 18.509901933497936], [18.571444965236644, 17.583481004452818, 16.76053020140344, 15.700984616618742, 14.761467235020907, 14.434202491083225, 13.453127193365871, 12.487125701693966, 11.467896211445364, 10.529181458793651, 9.600441984269704, 8.719946721880534, 7.723444873651496, 6.915636124593303, 5.982814756215746, 5.038548371636562, 6.080869653700406, 6.847118196003963, 7.693830933127154, 8.647926566420592, 17.56898163808936, 16.638925194902903, 15.75504104351827, 14.814695233256195, 13.832313021514308, 14.755873641416432, 14.407903568252932, 13.422497673206692, 12.40766016079193, 11.456018535382551, 10.647469653057753, 9.654830190307086, 8.715767437549676, 7.849671331814503, 6.982031207952012, 6.003304995035175, 7.040917429422796, 7.827570619709873, 8.692091964657923, 7.795158094705643, 16.70648823262698, 15.705893601431631, 14.785684909566369, 13.80775918645619, 12.88665979595211, 13.790052067713928, 14.654156582890167, 14.369067187672073, 13.429837546347631, 12.504690322241576, 11.638398904441548, 10.6012100823379, 9.753596682634164, 8.888098779695598, 7.956460825739887, 7.033731765603937, 8.011966976186622, 8.673108928765133, 7.733596471582966, 6.835890309298563, 15.793895131632542, 14.748139250537445, 13.848473545633155, 12.797187201079923, 11.8680359963603, 12.81240946468168, 13.714221537696018, 14.743855109720334, 14.405063167099758, 13.549638299511594, 12.680078665556074, 11.652437872440702, 10.739162865552927, 9.830434817456196, 8.954081633276186, 7.983420627415872, 8.839543062625827, 7.825310056156335, 6.805112388506663, 5.865146528078606, 14.804891963224307, 13.755693235889037, 12.870700756266807, 11.81309773838244, 10.882402604683094, 11.809585167009374, 12.739263056582892, 13.74397088950653, 14.610022398277037, 14.563129654823399, 13.591268025777671, 12.587984832289017, 11.68276207288752, 10.815008899175021, 9.997244551780318, 9.033407692504092, 8.012463985703866, 6.964596130013891, 5.922061603048482, 4.976621354518442, 13.747616720538634, 12.74851495957125, 11.877650645126467, 10.910196668275306, 9.90485517310925, 10.854409380017177, 11.822216110126822, 12.684285286517257, 13.671853943295222, 14.639960021876899, 14.533056118070512, 13.599407671469129, 12.647805864940544, 11.816222451561252, 10.986418655302801, 10.043260609027913, 8.984412807206812, 7.919538567895294, 6.9231912266012445, 5.9929889941606, 12.703424577059895, 11.784518745904691, 10.860331910610249, 9.901909061076482, 8.93891569732114, 9.887163055025578, 10.86907637461832, 11.675160454935808, 12.629575381262612, 13.653786553390137, 14.725450368386023, 14.544796285523669, 13.592767978924345, 12.84693704647526, 11.915628526290805, 10.86292570086312, 9.839263950706254, 8.896437610331398, 7.891768112411178, 6.962702283886646, 11.772795945079535, 10.787438567507483, 9.834879815816972, 8.90363681747527, 7.905689534285553, 8.845425795696352, 9.849138904604871, 10.718347502068916, 11.676631570504986, 12.695591647521091, 13.705341811322912, 14.675755338438348, 14.578031343768416, 13.811462424301096, 12.748118540675353, 11.728335356978178, 10.78091543765931, 9.796629847104034, 8.841384022058413, 7.900664321952488, 10.840377332687138, 9.833352019753303, 8.866817018938516, 7.93552401212918, 6.979865875869626, 7.914692567055441, 8.869138781012445, 9.744986033804622, 10.725254701372307, 11.704196568497716, 12.72211038533184, 13.649630474096426, 14.629203619738348, 14.588329788569407, 13.633589133559827, 12.706139247506243, 11.805828711461672, 10.863470660476386, 9.903988852912189, 8.868705049751197, 9.786635396852807, 8.774772704381956, 7.919354527147631, 6.977763655658043, 6.034894324985783, 6.936450968007584, 7.865052721090195, 8.790444506957861, 9.779670948389219, 10.709508783610428, 11.746320051766748, 12.645959379739216, 13.653302258545866, 14.512879879798193, 14.632121287275224, 13.704494317766017, 12.777530236174455, 11.796768562019112, 10.761630689961486, 9.730997126823286, 8.776712128496138, 7.829964534509785, 6.88251786427898, 5.953175744733159, 4.991716625868719, 5.868581187696904, 6.832282953732408, 7.734263390086542, 8.753261867908178, 9.79253390669818, 10.758385525050647, 11.680798891972962, 12.607423938740988, 13.578091470789255, 14.570463402299337, 14.751617505344424, 13.760840385226503, 12.6959222948835, 11.678252283841095, 10.67684179208676, 7.888412131805952, 6.820111980940091, 5.826383955367358, 4.896722857491045, 3.9687011323009362, 4.814695282664491, 5.830294661319375, 6.802891754611599, 7.780796834861366, 8.806957809722542, 9.733051642045297, 10.726580096466213, 11.599425252955204, 12.607418011162876, 13.56996459219782, 14.524589358833172, 14.714383420028755, 13.68451239982556, 12.665215503707717, 11.647649696219963, 6.969680042701199, 5.903643975960579, 4.857898315933174, 3.9237865515107964, 2.997074301948384, 3.8644673899813675, 4.81332131782804, 5.808120471611854, 6.8235343213759805, 7.783557479996798, 8.716359357657037, 9.710247861813707, 10.67420712961265, 11.62841656093931, 12.674417673990565, 13.636665349050755, 14.687506957896781, 14.505272267353694, 13.5708540125206, 12.573007678631155, 5.966664646430341, 5.085217609273762, 4.06464405874941, 2.991187942738807, 1.98634410958352, 2.907142230528532, 3.868053109405861, 4.890560290344331, 5.839795394359506, 6.780567401297749, 7.830969242588274, 8.758814192005914, 9.776874039609423, 10.830201726544598, 11.784388893887071, 12.833188383171533, 13.750584037772203, 14.811618811128604, 14.55196876722756, 13.527491727779344, 4.987108264343894, 4.097604870473432, 3.05696809791774, 1.9835208534543654, 1.0166091245924178, 1.967692387714131, 2.92507096379281, 3.864716792649045, 4.829469804461663, 5.870231016223741, 6.942133741671629, 7.970259248409643, 8.929204721202874, 9.886249995541451, 10.822047183125527, 11.779744843732164, 12.819362726779886, 13.879747161251176, 14.82919518354098, 14.585063296839863, 4.006841870466777, 3.0607484701280168, 1.998734429915619, 1.0274935976515898, 0.0, 0.9698458681504458, 1.9506188694525588, 2.899628271204098, 3.9675901707164085, 4.97685620337556, 6.02802014364934, 6.989884115550579, 8.024246676984195, 9.008836838404923, 10.072083039889664, 11.117197861330284, 12.124303280287439, 13.16276046210131, 14.227821510886292, 15.18630462190777, 4.8644294865837505, 3.899997511671534, 2.9320413923158135, 2.0005036666418294, 1.0374308187560448, 2.023536849458316, 2.965103695440268, 3.896564390050136, 4.93288843353276, 5.91005848249177, 6.974563725362787, 7.957399668107211, 8.93174439954951, 9.971387980768117, 10.981457721272637, 12.008487720410058, 13.019985630059008, 14.011310877698895, 15.016676520637281, 16.044155059419275, 5.937001495597866, 4.917500604664964, 3.8618428657205777, 3.017670010474191, 2.07978110289732, 3.076106712103224, 3.897079831545323, 4.886314381618889, 5.957487224207269, 6.885638406686298, 7.88668061831093, 8.896551285968206, 9.876660119295492, 10.841343933881332, 11.833462358523931, 12.778841437293707, 13.708235035616035, 14.63787134609734, 15.626916580424346, 16.561591008990213, 6.773251516682008, 5.75026035719435, 4.813107043950108, 4.01266191035085, 3.0803021922725646, 4.028151150748746, 4.918076062109536, 5.826095900490978, 6.7631371737399135, 7.6989037571478836, 8.771921682176174, 9.754843438404718, 10.742452255685002, 11.728189123065324, 12.78647959487904, 13.712023018439181, 14.648899952716707, 15.612385493754411, 16.561410589044378, 17.514522376657055, 7.7092926007750755, 6.697650865131682, 5.856072809839235, 5.073841390273886, 4.09782101450284, 4.9657068835145814, 5.977305744456251, 6.790177484157981, 7.690716148343157, 8.655714875690723, 9.61157787201492, 10.660919419818569, 11.671155226979145, 12.727061201969823, 13.680680812190024, 14.669679831115026, 15.68472256769888, 16.64875162255441, 17.533248623791994, 18.466208024193904], [18.497404842540053, 17.50496012508522, 16.51387774731905, 15.45433216253435, 14.514814780936515, 13.464356622932781, 12.483281325215428, 11.517279833543522, 10.498050343294919, 9.559335590643206, 8.630596116119259, 7.750100853730089, 6.753599005501051, 5.945790256442857, 5.0129688880653, 5.9703232234749, 7.021736678161988, 7.81696406415441, 8.663676801277601, 9.61777243457104, 17.49494151539277, 17.520641231940214, 16.590425203525825, 15.650079393263752, 14.667697181521865, 13.950035489560236, 13.438057700102489, 12.452651805056247, 11.437814292641486, 10.486172667232104, 9.677623784907308, 8.684984322156641, 7.745921569399232, 6.879825463664057, 6.0212250480966265, 6.9350798468735135, 7.975016315044751, 8.79741648786032, 9.661937832808368, 8.765003962856088, 16.66431680490065, 16.587609638468944, 15.622184729462285, 14.643143346463747, 13.722043955959666, 12.984213915857731, 13.794610403801261, 13.399221319521628, 12.459991678197186, 11.534844454091129, 10.668553036291103, 9.631364214187455, 8.78375081448372, 7.918252911545153, 6.995654665884501, 7.965506617442276, 8.946065861808577, 9.642954796915577, 8.70344233973341, 7.805736177449008, 16.113663251462814, 15.629855287574756, 14.684973365529071, 13.63257136108748, 12.703420156367857, 12.006571312825484, 12.854675358607112, 13.813345895313788, 13.435217298949313, 12.579792431361147, 11.710232797405629, 10.682592004290257, 9.769316997402484, 8.86058894930575, 8.030695537658655, 8.91519547925421, 9.809388930776272, 8.79515592430678, 7.774958256657108, 6.834992396229051, 15.287245129447887, 14.637409272926348, 13.71200133587635, 12.648481898389997, 11.71778676469065, 11.003747015153177, 11.879716877493987, 12.774125021356083, 13.64017653012659, 13.593283786672952, 12.621422157627226, 11.618138964138572, 10.712916204737077, 9.845163031024576, 9.080069734649657, 9.96518254434243, 8.982309853854312, 7.9344419981643375, 6.891907471198928, 5.946467222668888, 14.648306027528237, 13.63023099660856, 12.748098549221297, 11.745580828282863, 10.740239333116806, 9.990401111989861, 10.91800152711576, 11.71443941836681, 12.702008075144775, 13.670114153726452, 13.563210249920067, 12.629561803318683, 11.6779599967901, 10.846376583410809, 10.100473893362697, 11.01310647717836, 9.95425867535726, 8.88938443604574, 7.893037094751691, 6.962834862311046, 13.606191642550806, 12.666234782942002, 11.73127399103444, 10.73729322108404, 9.774299857328696, 9.023154786998262, 9.941212871286435, 10.705314586785361, 11.659729513112165, 12.68394068523969, 13.755604500235576, 13.574950417373223, 12.622922110773901, 11.902621519828568, 11.079054252245495, 11.832771569013564, 10.8091098188567, 9.866283478481844, 8.861613980561623, 7.932548152037092, 12.706498003480545, 11.669154604544794, 10.705821896241163, 9.739020977482829, 8.741073694293112, 7.981417527669036, 8.879293036454426, 9.748501633918469, 10.706785702354539, 11.725745779370644, 12.735495943172465, 13.705909470287903, 13.608185475617972, 12.928861048981679, 12.05262291821333, 12.698181225128623, 11.750761305809755, 10.76647571525448, 9.811229890208859, 8.870510190102936, 11.774079391088149, 10.717773824048955, 9.737759099362707, 8.770908172136739, 7.8152500358771855, 6.944846698904996, 7.899292912861999, 8.775140165654175, 9.75540883322186, 10.73435070034727, 11.752264517181393, 12.679784605945981, 13.659357751587903, 13.893144307348187, 13.0471149026378, 13.675985115656689, 12.775674579612117, 11.833316528626831, 10.873834721062632, 9.838550917901646, 10.756481265003256, 9.744618572532403, 8.807224009389087, 7.8131478156656025, 6.870278484993342, 5.966605099857139, 6.89520685293975, 7.8205986388074145, 8.809825080238772, 9.73966291545998, 10.776474183616303, 11.67611351158877, 12.68345639039542, 13.543034011647748, 14.084377231365236, 14.674340185916462, 13.7473761043249, 12.766614430169557, 11.731476558111934, 10.700842994973735, 9.746557996646587, 8.799810402660233, 7.852363732429427, 6.853140623843089, 5.827100785876278, 4.898735319546459, 5.862437085581963, 6.764417521936095, 7.783415999757731, 8.822688038547735, 9.788539656900202, 10.710953023822517, 11.637578070590543, 12.60824560263881, 13.600617534148892, 14.55036128331767, 14.730686253376952, 13.665768163033949, 12.648098151991544, 11.646687660237209, 8.858257999956399, 7.789957849090538, 6.796229823517805, 5.856333125334654, 4.829591030243163, 3.844849414514046, 4.8604487931689295, 5.833045886461152, 6.810950966710919, 7.837111941572097, 8.763205773894851, 9.756734228315768, 10.629579384804758, 11.63757214301243, 12.600118724047375, 13.554743490682727, 14.55625318496763, 14.654358267976006, 13.635061371858164, 12.617495564370412, 7.939525910851646, 6.873489844111026, 5.827744184083621, 4.893632419661243, 3.8579641998906116, 2.894621521830922, 3.8434754496775936, 4.838274603461407, 5.8536884532255336, 6.813711611846353, 7.746513489506591, 8.740401993663262, 9.704361261462205, 10.658570692788865, 11.70457180584012, 12.66681948090031, 13.717661089746336, 14.693768219869444, 14.540699880671049, 13.542853546781604, 6.936510514580787, 6.055063477424208, 5.034489926899856, 3.961033810889253, 2.956189977733966, 1.9372963623780863, 2.898207241255415, 3.9207144221938846, 4.86994952620906, 5.810721533147304, 6.861123374437829, 7.788968323855469, 8.807028171458978, 9.860355858394152, 10.814543025736626, 11.863342515021088, 12.780738169621758, 13.841772942978158, 14.785995500914419, 14.497337595929793, 5.9569541324943405, 5.067450738623878, 4.026813966068186, 2.9533667216048114, 1.9864549927428636, 0.9978465195636853, 1.955225095642364, 2.894870924498599, 3.859623936311217, 4.900385148073294, 5.972287873521182, 7.0004133802591975, 7.959358853052429, 8.916404127391006, 9.852201314975082, 10.809898975581719, 11.84951685862944, 12.90990129310073, 13.859349315390535, 14.792146020213714, 4.9766877386172235, 4.030594338278463, 2.968580298066065, 1.9973394658020356, 0.9698458681504458, 0.0, 0.980773001302113, 1.9297824030536521, 2.9977443025659625, 4.007010335225114, 5.058174275498894, 6.020038247400134, 7.0544008088337495, 8.038990970254478, 9.102237171739219, 10.14735199317984, 11.154457412136994, 12.192914593950865, 13.257975642735847, 14.216458753757324, 5.834275354734196, 4.86984337982198, 3.9018872604662596, 2.970349534792275, 2.007276686906491, 1.0536909813078705, 1.995257827289822, 2.92671852189969, 3.9630425653823136, 4.940212614341324, 6.0047178572123405, 6.987553799956766, 7.961898531399065, 9.001542112617672, 10.011611853122192, 11.038641852259612, 12.050139761908563, 13.04146500954845, 14.046830652486836, 15.07430919126883, 6.906847363748311, 5.88734647281541, 4.831688733871024, 3.9875158786246367, 3.049626971047766, 2.1062608439527786, 2.927233963394877, 3.916468513468443, 4.987641356056823, 5.915792538535852, 6.9168347501604845, 7.926705417817761, 8.906814251145047, 9.871498065730886, 10.863616490373486, 11.808995569143262, 12.73838916746559, 13.668025477946895, 14.657070712273901, 15.591745140839766, 7.743097384832455, 6.7201062253447965, 5.782952912100555, 4.982507778501296, 4.050148060423011, 3.0583052825983006, 3.9482301939590903, 4.856250032340532, 5.793291305589468, 6.729057888997438, 7.802075814025729, 8.784997570254273, 9.772606387534557, 10.758343254914879, 11.816633726728595, 12.742177150288736, 13.679054084566262, 14.642539625603966, 15.591564720893933, 16.544676508506612, 8.679138468925522, 7.667496733282129, 6.825918677989682, 6.043687258424332, 5.029595866341179, 3.995861015364136, 5.007459876305805, 5.820331616007536, 6.720870280192712, 7.685869007540277, 8.641732003864474, 9.691073551668122, 10.701309358828698, 11.757215333819378, 12.71083494403958, 13.699833962964581, 14.714876699548435, 15.678905754403965, 16.563402755641548, 17.49636215604346], [17.51663184123794, 16.524187123783104, 15.533104746016933, 14.473559161232235, 13.5340417796344, 12.483583621630666, 11.502508323913313, 10.536506832241407, 9.517277341992806, 8.578562589341093, 7.649823114817146, 6.769327852427976, 5.772826004198937, 4.974543552991584, 5.8650739753987615, 6.822428310808361, 7.873841765495448, 8.797737065456522, 9.644449802579713, 10.59854543587315, 16.514168514090656, 17.32212259011291, 16.349482010620573, 15.409136200358498, 14.42675398861661, 13.423782947884595, 12.457284698800374, 11.471878803754134, 10.457041291339372, 9.505399665929993, 8.696850783605194, 7.704211320854528, 6.765148568097119, 5.908578760212784, 6.859224894845874, 7.787184934206974, 8.827121402378213, 9.77818948916243, 10.642710834110481, 9.745776964158201, 15.683543803598539, 16.68413843479389, 16.58281673664479, 15.603775353646254, 14.682675963142174, 13.868951905459062, 12.874854400257492, 12.418448318219514, 11.479218676895073, 10.554071452789017, 9.68778003498899, 8.650591212885342, 7.802977813181607, 6.94700620809388, 7.833654512633749, 8.817611704775736, 9.798170949142039, 10.62372779821769, 9.684215341035523, 8.786509178751121, 15.1328902501607, 16.1786461312558, 15.645605372711579, 14.593203368269988, 13.664052163550364, 12.891309302426814, 11.934919355063343, 12.859220750338938, 12.4544442976472, 11.599019430059036, 10.729459796103516, 9.701819002988143, 8.788543996100369, 7.889342245854477, 8.861845674016813, 9.76730056658767, 10.790161932078385, 9.775928925608893, 8.755731257959221, 7.815765397531164, 14.306472128145774, 15.355670855481044, 14.672633343058857, 13.609113905572505, 12.678418771873158, 11.889638763523736, 10.959960873950218, 11.819999876381235, 12.686051385151742, 12.61251078537084, 11.640649156325113, 10.637365962836459, 9.732143203434962, 8.873916327573303, 9.868509593926854, 10.817287631675889, 9.963082855156424, 8.91521499946645, 7.872680472501041, 6.927240223971001, 14.757677930292784, 14.590863003791068, 13.708730556403804, 12.70621283546537, 11.700871340299313, 10.935535985338271, 9.99824552357199, 10.760314273391963, 11.747882930169927, 12.715989008751603, 12.582437248617953, 11.64878880201657, 10.697186995487986, 9.875129879959534, 10.851489991269018, 11.794648037543906, 10.93503167665937, 9.870157437347853, 8.873810096053804, 7.943607863613159, 14.566823649733314, 13.62686679012451, 12.691905998216948, 11.697925228266547, 10.734931864511204, 9.968289660346672, 9.021456867742666, 9.751189441810514, 10.705604368137317, 11.729815540264841, 12.801479355260726, 12.59417741607111, 11.642149109471786, 10.931374816377293, 11.830070350151816, 12.813544570315678, 11.789882820158812, 10.847056479783957, 9.842386981863736, 8.913321153339204, 13.667130010663053, 12.629786611727301, 11.66645390342367, 10.699652984665336, 9.70170570147562, 8.926552401017446, 7.959537032910656, 8.794376488943621, 9.752660557379691, 10.771620634395797, 11.781370798197617, 12.72513646898579, 12.627412474315857, 11.957614345530404, 12.803639016119652, 13.678954226430736, 12.731534307111868, 11.747248716556593, 10.792002891510972, 9.833711840801284, 12.734711398270656, 11.678405831231462, 10.698391106545214, 9.731540179319246, 8.775882043059692, 7.889981572253406, 6.979536909318229, 7.821015020679327, 8.801283688247011, 9.780225555372422, 10.798139372206546, 11.699011604643868, 12.67858475028579, 12.921897603896912, 13.798131000544121, 14.656758116958802, 13.75644758091423, 12.814089529928944, 11.84245902566383, 10.801752568599994, 11.719682915701604, 10.707820223230751, 9.767856016571592, 8.773779822848107, 7.830910492175848, 6.911739973205549, 5.97545084939598, 6.866473493832565, 7.855699935263924, 8.785537770485133, 9.79570118231419, 10.695340510286657, 11.702683389093307, 12.562261010345637, 13.56368134847493, 14.491308317984137, 14.728149105627013, 13.74738743147167, 12.694678208810283, 11.664044645672083, 10.709759647344935, 9.763012053358581, 8.815565383127776, 7.813772631025595, 6.787732793058784, 5.8593673267289645, 4.942681082038193, 5.810292376961245, 6.82929085478288, 7.841915037245623, 8.807766655598089, 9.730180022520404, 10.656805069288431, 11.627472601336699, 12.61984453284678, 13.569588282015559, 14.52902321846777, 14.628969813732297, 13.611299802689892, 12.609889310935557, 9.821459650654747, 8.753159499788886, 7.759431474216154, 6.816965132517161, 5.790223037425671, 4.805481421696553, 3.9406927896251593, 4.878920741486302, 5.85682582173607, 6.856338940269984, 7.782432772592738, 8.775961227013655, 9.648806383502647, 10.65679914171032, 11.619345722745264, 12.573970489380615, 13.575480183665519, 14.609844570618097, 14.598263022556512, 13.58069721506876, 8.902727561549995, 7.836691494809374, 6.79094583478197, 5.856834070359591, 4.818596207073118, 3.855253529013429, 2.889350304702743, 3.884149458486557, 4.899563308250684, 5.83293861054424, 6.765740488204478, 7.75962899236115, 8.723588260160094, 9.677797691486754, 10.723798804538008, 11.686046479598199, 12.736888088444225, 13.712995218567333, 14.647413473400427, 14.506055197479952, 7.9172835158829, 7.035836478726321, 5.9976915775982045, 4.924235461587601, 3.919391628432314, 2.897928369560593, 1.9440820962805643, 2.9399414208917714, 3.8891765249069468, 4.829948531845191, 5.880350373135716, 6.808195322553356, 7.826255170156865, 8.87958285709204, 9.833770024434513, 10.882569513718975, 11.799965168319645, 12.860999941676045, 13.805222499612306, 14.829699539060522, 6.937727133796454, 6.04822373992599, 5.007586967370298, 3.9341397229069237, 2.9672279940449764, 1.958478526746192, 1.0010999506675133, 1.914097923196486, 2.878850935009104, 3.9196121467711813, 4.991514872219069, 6.019640378957084, 6.978585851750315, 7.935631126088892, 8.871428313672968, 9.829125974279606, 10.868743857327328, 11.929128291798618, 12.878576314088422, 13.8113730189116, 5.957460739919337, 5.011367339580576, 3.9493532993681777, 2.9781124671041486, 1.9506188694525588, 0.980773001302113, 0.0, 0.9490094017515392, 2.0169713012638493, 3.0262373339230004, 4.077401274196781, 5.0392652460980205, 6.073627807531636, 7.0582179689523645, 8.121464170437106, 9.166578991877726, 10.17368441083488, 11.212141592648752, 12.277202641433734, 13.235685752455211, 6.815048356036308, 5.850616381124092, 4.882660261768372, 3.9511225360943882, 2.9880496882086036, 2.0177337100403028, 1.014484825987709, 1.945945520597577, 2.982269564080201, 3.959439613039211, 5.023944855910227, 6.006780798654653, 6.981125530096952, 8.020769111315559, 9.030838851820079, 10.0578688509575, 11.06936676060645, 12.060692008246336, 13.066057651184723, 14.093536189966716, 7.887620365050424, 6.868119474117521, 5.812461735173136, 4.9682888799267495, 4.030399972349879, 3.008013482350848, 1.9464609620927642, 2.93569551216633, 4.00686835475471, 4.935019537233739, 5.936061748858371, 6.945932416515648, 7.9260412498429345, 8.890725064428773, 9.882843489071373, 10.828222567841149, 11.757616166163476, 12.687252476644781, 13.676297710971788, 14.610972139537653, 8.723870386134568, 7.700879226646908, 6.763725913402666, 5.963280779803409, 4.913260187095808, 3.9104103699317614, 2.967457192656977, 3.8754770310384195, 4.812518304287355, 5.748284887695325, 6.821302812723616, 7.8042245689521605, 8.791833386232444, 9.777570253612765, 10.835860725426482, 11.761404148986623, 12.698281083264149, 13.661766624301853, 14.61079171959182, 15.563903507204499, 9.659911470227634, 8.648269734584241, 7.806691679291793, 6.956509192076019, 5.881700953674639, 4.847966102697597, 4.0266868750036915, 4.839558614705423, 5.740097278890599, 6.705096006238164, 7.660959002562361, 8.71030055036601, 9.720536357526587, 10.776442332517265, 11.730061942737466, 12.719060961662468, 13.734103698246322, 14.698132753101852, 15.582629754339436, 16.51558915474135], [16.5676224394864, 15.575177722031569, 14.584095344265398, 13.5245497594807, 12.585032377882865, 11.534574219879131, 10.553498922161777, 9.587497430489872, 8.568267940241268, 7.629553187589555, 6.700813713065607, 5.820318450676437, 4.8238166024473985, 5.833674074010574, 6.762979719216363, 7.720334054625963, 8.77174750931305, 9.73447599276648, 10.593459204331253, 11.547554837624691, 15.565159112339119, 16.373113188361376, 15.400472608869038, 14.460126798606963, 13.477744586865075, 12.47477354613306, 11.508275297048838, 10.522869402002597, 9.508031889587835, 8.556390264178454, 7.747841381853656, 6.755201919102989, 5.81613916634558, 6.767709281231774, 7.718355415864864, 8.685090678024576, 9.725027146195814, 10.71492841647239, 11.591720235862022, 10.694786365909742, 14.734534401847, 15.735129033042352, 16.40957740426899, 15.409185994291006, 14.411794054360321, 13.440595119835564, 12.470567304671887, 11.469438916467977, 10.530209275143536, 9.605062051037478, 8.738770633237452, 7.701581811133804, 6.853968411430068, 7.80613672911287, 8.692785033652738, 9.715517448593339, 10.69607669295964, 11.57273719996923, 10.633224742787064, 9.735518580502662, 14.183880848409162, 15.229636729504259, 16.270984147718796, 15.542212770021527, 14.613061565301903, 13.77226134824088, 12.815871400877409, 11.963170779956478, 11.505434895895663, 10.650010028307497, 9.780450394351977, 8.752809601236605, 7.839534594348831, 8.748472766873467, 9.720976195035803, 10.665206310405273, 11.70689130107184, 10.724938327360434, 9.704740659710762, 8.764774799282705, 13.357462726394237, 14.406661453729507, 15.384500532815315, 14.558123307324044, 13.627428173624697, 12.770590809337802, 11.840912919764284, 10.923949905998775, 11.790001414769282, 11.663501383619302, 10.691639754573574, 9.68835656108492, 8.783133801683423, 9.723867663265889, 10.71846092961944, 11.682297788895665, 10.912092256907965, 9.86422440121799, 8.82168987425258, 7.876249625722541, 13.808668528541244, 14.82674355946092, 14.657739958155343, 13.65522223721691, 12.649880742050852, 11.847004299495701, 10.879197569386056, 9.864264303009502, 10.851832959787467, 11.819939038369142, 11.633427846866415, 10.699779400265031, 9.748177593736447, 10.725081215652121, 11.701441326961605, 12.644599373236494, 11.884041078410913, 10.819166839099394, 9.822819497805344, 8.892617265364699, 14.846415772805814, 14.575876191876048, 13.640915399968486, 12.646934630018086, 11.683941266262742, 10.884322233149474, 9.902408913556732, 8.855139471428053, 9.809554397754857, 10.833765569882381, 11.905429384878266, 11.645168014319571, 10.693139707720247, 11.717431254262557, 12.648739774447012, 13.701442599874698, 12.738892221910353, 11.796065881535498, 10.791396383615277, 9.862330555090745, 14.616139412414592, 13.57879601347884, 12.61546330517521, 11.648662386416875, 10.650715103227158, 9.857398239317295, 8.840489078724723, 7.898326518561161, 8.856610586997231, 9.875570664013336, 10.885320827815157, 11.77612706723425, 11.678403072564318, 12.616607707339432, 13.622308440414848, 14.627963628182277, 13.680543708863409, 12.696258118308133, 11.741012293262513, 10.782721242552823, 13.683720800022195, 12.627415232983001, 11.647400508296753, 10.680549581070785, 9.724891444811231, 8.820827410553255, 7.860488955132297, 6.9249650502968665, 7.905233717864552, 8.884175584989961, 9.89954673197559, 10.750002202892329, 11.72957534853425, 12.606021317858449, 13.560761972868029, 14.488211858921613, 14.70545698266577, 13.763098931680485, 12.791468427415369, 11.750761970351533, 12.668692317453143, 11.65682962498229, 10.716865418323131, 9.722789224599646, 8.779919893927387, 7.842585811505398, 6.9062966876958285, 5.970423523450105, 6.959649964881463, 7.889487800102672, 8.84669178056265, 9.746331108535118, 10.753673987341768, 11.613251608594096, 12.614671946723387, 13.542298916232594, 14.552224029287757, 14.696396833223211, 13.643687610561821, 12.613054047423622, 11.658769049096474, 10.71202145511012, 9.764574784879315, 8.762782032777134, 7.736742194810323, 6.8083767284805035, 5.873526920338041, 4.914242406578785, 5.93324088440042, 6.892905635494084, 7.858757253846551, 8.781170620768865, 9.70779566753689, 10.678463199585158, 11.67083513109524, 12.62057888026402, 13.58001381671623, 14.644931907059233, 14.560309204441431, 13.558898712687096, 10.770469052406286, 9.702168901540425, 8.708440875967693, 7.7659745342687, 6.73923243917721, 5.754490823448092, 4.889702191376698, 3.9828707711038414, 4.96077585135361, 5.907329538518445, 6.833423370841199, 7.826951825262116, 8.699796981751106, 9.707789739958779, 10.670336320993723, 11.624961087629075, 12.626470781913978, 13.660835168866557, 14.680132064984399, 14.529706616820299, 9.851736963301533, 8.785700896560913, 7.7399552365335085, 6.80584347211113, 5.767605608824657, 4.804262930764968, 3.8383597064542823, 2.9880994881040968, 4.003513337868224, 4.883929208792701, 5.816731086452939, 6.810619590609611, 7.774578858408554, 8.728788289735213, 9.774789402786467, 10.737037077846658, 11.787878686692684, 12.763985816815792, 13.698404071648886, 14.696250405538331, 8.866292917634441, 7.98484588047786, 6.946700979349743, 5.87324486333914, 4.868401030183853, 3.8469377713121324, 2.8930914980321036, 1.9909320191402324, 2.940167123155408, 3.880939130093652, 4.931340971384177, 5.859185920801817, 6.877245768405326, 7.930573455340501, 8.884760622682975, 9.933560111967434, 10.850955766568104, 11.911990539924505, 12.856213097860765, 13.880690137308981, 7.8867365355479935, 6.99723314167753, 5.956596369121838, 4.8831491246584635, 3.916237395796516, 2.9074879284977313, 1.9501093524190525, 0.9650885214449468, 1.929841533257565, 2.9706027450196424, 4.04250547046753, 5.070630977205545, 6.0295764499987765, 6.986621724337353, 7.9224189119214286, 8.880116572528065, 9.919734455575787, 10.980118890047077, 11.929566912336881, 12.86236361716006, 6.9064701416708765, 5.960376741332116, 4.8983627011197175, 3.927121868855688, 2.899628271204098, 1.9297824030536521, 0.9490094017515392, 0.0, 1.0679618995123101, 2.0772279321714615, 3.128391872445242, 4.090255844346482, 5.124618405780097, 6.109208567200826, 7.172454768685568, 8.217569590126189, 9.224675009083343, 10.263132190897215, 11.328193239682196, 12.286676350703674, 7.764057757787849, 6.799625782875633, 5.831669663519913, 4.900131937845927, 3.937059089960143, 2.966743111791842, 1.9634942277392482, 0.9969361188460377, 2.0332601623286615, 3.0104302112876717, 4.074935454158688, 5.057771396903114, 6.032116128345413, 7.07175970956402, 8.08182945006854, 9.10885944920596, 10.12035735885491, 11.111682606494798, 12.117048249433184, 13.144526788215178, 8.836629766801964, 7.817128875869062, 6.761471136924676, 5.917298281678288, 4.979409374101419, 3.957022884102388, 2.8954703638443036, 1.9866861104147908, 3.057858953003171, 3.9860101354822, 4.987052347106832, 5.996923014764109, 6.9770318480913955, 7.941715662677235, 8.933834087319834, 9.87921316608961, 10.808606764411937, 11.738243074893242, 12.72728830922025, 13.661962737786114, 9.672879787886108, 8.649888628398449, 7.712735315154207, 6.8658430863311315, 5.811165930913409, 4.808316113749363, 3.865362936474579, 2.92646762928688, 3.863508902535816, 4.799275485943786, 5.872293410972077, 6.855215167200622, 7.842823984480905, 8.828560851861226, 9.886851323674943, 10.812394747235084, 11.74927168151261, 12.712757222550314, 13.66178231784028, 14.61489410545296, 10.608920871979175, 9.597279136335782, 8.755701081043334, 7.854414935893621, 6.779606697492241, 5.7458718465151986, 4.924592618821293, 3.8905492129538835, 4.79108787713906, 5.756086604486625, 6.711949600810822, 7.761291148614471, 8.771526955775048, 9.827432930765726, 10.781052540985927, 11.770051559910929, 12.785094296494783, 13.749123351350313, 14.633620352587897, 15.56657975298981], [15.529573126222882, 14.662049452554935, 13.733825118952621, 12.683407335515067, 11.743889953917233, 10.693431795913499, 9.712356498196145, 8.74635500652424, 7.7271255162756365, 6.788410763623924, 5.859671289099976, 5.008818982659765, 5.855516553451715, 6.865374025014891, 7.794679670220681, 8.75203400563028, 9.803447460317367, 10.766175943770797, 11.661421103843562, 12.615516737137, 14.5271097990756, 15.45716624226206, 14.559330184903406, 13.61898437464133, 12.636602162899443, 11.633631122167428, 10.667132873083206, 9.681726978036965, 8.666889465622203, 7.715247840212823, 6.929556118145513, 5.943702451086317, 6.8478391173498965, 7.799409232236091, 8.750055366869182, 9.716790629028894, 10.756727097200132, 11.746628367476706, 12.65968213537433, 11.76274826542205, 13.696485088583481, 14.697079719778833, 15.568434980303358, 14.568043570325374, 13.57065163039469, 12.599452695869932, 11.629424880706255, 10.628296492502345, 9.689066851177904, 8.763919627071848, 7.92727116522078, 6.890082343117132, 7.885668362434385, 8.837836680117187, 9.724484984657057, 10.747217399597657, 11.727776643963958, 12.64069909948154, 11.701186642299373, 10.80348048001497, 13.115918948896852, 14.161674829991949, 15.203022248206485, 15.424836219664918, 14.495685014945295, 13.525749873263875, 12.569359925900404, 11.630077122228148, 10.66429247193003, 9.808867604341867, 8.968950926335305, 7.9413101332199325, 8.871234545353147, 9.780172717877784, 10.75267614604012, 11.696906261409591, 12.738591252076159, 11.792900226872742, 10.77270255922307, 9.832736698795014, 12.289500826881927, 13.338699554217197, 14.316538633303004, 15.380058070789357, 14.632895072302585, 13.732120781859312, 12.802442892285793, 11.885479878520284, 11.031849614970973, 10.822358959653672, 9.880140286556902, 8.876857093068248, 9.81483375268774, 10.755567614270205, 11.750160880623756, 12.713997739899982, 11.980054156420273, 10.932186300730299, 9.88965177376489, 8.94421152523485, 12.740706629028933, 13.75878165994861, 14.79621352375352, 14.660689135894797, 13.65534764072874, 12.80853427201721, 11.840727541907565, 10.825794275531011, 10.093681159989158, 10.924436119356685, 10.821928378849742, 9.88827993224836, 10.779877544740764, 11.756781166656438, 12.733141277965922, 13.67629932424081, 12.952002977923222, 11.887128738611702, 10.890781397317653, 9.960579164877007, 13.778453873293504, 14.718410732902308, 14.646382298646374, 13.652401528695973, 12.68940816494063, 11.845852205670983, 10.863938886078241, 9.816669443949563, 9.051402597956548, 9.938262650869923, 11.009926465865808, 10.8336685463029, 11.724839658724564, 12.749131205266874, 13.680439725451329, 14.733142550879014, 13.806854121422662, 12.864027781047806, 11.859358283127586, 10.930292454603054, 14.590154768980758, 14.584262912156728, 13.620930203853097, 12.654129285094763, 11.656182001905046, 10.818928211838804, 9.802019051246232, 8.85985649108267, 8.098458787198922, 8.943626362006368, 9.953376525808189, 10.83918683172541, 11.829564893479636, 12.633364340716117, 13.618313721783657, 14.529075513940837, 14.748505608375718, 13.764220017820442, 12.808974192774821, 11.803284932558423, 14.689187698700083, 13.632882131660889, 12.652867406974641, 11.686016479748673, 10.730358343489119, 9.782357383074764, 8.822018927653806, 7.886495022818376, 7.096350537545551, 7.952231282982993, 8.96260649646675, 9.813061967383488, 10.79263511302541, 11.669081082349608, 12.623821737359188, 13.551271623412772, 14.485285434827023, 14.831060831192794, 13.81203211742097, 12.771325660357133, 13.689256007458743, 12.67739331498789, 11.722332317001019, 10.728256123277534, 9.785386792605275, 8.804115784026907, 7.867826660217338, 6.931953495971614, 6.149965997075309, 6.957543498095704, 7.909751545053809, 8.809390873026278, 9.816733751832928, 10.676311373085255, 11.677731711214548, 12.605358680723755, 13.615283793778918, 14.59604546793426, 14.664251300567422, 13.633617737429223, 12.679332739102074, 11.73258514511572, 10.785138474884915, 9.783345722782736, 8.757305884815926, 7.828940418486107, 6.8350568928595505, 5.875772379100294, 5.095943966071649, 5.955965399985242, 6.921817018337709, 7.8442303852600235, 8.77085543202805, 9.741522964076317, 10.733894895586399, 11.683638644755177, 12.643073581207389, 13.707991671550392, 14.696524293565602, 14.579462402692696, 11.791032742411886, 10.722732591546025, 9.729004565973293, 8.786538224274302, 7.759796129182812, 6.775054513453695, 5.9102658813823, 4.9444007436253505, 4.029909270180971, 4.970389303009603, 5.896483135332358, 6.890011589753274, 7.7628567462422655, 8.770849504449938, 9.733396085484882, 10.688020852120234, 11.689530546405138, 12.7188270723022, 13.657778015586779, 14.563481941304719, 10.872300653307134, 9.806264586566513, 8.76051892653911, 7.826407162116732, 6.78816929883026, 5.824826620770571, 4.858923396459884, 3.9496294606256064, 3.072646756695585, 3.946988973283859, 4.879790850944097, 5.873679355100769, 6.837638622899712, 7.791848054226372, 8.795549720661521, 9.757797395721711, 10.72975224004788, 11.705859370170987, 12.640277625004082, 13.638123958893527, 9.93425481714675, 9.034892404613469, 7.967264669355346, 6.893808553344743, 5.888964720189456, 4.867501461317735, 3.9136551880377057, 2.952461991661742, 2.0032268876465666, 2.943998894584811, 3.9944007358753355, 4.9222456852929755, 5.932118929376605, 6.969326464243214, 7.83996944763282, 8.865598212455124, 9.782993867055794, 10.844028640412194, 11.788251198348455, 12.812728237796671, 8.954698435060303, 8.047279665813138, 7.006642893257446, 5.933195648794071, 4.966283919932124, 3.928051618503334, 2.970673042424655, 1.9404630441636477, 0.9757100323510298, 2.016471244113107, 3.088373969560995, 4.002669077693234, 4.961614550486465, 5.918659824825042, 6.854457012409117, 7.812154673015755, 8.851772556063477, 9.912156990534767, 10.86160501282457, 11.79440171764775, 7.974432041183186, 7.028338640844425, 5.966324600632027, 4.995083768367998, 3.9675901707164085, 2.9977443025659625, 2.0169713012638493, 1.0679618995123101, 0.0, 1.0092660326591512, 2.0604299729329316, 3.022293944834171, 4.056656506267787, 5.041246667688515, 6.104492869173257, 7.149607690613878, 8.156713109571033, 9.195170291384905, 10.260231340169886, 11.218714451191364, 8.832019657300158, 7.867587682387941, 6.899631563032221, 5.9680938373582375, 5.005020989472453, 4.034705011304152, 3.031456127251558, 2.0286360698503554, 0.9923120263677315, 1.969482075326742, 3.006973554646378, 3.9898094973908034, 4.964154228833102, 6.00379781005171, 7.0138675505562285, 8.04089754969365, 9.0523954593426, 10.043720706982487, 11.049086349920874, 12.076564888702867, 9.904591666314273, 8.885090775381371, 7.829433036436985, 6.985260181190599, 6.047371273613729, 5.0249847836146975, 3.963432263356613, 3.0183860614191085, 2.060540990656061, 2.9886921731350897, 3.9587878857749477, 4.95887370150059, 5.938982534827876, 6.903666349413716, 7.895784774056315, 8.84116385282609, 9.770557451148418, 10.700193761629723, 11.68923899595673, 12.623913424522595, 10.740841687398417, 9.717850527910757, 8.780697214666516, 7.89754303733545, 6.842865881917728, 5.840016064753681, 4.897062887478897, 3.9581675802911978, 3.0520094345191446, 3.9581330619781556, 4.947619332037507, 5.930541088266052, 6.899645340732999, 7.885382208113319, 8.90664213524608, 9.774345433971565, 10.711222368249091, 11.674707909286795, 12.623733004576762, 13.57684479218944, 11.676882771491483, 10.66524103584809, 9.823662980555643, 8.886114886897937, 7.811306648496559, 6.777571797519516, 5.956292569825611, 4.922249163958201, 3.979588409122389, 4.914944180520994, 5.870807176845191, 6.92014872464884, 7.828348312027141, 8.88425428701782, 9.83787389723802, 10.748337063922264, 11.74754068985777, 12.711074038086794, 13.595571039324378, 14.52853043972629], [14.52030709356373, 13.652783419895783, 12.72455908629347, 11.683476587170563, 10.743959205572729, 9.693501047568995, 8.712425749851642, 7.746424258179736, 6.846506660428601, 5.907791907776889, 4.9790524332529404, 5.9364844960120475, 6.847671035948543, 7.857528507511718, 8.786834152717509, 9.74418848812711, 10.795601942814196, 11.758330426267626, 12.670687136502714, 13.624782769796152, 13.517843766416448, 14.447900209602908, 13.559399436558902, 12.619053626296827, 11.63667141455494, 10.633700373822924, 9.667202124738703, 8.801108122189929, 7.786270609775168, 6.8346289843657875, 6.0489372622984785, 6.871367964438599, 7.819562312384915, 8.791563714732918, 9.74220984936601, 10.708945111525724, 11.748881579696961, 12.738782849973536, 13.668948168033483, 12.772014298081203, 12.687219055924329, 13.68781368711968, 14.568504231958855, 13.56811282198087, 12.570720882050185, 11.599521947525428, 10.629494132361751, 9.74767763665531, 8.808447995330868, 7.883300771224812, 7.105799531913275, 7.817747856469414, 8.849517036559869, 9.818784677938226, 10.716639467153884, 11.739371882094487, 12.719931126460787, 13.649965132140691, 12.710452674958525, 11.812746512674122, 12.1066529162377, 13.152408797332797, 14.193756215547333, 14.424905471320415, 13.495754266600791, 12.525819124919371, 11.5694291775559, 10.749458266381112, 9.783673616082995, 8.92824874849483, 8.172049554971323, 8.868975646572215, 9.835083219478632, 10.761120715698823, 11.733624143861158, 12.68906074390642, 13.730745734572988, 12.802166259531894, 11.781968591882222, 10.842002731454166, 11.280234794222775, 12.329433521558045, 13.307272600643852, 14.370792038130205, 14.401248110568822, 13.474065548242544, 12.544387658669025, 11.766035036842778, 10.812179408713817, 9.941740103806636, 9.144711968125938, 9.80452260642053, 10.771039338645341, 11.711773200227807, 12.706366466581358, 13.670203325857583, 12.989320189079425, 11.941452333389451, 10.898917806424041, 9.953477557894002, 11.731440596369783, 12.74951562728946, 13.78694749109437, 14.789465212032804, 14.546962028012741, 13.700148659301208, 12.732341929191563, 11.717408662815009, 10.841166869638274, 9.934506492764198, 10.086500060418778, 10.815945445600642, 11.736083130698365, 12.71298675261404, 13.689346863923523, 14.632504910198412, 13.961269010582374, 12.896394771270854, 11.900047429976805, 10.96984519753616, 12.769187840634354, 13.709144700243158, 14.680338714961852, 14.544015915979974, 13.581022552224631, 12.73746659295498, 11.755553273362239, 10.70828383123356, 9.798888307605663, 8.948333024277437, 10.019996839273322, 10.83056521132142, 11.82489863173122, 12.66967424327674, 13.600982763461195, 14.609228263269394, 14.816120154081814, 13.873293813706958, 12.868624315786738, 11.939558487262206, 13.580888736321608, 14.654010602635662, 14.512544591137098, 13.545743672378764, 12.547796389189047, 11.710542599122805, 10.69363343853023, 9.751470878366668, 8.845944496848038, 7.953696735413881, 8.9634468992157, 9.849257205132922, 10.839635266887148, 11.643434714123629, 12.628384095191167, 13.539145887348347, 14.486565806667215, 14.766831267704772, 13.811585442659151, 12.802039476593855, 14.513307348714005, 14.52449651894489, 13.544481794258642, 12.577630867032674, 11.62197273077312, 10.673971770358765, 9.713633314937804, 8.778109410102374, 7.843836247194666, 6.962301656390505, 7.9726768698742605, 8.823132340791, 9.802705486432922, 10.679151455757118, 11.633892110766698, 12.561341996820282, 13.495355808234534, 14.460952074306588, 14.810786661456401, 13.770080204392565, 14.67064459580241, 13.614568605938658, 12.61394670428502, 11.619870510561535, 10.677001179889276, 9.695730171310908, 8.759441047501339, 7.823567883255613, 6.897451706724424, 5.967613871503215, 6.919821918461321, 7.819461246433789, 8.82680412524044, 9.686381746492765, 10.687802084622056, 11.615429054131264, 12.625354167186426, 13.606115841341769, 14.612628694717964, 14.632372281464654, 13.678087283137506, 12.731339689151152, 11.783893018920347, 10.755902882184024, 9.729863044217215, 8.801497577887396, 7.726671280143551, 6.767386766384294, 5.987558353355648, 4.966035773392754, 5.931887391745221, 6.854300758667535, 7.78092580543556, 8.751593337483827, 9.74396526899391, 10.69370901816269, 11.6531439546149, 12.718062044957902, 13.68725826090645, 14.525023812778771, 12.789787286447318, 11.721487135581457, 10.727759110008725, 9.767888792665582, 8.741146697574091, 7.756405081844974, 6.886621969239332, 5.836015130909351, 4.92152365746497, 3.980459676417115, 4.9065535087398695, 5.900081963160786, 6.7729271196497765, 7.780919877857448, 8.743466458892392, 9.698091225527744, 10.699600919812648, 11.70956103964305, 12.648511982927628, 13.554215908645569, 11.871055197342566, 10.805019130601945, 9.759273470574541, 8.825161706152164, 7.76951986722154, 6.8061771891618505, 5.836043001693421, 4.841243847909606, 3.9642611439795843, 2.957059346691371, 3.889861224351609, 4.88374972850828, 5.847708996307223, 6.801918427633883, 7.786283688002371, 8.748531363062561, 9.72048620738873, 10.696593337511837, 11.631011592344931, 12.628857926234376, 10.9435208498059, 10.044158437272621, 8.976530702014497, 7.903074586003894, 6.898230752848606, 5.876767493976886, 4.912397347095409, 3.8440763789457417, 2.8948412749305663, 1.9540692679923222, 3.004471109282847, 3.932316058700487, 4.922852896717455, 5.960060431584064, 6.830703414973669, 7.856332179795974, 8.773727834396643, 9.834762607753044, 10.778985165689305, 11.80346220513752, 9.963964467719453, 9.05654569847229, 8.015908925916598, 6.9424616814532225, 5.975549952591275, 4.937317651162485, 3.979939075083806, 2.949729076822799, 1.9849760650101809, 1.0241092870991846, 2.0960120125470723, 2.9934030450340834, 3.952348517827315, 4.909393792165892, 5.845190979749967, 6.8028886403566045, 7.842506523404326, 8.902890957875616, 9.85233898016542, 10.7851356849886, 8.983698073842337, 8.037604673503576, 6.975590633291179, 6.00434980102715, 4.97685620337556, 4.007010335225114, 3.026237333923001, 2.0772279321714615, 1.0092660326591512, 0.0, 1.0511639402737807, 2.01302791217502, 3.0473904736086364, 4.031980635029364, 5.095226836514106, 6.1403416579547265, 7.147447076911882, 8.185904258725753, 9.250965307510734, 10.209448418532212, 9.84128568995931, 8.876853715047094, 7.908897595691373, 6.9773598700173896, 6.0142870221316045, 5.043971043963304, 4.04072215991071, 3.0379021025095065, 2.001578059026883, 1.0508187682553571, 1.9977075219872273, 2.9805434647316527, 3.9548881961739517, 4.994531777392559, 6.004601517897077, 7.031631517034498, 8.043129426683448, 9.034454674323335, 10.039820317261722, 11.067298856043715, 10.913857698973425, 9.894356808040524, 8.838699069096137, 7.994526213849751, 7.056637306272879, 6.0342508162738495, 4.972698296015765, 4.02765209407826, 3.036224499767083, 2.108073317288054, 2.949521853115797, 3.949607668841439, 4.929716502168725, 5.894400316754565, 6.886518741397164, 7.831897820166939, 8.761291418489266, 9.690927728970571, 10.679972963297578, 11.614647391863443, 11.750107720057569, 10.72711656056991, 9.789963247325668, 8.889697519832279, 7.8350203644145555, 6.8321705472505085, 5.889217369975724, 4.950322062788025, 4.01328078953909, 3.07751420613112, 3.9383532993783565, 4.921275055606901, 5.890379308073848, 6.876116175454168, 7.89737610258693, 8.765079401312413, 9.701956335589939, 10.665441876627643, 11.61446697191761, 12.567578759530289, 12.686148804150635, 11.674507068507243, 10.832929013214795, 9.878269369394767, 8.803461130993387, 7.769726280016344, 6.948447052322439, 5.914403646455028, 4.940859764142334, 4.034325324673959, 4.884671370129908, 5.934012917933557, 6.81908227936799, 7.8749882543586684, 8.828607864578869, 9.739071031263112, 10.738274657198618, 11.701808005427642, 12.586305006665226, 13.519264407067139], [13.46914315328995, 12.601619479622004, 11.67339514601969, 10.632312646896782, 9.692795265298948, 8.642337107295214, 7.66126180957786, 6.695260317905955, 5.809189143395502, 4.870474390743789, 5.734097534759306, 6.6915295975184135, 7.638997843127137, 8.648855314690312, 9.578160959896103, 10.535515295305704, 11.58692874999279, 12.54965723344622, 13.568568006288084, 14.522663639581522, 12.466679826142668, 13.396736269329129, 12.50823549628512, 11.567889686023046, 10.585507474281158, 9.582536433549143, 8.616038184464921, 7.76379060515683, 6.7489530927420684, 5.797311467332688, 6.79745922660239, 7.626413065944965, 8.57460741389128, 9.57966241334571, 10.530308547978802, 11.500271918704318, 12.540208386875555, 13.53010965715213, 14.509413074822746, 13.69393020734583, 11.63605511565055, 12.636649746845901, 13.517340291685073, 12.516948881707089, 11.519556941776404, 10.548358007251647, 9.57833019208797, 8.71036011962221, 7.771130478297769, 6.8459832541917125, 7.854321496217187, 8.57279295797578, 9.604562138066235, 10.573829779444592, 11.504738165766677, 12.53069868927308, 13.511257933639381, 14.474167433838451, 13.761616615232306, 12.863910452947904, 11.05548897596392, 12.101244857059017, 13.142592275273554, 13.373741531046633, 12.44459032632701, 11.47465518464559, 10.518265237282119, 9.712140749348013, 8.746356099049896, 7.890931231461731, 8.848312302843109, 9.624020748078582, 10.590128320984999, 11.51616581720519, 12.488669245367525, 13.459330251227838, 14.51201523737786, 13.853330199805676, 12.833132532156004, 11.893166671727947, 10.229070853948995, 11.278269581284265, 12.256108660370073, 13.319628097856425, 13.350084170295041, 12.422901607968763, 11.493223718395244, 10.72871751980968, 9.774861891680718, 8.904422586773535, 9.820974715997723, 10.559567707926897, 11.526084440151708, 12.466818301734174, 13.461411568087724, 14.42524842736395, 14.040484129353207, 12.992616273663232, 11.950081746697823, 11.004641498167784, 10.680276656096002, 11.698351687015679, 12.735783550820589, 13.738301271759022, 14.327631601868886, 13.422745798883117, 12.454939068773472, 11.774196531944092, 10.713030346662533, 9.871692318394677, 10.12390784965375, 10.7656994376801, 11.759606358019159, 12.697213268384111, 13.550857211033604, 14.494015257308492, 15.012432950856155, 13.947558711544636, 12.951211370250586, 12.02100913780994, 11.718023900360572, 12.657980759969377, 13.629174774688071, 14.647716403763287, 14.632186492498413, 13.718234216294539, 12.736320896701796, 11.68905145457312, 10.733660426285244, 9.883105142957017, 9.127831619311717, 9.82031082362556, 10.814644244035359, 11.64096833196635, 12.572276852150805, 13.580522351959006, 14.424573178660296, 14.92445775398074, 13.919788256060519, 12.990722427535987, 12.529724796047827, 13.60284666236188, 14.56617937066551, 14.596907612652545, 13.598960329462829, 12.71387351299853, 11.674401061869787, 10.732238501706227, 9.780716615527618, 8.888468854093462, 8.06168352005749, 8.839002817437061, 9.829380879191287, 10.61472880281324, 11.59967818388078, 12.51043997603796, 13.457859895356828, 14.442145485912103, 14.862749382932932, 13.853203416867636, 13.462143408440223, 14.518448975479417, 14.595645734532424, 13.628794807306456, 12.673136671046901, 11.725135710632546, 10.694400938277361, 9.758877033441932, 8.778608365874247, 7.897073775070086, 7.041845233233365, 7.812877953095139, 8.792451098737061, 9.65044554444673, 10.60518619945631, 11.532636085509894, 12.466649896924146, 13.4322461629962, 14.477436605458164, 14.821244144666347, 14.50459271760597, 14.665732546212439, 13.665110644558801, 12.671034450835316, 11.728165120163057, 10.74689411158469, 9.81060498777512, 8.821450266835363, 7.8322238254040055, 6.902385990182797, 5.988990281820426, 6.809206858737928, 7.798349328324321, 8.657675835182378, 9.65909617331167, 10.586723142820878, 11.59664825587604, 12.577409930031383, 13.561464754444183, 14.419704537768464, 14.729251223411286, 13.782503629424932, 12.835056959194127, 11.807066822457806, 10.781026984490996, 9.852661518161177, 8.777835220417332, 7.818550706658074, 6.930906829079397, 5.9008078920723355, 5.001055755104326, 5.844046370971675, 6.752219894125172, 7.72288742617344, 8.715259357683522, 9.6650031068523, 10.608114315912696, 11.673032406255698, 12.636094320632669, 13.47385987250499, 13.840951226721097, 12.772651075855237, 11.778923050282504, 10.819052732939362, 9.792310637847871, 8.807569022118754, 7.937785909513113, 6.887179071183131, 5.86487213318872, 4.915231795096696, 3.9757218720989744, 4.889827575464926, 5.744221208339389, 6.75221396654706, 7.6985071511476955, 8.65306158682554, 9.654571281110444, 10.65839709936927, 11.597348042653847, 12.503051968371787, 12.922219137616347, 11.856183070875726, 10.810437410848321, 9.876325646425943, 8.82068380749532, 7.85734112943563, 6.8872069419672, 5.8924077881833865, 4.907609619703334, 3.8918314653709523, 2.959029587710714, 3.8653415175830625, 4.819003084996836, 5.773212516323495, 6.73511974772859, 7.697367422788781, 8.669322267114948, 9.645429397238056, 10.57984765207115, 11.577693985960595, 11.994684790079681, 11.095322377546399, 10.027694642288278, 8.954238526277676, 7.949394693122388, 6.927931434250667, 5.963561287369189, 4.895240319219522, 3.9460052152043468, 3.0052332082661026, 1.9911355654286849, 2.913907847775269, 3.871688956443673, 4.9088964913102835, 5.779539474699889, 6.805168239522192, 7.722563894122861, 8.78359866747926, 9.727821225415523, 10.75229826486374, 11.015128407993235, 10.10770963874607, 9.067072866190378, 7.993625621727003, 7.026713892865056, 5.9884815914362655, 5.031103015357587, 4.00089301709658, 3.0361400052839613, 2.075273227372965, 1.0618600364269775, 1.9422391047603025, 2.9011845775535337, 3.8582298518921108, 4.794027039476187, 5.751724700082823, 6.791342583130545, 7.851727017601834, 8.801175039891639, 9.733971744714818, 10.034862014116118, 9.088768613777358, 8.02675457356496, 7.0555137413009295, 6.02802014364934, 5.058174275498894, 4.077401274196781, 3.128391872445242, 2.0604299729329316, 1.0511639402737807, 0.0, 0.9618639719012392, 1.9962265333348554, 2.9808166947555836, 4.044062896240326, 5.089177717680946, 6.096283136638101, 7.134740318451973, 8.199801367236955, 9.158284478258432, 10.892449630233092, 9.928017655320875, 8.960061535965155, 8.02852381029117, 7.065450962405385, 6.0567911350152634, 5.0535422509626695, 4.025081514761922, 2.988757471279298, 2.0115874223202876, 0.9465435817134467, 1.9293795244578718, 2.903724255900171, 3.9433678371187777, 4.953437577623297, 5.980467576760717, 6.9919654864096685, 7.983290734049555, 8.988656376987942, 10.016134915769936, 11.965021639247206, 10.945520748314305, 9.889863009369918, 8.987551716907634, 8.029416314129985, 6.969816671002036, 5.9082641507439515, 4.898724149534057, 3.827551306945677, 2.899400124466648, 1.898357912842016, 2.898443728567658, 3.878552561894945, 4.843236376480784, 5.835354801123383, 6.780733879893159, 7.710127478215487, 8.639763788696792, 9.628809023023798, 10.563483451589663, 12.647988589842939, 11.624997430355279, 10.687844117111037, 9.68102432701087, 8.62634717159315, 7.6234973544291025, 6.680544177154318, 5.741648869966619, 4.804607596717684, 3.868841013309714, 2.8871893591045756, 3.8701111153331205, 4.839215367800067, 5.824952235180388, 6.846212162313149, 7.713915461038633, 8.65079239531616, 9.614277936353863, 10.56330303164383, 11.516414819256509, 13.584029673936005, 12.572387938292612, 11.685725686462872, 10.66959617657336, 9.594787938171981, 8.561053087194939, 7.739773859501033, 6.705730453633622, 5.732186571320928, 4.789370426180325, 3.8335074298561276, 4.882848977659776, 5.7679183390942095, 6.823824314084888, 7.777443924305089, 8.687907090989333, 9.687110716924838, 10.650644065153863, 11.535141066391446, 12.46810046679336], [12.50727918138871, 11.639755507720764, 10.71153117411845, 9.670448674995543, 8.730931293397708, 7.680473135393975, 6.699397837676622, 5.733396346004716, 4.9441125408633155, 5.832338362645028, 6.695961506660545, 7.653393569419652, 8.600861815028377, 9.610719286591554, 10.540024931797342, 11.497379267206943, 12.54879272189403, 13.51152120534746, 14.530431978189325, 15.484527611482763, 11.504815854241428, 12.434872297427889, 11.546371524383883, 10.606025714121808, 9.62364350237992, 8.620672461647905, 7.654174212563682, 6.802599544295363, 5.883876490209882, 6.7591754392339265, 7.759323198503629, 8.588277037846204, 9.53647138579252, 10.54152638524695, 11.492172519880041, 12.462135890605557, 13.502072358776795, 14.49197362905337, 15.471277046723985, 14.65579417924707, 10.674191143749312, 11.674785774944663, 12.555476319783835, 11.555084909805851, 10.557692969875166, 9.586494035350409, 8.61646622018673, 7.749169058760744, 6.906053875765583, 7.807847226092951, 8.816185468118427, 9.534656929877018, 10.566426109967473, 11.53569375134583, 12.466602137667916, 13.49256266117432, 14.473121905540621, 15.43603140573969, 14.723480587133546, 13.825774424849143, 10.09362500406268, 11.139380885157777, 12.180728303372314, 12.411877559145394, 11.48272635442577, 10.51279121274435, 9.55640126538088, 8.750949688486546, 7.88127949651771, 8.85279520336297, 9.810176274744347, 10.58588471997982, 11.551992292886236, 12.478029789106428, 13.450533217268763, 14.421194223129076, 15.473879209279097, 14.815194171706915, 13.794996504057243, 12.855030643629187, 9.267206882047756, 10.316405609383025, 11.294244688468833, 12.357764125955185, 12.388220198393803, 11.461037636067523, 10.531359746494005, 9.79017056244425, 8.909785289148534, 9.866286558674775, 10.78283868789896, 10.815258304958974, 11.762786178170945, 12.70352003975341, 13.609397397845406, 14.573234257121632, 15.002348101254446, 13.954480245564472, 12.911945718599062, 11.966505470069023, 9.718412684194764, 10.736487715114441, 11.773919578919351, 12.776437299857784, 13.365767629967648, 12.460881826981877, 11.493075096872232, 10.849856165433522, 9.847953744130349, 10.833556290295917, 10.74803054471068, 9.803835465778862, 10.797742386117921, 11.735349296482873, 12.588993239132366, 13.532151285407254, 14.537287378771902, 14.909422683445875, 13.913075342151826, 12.982873109711178, 10.756159928459335, 11.696116788068139, 12.667310802786833, 13.685852431862049, 14.331707105755758, 13.428128151973477, 12.469863752701556, 11.85898099701497, 10.89023230616296, 10.771858402820001, 9.824843733805256, 8.858446851724322, 9.85278027213412, 10.679104360065113, 11.610412880249568, 12.618658380057767, 13.462709206759056, 14.405535547133912, 14.881652227961757, 13.952586399437225, 11.567860824146589, 12.640982690460643, 13.604315398764273, 14.656320516552794, 14.518329270609888, 13.602626772861516, 12.563154321732773, 11.620991761569211, 10.669469875390604, 9.777222113956446, 8.853335601753443, 7.877138845535823, 8.86751690729005, 9.652864830912002, 10.63781421197954, 11.54857600413672, 12.495995923455588, 13.480281514010864, 14.435527339056485, 14.772572358014695, 12.500279436538985, 13.55658500357818, 14.536599728264427, 14.548163748453515, 13.59250561219396, 12.644504651779608, 11.583154198140347, 10.647630293304918, 9.667361625737232, 8.785827034933071, 7.846188027665199, 6.851013981193901, 7.830587126835822, 8.688581572545491, 9.643322227555071, 10.570772113608655, 11.504785925022906, 12.470382191094961, 13.515572633556925, 14.451850505354141, 13.542728745704732, 14.598804735568484, 14.584479585705862, 13.590403391982377, 12.647534061310118, 11.66626305273175, 10.729973928922181, 9.710203526698349, 8.720977085266991, 7.791139250045783, 6.793333076252259, 5.847342886836691, 6.836485356423083, 7.695811863281138, 8.69723220141043, 9.624859170919636, 10.634784283974799, 11.615545958130141, 12.599600782542945, 13.457840565867226, 14.412125564194374, 14.701872570571993, 13.754425900341188, 12.726435763604867, 11.700395925638057, 10.772030459308239, 9.697204161564393, 8.737919647805136, 7.819660088942383, 6.789561151935321, 5.889809014967311, 4.8821823990704365, 5.790355922223934, 6.761023454272201, 7.753395385782282, 8.703139134951062, 9.646250344011456, 10.711168434354459, 11.674230348731431, 12.511995900603752, 14.760320167868159, 13.692020017002298, 12.698291991429565, 11.738421674086423, 10.711679578994932, 9.726937963265815, 8.857154850660173, 7.806548012330191, 6.753625393051705, 5.803985054959682, 4.864475131961959, 3.9279636035636876, 4.78235723643815, 5.790349994645822, 6.736643179246457, 7.6911976149243015, 8.692707309209204, 9.696533127468031, 10.635484070752609, 11.54118799647055, 13.841588078763406, 12.775552012022786, 11.729806351995382, 10.795694587573005, 9.74005274864238, 8.776710070582691, 7.806575883114261, 6.811776729330447, 5.79636287956632, 4.780584725233938, 3.8477828475736993, 2.903477545681824, 3.857139113095597, 4.811348544422256, 5.7732557758273515, 6.735503450887542, 7.70745829521371, 8.683565425336818, 9.617983680169912, 10.615830014059357, 12.95654876198092, 12.05718634944764, 10.98955861418952, 9.916102498178915, 8.911258665023627, 7.889795406151906, 6.888618745685282, 5.820297777535615, 4.871062673520439, 3.9302906665821946, 2.87988882529167, 1.9520438758740302, 2.909824984542434, 3.9470325194090448, 4.81767550279865, 5.843304267620955, 6.760699922221623, 7.821734695578023, 8.765957253514285, 9.790434292962502, 11.976992379894474, 11.069573610647309, 10.028936838091617, 8.955489593628243, 7.988577864766295, 6.950345563337505, 5.992966987258827, 4.962756988997819, 3.998003977185201, 3.0371371992742047, 2.023724008328217, 0.9803751328590634, 1.939320605652295, 2.896365879990872, 3.832163067574948, 4.789860728181585, 5.829478611229307, 6.889863045700596, 7.839311067990401, 8.77210777281358, 10.996725986017358, 10.050632585678597, 8.988618545466199, 8.017377713202169, 6.98988411555058, 6.020038247400134, 5.0392652460980205, 4.090255844346482, 3.0222939448341712, 2.01302791217502, 0.9618639719012392, 0.0, 1.0343625614336163, 2.018952722854344, 3.082198924339086, 4.1273137457797064, 5.134419164736862, 6.1728763465507335, 7.237937395335715, 8.196420506357192, 11.854313602134331, 10.889881627222115, 9.921925507866394, 8.990387782192409, 8.027314934306624, 7.018655106916503, 6.015406222863909, 4.986945486663162, 3.9506214431805375, 2.9734513942215273, 1.9084075536146858, 0.9675155525566326, 1.9418602839989316, 2.9815038652175385, 3.991573605722057, 5.018603604859478, 6.030101514508429, 7.021426762148315, 8.026792405086702, 9.054270943868696, 12.926885611148446, 11.907384720215543, 10.851726981271158, 9.949415688808875, 8.991280286031227, 7.931680642903276, 6.870128122645191, 5.860588121435296, 4.789415278846916, 3.8612640963678873, 2.8602218847432552, 1.936579756666419, 2.916688589993705, 3.8813724045795444, 4.873490829222144, 5.818869907991919, 6.748263506314247, 7.677899816795553, 8.66694505112256, 9.601619479688425, 13.60985256174418, 12.58686140225652, 11.649708089012279, 10.642888298912112, 9.588211143494389, 8.585361326330343, 7.642408149055558, 6.703512841867859, 5.766471568618924, 4.830704985210954, 3.849053331005815, 2.942083450956557, 3.877351395898828, 4.863088263279149, 5.8843481904119095, 6.7520514891373935, 7.68892842341492, 8.652413964452624, 9.60143905974259, 10.55455084735527, 14.545893645837246, 13.534251910193854, 12.647589658364112, 11.6314601484746, 10.55665191007322, 9.522917059096178, 8.701637831402273, 7.667594425534862, 6.6940505432221675, 5.7512343980815634, 4.795371401757366, 4.011790807173257, 4.806054367192971, 5.861960342183649, 6.81557995240385, 7.726043119088092, 8.725246745023599, 9.688780093252623, 10.573277094490207, 11.50623649489212], [11.58492797955012, 10.717404305882173, 9.78917997227986, 8.770849535147672, 7.8313321535498375, 6.8358537104112145, 5.854778412693861, 4.888776921021956, 5.908006411270558, 6.846721163922271, 7.730324068094162, 8.68775613085327, 9.635224376461993, 10.64508184802517, 11.574387493230956, 12.531741828640557, 13.583155283327644, 14.545883766781074, 15.56479453962294, 16.51889017291638, 10.582464652402837, 11.512521095589298, 10.678865388958217, 9.738519578696142, 8.760486367056437, 7.776053036665143, 6.809554787580922, 5.9579801193126025, 6.847770360617125, 7.77355824051117, 8.773705999780871, 9.622639599279822, 10.570833947226138, 11.575888946680568, 12.526535081313659, 13.496498452039171, 14.536434920210409, 15.526336190486983, 16.505639608157598, 15.690156740680685, 9.75183994191072, 10.752434573106072, 11.703922942527305, 10.70353153254932, 9.706139592618635, 8.741874610367647, 7.77184679520397, 6.904549633777983, 7.863367870337873, 8.822230027370194, 9.830568269395668, 10.569019491310636, 11.60078867140109, 12.570056312779448, 13.500964699101534, 14.526925222607934, 15.507484466974235, 16.470393967173305, 15.757843148567162, 14.86013698628276, 9.116522136550577, 10.162278017645674, 11.20362543586021, 11.567258134162634, 10.63810692944301, 9.66817178776159, 8.71178184039812, 7.906330263503785, 8.83859349109, 9.82472179242693, 10.782102863808309, 11.620247281413437, 11.866183410923098, 12.832092034341578, 13.769726698590054, 14.734176425963497, 15.685129300036483, 15.849556733140531, 14.82935906549086, 13.889393205062802, 8.23284432061414, 9.28204304794941, 10.259882127035217, 11.32340156452157, 11.543600773411043, 10.616418211084763, 9.686740321511245, 8.94555113746149, 9.867099283720822, 10.838213147738735, 11.754765276962923, 11.81199925175694, 10.922584203588505, 11.847517952622752, 12.720352501599052, 13.684189360875278, 14.689644935369824, 14.988842806998088, 13.946308280032678, 13.00086803150264, 8.82936778794841, 9.847442818868087, 10.884874682672997, 11.88739240361143, 12.521148204984888, 11.616262401999117, 10.648455671889472, 10.005236740450762, 10.805267738702637, 11.805482879359877, 11.744771491508647, 10.800576412576829, 9.957540411535481, 10.84630440023652, 11.699948342886012, 12.6431063891609, 13.64824248252555, 14.569465673031068, 14.947437903585442, 14.017235671144796, 9.86711503221298, 10.807071891821785, 11.77826590654048, 12.796807535615695, 13.487087680772998, 12.583508726990717, 11.625244327718796, 11.014361572032211, 11.847546300735248, 11.80070445216011, 10.821584680603223, 9.855187798522289, 9.01257829755168, 9.790059463818759, 10.721367984003214, 11.729613483811415, 12.573664310512704, 13.51649065088756, 14.496098352457368, 14.986948960870842, 10.678815927900235, 11.751937794214289, 12.71527050251792, 13.76727562030644, 14.520313843808584, 13.625245986319943, 12.687164162550806, 11.971174524899103, 11.698315924730712, 10.806068163296555, 9.85007654855141, 8.87387979233379, 8.02731493270761, 8.763819934665648, 9.748769315733188, 10.659531107890368, 11.606951027209236, 12.591236617764512, 13.546482442810133, 14.530846336906498, 11.611234540292632, 12.667540107331826, 13.647554832018074, 14.614405759244042, 14.621351661534067, 13.673350701119714, 12.612000247480456, 11.676476342645026, 10.696207675077341, 9.81467308427318, 8.842928974463167, 7.847754927991868, 6.990385152253382, 7.799536676299139, 8.75427733130872, 9.681727217362303, 10.615741028776554, 11.581337294848609, 12.626527737310573, 13.562805609107787, 12.653683849458378, 13.70975983932213, 14.595017323808959, 14.619249441322484, 13.676380110650225, 12.695109102071857, 11.758819978262288, 10.739049576038457, 9.7498231346071, 8.819985299385891, 7.790074023050226, 6.844083833634658, 5.947440460176729, 6.806766967034785, 7.808187305164077, 8.735814274673285, 9.745739387728447, 10.72650106188379, 11.710555886296591, 12.568795669620872, 13.52308066794802, 14.469828261934374, 14.783271949681296, 13.755281812944974, 12.729241974978164, 11.800876508648345, 10.7260502109045, 9.766765697145242, 8.848506138282493, 7.818407201275431, 6.918655064307421, 5.878923345868404, 4.901311025977581, 5.871978558025848, 6.86435048953593, 7.814094238704709, 8.757205447765104, 9.822123538108107, 10.785185452485077, 11.622951004357398, 14.454578278225815, 14.720866066342406, 13.727138040769674, 12.767267723426531, 11.74052562833504, 10.755784012605924, 9.886000900000282, 8.8353940616703, 7.782471442391815, 6.832831104299792, 5.89332118130207, 4.924704550361654, 3.8933123401917973, 4.901305098399469, 5.847598283000104, 6.802152718677949, 7.8036624129628525, 8.807488231221678, 9.746439174506255, 10.652143100224196, 14.870434128103517, 13.804398061362896, 12.75865240133549, 11.824540636913113, 10.768898797982489, 9.8055561199228, 8.83542193245437, 7.840622778670555, 6.825208928906429, 5.809430774574047, 4.876628896913809, 3.932053484648187, 2.968094216849244, 3.922303648175904, 4.884210879580999, 5.846458554641189, 6.8184133989673565, 7.794520529090464, 8.728938783923558, 9.726785117813003, 13.990911323414537, 13.091548910881258, 12.023921175623133, 10.950465059612531, 9.945621226457243, 8.924157967585522, 7.91746479502539, 6.849143826875723, 5.899908722860548, 4.9591367159223045, 3.90873487463178, 2.98088992521414, 2.0207800882960814, 3.057987623162692, 3.9286306065522973, 4.954259371374601, 5.8716550259752704, 6.93268979933167, 7.876912357267932, 8.901389396716148, 13.01135494132809, 12.103936172080926, 11.063299399525235, 9.98985215506186, 9.022940426199911, 7.984708124771121, 7.0273295486924425, 5.997119550431435, 5.032366538618817, 4.0714997607078205, 3.0556636299362108, 2.0092211821991732, 1.050275709405942, 2.007320983744519, 2.943118171328595, 3.900815831935232, 4.940433714982954, 6.000818149454243, 6.9502661717440475, 7.883062876567227, 12.031088547450974, 11.084995147112213, 10.022981106899815, 9.051740274635785, 8.024246676984195, 7.0544008088337495, 6.073627807531636, 5.124618405780097, 4.056656506267787, 3.047390473608636, 1.9962265333348554, 1.0343625614336163, 0.0, 0.984590161420728, 2.04783636290547, 3.0929511843460906, 4.100056603303246, 5.138513785117118, 6.203574833902099, 7.162057944923577, 12.888676163567947, 11.92424418865573, 10.95628806930001, 10.024750343626025, 9.06167749574024, 8.053017668350119, 7.049768784297525, 6.0213080480967776, 4.984984004614153, 4.007813955655143, 2.942770115048302, 1.9849694756371137, 1.0106247441948146, 2.004400997705435, 3.014470738209954, 4.041500737347374, 5.0529986469963255, 6.044323894636212, 7.049689537574599, 8.077168076356593, 13.961248172582062, 12.94174728164916, 11.886089542704774, 10.983778250242493, 10.025642847464844, 8.966043204336893, 7.904490684078809, 6.894950682868913, 5.823777840280533, 4.895626657801504, 3.8945844461768715, 2.9540336797469, 2.0720691650109444, 2.9590212027409533, 3.9511396273835526, 4.896518706153328, 5.825912304475656, 6.755548614956962, 7.744593849283969, 8.679268277849834, 14.644215123177794, 13.621223963690134, 12.684070650445893, 11.677250860345726, 10.622573704928003, 9.619723887763957, 8.676770710489173, 7.737875403301475, 6.8008341300525395, 5.865067546644569, 4.883415892439431, 3.9595373740370383, 3.032731970916067, 3.985036492889993, 4.961996988573318, 5.829700287298802, 6.766577221576329, 7.7300627626140335, 8.679087857904, 9.632199645516678, 15.58025620727086, 14.568614471627468, 13.681952219797726, 12.665822709908214, 11.591014471506835, 10.557279620529792, 9.736000392835887, 8.701956986968478, 7.728413104655783, 6.78559695951518, 5.829733963190983, 4.996918882836544, 3.9614349422102095, 4.983908571794493, 5.9375281820146935, 6.803691917249501, 7.8028955431850076, 8.766428891414032, 9.650925892651616, 10.583885293053529], [10.600337818129391, 9.732814144461445, 8.804589810859131, 7.786259373726944, 6.846741992129109, 5.898016681473946, 4.9581389756011465, 5.755822611917075, 6.775052102165677, 7.71376685481739, 8.642506329341337, 9.599938392100444, 10.619814537882721, 11.629672009445898, 12.558977654651684, 13.516331990061285, 14.567745444748372, 15.530473928201802, 16.549384701043667, 17.503480334337105, 9.59787449098211, 10.52793093416857, 9.69427522753749, 8.753929417275415, 7.775896205635708, 6.838216007727874, 5.912915350488207, 6.8250258102077215, 7.714816051512244, 8.64060393140629, 9.640751690675991, 10.534821860526996, 11.483016208473313, 12.488071207927742, 13.438717342560834, 14.41744355547767, 15.457380023648907, 16.488281776992423, 17.467585194663037, 16.67474690210141, 8.767249780489994, 9.767844411685346, 10.719332781106576, 9.718941371128592, 8.721549431197907, 7.804037581430379, 6.875207358111256, 7.771595324673102, 8.730413561232993, 9.689275718265314, 10.697613960290788, 11.48120175255781, 12.512970932648265, 12.890442790555174, 13.831743135267542, 14.799880006228431, 15.811958626601683, 16.62918976123245, 16.74243330998789, 15.844727147703487, 8.131931975129847, 9.177687856224944, 10.21903527443948, 10.66932443550934, 9.740173230789717, 8.771532350668878, 7.815142403305406, 8.773375954398904, 9.70563918198512, 10.69176748332205, 11.649148554703427, 12.532429542660612, 12.65690776610925, 11.948106752794576, 12.885741417043054, 13.850191144416497, 14.801144018489483, 15.65323839546548, 15.813949226911587, 14.87398336648353, 7.2482541591934115, 8.297452886528681, 9.275291965614489, 10.338811403100841, 10.646961336318327, 9.719778773992049, 8.79010088441853, 9.812596828356607, 10.734144974615944, 11.705258838633855, 12.62181096785804, 12.679825290999467, 11.713308558774656, 10.96353267107575, 11.836367220052052, 12.800204079328278, 13.805659653822824, 14.721494830330304, 14.930898441453406, 13.985458192923367, 7.866975019059972, 8.885050049979649, 9.922481913784559, 10.924999634722992, 11.624508767892172, 10.719622964906403, 9.751816234796758, 10.784206781158067, 11.672313429597759, 12.672528570254997, 12.687085711353465, 11.742890632421647, 10.748264766721633, 9.962319118689518, 10.815963061339012, 11.7591211076139, 12.76425720097855, 13.68548039148407, 14.65340069534434, 15.001825832565522, 8.904722263324544, 9.844679122933348, 10.815873137652043, 11.834414766727258, 12.590448243680282, 11.686869289898002, 10.728604890626082, 11.779886029180519, 12.71459199163037, 12.752402231948826, 11.76389890044804, 10.797502018367107, 9.803302652737832, 8.906074182271759, 9.837382702456214, 10.845628202264415, 11.689679028965704, 12.63250536934056, 13.612113070910368, 14.5411788994349, 9.716423159011798, 10.789545025325852, 11.752877733629482, 12.804882851418004, 13.623674406715867, 12.728606549227228, 11.790524725458091, 12.736698982047411, 12.650013704519429, 11.757765943085271, 10.792390768396228, 9.816194012178608, 8.818039287893761, 7.879834653118648, 8.864784034186188, 9.775545826343368, 10.722965745662236, 11.707251336217512, 12.662497161263133, 13.568453568018061, 10.648841771404195, 11.705147338443389, 12.685162063129637, 13.652012990355605, 14.549498065131795, 13.765177377991268, 12.770524849050517, 12.628174122433743, 11.647905454866057, 10.766370864061896, 9.794626754251881, 8.799452707780585, 7.842052173274573, 6.915551394752138, 7.870292049761719, 8.797741935815303, 9.731755747229554, 10.69735201330161, 11.700717650948691, 12.60041284021935, 11.691291080569943, 12.747367070433695, 13.632624554920522, 14.626700748644007, 14.628077890438941, 13.646806881860574, 12.710517758051004, 11.690747355827174, 10.701520914395816, 9.771683079174608, 8.741771802838942, 7.795781613423374, 6.8991382399654455, 5.922781685487784, 6.9242020236170765, 7.851828993126284, 8.815354251471442, 9.796115925626784, 10.748163117408156, 11.606402900732435, 12.560687899059584, 13.507435493045937, 14.528538056194025, 14.70697959273369, 13.68093975476688, 12.752574288437062, 11.677747990693216, 10.718463476933959, 9.80020391807121, 8.770104981064147, 7.8703528440961374, 6.83062112565712, 5.853008805766297, 4.987993276478847, 5.9259821018702, 6.860816651928856, 7.794812678876668, 8.859730769219672, 9.822792683596642, 10.660558235468962, 13.492185509337379, 14.517288046615633, 14.67883582055839, 13.718965503215248, 12.692223408123757, 11.70748179239464, 10.837698679788998, 9.787091841459016, 8.734169222180531, 7.784528884088508, 6.845018961090786, 5.876402330150371, 4.845010119980514, 4.017319816852468, 4.885205514111667, 5.839759949789512, 6.841269644074416, 7.845095462333241, 8.784046405617818, 9.689750331335759, 14.49943784726935, 14.756095841151613, 13.710350181124207, 12.77623841670183, 11.720596577771206, 10.757253899711516, 9.787119712243086, 8.792320558459272, 7.7769067086951456, 6.761128554362764, 5.828326676702526, 4.8837512644369045, 3.919791996637961, 3.028834829870109, 3.921818110692562, 4.884065785752752, 5.85602063007892, 6.832127760202027, 7.766546015035122, 8.764392348924567, 14.975501484835265, 14.076139072301984, 13.008511337043863, 11.93505522103326, 10.930211387877971, 9.90874812900625, 8.869162574814109, 7.8008416066644415, 6.851606502649266, 5.910834495711022, 4.860432654420497, 3.9325877050028573, 2.9724778680847983, 2.095594854274254, 2.96623783766386, 3.991866602486164, 4.909262257086833, 5.970297030443232, 6.914519588379495, 7.938996627827711, 13.995945102748818, 13.088526333501653, 12.047889560945961, 10.974442316482588, 10.00753058762064, 8.969298286191849, 8.01191971011317, 6.981709711852163, 6.016956700039545, 5.056089922128549, 4.007361409724928, 2.9609189619878906, 2.001973489194659, 1.044928214856082, 1.9807254024401575, 2.9384230630467947, 3.9780409460945165, 5.038425380565806, 5.987873402855611, 6.92067010767879, 13.015678708871702, 12.069585308532941, 11.007571268320543, 10.036330436056513, 9.008836838404923, 8.038990970254478, 7.0582179689523645, 6.109208567200826, 5.041246667688515, 4.031980635029364, 2.980816694755583, 2.018952722854344, 0.984590161420728, 0.0, 1.063246201484742, 2.1083610229253624, 3.1154664418825178, 4.1539236236963895, 5.218984672481371, 6.177467783502848, 13.873266324988675, 12.908834350076459, 11.940878230720738, 11.009340505046753, 10.046267657160968, 9.037607829770847, 8.034358945718253, 7.005898209517506, 5.969574166034882, 4.992404117075871, 3.92736027646903, 2.969559637057842, 1.9952149056155426, 1.019810836284707, 2.0298805767892256, 3.056910575926646, 4.068408485575597, 5.0597337332154835, 6.065099376153871, 7.092577914935863, 14.94583833400279, 13.926337443069887, 12.870679704125502, 11.968368411663219, 11.01023300888557, 9.950633365757621, 8.889080845499537, 7.879540844289641, 6.808368001701261, 5.880216819222232, 4.8791746075976, 3.919223689233351, 2.9391148559060642, 1.974431041320225, 2.9665494659628244, 3.9119285447326, 4.841322143054928, 5.770958453536234, 6.760003687863241, 7.694678116429107, 15.62880528459852, 14.60581412511086, 13.66866081186662, 12.661841021766453, 11.607163866348731, 10.604314049184685, 9.661360871909901, 8.722465564722203, 7.785424291473268, 6.849657708065298, 5.868006053860159, 4.887386479091471, 3.899777661811187, 3.0004463314692646, 3.97740682715259, 4.845110125878074, 5.7819870601556005, 6.745472601193305, 7.694497696483271, 8.64760948409595, 16.564846368691587, 15.553204633048194, 14.666542381218454, 13.650412871328943, 12.575604632927563, 11.54186978195052, 10.720590554256615, 9.686547148389206, 8.713003266076512, 7.770187120935908, 6.814324124611711, 5.863964573731664, 4.828480633105329, 3.9993184103737645, 4.952938020593965, 5.819101755828773, 6.818305381764279, 7.781838729993304, 8.666335731230888, 9.5992951316328], [9.587591912079066, 8.72006823841112, 7.791843904808806, 6.773513467676619, 5.833996086078784, 4.892851481769912, 5.860212996337515, 6.727313555151948, 7.746543045400551, 8.685257798052264, 9.613997272576212, 10.571429335335319, 11.64122523041062, 12.651082701973797, 13.580388347179584, 14.537742682589185, 15.589156137276271, 16.5518846207297, 17.570795393571565, 18.524891026865006, 8.585128584931784, 9.515185028118244, 8.681529321487163, 7.741183511225089, 6.763150299585383, 5.833050808023841, 6.814989371224575, 7.796516753442595, 8.686306994747117, 9.612094874641162, 10.612242633910864, 11.50631280376187, 12.454507151708187, 13.459562151162617, 14.011573032140676, 14.946667902332788, 15.859669126191253, 16.649908490744515, 17.603858664315318, 17.696157594629312, 7.754503874439666, 8.755098505635017, 9.706586875056251, 8.706195465078267, 7.708803525147582, 6.798872381726345, 7.777281378847624, 8.743086267907977, 9.701904504467867, 10.660766661500187, 11.66910490352566, 12.452692695792685, 13.48446187588314, 13.701020519250445, 13.037143414352801, 13.916241131764025, 14.888619579427427, 15.705850714058194, 16.645363171240362, 16.90797334918823, 7.078990753146158, 8.124746634241255, 9.166094052455792, 9.656578529459015, 8.727427324739391, 7.776514984758593, 8.717216424041773, 9.744866897633779, 10.677130125219994, 11.663258426556924, 12.620639497938303, 13.503920485895486, 13.467485494804519, 12.758684481489848, 12.002102542578648, 12.966552269952091, 13.877804971315227, 14.729899348291225, 15.750097015940897, 15.937229567968272, 6.185007957708669, 7.23420668504394, 8.212045764129748, 9.2755652016161, 9.70652184475718, 8.7793392824309, 9.692174905154898, 10.73101418997411, 11.68486981810307, 12.658339360628819, 13.593301911092917, 13.490403019694737, 12.523886287469926, 11.774110399771022, 10.952728345587646, 11.916565204863872, 12.882320606648568, 13.798155783156048, 14.729281201184644, 15.048704394408109, 6.852722597023162, 7.8707976279428395, 8.908229491747749, 9.910747212686182, 10.684069276331025, 9.792685185594216, 10.653890255533126, 11.686280801894435, 12.623038273084886, 13.625609092249961, 13.497663440048735, 12.553468361116916, 11.558842495416902, 10.77289684738479, 9.932324186874606, 10.875482233149494, 11.840918153804294, 12.762141344309814, 13.72815157763188, 14.512567354492312, 7.890469841287733, 8.830426700896538, 9.801620715615233, 10.820162344690448, 11.650008752119135, 10.759931510585815, 11.63067891136245, 12.681960049916887, 13.651566371717067, 13.607354949756873, 12.57447662914331, 11.608079747062376, 10.613880381433102, 9.716651910967029, 8.953743827991808, 9.922289155090159, 10.766339981791448, 11.709166322166304, 12.686863953197909, 13.542854064766265, 8.702170736974988, 9.775292603289042, 10.738625311592672, 11.790630429381194, 12.68323491515472, 11.801668769915041, 12.69259874619446, 13.638773002783779, 13.50735565765077, 12.612718660893318, 11.602968497091497, 10.626771740873878, 9.62861701658903, 8.690412381813918, 7.980175162023972, 8.852206779169112, 9.79962669848798, 10.782002218505053, 11.737248043550673, 12.554201145981251, 9.634589349367385, 10.69089491640658, 11.670909641092827, 12.637760568318795, 13.59341870457835, 12.838239598679081, 13.672598869786885, 13.485516075565084, 12.505247407997398, 11.623712817193237, 10.651968707383222, 9.632203047611764, 8.652629901969842, 7.726129123447407, 6.985683177599503, 7.874402888641047, 8.775591811476803, 9.7151614051327, 10.686465228911882, 11.58616041818254, 10.677038658533132, 11.733114648396883, 12.618372132883712, 13.612448326607197, 14.538390255462193, 13.816481197726938, 13.567859711182347, 12.548089308958515, 11.558862867527157, 10.629025032305949, 9.599113755970283, 8.653123566554715, 7.756480193096788, 6.733359414183053, 5.9484208488720665, 6.876047818381274, 7.801101829434632, 8.781863503589975, 9.733910695371346, 10.592150478695626, 11.546435477022774, 12.493183071009128, 13.514285634157215, 14.544362760618135, 14.538281707898223, 13.609916241568405, 12.535089943824559, 11.575805430065301, 10.657545871202553, 9.627446934195488, 8.727694797227478, 7.687963078788462, 6.710350758897639, 5.798571005174116, 4.911729679833389, 5.846564229892046, 6.780560256839858, 7.845478347182862, 8.808540261559832, 9.646305813432152, 12.477933087300569, 13.503035624578823, 14.496763650151555, 14.57630745634659, 13.5495653612551, 12.564823745525983, 11.69504063292034, 10.644433794590359, 9.591511175311874, 8.64187083721985, 7.702360914222128, 6.7337442832817125, 5.7023520731118555, 4.827897545547737, 3.8709530920748563, 4.825507527752702, 5.827017222037606, 6.830843040296431, 7.7697939835810095, 8.675497909298949, 13.48518542523254, 14.539234058063728, 14.56769213425555, 13.633580369833172, 12.577938530902548, 11.614595852842859, 10.644461665374429, 9.649662511590614, 8.634248661826488, 7.618470507494106, 6.6856686298338674, 5.741093217568245, 4.777133949769302, 3.839412558565378, 2.9075656886557515, 3.869813363715942, 4.84176820804211, 5.8178753381652175, 6.7522935929983126, 7.750139926887757, 14.537558106473428, 14.968216558221815, 13.895230049056291, 12.821773933045689, 11.816930099890401, 10.79546684101868, 9.72650452794545, 8.658183559795782, 7.7089484557806065, 6.768176448842363, 5.7177746075518385, 4.789929658134199, 3.829819821216139, 2.9061725829695235, 1.95198541562705, 2.9776141804493537, 3.8950098350500233, 4.9560446084064225, 5.900267166342685, 6.924744205790901, 15.05919130423356, 14.048936933528344, 13.008300160972652, 11.934852916509277, 10.967941187647329, 9.929708886218538, 8.97233031013986, 7.942120311878853, 6.977367300066234, 5.936606088304156, 4.864703362856269, 3.8182609151192315, 2.859315442326, 1.902270167987423, 0.9664729804033474, 1.9241706410099844, 2.9637885240577067, 4.024172958528996, 4.973620980818801, 5.90641768564198, 14.078924910356443, 13.132831510017683, 12.070817469805284, 11.099576637541254, 10.072083039889664, 9.102237171739219, 8.121464170437106, 7.172454768685567, 6.1044928691732565, 5.095226836514105, 4.044062896240325, 3.082198924339086, 2.04783636290547, 1.063246201484742, 0.0, 1.0451148214406205, 2.0522202403977756, 3.090677422211647, 4.155738470996629, 5.114221582018106, 14.936512526473416, 13.9720805515612, 13.00412443220548, 12.072586706531494, 11.109513858645709, 10.100854031255588, 9.097605147202994, 8.069144411002247, 7.032820367519623, 6.0556503185606125, 4.990606477953771, 4.032805838542584, 3.0584611071002845, 2.0226656317152782, 1.0125958912107595, 2.0039693539429573, 3.015467263591908, 4.006792511231795, 5.012158154170182, 6.0396366929521745, 16.00908453548753, 14.989583644554628, 13.933925905610243, 12.98977910419112, 12.031643701413472, 10.97204405828552, 9.910491538027436, 8.90095153681754, 7.8297786942291605, 6.901627511750132, 5.9005853001255, 4.890714632468224, 3.9106057991409373, 2.945921984555098, 1.9538035599124992, 2.8991826386822748, 3.828576237004602, 4.758212547485908, 5.747257781812914, 6.68193221037878, 16.65021597712642, 15.627224817638762, 14.69007150439452, 13.683251714294354, 12.62857455887663, 11.625724741712585, 10.6827715644378, 9.743876257250102, 8.806834984001167, 7.871068400593197, 6.841799178554888, 5.858877422326343, 4.87126860504606, 3.9719372747041373, 2.964660921102265, 3.832364219827749, 4.769241154105275, 5.73272669514298, 6.681751790432946, 7.634863578045625, 17.586257061219488, 16.574615325576094, 15.687953073746353, 14.671823563856842, 13.597015325455462, 12.56328047447842, 11.742001246784515, 10.707957840917105, 9.722585354482373, 8.743980245630636, 7.78811724930644, 6.835455516966538, 5.799971576340202, 4.901392431110133, 3.947772820889932, 4.8063558497784475, 5.805559475713954, 6.769092823942978, 7.653589825180562, 8.586549225582475], [8.697704505761601, 7.830180832093656, 6.901956498491342, 5.883626061359156, 4.944108679761321, 5.850546123265967, 6.817907637833569, 7.700602195580946, 8.719831685829549, 9.658546438481261, 10.587285913005209, 11.544717975764316, 12.61451387083962, 13.624371342402796, 14.553676987608583, 15.11936423336707, 15.845897212041098, 16.65654122457788, 17.657658680688435, 18.47893600901198, 7.695241178614319, 8.62529762180078, 7.7916419151697, 6.851296104907626, 5.87326289326792, 6.790745449519895, 7.77268401272063, 8.769805393871593, 9.659595635176116, 10.58538351507016, 11.58553127433986, 12.479601444190868, 13.427795792137184, 14.432850791591614, 14.909621737639618, 14.154607609968457, 14.885849436318708, 15.67608880087197, 16.630038974442773, 17.460286668280474, 6.864616468122203, 7.865211099317555, 8.816699468738788, 7.816308058760804, 6.818916118830119, 7.7565670232223995, 8.734976020343678, 9.716374908336974, 10.675193144896864, 11.634055301929184, 12.642393543954658, 13.425981336221682, 14.457750516312137, 14.625293431449347, 13.935192119851743, 13.124180839399694, 13.914799889554882, 14.732031024185648, 15.671543481367815, 16.501018882873396, 6.033875931705538, 7.079631812800635, 8.120979231015172, 8.766691123141552, 7.837539918421928, 8.734209626254646, 9.674911065537827, 10.704544637562144, 11.650418765648991, 12.636547066985921, 13.5939281383673, 14.477209126324484, 14.39175840700342, 13.68295739368875, 12.90015124807759, 12.17449197758776, 12.903985281442681, 13.75607965841868, 14.776277326068351, 15.53027510165344, 5.139893136268048, 6.189091863603319, 7.166930942689127, 8.230450380175478, 8.823173310099135, 9.737033923926953, 10.649869546650953, 11.688708831470164, 12.642564459599125, 13.616034002124874, 14.566590551521914, 14.414675931893639, 13.448159199668828, 12.698383311969923, 11.850777051086588, 11.12450491249954, 11.908500916776022, 12.824336093283502, 13.749980808385258, 14.57900168211087, 5.861600188008793, 6.87967521892847, 7.917107082733379, 8.919624803671812, 9.80072074167298, 10.750379827090269, 11.61158489702918, 12.64397544339049, 13.58073291458094, 14.583303733746016, 14.421936352247636, 13.477741273315818, 12.483115407615804, 11.69716975958369, 10.830372892373548, 10.074680437138781, 10.867098463931748, 11.788321654437269, 12.748851184832494, 13.521444945477942, 6.8993474322733634, 7.839304291882168, 8.810498306600863, 9.829039935676079, 10.766660217461089, 11.717626152081868, 12.588373552858505, 13.639654691412941, 14.609261013213121, 14.531627861955775, 13.498749541342212, 12.532352659261278, 11.538153293632003, 10.64092482316593, 9.85179253349075, 9.004168263493973, 9.792520291918903, 10.735346632293759, 11.707563560398523, 12.551731655751896, 7.711048327960619, 8.784170194274672, 9.747502902578303, 10.799508020366824, 11.797455303556541, 12.73719156496734, 13.650293387690514, 14.596467644279834, 14.431628569849675, 13.53699157309222, 12.527241409290399, 11.551044653072779, 10.552889928787932, 9.61468529401282, 8.878223867522914, 7.934085887572927, 8.825807008615435, 9.807304141841323, 10.757947650751287, 11.563078736966881, 8.643466940353015, 9.69977250739221, 10.679787232078457, 11.646638159304425, 12.60229629556398, 13.584549903655704, 14.63029351128294, 14.409788987763989, 13.429520320196303, 12.547985729392142, 11.576241619582126, 10.556475959810667, 9.576902814168745, 8.65040203564631, 7.883731883098445, 6.9562819970448615, 7.800893734813073, 8.740463328468971, 9.695342819897512, 10.59503800916817, 9.685916249518762, 10.741992239382514, 11.627249723869342, 12.621325917592827, 13.547267846447824, 14.528538855026191, 14.492132623381252, 13.47236222115742, 12.483135779726062, 11.553297944504854, 10.523386668169186, 9.577396478753618, 8.680753105295691, 7.657632326381957, 6.87269376107097, 5.957926926785088, 6.8264037527709025, 7.807165426926245, 8.742788286356976, 9.601028069681256, 10.555313068008404, 11.502060661994758, 12.523163225142845, 13.553240351603765, 14.579280189570575, 14.53418915376731, 13.459362856023464, 12.500078342264207, 11.581818783401458, 10.551719846394393, 9.651967709426382, 8.612235990987365, 7.634623671096543, 6.7228439173730195, 5.836002592032293, 4.888324694799238, 5.8058621801761285, 6.870780270519132, 7.8174178525454625, 8.655183404417782, 11.486810678286199, 12.511913215564453, 13.505641241137186, 14.524745855889988, 14.473838273454005, 13.489096657724888, 12.619313545119246, 11.568706706789264, 10.515784087510779, 9.566143749418755, 8.626633826421031, 7.658017195480617, 6.62662498531076, 5.75217045774664, 4.7952260042737604, 3.8672679926598947, 4.852319145373876, 5.839720631282061, 6.77867157456664, 7.684375500284579, 12.49406301621817, 13.548111649049359, 14.474126880571369, 14.557853282032077, 13.502211443101453, 12.538868765041764, 11.568734577573334, 10.57393542378952, 9.558521574025393, 8.54274341969301, 7.609941542032772, 6.66536612976715, 5.701406861968207, 4.7636854707642815, 3.831838600854655, 2.9115738286231347, 3.85064579902774, 4.826752929150848, 5.761171183983943, 6.759017517873387, 13.546435697459058, 14.517999714374184, 14.819502961255196, 13.746046845244594, 12.741203012089306, 11.719739753217585, 10.650777440144354, 9.582456471994687, 8.633221367979512, 7.692449361041268, 6.642047519750743, 5.714202570333103, 4.754092733415043, 3.8304454951684273, 2.876258327825954, 1.986491771434984, 2.9038874260356535, 3.9649221993920527, 4.909144757328315, 5.9336217967765315, 14.525992079545505, 14.973209845727249, 13.932573073171557, 12.859125828708182, 11.892214099846234, 10.853981798417443, 9.896603222338765, 8.866393224077758, 7.901640212265139, 6.860879000503061, 5.788976275055173, 4.742533827318136, 3.783588354524904, 2.826543080186327, 1.8907458926022516, 0.9330482319956147, 1.9726661150433369, 3.033050549514626, 3.9824985718044306, 4.91529527662761, 15.124039731797065, 14.177946331458305, 13.115932291245906, 12.144691458981876, 11.117197861330286, 10.147351993179841, 9.166578991877728, 8.217569590126189, 7.149607690613879, 6.140341657954727, 5.089177717680947, 4.127313745779707, 3.0929511843460906, 2.1083610229253624, 1.0451148214406205, 0.0, 1.007105418957155, 2.045562600771026, 3.110623649556008, 4.069106760577485, 15.981627347914038, 15.017195373001822, 14.049239253646101, 13.117701527972116, 12.154628680086331, 11.11052549638247, 10.107276612329876, 9.078815876129129, 8.042491832646505, 7.0653217836874935, 6.000277943080652, 5.009942584805183, 4.035597853362884, 2.9959542721442762, 1.985884531639757, 0.9588545325023365, 1.9703524421512872, 2.9616776897911734, 3.9670433327295607, 4.994521871511553, 17.054199356928155, 16.03037779792976, 14.974720058985374, 13.963067744620117, 13.00493234184247, 11.94533269871452, 10.883780178456435, 9.87424017724654, 8.80306733465816, 7.87491615217913, 6.873873940554499, 5.8640032728972225, 4.883894439569936, 3.919210624984096, 2.9270922003414968, 2.0092952323648112, 2.9386888306871386, 3.868325141168444, 4.857370375495451, 5.792044804061317, 17.62350461755542, 16.60051345806776, 15.663360144823518, 14.65654035472335, 13.60186319930563, 12.599013382141584, 11.6560602048668, 10.717164897679101, 9.780123624430166, 8.844357041022196, 7.815087818983886, 6.832166062755341, 5.844557245475058, 4.945225915133135, 3.937949561531262, 2.9424768135102854, 3.8793537477878113, 4.842839288825516, 5.791864384115482, 6.744976171728161, 18.559545701648485, 17.54790396600509, 16.66124171417535, 15.64511220428584, 14.570303965884461, 13.536569114907419, 12.715289887213514, 11.681246481346104, 10.69587399491137, 9.717268886059633, 8.761405889735437, 7.808744157395536, 6.7732602167692, 5.8590870726061866, 4.905467462385986, 3.916468443460984, 4.91567206939649, 5.879205417625514, 6.763702418863098, 7.696661819265011], [7.793908261525012, 6.926384587857067, 5.998160254254753, 5.052228825564111, 5.899099632169387, 6.805537075674033, 7.7728985902416365, 8.683175258782102, 9.702404749030705, 10.641119501682418, 11.569858976206365, 12.527291038965473, 13.597086934040776, 14.606944405603953, 15.53625005080974, 15.932164392258867, 14.887519076411406, 15.698163088948185, 16.69928054505874, 17.52055787338229, 6.79144493437773, 7.7215013775641905, 6.9602446793746555, 6.019898869112581, 6.828253845675985, 7.745736401927962, 8.727674965128697, 9.752378457072748, 10.642168698377272, 11.567956578271318, 12.568104337541019, 13.462174507392024, 14.41036885533834, 15.41542385479277, 15.72986915119239, 14.967407768860253, 13.927471300689016, 14.717710665242276, 15.671660838813079, 16.501908532650784, 5.960820223885614, 6.961414855080966, 8.003396862234734, 7.040353616081258, 7.773907071238185, 8.711557975630466, 9.689966972751746, 10.698947971538129, 11.65776620809802, 12.616628365130342, 13.624966607155816, 14.408554399422838, 15.440323579513294, 15.555104089101459, 14.755439533404514, 13.944428252952465, 12.95642175392519, 13.773652888555954, 14.71316534573812, 15.542640747243704, 5.099129381763381, 6.1448852628584785, 7.13759831309832, 8.050925601457525, 8.792530870829994, 9.689200578662714, 10.629902017945895, 11.659535589970211, 12.632991828850146, 13.619120130187076, 14.576501201568455, 15.45978218952564, 15.376063852385995, 14.612768051340861, 13.72039866163036, 12.99473939114053, 11.945607145812989, 12.797701522788985, 13.817899190438657, 14.571896966023747, 4.132787717310894, 5.1819864446461645, 6.159825523731972, 7.223344961218324, 8.15404009491767, 9.081222657243949, 10.010900546817467, 11.049739831636678, 12.00359545976564, 12.977065002291388, 14.04176641290556, 15.045049606394214, 14.432464645051402, 13.628193969622036, 12.671024464639359, 11.944752326052312, 10.95012278114633, 11.865957957653809, 12.791602672755564, 13.620623546481177, 4.88163031847887, 5.899705349398547, 6.9371372132034566, 7.93965493414189, 9.011809701900747, 10.049201630317366, 10.972615897195695, 12.005006443557004, 12.941763914747455, 13.94433473391253, 14.94820973735245, 14.462046718698392, 13.467420852998378, 12.626980417235803, 11.650620305926319, 10.894927850691552, 9.908720328302056, 10.829943518807575, 11.7904730492028, 12.563066809848248, 5.919377562743441, 6.859334422352245, 7.8305284370709405, 8.849070066146156, 9.8120634299015, 10.86074921363306, 11.842662533225802, 12.893943671780239, 13.863549993580419, 14.887761165707943, 14.483054986724786, 13.516658104643852, 12.522458739014578, 11.603348467227976, 10.67203994704352, 9.824415677046746, 8.83414215628921, 9.776968496664066, 10.749185424768829, 11.593353520122202, 6.752670192330925, 7.8257920586449785, 8.789124766948609, 9.84112988473713, 10.839077167926847, 11.778813429337646, 12.818285880466389, 13.846087162473937, 14.804371230910007, 14.521297018474794, 13.511546854672973, 12.535350098455353, 11.537195374170507, 10.598990739395393, 9.698471281075685, 8.7543333011257, 7.867428872985743, 8.848926006211629, 9.799569515121593, 10.604700601337187, 7.685088804723321, 8.741394371762516, 9.721409096448763, 10.688260023674731, 11.643918159934286, 12.62617176802601, 13.691271475013096, 14.626795379848526, 14.436625739153458, 13.555091148349296, 12.579742408430793, 11.54078140519324, 10.561208259551318, 9.634707481028883, 8.703979296651216, 7.776529410597633, 6.842515599183381, 7.782085192839277, 8.736964684267818, 9.636659873538477, 8.727538113889068, 9.78361410375282, 10.668871588239648, 11.662947781963133, 12.58888971081813, 13.570160719396497, 14.506449843206067, 14.479467640114574, 13.490241198683217, 12.560403363462008, 11.530492087126342, 10.584501897710775, 9.687858524252848, 8.64193777176453, 7.805577699705579, 6.877950730196372, 5.8680256171412095, 6.848787291296551, 7.7844101507272825, 8.642649934051562, 9.59693493237871, 10.543682526365064, 11.564785089513151, 12.594862215974072, 13.620902053940881, 14.5492675202707, 14.46646827498062, 13.507183761221363, 12.588924202358612, 11.558825265351548, 10.659073128383536, 9.619341409944521, 8.6417290900537, 7.707149362755593, 6.788004913833134, 5.838261164664355, 4.8474840445464356, 5.912402134889439, 6.859039716915769, 7.696805268788087, 10.528432542656505, 11.55353507993476, 12.547263105507492, 13.566367720260294, 14.593109815351784, 14.496202076682042, 13.6264189640764, 12.575812125746419, 11.522889506467934, 10.57324916837591, 9.633739245378186, 8.665122614437772, 7.633730404267915, 6.736475903129214, 5.773929322094269, 4.819304555458918, 3.8939410097441836, 4.881342495652367, 5.820293438936946, 6.725997364654885, 11.535684880588477, 12.589733513419665, 13.515748744941675, 14.449860509364052, 14.509316862058608, 13.545974183998919, 12.575839996530489, 11.581040842746674, 10.565626992982548, 9.549848838650165, 8.617046960989926, 7.672471548724305, 6.708512280925362, 5.770790889721438, 4.825858066482349, 3.863610391422158, 2.892267663398047, 3.8683747935211543, 4.802793048354249, 5.800639382243693, 12.588057561829364, 13.55962157874449, 14.500907379642369, 14.753152264201749, 13.74830843104646, 12.72684517217474, 11.657882859101509, 10.589561890951842, 9.640326786936667, 8.699554779998422, 7.649152938707897, 6.721307989290257, 5.761198152372199, 4.837550914125583, 3.8833637467831092, 2.938528334234007, 1.9455092904059605, 2.9849523298621303, 3.9291748877983923, 4.953651927246609, 13.567613943915811, 14.54723431754482, 14.93967849212871, 13.866231247665336, 12.899319518803388, 11.861087217374598, 10.90370864129592, 9.873498643034912, 8.908745631222294, 7.867984419460216, 6.796081694012328, 5.74963924627529, 4.790693773482059, 3.8336484991434823, 2.897851311559407, 1.94015365095277, 1.0142879794136441, 2.0530806799847037, 3.002528702274508, 3.9353254070976877, 14.547880337792927, 15.18505175041546, 14.12303771020306, 13.15179687793903, 12.12430328028744, 11.154457412136995, 10.173684410834882, 9.224675009083343, 8.156713109571033, 7.147447076911882, 6.096283136638101, 5.134419164736862, 4.100056603303246, 3.1154664418825178, 2.0522202403977756, 1.007105418957155, 0.0, 1.0384571818138713, 2.103518230598853, 3.0620013416203307, 15.488680880095831, 16.024300791958975, 15.056344672603256, 14.12480694692927, 13.161734099043485, 12.117630915339623, 11.114382031287029, 10.085921295086282, 9.049597251603657, 8.072427202644647, 7.007383362037807, 6.017048003762337, 5.042703272320038, 4.003059691101431, 2.992989950596912, 1.9659599514594917, 1.0356058922091305, 2.026931139849017, 3.0322967827874043, 4.059775321569397, 16.53640345289368, 17.012950861130918, 15.957293122186533, 14.945640807821276, 13.987505405043628, 12.927905761915676, 11.866353241657592, 10.856813240447696, 9.785640397859316, 8.857489215380287, 7.856447003755655, 6.846576336098378, 5.8664675027710915, 4.901783688185252, 3.909665263542653, 2.9642861847728774, 2.03489258645055, 2.9645288969318555, 3.9535741312588626, 4.888248559824728, 17.513678149071286, 17.583086521268918, 16.645933208024676, 15.63911341792451, 14.584436262506786, 13.58158644534274, 12.638633268067956, 11.699737960880258, 10.762696687631323, 9.826930104223353, 8.797660882185042, 7.814739125956497, 6.827130308676214, 5.927798978334291, 4.9168925873909135, 3.8974677659183516, 2.9755575035512227, 3.939043044588927, 4.888068139878893, 5.841179927491572, 18.449719233164352, 17.695460613054212, 16.689208475112913, 15.894547339837926, 15.552877029085618, 14.519142178108575, 13.69786295041467, 12.66381954454726, 11.678447058112527, 10.69984194926079, 9.743978952936594, 8.79131722059669, 7.755833279970356, 6.814078025014254, 5.860458414794053, 4.87145939586905, 4.011875825159902, 4.975409173388925, 5.859906174626509, 6.792865575028422], [6.849332793256151, 5.981809119588205, 5.053584785985891, 5.956287251365767, 6.803158057971043, 7.70959550147569, 8.676957016043293, 9.587233684583758, 10.60646317483236, 11.545177927484072, 12.47391740200802, 13.431349464767127, 14.501145359842432, 15.511002831405609, 16.440308476611396, 16.907545351275242, 15.862900035427783, 14.981668334442123, 15.77174302890575, 16.543724572152453, 5.846869466108869, 6.776925909295329, 6.089890606645871, 6.923957294914238, 7.7323122714776416, 8.649794827729618, 9.631733390930354, 10.656436882874406, 11.546227124178927, 12.472015004072972, 13.472162763342673, 14.366232933193679, 15.314427281139995, 16.319482280594425, 16.705250110208766, 15.94278872787663, 14.902852259705393, 14.001215910736214, 14.744123322660087, 15.525075231420946, 5.005606028724659, 6.006200659920011, 7.0363524952176615, 7.944412041882914, 8.67796549703984, 9.615616401432122, 10.594025398553402, 11.603006397339787, 12.561824633899677, 13.520686790931997, 14.52902503295747, 15.312612825224493, 16.344382005314948, 16.530485048117836, 15.730820492420891, 14.919809211968841, 13.931802712941566, 13.057158134049892, 13.78562782958513, 14.565807446013865, 4.06956180349381, 5.1153176845889075, 6.099141131284449, 7.151543135726039, 8.080694340445662, 9.045589773102384, 9.94740184611672, 10.977035418141037, 11.960843388823932, 12.946971690160861, 13.904352761542238, 14.93199355465761, 15.916708364139746, 15.588149010357238, 14.695779620646737, 13.970120350156908, 12.920988104829366, 12.081206768282923, 12.857143746508827, 13.595063664793908, 3.094330535497022, 4.143529262832293, 5.1213683419181, 6.184887779404452, 7.115582913103798, 8.042765475430077, 8.972443365003596, 10.011282649822807, 10.965138277951768, 11.938607820477516, 13.003309231091688, 14.006592424580342, 14.973109156805153, 14.603574928638412, 13.646405423655736, 12.920133285068689, 11.925503740162707, 11.149463203147747, 11.814769371525726, 12.643790245251338, 3.843173136664999, 4.861248167584676, 5.898680031389585, 6.901197752328018, 7.973352520086875, 9.010744448503495, 9.934158715381823, 10.966549261743133, 11.903306732933583, 12.905877552098659, 13.909752555538578, 14.853947634470396, 14.466814282646668, 13.60236137625218, 12.626001264942696, 11.870308809707929, 10.884101287318433, 10.113448764301513, 10.813639747972962, 11.58623350861841, 4.880920380929569, 5.8208772405383735, 6.792071255257069, 7.810612884332285, 8.773606248087628, 9.822292031819188, 10.80420535141193, 11.855486489966367, 12.825092811766547, 13.849303983894071, 14.90582878588061, 14.516051534292142, 13.521852168662868, 12.578729426244353, 11.647420906059898, 10.799796636063121, 9.809523115305588, 9.060473742158004, 9.77235212353899, 10.616520218892363, 5.775836891101087, 6.817957418935581, 7.781290127239211, 8.81957283745449, 9.806832411123214, 10.746568672534012, 11.786041123662756, 12.81229944283326, 13.77058351126933, 14.830807251734923, 14.510940284321263, 13.534743528103643, 12.536588803818796, 11.598384169043683, 10.673852240092062, 9.729714260142075, 8.84280983200212, 8.021673817119552, 8.822736213891755, 9.627867300107349, 6.7082555034934845, 7.764561070532679, 8.744575795218926, 9.711426722444894, 10.667084858704449, 11.649338466796173, 12.71443817378326, 13.649962078618689, 14.630230746186374, 14.593548330163168, 13.579135838079083, 12.54017483484153, 11.560601689199608, 10.634100910677173, 9.679360255667593, 8.75191036961401, 7.817896558199758, 6.9548330037472015, 7.76013138303798, 8.659826572308639, 7.75070481265923, 8.806780802522981, 9.692038287009812, 10.686114480733297, 11.612056409588291, 12.593327418166659, 13.529616541976228, 14.560717990782313, 14.528698380497088, 13.59886054527588, 12.568949268940212, 11.622959079524644, 10.726315706066718, 9.680394953578402, 8.780958658721957, 7.853331689212749, 6.843406576157586, 6.021535102204475, 6.807576849497445, 7.665816632821723, 8.620101631148872, 9.566849225135226, 10.587951788283313, 11.618028914744233, 12.644068752711043, 13.572434219040861, 14.562386309334016, 14.545640943035234, 13.627381384172484, 12.59728244716542, 11.697530310197408, 10.657798591758391, 9.68018627186757, 8.745606544569464, 7.763385872849511, 6.813642123680732, 5.8228650035628124, 4.961050105747388, 5.882206415685931, 6.71997196755825, 9.551599241426667, 10.576701778704921, 11.570429804277653, 12.589534419030455, 13.616276514121946, 14.626320124073274, 14.664876145890272, 13.61426930756029, 12.561346688281805, 11.611706350189781, 10.672196427192057, 9.703579796251642, 8.672187586081785, 7.774933084943085, 6.812386503908141, 5.8577617372727895, 4.86932196876056, 3.904509194422529, 4.843460137707108, 5.749164063425048, 10.558851579358638, 11.612900212189826, 12.538915443711836, 13.473027208134214, 14.528669047064838, 14.58443136581279, 13.61429717834436, 12.619498024560546, 11.60408417479642, 10.588306020464037, 9.655504142803798, 8.710928730538175, 7.746969462739232, 6.809248071535308, 5.86431524829622, 4.90206757323603, 3.8676486224144235, 2.8915414922913163, 3.825959747124411, 4.823806081013855, 11.611224260599526, 12.582788277514652, 13.52407407841253, 14.405625816906204, 14.78676561286033, 13.76530235398861, 12.696340040915379, 11.628019072765712, 10.678783968750537, 9.738011961812292, 8.687610120521768, 7.759765171104128, 6.799655334186069, 5.876008095939453, 4.92182092859698, 3.9769855160478786, 2.9839664722198322, 1.9464951480482593, 2.890717705984521, 3.9151947454327374, 12.590780642685973, 13.570401016314982, 14.554347732289472, 14.904688429479206, 13.937776700617258, 12.899544399188468, 11.94216582310979, 10.911955824848782, 9.947202813036164, 8.906441601274086, 7.8345388758261985, 6.788096428089161, 5.82915095529593, 4.872105680957353, 3.9363084933732777, 2.9786108327666407, 2.0527451612275156, 1.0146234981708324, 1.964071520460637, 2.8968682252838165, 13.571047036563089, 14.51714043690185, 15.161494892016933, 14.190254059752903, 13.162760462101312, 12.192914593950867, 11.212141592648754, 10.263132190897215, 9.195170291384905, 8.185904258725754, 7.134740318451973, 6.1728763465507335, 5.138513785117117, 4.153923623696389, 3.0906774222116464, 2.045562600771026, 1.0384571818138713, 0.0, 1.0650610487849819, 2.0235441598064594, 14.511847578865993, 15.476279553778209, 16.094801854417128, 15.163264128743142, 14.200191280857357, 13.151857682748416, 12.148608798695822, 11.120148062495074, 10.08382401901245, 9.10665397005344, 8.0416101294466, 7.05127477117113, 6.076930039728831, 5.0372864585102235, 4.027216718005705, 3.0001867188682843, 1.9886888092193333, 0.9973635615794469, 2.002729204517834, 3.030207743299827, 15.559570151663841, 16.527498741411648, 16.861351547988185, 15.84969923362293, 14.891563830845282, 13.831964187717332, 12.770411667459248, 11.760871666249352, 10.689698823660972, 9.761547641181943, 8.76050542955731, 7.750634761900034, 6.770525928572748, 5.805842113986908, 4.813723689344309, 3.8683446105745336, 2.9389510122522062, 2.0093147017709008, 2.998359936097908, 3.933034364663773, 16.536844847841447, 17.53827783027721, 17.01567948649598, 16.543171843726164, 15.488494688308442, 14.485644871144396, 13.542691693869612, 12.603796386681914, 11.666755113432979, 10.730988530025009, 9.701719307986698, 8.718797551758154, 7.73118873447787, 6.831857404135947, 5.82095101319257, 4.801526191720008, 3.879615929352879, 2.9944675763200657, 3.9434926716100316, 4.8966044592227105, 17.472885931934513, 16.76792309690122, 15.972713720606851, 16.869928298854305, 16.456935454887272, 15.423200603910232, 14.601921376216326, 13.567877970348917, 12.582505483914183, 11.603900375062446, 10.64803737873825, 9.695375646398347, 8.659891705772012, 7.71813645081591, 6.764516840595709, 5.775517821670706, 4.915934250961558, 4.030833705120064, 4.915330706357648, 5.848290106759561], [5.996310390939974, 5.168120097212078, 6.118645834770874, 7.021348300150749, 7.868219106756026, 8.774656550260673, 9.742018064828276, 10.652294733368741, 11.671524223617343, 12.610238976269056, 13.538978450793003, 14.49641051355211, 15.566206408627416, 16.576063880190592, 17.50536952539638, 17.730208391964425, 16.67879493727734, 15.716066453823906, 14.83815899557013, 15.587957897881813, 4.993847063792692, 5.923903506979152, 6.89654408647149, 7.836889896733564, 8.797373320262626, 9.714855876514601, 10.696794439715337, 11.721497931659389, 12.61128817296391, 13.537076052857955, 14.537223812127657, 15.431293981978662, 16.37948832992498, 17.384543329379408, 17.60250676695066, 16.806452251632752, 15.766515783461514, 14.735614030117997, 13.810539289324467, 14.569308557150306, 4.048549624751256, 5.0286685795899055, 5.97129144643268, 6.971682856410664, 7.969074796341348, 8.940273730866107, 9.822275842525888, 10.866386986846042, 11.825205223405932, 12.865892775603674, 13.905541735815307, 14.918160295975433, 15.837213498273528, 16.769722858045814, 16.628077149162788, 15.817065868710737, 14.829059369683463, 13.791556253431676, 12.852043796249509, 13.610040771743225, 3.036230516110694, 4.0709142286957185, 5.034080082499466, 6.086482086941056, 7.01563329166068, 7.980528724317403, 8.88234079733174, 9.911974369356056, 10.89578234003895, 11.88191064137588, 12.839291712757259, 13.866932505872631, 14.851647315354764, 15.827386820285215, 15.593036277388634, 14.867377006898803, 13.818244761571263, 12.844161059912802, 11.923559713173207, 12.639296990523269, 2.02926948671204, 3.0784682140473105, 4.056307293133118, 5.1198267306194705, 6.050521864318816, 6.977704426645095, 7.907382316218614, 8.946221601037825, 9.900077229166786, 10.873546771692535, 11.938248182306706, 12.94153137579536, 13.908048108020171, 14.848781969602637, 14.543662080397633, 13.817389941810584, 12.822760396904604, 11.912417494777625, 10.881185338190106, 11.688023570980699, 2.841533748827288, 3.8596087797469645, 4.897040643551874, 5.899558364490307, 6.971713132249164, 7.991050329808411, 8.869097666596842, 9.901488212958151, 10.838245684148601, 11.840816503313677, 12.844691506753596, 13.788886585685415, 14.80026080787773, 14.499618032994077, 13.523257921684593, 12.767565466449824, 11.78135794406033, 10.876403055931391, 9.880055714637342, 10.63046683434777, 3.879280993091858, 4.819237852700662, 5.790431867419358, 6.808973496494573, 7.771966860249917, 8.820652643981477, 9.802565963574219, 10.853847102128656, 11.823453423928836, 12.826989971800439, 13.840767737095629, 14.734275199739955, 14.419108825404763, 13.47598608298625, 12.544677562801795, 11.697053292805018, 10.706779772047485, 9.84343758812359, 8.83876809020337, 9.660753544621723, 4.809909625072218, 5.81631803109787, 6.7796507394015, 7.8179334496167785, 8.8051930232855, 9.7449292846963, 10.784401735825043, 11.810660054995548, 12.768944123431618, 13.821626260663994, 14.831376424465814, 14.432000184845538, 13.433845460560692, 12.495640825785578, 11.571108896833959, 10.626970916883971, 9.740066488744016, 8.844398005601755, 7.889152180556135, 8.672100625836709, 5.742328237464616, 6.770404578852049, 7.7477135362799565, 8.714564463505925, 9.670222599765479, 10.652476207857204, 11.71757591484429, 12.653099819679719, 13.633368487247404, 14.656716915944664, 14.47639249482098, 13.437431491583427, 12.457858345941505, 11.53135756741907, 10.57661691240949, 9.649167026355906, 8.715153214941655, 7.8520896604891, 6.82654734970236, 7.7040598980379995, 6.7949381383885905, 7.828983894223397, 8.695176028070842, 9.689252221794327, 10.615194150649323, 11.59646515922769, 12.53275428303726, 13.563855731843345, 14.553082173274703, 14.63213218494098, 13.590014108523757, 12.64402391910819, 11.657800583311836, 10.58780287011043, 9.678215315463854, 8.750588345954647, 7.740663232899484, 6.918791758946374, 5.873992816161825, 6.7100499585510835, 7.664334956878232, 8.611082550864586, 9.632185114012673, 10.662262240473593, 11.658371849766386, 12.586737316096205, 13.565524050395048, 14.524808564154306, 14.660653023837584, 13.63055408683052, 12.729317365899485, 11.678863431341936, 10.701251111451114, 9.653014461101492, 8.66064252959141, 7.71089878042263, 6.72012166030471, 5.858306762489287, 4.948622382350311, 5.76420529328761, 8.595832567156027, 9.620935104434281, 10.614663130007013, 11.633767744759815, 12.660509839851306, 13.640623221128617, 14.567512342808081, 14.64754094722539, 13.594618327946906, 12.644977989854882, 11.705468066857158, 10.724644635835187, 9.69325242566533, 8.685259667457657, 7.722713086422713, 6.768088319787362, 5.766578625502458, 4.8017658511644274, 3.909876104371488, 4.793397389154408, 9.603084905087998, 10.657133537919186, 11.583148769441197, 12.517260533863574, 13.572902372794198, 14.536245050853887, 14.64756881800946, 13.652769664225646, 12.63735581446152, 11.621577660129137, 10.688775782468898, 9.742164375239396, 8.778205107440453, 7.8239956761137925, 6.7779945630625384, 5.815746888002348, 4.764905279156322, 3.788798149033214, 2.892375713788791, 3.8680394067432156, 10.655457586328886, 11.627021603244012, 12.56830740414189, 13.449859142635564, 14.454702975790852, 14.79857399365371, 13.72961168058048, 12.661290712430812, 11.712055608415637, 10.771283601477393, 9.720881760186868, 8.793036810769228, 7.832926973851171, 6.902613748208885, 5.948426580866411, 4.896504944204382, 3.9034859003763365, 2.8437518047901573, 1.8890783181468098, 2.913555357595026, 11.635013968415333, 12.614634342044344, 13.59858105801883, 14.521352777859862, 14.97104834028236, 13.93281603885357, 12.975437462774892, 11.945227464513884, 10.980474452701266, 9.939713240939188, 8.8678105154913, 7.821368067754262, 6.862422594961031, 5.9053773206224545, 4.969580133038379, 4.011882472431742, 2.97226458938402, 1.9118801549127302, 0.9624321326229257, 1.8952288374461053, 12.615280362292449, 13.56137376263121, 14.623387802843608, 15.255315108537886, 14.227821510886296, 13.25797564273585, 12.277202641433737, 11.328193239682198, 10.260231340169888, 9.250965307510736, 8.199801367236955, 7.237937395335715, 6.203574833902099, 5.218984672481371, 4.155738470996629, 3.1106236495560085, 2.103518230598853, 1.0650610487849819, 0.0, 0.9584831110214774, 13.556080904595353, 14.520512879507569, 15.48846899886329, 16.228325177528124, 15.26525232964234, 14.216918731533399, 13.213669847480805, 12.185209111280058, 11.148885067797433, 10.171715018838423, 9.106671178231581, 8.116335819956111, 7.141991088513812, 6.102347507295206, 5.092277766790687, 4.065247767653267, 3.0537498580043154, 2.062424610364429, 1.063363225312135, 1.99687645591671, 14.603803477393203, 15.571732067141006, 16.418270472268055, 16.91476028240791, 15.956624879630265, 14.897025236502316, 13.835472716244231, 12.825932715034336, 11.754759872445955, 10.826608689966926, 9.825566478342294, 8.815695810685018, 7.835586977357731, 6.870903162771891, 5.878784738129292, 4.933405659359517, 4.004012061037189, 3.074375750555883, 2.113441016044759, 3.010435616852692, 15.581078173570809, 16.582511156006568, 17.369534650497584, 17.608232892511147, 16.553555737093426, 15.55070591992938, 14.607752742654595, 13.668857435466897, 12.731816162217962, 11.796049578809992, 10.766780356771681, 9.783858600543137, 8.796249783262853, 7.89691845292093, 6.886012061977553, 5.866587240504991, 4.944676978137862, 4.059528625105048, 3.129803649233905, 4.0435820569065335, 16.517119257663875, 15.8343390635656, 16.707111839988634, 17.685823200703858, 17.521996503672256, 16.488261652695215, 15.66698242500131, 14.6329390191339, 13.647566532699166, 12.66896142384743, 11.713098427523233, 10.76043669518333, 9.724952754556995, 8.783197499600893, 7.829577889380692, 6.84057887045569, 5.9809952997465405, 5.095894753905046, 4.101641683981521, 4.995267704443384], [5.037827279918496, 5.909976205507588, 6.901058583273759, 7.846076829260557, 8.769515524924229, 9.675952968428875, 10.643314482996479, 11.553591151536946, 12.572820641785547, 13.51153539443726, 14.440274868961207, 15.397706931720315, 16.467502826795616, 17.477360298358793, 18.406665943564583, 18.56014601329494, 17.508732558607853, 16.54600407515442, 15.668096616900645, 14.76219238143421, 4.035363952771214, 4.965420395957675, 5.938060975450012, 6.8784067857120865, 7.860788997453975, 8.86376003818599, 9.82608473912746, 10.854473390289945, 11.869310902704706, 12.874144699144026, 13.874292458413727, 14.866931921164394, 15.81512626911071, 16.82018126856514, 17.726969709524578, 17.636389872963267, 16.59645340479203, 15.565551651448512, 14.640476910654982, 13.743543040702702, 3.090066513729778, 4.070185468568428, 5.0128083354112025, 6.013199745389186, 7.010591685319871, 7.981790619844628, 8.863792731504411, 9.907903875824564, 10.866722112384455, 11.907409664582197, 12.947058624793828, 13.959677184953954, 14.87873038725205, 15.811239747024334, 16.752540091736705, 16.748635559959503, 15.685178659693644, 14.62149387476219, 13.681981417580024, 12.784275255295622, 2.0777474050892164, 3.1124311176742414, 4.07559697147799, 5.12799897591958, 6.057150180639203, 7.0220456132959255, 7.923857686310262, 8.953491258334578, 9.937299229017473, 10.923427530354402, 11.88080860173578, 12.908449394851152, 13.893164204333287, 14.868903709263737, 15.841407137426073, 15.825860117920282, 14.77672787259274, 13.769446826408084, 12.753497334503722, 11.813531474075665, 1.070786375690563, 2.1199851030258334, 3.0978241821116415, 4.161343619597993, 5.092038753297339, 6.019221315623618, 6.9488992051971366, 7.987738490016348, 8.941594118145309, 9.915063660671057, 10.979765071285229, 11.983048264773883, 12.949564996998694, 13.89029885858116, 14.88489212493471, 14.775873052832063, 13.781243507926082, 12.837703261272907, 11.806471104685388, 10.862258054533095, 1.9765231834680854, 2.9945982143877625, 4.032030078192673, 5.034547799131106, 6.0695861848711825, 7.032567218786934, 7.910614555575364, 8.943005101936674, 9.879762573127124, 10.8823333922922, 11.886208395732119, 12.830403474663937, 13.841777696856253, 14.826375233094742, 14.48174103270607, 13.726048577471303, 12.739841055081808, 11.801688822426673, 10.805341481132624, 9.804701317900166, 3.0207153269468248, 3.95859442805432, 4.929788442773015, 5.948330071848231, 6.911323435603574, 7.9600092193351335, 8.887403211404688, 9.938684349959125, 10.908290671759305, 11.868506860778961, 12.882284626074151, 13.775792088718477, 14.786739810840054, 14.434469194007727, 13.503160673823272, 12.655536403826495, 11.665262883068962, 10.768723354618873, 9.764053856698652, 8.83498802817412, 3.9513439589271853, 4.955674606451528, 5.919007314755158, 6.957290024970436, 7.944549598639159, 8.884285860049957, 9.9237583111787, 10.895497302826017, 11.853781371262087, 12.863143149642516, 13.872893313444337, 14.757100094906976, 14.392328571582171, 13.454123936807058, 12.529592007855436, 11.585454027905449, 10.698549599765494, 9.802881116623233, 8.847635291577612, 7.846335109389106, 4.883762571319583, 5.909761154205707, 6.887070111633614, 7.853921038859582, 8.809579175119136, 9.791832783210861, 10.856932490197947, 11.792456395033376, 12.772725062601062, 13.79607349129832, 14.813987308132443, 14.395914602604904, 13.416341456962982, 12.489840678440547, 11.535100023430967, 10.607650137377384, 9.673636325963132, 8.810572771510579, 7.785030460723838, 6.878294381590395, 5.937504507153913, 6.968340469577054, 7.834532603424499, 8.828608797147984, 9.754550726002979, 10.735821734581346, 11.672110858390916, 12.703212307197001, 13.692438748628359, 14.622276583849567, 14.548497219545235, 13.602507030129667, 12.616283694333312, 11.546285981131906, 10.636698426485331, 9.709071456976124, 8.699146343920962, 7.877274869967851, 6.832475927183302, 5.884284442103479, 6.838569440430628, 7.78531703441698, 8.806419597565068, 9.836496724025988, 10.797728425120042, 11.72609389144986, 12.704880625748704, 13.664165139507961, 14.683163617329598, 14.589037197851997, 13.687800476920962, 12.637346542363414, 11.659734222472592, 10.611497572122968, 9.619125640612886, 8.669381891444107, 7.678604771326188, 6.816789873510764, 5.907105493371788, 4.9384397768400055, 7.770067050708422, 8.795169587986676, 9.788897613559408, 10.80800222831221, 11.820743918687825, 12.779979796482273, 13.706868918161737, 14.595536774982904, 14.553101438968383, 13.603461100876359, 12.663951177878635, 11.683127746856664, 10.651735536686807, 9.643742778479135, 8.68119619744419, 7.726571430808839, 6.725061736523935, 5.760248962185905, 4.868359215392966, 3.9676318727068036, 8.777319388640395, 9.831368021471581, 10.757383252993591, 11.691495017415969, 12.747136856346593, 13.710479534406282, 14.680613721874712, 14.611252775247124, 13.595838925482997, 12.580060771150615, 11.647258893490376, 10.700647486260873, 9.73668821846193, 8.78247878713527, 7.736477674084016, 6.7742299990238255, 5.723388390177799, 4.747281260054692, 3.8508588248102686, 3.0422738902956117, 9.829692069881283, 10.801256086796409, 11.742541887694285, 12.624093626187959, 13.628937459343247, 14.650400718214968, 14.688094791601957, 13.61977382345229, 12.670538719437115, 11.72976671249887, 10.679364871208346, 9.751519921790706, 8.791410084872648, 7.861096859230362, 6.906909691887889, 5.85498805522586, 4.861969011397814, 3.802234915811635, 2.8475614291682874, 2.0877898411474223, 10.80924845196773, 11.78886882559674, 12.772815541571227, 13.695587261412257, 14.59867244433435, 14.891299149875048, 13.93392057379637, 12.903710575535362, 11.938957563722743, 10.898196351960665, 9.826293626512777, 8.77985117877574, 7.820905705982509, 6.863860431643932, 5.928063244059857, 4.970365583453219, 3.9307477004054974, 2.8703632659342078, 1.9209152436444032, 1.0302182720869029, 11.789514845844845, 12.735608246183606, 13.797622286396004, 14.654251209912331, 15.186304621907771, 14.216458753757326, 13.235685752455213, 12.286676350703674, 11.218714451191364, 10.209448418532213, 9.158284478258432, 8.196420506357192, 7.162057944923577, 6.177467783502848, 5.114221582018106, 4.069106760577486, 3.0620013416203307, 2.0235441598064594, 0.9584831110214774, 0.0, 12.73031538814775, 13.694747363059966, 14.662703482415687, 15.618046400026442, 16.223735440663816, 15.175401842554875, 14.17215295850228, 13.143692222301533, 12.10736817881891, 11.130198129859899, 10.065154289253059, 9.074818930977589, 8.10047419953529, 7.060830618316683, 6.050760877812165, 5.023730878674744, 4.012232969025793, 3.0209077213859064, 2.0218463363336125, 1.0383933448952325, 13.7780379609456, 14.745966550693403, 15.59250495582045, 16.604157270185706, 16.857921297798466, 15.798321654670517, 14.736769134412432, 13.727229133202536, 12.656056290614156, 11.727905108135127, 10.726862896510495, 9.716992228853218, 8.736883395525933, 7.772199580940094, 6.780081156297495, 5.834702077527719, 4.9053084792053925, 3.9756721687240866, 2.9866269343970795, 2.0519525058312142, 14.755312657123206, 15.756745639558964, 16.54376913404998, 17.550588924150148, 17.45485215526163, 16.452002338097582, 15.509049160822796, 14.570153853635098, 13.633112580386163, 12.697345996978193, 11.668076774939884, 10.68515501871134, 9.697546201431056, 8.798214871089133, 7.7873084801457555, 6.767883658673194, 5.845973396306065, 4.952014662876191, 4.0029895675862255, 3.085098945885056, 15.691353741216272, 16.664276684896116, 17.53704946131915, 18.515760822034373, 18.423292921840464, 17.38955807086342, 16.56827884316951, 15.534235437302101, 14.548862950867369, 13.570257842015632, 12.614394845691436, 11.661733113351534, 10.626249172725199, 9.684493917769096, 8.730874307548895, 7.741875288623892, 6.882291717914744, 5.98838079167619, 4.974827602333842, 4.036784593421906], [16.0502506834807, 16.616440227139403, 17.607522604905572, 18.55254085089237, 18.37576142441336, 17.325303266409627, 16.344227968692273, 15.378226477020366, 14.358996986771764, 13.420282234120052, 12.491542759596104, 11.611047497206934, 10.614545648977897, 9.671835241544022, 8.739013873166465, 7.747331580714132, 6.695918126027045, 5.733189642573614, 4.855282184319835, 3.9245217549303053, 15.04778735633342, 15.671884417589489, 16.644524997081827, 17.5848708073439, 17.80544938665301, 16.807594145251052, 15.760076724966128, 14.718655666207582, 13.70381815379282, 12.6989843573535, 11.6988365980838, 10.706197135333133, 9.758002787386816, 8.752947787932387, 7.8023016532992955, 6.823575440382459, 5.783638972211221, 4.752737218867704, 3.8276624780741724, 2.9307286081218926, 14.041433693838263, 14.738852824118219, 15.681475690960994, 16.681867100938977, 16.85979616109081, 15.888597226566052, 14.894499721364483, 13.87516699077514, 12.91634875421525, 11.999942809396211, 10.951524677547807, 9.91433585544416, 8.882566675353704, 7.913299033975347, 6.98364710469335, 5.935821127378695, 4.872364227112836, 3.8086794421813823, 2.8691669849992154, 1.9714608227148123, 13.029114585197702, 13.781098473224032, 14.74426432702778, 15.752140637821196, 15.880889765215224, 14.910954623533804, 13.954564676170333, 12.924931104146017, 11.941123133463122, 10.954994832126193, 9.997613760744816, 8.969972967629444, 7.9467025011452, 6.97096299621475, 5.9984595680524135, 5.0277985621921, 3.9751135760420775, 2.960880569572585, 1.9406829019229126, 1.0007170414948559, 11.98382298410954, 12.788652458575624, 13.766491537661432, 14.713457931183173, 15.615494610020754, 15.801793536171608, 14.87211564659809, 13.833276361778879, 12.879420733649917, 11.905951191124169, 10.841249780509997, 9.837966587021343, 8.871449854796532, 7.930715993214067, 6.936122726860516, 5.97228586758429, 4.940491990397737, 3.892624134707762, 2.8560202748846084, 1.9105800263545691, 10.921713252461213, 11.781474182257837, 12.801282443909715, 13.763976154181394, 14.63794717844691, 15.587501385354837, 15.833830996976317, 14.878755373913291, 13.817589188631732, 12.786912876242758, 11.783037872802838, 10.847867869041872, 9.836493646849556, 8.896737438448412, 7.920377327138928, 6.977219280864039, 5.918371479042939, 4.85349723973142, 3.8571498984373713, 2.9269476659967264, 9.877521108982474, 10.817477968591279, 11.783963709393497, 12.75568854698257, 13.6720077026588, 14.620255060363238, 15.60216837995598, 15.766903838657223, 14.797297516857043, 13.773086344729519, 12.759653365177346, 11.793256483096412, 10.781455760833357, 9.780895718311386, 8.849587198126931, 7.796884372699246, 6.773222622542381, 5.830396282167525, 4.825726784247305, 3.8966609557227727, 8.946892477002114, 9.855030287402768, 10.75851161460022, 11.746728593860364, 12.638781539623213, 13.578517801034012, 14.617990252162755, 15.55139898207776, 15.727951115682217, 14.667727375216623, 13.657977211414803, 12.681780455197183, 11.683625730912336, 10.745421096137223, 9.68207721251148, 8.662294028814305, 7.714874109495438, 6.730588518940162, 5.77534269389454, 4.883980278758645, 8.014473864609718, 8.900943739648588, 9.790448817721764, 10.757299744947732, 11.712957881207286, 12.69521148929901, 13.674229497942802, 14.578037513813465, 15.55830618138115, 15.485237204641567, 14.467323387807443, 13.42836238456989, 12.448789238927969, 11.522288460405534, 10.567547805395954, 9.64009791934237, 8.7397873832978, 7.797429332312514, 6.837947524748315, 5.852021006557355, 6.960731928775387, 7.842364424277241, 8.842986325930879, 9.837062519654364, 10.779931850326623, 11.733854314210983, 12.670143438020553, 13.623495986966704, 14.612722428398062, 15.54256026361927, 15.378023668342669, 14.432033478927101, 13.491733931004621, 12.515058169669887, 11.56607995911135, 10.638452989602143, 9.711488908010583, 8.73072723385524, 7.79050205828885, 6.846030946044271, 5.950808660418717, 6.89755625440507, 7.918658817553157, 8.829081274650886, 9.737619067570485, 10.665984533900303, 11.66533443374125, 12.567314870095384, 13.58631334791702, 14.631037476823822, 15.610980266389475, 15.397193966693354, 14.513582691136683, 13.449846578678825, 12.602771128150028, 11.708055221587994, 10.732030480605356, 9.73354250314277, 8.715872492100365, 7.791875611307745, 5.019311050140923, 5.958637118431863, 6.898818118481998, 7.772628387408772, 8.714603574002702, 9.647746762673334, 10.663346141328217, 11.635943234620441, 12.613848314870209, 13.671387296306293, 14.597481128629047, 15.591009583049964, 15.428512796512877, 14.420520038305204, 13.641707976327863, 12.687083209692512, 11.685573515407608, 10.773915666197029, 9.754618770079187, 8.762683515440948, 3.952995999507356, 4.922438684946957, 5.930332479047814, 6.799692081428523, 7.742976743650149, 8.69751886999021, 9.646372797836882, 10.641171951620697, 11.656585801384823, 12.647986966580548, 13.580788844240788, 14.574677348397458, 15.538636616196401, 15.409005025287563, 14.605025048789463, 13.642777373729272, 12.596413216697787, 11.62030608657468, 10.685887831741585, 9.68804149785214, 2.9006233182664682, 3.8721873351815947, 4.94517384434712, 5.867093472656534, 6.732246551285285, 7.740193710537374, 8.701104589414703, 9.754989776928081, 10.704224880943256, 11.6449968878815, 12.695398729172025, 13.623243678589665, 14.641303526193173, 15.694631213128348, 15.560605321818164, 14.536190633517919, 13.543171589689873, 12.565352430817736, 11.667002586448545, 10.642525547000329, 1.9210669361800212, 2.959203426982765, 3.9365884821996913, 4.795599837432236, 5.762511566294183, 6.800743867722973, 7.758122443801652, 8.729146279232795, 9.693899291045414, 10.734660502807492, 11.80656322825538, 12.834688734993394, 13.793634207786626, 14.750679482125204, 15.686476669709279, 15.514010783729912, 14.47439290068219, 13.497224080695164, 12.593648771972429, 11.700097116060848, 0.9408005423029044, 1.8868939426416653, 2.865695056668131, 3.8369358889321603, 4.8644294865837505, 5.834275354734197, 6.81504835603631, 7.764057757787849, 8.832019657300158, 9.84128568995931, 10.892449630233092, 11.854313602134331, 12.888676163567947, 13.873266324988675, 14.936512526473416, 15.981627347914037, 15.488680880095835, 14.511847578865996, 13.556080904595355, 12.730315388147751, 0.0, 0.9644319749122161, 1.9323880942679366, 2.887731011878691, 3.8817196295135576, 4.947555997687623, 5.950804881740217, 6.979265617940964, 8.015589661423588, 8.992759710382598, 10.05780355098944, 11.04813890926491, 12.02248364070721, 13.062127221925817, 14.072196962430336, 15.099226961567757, 16.110724871216707, 15.509211140445444, 14.619444129907489, 13.768708733042985, 1.0725720090141155, 2.0156511625456544, 2.8621895676727007, 3.8738418820379574, 4.831977284815606, 5.891576927943556, 6.8827810178452715, 7.892321019055167, 8.963493861643547, 9.891645044122576, 10.892687255747209, 11.902557923404485, 12.882666756731771, 13.84735057131761, 14.83946899596021, 15.784848074729986, 16.714241673052314, 16.521162280636897, 15.669521920640113, 14.782267893978966, 2.049846705191721, 3.0264302514112154, 3.813453745902231, 4.820273536002398, 5.83249837419085, 6.835348191354896, 7.7783013686296805, 8.717196675817378, 9.654237949066314, 10.590004532474284, 11.663022457502574, 12.645944213731118, 13.633553031011402, 14.619289898391724, 15.67758037020544, 16.697005191678002, 17.654906590152986, 17.506315155186062, 16.685884553829258, 15.815414334032807, 2.9858877892847877, 3.9738207593485484, 4.8564195117913584, 5.87254902168087, 6.850017196421126, 7.772903924120731, 8.831428369516853, 9.681278259484381, 10.581816923669559, 11.546815651017123, 12.50267864734132, 13.55202019514497, 14.562256002305546, 15.618161977296223, 16.571781587516423, 17.560780606441426, 18.57582334302528, 18.54268128398606, 17.657722588576874, 16.767099981569658], [16.94798548095644, 15.960021520172614, 16.951103897938783, 17.875058173357733, 17.411329449501142, 16.36087129149741, 15.379795993780055, 14.41379450210815, 13.394565011859548, 12.455850259207836, 11.527110784683888, 10.64661552229472, 9.650113674065683, 8.75081623947252, 7.817994871094965, 6.826312578642631, 5.845761406497301, 4.883032923043871, 4.0055688524318045, 4.888953729842521, 15.94552215380916, 15.0154657106227, 15.967042319547188, 16.907388129809263, 17.613783488303856, 17.30107061775134, 16.334572368667114, 15.349166473620876, 14.334328961206115, 13.382687335796735, 12.574138453471939, 11.581498990721272, 10.642436237963864, 9.68485144669372, 8.766733628211512, 7.788007415294675, 6.748070947123437, 5.71716919377992, 4.7920944529863885, 3.8951605830341087, 15.00586566875048, 14.08243411715143, 14.915375389498303, 15.915766799476287, 16.668130262741656, 16.853029201478268, 15.858931696276699, 14.839598965687356, 13.880780729127466, 12.964374784308427, 11.915956652460023, 10.878767830356376, 9.84699865026592, 8.877731008887563, 7.9480790796055665, 6.900253102290911, 5.836796202025052, 4.773111417093598, 3.8335989599114315, 2.9358927976270284, 13.99354656010992, 13.124679766257243, 13.97816402556509, 14.94563420343836, 15.649506463149846, 15.87538659844602, 14.91899665108255, 13.889363079058233, 12.905555108375339, 11.919426807038409, 10.962045735657032, 9.93440494254166, 8.911134476057416, 7.935394971126966, 6.96289154296463, 5.992230537104316, 4.939545550954294, 3.925312544484801, 2.9051148768351287, 1.965149016407072, 12.948254959021758, 12.132233751608835, 13.000391236198741, 13.906951496800337, 14.66387307147264, 15.59105563379892, 15.836547621510306, 14.797708336691095, 13.843852708562133, 12.870383166036385, 11.805681755422214, 10.80239856193356, 9.835881829708748, 8.895147968126283, 7.900554701772732, 6.936717842496506, 5.904923965309953, 4.857056109619978, 3.8204522497968245, 2.8750120012667852, 11.886145227373431, 11.125055475291047, 12.007341125058401, 12.957469719798558, 13.686325639898795, 14.635879846806725, 15.60368657691637, 15.843187348825507, 14.782021163543948, 13.751344851154974, 12.747469847715054, 11.812299843954088, 10.800925621761772, 9.861169413360628, 8.884809302051144, 7.9416512557762555, 6.882803453955155, 5.8179292146436365, 4.821581873349587, 3.8913796409089425, 10.841953083894692, 10.161059261624489, 10.990022390542183, 11.949182112599734, 12.720386164110685, 13.668633521815126, 14.650546841407868, 15.543779960032436, 15.761729491769259, 14.737518319641735, 13.724085340089562, 12.757688458008628, 11.745887735745573, 10.745327693223603, 9.814019173039148, 8.761316347611462, 7.737654597454597, 6.794828257079741, 5.790158759159521, 4.861092930634989, 9.911324451914332, 9.16397908322728, 9.964570295748906, 10.940222159477528, 11.687160001075101, 12.6268962624859, 13.666368713614643, 14.586967007165544, 15.545251075601614, 15.63215935012884, 14.622409186327019, 13.646212430109399, 12.648057705824552, 11.709853071049439, 10.646509187423696, 9.626726003726521, 8.679306084407653, 7.695020493852378, 6.739774668806756, 5.848412253670861, 8.978905839521936, 8.2098925354731, 8.99650749887045, 9.950793310564896, 10.761336342659174, 11.743589950750899, 12.709797523030586, 13.613605538901249, 14.593874206468934, 15.572816073594343, 15.43175536271966, 14.392794359482107, 13.413221213840185, 12.48672043531775, 11.53197978030817, 10.604529894254586, 9.704219358210015, 8.761861307224729, 7.802379499660531, 6.816452981469571, 7.925163903687604, 7.151313220101753, 8.049045007079565, 8.904050772014235, 9.816364791775332, 10.769422339298767, 11.705711463108337, 12.659064012054488, 13.648290453485846, 14.578128288707054, 15.63448281819336, 15.396465453839317, 14.456165905916837, 13.479490144582103, 12.530511934023567, 11.60288496451436, 10.675920882922798, 9.695159208767455, 8.754934033201067, 7.810462920956487, 6.915240635330934, 6.206505050229582, 7.012208344210914, 7.864649299738669, 8.773187092658269, 9.701552558988087, 10.700902458829034, 11.602882895183168, 12.621881373004804, 13.666605501911606, 14.64654829147726, 15.580796403644495, 15.4780146660489, 14.414278553591041, 13.567203103062244, 12.67248719650021, 11.696462455517572, 10.697974478054986, 9.680304467012581, 8.756307586219961, 5.98374302505314, 5.196652496659888, 5.956074435299293, 6.808196412496556, 7.750171599090486, 8.683314787761118, 9.698914166416001, 10.671511259708225, 11.649416339957993, 12.706955321394075, 13.63304915371683, 14.626577608137746, 15.499422764626736, 15.38495201321742, 14.60613995124008, 13.651515184604728, 12.650005490319824, 11.738347641109245, 10.719050744991403, 9.727115490353164, 4.917427974419573, 4.160454063174981, 4.9875887958651095, 5.835260106516307, 6.778544768737933, 7.733086895077994, 8.681940822924666, 9.67673997670848, 10.692153826472607, 11.68355499166833, 12.61635686932857, 13.61024537348524, 14.574204641284183, 15.528414072610843, 15.569457023701679, 14.607209348641488, 13.560845191610003, 12.584738061486895, 11.650319806653801, 10.652473472764356, 3.8650552931786843, 3.1102027134096195, 4.0024301611644155, 4.902661497744318, 5.767814576373069, 6.775761735625158, 7.736672614502487, 8.790557802015863, 9.739792906031038, 10.680564912969283, 11.730966754259807, 12.658811703677447, 13.676871551280955, 14.73019923821613, 15.684386405558604, 15.500622608430135, 14.507603564602089, 13.529784405729952, 12.631434561360761, 11.606957521912545, 2.8854989110922373, 2.122589974609289, 2.972156507287475, 3.8311678625200196, 4.798079591381967, 5.836311892810757, 6.7936904688894355, 7.764714304320578, 8.729467316133196, 9.770228527895274, 10.842131253343162, 11.870256760081178, 12.82920223287441, 13.786247507212988, 14.722044694797063, 15.6797423554037, 15.438824875594406, 14.46165605560738, 13.558080746884645, 12.664529090973064, 1.9052325172151205, 1.0502804902681888, 1.901263081755915, 2.872503914019944, 3.899997511671534, 4.86984337982198, 5.850616381124093, 6.799625782875632, 7.867587682387942, 8.876853715047094, 9.928017655320875, 10.889881627222115, 11.92424418865573, 12.908834350076459, 13.9720805515612, 15.01719537300182, 16.024300791958975, 15.476279553778213, 14.52051287950757, 13.694747363059967, 0.9644319749122161, 0.0, 0.9679561193557203, 1.9232990369664749, 2.9172876546013415, 3.983124022775406, 4.9863729068280005, 6.014833643028748, 7.051157686511372, 8.028327735470382, 9.093371576077224, 10.083706934352694, 11.058051665794993, 12.0976952470136, 13.10776498751812, 14.13479498665554, 15.146292896304491, 16.137618143944376, 15.583876104819705, 14.7331407079552, 2.037003983926332, 1.0512191876334382, 1.8977575927604846, 2.9094099071257413, 3.8675453099033894, 4.927144953031339, 5.918349042933055, 6.927889044142951, 7.999061886731331, 8.92721306921036, 9.928255280834993, 10.938125948492269, 11.918234781819555, 12.882918596405394, 13.875037021047994, 14.82041609981777, 15.749809698140098, 16.679446008621404, 16.63395389555233, 15.746699868891183, 3.014278680103937, 2.0619982764989992, 2.849021770990015, 3.855841561090182, 4.868066399278634, 5.87091621644268, 6.813869393717464, 7.752764700905163, 8.6898059741541, 9.62557255756207, 10.69859048259036, 11.681512238818904, 12.669121056099188, 13.65485792347951, 14.713148395293226, 15.732573216765788, 16.69047461524077, 17.653960156278476, 17.650316528741477, 16.779846308945025, 3.950319764197004, 3.0093887844363323, 3.8919875368791423, 4.908117046768654, 5.88558522150891, 6.808471949208515, 7.866996394604637, 8.716846284572167, 9.617384948757344, 10.582383676104907, 11.538246672429104, 12.587588220232753, 13.59782402739333, 14.653730002384009, 15.60734961260421, 16.596348631529214, 17.61139136811307, 17.97385497880461, 17.02649993340317, 17.731531956481874], [17.73317932581286, 16.74521536502903, 16.035392020851447, 16.907102054002014, 16.443373330145423, 15.39291517214169, 14.411839874424336, 13.44583838275243, 12.426608892503829, 11.487894139852116, 10.559154665328169, 9.678659402939, 8.682157554709962, 7.7828601201168, 6.850038751739244, 5.85835645928691, 4.877805287141581, 3.9150768036881507, 4.761789540811342, 5.7158851741047805, 16.730715998665577, 15.800659555479116, 14.999086200191469, 15.939432010453544, 16.645827368948137, 16.33311449839562, 15.366616249311397, 14.381210354265157, 13.366372841850396, 12.414731216441016, 11.606182334116218, 10.613542871365551, 9.674480118608143, 8.716895327338, 7.80183929560236, 6.8231130826855235, 5.837853062863973, 4.895529227394061, 5.760050572342109, 4.86311670238983, 15.868222593203198, 14.867627962007846, 13.947419270142584, 14.947810680120568, 15.700174143385937, 16.603566415147753, 16.328908256934447, 15.327779868730538, 14.388550227406096, 13.46340300330004, 12.597111585500013, 11.559922763396365, 10.68683689948096, 9.717569258102603, 8.776268913390235, 7.853539853254286, 6.804752321380773, 5.741067536449319, 4.801555079267152, 3.903848916982749, 14.955629492208757, 13.90987361111366, 13.01020790620937, 13.977678084082639, 14.681550343794127, 15.625923812115508, 15.886952770438269, 14.857319198413952, 13.873511227731058, 12.887382926394128, 11.930001855012751, 10.902361061897379, 9.879090595413135, 8.903351090482685, 7.93084766232035, 6.960186656460036, 5.907501670310014, 4.893268663840521, 3.873070996190849, 2.9331051357627924, 13.916211078377478, 12.917427596465252, 12.032435116843022, 12.938995377444616, 13.69591695211692, 14.6230995144432, 15.55277740401672, 15.765664456046814, 14.811808827917853, 13.838339285392104, 12.773637874777933, 11.770354681289279, 10.803837949064468, 9.863104087482002, 8.868510821128451, 7.904673961852225, 6.872880084665672, 5.825012228975698, 4.788408369152545, 3.8429681206225057, 12.85410134672915, 11.910249320147464, 11.039385005702682, 11.989513600442837, 12.718369520543076, 13.667923727451006, 14.635730457560651, 15.584948672258166, 15.749977282899668, 14.719300970510693, 13.715425967070773, 12.780255963309807, 11.768881741117491, 10.829125532716349, 9.852765421406865, 8.909607375131976, 7.850759573310876, 6.7858853339993574, 5.789537992705308, 4.859335760264663, 11.809909203250411, 10.946253106480906, 10.022066271186464, 10.981225993244013, 11.752430044754966, 12.700677402459407, 13.682590722052149, 14.575823840676717, 15.530238767003521, 15.705474438997454, 14.692041459445282, 13.725644577364347, 12.713843855101292, 11.713283812579323, 10.781975292394868, 9.729272466967183, 8.705610716810318, 7.762784376435462, 6.758114878515242, 5.82904904999071, 10.879280571270051, 9.949172928083698, 8.996614176393187, 9.972266040121808, 10.719203881719382, 11.658940143130181, 12.698412594258924, 13.619010887809825, 14.577294956245895, 15.596255033261999, 15.59036530568274, 14.61416854946512, 13.616013825180273, 12.67780919040516, 11.614465306779417, 10.594682123082242, 9.647262203763374, 8.662976613208098, 7.707730788162477, 6.816368373026581, 9.946861958877655, 8.995086380329518, 8.028551379514731, 8.982837191209175, 9.793380223303455, 10.77563383139518, 11.741841403674865, 12.64564941954553, 13.625918087113215, 14.604859954238623, 15.622773771072747, 15.360750478837828, 14.381177333195906, 13.45467655467347, 12.49993589966389, 11.572486013610307, 10.672175477565736, 9.72981742658045, 8.770335619016251, 7.784409100825291, 8.893120023043323, 7.936507064958171, 7.081088887723846, 7.9360946526585145, 8.84840867241961, 9.801466219943046, 10.737755343752616, 11.691107892698769, 12.680334334130126, 13.610172169351335, 14.666526698837641, 15.578000772055029, 15.424122025272558, 14.447446263937824, 13.498468053379288, 12.57084108387008, 11.643877002278519, 10.663115328123176, 9.722890152556786, 8.778419040312206, 7.883196754686654, 6.991698895086, 6.044252224855195, 6.896693180382949, 7.805230973302548, 8.733596439632366, 9.732946339473314, 10.634926775827449, 11.653925253649085, 12.698649382555887, 13.67859217212154, 14.612840284288776, 15.539465331056801, 15.382234672946762, 14.535159222417965, 13.640443315855931, 12.664418574873292, 11.665930597410705, 10.6482605863683, 9.72426370557568, 6.95169914440886, 5.981846341516306, 4.988118315943574, 5.840240293140836, 6.782215479734765, 7.715358668405398, 8.73095804706028, 9.703555140352504, 10.681460220602272, 11.738999202038356, 12.66509303436111, 13.658621488782027, 14.531466645271017, 15.53945940347869, 15.574096070595798, 14.619471303960447, 13.617961609675543, 12.706303760464964, 11.687006864347122, 10.695071609708883, 5.885384093775293, 5.065378336536794, 4.0196326765093895, 4.867303987160587, 5.810588649382213, 6.765130775722274, 7.713984703568945, 8.70878385735276, 9.724197707116886, 10.715598872312611, 11.64840074997285, 12.64228925412952, 13.606248521928464, 14.560457953255124, 15.606459066306378, 15.575165467997207, 14.528801310965722, 13.552694180842614, 12.61827592600952, 11.620429592120075, 4.833011412534405, 4.032449899287776, 3.034474041808695, 3.9347053783885975, 4.799858457017349, 5.807805616269438, 6.768716495146767, 7.822601682660144, 8.771836786675319, 9.712608793613564, 10.763010634904088, 11.690855584321728, 12.708915431925236, 13.762243118860411, 14.716430286202884, 15.765229775487349, 15.475559683957808, 14.497740525085671, 13.59939068071648, 12.574913641268264, 3.8534550304479582, 3.0448371604874462, 2.0042003879317547, 2.863211743164299, 3.830123472026247, 4.868355773455037, 5.8257343495337155, 6.796758184964858, 7.761511196777477, 8.802272408539555, 9.874175133987443, 10.902300640725457, 11.861246113518689, 12.818291387857267, 13.754088575441342, 14.71178623604798, 15.751404119095701, 15.429612174963099, 14.526036866240364, 13.632485210328783, 2.8731886365708412, 1.9953210026125927, 0.9333069624001946, 1.9045477946642237, 2.9320413923158135, 3.9018872604662596, 4.882660261768373, 5.831669663519912, 6.899631563032222, 7.908897595691373, 8.960061535965155, 9.921925507866394, 10.95628806930001, 11.940878230720738, 13.00412443220548, 14.0492392536461, 15.056344672603254, 16.094801854417124, 15.48846899886329, 14.662703482415687, 1.9323880942679366, 0.9679561193557203, 0.0, 0.9553429176107545, 1.949331535245621, 3.0151679034196857, 4.01841678747228, 5.046877523673027, 6.083201567155651, 7.0603716161146615, 8.125415456721502, 9.115750814996971, 10.09009554643927, 11.129739127657878, 12.139808868162397, 13.166838867299818, 14.178336776948768, 15.169662024588655, 16.175027667527043, 15.70109682731092, 3.004960103282052, 1.98545921234915, 0.9298014734047642, 1.9414537877700209, 2.899589190547669, 3.9591888336756194, 4.9503929235773345, 5.95993292478723, 7.03110576737561, 7.959256949854639, 8.960299161479272, 9.970169829136548, 10.950278662463834, 11.914962477049674, 12.907080901692273, 13.852459980462049, 14.781853578784377, 15.711489889265682, 16.70053512359269, 16.7146559882469, 3.841210124366196, 2.8182189648785365, 1.8810656516342945, 2.8878854417344613, 3.9001102799229135, 4.90296009708696, 5.845913274361744, 6.784808581549443, 7.7218498547983785, 8.657616438206349, 9.730634363234639, 10.713556119463183, 11.701164936743467, 12.686901804123789, 13.745192275937505, 14.764617097410067, 15.72251849588505, 16.686004036922753, 17.63502913221272, 17.680981005551736, 4.777251208459263, 3.7656094728158696, 2.924031417523422, 3.940160927412933, 4.917629102153189, 5.840515829852795, 6.899040275248917, 7.748890165216446, 8.649428829401623, 9.614427556749188, 10.570290553073384, 11.619632100877034, 12.62986790803761, 13.685773883028288, 14.63939349324849, 15.628392512173491, 16.643435248757346, 17.058143101717274, 17.811693778259585, 18.632666653088584], [18.58342467521245, 17.595460714428622, 16.885637370251036, 16.044837134302067, 15.519085886207765, 14.468627728204032, 13.487552430486678, 12.521550938814773, 11.502321448566171, 10.563606695914459, 9.634867221390511, 8.754371959001341, 7.757870110772303, 6.858572676179142, 5.925751307801585, 4.934069015349252, 4.080365987058577, 4.870419721298905, 5.717132458422096, 6.671228091715535, 17.580961348065166, 16.650904904878708, 15.849331549591058, 15.077167090753598, 15.714289643274151, 15.40882705445796, 14.442328805373739, 13.4569229103275, 12.442085397912738, 11.490443772503358, 10.68189489017856, 9.689255427427893, 8.750192674670483, 7.792607883400342, 6.877551851664702, 5.898825638747865, 5.040413762780968, 5.850872145004815, 6.715393489952864, 5.818459620000584, 16.71846794260279, 15.717873311407438, 14.797664619542173, 14.056712343784922, 14.768636417711953, 15.672028689473771, 15.404620812996788, 14.40349242479288, 13.464262783468438, 12.539115559362383, 11.672824141562355, 10.635635319458707, 9.762549455543303, 8.793281814164946, 7.851981469452577, 6.929252409316627, 6.011463309544794, 6.696410454060073, 5.756897996877907, 4.859191834593504, 15.805874841608349, 14.760118960513251, 13.86045325560896, 13.046140358408655, 13.750012618120143, 14.694386086441524, 15.596198159455861, 15.405273054518682, 14.439488404220565, 13.584063536632401, 12.714503902676881, 11.686863109561509, 10.711357356855993, 9.735617851925543, 8.849602276988875, 7.878941271128562, 6.862844587920769, 5.8486115814512765, 4.828413913801604, 3.888448053373547, 14.816871673200113, 13.767672945864843, 12.882680466242611, 12.007457651770633, 12.764379226442937, 13.691561788769217, 14.621239678342736, 15.660078963161947, 15.46799419685139, 14.597554891944206, 13.624756489904051, 12.621473296415397, 11.654956564190586, 10.720191933644369, 9.823853738739206, 8.86001687946298, 7.828223002276427, 6.780355146586453, 5.7437512867633, 4.79831103823326, 13.75959643051444, 12.760494669547056, 11.889630355102273, 11.057975874768854, 11.786831794869093, 12.736386001777023, 13.704192731886668, 14.653410946584179, 15.640979603362144, 15.564824623565348, 14.566544582196892, 13.631374578435926, 12.62000035624361, 11.721405486030601, 10.80810833901762, 9.864950292742732, 8.806102490921631, 7.741228251610112, 6.744880910316063, 5.814678677875418, 12.715404287035701, 11.796498455880498, 10.872311620586055, 10.04968826757003, 10.820892319080983, 11.769139676785423, 12.751052996378165, 13.64428611500273, 14.598701041329534, 15.62291221345706, 15.5431600745714, 14.576763192490466, 13.56496247022741, 12.668626730190077, 11.737318210005622, 10.684615384577937, 9.660953634421071, 8.718127294046216, 7.713457796125996, 6.784391967601464, 11.784775655055341, 10.799418277483289, 9.846859525792778, 9.040728314447824, 9.787666156045399, 10.727402417456197, 11.76687486858494, 12.687473162135838, 13.645757230571908, 14.664717307588012, 15.674467471389832, 15.548380559356328, 14.550225835071481, 13.633152108015913, 12.56980822439017, 11.550025040692995, 10.602605121374127, 9.618319530818852, 8.66307370577323, 7.771711290637335, 10.852357042662945, 9.845331729729109, 8.878796728914322, 8.051299465535191, 8.861842497629471, 9.844096105721196, 10.810303678000883, 11.714111693871542, 12.694380361439228, 13.673322228564636, 14.69123604539876, 15.650134140738254, 15.33652025080666, 14.410019472284224, 13.455278817274644, 12.52782893122106, 11.627518395176489, 10.685160344191203, 9.725678536627004, 8.739752018436045, 9.798615106828613, 8.786752414357762, 7.931334237123437, 7.004556926984531, 7.916870946745628, 8.869928494269065, 9.806217618078634, 10.759570167024782, 11.74879660845614, 12.678634443677348, 13.734988973163654, 14.646463046381044, 15.653805925187694, 15.402789181548577, 14.453810970990041, 13.526184001480834, 12.599219919889272, 11.61845824573393, 10.67823307016754, 9.73376195792296, 8.788691838471944, 7.841944244485592, 6.894497574254786, 5.965155454708965, 6.873693247628564, 7.802058713958384, 8.80140861379933, 9.703389050153461, 10.722387527975098, 11.7671116568819, 12.747054446447553, 13.68130255861479, 14.607927605382816, 15.578595137431083, 15.490502140028719, 14.595786233466685, 13.619761492484045, 12.621273515021459, 11.603603503979054, 10.679606623186434, 7.900391841781758, 6.832091690915897, 5.838363665343165, 4.908702567466851, 5.850677754060781, 6.783820942731413, 7.799420321386297, 8.772017414678519, 9.749922494928287, 10.80746147636437, 11.733555308687125, 12.727083763108041, 13.599928919597032, 14.607921677804704, 15.570468258839648, 15.5748142215712, 14.573304527286297, 13.661646678075718, 12.642349781957876, 11.650414527319636, 6.840727011386047, 5.915623685936385, 4.869878025908981, 3.9357662614866027, 4.8790509237082285, 5.8335930500482895, 6.782446977894961, 7.777246131678774, 8.7926599814429, 9.784061146638626, 10.716863024298865, 11.710751528455535, 12.674710796254478, 13.628920227581139, 14.674921340632393, 15.637169015692583, 15.484144228576476, 14.508037098453368, 13.573618843620274, 12.575772509730829, 5.788354330145159, 4.987792816898531, 3.9898169594194495, 3.0031676527146134, 3.8683207313433643, 4.876267890595454, 5.837178769472782, 6.891063956986159, 7.840299061001334, 8.781071067939578, 9.831472909230103, 10.759317858647742, 11.77737770625125, 12.830705393186426, 13.784892560528899, 14.833692049813363, 15.751087704414033, 15.453083442696425, 14.554733598327234, 13.530256558879017, 4.808797948058713, 4.0001800780982, 2.959543305542509, 1.9316740174903149, 2.8985857463522624, 3.9368180477810526, 4.894196623859731, 5.865220459290874, 6.829973471103491, 7.870734682865569, 8.942637408313457, 9.970762915051472, 10.929708387844704, 11.886753662183281, 12.822550849767357, 13.780248510373994, 14.819866393421716, 15.880250827893006, 15.481379783851118, 14.587828127939536, 3.8285315541815956, 2.950663920223347, 1.888649880010949, 0.9730100689902396, 2.0005036666418294, 2.970349534792275, 3.9511225360943882, 4.900131937845927, 5.9680938373582375, 6.977359870017389, 8.02852381029117, 8.990387782192409, 10.024750343626025, 11.009340505046753, 12.072586706531494, 13.117701527972114, 14.124806946929269, 15.16326412874314, 16.228325177528124, 15.61804640002644, 2.887731011878691, 1.9232990369664749, 0.9553429176107545, 0.0, 0.9939886176348667, 2.0598249858089313, 3.063073869861525, 4.091534606062273, 5.127858649544896, 6.105028698503906, 7.170072539110747, 8.160407897386216, 9.134752628828515, 10.174396210047123, 11.184465950551642, 12.211495949689063, 13.222993859338013, 14.2143191069779, 15.219684749916286, 16.247163288698278, 3.9603030208928063, 2.9408021299599043, 1.8851443910155186, 1.0171663438323617, 1.9753017466100098, 3.03490138973796, 3.99505000596658, 5.004590007176475, 6.075762849764855, 7.003914032243884, 8.004956243868516, 9.014826911525793, 9.994935744853079, 10.959619559438918, 11.951737984081518, 12.897117062851294, 13.826510661173621, 14.756146971654927, 15.745192205981933, 16.6798666345478, 4.79655304197695, 3.773561882489291, 2.836408569245049, 2.0121582437090213, 2.9758228359852543, 3.978672653149301, 4.921625830424086, 5.8605211376117845, 6.797562410860721, 7.733328994268691, 8.806346919296981, 9.789268675525525, 10.77687749280581, 11.76261436018613, 12.820904831999847, 13.830298643996768, 14.767175578274294, 15.730661119311998, 16.679686214601965, 17.632798002214642, 5.732594126070017, 4.720952390426624, 3.8793743351341763, 3.073337723632057, 3.99334165821553, 4.916228385915137, 5.974752831311259, 6.824602721278788, 7.725141385463965, 8.69014011281153, 9.646003109135727, 10.695344656939376, 11.705580464099953, 12.76148643909063, 13.715106049310831, 14.704105068235833, 15.719147804819688, 16.69945539732873, 17.65152424934958, 18.58448364975149], [18.591537718613218, 17.576279767887737, 16.585197390121568, 15.525651805336867, 14.586134423739033, 13.5356762657353, 12.554600968017946, 11.58859947634604, 10.569369986097437, 9.630655233445724, 8.701915758921777, 7.821420496532607, 6.824918648303568, 5.925621213710407, 4.992799845332851, 4.001117552880517, 5.052531007567604, 5.864408338933771, 6.711121076056962, 7.665216709350401, 17.589074391465935, 17.644893522513577, 16.79247186227431, 15.852126052012238, 14.86974384027035, 14.475875591989228, 13.509377342905006, 12.523971447858765, 11.509133935444003, 10.557492310034622, 9.748943427709825, 8.756303964959159, 7.81724121220175, 6.859656420931607, 5.944600389195967, 4.96587417627913, 6.005810644450369, 6.844860762639681, 7.7093821075877305, 6.812448237635451, 16.75844968097382, 16.711861929042307, 15.791653237177043, 14.845190005212233, 13.924090614708152, 14.827482886469971, 14.471669350528055, 13.470540962324145, 12.531311320999704, 11.606164096893647, 10.73987267909362, 9.702683856989973, 8.829597993074568, 7.860330351696211, 6.919030006983842, 5.996300946847892, 6.976860191214195, 7.69039907169494, 6.7508866145127735, 5.85318045222837, 16.2925287312574, 15.754107578148119, 14.854441873243829, 13.834618019835967, 12.905466815116343, 13.849840283437723, 14.75165235645206, 14.472321592049948, 13.50653694175183, 12.651112074163665, 11.781552440208147, 10.753911647092774, 9.778405894387259, 8.802666389456808, 7.916650814520141, 6.945989808659827, 7.856833205555635, 6.842600199086142, 5.82240253143647, 4.8824366710084135, 15.810860290834981, 14.761661563499711, 13.87666908387748, 12.850528557138484, 11.919833423439137, 12.847015985765417, 13.776693875338935, 14.781401708262576, 14.535042734382653, 13.66460342947547, 12.691805027435317, 11.688521833946663, 10.722005101721852, 9.787240471175634, 8.959813733024273, 7.995976873748046, 8.822211619911293, 7.774343764221319, 6.7377399043981665, 5.792299655868127, 14.75358504814931, 13.754483287181923, 12.88361897273714, 11.94762748703135, 10.942285991865292, 11.891840198773222, 12.859646928882867, 13.721716105273304, 14.709284762051269, 14.631873161096612, 13.633593119728157, 12.698423115967191, 11.687048893774875, 10.788454023561865, 9.980217891737313, 9.045801349108805, 9.800091108556497, 8.735216869244978, 7.738869527950929, 6.8086672955102845, 13.70939290467057, 12.790487073515365, 11.866300238220923, 10.939339879832525, 9.976346516077182, 10.924593873781623, 11.906507193374365, 12.712591273691855, 13.667006200018658, 14.691217372146184, 14.610208612102666, 13.643811730021731, 12.632011007758676, 11.844698959979624, 10.958798250620111, 10.116313522753611, 10.654942252055939, 9.712115911681083, 8.707446413760863, 7.778380585236331, 12.77876427269021, 11.793406895118157, 10.840848143427646, 9.941067636231315, 8.943120353041598, 9.882856614452397, 10.886569723360916, 11.755778320824962, 12.714062389261032, 13.733022466277136, 14.742772630078957, 14.615429096887594, 13.617274372602747, 12.870938489132735, 11.932366916587947, 11.186395898674657, 11.596593739008995, 10.61230814845372, 9.657062323408098, 8.765699908272202, 11.846345660297814, 10.839320347363977, 9.87278534654919, 8.972954830885225, 8.01729669462567, 8.952123385811486, 9.90656959976849, 10.782416852560667, 11.762685520128352, 12.74162738725376, 13.759541204087885, 14.687061292852471, 14.654204153056973, 13.835221747499244, 12.926858901012416, 12.164199789202723, 12.621507012811357, 11.67914896182607, 10.719667154261874, 9.733740636070912, 10.792603724463483, 9.78074103199263, 8.925322854758305, 7.9985455446193985, 7.0723251437418275, 7.973881786763629, 8.90248353984624, 9.827875325713906, 10.817101767145264, 11.746939602366472, 12.783750870522793, 13.68339019849526, 14.69073307730191, 14.827991456763597, 13.964121229739852, 13.162554859462496, 13.59320853752414, 12.612446863368797, 11.67222168780241, 10.727750575557828, 9.782680456106814, 8.83593286212046, 7.888486191889654, 6.9591440723438325, 6.029147444624764, 6.906012006452949, 7.869713772488454, 8.771694208842586, 9.790692686664222, 10.829964725454225, 11.795816343806692, 12.718229710729007, 13.644854757497033, 14.6155222895453, 15.00081239877853, 14.232157091448347, 14.613750110118914, 13.615262132656328, 12.597592121613923, 11.673595240821301, 8.894380459416626, 7.826080308550765, 6.832352282978032, 5.902691185101719, 5.006131951056981, 5.852126101420537, 6.86772548007542, 7.840322573367644, 8.818227653617411, 9.844388628478587, 10.770482460801341, 11.764010915222258, 12.636856071711248, 13.64484882991892, 14.607395410953865, 15.25321379358769, 15.567293144921166, 14.655635295710587, 13.636338399592745, 12.644403144954504, 7.834715629020914, 6.909612303571253, 5.863866643543848, 4.92975487912147, 4.034505120704429, 4.901898208737413, 5.850752136584084, 6.845551290367899, 7.860965140132025, 8.820988298752843, 9.753790176413082, 10.747678680569752, 11.711637948368695, 12.665847379695355, 13.71184849274661, 14.6740961678068, 15.724937776652826, 15.502025716088236, 14.567607461255141, 13.569761127365696, 6.782342947780026, 5.981781434533398, 4.983805577054316, 3.99715627034948, 3.0237749283395647, 3.9445730492845774, 4.905483928161906, 5.927991109100375, 6.87722621311555, 7.817998220053794, 8.86840006134432, 9.79624501076196, 10.814304858365468, 11.867632545300642, 12.821819712643116, 13.870619201927578, 14.788014856528248, 15.849049629884648, 15.548722215962101, 14.524245176513885, 5.802786565693579, 4.994168695733068, 3.953531923177376, 2.9256626351251818, 2.054039943348463, 3.0051232064701763, 3.962501782548855, 4.90214761140509, 5.866900623217708, 6.907661834979786, 7.979564560427674, 9.007690067165687, 9.966635539958919, 10.923680814297496, 11.859478001881572, 12.817175662488209, 13.85679354553593, 14.91717798000722, 15.866626002297025, 15.581816745574404, 4.822520171816462, 3.9446525378582136, 2.8826384976458157, 1.9669986866251064, 1.0374308187560448, 2.007276686906491, 2.988049688208604, 3.9370590899601434, 5.005020989472453, 6.0142870221316045, 7.065450962405385, 8.027314934306624, 9.06167749574024, 10.046267657160968, 11.109513858645709, 12.15462868008633, 13.161734099043484, 14.200191280857355, 15.265252329642337, 16.223735440663813, 3.8817196295135576, 2.9172876546013415, 1.949331535245621, 0.9939886176348667, 0.0, 1.0658363681740646, 2.0690852522266585, 3.097545988427406, 4.13387003191003, 5.11104008086904, 6.176083921475882, 7.166419279751351, 8.140764011193651, 9.180407592412259, 10.190477332916778, 11.217507332054199, 12.229005241703149, 13.220330489343036, 14.225696132281422, 15.253174671063416, 4.954291638527673, 3.934790747594771, 2.8791330086503852, 2.0004856869189234, 1.0423502841412753, 2.1019499272692257, 3.0010613883317134, 4.010601389541609, 5.081774232129989, 6.009925414609018, 7.010967626233651, 8.020838293890927, 9.000947127218213, 9.965630941804053, 10.957749366446652, 11.903128445216428, 12.832522043538756, 13.76215835402006, 14.751203588347067, 15.685878016912932, 5.790541659611816, 4.767550500124157, 3.8303971868799156, 2.995477586795583, 2.04287137351652, 3.0457211906805663, 3.988674367955351, 4.92756967514305, 5.864610948391986, 6.800377531799956, 7.873395456828247, 8.85631721305679, 9.843926030337075, 10.829662897717396, 11.887953369531113, 12.836310026361902, 13.773186960639428, 14.736672501677132, 15.685697596967099, 16.638809384579776, 6.726582743704883, 5.71494100806149, 4.8733629527690425, 4.056657066718619, 3.0603901957467956, 3.9832769234464016, 5.041801368842524, 5.891651258810054, 6.79218992299523, 7.757188650342795, 8.713051646666992, 9.76239319447064, 10.772629001631216, 11.828534976621896, 12.782154586842097, 13.771153605767099, 14.786196342350953, 15.766503934859996, 16.657535631714715, 17.590495032116625], [17.525701350439153, 16.53325663298432, 15.542174255218148, 14.48262867043345, 13.543111288835615, 12.492653130831881, 11.511577833114528, 10.545576341442622, 9.52634685119402, 8.587632098542308, 7.65889262401836, 6.778397361629191, 5.781895513400152, 4.892099275134987, 3.95927790675743, 4.916632242167029, 5.968045696854117, 6.9302447071078355, 7.7769574442310265, 8.731053077524464, 16.52323802329187, 17.331192099314126, 16.358551519821788, 15.418205709559713, 14.435823497817825, 13.43285245708581, 12.466354208001588, 11.480948312955348, 10.466110800540587, 9.514469175131207, 8.70592029280641, 7.7132808300557425, 6.774218077298333, 5.826134482356187, 4.967534066788756, 5.8813888655656426, 6.921325333736881, 7.9106971308137455, 8.775218475761795, 7.878284605809515, 15.692613312799754, 16.693207943995105, 16.675875710770153, 15.696834327771617, 14.775734937267536, 14.037904897165602, 13.428646215624637, 12.42751782742073, 11.488288186096288, 10.563140961990232, 9.696849544190204, 8.659660722086556, 7.8120473223828215, 6.864561930237283, 5.941963684576631, 6.9118156361344045, 7.892374880500707, 8.756235439869005, 7.816722982686838, 6.919016820402435, 15.226692363083334, 16.27244824417843, 15.738664346836941, 14.68626234239535, 13.757111137675727, 13.060262294133354, 13.908366339914982, 13.429298457146531, 12.463513806848415, 11.60808893926025, 10.73852930530473, 9.710888512189358, 8.78263747292833, 7.80689796799788, 6.977004556350785, 7.861504497946339, 8.903189488612908, 7.908436567260207, 6.888238899610535, 5.948273039182478, 16.24618821824544, 15.691100254234218, 14.76569231718422, 13.702172879697867, 12.77147774599852, 12.057437996461047, 12.933407858801857, 13.827816002663956, 13.492019599479239, 12.621580294572055, 11.649718665526327, 10.646435472037673, 9.726236680262923, 8.791472049716706, 8.026378753341787, 8.91149156303456, 9.888047988085358, 8.840180132395384, 7.803576272572231, 6.858136024042191, 15.701997008836107, 14.68392197791643, 13.801789530529167, 12.799271809590733, 11.793930314424676, 11.044092093297731, 11.97169250842363, 12.768130399674684, 13.755699056452649, 13.588850026193198, 12.591506757819168, 11.657858311217785, 10.691280472315947, 9.792685602102939, 9.046782912054827, 9.961316038395319, 10.865927476730562, 9.801053237419044, 8.804705896124995, 7.874503663684349, 14.659882623858676, 13.719925764249872, 12.78496497234231, 11.79098420239191, 10.827990838636566, 10.076845768306132, 10.994903852594305, 11.759005568093235, 12.713420494420038, 13.737631666547564, 13.569643807353259, 12.603246925272325, 11.636242586299748, 10.848930538520698, 10.025363270937625, 11.031828212040125, 11.720778620230003, 10.777952279855148, 9.773282781934927, 8.844216953410395, 13.760188984788416, 12.722845585852664, 11.759512877549033, 10.792711958790699, 9.794764675600982, 9.035108508976906, 9.932984017762296, 10.802192615226343, 11.760476683662413, 12.779436760678516, 13.789186924480337, 13.584554931460824, 12.621505951143819, 11.875170067673809, 10.99893193690546, 12.018715120602636, 12.66243010718306, 11.678144516627784, 10.722898691582163, 9.831536276446267, 12.827770372396019, 11.771464805356825, 10.791450080670577, 9.824599153444609, 8.868941017185055, 7.998537680212866, 8.95298389416987, 9.828831146962047, 10.809099814529732, 11.788041681655141, 12.805955498489265, 13.71674531468417, 13.658435731598045, 12.839453326040317, 11.99342392132993, 12.920873807383513, 13.687343380985421, 12.744985330000135, 11.785503522435938, 10.799577004244977, 11.810172246311126, 10.798309553840273, 9.860914990696957, 8.866838796973472, 7.923969466301212, 7.020296081165009, 7.94889783424762, 8.874289620115286, 9.863516061546644, 10.793353896767853, 11.813434892354492, 12.713074220326959, 13.72041709913361, 13.83222303530467, 13.030686250057366, 13.919228877643286, 14.659044905698204, 13.678283231542862, 12.738058055976474, 11.754533976281605, 10.800248977954457, 9.853501383968103, 8.906054713737298, 7.906831605150959, 6.8807917671841485, 5.952426300854329, 6.916128066889833, 7.818108503243967, 8.837106981065602, 9.859648747285924, 10.82550036563839, 11.747913732560706, 12.674538779328731, 13.645206311376999, 14.067377419096044, 14.988831109629137, 15.679586478292979, 14.681098500830393, 13.663428489787988, 12.700378641545079, 9.911948981264269, 8.843648830398408, 7.8499208048256754, 6.910024106642524, 5.883282011551033, 4.898540395821916, 5.9141397744768, 6.886736867769024, 7.864641948018791, 8.874072650310286, 9.80016648263304, 10.793694937053957, 11.666540093542947, 12.67453285175062, 13.637079432785564, 14.591704199420915, 15.59321389370582, 15.708049249283876, 14.688752353166034, 13.671186545678282, 8.900551997194977, 7.927180825418896, 6.881435165391491, 5.947323400969113, 4.911655181198482, 3.9483125031387925, 4.897166430985465, 5.891965584769279, 6.907379434533405, 7.8506723205845415, 8.78347419824478, 9.777362702401451, 10.741321970200394, 11.695531401527054, 12.741532514578308, 13.703780189638499, 14.726113402130213, 15.702220532253321, 15.594390861978919, 14.596544528089474, 7.8481793159540905, 7.047617802707463, 6.049641945228381, 5.014724792197123, 4.009880959041836, 2.990987343685957, 3.951898222563286, 4.957675130932074, 5.906910234947249, 6.847682241885493, 7.898084083176018, 8.825929032593658, 9.843988880197166, 10.897316567132341, 11.836330609715153, 12.861959374537458, 13.779355029138127, 14.840389802494528, 15.784612360430788, 15.551028577237663, 6.868622933867644, 6.060005063907132, 5.019368291351441, 3.9914990032992463, 3.040145974050734, 2.051537500871556, 3.0089160769502348, 3.931831633236789, 4.896584645049407, 5.9373458568114845, 7.009248582259373, 7.999030239775567, 8.957975712568798, 9.915020986907376, 10.850818174491451, 11.808515835098088, 12.84813371814581, 13.9085181526171, 14.857966174906904, 15.790762879730083, 5.888356539990527, 5.010488906032278, 3.9484748658198803, 3.032835054799171, 2.023536849458316, 1.0536909813078705, 2.0177337100403028, 2.966743111791842, 4.034705011304152, 5.043971043963303, 6.0567911350152634, 7.018655106916503, 8.053017668350119, 9.037607829770847, 10.100854031255588, 11.110525496382468, 12.117630915339623, 13.151857682748417, 14.216918731533399, 15.175401842554876, 4.947555997687623, 3.983124022775406, 3.0151679034196857, 2.0598249858089313, 1.0658363681740646, 0.0, 1.003248884052594, 2.0317096202533413, 3.068033663735965, 4.045203712694976, 5.110247553301817, 6.100582911577287, 7.074927643019586, 8.114571224238192, 9.124640964742712, 10.151670963880132, 11.163168873529083, 12.15449412116897, 13.159859764107356, 14.18733830288935, 6.020128006701738, 5.000627115768836, 3.94496937682445, 3.066322055092988, 2.10818665231534, 1.052569862644908, 1.935225020157649, 2.9447650213675445, 4.015937863955925, 4.944089046434954, 5.945131258059586, 6.9550019257168625, 7.935110759044149, 8.899794573629988, 9.891912998272588, 10.837292077042363, 11.766685675364691, 12.696321985845996, 13.685367220173003, 14.620041648738868, 6.856378027785881, 5.833386868298222, 4.89623355505398, 4.0613139549696475, 3.0074641184544766, 2.00461430129043, 2.9475674785652144, 3.8845465402396337, 4.82158781348857, 5.75735439689654, 6.8303723219248305, 7.813294078153375, 8.800902895433659, 9.78663976281398, 10.844930234627697, 11.770473658187838, 12.707350592465364, 13.670836133503068, 14.619861228793035, 15.572973016405713, 7.792419111878948, 6.780777376235554, 5.939199320943107, 5.050713123434687, 3.975904885033308, 2.9421700340562653, 4.000694479452387, 4.8486281239066376, 5.749166788091814, 6.714165515439379, 7.670028511763576, 8.719370059567225, 9.729605866727802, 10.78551184171848, 11.73913145193868, 12.728130470863682, 13.743173207447537, 14.707202262303067, 15.59169926354065, 16.524658663942564], [16.52245246638656, 15.530007748931727, 14.538925371165556, 13.479379786380857, 12.539862404783022, 11.489404246779289, 10.508328949061935, 9.54232745739003, 8.523097967141426, 7.584383214489714, 6.6556437399657655, 5.775148477576595, 4.778646629347557, 3.960058727003875, 4.850589149411053, 5.807943484820652, 6.859356939507739, 7.82208542296117, 8.78020632828362, 9.734301961577058, 15.519989139239279, 16.327943215261534, 15.355302635769196, 14.41495682550712, 13.432574613765233, 12.429603573033218, 11.463105323948996, 10.477699428902755, 9.462861916487993, 8.511220291078612, 7.7026714087538135, 6.710031946003147, 5.7709691932457385, 4.894093934225075, 5.844740068858165, 6.772700108219265, 7.812636576390503, 8.802537846667079, 9.778467359814389, 8.88153348986211, 14.68936442874716, 15.689959059942511, 16.36440743116915, 15.364016021191164, 14.366624081260479, 13.395425146735722, 12.425397331572045, 11.424268943368135, 10.485039302043694, 9.559892077937636, 8.69360066013761, 7.656411838033962, 6.808798438330227, 5.93252138210617, 6.81916968664604, 7.803126878788028, 8.783686123154329, 9.7465956233534, 8.819971866739431, 7.922265704455029, 14.22344347903074, 15.269199360125837, 16.310546778340374, 15.607688194257696, 14.678536989538072, 13.905794128414522, 12.949404181051051, 12.426049573093938, 11.46026492279582, 10.604840055207655, 9.735280421252135, 8.707639628136763, 7.79436462124899, 6.874857419866768, 7.847360848029104, 8.752815740599962, 9.79450073126653, 8.9116854513128, 7.891487783663129, 6.951521923235072, 15.242939334192844, 16.261645374774247, 15.687118169046565, 14.623598731560213, 13.692903597860866, 12.904123589511444, 11.974445699937926, 12.834484702368941, 12.488770715426643, 11.61833141051946, 10.646469781473732, 9.643186587985078, 8.737963828583583, 7.859431501585593, 8.854024767939144, 9.80280280568818, 10.789985095933188, 9.843429016447978, 8.806825156624823, 7.861384908094784, 15.733818907058673, 15.605347829778776, 14.723215382391512, 13.720697661453078, 12.715356166287021, 11.950020811325981, 11.012730349559698, 11.774799099379669, 12.762367756157634, 12.585601142140602, 11.588257873766572, 10.65460942716519, 9.703007620636606, 8.860645053971826, 9.83700516528131, 10.780163211556198, 11.831387548777462, 10.804302121471636, 9.807954780177587, 8.877752547736943, 15.581308475721022, 14.641351616112217, 13.706390824204655, 12.712410054254255, 11.749416690498911, 10.982774486334382, 10.035941693730374, 10.76567426779822, 11.720089194125023, 12.74430036625255, 12.566394923300663, 11.59999804121973, 10.647969734620407, 9.916889990389585, 10.815585524164108, 11.850675385201004, 12.724027504282597, 11.781201163907742, 10.776531665987521, 9.84746583746299, 14.68161483665076, 13.644271437715009, 12.680938729411379, 11.714137810653044, 10.716190527463327, 9.941037227005156, 8.974021858898364, 9.808861314931328, 10.767145383367398, 11.786105460383503, 12.795855624185323, 12.581306047408228, 11.633233099464478, 10.943129519542696, 11.789154190131944, 12.808937373829119, 13.665678991235653, 12.681393400680378, 11.726147575634757, 10.83478516049886, 13.749196224258364, 12.69289065721917, 11.712875932532922, 10.746025005306954, 9.7903668690474, 8.904466398241116, 7.994021735305938, 8.835499846667034, 9.815768514234719, 10.794710381360128, 11.812624198194252, 12.713496430631576, 12.670162879918704, 11.907412777909204, 12.783646174556413, 13.711096060609997, 14.645109872024248, 13.74823421405273, 12.78875240648853, 11.802825888297571, 12.734167741689312, 11.722305049218459, 10.782340842559302, 9.788264648835817, 8.845395318163558, 7.926224799193258, 6.9899356753836885, 7.880958319820273, 8.87018476125163, 9.80002259647284, 10.810186008301898, 11.709825336274365, 12.717168215081015, 12.900182487173558, 13.82090850328385, 14.70945113086977, 15.619599854066418, 14.681532115595456, 13.70916303479799, 12.678529471659791, 11.724244473332643, 10.77749687934629, 9.830050209115484, 8.828257457013304, 7.802217619046494, 6.873852152716674, 5.957165908025901, 6.824777202948954, 7.843775680770589, 8.856399863233332, 9.822251481585797, 10.744664848508112, 11.671289895276137, 12.641957427324405, 13.634329358834487, 14.584073108003267, 15.543508044455477, 15.643454639720005, 14.6257846286776, 13.624374136923265, 10.835944476642455, 9.767644325776594, 8.773916300203862, 7.831449958504869, 6.804707863413379, 5.8199662476842615, 4.955177615612868, 5.8934055674740105, 6.871310647723778, 7.8708237662576925, 8.796917598580446, 9.790446053001363, 10.663291209490353, 11.671283967698026, 12.63383054873297, 13.588455315368321, 14.589965009653225, 15.624329396605804, 15.61274784854422, 14.595182041056468, 9.903800881247571, 8.851176320797082, 7.8054306607696775, 6.871318896347299, 5.833081033060827, 4.869738355001138, 3.903835130690452, 4.898634284474266, 5.914048134238392, 6.847423436531948, 7.780225314192187, 8.774113818348857, 9.7380730861478, 10.69228251747446, 11.738283630525714, 12.700531305585905, 13.72286451807762, 14.698971648200727, 15.633389903033821, 15.52054002346766, 8.851428200006684, 8.05032130471403, 7.012176403585913, 5.93872028757531, 4.933876454420023, 3.9124131955483024, 2.9585669222682736, 3.9544262468794806, 4.903661350894656, 5.8444333578329, 6.894835199123424, 7.822680148541064, 8.840739996144572, 9.894067683079747, 10.83308172566256, 11.858710490484864, 12.776106145085533, 13.837140918441934, 14.781363476378194, 15.80584051582641, 7.871871817920237, 7.0627085659137, 6.022071793358008, 4.948624548894633, 3.981712820032686, 2.972963352733901, 2.0155847766552224, 2.928582749184195, 3.893335760996813, 4.934096972758891, 6.005999698206779, 6.995781355722973, 7.954726828516204, 8.911772102854782, 9.847569290438857, 10.805266951045494, 11.844884834093216, 12.905269268564506, 13.85471729085431, 14.78751399567749, 6.89160542404312, 6.013737790084873, 4.951723749872475, 3.992597293091858, 2.965103695440268, 1.995257827289822, 1.014484825987709, 1.9634942277392482, 3.031456127251558, 4.040722159910709, 5.0535422509626695, 6.015406222863909, 7.049768784297525, 8.034358945718253, 9.097605147202994, 10.107276612329875, 11.114382031287029, 12.148608798695822, 13.213669847480803, 14.17215295850228, 5.950804881740216, 4.986372906828, 4.01841678747228, 3.063073869861525, 2.0690852522266585, 1.003248884052594, 0.0, 1.0284607362007476, 2.0647847796833716, 3.041954828642382, 4.106998669249223, 5.097334027524693, 6.071678758966992, 7.111322340185598, 8.121392080690118, 9.148422079827538, 10.159919989476489, 11.151245237116376, 12.156610880054762, 13.184089418836756, 7.0233768907543315, 6.003875999821429, 4.948218260877043, 4.011263702268738, 3.0531282994910898, 1.9935286563631394, 0.9319761361050551, 1.9415161373149503, 3.0126889799033303, 3.9408401623823592, 4.941882374006991, 5.951753041664268, 6.931861874991554, 7.896545689577394, 8.888664114219994, 9.83404319298977, 10.763436791312097, 11.693073101793402, 12.682118336120409, 13.616792764686274, 7.8596269118384745, 6.836635752350816, 5.899482439106574, 4.953452516525822, 3.898775361108099, 2.8959255439440525, 1.9529723666692682, 2.8812976561870394, 3.818338929435975, 4.754105512843945, 5.8271234378722365, 6.810045194100781, 7.797654011381065, 8.783390878761386, 9.841681350575103, 10.767224774135244, 11.70410170841277, 12.667587249450474, 13.61661234474044, 14.56972413235312, 8.795667995931542, 7.784026260288148, 6.942448204995701, 5.94202436608831, 4.86721612768693, 3.833481276709888, 3.0122020490159827, 3.8453792398540427, 4.745917904039219, 5.710916631386784, 6.666779627710981, 7.71612117551463, 8.726356982675206, 9.782262957665885, 10.735882567886087, 11.724881586811088, 12.739924323394943, 13.703953378250473, 14.588450379488057, 15.52140977988997], [15.570686320640363, 14.578241603185528, 13.587159225419358, 12.527613640634659, 11.588096259036824, 10.53763810103309, 9.556562803315737, 8.590561311643832, 7.571331821395229, 6.632617068743516, 5.703877594219568, 4.823382331830398, 3.82688048360136, 4.836737955164535, 5.766043600370326, 6.723397935779925, 7.774811390467012, 8.737539873920444, 9.756450646762307, 10.710546280055745, 14.56822299349308, 15.376177069515336, 14.403536490022997, 13.463190679760922, 12.480808468019035, 11.47783742728702, 10.511339178202798, 9.525933283156556, 8.511095770741795, 7.559454145332415, 6.750905263007617, 5.75826580025695, 4.819203047499541, 5.770773162385735, 6.721419297018826, 7.688154559178538, 8.728091027349777, 9.717992297626353, 10.697295715296969, 9.881812847820054, 13.737598283000962, 14.738192914196313, 15.41264128542295, 14.412249875444965, 13.41485793551428, 12.443659000989523, 11.473631185825846, 10.472502797621937, 9.533273156297495, 8.60812593219144, 7.741834514391414, 6.704645692287765, 5.857032292584029, 6.809200610266831, 7.6958489148067, 8.7185813297473, 9.699140574113603, 10.662050074312674, 9.848432602940179, 8.950726440655776, 13.194982742829993, 14.24073862392509, 15.282086042139627, 15.26904252478451, 14.339891320064886, 13.369956178383466, 12.413566231019995, 11.47428342734774, 10.508498777049622, 9.653073909461458, 8.783514275505938, 7.755873482390566, 6.842598475502792, 7.751536648027429, 8.724040076189764, 9.668270191559234, 10.709955182225803, 9.940146187513548, 8.919948519863876, 7.979982659435819, 14.214478597992098, 15.233184638573498, 16.211023717659305, 15.55505942617008, 14.624364292470734, 13.76752692818384, 12.83784903861032, 11.920886024844812, 11.537004569680445, 10.666565264773263, 9.694703635727535, 8.691420442238881, 7.7861976828373844, 8.72693154441985, 9.721524810773401, 10.685361670049627, 11.705439546892462, 10.861160520064027, 9.818625993098617, 8.873185744568579, 14.705358170857926, 15.723433201777603, 15.65467607700138, 14.652158356062946, 13.64681686089689, 12.843940418341738, 11.876133688232093, 10.86120042185554, 11.848769078633504, 11.633834996394405, 10.636491728020376, 9.702843281418993, 8.751241474890408, 9.728145096806081, 10.704505208115565, 11.647663254390453, 12.706511056211554, 11.81610295794543, 10.819755616651381, 9.889553384210735, 15.743105415122496, 15.572812310722085, 14.637851518814523, 13.643870748864122, 12.68087738510878, 11.88125835199551, 10.899345032402769, 9.85207559027409, 10.806490516600894, 11.830701688728418, 11.614628777554467, 10.648231895473533, 9.696203588874209, 10.720495135416519, 11.651803655600974, 12.704506481028659, 13.728168231185524, 12.793002000381534, 11.788332502461314, 10.859266673936782, 15.613075531260629, 14.575732132324877, 13.612399424021246, 12.645598505262912, 11.647651222073195, 10.854334358163332, 9.83742519757076, 8.895262637407198, 9.853546705843268, 10.872506782859373, 11.882256946661194, 11.629539901662032, 10.68146695371828, 11.619671588493393, 12.62537232156881, 13.645155505265985, 14.592575424584853, 13.69319423715417, 12.73794841210855, 11.779657361398858, 14.680656918868232, 13.624351351829038, 12.64433662714279, 11.677485699916822, 10.721827563657268, 9.817763529399292, 8.857425073978334, 7.921901169142903, 8.902169836710588, 9.881111703835998, 10.896482850821629, 11.746938321738368, 11.718396734172506, 12.583954846859903, 13.538695501869483, 14.466145387923067, 15.400159199337319, 14.760035050526522, 13.788404546261404, 12.747698089197568, 13.665628436299178, 12.653765743828325, 11.713801537169168, 10.719725343445683, 9.776856012773424, 8.839521930351435, 7.903232806541866, 6.967359642296142, 7.9565860837275, 8.88642391894871, 9.84362789940869, 10.743267227381157, 11.750610106187807, 12.610187727440135, 13.611608065569428, 14.539235035078635, 15.549160148133797, 15.693332952069248, 14.640623729407857, 13.609990166269657, 12.655705167942509, 11.708957573956155, 10.76151090372535, 9.75971815162317, 8.73367831365636, 7.805312847326542, 6.870463039184079, 5.911178525424822, 6.930177003246458, 7.889841754340122, 8.855693372692588, 9.778106739614904, 10.70473178638293, 11.675399318431197, 12.667771249941278, 13.617514999110057, 14.576949935562268, 15.641868025905271, 15.557245323287466, 14.555834831533131, 11.76740517125232, 10.69910502038646, 9.705376994813728, 8.762910653114737, 7.736168558023246, 6.751426942294129, 5.886638310222736, 4.979806889949879, 5.957711970199647, 6.9042656573644825, 7.830359489687237, 8.823887944108154, 9.696733100597145, 10.704725858804817, 11.667272439839762, 12.621897206475113, 13.623406900760017, 14.657771287712595, 15.62242955741577, 15.526642735666334, 10.848673082147569, 9.782637015406948, 8.736891355379544, 7.802779590957167, 6.764541727670695, 5.8011990496110055, 4.83529582530032, 3.9850356069501345, 5.000449456714261, 5.880865327638738, 6.813667205298977, 7.807555709455648, 8.771514977254592, 9.725724408581252, 10.760201262490513, 11.722448937550704, 12.694403781876872, 13.67051091199998, 14.604929166833074, 15.602775500722519, 9.863229036480478, 8.981781999323898, 7.943637098195781, 6.870180982185178, 5.865337149029891, 4.84387389015817, 3.8900276168781414, 2.98786813798627, 3.9371032420014456, 4.87787524893969, 5.928277090230214, 6.856122039647854, 7.874181887251363, 8.927509574186537, 9.804620989461812, 10.830249754284116, 11.747645408884786, 12.808680182241186, 13.752902740177447, 14.777379779625663, 8.883672654394031, 7.9941692605235675, 6.953532487967876, 5.880085243504501, 4.913173514642554, 3.904424047343769, 2.94704547126509, 1.9620246402909847, 2.9267776521036026, 3.96753886386568, 5.039441589313568, 5.9673206195222255, 6.926266092315457, 7.883311366654033, 8.81910855423811, 9.776806214844747, 10.816424097892469, 11.876808532363759, 12.826256554653563, 13.759053259476742, 7.903406260516914, 6.9573128601781535, 5.895298819965755, 4.924057987701726, 3.896564390050136, 2.92671852189969, 1.945945520597577, 0.9969361188460377, 2.0286360698503554, 3.0379021025095065, 4.025081514761922, 4.986945486663162, 6.0213080480967776, 7.005898209517506, 8.069144411002247, 9.078815876129127, 10.085921295086282, 11.120148062495076, 12.185209111280058, 13.143692222301535, 6.979265617940963, 6.014833643028747, 5.046877523673027, 4.091534606062273, 3.097545988427406, 2.0317096202533413, 1.0284607362007476, 0.0, 1.0363240434826237, 2.013494092441634, 3.0785379330484752, 4.0688732913239445, 5.0432180227662435, 6.082861603984851, 7.09293134448937, 8.119961343626791, 9.131459253275741, 10.122784500915628, 11.128150143854015, 12.155628682636008, 8.051837626955079, 7.0323367360221765, 5.976678997077791, 5.039724438469485, 4.081589035691837, 3.0219893925638868, 1.9604368723058028, 0.989749991568753, 2.060922834157133, 2.989074016636162, 3.990116228260794, 4.99998689591807, 5.980095729245357, 6.9447795438311966, 7.9368979684737955, 8.882277047243571, 9.811670645565899, 10.741306956047204, 11.73035219037421, 12.665026618940075, 8.835871230317162, 7.812880070829503, 6.875726757585261, 5.868906967485095, 4.8142298120673725, 3.8113799949033256, 2.868426817628541, 1.9295315104408421, 2.8665727836897776, 3.8023393670977477, 4.875357292126038, 5.858279048354583, 6.845887865634866, 7.831624733015187, 8.889915204828904, 9.815458628389045, 10.752335562666572, 11.715821103704275, 12.664846198994242, 13.617957986606921, 9.771912314410228, 8.760270578766836, 7.873608326937093, 6.857478817047583, 5.782670578646203, 4.748935727669161, 3.9276564999752552, 2.8936130941078453, 3.794151758293022, 4.759150485640586, 5.7150134819647835, 6.764355029768432, 7.774590836929009, 8.830496811919687, 9.784116422139888, 10.77311544106489, 11.788158177648745, 12.752187232504275, 13.636684233741859, 14.569643634143771], [14.572312876673399, 13.704789203005452, 12.750640893932035, 11.691095309147336, 10.751577927549501, 9.701119769545768, 8.720044471828414, 7.754042980156508, 6.734813489907905, 5.796098737256193, 4.867359262732244, 4.016506956292034, 4.863204527083984, 5.8730619986471595, 6.802367643852949, 7.759721979262548, 8.811135433949635, 9.773863917403066, 10.792774690244931, 11.746870323538369, 13.569849549526117, 14.499905992712577, 13.567018158535674, 12.6266723482736, 11.644290136531712, 10.641319095799696, 9.674820846715475, 8.689414951669233, 7.674577439254472, 6.722935813845091, 5.937244091777782, 4.951390424718586, 5.855527090982165, 6.807097205868359, 7.75774334050145, 8.724478602661161, 9.7644150708324, 10.754316341108975, 11.733619758779591, 10.918136891302677, 12.739224839033998, 13.73981947022935, 14.576122953935627, 13.575731543957643, 12.578339604026958, 11.6071406695022, 10.637112854338524, 9.635984466134614, 8.696754824810172, 7.771607600704116, 6.934959138853049, 5.8977703167494, 6.893356336066653, 7.845524653749456, 8.732172958289324, 9.754905373229924, 10.735464617596225, 11.698374117795296, 10.884756646422801, 9.987050484138399, 12.158658699347368, 13.204414580442466, 14.245761998657002, 14.432524193297187, 13.503372988577564, 12.533437846896144, 11.577047899532673, 10.637765095860416, 9.6719804455623, 8.816555577974135, 7.976638899967574, 6.948998106852201, 7.878922518985417, 8.787860691510053, 9.760364119672388, 10.704594235041858, 11.746279225708426, 10.97647023099617, 9.956272563346499, 9.016306702918442, 13.178154554509472, 14.196860595090874, 15.174699674176681, 15.339561966244942, 14.408866832545595, 13.481684270219317, 12.552006380645798, 11.654341866322083, 10.700486238193122, 9.83004693328594, 8.88782826018917, 7.8845450667005155, 8.822521726320009, 9.763255587902474, 10.757848854256025, 11.721685713532251, 12.741763590375085, 11.897484563546653, 10.854950036581243, 9.909509788051205, 13.6690341273753, 14.687109158294977, 15.724541022099887, 15.653001162262528, 14.647659667096471, 13.80084629838494, 12.833039568275295, 11.818106301898743, 11.08599318635689, 10.797316664907083, 9.829616352482011, 8.895967905880626, 9.787565518373032, 10.764469140288707, 11.740829251598191, 12.68398729787308, 13.74283509969418, 12.852427001428056, 11.856079660134007, 10.925877427693361, 14.70678137163987, 15.646738231248674, 15.638694325014106, 14.644713555063705, 13.681720191308361, 12.838164232038713, 11.85625091244597, 10.808981470317294, 10.043714624324279, 10.930574677237654, 10.8077534020161, 9.841356519935166, 10.732527632356833, 11.756819178899143, 12.688127699083598, 13.740830524511283, 14.764492274668148, 13.82932604386416, 12.82465654594394, 11.895590717419408, 15.518482267327125, 15.576574938524459, 14.613242230220829, 13.646441311462494, 12.648494028272777, 11.811240238206535, 10.794331077613961, 9.852168517450401, 9.090770813566653, 9.9359383883741, 10.94568855217592, 10.822664526123665, 11.717790997200904, 12.655995631976017, 13.661696365051434, 14.681479548748609, 15.628899468067477, 14.729518280636796, 13.774272455591175, 12.795596958926154, 15.681499725067814, 14.62519415802862, 13.645179433342372, 12.678328506116404, 11.72267036985685, 10.774669409442495, 9.814330954021536, 8.878807049186106, 8.088662563913282, 8.944543309350724, 9.95491852283448, 10.801635424374439, 11.78120857001636, 12.63920301572603, 13.59394367073561, 14.521393556789194, 15.455407368203446, 15.796359094009148, 14.8043441437887, 13.763637686724865, 14.681568033826474, 13.669705341355622, 12.71464434336875, 11.720568149645265, 10.777698818973006, 9.796427810394638, 8.860138686585069, 7.924265522339345, 7.1422780234430405, 7.949855524463435, 8.902063571421541, 9.797964330017228, 10.78710679960362, 11.646433306461677, 12.64785364459097, 13.575480614100178, 14.58540572715534, 15.566167401310683, 15.656563326935153, 14.625929763796954, 13.671644765469805, 12.724897171483452, 11.777450501252646, 10.775657749150467, 9.749617911183657, 8.821252444853839, 7.827368919227282, 6.868084405468025, 6.08825599243938, 6.948277426352973, 7.91412904470544, 8.832803842250975, 9.740977365404472, 10.71164489745274, 11.704016828962821, 12.6537605781316, 13.596871787191994, 14.661789877534996, 15.624851791911968, 15.571774429060428, 12.783344768779617, 11.715044617913756, 10.721316592341024, 9.778850250642034, 8.752108155550543, 7.767366539821426, 6.902577907750032, 5.936712769993082, 5.022221296548702, 5.962701329377334, 6.888795161700089, 7.8785850467442256, 8.732978679618688, 9.74097143782636, 10.687264622426992, 11.641819058104838, 12.643328752389742, 13.647154570648567, 14.586105513933145, 15.491809439651085, 11.864612679674865, 10.798576612934244, 9.75283095290684, 8.818719188484463, 7.780481325197991, 6.817138647138302, 5.851235422827616, 4.941941486993337, 4.064958783063316, 4.93930099965159, 5.8721028773118285, 6.854098988862361, 7.8077605562761345, 8.761969987602795, 9.723877219007887, 10.686124894068078, 11.658079738394246, 12.634186868517354, 13.568605123350448, 14.566451457239893, 10.899553079963102, 10.018106042806522, 8.959576695723078, 7.8861205797124745, 6.881276746557187, 5.859813487685466, 4.905967214405438, 3.9447740180294733, 2.995538914014298, 3.936310920952542, 4.979893036707983, 5.9026653190545675, 6.860446427722971, 7.8976539625895805, 8.768296945979186, 9.79392571080149, 10.71132136540216, 11.77235613875856, 12.716578696694821, 13.741055736143037, 9.919996697876655, 9.030493304006193, 7.9898565314505, 6.916409286987125, 5.949497558125178, 4.920363644871065, 3.9629850687923867, 2.9327750705313793, 1.9680220587187613, 3.008783270480839, 4.050617507706275, 4.9309965760396, 5.889942048832832, 6.846987323171408, 7.782784510755484, 8.740482171362121, 9.780100054409843, 10.840484488881133, 11.789932511170937, 12.722729215994116, 8.93973030399954, 7.993636903660778, 6.931622863448379, 5.96038203118435, 4.93288843353276, 3.963042565382314, 2.982269564080201, 2.0332601623286615, 0.9923120263677315, 2.001578059026883, 2.988757471279298, 3.950621443180537, 4.984984004614153, 5.969574166034882, 7.032820367519624, 8.042491832646503, 9.049597251603657, 10.08382401901245, 11.148885067797432, 12.10736817881891, 8.015589661423586, 7.051157686511371, 6.083201567155651, 5.127858649544897, 4.13387003191003, 3.0680336637359655, 2.0647847796833716, 1.0363240434826237, 0.0, 0.9771700489590104, 2.0422138895658515, 3.032549247841321, 4.00689397928362, 5.046537560502227, 6.056607301006745, 7.083637300144166, 8.095135209793117, 9.086460457433004, 10.09182610037139, 11.119304639153384, 9.088161670437701, 8.0686607795048, 7.013003040560415, 6.0760484819521094, 5.117913079174461, 4.058313436046511, 2.9967609157884265, 2.026074035051377, 1.0682289642883291, 1.996380146767358, 2.994028220694421, 4.0016134519511075, 4.981722285278394, 5.946406099864234, 6.938524524506833, 7.883903603276608, 8.813297201598935, 9.74293351208024, 10.731978746407247, 11.666653174973112, 9.872195273799786, 8.849204114312126, 7.912050801067884, 6.905231010967717, 5.850553855549995, 4.847704038385949, 3.9047508611111645, 2.965855553923466, 2.059697408151413, 2.965821035610424, 3.9828596669569807, 4.9657814231855255, 5.9423850911835165, 6.928121958563837, 7.9493818856965985, 8.817085184422082, 9.753962118699608, 10.717447659737312, 11.666472755027279, 12.619584542639958, 10.808236357892852, 9.79659462224946, 8.909932370419718, 7.893802860530206, 6.818994622128827, 5.785259771151784, 4.963980543457879, 3.9299371375904695, 2.9872763827546573, 3.9226321541532627, 4.87849515047746, 5.927836698281109, 6.871088062477659, 7.926994037468337, 8.880613647688538, 9.791076814372781, 10.790280440308287, 11.753813788537311, 12.638310789774895, 13.571270190176808], [13.595142827714389, 12.727619154046442, 11.799394820444128, 10.751969711412674, 9.812452329814839, 8.761994171811105, 7.780918874093752, 6.8149173824218465, 5.795687892173244, 4.856973139521531, 3.928233664997583, 4.88566572775669, 5.796852267693187, 6.8067097392563625, 7.736015384462152, 8.693369719871752, 9.744783174558838, 10.707511658012269, 11.726422430854134, 12.680518064147572, 12.592679500567106, 13.522735943753567, 12.627892560801012, 11.687546750538937, 10.70516453879705, 9.702193498065034, 8.735695248980813, 7.750289353934572, 6.735451841519811, 5.78381021611043, 4.998118494043121, 5.820549196183242, 6.768743544129557, 7.740744946477562, 8.691391081110654, 9.658126343270366, 10.698062811441604, 11.687964081718178, 12.667267499388794, 11.85178463191188, 11.762054790074988, 12.76264942127034, 13.636997356200965, 12.63660594622298, 11.639214006292296, 10.668015071767538, 9.697987256603861, 8.696858868399953, 7.757629227075511, 6.832482002969455, 6.054980763657918, 6.766929088214057, 7.798698268304511, 8.767965909682868, 9.665820698898528, 10.688553113839129, 11.66911235820543, 12.6320218584045, 11.861926695381813, 10.96422053309741, 11.181488650388358, 12.227244531483455, 13.268591949697992, 13.493398595562525, 12.564247390842901, 11.594312249161481, 10.63792230179801, 9.698639498125756, 8.732854847827639, 7.877429980239473, 7.121230786715967, 7.818156878316858, 8.784264451223274, 9.710301947443465, 10.6828053756058, 11.638241975651063, 12.67992696631763, 11.953640279955183, 10.93344261230551, 9.993476751877454, 12.200984505550462, 13.219690546131863, 14.19752962521767, 14.40043636851028, 13.469741234810932, 12.542558672484654, 11.612880782911136, 10.715216268587424, 9.761360640458463, 8.890921335551278, 8.09389319987058, 8.753703838165173, 9.720220570389984, 10.66095443197245, 11.655547698326, 12.619384557602226, 13.651178434788779, 12.874654612505662, 11.832120085540252, 10.886679837010213, 12.69186407841629, 13.709939109335966, 14.747370973140876, 15.349918145512058, 14.447288666384777, 13.542402863399008, 12.574596133289363, 11.760695280721837, 10.699529095440278, 9.85819106717242, 9.03568129216342, 9.765126677345284, 10.685264362443007, 11.662167984358682, 12.638528095668166, 13.581686141943054, 14.640533943764154, 13.829597050387065, 12.833249709093016, 11.903047476652368, 13.72961132268086, 14.669568182289664, 15.640762197008359, 15.594834684235332, 14.631841320479989, 13.788285361210338, 12.806372041617596, 11.759102599488918, 10.84970707586102, 9.99915179253279, 10.031757522505453, 10.710515291399824, 11.630226476426808, 12.654518022969118, 13.585826543153573, 14.638529368581258, 15.662191118738123, 14.806496092823167, 13.801826594902947, 12.872760766378414, 14.541312218368114, 15.614434084682168, 15.563363359392456, 14.596562440634122, 13.598615157444405, 12.761361367378163, 11.744452206785587, 10.802289646622025, 9.896763265103393, 9.004515503669236, 10.014265667471056, 10.85059023975735, 11.840968301511577, 12.626316225133529, 13.61126560620107, 14.522027398358249, 15.469447317677117, 15.706688329595803, 14.751442504550182, 13.772767007885168, 15.47373083076051, 15.575315287200247, 14.595300562514, 13.628449635288032, 12.672791499028477, 11.724790538614123, 10.764452083193161, 9.828928178357732, 8.894655015450022, 8.01312042464586, 9.023495638129617, 9.824465375415429, 10.80403852105735, 11.66203296676702, 12.6167736217766, 13.544223507830184, 14.478237319244435, 15.44383358531649, 15.781514192747714, 14.740807735683878, 15.658738082785487, 14.646875390314634, 13.664765472540378, 12.670689278816893, 11.727819948144633, 10.746548939566265, 9.810259815756696, 8.87438665151097, 7.948270474979781, 7.018432639758572, 7.970640686716678, 8.820794281058218, 9.80993675064461, 10.669263257502667, 11.67068359563196, 12.598310565141167, 13.60823567819633, 14.588997352351672, 15.573052176764472, 15.603099812755966, 14.648814814428817, 13.702067220442464, 12.754620550211659, 11.752827798109477, 10.726787960142667, 9.798422493812849, 8.777490048398908, 7.8182055346396515, 7.038377121611005, 6.016854541648111, 6.9827061600005775, 7.855633793291965, 8.763807316445462, 9.73447484849373, 10.726846780003811, 11.67659052917259, 12.619701738232983, 13.684619828575986, 14.647681742952958, 15.485447294825278, 13.76051481773863, 12.692214666872768, 11.698486641300036, 10.756020299601044, 9.729278204509553, 8.744536588780436, 7.879747956709043, 6.886833899164708, 5.972342425720328, 5.031278444672472, 5.957372276995226, 6.901414997785215, 7.755808630659677, 8.76380138886735, 9.710094573467982, 10.664649009145828, 11.666158703430732, 12.669984521689557, 13.608935464974135, 14.514639390692075, 12.841782728633879, 11.775746661893258, 10.730001001865853, 9.795889237443475, 8.757651374157001, 7.794308696097312, 6.828405471786627, 5.892062616164964, 5.015079912234942, 4.0078781149467275, 4.940679992606966, 5.876928939903351, 6.830590507317124, 7.784799938643784, 8.746707170048877, 9.708954845109067, 10.680909689435236, 11.657016819558343, 12.591435074391438, 13.589281408280883, 11.87672312892211, 10.995276091765533, 9.93674674468209, 8.863290628671486, 7.858446795516198, 6.8369835366444764, 5.883137263364448, 4.894895147201099, 3.9456600431859234, 3.0048880362476793, 4.002722987748973, 4.925495270095557, 5.883276378763961, 6.92048391363057, 7.791126897020176, 8.81675566184248, 9.73415131644315, 10.79518608979955, 11.73940864773581, 12.763885687184027, 10.897166746835664, 10.007663352965201, 8.96702658040951, 7.893579335946136, 6.926667607084188, 5.897533693830075, 4.940155117751397, 3.9099451194903896, 2.9451921076777716, 2.0749280553545417, 3.073447458747265, 3.95382652708059, 4.912771999873821, 5.869817274212398, 6.805614461796473, 7.763312122403111, 8.802930005450833, 9.863314439922123, 10.812762462211927, 11.745559167035106, 9.916900352958548, 8.970806952619787, 7.90879291240739, 6.9375520801433606, 5.91005848249177, 4.940212614341324, 3.959439613039211, 3.0104302112876717, 1.969482075326742, 1.0508187682553571, 2.0115874223202876, 2.973451394221527, 4.007813955655143, 4.992404117075871, 6.055650318560613, 7.065321783687493, 8.072427202644647, 9.10665397005344, 10.171715018838421, 11.130198129859899, 8.992759710382598, 8.028327735470382, 7.0603716161146615, 6.105028698503907, 5.11104008086904, 4.045203712694976, 3.041954828642382, 2.013494092441634, 0.9771700489590104, 0.0, 1.0650438406068412, 2.055379198882311, 3.02972393032461, 4.069367511543216, 5.079437252047735, 6.106467251185156, 7.117965160834107, 8.109290408473994, 9.11465605141238, 10.142134590194374, 10.065331719396713, 9.04583082846381, 7.990173089519425, 7.05321853091112, 6.095083128133472, 5.035483485005521, 3.973930964747437, 3.003244084010387, 1.985405731511726, 1.057254549032697, 2.016858171735411, 3.0244434029920972, 4.004552236319384, 4.969236050905224, 5.9613544755478225, 6.906733554317598, 7.836127152639925, 8.76576346312123, 9.754808697448237, 10.689483126014101, 10.805843014408989, 9.78285185492133, 8.845698541677088, 7.83887875157692, 6.784201596159198, 5.781351778995152, 4.8383986017203675, 3.8995032945326686, 2.962462021283733, 2.026695437875763, 3.0056896179979704, 3.9886113742265152, 4.965215042224506, 5.950951909604827, 6.972211836737588, 7.839915135463072, 8.776792069740598, 9.740277610778302, 10.689302706068268, 11.642414493680947, 11.741884098502055, 10.730242362858663, 9.84358011102892, 8.82745060113941, 7.75264236273803, 6.718907511760987, 5.897628284067082, 4.8635848781996724, 3.8900409958869773, 2.9835065564186016, 3.9393695527427983, 4.988711100546447, 5.893918013518649, 6.949823988509327, 7.9034435987295275, 8.81390676541377, 9.813110391349277, 10.7766437395783, 11.661140740815885, 12.594100141217798], [12.530098987107548, 11.662575313439602, 10.734350979837288, 9.69326848071438, 8.753751099116545, 7.703292941112813, 6.722217643395459, 5.756216151723554, 4.862645561682054, 3.9239308090303417, 4.787553953045859, 5.744986015804966, 6.692454261413691, 7.702311732976867, 8.631617378182657, 9.588971713592256, 10.640385168279343, 11.603113651732773, 12.622024424574638, 13.576120057868076, 11.527635659960266, 12.457692103146726, 11.56919133010272, 10.628845519840645, 9.646463308098758, 8.643492267366742, 7.676994018282519, 6.817247023443382, 5.802409511028621, 4.85076788561924, 5.850915644888943, 6.679869484231518, 7.628063832177833, 8.633118831632263, 9.583764966265354, 10.55372833699087, 11.593664805162108, 12.583566075438682, 13.562869493109298, 12.747386625632384, 10.69701094946815, 11.6976055806635, 12.578296125502673, 11.577904715524689, 10.580512775594004, 9.609313841069246, 8.639286025905568, 7.763816537908763, 6.8245868965843215, 5.899439672478265, 6.90777791450374, 7.626249376262333, 8.658018556352788, 9.627286197731145, 10.55819458405323, 11.584155107559633, 12.564714351925934, 13.527623852125004, 12.926970535988655, 12.029264373704253, 10.116444809781518, 11.162200690876615, 12.203548109091152, 12.434697364864231, 11.505546160144608, 10.535611018463188, 9.579221071099717, 8.765597167634565, 7.7998125173364485, 6.9443876497482835, 7.901768721129661, 8.677477166365135, 9.643584739271551, 10.569622235491742, 11.542125663654078, 12.51278666951439, 13.565471655664412, 13.018684120562025, 11.998486452912353, 11.058520592484296, 11.135940664943622, 12.154646705525023, 13.13248578461083, 13.341735137811986, 12.411040004112639, 11.48385744178636, 10.554179552212842, 9.782173938096234, 8.828318309967273, 7.9578790050600885, 8.874431134284276, 9.61302412621345, 10.57954085843826, 11.520274720020726, 12.514867986374277, 13.478704845650503, 14.510498722837056, 13.93915985537668, 12.89662532841127, 11.951185079881231, 11.626820237809449, 12.644895268729126, 13.682327132534036, 14.291216914813765, 13.388587435686484, 12.483701632700715, 11.51589490259107, 10.827652950230647, 9.766486764949088, 8.92514873668123, 9.816219226577116, 10.624446965393561, 11.544584650491284, 12.521488272406959, 13.497848383716443, 14.441006429991331, 15.499854231812431, 14.894102293258083, 13.897754951964034, 12.967552719523386, 12.66456748207402, 13.604524341682824, 14.575718356401518, 15.299504522012588, 14.354526911474593, 13.450947957692314, 12.492683558420394, 11.778371648781878, 10.808765326981698, 9.911322205167991, 10.074375201025164, 10.766854405339007, 11.761187825748806, 12.5875119136798, 13.518820433864255, 14.527065933672453, 15.371116760373743, 15.871001335694185, 14.866331837773965, 13.937266009249432, 13.476268377761274, 14.549390244075328, 15.512722952378958, 15.543451194365991, 14.545503911176274, 13.660417094711978, 12.620944643583234, 11.678782083419673, 10.727260197241065, 9.835012435806908, 9.008227101770938, 9.785546399150508, 10.775924460904735, 11.561272384526688, 12.546221765594227, 13.456983557751407, 14.404403477070275, 15.38868906762555, 15.809292964646378, 14.799746998581082, 14.40868699015367, 15.464992557192865, 15.542189316245869, 14.575338389019901, 13.619680252760347, 12.671679292345994, 11.640944519990809, 10.70542061515538, 9.725151947587694, 8.843617356783533, 7.988388814946812, 8.759421534808586, 9.738994680450508, 10.596989126160178, 11.551729781169758, 12.479179667223342, 13.413193478637593, 14.378789744709648, 15.423980187171612, 15.767787726379792, 15.451136299319419, 15.612276127925886, 14.611654226272249, 13.617578032548764, 12.674708701876504, 11.693437693298137, 10.757148569488567, 9.76799384854881, 8.778767407117453, 7.848929571896244, 6.935533863533872, 7.755750440451376, 8.74489291003777, 9.604219416895825, 10.605639755025116, 11.533266724534323, 12.543191837589486, 13.523953511744828, 14.508008336157632, 15.366248119481911, 15.675794805124733, 14.72904721113838, 13.781600540907574, 12.753610404171253, 11.727570566204443, 10.799205099874625, 9.72437880213078, 8.765094288371522, 7.877450410792845, 6.847351473785783, 5.947599336817772, 6.7905899526851226, 7.6987634758386205, 8.669431007886887, 9.661802939396969, 10.611546688565749, 11.554657897626143, 12.619575987969146, 13.582637902346118, 14.420403454218437, 14.787494808434545, 13.719194657568684, 12.725466631995952, 11.765596314652809, 10.738854219561318, 9.754112603832201, 8.88432949122656, 7.8337226528965775, 6.811415714902167, 5.861775376810144, 4.922265453812421, 5.836371157178373, 6.690764790052837, 7.698757548260509, 8.645050732861142, 9.599605168538988, 10.601114862823891, 11.604940681082716, 12.543891624367294, 13.449595550085235, 13.868762719329792, 12.802726652589172, 11.756980992561768, 10.82286922813939, 9.767227389208767, 8.803884711149077, 7.8337505236806475, 6.838951369896833, 5.854153201416781, 4.8383750470844, 3.905573169424161, 4.81188509929651, 5.765546666710284, 6.719756098036943, 7.681663329442037, 8.643911004502227, 9.615865848828395, 10.591972978951503, 11.526391233784597, 12.524237567674042, 12.941228371793128, 12.041865959259848, 10.974238224001724, 9.900782107991121, 8.895938274835833, 7.874475015964113, 6.910104869082636, 5.841783900932969, 4.892548796917794, 3.9517767899795495, 2.9376791471421315, 3.860451429488716, 4.818232538157121, 5.85544007302373, 6.726083056413335, 7.75171182123564, 8.66910747583631, 9.73014224919271, 10.67436480712897, 11.698841846577187, 11.961671989706682, 11.054253220459517, 10.013616447903825, 8.94016920344045, 7.973257474578502, 6.935025173149712, 5.9776465970710335, 4.947436598810026, 3.982683586997408, 3.021816809086412, 2.008403618140424, 2.8887826864737494, 3.847728159266981, 4.804773433605558, 5.740570621189633, 6.69826828179627, 7.737886164843992, 8.798270599315282, 9.747718621605086, 10.680515326428266, 10.981405595829566, 10.035312195490805, 8.973298155278407, 8.002057323014377, 6.974563725362787, 6.0047178572123405, 5.023944855910227, 4.074935454158688, 3.0069735546463785, 1.9977075219872273, 0.9465435817134467, 1.9084075536146858, 2.942770115048302, 3.92736027646903, 4.990606477953772, 6.000277943080652, 7.007383362037808, 8.0416101294466, 9.106671178231581, 10.065154289253059, 10.05780355098944, 9.093371576077224, 8.125415456721504, 7.170072539110748, 6.176083921475882, 5.110247553301817, 4.106998669249223, 3.0785379330484752, 2.0422138895658515, 1.0650438406068412, 0.0, 0.9903353582754695, 1.9646800897177688, 3.0043236709363756, 4.014393411440895, 5.041423410578315, 6.0529213202272665, 7.044246567867153, 8.04961221080554, 9.077090749587533, 11.130375560003555, 10.108318188503834, 9.052660449559447, 8.04100813519419, 7.082872732416541, 6.02327308928859, 4.961720569030506, 3.9521805678206103, 2.8810077252322306, 1.9528565427532016, 0.9518143311285695, 1.959399562385256, 2.9395083957125427, 3.904192210298382, 4.896310634940981, 5.841689713710757, 6.771083312033085, 7.700719622514391, 8.689764856841398, 9.624439285407263, 11.701445008129493, 10.678453848641833, 9.741300535397592, 8.734480745297425, 7.679803589879704, 6.676953772715657, 5.734000595440873, 4.795105288253174, 3.8580640150042376, 2.9222974315962675, 1.940645777391129, 2.9235675336196736, 3.9001712016176655, 4.885908068997987, 5.907167996130747, 6.774871294856231, 7.711748229133757, 8.675233770171461, 9.624258865461428, 10.577370653074107, 12.63748609222256, 11.625844356579167, 10.739182104749425, 9.723052594859913, 8.648244356458534, 7.614509505481492, 6.793230277787587, 5.759186871920177, 4.7856429896074815, 3.8428268444668774, 2.8869638481426807, 3.9363053959463294, 4.828874172911808, 5.884780147902487, 6.838399758122687, 7.74886292480693, 8.748066550742436, 9.71159989897146, 10.596096900209044, 11.529056300610957], [11.539763628832079, 10.672239955164132, 9.744015621561818, 8.70293312243891, 7.763415740841076, 6.712957582837343, 5.7318822851199895, 4.765880793448084, 3.9765969883066834, 4.9142661673058115, 5.777889311321329, 6.735321374080436, 7.682789619689159, 8.692647091252335, 9.621952736458125, 10.579307071867726, 11.630720526554812, 12.593449010008243, 13.612359782850108, 14.566455416143546, 10.537300301684796, 11.467356744871257, 10.57885597182725, 9.638510161565176, 8.656127949823288, 7.653156909091272, 6.6866586600070494, 5.835083991738731, 4.91636093765325, 5.84110324389471, 6.8412510031644125, 7.670204842506988, 8.618399190453303, 9.623454189907733, 10.574100324540824, 11.54406369526634, 12.584000163437578, 13.573901433714152, 14.553204851384768, 13.737721983907853, 9.70667559119268, 10.707270222388031, 11.587960767227202, 10.587569357249217, 9.590177417318532, 8.618978482793775, 7.648950667630098, 6.781653506204112, 5.938538323208951, 6.889775030753735, 7.898113272779209, 8.616584734537803, 9.648353914628258, 10.617621556006615, 11.548529942328699, 12.574490465835103, 13.555049710201404, 14.517959210400473, 13.917305894264125, 13.019599731979723, 9.126109451506048, 10.171865332601145, 11.213212750815682, 11.444362006588761, 10.515210801869138, 9.545275660187718, 8.588885712824247, 7.783434135929913, 6.913763943961078, 7.899892245298007, 8.857273316679386, 9.667812524640604, 10.633920097547021, 11.559957593767212, 12.532461021929548, 13.50312202778986, 14.555807013939882, 14.009019478837494, 12.988821811187822, 12.048855950759766, 10.145605306668152, 11.164311347249553, 12.14215042633536, 12.351399779536516, 11.42070464583717, 10.493522083510891, 9.563844193937372, 8.822655009887617, 7.942269736591901, 8.913383600609812, 9.829935729834, 10.60335948448892, 11.56987621671373, 12.510610078296196, 13.505203344649747, 14.469040203925973, 15.500834081112526, 14.921995798121104, 13.879461271155694, 12.934021022625656, 10.685928236751396, 11.704003267671073, 12.741435131475983, 13.300881556538295, 12.398252077411014, 11.493366274425245, 10.5255595443156, 9.88234061287689, 8.880438191573717, 9.880653332230954, 10.771723822126841, 10.771351018335494, 11.765257938674553, 12.702864849039504, 13.556508791688996, 14.499666837963884, 15.504802931328534, 15.876938236002507, 14.880590894708458, 13.950388662267812, 11.723675481015967, 12.66363234062477, 13.634826355343465, 14.309169163737119, 13.364191553199124, 12.460612599416844, 11.502348200144924, 10.891465444458339, 9.922716753606327, 10.866826800717716, 10.792359286361888, 9.825962404280954, 10.820295824690753, 11.646619912621743, 12.577928432806198, 13.586173932614399, 14.430224759315688, 15.373051099690544, 15.84916778051839, 14.920101951993859, 12.535376376703221, 13.608498243017275, 14.571830951320905, 15.318129116859325, 14.39741771623471, 13.50234985874607, 12.564268034976934, 11.833944632800023, 10.875660564363953, 10.744737666513078, 9.820851154310075, 8.844654398092455, 9.835032459846682, 10.620380383468632, 11.605329764536172, 12.516091556693352, 13.46351147601222, 14.447797066567496, 15.403042891613117, 15.74008791057133, 13.467794989095617, 14.524100556134812, 15.50411528082106, 15.515679301010145, 14.56002116475059, 13.612020204336238, 12.55066975069698, 11.61514584586155, 10.634877178293864, 9.753342587489703, 8.813703580221832, 7.818529533750533, 8.798102679392455, 9.656097125102123, 10.610837780111703, 11.538287666165287, 12.472301477579538, 13.437897743651593, 14.483088186113557, 15.419366057910773, 14.510244298261366, 15.566320288125118, 15.551995138262493, 14.557918944539008, 13.615049613866749, 12.63377860528838, 11.697489481478812, 10.677719079254981, 9.688492637823623, 8.758654802602415, 7.760848628808891, 6.814858439393323, 7.804000908979715, 8.66332741583777, 9.664747753967063, 10.59237472347627, 11.602299836531433, 12.583061510686775, 13.567116335099579, 14.425356118423858, 15.379641116751007, 15.669388123128625, 14.72194145289782, 13.693951316161497, 12.667911478194688, 11.739546011864869, 10.664719714121023, 9.705435200361766, 8.787175641499015, 7.757076704491953, 6.857324567523944, 5.8496979516270695, 6.757871474780566, 7.728539006828833, 8.720910938338914, 9.670654687507692, 10.61376589656809, 11.678683986911093, 12.641745901288065, 13.479511453160384, 15.72783572042479, 14.65953556955893, 13.665807543986197, 12.705937226643055, 11.679195131551564, 10.694453515822447, 9.824670403216805, 8.774063564886823, 7.7211409456083375, 6.771500607516314, 5.831990684518592, 4.89547915612032, 5.749872788994782, 6.757865547202454, 7.704158731803089, 8.658713167480935, 9.660222861765838, 10.664048680024663, 11.602999623309241, 12.508703549027182, 14.80910363132004, 13.74306756457942, 12.697321904552014, 11.763210140129637, 10.707568301199013, 9.744225623139323, 8.774091435670893, 7.779292281887079, 6.763878432122952, 5.74810027779057, 4.815298400130332, 3.870993098238456, 4.824654665652229, 5.7788640969788885, 6.740771328383984, 7.703019003444174, 8.674973847770342, 9.65108097789345, 10.585499232726544, 11.58334556661599, 13.924064314537553, 13.024701902004274, 11.95707416674615, 10.883618050735548, 9.87877421758026, 8.857310958708538, 7.856134298241914, 6.787813330092247, 5.838578226077071, 4.897806219138827, 3.8474043778483025, 2.9195594284306625, 3.8773405370990663, 4.914548071965677, 5.785191055355282, 6.810819820177587, 7.728215474778255, 8.789250248134655, 9.733472806070917, 10.757949845519134, 12.944507932451106, 12.037089163203943, 10.996452390648251, 9.923005146184876, 8.956093417322927, 7.917861115894137, 6.960482539815459, 5.9302725415544515, 4.965519529741833, 4.004652751830837, 2.991239560884849, 1.9478906854156959, 2.906836158208927, 3.863881432547504, 4.79967862013158, 5.757376280738217, 6.796994163785939, 7.857378598257228, 8.806826620547033, 9.739623325370212, 11.96424153857399, 11.01814813823523, 9.956134098022831, 8.984893265758801, 7.957399668107212, 6.987553799956766, 6.006780798654653, 5.057771396903114, 3.9898094973908034, 2.980543464731652, 1.9293795244578718, 0.9675155525566326, 1.9849694756371137, 2.9695596370578414, 4.032805838542584, 5.009942584805183, 6.017048003762338, 7.05127477117113, 8.116335819956111, 9.074818930977589, 11.04813890926491, 10.083706934352694, 9.115750814996973, 8.160407897386218, 7.16641927975135, 6.100582911577286, 5.097334027524692, 4.0688732913239445, 3.032549247841321, 2.055379198882311, 0.9903353582754695, 0.0, 0.9743447314422992, 2.013988312660906, 3.024058053165425, 4.051088052302846, 5.062585961951797, 6.053911209591683, 7.05927685253007, 8.086755391312064, 12.120710918279025, 11.0986535467793, 10.042995807834915, 9.031343493469658, 8.07320809069201, 7.01360844756406, 5.952055927305976, 4.94251592609608, 3.8713430835077, 2.943191901028671, 1.9421496894040389, 0.9690642041097864, 1.949173037437073, 2.9138568520229122, 3.9059752766655116, 4.851354355435287, 5.780747953757615, 6.710384264238921, 7.699429498565928, 8.634103927131793, 12.691780366404963, 11.668789206917303, 10.731635893673062, 9.724816103572895, 8.670138948155172, 7.667289130991125, 6.7243359537163405, 5.785440646528642, 4.848399373279706, 3.912632789871737, 2.9309811356665985, 1.9745678983999246, 2.909835843342196, 3.8955727107225164, 4.916832637855277, 5.784535936580761, 6.721412870858288, 7.684898411895992, 8.633923507185958, 9.587035294798637, 13.627821450498029, 12.616179714854637, 11.729517463024894, 10.713387953135383, 9.638579714734004, 8.604844863756961, 7.783565636063055, 6.749522230195645, 5.77597834788295, 4.833162202742347, 3.8772992064181504, 3.044275254616624, 3.838538814636338, 4.894444789627016, 5.8480643998472175, 6.75852756653146, 7.7577311924669665, 8.72126454069599, 9.605761541933575, 10.538720942335488], [10.62017056306329, 9.752646889395344, 8.82442255579303, 7.806092118660843, 6.866574737063009, 5.825228966216399, 4.844153668499046, 3.8781521768271405, 4.897381667075743, 5.836096419727456, 6.752234042763629, 7.709666105522736, 8.657134351131461, 9.666991822694637, 10.596297467900426, 11.553651803310027, 12.605065257997113, 13.567793741450544, 14.586704514292409, 15.540800147585847, 9.617707235916008, 10.547763679102468, 9.691127355206307, 8.750781544944232, 7.768399333202344, 6.765428292470328, 5.798930043386106, 4.9473553751177874, 5.83714561642231, 6.7629334963163545, 7.763081255586057, 8.644549573949288, 9.592743921895604, 10.597798921350034, 11.548445055983125, 12.51840842670864, 13.558344894879879, 14.548246165156453, 15.527549582827069, 14.712066715350154, 8.787082525423891, 9.787677156619242, 10.70023215060626, 9.699840740628275, 8.70244880069759, 7.731249866172832, 6.761222051009154, 5.893924889583168, 6.852743126143058, 7.811605283175379, 8.819943525200854, 9.590929465980102, 10.622698646070557, 11.591966287448914, 12.522874673771, 13.548835197277404, 14.529394441643705, 15.492303941842774, 14.891650625706422, 13.99394446342202, 8.151764720063747, 9.197520601158844, 10.238868019373381, 10.55663338996782, 9.627482185248196, 8.657547043566776, 7.701157096203304, 6.89570551930897, 7.827968746895185, 8.814097048232115, 9.771478119613494, 10.642157256082903, 11.60826482898932, 12.534302325209511, 13.506805753371847, 14.47746675923216, 15.530151745382181, 14.983364210279792, 13.96316654263012, 13.023200682202063, 9.171260575225853, 10.189966615807252, 11.16780569489306, 11.463671162915572, 10.532976029216226, 9.605793466889947, 8.676115577316429, 7.934926393266673, 8.856474539526008, 9.82758840354392, 10.744140532768109, 11.577704215931218, 11.933208947783317, 12.858142696817566, 13.730977245793866, 14.694814105070092, 15.700269679564638, 15.896340529563403, 14.853806002597993, 13.908365754067955, 9.839992532143224, 10.858067563062901, 11.895499426867811, 12.413152939917351, 11.51052346079007, 10.605637657804301, 9.637830927694656, 8.994611996255946, 9.794642994507823, 10.794858135165063, 11.68592862506095, 11.745695749777793, 10.968165155730293, 11.856929144431334, 12.710573087080826, 13.653731133355715, 14.658867226720364, 15.580090417225883, 15.854935626150757, 14.92473339371011, 10.877739776407795, 11.8176966360166, 12.788890650735294, 13.421440547116175, 12.47646293657818, 11.5728839827959, 10.61461958352398, 10.003736827837395, 10.836921556540434, 11.781031603651824, 11.766704017804187, 10.800307135723253, 10.023203041746493, 10.800684208013573, 11.731992728198028, 12.740238228006229, 13.584289054707519, 14.527115395082374, 15.506723096652182, 15.894446683436156, 11.68944067209505, 12.762562538409103, 13.725895246712733, 14.430400500238381, 13.509689099613766, 12.614621242125127, 11.67653941835599, 10.960549780704287, 11.78986536729806, 11.719082397955376, 10.795195885752374, 9.818999129534754, 9.037939676902422, 9.774444678860462, 10.759394059928002, 11.670155852085182, 12.61757577140405, 13.601861361959326, 14.557107187004947, 15.541471081101312, 12.621859284487446, 13.67816485152664, 14.658179576212888, 15.391170894289248, 14.435512758029693, 13.651192070889167, 12.656539541948415, 11.933911248968581, 11.609221909736162, 10.727687318932, 9.788048311664129, 8.792874265192832, 8.001009896448195, 8.810161420493953, 9.764902075503533, 10.692351961557117, 11.626365772971369, 12.591962039043423, 13.637152481505387, 14.573430353302602, 13.664308593653193, 14.720384583516944, 15.605642068003773, 15.532263675981305, 14.589394345309046, 13.608123336730678, 12.671834212921109, 11.652063810697278, 10.66283736926592, 9.732999534044712, 8.73519336025119, 7.789203170835622, 6.958065204371543, 7.817391711229599, 8.818812049358892, 9.746439018868099, 10.756364131923261, 11.737125806078604, 12.721180630491405, 13.579420413815686, 14.533705412142835, 15.480453006129189, 15.696286184340117, 14.668296047603794, 13.642256209636985, 12.713890743307166, 11.63906444556332, 10.679779931804063, 9.761520372941314, 8.731421435934251, 7.831669298966242, 6.824042683069369, 5.911935770172395, 6.882603302220662, 7.874975233730744, 8.824718982899523, 9.767830191959918, 10.832748282302921, 11.795810196679891, 12.633575748552213, 15.46520302242063, 15.633880301001227, 14.640152275428495, 13.680281958085352, 12.653539862993862, 11.668798247264744, 10.799015134659102, 9.74840829632912, 8.695485677050636, 7.745845338958612, 6.80633541596089, 5.869823887562619, 4.9039370843866115, 5.911929842594283, 6.858223027194918, 7.812777462872763, 8.814287157157667, 9.818112975416492, 10.75706391870107, 11.66276784441901, 15.783448362762337, 14.717412296021717, 13.671666635994312, 12.737554871571934, 11.68191303264131, 10.71857035458162, 9.74843616711319, 8.753637013329376, 7.73822316356525, 6.722445009232868, 5.78964313157263, 4.845337829680755, 3.9787189610440588, 4.932928392370719, 5.894835623775813, 6.857083298836003, 7.829038143162171, 8.805145273285278, 9.739563528118373, 10.737409862007818, 14.898409045979852, 13.999046633446572, 12.93141889818845, 11.857962782177847, 10.853118949022559, 9.831655690150837, 8.830479029684213, 7.762158061534546, 6.81292295751937, 5.872150950581126, 4.821749109290601, 3.8939041598729616, 3.031404832490896, 4.068612367357506, 4.9392553507471115, 5.964884115569415, 6.882279770170084, 7.943314543526483, 8.887537101462746, 9.912014140910962, 13.918852663893405, 13.01143389464624, 11.970797122090548, 10.897349877627175, 9.930438148765226, 8.892205847336436, 7.934827271257758, 6.9046172729967505, 5.939864261184132, 4.978997483273136, 3.965584292327148, 2.922235416857995, 2.0609004536007567, 3.017945727939334, 3.953742915523409, 4.911440576130046, 5.9510584591777675, 7.011442893649057, 7.960890915938862, 8.89368762076204, 12.93858627001629, 11.992492869677529, 10.93047882946513, 9.9592379972011, 8.93174439954951, 7.961898531399065, 6.981125530096952, 6.032116128345413, 4.964154228833102, 3.9548881961739513, 2.903724255900171, 1.9418602839989316, 1.0106247441948146, 1.9952149056155426, 3.0584611071002845, 4.035597853362884, 5.042703272320039, 6.076930039728831, 7.141991088513812, 8.10047419953529, 12.022483640707208, 11.058051665794991, 10.09009554643927, 9.134752628828515, 8.14076401119365, 7.074927643019585, 6.071678758966991, 5.0432180227662435, 4.00689397928362, 3.02972393032461, 1.9646800897177688, 0.9743447314422992, 0.0, 1.039643581218607, 2.049713321723126, 3.0767433208605466, 4.088241230509498, 5.079566478149384, 6.084932121087771, 7.112410659869764, 13.095055649721322, 12.0729982782216, 11.017340539277216, 10.005688224911959, 9.04755282213431, 7.987953179006359, 6.926400658748275, 5.91686065753838, 4.84568781495, 3.9175366324709704, 2.9164944208463384, 1.9434089355520856, 1.06144442081613, 1.994263786254125, 2.986382210896724, 3.9317612896664995, 4.8611548879888264, 5.790791198470132, 6.77983643279714, 7.714510861363006, 13.666125097847264, 12.643133938359604, 11.705980625115362, 10.699160835015196, 9.644483679597473, 8.641633862433427, 7.698680685158641, 6.7597853779709425, 5.822744104722006, 4.886977521314036, 3.905325867108898, 2.9489126298422237, 2.0221072267212525, 3.007844094101573, 3.9972395720864897, 4.864942870811974, 5.801819805089499, 6.765305346127204, 7.71433044141717, 8.667442229029849, 14.60216618194033, 13.590524446296937, 12.703862194467195, 11.687732684577684, 10.612924446176304, 9.579189595199262, 8.757910367505357, 7.723866961637945, 6.75032307932525, 5.807506934184647, 4.85164393786045, 3.98629413864173, 2.950810198015395, 4.006716173006073, 4.960335783226274, 5.838934500762672, 6.838138126698178, 7.801671474927202, 8.686168476164786, 9.619127876566699], [9.580526981844683, 8.713003308176736, 7.784778974574423, 6.766448537442237, 5.826931155844402, 4.878205845189238, 3.938328139316439, 4.7360117756323685, 5.755241265880971, 6.693956018532684, 7.622695493056632, 8.58012755581574, 9.649923450891041, 10.659780922454217, 11.589086567660004, 12.546440903069605, 13.597854357756692, 14.560582841210122, 15.579493614051986, 16.533589247345425, 8.5780636546974, 9.508120097883861, 8.674464391252782, 7.734118580990708, 6.756085369351001, 5.818405171443167, 4.8931045142034995, 5.805214973923015, 6.695005215227538, 7.6207930951215825, 8.620940854391284, 9.515011024242291, 10.463205372188607, 11.468260371643037, 12.418906506276128, 13.397632719192965, 14.437569187364202, 15.468470940707718, 16.447774358378332, 15.704855815109731, 7.7474389442052845, 8.748033575400635, 9.69952194482187, 8.699130534843885, 7.7017385949132, 6.784226745145671, 5.855396521826548, 6.751784488388396, 7.710602724948286, 8.669464881980607, 9.677803124006081, 10.461390916273105, 11.49316009636356, 12.462427737741917, 13.393336124064003, 14.428059489761727, 15.408618734128028, 16.41252871739404, 15.931294206925031, 15.033588044640629, 7.11212113884514, 8.157877019940237, 9.199224438154774, 9.649513599224633, 8.72036239450501, 7.751721514384169, 6.795331567020698, 7.753565118114198, 8.685828345700413, 9.671956647037343, 10.629337718418721, 11.512618706375907, 12.478726279282323, 12.967917589079285, 13.90555225332776, 14.870001980701204, 15.820954854774188, 16.0230077914984, 15.002810123848729, 14.062844263420672, 8.131616994007246, 9.150323034588645, 10.128162113674453, 10.557845633732969, 9.627150500033622, 8.699967937707342, 7.770290048133823, 8.792785992071902, 9.714334138331235, 10.685448002349148, 11.602000131573336, 12.448165666224222, 12.733119395059363, 11.983343507360459, 12.85617805633676, 13.820014915612985, 14.825470490107529, 15.741305666615009, 15.8934495838166, 14.948009335286562, 8.857554460153068, 9.875629491072745, 10.913061354877655, 11.507327410734748, 10.604697931607467, 9.699812128621696, 8.732005398512051, 9.76439594487336, 10.65250259331305, 11.65271773397029, 12.543788223866176, 12.762701468706354, 11.76807560300634, 10.982129954974226, 11.835773897623719, 12.778931943898607, 13.784068037263255, 14.705291227768775, 15.673211531629045, 15.964376974928719, 9.895301704417639, 10.835258564026443, 11.806452578745137, 12.515615017933571, 11.570637407395576, 10.667058453613295, 9.708794054341375, 10.760075192895812, 11.69478115534566, 12.638891202457051, 12.783709736732748, 11.817312854651814, 10.82311348902254, 9.925885018556466, 10.85719353874092, 11.86543903854912, 12.70948986525041, 13.652316205625265, 14.631923907195073, 15.54768592789617, 10.707002600104893, 11.780124466418947, 12.743457174722577, 13.524574971055777, 12.603863570431162, 11.708795712942521, 10.770713889173384, 11.716888145762704, 12.647724966103286, 12.758725979173981, 11.812201604680935, 10.836004848463315, 9.837850124178468, 8.899645489403355, 9.884594870470893, 10.795356662628073, 11.742776581946941, 12.727062172502217, 13.682307997547838, 14.559033009111156, 11.63942121249729, 12.695726779536484, 13.675741504222731, 14.485345365106644, 13.52968722884709, 12.745366541706561, 11.75071401276581, 12.68623791760124, 12.648865490954767, 11.767330900150606, 10.814437590536588, 9.819263544065292, 8.86186300955928, 7.935362231036844, 8.890102886046424, 9.817552772100008, 10.75156658351426, 11.717162849586314, 12.691297092041784, 13.590992281312445, 12.681870521663036, 13.737946511526788, 14.623203996013617, 15.417528110403193, 14.474658779730934, 13.691089196497629, 12.75480007268806, 12.691707391915884, 11.702480950484526, 10.772643115263318, 9.761582639123649, 8.815592449708081, 7.918949076250154, 6.94259252177249, 7.9440128599017825, 8.87163982941099, 9.822358024915175, 10.803119699070518, 11.738742558501249, 12.59698234182553, 13.551267340152679, 14.498014934139032, 15.51911749728712, 15.707939628822404, 14.681899790855594, 13.753534324525775, 12.67870802678193, 11.719423513022672, 10.801163954159922, 9.771065017152857, 8.871312880184849, 7.850431961941828, 6.872819642051005, 6.007804112763553, 6.934395311548667, 7.869229861607323, 8.801816452320402, 9.866734542663405, 10.813372124689735, 11.651137676562056, 14.482764950430473, 15.507867487708728, 15.679795856647102, 14.71992553930396, 13.693183444212469, 12.708441828483352, 11.83865871587771, 10.788051877547728, 9.735129258269243, 8.785488920177219, 7.845978997179498, 6.8962131664350785, 5.864820956265222, 5.037130653137174, 5.8936187237901345, 6.848173159467979, 7.8482734175181506, 8.835674903426336, 9.774625846710913, 10.680329772428854, 15.490017288362445, 15.757055877240322, 14.711310217212919, 13.777198452790541, 12.721556613859917, 11.758213935800228, 10.788079748331798, 9.793280594547983, 8.777866744783857, 7.762088590451476, 6.829286712791237, 5.884981410899362, 4.939602832922668, 4.048645666154815, 4.930231320371029, 5.89247899543122, 6.8466000711720145, 7.822707201295122, 8.757125456128216, 9.754971790017661, 15.93805262719846, 15.03869021466518, 13.971062479407056, 12.897606363396454, 11.892762530241166, 10.871299271369445, 9.87012261090282, 8.801801642753153, 7.852566538737977, 6.911794531799734, 5.861392690509208, 4.9335477410915685, 3.9922887043695052, 3.115405690558961, 3.974651047342328, 4.98244604357926, 5.899841698179928, 6.960876471536328, 7.90509902947259, 8.929576068920806, 14.958496245112013, 14.05107747586485, 13.010440703309158, 11.936993458845782, 10.970081729983834, 9.931849428555044, 8.974470852476365, 7.944260854215358, 6.9795078424027395, 6.018641064491743, 5.005227873545755, 3.961878998076602, 3.021784325479366, 2.064739051140789, 2.9891386121186256, 3.9290025041398904, 4.968620387187612, 6.029004821658901, 6.9784528439487055, 7.911249548771885, 13.978229851234897, 13.032136450896136, 11.970122410683738, 10.998881578419708, 9.971387980768117, 9.001542112617672, 8.020769111315559, 7.07175970956402, 6.00379781005171, 4.994531777392559, 3.9433678371187777, 2.9815038652175385, 2.004400997705435, 1.019810836284707, 2.0226656317152782, 2.995954272144276, 4.003059691101431, 5.0372864585102235, 6.102347507295205, 7.0608306183166825, 13.062127221925817, 12.0976952470136, 11.12973912765788, 10.174396210047124, 9.180407592412257, 8.114571224238192, 7.111322340185598, 6.082861603984851, 5.046537560502227, 4.069367511543216, 3.004323670936375, 2.013988312660906, 1.039643581218607, 0.0, 1.010069740504519, 2.0370997396419392, 3.04859764929089, 4.0399228969307766, 5.045288539869164, 6.0727670786511565, 14.109573814692176, 13.06578737798118, 12.010129639036796, 10.998477324671539, 10.04034192189389, 8.980742278765941, 7.919189758507857, 6.909649757297961, 5.838476914709581, 4.910325732230552, 3.9092835206059204, 2.899412852948644, 1.9193040196213573, 0.954620205035518, 1.946738629678117, 2.8921177084478926, 3.82151130677022, 4.751147617251526, 5.7401928515785325, 6.674867280144398, 14.65891419760684, 13.63592303811918, 12.69876972487494, 11.691949934774772, 10.637272779357051, 9.634422962193005, 8.69146978491822, 7.752574477730523, 6.8155332044815875, 5.8797666210736175, 4.850497399035309, 3.867575642806764, 2.87996682552648, 1.9806354951845573, 2.9575959908678824, 3.825299289593367, 4.762176223870893, 5.7256617649085975, 6.674686860198563, 7.627798647811242, 15.594955281699907, 14.583313546056514, 13.696651294226774, 12.680521784337262, 11.605713545935883, 10.57197869495884, 9.750699467264935, 8.716656061397526, 7.731283574962793, 6.752678466111058, 5.796815469786861, 4.844153737446957, 3.8086697968206225, 2.979507574089057, 3.933127184309258, 4.799290919544066, 5.7984945454795715, 6.762027893708596, 7.64652489494618, 8.579484295348092], [8.574996020868305, 7.707472347200359, 6.779248013598045, 5.760917576465859, 4.8214001948680245, 3.8802555905591523, 4.847617105126755, 5.714717663941189, 6.733947154189792, 7.672661906841505, 8.601401381365452, 9.55883344412456, 10.628629339199863, 11.63848681076304, 12.567792455968826, 13.525146791378427, 14.576560246065513, 15.539288729518944, 16.55819950236081, 17.51229513565425, 7.572532693721023, 8.502589136907483, 7.668933430276404, 6.72858762001433, 5.750554408374623, 4.820454916813081, 5.802393480013816, 6.783920862231836, 7.673711103536359, 8.599498983430404, 9.599646742700106, 10.493716912551111, 11.441911260497427, 12.446966259951857, 13.397612394584948, 14.376338607501784, 15.416275075673022, 16.447176829016538, 17.426480246687152, 16.683561703418555, 6.741907983228907, 7.742502614424258, 8.693990983845492, 7.693599573867507, 6.696207633936822, 5.7862764905155855, 6.764685487636864, 7.730490376697217, 8.689308613257108, 9.648170770289429, 10.656509012314903, 11.440096804581925, 12.47186598467238, 13.441133626050737, 14.04973930556356, 14.928837022974784, 15.900684421194638, 16.717915555825403, 16.94136394742955, 16.043657785145147, 6.102051398340622, 7.147807279435719, 8.189154697650256, 8.643982638248255, 7.714831433528632, 6.763919093547833, 7.704620532831014, 8.73227100642302, 9.664534234009235, 10.650662535346164, 11.608043606727541, 12.491324594684727, 13.457432167591143, 13.771280372700605, 13.014698433789407, 13.97914816116285, 14.889869813082438, 15.741964190058434, 16.01287986435325, 15.072914003925192, 7.121547253502728, 8.140253294084127, 9.118092373169935, 9.624621087245766, 8.693925953546419, 7.766743391220141, 8.679579013944139, 9.71841829876335, 10.672273926892311, 11.64574346941806, 12.580706019882156, 13.426871554533042, 13.536482178680684, 12.78670629098178, 11.965324236798406, 12.929161096074631, 13.894385448415779, 14.810220624923257, 15.735865340025013, 15.95807907579108, 7.847484719648549, 8.865559750568226, 9.902991614373136, 10.574102864247545, 9.671473385120263, 8.780089294383457, 9.641294364322366, 10.673684910683676, 11.610442381874126, 12.613013201039202, 13.522494112174996, 13.566064252327674, 12.57143838662766, 11.785492738595547, 10.944920078085365, 11.888078124360254, 12.852982995571505, 13.774206186077024, 14.73473571647225, 15.507329477117699, 8.885231963913121, 9.825188823521925, 10.79638283824062, 11.582390471446368, 10.637412860908373, 9.747335619375056, 10.61808302015169, 11.669364158706127, 12.638970480506307, 13.599186669525963, 13.587072520354068, 12.620675638273134, 11.62647627264386, 10.729247802177786, 9.966339719202567, 10.934885046300918, 11.77840482355866, 12.721231163933515, 13.693448092038278, 14.537616187391652, 9.696932859600375, 10.770054725914429, 11.73338743421806, 12.591350424568574, 11.67063902394396, 10.789072878704282, 11.6800028549837, 12.62617711157302, 13.58446118000909, 13.625314552104076, 12.615564388302255, 11.639367632084635, 10.641212907799789, 9.703008273024675, 8.992771053234732, 9.864802670379872, 10.811691540255191, 11.79318867348108, 12.743832182391042, 13.548963268606638, 10.629351471992772, 11.685657039031966, 12.665671763718214, 13.552120818619441, 12.596462682359887, 11.825643707468322, 12.660002978576125, 13.595526883411555, 13.517843299208158, 12.636308708403996, 11.664564598593982, 10.644798938822523, 9.665225793180602, 8.738725014658167, 7.9982790688102625, 8.886998779851806, 9.78677826645283, 10.726347860108728, 11.681227351537268, 12.580922540807927, 11.67180078115852, 12.727876771022272, 13.613134255509099, 14.48430356391599, 13.54143423324373, 12.803885306516179, 13.664089038498375, 13.560685200169274, 12.571458758737917, 11.641620923516708, 10.611709647181042, 9.665719457765475, 8.769076084307548, 7.745955305393813, 6.961016740082826, 7.888643709592033, 8.81228828441066, 9.793049958566002, 10.728672817996733, 11.586912601321012, 12.54119759964816, 13.487945193634514, 14.509047756782602, 15.523705036191556, 14.584611932360794, 13.871755086826859, 13.54768583503532, 12.588401321276063, 11.670141762413312, 10.640042825406248, 9.740290688438238, 8.700558969999221, 7.7229466501083985, 6.811166896384876, 5.9243255710441485, 6.8591601211028035, 7.791746711815885, 8.856664802158889, 9.80330238418522, 10.641067936057539, 13.472695209925956, 14.49779774720421, 15.491525772776942, 15.58890334755735, 14.56216125246586, 13.577419636736742, 12.7076365241311, 11.657029685801119, 10.604107066522634, 9.65446672843061, 8.714956805432887, 7.746340174492472, 6.714947964322615, 5.840493436758496, 4.883548983285616, 5.838103418963461, 6.838203677013633, 7.825605162921818, 8.764556106206395, 9.670260031924336, 14.479947547857927, 15.533996180689115, 15.58028802546631, 14.646176261043932, 13.590534422113308, 12.627191744053619, 11.657057556585189, 10.662258402801374, 9.646844553037248, 8.631066398704865, 7.698264521044627, 6.753689108779005, 5.789729840980062, 4.852008449776138, 3.9201615798665106, 4.882409254926701, 5.836530330667497, 6.812637460790604, 7.747055715623699, 8.744902049513144, 15.532320229098815, 15.980812449432577, 14.907825940267053, 13.834369824256449, 12.82952599110116, 11.80806273222944, 10.739100419156209, 9.670779451006542, 8.721544346991367, 7.780772340053122, 6.730370498762598, 5.802525549344958, 4.842415712426899, 3.9187684741802826, 2.9645813068378093, 3.972376303074741, 4.88977195767541, 5.950806731031809, 6.895029288968072, 7.919506328416288, 15.96856598561653, 15.061147216369365, 14.020510443813674, 12.9470631993503, 11.980151470488352, 10.941919169059561, 9.984540592980883, 8.954330594719876, 7.989577582907258, 6.949201979514916, 5.877299254067029, 4.830856806329991, 3.8719113335367594, 2.9148660591981823, 1.979068871614107, 2.9189327636353717, 3.9585506466830935, 5.018935081154383, 5.968383103444188, 6.901179808267367, 14.988299591739414, 14.042206191400654, 12.980192151188255, 12.008951318924225, 10.981457721272635, 10.01161185312219, 9.030838851820077, 8.081829450068538, 7.0138675505562285, 6.004601517897077, 4.953437577623297, 3.9915736057220577, 3.014470738209954, 2.0298805767892256, 1.0125958912107595, 1.985884531639757, 2.992989950596912, 4.027216718005705, 5.092277766790687, 6.050760877812165, 14.072196962430336, 13.10776498751812, 12.1398088681624, 11.184465950551644, 10.190477332916776, 9.124640964742712, 8.121392080690118, 7.0929313444893705, 6.056607301006746, 5.079437252047736, 4.014393411440895, 3.024058053165425, 2.049713321723126, 1.010069740504519, 0.0, 1.0270299991374205, 2.0385279087863712, 3.029853156426258, 4.035218799364645, 5.062697338146638, 15.088279703001, 14.044493266290004, 12.98883552734562, 11.977183212980362, 11.019047810202714, 9.959448167074763, 8.897895646816679, 7.888355645606783, 6.817182803018403, 5.889031620539374, 4.887989408914741, 3.878118741257465, 2.898009907930178, 1.9333260933443388, 0.9412076687017397, 1.8865867474715152, 2.8159803457938426, 3.745616656275148, 4.734661890602155, 5.66933631916802, 15.637620085915664, 14.614628926428004, 13.677475613183763, 12.670655823083596, 11.615978667665873, 10.613128850501827, 9.670175673227043, 8.731280366039345, 7.794239092790409, 6.858472509382439, 5.8292032873441295, 4.846281531115585, 3.858672713835301, 2.959341383493378, 1.9520650298915052, 2.8197683286169895, 3.7566452628945153, 4.72013080393222, 5.6691558992221855, 6.622267686834864, 16.57366117000873, 15.562019434365338, 14.675357182535596, 13.659227672646084, 12.584419434244705, 11.550684583267662, 10.729405355573757, 9.695361949706347, 8.709989463271615, 7.731384354419879, 6.7755213580956815, 5.822859625755779, 4.787375685129444, 3.888796539899373, 2.935176929679172, 3.793759958567688, 4.792963584503195, 5.756496932732218, 6.640993933969802, 7.573953334371715], [7.738849973259264, 6.871326299591319, 5.943101965989005, 4.924771528856819, 3.985254147258984, 4.89169159076363, 5.859053105331233, 6.741747663078609, 7.760977153327212, 8.699691905978925, 9.628431380502873, 10.58586344326198, 11.655659338337282, 12.665516809900458, 13.594822455106245, 14.552176790515846, 15.603590245202932, 16.566318728656363, 17.585229501498226, 18.539325134791667, 6.736386646111982, 7.6664430892984425, 6.832787382667363, 5.892441572405289, 4.914408360765583, 5.831890917017558, 6.813829480218294, 7.810950861369256, 8.700741102673778, 9.626528982567823, 10.626676741837525, 11.520746911688532, 12.468941259634848, 13.473996259089278, 14.424642393722369, 15.113462142470793, 15.844703968821044, 16.634943333374306, 17.58889350694511, 17.710591702555973, 5.905761935619866, 6.906356566815218, 7.85784493623645, 6.857453526258467, 5.860061586327782, 6.797712490720063, 7.776121487841342, 8.757520375834638, 9.716338612394528, 10.675200769426848, 11.683539011452321, 12.467126803719346, 13.4988959838098, 14.468163625188158, 14.89404665235408, 14.08303537190203, 14.873654422057218, 15.690885556687984, 16.630398013870153, 17.070687784282566, 5.075021399203202, 6.120777280298299, 7.1621246985128355, 7.807836590639216, 6.878685385919592, 7.77535509375231, 8.716056533035491, 9.745690105059808, 10.691564233146655, 11.677692534483585, 12.635073605864964, 13.518354593822147, 14.484462166728564, 14.641811926191089, 13.859005780579926, 13.133346510090096, 13.862839813945017, 14.714934190921015, 15.735131858570687, 16.09994400306261, 6.094517254365307, 7.113223294946707, 8.091062374032514, 8.795013911296145, 7.864318777596798, 8.778179391424617, 9.691015014148617, 10.729854298967828, 11.683709927096789, 12.657179469622537, 13.607736019019578, 14.453901553670462, 14.407013732171167, 13.657237844472263, 12.809631583588924, 12.083359445001877, 12.867355449278358, 13.783190625785839, 14.708835340887594, 15.537856214613207, 6.820454720511129, 7.838529751430806, 8.875961615235715, 9.744495688297924, 8.841866209170643, 9.791525294587933, 10.652730364526844, 11.685120910888154, 12.621878382078604, 13.62444920124368, 14.549524111312419, 14.436595805818158, 13.441969940118144, 12.65602429208603, 11.789227424875884, 11.033534969641117, 11.825952996434085, 12.747176186939605, 13.70770571733483, 14.480299477980278, 7.8582019647756995, 8.798158824384505, 9.769352839103199, 10.752783295496748, 9.807805684958753, 10.758771619579532, 11.629519020356168, 12.680800158910605, 13.650406480710785, 14.610622669730441, 14.457604073844552, 13.491207191763618, 12.497007826134343, 11.59977935566827, 10.810647065993086, 9.96302279599631, 10.751374824421239, 11.694201164796095, 12.666418092900859, 13.510586188254232, 8.669902860462955, 9.743024726777008, 10.706357435080639, 11.75836255286916, 10.841031847994337, 11.780768109405136, 12.691438855188178, 13.637613111777497, 14.595897180213568, 14.495846105594559, 13.486095941792739, 12.509899185575119, 11.511744461290272, 10.573539826515159, 9.83707840002525, 8.892940420075263, 9.78466154111777, 10.766158674343659, 11.716802183253623, 12.521933269469217, 9.602321472855351, 10.658627039894546, 11.638641764580793, 12.605492691806761, 11.766855506410264, 12.749109114501989, 13.671438978780603, 14.606962883616033, 14.38837485269864, 13.506840261894478, 12.535096152084463, 11.515330492313005, 10.535757346671083, 9.609256568148648, 8.842586415600781, 7.915136529547198, 8.759748267315409, 9.699317860971307, 10.654197352399848, 11.553892541670507, 10.644770782021098, 11.70084677188485, 12.586104256371678, 13.580180450095163, 12.711827057294109, 13.693098065872476, 14.629387189682046, 14.431216753659756, 13.441990312228398, 12.51215247700719, 11.482241200671524, 10.536251011255956, 9.63960763779803, 8.616486858884295, 7.831548293573308, 6.916781459287424, 7.785258285273239, 8.766019959428581, 9.701642818859312, 10.559882602183592, 11.51416760051074, 12.460915194497094, 13.482017757645181, 14.512094884106101, 13.755004756411171, 14.68337022274099, 14.4182173885258, 13.458932874766543, 12.540673315903794, 11.51057437889673, 10.610822241928718, 9.571090523489703, 8.593478203598881, 7.681698449875357, 6.79485712453463, 5.847179227301574, 6.764716712678465, 7.829634803021468, 8.776272385047799, 9.614037936920118, 12.445665210788535, 13.47076774806679, 14.464495773639522, 15.483600388392324, 14.778020249978955, 14.447951190227224, 13.578168077621582, 12.5275612392916, 11.474638620013115, 10.524998281921091, 9.585488358923367, 8.616871727982954, 7.585479517813097, 6.711024990248978, 5.754080536776097, 4.826122525162231, 5.811173677876212, 6.798575163784397, 7.737526107068976, 8.643230032786915, 13.452917548720507, 14.506966181551695, 15.432981413073705, 15.516707814534414, 14.46106597560379, 13.4977232975441, 12.52758911007567, 11.532789956291856, 10.51737610652773, 9.501597952195347, 8.568796074535108, 7.624220662269487, 6.6602613944705436, 5.722540003266619, 4.790693133356992, 3.8704283611254713, 4.809500331530076, 5.785607461653184, 6.720025716486279, 7.717872050375723, 14.505290229961394, 15.47685424687652, 15.778357493757532, 14.70490137774693, 13.700057544591642, 12.678594285719921, 11.60963197264669, 10.541311004497024, 9.592075900481849, 8.651303893543604, 7.600902052253079, 6.673057102835439, 5.71294726591738, 4.789300027670764, 3.835112860328291, 2.9453463039373204, 3.8627419585379896, 4.923776731894389, 5.867999289830651, 6.8924763292788676, 15.484846612047841, 15.932064378229585, 14.891427605673893, 13.817980361210518, 12.85106863234857, 11.81283633091978, 10.855457754841101, 9.825247756580094, 8.860494744767475, 7.819733533005397, 6.747830807557509, 5.701388359820472, 4.742442887027241, 3.785397612688664, 2.849600425104588, 1.8919027644979511, 2.931520647545673, 3.991905082016962, 4.941353104306767, 5.874149809129946, 16.01532959087684, 15.069236190538076, 14.007222150325678, 13.035981318061648, 12.008487720410058, 11.038641852259612, 10.0578688509575, 9.10885944920596, 8.04089754969365, 7.031631517034499, 5.980467576760718, 5.018603604859479, 4.041500737347374, 3.056910575926646, 2.0039693539429573, 0.9588545325023365, 1.9659599514594917, 3.0001867188682843, 4.065247767653267, 5.023730878674744, 15.099226961567755, 14.134794986655539, 13.166838867299818, 12.211495949689063, 11.217507332054197, 10.151670963880132, 9.148422079827538, 8.119961343626791, 7.083637300144167, 6.1064672511851565, 5.041423410578315, 4.051088052302846, 3.076743320860546, 2.0370997396419392, 1.0270299991374205, 0.0, 1.0114979096489507, 2.0028231572888373, 3.0081888002272246, 4.035667339009217, 16.11530970213842, 15.071523265427423, 14.015865526483038, 13.004213212117781, 12.046077809340133, 10.986478166212182, 9.924925645954097, 8.915385644744202, 7.8442128021558215, 6.916061619676793, 5.915019408052161, 4.905148740394885, 3.9250399070675983, 2.960356092481759, 1.9682376678391602, 1.0504406998624747, 1.979834298184802, 2.9094706086661075, 3.8985158429931146, 4.83319027155898, 16.664650085053083, 15.641658925565423, 14.704505612321181, 13.697685822221015, 12.643008666803292, 11.640158849639246, 10.697205672364461, 9.758310365176763, 8.821269091927828, 7.885502508519858, 6.856233286481549, 5.873311530253004, 4.885702712972721, 3.9863713826307983, 2.979095029028926, 1.983622281007949, 2.9204992152854747, 3.883984756323179, 4.833009851613145, 5.786121639225824, 17.60069116914615, 16.589049433502755, 15.702387181673014, 14.686257671783503, 13.611449433382123, 12.577714582405081, 11.756435354711176, 10.722391948843766, 9.737019462409034, 8.758414353557297, 7.802551357233101, 6.849889624893199, 5.814405684266863, 4.9002325401038505, 3.9466129298836496, 2.9576139109586475, 3.956817536894154, 4.920350885123177, 5.804847886360761, 6.737807286762674], [6.758302369315882, 5.890778695647937, 4.962554362045623, 4.01662293335498, 4.863493739960257, 5.7699311834649025, 6.737292698032505, 7.647569366572972, 8.666798856821575, 9.605513609473288, 10.534253083997235, 11.491685146756343, 12.561481041831646, 13.571338513394823, 14.50064415860061, 15.45799849401021, 15.923124968620536, 16.733768981157315, 17.73488643726787, 18.532413381371782, 5.7558390421686, 6.6858954853550605, 5.924638787165525, 4.9842929769034505, 5.792647953466855, 6.710130509718831, 7.6920690729195655, 8.716772564863618, 9.606562806168142, 10.532350686062188, 11.532498445331889, 12.426568615182894, 13.37476296312921, 14.37981796258364, 15.330464097216732, 16.003013661069385, 14.963077192898146, 15.753316557451406, 16.70726673102221, 17.513764040640275, 4.925214331676484, 5.925808962871836, 6.967790970025604, 6.004747723872127, 6.738301179029055, 7.675952083421335, 8.654361080542614, 9.663342079328999, 10.62216031588889, 11.581022472921212, 12.589360714946686, 13.372948507213708, 14.404717687304164, 15.37398532868252, 15.791045425613644, 14.980034145161595, 13.99202764613432, 14.809258780765084, 15.74877123794725, 16.554496255233197, 4.06352348955425, 5.109279370649347, 6.1506267888638835, 7.015319709248394, 7.756924978620864, 8.653594686453584, 9.594296125736763, 10.62392969776108, 11.597385936641016, 12.583514237977946, 13.540895309359325, 14.42417629731651, 15.390283870222927, 15.648373943549991, 14.75600455383949, 14.03034528334966, 12.98121303802212, 13.833307414998115, 14.84583255572816, 15.583752474013242, 5.083019344716356, 6.101725385297755, 7.079564464383562, 8.054002415886416, 8.74255837029807, 9.65641898412589, 10.569254606849888, 11.6080938916691, 12.56194951979806, 13.53541906232381, 14.513557722513939, 15.359723257164825, 15.418511641820116, 14.663799861831166, 13.706630356848489, 12.980358218261442, 11.98572867335546, 12.901563849862939, 13.803458180745059, 14.632479054470672, 5.831861945884333, 6.84993697680401, 7.88736884060892, 8.889886561547353, 9.720105801871915, 10.669764887289206, 11.530969957228116, 12.563360503589426, 13.500117974779876, 14.502688793944952, 15.45534581480678, 15.448093715467106, 14.453467849767092, 13.662586309444933, 12.686226198135449, 11.930533742900682, 10.944326220511186, 11.865549411016705, 12.802328557192295, 13.574922317837743, 6.8696091901489025, 7.809566049757707, 8.780760064476402, 9.799301693551618, 10.686045277660025, 11.637011212280806, 12.50775861305744, 13.559039751611877, 14.528646073412057, 15.488862262431713, 15.4691019834935, 14.502705101412566, 13.508505735783292, 12.611277265317218, 11.70764583925265, 10.860021569255874, 9.86974804849834, 10.812574388873196, 11.761040932758323, 12.605209028111696, 7.76452570032042, 8.806646228154914, 9.769978936458545, 10.808261646673824, 11.71927144069561, 12.65900770210641, 13.56967844788945, 14.51585270447877, 15.47413677291484, 15.507344015243508, 14.497593851441687, 13.521397095224067, 12.52324237093922, 11.585037736164107, 10.734077173284815, 9.789939193334828, 8.903034765194873, 9.88453189842076, 10.811425023111088, 11.616556109326682, 8.696944312712818, 9.753249879752012, 10.73326460443826, 11.700115531664228, 12.645095099111538, 13.627348707203263, 14.549678571481875, 15.485202476317305, 15.39987276234759, 14.518338171543428, 13.546594061733414, 12.526828401961955, 11.547255256320033, 10.620754477797599, 9.739585188860346, 8.812135302806762, 7.878121491392511, 8.81769108504841, 9.748820192257314, 10.648515381527972, 9.739393621878563, 10.795469611742314, 11.680727096229145, 12.67480328995263, 13.590066649995382, 14.57133765857375, 15.50762678238332, 15.442714663308706, 14.453488221877349, 13.52365038665614, 12.493739110320474, 11.547748920904906, 10.65110554744698, 9.627984768533246, 8.84118359191471, 7.913556622405503, 6.90363150935034, 7.884393183505683, 8.796265658716779, 9.654505442041057, 10.608790440368205, 11.555538034354559, 12.576640597502646, 13.606717723963566, 14.632757561930376, 15.561123028260194, 15.429715298174752, 14.470430784415495, 13.552171225552744, 12.52207228854568, 11.622320151577668, 10.582588433138653, 9.604976113247831, 8.693196359524308, 7.80635503418358, 6.858677136950526, 5.8830899367555665, 6.94800802709857, 7.870895224905264, 8.708660776777583, 11.540288050646, 12.565390587924254, 13.559118613496986, 14.578223228249788, 15.604965323341279, 15.459449099876174, 14.589665987270532, 13.53905914894055, 12.486136529662065, 11.536496191570041, 10.596986268572318, 9.628369637631904, 8.596977427462047, 7.722522899897928, 6.765578446425048, 5.837620434811182, 4.929546901953314, 5.893198003641862, 6.832148946926441, 7.737852872644381, 12.547540388577971, 13.60158902140916, 14.52760425293117, 15.461716017353547, 15.47256388525274, 14.50922120719305, 13.53908701972462, 12.544287865940806, 11.52887401617668, 10.513095861844297, 9.580293984184058, 8.635718571918437, 7.671759304119494, 6.73403791291557, 5.8021910430059425, 4.881926270774422, 3.927873555607178, 4.880230301510649, 5.8146485563437444, 6.8124948902331885, 13.599913069818859, 14.571477086733985, 15.512762887631864, 15.716399287395879, 14.71155545424059, 13.69009219536887, 12.621129882295639, 11.552808914145972, 10.603573810130797, 9.662801803192552, 8.612399961902028, 7.684555012484389, 6.724445175566331, 5.8007979373197145, 4.846610769977241, 3.956844213586271, 2.9811151826150915, 3.9351839572675926, 4.879406515203854, 5.9038835546520705, 14.579469451905306, 15.559089825534315, 15.902925515322842, 14.829478270859468, 13.86256654199752, 12.82433424056873, 11.866955664490051, 10.836745666229044, 9.871992654416426, 8.831231442654348, 7.75932871720646, 6.712886269469422, 5.753940796676191, 4.796895522337614, 3.861098334753539, 2.903400674146902, 2.049893871622775, 3.003312307390166, 3.9527603296799705, 4.88555703450315, 15.559735845782422, 16.080734100187026, 15.01872005997463, 14.0474792277106, 13.01998563005901, 12.050139761908564, 11.069366760606451, 10.120357358854912, 9.052395459342602, 8.04312942668345, 6.9919654864096685, 6.030101514508429, 5.0529986469963255, 4.068408485575597, 3.0154672635919075, 1.9703524421512872, 1.0356058922091305, 1.9886888092193333, 3.0537498580043154, 4.012232969025793, 16.110724871216707, 15.146292896304491, 14.17833677694877, 13.222993859338015, 12.229005241703149, 11.163168873529084, 10.15991998947649, 9.131459253275743, 8.095135209793119, 7.117965160834108, 6.0529213202272665, 5.062585961951797, 4.088241230509498, 3.0485976492908904, 2.0385279087863712, 1.0114979096489507, 0.0, 0.9913252476398864, 1.9966908905782734, 3.024169429360266, 17.021131405632783, 15.977344968921788, 14.921687229977403, 13.910034915612146, 12.951899512834498, 11.892299869706546, 10.830747349448462, 9.821207348238566, 8.750034505650186, 7.821883323171157, 6.820841111546525, 5.810970443889248, 4.8308616105619615, 3.866177795976122, 2.8740593713335225, 1.928680292563747, 0.9992866942414195, 1.928923004722725, 2.917968239049732, 3.8526426676155974, 17.570471788547447, 16.547480629059788, 15.610327315815546, 14.60350752571538, 13.548830370297656, 12.54598055313361, 11.603027375858826, 10.664132068671128, 9.727090795422193, 8.791324212014223, 7.762054989975912, 6.779133233747367, 5.791524416467084, 4.892193086125161, 3.881286695181783, 2.861861873709221, 1.9399516113420923, 2.903437152379797, 3.852462247669763, 4.805574035282442, 18.506512872640513, 17.49487113699712, 16.60820888516738, 15.592079375277867, 14.517271136876488, 13.483536285899445, 12.66225705820554, 11.62821365233813, 10.642841165903397, 9.66423605705166, 8.708373060727464, 7.755711328387561, 6.720227387761226, 5.778472132805122, 4.824852522584922, 3.8358535036599197, 2.976269932950771, 3.9398032811797954, 4.824300282417379, 5.757259682819292], [5.851969231676704, 4.984445558008758, 4.056221224406445, 4.95892368978632, 5.805794496391597, 6.712231939896244, 7.679593454463847, 8.589870123004312, 9.609099613252916, 10.547814365904628, 11.476553840428576, 12.433985903187683, 13.503781798262986, 14.513639269826163, 15.44294491503195, 16.40029925044155, 16.86026359700723, 15.97903189602157, 16.769106590485197, 17.5410881337319, 4.849505904529422, 5.779562347715882, 5.092527045066425, 5.926593733334791, 6.7349487098981955, 7.652431266150172, 8.634369829350907, 9.659073321294958, 10.548863562599482, 11.474651442493528, 12.47479920176323, 13.368869371614235, 14.31706371956055, 15.32211871901498, 16.27276485364807, 16.940152289456076, 15.900215821284839, 14.998579472315662, 15.741486884239535, 16.522438793000394, 4.008242467145212, 5.008837098340564, 6.050819105494332, 6.947048480303467, 7.680601935460395, 8.618252839852676, 9.596661836973956, 10.605642835760339, 11.56446107232023, 12.523323229352552, 13.531661471378026, 14.315249263645049, 15.347018443735504, 16.31628608511386, 16.728184054000337, 15.917172773548286, 14.929166274521013, 14.05452169562934, 14.782991391164577, 15.563171007593313, 3.072198241914364, 4.117954123009461, 5.159301541223998, 6.211703545665588, 7.140854750385212, 8.11078989206663, 9.067179839430102, 10.096813411454418, 11.080621382137313, 12.066749683474242, 13.02413075485562, 14.051771547970992, 15.075042014455235, 16.050781519385687, 15.693143182226184, 14.967483911736352, 13.918351666408812, 13.078570329862371, 13.854507308088275, 14.592427226373356, 4.091694097076469, 5.110400137657869, 6.088239216743677, 7.151758654230029, 8.082453787929376, 9.009636350255654, 9.939314239829173, 10.978153524648384, 11.932009152777345, 12.905478695303094, 13.970180105917265, 14.97346329940592, 15.93998003163073, 15.600938490217857, 14.643768985235182, 13.917496846648133, 12.922867301742153, 12.146826764727194, 12.812132933105174, 13.641153806830786, 4.840536698244446, 5.8586117291641235, 6.896043592969033, 7.898561313907466, 8.970716081666323, 10.008108010082942, 10.9010295902074, 11.93342013656871, 12.87017760775916, 13.872748426924236, 14.876623430364155, 15.820818509295973, 15.444793097406981, 14.599724937831626, 13.623364826522142, 12.867672371287373, 11.88146484889788, 11.11081232588096, 11.81100330955241, 12.583597070197857, 5.878283942509016, 6.8182408021178205, 7.789434816836516, 8.807976445911732, 9.770969809667076, 10.819655593398636, 11.801568912991378, 12.852850051545815, 13.822456373345995, 14.846667545473519, 15.872699660706187, 15.494030349052455, 14.49983098342318, 13.576092987823799, 12.644784467639344, 11.797160197642567, 10.806886676885034, 10.057837303737452, 10.769715685118438, 11.613883780471811, 6.773200452680534, 7.815320980515029, 8.77865368881866, 9.816936399033938, 10.804195972702662, 11.74393223411346, 12.783404685242203, 13.809663004412707, 14.767947072848777, 15.82817081331437, 15.488919099081576, 14.512722342863956, 13.51456761857911, 12.576362983803996, 11.671215801671508, 10.72707782172152, 9.840173393581566, 9.019037378699, 9.820099775471203, 10.625230861686797, 7.705619065072931, 8.761924632112125, 9.741939356798373, 10.70879028402434, 11.664448420283895, 12.64670202837562, 13.711801735362705, 14.647325640198135, 15.62759430776582, 15.509663419183315, 14.5379193093733, 13.518153649601842, 12.53858050395992, 11.612079725437486, 10.676723817247039, 9.749273931193455, 8.815260119779204, 7.952196565326649, 8.757494944617427, 9.657190133888086, 8.748068374238677, 9.804144364102429, 10.689401848589258, 11.683478042312743, 12.609419971167739, 13.590690979746107, 14.526980103555676, 15.558081552361761, 15.444813469517236, 14.514975634296027, 13.485064357960361, 12.539074168544794, 11.642430795086867, 10.619310016173133, 9.778322220301403, 8.850695250792196, 7.840770137737033, 7.018898663783923, 7.804940411076892, 8.663180194401171, 9.61746519272832, 10.564212786714673, 11.58531534986276, 12.61539247632368, 13.64143231429049, 14.56979778062031, 15.559749870913464, 15.46175603205538, 14.543496473192631, 13.513397536185566, 12.613645399217555, 11.57391368077854, 10.596301360887718, 9.684521607164195, 8.76074943442896, 7.811005685260179, 6.820228565142259, 5.958413667326836, 6.879569977265378, 7.717335529137697, 10.548962803006114, 11.574065340284369, 12.567793365857101, 13.586897980609903, 14.613640075701394, 15.623683685652722, 15.58099123491042, 14.530384396580438, 13.477461777301952, 12.527821439209928, 11.588311516212205, 10.619694885271791, 9.588302675101934, 8.713848147537815, 7.756903694064935, 6.828945682451068, 5.866685530340007, 4.901872756001977, 5.840823699286555, 6.746527625004495, 11.556215140938086, 12.610263773769274, 13.536279005291284, 14.470390769713662, 15.526032608644286, 15.500546454832937, 14.530412267364508, 13.535613113580693, 12.520199263816567, 11.504421109484184, 10.571619231823945, 9.627043819558324, 8.66308455175938, 7.725363160555457, 6.7935162906458295, 5.873251518414309, 4.865012183993871, 3.8889050538707632, 4.823323308703858, 5.821169642593302, 12.608587822178974, 13.5801518390941, 14.521437639991978, 15.402989378485652, 15.702880701880478, 14.681417443008757, 13.612455129935526, 12.544134161785859, 11.594899057770684, 10.65412705083244, 9.603725209541915, 8.675880260124275, 7.715770423206218, 6.7921231849596015, 5.837936017617128, 4.948169461226158, 3.9724404302549776, 2.9438587096277065, 3.888081267563968, 4.912558307012184, 13.58814420426542, 14.56776457789443, 15.55171129386892, 15.820803518499355, 14.853891789637407, 13.815659488208617, 12.858280912129938, 11.828070913868931, 10.863317902056313, 9.822556690294235, 8.750653964846347, 7.704211517109309, 6.745266044316078, 5.788220769977501, 4.852423582393426, 3.8947259217867884, 3.041219119262661, 2.0119870597502794, 2.961435082040084, 3.8942317868632634, 14.568410598142536, 15.514503998481297, 16.010045307614515, 15.038804475350485, 14.011310877698895, 13.04146500954845, 12.060692008246336, 11.111682606494798, 10.043720706982487, 9.034454674323335, 7.983290734049554, 7.021426762148314, 6.044323894636212, 5.0597337332154835, 4.006792511231795, 2.961677689791174, 2.026931139849017, 0.9973635615794469, 2.062424610364429, 3.0209077213859064, 15.50921114044544, 16.137618143944376, 15.169662024588655, 14.2143191069779, 13.220330489343032, 12.154494121168968, 11.151245237116374, 10.122784500915627, 9.086460457433002, 8.109290408473992, 7.044246567867152, 6.053911209591682, 5.079566478149383, 4.0399228969307766, 3.029853156426258, 2.0028231572888373, 0.9913252476398864, 0.0, 1.005365642938387, 2.03284418172038, 16.55693371324329, 16.919645725353128, 15.863987986408743, 14.852335672043486, 13.894200269265838, 12.834600626137886, 11.773048105879802, 10.763508104669906, 9.692335262081526, 8.764184079602497, 7.763141867977865, 6.753271200320588, 5.773162366993302, 4.808478552407462, 3.8163601277648627, 2.870981048995087, 1.9415874506727597, 1.011951140191454, 2.0009963745184614, 2.9356708030843266, 17.534208409420895, 17.489781385491128, 16.552628072246886, 15.54580828214672, 14.491131126728996, 13.48828130956495, 12.545328132290166, 11.606432825102468, 10.669391551853533, 9.733624968445563, 8.704355746407252, 7.721433990178707, 6.733825172898424, 5.834493842556501, 4.823587451613124, 3.8041626301405613, 2.8822523677734324, 1.997104014740619, 2.946129110030585, 3.8992408976432635, 18.47024949351396, 17.76528665848067, 16.9700772821863, 16.534380131709206, 15.459571893307828, 14.425837042330786, 13.60455781463688, 12.570514408769471, 11.585141922334737, 10.606536813483, 9.650673817158804, 8.6980120848189, 7.662528144192566, 6.720772889236464, 5.767153279016263, 4.77815426009126, 3.9185706893821113, 3.0334701435406175, 3.9179671447782014, 4.850926545180114], [4.970626993385772, 4.104756871899944, 5.061586867344832, 5.964289332724707, 6.811160139329983, 7.71759758283463, 8.684959097402233, 9.5952357659427, 10.614465256191302, 11.553180008843015, 12.481919483366962, 13.439351546126069, 14.509147441201373, 15.519004912764549, 16.448310557970338, 17.405664893379935, 17.742158162589472, 16.77942967913604, 15.901522220882264, 16.65132112319395, 3.96816366623849, 4.89822010942495, 5.870860688917288, 6.811206499179362, 7.740314352836582, 8.657796909088558, 9.639735472289294, 10.664438964233348, 11.554229205537869, 12.480017085431914, 13.480164844701616, 14.374235014552621, 15.322429362498937, 16.327484361953367, 17.278130496586456, 17.869815476944886, 16.82987900877365, 15.798977255430131, 14.873902514636601, 15.632671782462442, 3.057323883359376, 4.057918514554728, 5.091147262218826, 6.091538672196809, 7.088930612127494, 8.060129546652252, 9.001749241685866, 10.04586038600602, 11.00467862256591, 12.045366174763652, 13.085015134975285, 14.09763369513541, 15.055242554435615, 15.9877519142079, 16.92905225892027, 16.880429094022873, 15.892422594995598, 14.85491947874381, 13.915407021561643, 14.673403997055361, 2.066832598975977, 3.1125884800710746, 4.153935898285612, 5.206337902727202, 6.135489107446825, 7.105424249128245, 8.061814196491717, 9.091447768516034, 10.075255739198928, 11.061384040535858, 12.018765111917237, 13.046405905032609, 14.069676371516852, 15.045415876447302, 16.017919304609638, 15.930740232210937, 14.881607986883397, 13.907524285224936, 12.98692293848534, 13.702660215835405, 3.0926327120241757, 4.105034494719483, 5.082873573805291, 6.146393011291643, 7.077088144990989, 8.004270707317268, 8.933948596890787, 9.972787881709998, 10.926643509838959, 11.900113052364707, 12.964814462978879, 13.968097656467533, 14.934614388692344, 15.87534825027481, 15.607025305709767, 14.880753167122718, 13.886123622216738, 12.975780720089759, 11.94454856350224, 12.751386796292834, 3.904896974139423, 4.9229720050590995, 5.9604038688640095, 6.962921589802443, 8.0350763575613, 9.017616610480584, 9.895663947269014, 10.928054493630324, 11.864811964820774, 12.86738278398585, 13.871257787425769, 14.815452866357587, 15.826827088549903, 15.56298125830621, 14.586621146996727, 13.830928691761958, 12.844721169372464, 11.939766281243525, 10.943418939949476, 11.693830059659906, 4.942644218403993, 5.882601078012797, 6.853795092731493, 7.872336721806709, 8.835330085562052, 9.884015869293613, 10.865929188886355, 11.917210327440792, 12.886816649240972, 13.853556252472611, 14.867334017767801, 15.760841480412127, 15.482472050716897, 14.539349308298384, 13.608040788113929, 12.760416518117152, 11.770142997359619, 10.906800813435725, 9.902131315515504, 10.72411676993386, 5.873272850384353, 6.879681256410006, 7.843013964713636, 8.881296674928915, 9.868556248597638, 10.808292510008437, 11.84776496113718, 12.874023280307684, 13.832307348743754, 14.848192541336166, 15.857942705137987, 15.495363410157672, 14.497208685872826, 13.559004051097713, 12.634472122146093, 11.690334142196106, 10.80342971405615, 9.90776123091389, 8.952515405868269, 9.735463851148845, 6.80569146277675, 7.833767804164185, 8.811076761592092, 9.77792768881806, 10.733585825077615, 11.71583943316934, 12.780939140156425, 13.716463044991855, 14.69673171255954, 15.720080141256798, 15.539755720133114, 14.50079471689556, 13.521221571253639, 12.594720792731204, 11.639980137721624, 10.71253025166804, 9.778516440253789, 8.915452885801235, 7.889910575014495, 8.767423123350135, 7.8583013637007255, 8.892347119535533, 9.758539253382978, 10.752615447106463, 11.678557375961457, 12.659828384539825, 13.596117508349394, 14.62721895715548, 15.616445398586837, 15.520341277234413, 14.490430000898748, 13.54443981148318, 12.647796438025253, 11.624675659111519, 10.741578540775988, 9.81395157126678, 8.804026458211618, 7.982154984258508, 6.93735604147396, 7.773413183863219, 8.727698182190366, 9.67444577617672, 10.695548339324807, 11.725625465785727, 12.72173507507852, 13.650100541408339, 14.628887275707182, 15.58817178946644, 15.548862116131017, 14.518763179123953, 13.619011042155941, 12.579279323716927, 11.601667003826105, 10.689887250102581, 9.724005754903544, 8.774262005734764, 7.783484885616844, 6.921669987801421, 6.011985607662446, 6.827568518599745, 9.65919579246816, 10.684298329746415, 11.678026355319147, 12.69713097007195, 13.72387306516344, 14.703986446440751, 15.630875568120215, 15.535750039518824, 14.482827420240339, 13.533187082148315, 12.593677159150591, 11.625060528210177, 10.59366831804032, 9.719213790476202, 8.762269337003321, 7.831451545099496, 6.829941850814592, 5.865129076476562, 4.973239329683623, 5.856760614466543, 10.666448130400134, 11.72049676323132, 12.64651199475333, 13.580623759175708, 14.636265598106332, 15.599608276166022, 15.535777910302894, 14.54097875651908, 13.525564906754953, 12.50978675242257, 11.576984874762331, 10.63240946249671, 9.668450194697767, 8.730728803493843, 7.798881933584216, 6.878617161352696, 5.828268504468456, 4.852161374345349, 3.955738939100926, 4.931402632055351, 11.718820811641022, 12.690384828556148, 13.631670629454025, 14.513222367947698, 15.518066201102986, 15.686783085947143, 14.617820772873912, 13.549499804724245, 12.60026470070907, 11.659492693770826, 10.609090852480302, 9.681245903062662, 8.721136066144604, 7.797488827897988, 6.843301660555515, 5.953535104164545, 4.966849125688471, 3.9071150301022923, 2.952441543458945, 3.976918582907161, 12.698377193727469, 13.677997567356478, 14.661944283330964, 15.584716003171996, 15.859257432575793, 14.821025131147003, 13.863646555068325, 12.833436556807317, 11.868683544994699, 10.827922333232621, 9.756019607784733, 8.709577160047695, 7.750631687254464, 6.793586412915888, 5.857789225331812, 4.900091564725176, 4.035627814696155, 2.9752433802248652, 2.0257953579350607, 2.9585920627582403, 13.678643587604585, 14.624736987943345, 15.686751028155744, 16.04417011828887, 15.016676520637281, 14.046830652486836, 13.066057651184723, 12.117048249433184, 11.049086349920874, 10.039820317261722, 8.98865637698794, 8.0267924050867, 7.049689537574598, 6.06509937615387, 5.012158154170181, 3.9670433327295607, 3.032296782787404, 2.002729204517834, 1.063363225312135, 2.0218463363336125, 14.619444129907489, 15.583876104819705, 16.17502766752704, 15.219684749916286, 14.225696132281419, 13.159859764107354, 12.15661088005476, 11.128150143854013, 10.091826100371389, 9.114656051412378, 8.049612210805538, 7.059276852530068, 6.084932121087769, 5.045288539869163, 4.035218799364644, 3.008188800227224, 1.9966908905782734, 1.005365642938387, 0.0, 1.027478538781993, 15.667166702705337, 16.635095292453144, 16.869353629347128, 15.857701314981872, 14.899565912204224, 13.839966269076273, 12.778413748818188, 11.768873747608293, 10.697700905019913, 9.769549722540884, 8.768507510916251, 7.758636843258975, 6.778528009931688, 5.813844195345848, 4.8217257707032495, 3.876346691933474, 2.9469530936111465, 2.017316783129841, 1.0500777907326244, 1.9847522192984899, 16.644441398882943, 17.645874381318706, 17.557993715185273, 16.551173925085106, 15.496496769667383, 14.493646952503337, 13.550693775228552, 12.611798468040854, 11.674757194791919, 10.738990611383949, 9.709721389345638, 8.726799633117095, 7.73919081583681, 6.8398594854948875, 5.82895309455151, 4.809528273078948, 3.8876180107118192, 3.002469657679006, 2.0664404239217706, 3.0178986593523316, 17.58048248297601, 16.897702288877735, 17.77047506530077, 17.539745774647592, 16.464937536246214, 15.431202685269172, 14.609923457575267, 13.575880051707857, 12.590507565273123, 11.611902456421387, 10.65603946009719, 9.703377727757289, 8.667893787130954, 7.726138532174851, 6.772518921954649, 5.783519903029647, 4.9239363323204985, 4.038835786479004, 3.038278458669387, 3.969584306889182], [3.999433935023264, 4.871582860612357, 5.862665238378527, 6.807683484365325, 7.731122180028996, 8.637559623533642, 9.604921138101245, 10.515197806641712, 11.534427296890314, 12.473142049542027, 13.401881524065974, 14.359313586825081, 15.429109481900385, 16.43896695346356, 17.36827259866935, 18.32562693407895, 18.547125903503087, 17.584397420049655, 16.706489961795874, 15.800585726329441, 2.9969706078759817, 3.927027051062442, 4.89966763055478, 5.840013440816854, 6.822395652558742, 7.825366693290759, 8.872884113575683, 9.91430517233423, 10.92914268474899, 11.93397648118831, 12.934124240458011, 13.926763703208678, 14.874958051154994, 15.880013050609424, 16.830659185242514, 17.80938539815935, 17.634846749687263, 16.603944996343746, 15.678870255550214, 14.781936385597934, 2.0516731688345455, 3.0428642921832685, 4.063668723436832, 5.064060133414816, 6.0614520733455, 7.032651007870258, 7.974270702903873, 9.018381847224026, 9.977200083783917, 11.017887635981658, 12.05753659619329, 13.070155156353415, 14.02776401565362, 14.960273375425905, 15.901573720138273, 16.91079063349989, 16.723572004588878, 15.659887219657422, 14.720374762475256, 13.822668600190854, 1.039354060193984, 2.0851099412890814, 3.1264573595036182, 4.178859363945208, 5.108010568664832, 6.077945710346252, 7.034335657709723, 8.063969229734038, 9.047777200416933, 10.033905501753862, 10.991286573135241, 12.018927366250614, 13.042197832734857, 14.017937337665307, 14.990440765827643, 15.961101771687956, 15.81512121748797, 14.807840171303313, 13.791890679398954, 12.851924818970897, 2.0846456612821456, 3.0775559559374894, 4.055395035023297, 5.118914472509649, 6.049609606208995, 6.976792168535274, 7.906470058108793, 8.945309342928004, 9.899164971056965, 10.872634513582714, 11.937335924196885, 12.94061911768554, 13.90713584991035, 14.847869711492816, 15.842462977846367, 15.814266397727293, 14.819636852821311, 13.876096606168137, 12.84486444958062, 11.900651399428327, 3.014916528363318, 4.032991559282995, 5.048445146163636, 6.050962867102069, 7.027157037782839, 7.99013807169859, 8.86818540848702, 9.90057595484833, 10.83733342603878, 11.839904245203856, 12.843779248643775, 13.787974327575593, 14.79934854976791, 15.783946086006399, 15.5201343776013, 14.764441922366533, 13.778234399977038, 12.840082167321905, 11.843734826027855, 10.843094662795398, 4.059108671842058, 4.996987772949552, 5.9681817876682475, 6.986723416743464, 7.949716780498807, 8.95738439669019, 9.844974064316345, 10.896255202870782, 11.865861524670962, 12.826077713690617, 13.839855478985807, 14.733362941630133, 15.74431066375171, 15.472862538902957, 14.541554018718502, 13.693929748721725, 12.703656227964192, 11.807116699514104, 10.802447201593884, 9.873381373069352, 4.989737303822418, 5.994067951346761, 6.957400659650391, 7.995683369865669, 8.982942943534393, 9.922679204945192, 10.906893899148354, 11.853068155737674, 12.811352224173744, 13.820714002554173, 14.830464166355993, 15.714670947818632, 15.4307219164774, 14.492517281702288, 13.567985352750666, 12.623847372800679, 11.736942944660724, 10.841274461518465, 9.886028636472844, 8.884728454284337, 5.922155916214814, 6.94815449910094, 7.925463456528847, 8.892314383754815, 9.84797252001437, 10.830226128106094, 11.88689402274078, 12.82241792757621, 13.802686595143895, 14.812109081577548, 15.830022898411672, 15.434307947500134, 14.454734801858212, 13.528234023335777, 12.573493368326197, 11.646043482272614, 10.712029670858362, 9.848966116405808, 8.82342380561907, 7.916687726485628, 6.975897852049145, 8.006733814472287, 8.872925948319732, 9.867002142043217, 10.792944070898212, 11.77421507947658, 12.710504203286149, 13.741605652092234, 14.730832093523592, 15.6606699287448, 15.517908539680741, 14.571918350265173, 13.654677039228545, 12.584679326027139, 11.675091771380561, 10.747464801871354, 9.737539688816192, 8.915668214863082, 7.870869272078535, 6.922677786998712, 7.87696278532586, 8.823710379312214, 9.844812942460301, 10.874890068921221, 11.836121770015275, 12.764487236345094, 13.743273970643937, 14.702558484403195, 15.721556962224831, 15.546241717905948, 14.646489580937937, 13.60675786249892, 12.629145542608098, 11.649890917018201, 10.65751898550812, 9.707775236339339, 8.716998116221419, 7.855183218405996, 6.945498838267021, 5.976833121735238, 8.808460395603655, 9.83356293288191, 10.827290958454642, 11.846395573207444, 12.859137263583058, 13.818373141377506, 14.74526226305697, 15.633930119878137, 15.510305959022334, 14.56066562093031, 13.621155697932586, 12.652539066992171, 11.621146856822314, 10.682136123374367, 9.719589542339422, 8.76496477570407, 7.763455081419167, 6.798642307081137, 5.906752560288198, 5.006025217602036, 9.815712733535626, 10.869761366366815, 11.795776597888825, 12.729888362311202, 13.785530201241826, 14.748872879301516, 15.719007066769946, 15.568457295301075, 14.553043445536948, 13.537265291204566, 12.604463413544327, 11.659888001278704, 10.69592873347976, 9.758207342275837, 8.774871018979248, 7.812623343919057, 6.761781735073031, 5.785674604949924, 4.889252169705501, 4.080667235190844, 10.868085414776514, 11.83964943169164, 12.780935232589519, 13.662486971083192, 14.66733080423848, 15.688794063110201, 15.645299311655908, 14.57697834350624, 13.627743239491066, 12.686971232552821, 11.636569391262297, 10.708724441844657, 9.748614604926598, 8.824967366679981, 7.870780199337508, 6.8933814001210925, 5.900362356293046, 4.840628260706867, 3.88595477406352, 3.1261831860426548, 11.84764179686296, 12.82726217049197, 13.81120888646646, 14.73398060630749, 15.637065789229583, 15.848503669928999, 14.89112509385032, 13.860915095589313, 12.896162083776694, 11.855400872014616, 10.783498146566728, 9.73705569882969, 8.778110226036459, 7.821064951697881, 6.885267764113806, 5.927570103507168, 4.96914104530073, 3.9087566108294403, 2.9593085885396357, 2.0686116169821354, 12.827908190740077, 13.774001591078838, 14.836015631291236, 15.692644554807565, 16.044155059419275, 15.074309191268828, 14.093536189966715, 13.144526788215176, 12.076564888702865, 11.067298856043715, 10.016134915769934, 9.054270943868694, 8.07716807635659, 7.092577914935863, 6.039636692952174, 4.994521871511553, 4.059775321569397, 3.030207743299827, 1.99687645591671, 1.0383933448952325, 13.768708733042981, 14.733140707955197, 15.701096827310918, 16.24716328869828, 15.253174671063414, 14.18733830288935, 13.184089418836756, 12.155628682636008, 11.119304639153384, 10.142134590194374, 9.077090749587532, 8.086755391312062, 7.112410659869763, 6.0727670786511565, 5.062697338146638, 4.035667339009217, 3.024169429360266, 2.03284418172038, 1.027478538781993, 0.0, 14.81643130584083, 15.784359895588636, 16.630898300715682, 16.777663355680886, 15.819527952903236, 14.759928309775285, 13.6983757895172, 12.688835788307305, 11.617662945718925, 10.689511763239896, 9.688469551615263, 8.678598883957987, 7.698490050630701, 6.733806236044861, 5.7416878114022625, 4.796308732632487, 3.8669151343101595, 2.937278823828854, 1.948233589501847, 1.0135591609359815, 15.793706002018435, 16.795138984454198, 17.58216247894521, 17.471135965784118, 16.416458810366397, 15.413608993202349, 14.470655815927564, 13.531760508739866, 12.594719235490931, 11.658952652082961, 10.629683430044652, 9.646761673816108, 8.659152856535824, 7.7598215261939005, 6.748915135250523, 5.729490313777961, 4.807580051410833, 3.913621317980959, 2.964596222690993, 2.046705600989823, 16.7297470861115, 17.702670029791346, 18.575442806214383, 18.459707815346608, 17.38489957694523, 16.351164725968186, 15.529885498274279, 14.49584209240687, 13.510469605972137, 12.5318644971204, 11.576001500796204, 10.623339768456301, 9.587855827829966, 8.646100572873863, 7.692480962653661, 6.70348194372866, 5.8438983730195115, 4.949987446780957, 3.9364342574386093, 2.998391248526673], [17.122822692494818, 17.68901223615352, 18.68009461391969, 18.48169654624774, 17.542179164649905, 16.491721006646173, 15.510645708928818, 14.544644217256913, 13.525414727008311, 12.586699974356598, 11.657960499832651, 10.777465237443483, 9.780963389214445, 8.817924182288195, 7.885102813910639, 6.893420521458306, 5.8420070667712185, 4.879278583317788, 3.919765757624469, 2.8519497459161895, 16.120359365347536, 16.744456426603605, 17.717097006095944, 17.93903633846913, 16.95665412672724, 15.953683085995223, 14.906165665710299, 13.864744606951753, 12.849907094536992, 11.845073298097672, 10.84492553882797, 9.852286076077304, 8.904091728130988, 7.899036728676559, 6.9483905940434685, 5.969664381126632, 4.929727912955395, 3.8988261596118785, 2.968764998526704, 1.9530304910570573, 15.11400570285238, 15.811424833132335, 16.75404769997511, 17.235447483731786, 16.238055543801103, 15.266856609276346, 14.220949071620314, 13.176837927300161, 12.21801969074027, 11.177332138542528, 10.109262033722354, 9.072073211618706, 8.040304031528251, 7.071036390149893, 6.129736045437524, 5.081910068122869, 4.01845316785701, 2.954768382925556, 2.0152559257433893, 0.9937627056499769, 14.101686594211818, 14.85367048223815, 15.816836336041897, 16.82471264683531, 16.8446792105903, 15.874744068908882, 14.918354121545411, 13.888720549521095, 12.9049125788382, 11.91878427750127, 10.961403206119893, 9.933762413004521, 8.910491946520278, 7.934752441589827, 6.962249013427491, 5.991588007567177, 4.938903021417155, 3.9246700149476625, 2.90447234729799, 1.9645064868699333, 13.056394993123657, 13.861224467589741, 14.839063546675549, 15.786029940197288, 16.688066619034867, 16.765582981546686, 15.835905091973167, 14.797065807153956, 13.843210179024995, 12.869740636499246, 11.805039225885075, 10.80175603239642, 9.83523930017161, 8.894505438589144, 7.899912172235593, 6.9360753129593675, 5.904281435772814, 4.856413580082839, 3.8612201549425436, 2.915779906412504, 11.99428526147533, 12.854046191271953, 13.87385445292383, 14.83654816319551, 15.710519187461022, 16.66007339436895, 16.797620442351395, 15.842544819288369, 14.78137863400681, 13.750702321617835, 12.746827318177916, 11.81165731441695, 10.800283092224634, 9.895718990975375, 8.920316330948634, 7.982419160921975, 6.923571359100874, 5.858697119789356, 4.8623497784953065, 3.9733366430454335, 10.950093117996591, 11.890049977605395, 12.856535718407612, 13.828260555996685, 14.744579711672912, 15.692827069377353, 16.674740388970097, 16.730693284032302, 15.76108696223212, 14.736875790104596, 13.723442810552424, 12.75704592847149, 11.745245206208434, 10.827284695360094, 9.895976175175639, 8.843273349747953, 7.819611599591088, 6.876785259216232, 5.872115761296012, 4.94304993277148, 10.019464486016231, 10.927602296416882, 11.831083623614335, 12.81930060287448, 13.711353548637328, 14.651089810048127, 15.69056226117687, 16.623970991091877, 16.714030772989744, 15.71411635226533, 14.70436618846351, 13.72816943224589, 12.730014707961043, 11.79181007318593, 10.728466189560187, 9.708683005863012, 8.761263086544144, 7.776977495988869, 6.821731670943247, 5.931702851556494, 9.087045873623834, 9.973515748662702, 10.863020826735879, 11.829871753961847, 12.785529890221401, 13.767783498313126, 14.746801506956917, 15.650609522827581, 16.630878190395265, 16.531626181690275, 15.51371236485615, 14.474751361618598, 13.495178215976676, 12.568677437454241, 11.61393678244466, 10.686486896391077, 9.786176360346506, 8.84381830936122, 7.884336501797022, 6.899743579355205, 8.033303937789503, 8.914936433291356, 9.915558334944993, 10.909634528668478, 11.852503859340738, 12.806426323225098, 13.742715447034668, 14.69606799598082, 15.685294437412178, 16.61513227263339, 16.424412645391378, 15.478422455975808, 14.538122908053328, 13.561447146718594, 12.612468936160058, 11.68484196665085, 10.757877885059289, 9.777116210903946, 8.836891035337558, 7.893753518842121, 7.023380669432833, 7.970128263419186, 8.991230826567273, 9.901653283665002, 10.8101910765846, 11.738556542914418, 12.737906442755365, 13.6398868791095, 14.658885356931137, 15.703609485837939, 16.683552275403592, 16.44358294374206, 15.55997166818539, 14.496235555727532, 13.649160105198735, 12.754444198636701, 11.778419457654064, 10.779931480191477, 9.762261469149072, 8.839598184105595, 6.091883059155038, 7.031209127445979, 7.971390127496113, 8.845200396422888, 9.787175583016817, 10.720318771687449, 11.735918150342332, 12.708515243634558, 13.686420323884326, 14.74395930532041, 15.670053137643164, 16.66358159206408, 16.474901773561584, 15.466909015353911, 14.68809695337657, 13.733472186741219, 12.731962492456315, 11.820304643245736, 10.801007747127894, 9.810406088238798, 5.025568008521471, 5.995010693961072, 7.0029044880619296, 7.8722640904426395, 8.815548752664265, 9.770090879004325, 10.718944806850999, 11.713743960634813, 12.72915781039894, 13.720558975594665, 14.653360853254904, 15.647249357411575, 16.61120862521052, 16.45539400233627, 15.65141402583817, 14.68916635077798, 13.644135789495637, 12.66802865937253, 11.733610404539435, 10.73576407064999, 3.973195327280584, 4.9447593441957105, 6.017745853361236, 6.93966548167065, 7.804818560299401, 8.81276571955149, 9.77367659842882, 10.827561785942198, 11.776796889957373, 12.717568896895617, 13.767970738186142, 14.695815687603782, 15.71387553520729, 16.767203222142463, 16.606994298866873, 15.58391320631577, 14.590894162487723, 13.613075003615586, 12.714725159246395, 11.690248119798179, 2.993638945194137, 4.031775435996881, 5.009160491213807, 5.8681718464463515, 6.835083575308299, 7.873315876737089, 8.830694452815768, 9.801718288246912, 10.76647130005953, 11.807232511821608, 12.879135237269496, 13.90726074400751, 14.866206216800743, 15.82325149113932, 16.759048678723396, 16.561733356527764, 15.52211547348004, 14.544946653493014, 13.64137134477028, 12.747819688858698, 2.01337255131702, 2.9594659516557806, 3.938267065682247, 4.909507897946276, 5.937001495597865, 6.906847363748311, 7.887620365050425, 8.836629766801964, 9.904591666314275, 10.913857698973427, 11.965021639247208, 12.926885611148448, 13.961248172582064, 14.945838334002792, 16.009084535487535, 17.054199356928155, 16.536403452893683, 15.559570151663847, 14.603803477393205, 13.7780379609456, 1.0725720090141155, 2.037003983926332, 3.0049601032820523, 3.9603030208928067, 4.954291638527673, 6.0201280067017375, 7.0233768907543315, 8.051837626955079, 9.088161670437703, 10.065331719396713, 11.130375560003554, 12.120710918279023, 13.095055649721322, 14.109573814692176, 15.088279703000998, 16.11530970213842, 17.02113140563278, 16.556933713243293, 15.667166702705341, 14.816431305840833, 0.0, 1.0437864367109948, 2.0994441756553806, 3.1110964900206373, 4.069231892798285, 5.128831535926236, 6.19038405618432, 7.199924057394215, 8.271096899982595, 9.199248082461624, 10.200290294086257, 11.210160961743533, 12.190269795070819, 13.154953609656658, 14.147072034299258, 15.092451113069034, 16.02184471139136, 16.951481021872667, 16.717244493437967, 15.829990466776815, 0.9772746961776054, 2.0002658556652646, 2.9374191689095066, 3.944238959009674, 4.998916114427396, 6.001765931591443, 6.944719108866227, 7.883614416053926, 8.820655689302862, 9.756422272710832, 10.829440197739123, 11.812361953967667, 12.799970771247951, 13.785707638628272, 14.843998110441989, 15.86342293191455, 16.824602537974876, 17.78808807901258, 17.733607126627113, 16.863136906830658, 1.9133157802706724, 2.938895736202965, 3.967986849450736, 4.984116359340247, 6.016434936657672, 6.939321664357278, 7.9978461097534, 8.84769599972093, 9.748234663906107, 10.71323339125367, 11.669096387577866, 12.718437935381516, 13.728673742542092, 14.784579717532772, 15.738199327752973, 16.727198346677977, 17.74224108326183, 18.722548675770874, 18.70544516137473, 17.814822554367506], [17.99920466858988, 17.011240707806053, 18.002323085572222, 17.492209779448036, 16.5526923978502, 15.502234239846468, 14.521158942129114, 13.555157450457209, 12.535927960208607, 11.597213207556894, 10.668473733032947, 9.787978470643779, 8.791476622414741, 7.892179187821579, 6.959357819444023, 5.967675526991689, 4.941034579668825, 3.978306096215394, 2.954349664798366, 3.895736182627185, 16.996741341442597, 16.06668489825614, 16.98454541254062, 17.924891222802692, 17.445404606832415, 16.442433566100398, 15.475935317016175, 14.490529421969935, 13.475691909555174, 12.524050284145794, 11.715501401820998, 10.72286193907033, 9.783799186312923, 8.82621439504278, 7.911158363307139, 6.932432150390302, 5.901082355391216, 4.942612596322872, 3.9819693710440283, 2.996816927768052, 16.05708485638392, 15.133653304784866, 15.932878482491732, 16.933269892469717, 17.281841980512098, 16.31064304598734, 15.264735508331308, 14.220624364011154, 13.261806127451264, 12.221118575253522, 11.153048470433347, 10.1158596483297, 9.084090468239244, 8.114822826860888, 7.173522482148519, 6.125696504833863, 5.0622396045680045, 3.9985548196365506, 3.0590423624543837, 2.0375491423609717, 15.044765747743357, 14.17589895389068, 14.995667118558519, 15.963137296431789, 16.667009556143277, 16.918530505619877, 15.962140558256406, 14.93250698623209, 13.948699015549195, 12.962570714212266, 12.005189642830887, 10.977548849715514, 9.954278383231271, 8.97853887830082, 8.006035450138485, 7.035374444278172, 5.982689458128149, 4.968456451658657, 3.948258784008985, 3.008292923580928, 13.999474146655196, 13.183452939242272, 14.01789432919217, 14.924454589793767, 15.68137616446607, 16.60855872679235, 16.87969152868416, 15.84085224386495, 14.886996615735988, 13.91352707321024, 12.848825662596068, 11.845542469107414, 10.879025736882603, 9.938291875300138, 8.943698608946587, 7.979861749670361, 6.948067872483808, 5.900200016793834, 4.871671437430263, 3.926231188900223, 12.937364415006869, 12.176274662924484, 13.024844218051832, 13.974972812791988, 14.703828732892225, 15.653382939800155, 16.6211896699098, 16.886331255999362, 15.825165070717803, 14.794488758328828, 13.79061375488891, 12.855443751127943, 11.844069528935627, 10.912388600994065, 9.936028489684581, 8.992870443409693, 7.9340226415885935, 6.869148402277075, 5.872801060983026, 4.942598828542381, 11.89317227152813, 11.212278449257926, 12.007525483535614, 12.966685205593164, 13.737889257104115, 14.686136614808555, 15.668049934401298, 16.561283053025864, 16.804873398943116, 15.78066222681559, 14.767229247263417, 13.800832365182483, 12.789031642919428, 11.796546880857042, 10.865238360672587, 9.812535535244901, 8.788873785088036, 7.84604744471318, 6.841377946792959, 5.912312118268427, 10.96254363954777, 10.215198270860718, 10.982073388742338, 11.957725252470958, 12.70466309406853, 13.64439935547933, 14.683871806608073, 15.604470100158974, 16.562754168595042, 16.683378537762277, 15.673628373960458, 14.697431617742838, 13.699276893457991, 12.761072258682878, 11.697728375057135, 10.67794519135996, 9.730525272041092, 8.746239681485816, 7.790993856440195, 6.899631441304298, 10.030125027155373, 9.261111723106538, 10.014010591863881, 10.968296403558325, 11.778839435652603, 12.761093043744328, 13.727300616024015, 14.631108631894678, 15.611377299462363, 16.590319166587772, 16.4829745503531, 15.444013547115546, 14.464440401473624, 13.537939622951189, 12.583198967941609, 11.655749081888025, 10.755438545843454, 9.813080494858168, 8.85359868729397, 7.867672169103009, 8.976383091321042, 8.202532407735191, 9.066548100072996, 9.921553865007665, 10.833867884768761, 11.786925432292197, 12.723214556101766, 13.676567105047917, 14.665793546479275, 15.595631381700484, 16.651985911186788, 16.447684641472755, 15.507385093550276, 14.530709332215542, 13.581731121657006, 12.654104152147799, 11.727140070556237, 10.746378396400894, 9.806153220834505, 8.861682108589925, 7.966459822964372, 7.2577242378630205, 8.029711437204345, 8.882152392732099, 9.790690185651698, 10.719055651981517, 11.718405551822464, 12.620385988176597, 13.639384465998234, 14.684108594905036, 15.664051384470689, 16.598299496637924, 16.52923385368234, 15.46549774122448, 14.618422290695683, 13.72370638413365, 12.747681643151012, 11.749193665688423, 10.731523654646018, 9.807526773853398, 7.034962212686577, 6.247871684293326, 6.973577528292722, 7.825699505489985, 8.767674692083915, 9.700817880754547, 10.71641725940943, 11.689014352701655, 12.666919432951422, 13.724458414387506, 14.65055224671026, 15.644080701131177, 16.516925857620166, 16.436171200850858, 15.657359138873518, 14.702734372238167, 13.701224677953263, 12.789566828742684, 11.770269932624842, 10.778334677986601, 5.96864716205301, 5.21167325080842, 6.005091888858539, 6.852763199509736, 7.796047861731362, 8.750589988071424, 9.699443915918096, 10.69424306970191, 11.709656919466036, 12.701058084661762, 13.633859962322001, 14.627748466478671, 15.591707734277614, 16.545917165604273, 16.620676211335116, 15.658428536274927, 14.61206437924344, 13.635957249120333, 12.701538994287239, 11.703692660397794, 4.916274480812122, 4.161421901043058, 5.019933254157845, 5.920164590737747, 6.785317669366498, 7.793264828618588, 8.754175707495916, 9.808060895009294, 10.75729599902447, 11.698068005962714, 12.748469847253238, 13.676314796670878, 14.694374644274387, 15.747702331209561, 16.701889498552035, 16.551841796063574, 15.558822752235526, 14.58100359336339, 13.682653748994198, 12.658176709545982, 3.9367180987256756, 3.1738091622427267, 3.9896596002809046, 4.848670955513449, 5.815582684375396, 6.853814985804187, 7.811193561882865, 8.782217397314009, 9.746970409126627, 10.787731620888705, 11.859634346336593, 12.887759853074607, 13.84670532586784, 14.803750600206417, 15.739547787790492, 16.69724544839713, 16.49004406322784, 15.512875243240817, 14.609299934518083, 13.715748278606501, 2.9564517048485586, 2.101499677901627, 2.9187661747493445, 3.8900070070133737, 4.917500604664964, 5.88734647281541, 6.868119474117523, 7.817128875869062, 8.885090775381371, 9.894356808040524, 10.945520748314305, 11.907384720215545, 12.94174728164916, 13.926337443069889, 14.98958364455463, 16.030377797929763, 17.012950861130918, 16.527498741411648, 15.571732067141008, 14.745966550693403, 2.0156511625456544, 1.0512191876334382, 1.98545921234915, 2.9408021299599043, 3.934790747594771, 5.000627115768836, 6.00387599982143, 7.032336736022177, 8.068660779504802, 9.045830828463812, 10.108318188503832, 11.098653546779301, 12.0729982782216, 13.065787377981183, 14.044493266290004, 15.071523265427425, 15.977344968921788, 16.919645725353128, 16.635095292453144, 15.784359895588636, 1.0437864367109948, 0.0, 1.0556577389443857, 2.0673100533096425, 3.0254454560872905, 4.085045099215241, 5.146597619473326, 6.1561376206832215, 7.227310463271602, 8.15546164575063, 9.156503857375263, 10.16637452503254, 11.146483358359825, 12.111167172945665, 13.103285597588265, 14.04866467635804, 14.978058274680368, 15.907694585161673, 16.89673981948868, 16.797919056524616, 2.0210611328886, 1.010779088865561, 1.947932402109803, 2.9547521922099698, 4.009429347627692, 5.012279164791739, 5.955232342066523, 6.894127649254222, 7.831168922503158, 8.766935505911128, 9.839953430939419, 10.822875187167963, 11.810484004448247, 12.796220871828568, 13.854511343642285, 14.873936165114847, 15.835115771175172, 16.798601312212877, 17.747626407502842, 17.831065496578457, 2.957102216981667, 1.958169596802894, 2.9872607100506654, 4.003390219940176, 5.026948169857968, 5.949834897557574, 7.008359342953696, 7.858209232921226, 8.758747897106403, 9.723746624453966, 10.679609620778162, 11.728951168581812, 12.739186975742388, 13.795092950733068, 14.748712560953269, 15.73771157987827, 16.752754316462127, 17.73306190897117, 18.07771912103661, 18.782751144115306], [18.66298079921762, 17.675016838433795, 16.96519349425621, 16.453089238338492, 15.513571856740658, 14.463113698736924, 13.48203840101957, 12.516036909347665, 11.496807419099063, 10.558092666447351, 9.629353191923403, 8.748857929534235, 7.752356081305197, 6.853058646712037, 5.92023727833448, 4.928554985882147, 3.9480038137368174, 2.9852753302833865, 3.831988067406577, 4.786083700700016, 17.66051747207034, 16.73046102888388, 15.92888767359623, 16.869233483858306, 16.40628406572287, 15.403313024990853, 14.436814775906631, 13.451408880860392, 12.43657136844563, 11.48492974303625, 10.676380860711454, 9.683741397960787, 8.744678645203377, 7.787093853933237, 6.872037822197596, 5.89331160928076, 4.908051589459209, 3.965727753989296, 4.85960777365224, 3.9573502684643227, 16.79802406660796, 15.79742943541261, 14.877220743547346, 15.87761215352533, 16.6299756167907, 16.369134598693357, 15.39910678352968, 14.397978395325772, 13.45874875400133, 12.533601529895275, 11.66731011209525, 10.630121289991601, 9.757035426076197, 8.78776778469784, 7.846467439985471, 6.923738379849523, 5.879101136223035, 4.909785530675618, 4.114700101398769, 3.0932068813053575, 15.885430965613521, 14.839675084518424, 13.940009379614132, 14.907479557487404, 15.611351817198889, 16.55572528552027, 16.33904182872383, 15.399759025051575, 14.433974374753458, 13.578549507165294, 12.708989873209775, 11.681349080094403, 10.705843327388887, 9.730103822458437, 8.844088247521771, 7.8734272416614575, 6.837303143714777, 5.823070137245285, 4.802872469595613, 3.8629066091675566, 14.846012551782241, 13.847229069870016, 12.962236590247784, 13.868796850849382, 14.625718425521683, 15.552900987847963, 16.48257887742148, 16.416335795513245, 15.462480167384282, 14.592040862477099, 13.619242460436945, 12.615959266948291, 11.64944253472348, 10.714677904177263, 9.798312294533215, 8.834475435256989, 7.802681558070436, 6.754813702380462, 5.718209842557309, 4.772769594027269, 13.783902820133914, 12.840050793552228, 11.969186479107446, 12.919315073847603, 13.648170993947838, 14.597725200855768, 15.565531930965413, 16.51475014566293, 16.4006486223661, 15.55931059409824, 14.561030552729786, 13.62586054896882, 12.614486326776504, 11.715891456563494, 10.782566894811628, 9.83940884853674, 8.78056104671564, 7.715686807404121, 6.719339466110072, 5.789137233669427, 12.739710676655175, 11.87605457988567, 10.951867744591228, 11.911027466648779, 12.682231518159728, 13.630478875864169, 14.612392195456911, 15.50562531408148, 16.460040240408283, 16.545484062585, 15.537646045104294, 14.57124916302336, 13.559448440760304, 12.643085285984087, 11.711776765799632, 10.659073940371947, 9.635412190215082, 8.692585849840226, 7.6879163519200056, 6.758850523395473, 11.809082044674815, 10.878974401488462, 9.926415649797951, 10.902067513526573, 11.649005355124144, 12.588741616534943, 13.628214067663686, 14.548812361214587, 15.507096429650657, 16.526056506666762, 16.519063286106842, 15.542866529889222, 14.544711805604376, 13.607610663809924, 12.54426678018418, 11.524483596487006, 10.577063677168137, 9.592778086612862, 8.637532261567241, 7.746169846431345, 10.876663432282418, 9.924887853734282, 8.958352852919495, 9.91263866461394, 10.723181696708217, 11.705435304799941, 12.671642877079629, 13.575450892950292, 14.555719560517977, 15.534661427643385, 16.55257524447751, 16.29055195224259, 15.31097880660067, 14.384478028078235, 13.429737373068654, 12.50228748701507, 11.6019769509705, 10.659618899985214, 9.700137092421016, 8.714210574230055, 9.822921496448087, 8.866308538362935, 8.01089036112861, 8.86589612606328, 9.778210145824374, 10.73126769334781, 11.66755681715738, 12.62090936610353, 13.610135807534888, 14.539973642756097, 15.596328172242403, 16.507802245459793, 16.35392349867732, 15.377247737342588, 14.428269526784051, 13.500642557274844, 12.573678475683282, 11.59291680152794, 10.652691625961552, 9.70822051371697, 8.812998228091418, 7.921500368490764, 6.974053698259959, 7.826494653787714, 8.735032446707311, 9.66339791303713, 10.662747812878079, 11.56472824923221, 12.583726727053847, 13.628450855960649, 14.608393645526302, 15.54264175769354, 16.469266804461565, 16.312036146351524, 15.464960695822729, 14.570244789260695, 13.594220048278057, 12.59573207081547, 11.578062059773066, 10.654065178980444, 7.881500617813623, 6.91164781492107, 5.917919789348337, 6.7700417665456, 7.712016953139528, 8.645160141810162, 9.660759520465046, 10.633356613757268, 11.611261694007036, 12.66880067544312, 13.594894507765874, 14.58842296218679, 15.46126811867578, 16.469260876883453, 16.503897544000566, 15.549272777365212, 14.547763083080309, 13.63610523386973, 12.616808337751888, 11.624873083113647, 6.815185567180056, 5.995179809941558, 4.949434149914153, 5.797105460565351, 6.740390122786977, 7.694932249127038, 8.643786176973709, 9.638585330757524, 10.65399918052165, 11.645400345717375, 12.578202223377614, 13.572090727534285, 14.536049995333228, 15.490259426659888, 16.53626053971114, 16.50496694140197, 15.458602784370486, 14.482495654247378, 13.548077399414284, 12.550231065524839, 5.7628128859391685, 4.962251372692541, 3.9642755152134592, 4.864506851793362, 5.7296599304221125, 6.737607089674202, 7.69851796855153, 8.752403156064908, 9.701638260080083, 10.642410267018327, 11.692812108308852, 12.620657057726492, 13.63871690533, 14.692044592265175, 15.646231759607648, 16.695031248892114, 16.405361157362574, 15.427541998490435, 14.529192154121244, 13.504715114673028, 4.783256503852722, 3.9746386338922104, 2.934001861336519, 3.7930132165690633, 4.759924945431011, 5.798157246859801, 6.755535822938479, 7.726559658369622, 8.69131267018224, 9.732073881944318, 10.803976607392206, 11.83210211413022, 12.791047586923453, 13.74809286126203, 14.683890048846106, 15.641587709452743, 16.681205592500465, 16.359413648367862, 15.455838339645128, 14.562286683733547, 3.802990109975605, 2.925122476017357, 1.8631084358049588, 2.834349268068988, 3.8618428657205777, 4.831688733871023, 5.8124617351731365, 6.761471136924675, 7.829433036436986, 8.838699069096137, 9.889863009369918, 10.851726981271158, 11.886089542704774, 12.870679704125502, 13.933925905610243, 14.974720058985374, 15.957293122186531, 16.86135154798819, 16.418270472268055, 15.592504955820448, 2.8621895676727007, 1.8977575927604846, 0.9298014734047642, 1.8851443910155186, 2.8791330086503852, 3.94496937682445, 4.948218260877043, 5.976678997077791, 7.013003040560415, 7.990173089519425, 9.052660449559445, 10.042995807834915, 11.017340539277214, 12.010129639036796, 12.988835527345618, 14.015865526483038, 14.921687229977401, 15.863987986408741, 16.869353629347128, 16.630898300715682, 2.0994441756553806, 1.0556577389443857, 0.0, 1.0116523143652567, 1.9697877171429048, 3.029387360270855, 4.090939880528939, 5.100479881738835, 6.171652724327215, 7.099803906806244, 8.100846118430876, 9.110716786088153, 10.090825619415439, 11.055509434001278, 12.047627858643878, 12.993006937413654, 13.922400535735981, 14.852036846217286, 15.841082080544293, 16.77575650911016, 2.911408650961431, 1.8884174914737724, 0.9512641782295305, 1.9580839683296976, 2.9703088065181493, 3.973158623682196, 4.916111800956981, 5.8550071081446795, 6.792048381393615, 7.727814964801585, 8.800832889829875, 9.78375464605842, 10.771363463338703, 11.757100330719025, 12.815390802532741, 13.834815624005303, 14.795995230065628, 15.759480771103332, 16.7085058663933, 17.661617654005976, 3.8474497350544983, 2.8358079994111054, 1.9942299441186577, 3.0103594540081686, 3.987827628748425, 4.910714356448032, 5.969238801844154, 6.819088691811682, 7.719627355996859, 8.684626083344423, 9.640489079668619, 10.689830627472269, 11.700066434632845, 12.755972409623524, 13.709592019843726, 14.698591038768727, 15.713633775352582, 16.693941367861623, 17.680343901140915, 18.613303301542825], [18.50744858589106, 17.49206488652411, 16.50098250875794, 15.441436923973239, 14.501919542375404, 13.45146138437167, 12.470386086654317, 11.504384594982412, 10.485155104733808, 9.546440352082096, 8.617700877558148, 7.737205615168978, 6.74070376693994, 5.84140633234678, 4.908584963969224, 3.91690267151689, 3.0631996432262154, 3.9969276446486433, 4.843640381771834, 5.797736015065273, 17.600230346526878, 17.668071248711072, 16.86649789342342, 16.094333434585963, 15.394631751357615, 14.3916607106256, 13.425162461541378, 12.439756566495136, 11.424919054080375, 10.473277428670993, 9.664728546346197, 8.67208908359553, 7.733026330838121, 6.77544153956798, 5.860385507832341, 4.8816592949155035, 4.023247418948607, 4.977380068354553, 5.871260088017497, 4.96900258282958, 16.836675858805787, 16.735039655239802, 15.814830963374538, 15.073878687617285, 15.785802761544314, 15.357482284328103, 14.387454469164426, 13.386326080960517, 12.447096439636075, 11.521949215530018, 10.655657797729992, 9.618468975626344, 8.745383111710941, 7.776115470332584, 6.834815125620215, 5.9120860654842655, 4.994296965712433, 5.921437845040876, 5.126352415764027, 4.104859195670614, 16.82304118544071, 15.777285304345614, 14.877619599441324, 14.063306702241018, 14.767178961952505, 15.711552430273885, 15.327389514358575, 14.38810671068632, 13.422322060388202, 12.566897192800036, 11.697337558844518, 10.669696765729146, 9.694191013023632, 8.718451508093182, 7.832435933156514, 6.8617749272962, 6.005111573824633, 6.834722451610542, 5.81452478396087, 4.874558923532813, 15.834038017032476, 14.784839289697207, 13.899846810074976, 13.024623995602996, 13.781545570275298, 14.708728132601578, 15.638406022175097, 15.404683481147986, 14.450827853019025, 13.580388548111841, 12.60759014607169, 11.604306952583036, 10.637790220358225, 9.703025589812007, 8.875598851660646, 7.911761992384419, 7.000595938491291, 7.766466016745719, 6.729862156922566, 5.784421908392527, 14.776762774346805, 13.777661013379419, 12.906796698934636, 12.075142218601217, 12.803998138701454, 13.753552345609384, 14.721359075719029, 15.670577290416544, 15.38899630800084, 14.547658279732984, 13.54937823836453, 12.614208234603565, 11.602834012411249, 10.70423914219824, 9.896003010373686, 8.961586467745178, 8.041998391335564, 8.727339121769377, 7.730991780475329, 6.800789548034684, 13.732570630868066, 12.81366479971286, 11.889477964418418, 11.066854611402393, 11.838058662913344, 12.786306020617785, 13.768219340210527, 14.661452458835095, 15.615867385161899, 15.533831748219745, 14.525993730739039, 13.559596848658105, 12.547796126395049, 11.760484078615999, 10.874583369256484, 10.032098641389986, 9.11657656334841, 9.704238164205483, 8.699568666285263, 7.770502837760731, 12.801941998887706, 11.816584621315652, 10.864025869625141, 10.057894658280187, 10.80483249987776, 11.744568761288559, 12.784041212417302, 13.704639505968203, 14.662923574404273, 15.681883651420376, 15.507410971741587, 14.531214215523967, 13.53305949123912, 12.78672360776911, 11.84815203522432, 11.030709765970746, 10.083289846651878, 10.604430400978119, 9.649184575932498, 8.757822160796602, 11.86952338649531, 10.862498073561472, 9.895963072746685, 9.068465809367554, 9.879008841461832, 10.861262449553557, 11.827470021833243, 12.731278037703907, 13.711546705271592, 14.690488572397001, 15.708402389231125, 15.549562417335268, 14.569989271693347, 13.751006866135619, 12.84264401964879, 12.008513656498812, 11.10820312045424, 11.67127121435047, 10.711789406786274, 9.725862888595312, 10.815781450660978, 9.803918758190125, 8.9485005809558, 8.021723270816894, 8.934037290577988, 9.887094838101424, 10.823383961910993, 11.776736510857146, 12.765962952288504, 13.695800787509713, 14.752155316996019, 15.663629390213407, 15.612933963769999, 14.743776575399972, 13.879906348376226, 13.006868726758585, 12.08269310249641, 12.604569115893197, 11.664343940326809, 10.719872828082227, 9.80585818230431, 8.859110588317956, 7.911663918087149, 6.982321798541328, 7.890859591460925, 8.819225057790744, 9.818574957631691, 10.720555393985826, 11.739553871807463, 12.784278000714265, 13.764220790279918, 14.698468902447154, 15.625093949215179, 15.67856498440891, 14.916597517414903, 14.076470958744435, 13.103234675091183, 13.607384385180728, 12.589714374138323, 11.665717493345701, 8.89315293217888, 7.84925803474826, 6.855530009175528, 5.925868911299214, 6.867844097893142, 7.8009872865637755, 8.816586665218658, 9.789183758510882, 10.76708883876065, 11.824627820196733, 12.750721652519488, 13.744250106940404, 14.617095263429395, 15.625088021637067, 15.957374105173436, 15.058287404178339, 14.056777709893435, 14.647757548234987, 13.628460652117145, 12.636525397478904, 7.8268378815453135, 6.932790029768748, 5.887044369741344, 4.952932605318965, 5.896217267540591, 6.850759393880652, 7.799613321727323, 8.794412475511137, 9.809826325275264, 10.801227490470989, 11.734029368131228, 12.727917872287899, 13.691877140086842, 14.646086571413502, 15.692087684464756, 16.013981568215097, 15.058451056239571, 15.494147968612635, 14.559729713779541, 13.561883379890096, 6.774465200304426, 5.973903687057798, 4.9759278295787155, 4.0203339965469755, 4.8854870751757264, 5.893434234427816, 6.854345113305144, 7.908230300818522, 8.857465404833697, 9.798237411771941, 10.848639253062466, 11.776484202480106, 12.794544050083614, 13.847871737018789, 14.767091191607525, 15.79271995642983, 16.00520942923166, 16.439194312855694, 15.540844468486501, 14.516367429038285, 5.794908818217979, 4.9862909482574675, 3.9456541757017756, 2.948840361322677, 3.9157520901846246, 4.953984391613415, 5.911362967692093, 6.882386803123236, 7.847139814935854, 8.887901026697932, 9.95980375214582, 10.929790821667938, 11.88873629446117, 12.845781568799747, 13.781578756383823, 14.73927641699046, 15.778894300038182, 16.83927873450947, 16.467490654010383, 15.573938998098804, 4.814642424340862, 3.9367747903826134, 2.8747607501702155, 1.9901764128226014, 3.017670010474191, 3.987515878624637, 4.96828887992675, 5.917298281678289, 6.9852601811906, 7.994526213849751, 8.987551716907635, 9.949415688808875, 10.98377825024249, 11.968368411663219, 12.98977910419112, 13.963067744620117, 14.945640807821274, 15.849699233622932, 16.914760282407915, 16.604157270185706, 3.8738418820379574, 2.9094099071257413, 1.9414537877700209, 1.0171663438323617, 2.0004856869189234, 3.066322055092988, 4.011263702268738, 5.039724438469485, 6.076048481952109, 7.053218530911119, 8.041008135194188, 9.031343493469658, 10.005688224911957, 10.998477324671539, 11.97718321298036, 13.004213212117781, 13.910034915612144, 14.852335672043484, 15.85770131498187, 16.777663355680883, 3.1110964900206373, 2.0673100533096425, 1.0116523143652567, 0.0, 0.9581354027776481, 2.0177350459055985, 3.079287566163683, 4.088827567373578, 5.160000409961958, 6.088151592440987, 7.089193804065619, 8.099064471722896, 9.079173305050181, 10.043857119636021, 11.035975544278621, 11.981354623048396, 12.910748221370724, 13.84038453185203, 14.829429766179036, 15.7641041947449, 3.9230609653266884, 2.900069805839029, 1.962916492594787, 0.9949918998766594, 1.9586564921528926, 2.961506309316939, 3.9044594865917235, 4.843354793779422, 5.780396067028358, 6.716162650436328, 7.789180575464618, 8.772102331693162, 9.759711148973446, 10.745448016353768, 11.803738488167484, 12.823163309640046, 13.784342915700371, 14.747828456738075, 15.696853552028042, 16.64996533964072, 4.859102049419755, 3.847460313776362, 3.0058822584839144, 2.056171379799695, 2.9761753143831684, 3.8990620420827744, 4.957586487478896, 5.807436377446425, 6.7079750416316015, 7.672973768979166, 8.628836765303364, 9.678178313107011, 10.688414120267588, 11.744320095258267, 12.697939705478468, 13.68693872440347, 14.701981460987325, 15.682289053496367, 16.668691586775658, 17.601650987177567], [17.54931318311341, 16.53392948374646, 15.542847105980288, 14.483301521195589, 13.543784139597754, 12.49332598159402, 11.512250683876667, 10.546249192204762, 9.52701970195616, 8.588304949304447, 7.6595654747805, 6.77907021239133, 5.782568364162292, 4.883270929569132, 3.9504495611915753, 2.958767268739242, 4.010180723426329, 4.955063047426291, 5.801775784549482, 6.755871417842921, 16.642094943749232, 17.331864950076266, 16.359224370583927, 15.418878560321852, 14.436496348579965, 13.43352530784795, 12.467027058763728, 11.481621163717488, 10.466783651302727, 9.515142025893347, 8.706593143568549, 7.713953680817882, 6.774890928060473, 5.817306136790332, 4.9022501050546925, 3.9235238921378555, 4.963460360309094, 5.935515471132201, 6.829395490795145, 5.927137985607228, 15.878540456028139, 16.87913508722349, 16.772966366152183, 15.887540289353508, 14.966440898849427, 14.399346881550454, 13.429319066386777, 12.428190678182869, 11.488961036858427, 10.563813812752372, 9.697522394952344, 8.660333572848696, 7.787247708933293, 6.817980067554936, 5.876679722842567, 4.953950662706617, 5.93450990707292, 6.879573247818524, 6.084487818541675, 5.062994598448262, 16.85888201309722, 16.735420707123264, 15.83575500221897, 14.876968303977241, 13.947817099257618, 14.892190567578998, 14.369254111580926, 13.429971307908671, 12.464186657610554, 11.60876179002239, 10.73920215606687, 9.711561362951498, 8.736055610245984, 7.760316105315534, 6.874300530378866, 5.903639524518552, 6.94532451518512, 7.79285785438819, 6.772660186738518, 5.832694326310461, 16.792173419810126, 15.742974692474855, 14.857982212852622, 13.892878841279758, 12.962183707580412, 13.889366269906692, 14.81904415948021, 14.44654807837034, 13.492692450241378, 12.622253145334195, 11.649454743294042, 10.646171549805388, 9.679654817580577, 8.74489018703436, 7.917463448882997, 6.953626589606771, 7.940808879851778, 8.724601419523367, 7.687997559700214, 6.742557311170175, 15.734898177124453, 14.735796416157067, 13.864932101712284, 12.989977771172624, 11.984636276006567, 12.934190482914497, 13.901997213024142, 14.764066389414578, 14.430860905223193, 13.589522876955337, 12.591242835586883, 11.656072831825917, 10.6446986096336, 9.74610373942059, 8.937867607596036, 8.00345106496753, 8.982211332696052, 9.685474524547027, 8.689127183252978, 7.758924950812332, 14.690706033645714, 13.771800202490509, 12.847613367196066, 11.9816901639738, 11.018696800218457, 11.966944157922898, 12.94885747751564, 13.75494155783313, 14.709356484159933, 14.575696345442099, 13.56785832796139, 12.601461445880457, 11.589660723617401, 10.80234867583835, 9.916447966478835, 9.073963238612336, 10.056789504708897, 10.662373566983131, 9.65770406906291, 8.728638240538379, 13.760077401665354, 12.7747200240933, 11.82216127240279, 10.98341792037259, 9.985470637182873, 10.925206898593672, 11.928920007502192, 12.798128604966237, 13.756412673402307, 14.775372750418411, 14.549275568963939, 13.573078812746319, 12.574924088461472, 11.82858820499146, 10.89001663244667, 10.144045614533383, 11.023502788012365, 11.562565803755767, 10.607319978710146, 9.715957563574252, 12.827658789272958, 11.82063347633912, 10.854098475524333, 10.0153051150265, 9.059646978766946, 9.994473669952761, 10.948919883909767, 11.824767136701942, 12.805035804269627, 13.783977671395036, 14.80189148822916, 14.59142701455762, 13.611853868915698, 12.792871463357969, 11.88450861687114, 11.121849505061448, 12.048416061814727, 12.629406617128119, 11.66992480956392, 10.683998291372962, 11.773916853438626, 10.762054160967773, 9.906635983733448, 8.979858673594542, 8.114675427883101, 9.016232070904904, 9.944833823987517, 10.870225609855181, 11.859452051286539, 12.789289886507747, 13.826101154664068, 14.725740482636535, 14.65479856099235, 13.785641172622322, 12.921770945598576, 12.120204575321221, 13.022906043856898, 13.562704518670845, 12.622479343104455, 11.678008230859877, 10.763993585081957, 9.817245991095604, 8.869799320864798, 7.940457201318976, 7.0714977287660385, 7.948362290594224, 8.91206405662973, 9.81404449298386, 10.833042970805497, 11.8723150095955, 12.838166627947967, 13.760579994870282, 14.687205041638308, 14.72042958163126, 13.958462114637253, 13.189806807307072, 14.043447616451672, 14.565519787958374, 13.54784977691597, 12.623852896123351, 9.851288334956529, 8.807393437525908, 7.813665411953176, 6.884004314076862, 6.0484822351982555, 6.894476385561812, 7.910075764216695, 8.882672857508918, 9.860577937758686, 10.886738912619862, 11.812832744942616, 12.806361199363533, 13.679206355852523, 14.687199114060196, 14.999238702395786, 14.210863509446416, 14.996990651253924, 15.605892951012633, 14.586596054894791, 13.594660800256554, 8.784973284322962, 7.890925432546396, 6.845179772518992, 5.911068008096613, 5.076855404845704, 5.944248492878688, 6.893102420725359, 7.887901574509174, 8.9033154242733, 9.863338582894118, 10.796140460554357, 11.790028964711027, 12.75398823250997, 13.70819766383663, 14.754198776887884, 15.166557673483176, 15.99866399760006, 16.452283371390287, 15.517865116557191, 14.520018782667746, 7.732600603082074, 6.932039089835446, 5.9340632323563645, 4.978469399324624, 4.06612521248084, 4.986923333425852, 5.947834212303181, 6.97034139324165, 7.919576497256825, 8.86034850419507, 9.910750345485594, 10.838595294903234, 11.856655142506742, 12.909982829441917, 13.808955788829877, 14.834584553652181, 15.751980208252851, 16.81301498160925, 16.49897987126415, 15.474502831815935, 6.753044220995627, 5.944426351035116, 4.903789578479424, 3.906975764100325, 3.0963902274897377, 4.047473490611451, 5.0048520666901295, 5.944497895546364, 6.909250907358983, 7.950012119121061, 9.021914844568949, 9.97165541889029, 10.930600891683522, 11.8876461660221, 12.823443353606175, 13.781141014212812, 14.820758897260534, 15.881143331731824, 16.830591354021628, 16.532074400876454, 5.77277782711851, 4.894910193160261, 3.8328961529478636, 2.9483118156002495, 2.07978110289732, 3.0496269710477657, 4.030399972349879, 4.979409374101418, 6.047371273613728, 7.056637306272879, 8.029416314129987, 8.991280286031227, 10.025642847464843, 11.01023300888557, 12.031643701413472, 13.00493234184247, 13.987505405043626, 14.891563830845282, 15.956624879630263, 16.857921297798466, 4.831977284815606, 3.8675453099033894, 2.899589190547669, 1.9753017466100098, 1.0423502841412753, 2.10818665231534, 3.0531282994910898, 4.081589035691837, 5.1179130791744605, 6.095083128133471, 7.082872732416541, 8.07320809069201, 9.047552822134309, 10.04034192189389, 11.019047810202713, 12.046077809340133, 12.951899512834496, 13.894200269265836, 14.899565912204222, 15.819527952903234, 4.069231892798285, 3.0254454560872905, 1.9697877171429048, 0.9581354027776481, 0.0, 1.0595996431279504, 2.121152163386035, 3.13069216459593, 4.20186500718431, 5.130016189663339, 6.131058401287971, 7.140929068945248, 8.121037902272533, 9.085721716858373, 10.077840141500973, 11.023219220270748, 11.952612818593076, 12.882249129074381, 13.871294363401388, 14.805968791967253, 4.881196368104336, 3.858205208616677, 2.921051895372435, 1.9531273026543075, 1.0005210893752445, 2.003370906539291, 2.9463240838140754, 3.8852193910017743, 4.8222606642507095, 5.75802724765868, 6.83104517268697, 7.813966928915515, 8.801575746195798, 9.78731261357612, 10.845603085389836, 11.865027906862398, 12.826207512922723, 13.789693053960427, 14.738718149250394, 15.691829936863073, 5.8172374521974035, 4.80559571655401, 3.9640176612615625, 3.0143067825773433, 2.0180399116055203, 2.9409266393051263, 3.9994510847012483, 4.849300974668777, 5.749839638853953, 6.714838366201518, 7.670701362525715, 8.720042910329365, 9.730278717489941, 10.786184692480619, 11.73980430270082, 12.728803321625822, 13.743846058209677, 14.72415365071872, 15.71055618399801, 16.64351558439992], [16.497986715219643, 15.482603015852693, 14.491520638086522, 13.431975053301823, 12.492457671703988, 11.441999513700255, 10.460924215982901, 9.494922724310996, 8.475693234062394, 7.536978481410681, 6.608239006886732, 5.7277437444975625, 4.731241896268524, 3.8395294124900787, 2.906708044112522, 3.864062379522122, 4.915475834209209, 5.8782043176626395, 6.861375427677432, 7.815471060970871, 15.590768475855464, 16.2805384821825, 15.307897902690161, 14.367552092428086, 13.385169880686199, 12.382198839954183, 11.415700590869962, 10.430294695823722, 9.41545718340896, 8.46381555799958, 7.655266675674781, 6.662627212924114, 5.723564460166705, 4.773564619711278, 3.914964204143849, 4.828819002920735, 5.868755471091973, 6.8586567413685495, 7.837960159039165, 6.9867376287351775, 14.818940812900188, 15.81953544409554, 16.317002698090114, 15.31661128811213, 14.319219348181445, 13.348020413656688, 12.37799259849301, 11.376864210289103, 10.437634568964661, 9.512487344858604, 8.646195927058578, 7.609007104954929, 6.761393705251193, 5.811992067592374, 4.889393821931724, 5.859245773489498, 6.839805017855799, 7.802714518054872, 7.144087461669626, 6.122594241576214, 15.799282369969267, 16.777289794989727, 16.79123420948185, 15.738832205040259, 14.809681000320635, 14.112832156778262, 13.31792764368716, 12.378644840014905, 11.412860189716788, 10.557435322128622, 9.687875688173103, 8.66023489505773, 7.730067610283422, 6.754328105352972, 5.924434693705877, 6.808934635301433, 7.850619625967998, 8.77866588382184, 7.832259829866468, 6.892293969438411, 16.84457397105743, 16.743670116879127, 15.818262179829128, 14.754742742342776, 13.82404760864343, 13.110007859105956, 13.967974356301065, 13.395221610476574, 12.441365982347612, 11.570926677440427, 10.5990650483947, 9.595781854906045, 8.673666817618015, 7.738902187071798, 6.973808890696879, 7.858921700389652, 8.846103990634656, 9.710409448957018, 8.747597202828164, 7.802156954298124, 16.754566871481014, 15.736491840561339, 14.854359393174075, 13.851841672235642, 12.846500177069585, 12.09666195594264, 13.006259005922837, 13.768327755742812, 13.379534437329427, 12.53819640906157, 11.54085314068754, 10.607204694086157, 9.638710609671039, 8.74011573945803, 7.994213049409919, 8.90874617575041, 9.88750644347893, 10.745074167674977, 9.748726826380928, 8.818524593940282, 15.712452486503585, 14.77249562689478, 13.837534834987219, 12.843554065036818, 11.880560701281475, 11.12941563095104, 12.029470350093513, 12.759202924161363, 13.713617850488166, 13.524369877548331, 12.518990190221631, 11.552593308140697, 10.58367272365484, 9.796360675875789, 8.972793408292718, 9.979258349395216, 10.962084615491776, 11.72197321011108, 10.71730371219086, 9.788237883666328, 14.812758847433324, 13.775415448497572, 12.812082740193942, 11.845281821435607, 10.84733453824589, 10.087678371621815, 10.967550515261504, 11.80238997129447, 12.76067403973054, 13.779634116746644, 13.510098070546816, 12.533901314329196, 11.56893608849891, 10.8226002050289, 9.946362074260554, 10.966145257957729, 11.913565177276597, 12.622165446883717, 11.666919621838096, 10.775557206702201, 13.880340235040928, 12.824034668001733, 11.844019943315486, 10.877169016089518, 9.921510879829963, 9.051107542857775, 9.987550391669078, 10.829028503030175, 11.80929717059786, 12.788239037723269, 13.806152854557393, 13.560026178671118, 12.605865868953137, 11.786883463395409, 10.940854058685023, 11.868303944738607, 12.802317756152858, 13.689006260256068, 12.72952445269187, 11.743597934500912, 12.833516496566576, 11.821653804095723, 10.913484853341865, 9.91940865961838, 8.97653932894612, 8.072865943809918, 8.983464331746829, 9.874486976183414, 10.863713417614772, 11.79355125283598, 12.803714664665037, 13.703353992637505, 13.648810561029789, 12.779653172659762, 11.97811638741246, 12.86665901499838, 13.776807738195028, 14.622304161798795, 13.682078986232405, 12.737607873987827, 11.823593228209907, 10.876845634223553, 9.929398963992748, 8.959401467795868, 7.933361629829057, 7.0049961634992375, 7.950694564389041, 8.818305859312094, 9.83730433713373, 10.84992851959647, 11.815780137948936, 12.738193504871251, 13.664818551639277, 13.7144415816687, 13.014807556451137, 13.93626124698423, 14.797349310789802, 15.625119431086324, 14.607449420043919, 13.6834525392513, 10.910887978084478, 9.866993080653858, 8.873265055081125, 7.943603957204812, 6.935851874195942, 5.951110258466825, 6.9487062719760075, 7.88693422383715, 8.864839304086917, 9.864352422620831, 10.790446254943586, 11.783974709364502, 12.656819865853493, 13.664812624061165, 14.05558414420967, 14.957317949123574, 15.750892345592053, 16.66549259414058, 15.64619569802274, 14.654260443384503, 9.844572927450912, 8.950525075674346, 7.904779415646941, 6.970667651224563, 5.96422504384339, 5.000882365783701, 5.8973637870535915, 6.892162940837405, 7.9075767906015315, 8.840952092895087, 9.773753970555326, 10.767642474711996, 11.73160174251094, 12.6858111738376, 13.704936418730627, 14.667184093790818, 15.639138938116986, 16.615246068240094, 16.57746475968514, 15.579618425795696, 8.792200246210024, 7.991638732963396, 6.993662875484314, 6.038069042452573, 5.0624508216867445, 4.043557206330865, 4.952095578631413, 5.9479549032426196, 6.8971900072577945, 7.837962014196038, 8.888363855486563, 9.816208804904203, 10.834268652507712, 11.878713162312321, 12.749356145701926, 13.77498491052423, 14.6923805651249, 15.7534153384813, 16.69763789641756, 16.534102474943886, 7.812643864123577, 7.004025994163065, 5.963389221607374, 4.966575407228275, 4.092715836695643, 3.104107363516464, 4.009113433018362, 4.9221114055473345, 5.886864417359952, 6.92762562912203, 7.999528354569918, 8.912055775762338, 9.87100124855557, 10.828046522894148, 11.763843710478223, 12.72154137108486, 13.761159254132583, 14.821543688603873, 15.770991710893677, 16.703788415716858, 6.83237747024646, 5.954509836288212, 4.8924957960758135, 4.007911458728199, 3.0761067121032246, 2.1062608439527786, 3.008013482350848, 3.9570228841023876, 5.0249847836146975, 6.034250816273849, 6.969816671002036, 7.931680642903276, 8.966043204336891, 9.95063336575762, 10.97204405828552, 11.945332698714518, 12.927905761915675, 13.831964187717332, 14.897025236502314, 15.798321654670517, 5.8915769279435555, 4.927144953031339, 3.9591888336756194, 3.03490138973796, 2.1019499272692257, 1.052569862644908, 1.9935286563631394, 3.0219893925638868, 4.058313436046511, 5.035483485005521, 6.0232730892885895, 7.013608447564059, 7.987953179006358, 8.98074227876594, 9.959448167074761, 10.986478166212182, 11.892299869706545, 12.834600626137885, 13.839966269076271, 14.759928309775283, 5.128831535926237, 4.085045099215241, 3.029387360270855, 2.0177350459055985, 1.0595996431279504, 0.0, 1.0615525202580842, 2.071092521467979, 3.1422653640563594, 4.070416546535388, 5.07145875816002, 6.081329425817296, 7.061438259144583, 8.026122073730422, 9.018240498373022, 9.963619577142797, 10.893013175465125, 11.82264948594643, 12.811694720273437, 13.746369148839301, 5.940796011232286, 4.917804851744627, 3.9806515385003856, 3.0095714112272907, 1.9548942558095685, 0.9520444386455221, 1.8949976159203068, 2.8338929231080057, 3.7709341963569414, 4.706700779764912, 5.779718704793202, 6.762640461021747, 7.7502492783020305, 8.735986145682352, 9.794276617496068, 10.81370143896863, 11.774881045028955, 12.73836658606666, 13.687391681356626, 14.640503468969305, 6.876837095325353, 5.86519535968196, 5.014272770679291, 3.9981432607897798, 2.9233350223884003, 1.8896001714113575, 2.9481246168074797, 3.797974506775009, 4.698513170960186, 5.663511898307751, 6.619374894631948, 7.6687164424355965, 8.678952249596172, 9.734858224586851, 10.688477834807053, 11.677476853732054, 12.692519590315909, 13.672827182824951, 14.659229716104242, 15.592189116506155], [15.590476330281504, 14.59803161282667, 13.6069492350605, 12.5474036502758, 11.607886268677966, 10.557428110674232, 9.576352812956879, 8.610351321284973, 7.5911218310363715, 6.652407078384659, 5.723667603860711, 4.843172341471541, 3.8466704932425024, 3.02808259089882, 3.9186130133059978, 4.875967348715597, 5.927380803402684, 6.890109286856115, 7.90902005969798, 8.863115692991418, 14.588013003134222, 15.395967079156478, 14.423326499664139, 13.482980689402064, 12.500598477660176, 11.49762743692816, 10.53112918784394, 9.5457232927977, 8.530885780382938, 7.579244154973558, 6.7706952726487595, 5.778055809898093, 4.838993057140684, 3.96211779812002, 4.91276393275311, 5.84072397211421, 6.880660440285448, 7.870561710562025, 8.84986512823264, 8.034382260755725, 13.757388292642103, 14.757982923837455, 15.432431295064092, 14.432039885086107, 13.434647945155422, 12.463449010630665, 11.493421195466988, 10.49229280726308, 9.553063165938639, 8.627915941832583, 7.761624524032556, 6.724435701928908, 5.876822302225172, 5.000545246001115, 5.887193550540985, 6.871150742682973, 7.851709987049274, 8.814619487248347, 8.205639981927709, 7.184146761834296, 14.737729849711183, 15.71573727473164, 16.34123453886724, 15.288832534425651, 14.359681329706028, 13.389746188024608, 12.433356240661137, 11.494073436988883, 10.528288786690766, 9.672863919102602, 8.803304285147082, 7.7756634920317085, 6.862388485143935, 5.942881283761713, 6.915384711924049, 7.820839604494908, 8.862524595161474, 9.790570853015316, 8.823463919768184, 7.883498059340127, 15.783021450799344, 16.70818328938005, 16.619094305151616, 15.555574867665266, 14.62487973396592, 13.8360997256165, 12.90642183604298, 12.510650207450551, 11.55679457932159, 10.686355274414407, 9.714493645368677, 8.711210451880023, 7.805987692478527, 6.927455365480538, 7.922048631834089, 8.870826669583128, 9.858008959828133, 10.722314418150493, 9.738801292729878, 8.79336104419984, 16.588540806839955, 16.53732396588383, 15.655191518496565, 14.652673797558132, 13.647332302392075, 12.881996947431034, 11.944706485664753, 12.706775235484725, 12.494963034303405, 11.653625006035549, 10.656281737661518, 9.722633291060134, 8.77103148453155, 7.92866891786677, 8.905029029176255, 9.848187075451143, 10.899411412672407, 11.736278257576691, 10.739930916282642, 9.809728683841996, 16.513284611826077, 15.57332775221727, 14.638366960309709, 13.644386190359308, 12.681392826603965, 11.914750622439435, 10.967917829835429, 11.697650403903276, 12.65206533023008, 12.63979847452231, 11.634418787195608, 10.668021905114674, 9.71599359851535, 8.98491385428453, 9.883609388059053, 10.918699249095951, 11.942360999252816, 12.713177300012795, 11.708507802092575, 10.779441973568042, 15.613590972755814, 14.576247573820062, 13.612914865516432, 12.646113946758097, 11.64816666356838, 10.873013363110209, 9.90599799500342, 10.740837451036384, 11.699121519472454, 12.718081596488558, 12.625526667520793, 11.649329911303173, 10.701256963359421, 10.011153383437641, 10.857178054026889, 11.876961237724064, 12.824381157042932, 13.61336953678543, 12.65812371173981, 11.766761296603915, 14.681172360363417, 13.624866793324223, 12.644852068637976, 11.678001141412008, 10.722343005152453, 9.836442534346169, 8.925997871410994, 9.767475982772089, 10.747744650339774, 11.726686517465183, 12.744600334299307, 12.675454775645095, 11.738186743813648, 10.975436641804151, 11.851670038451358, 12.779119924504942, 13.713133735919193, 14.678730001991248, 13.720728542593584, 12.734802024402626, 13.666143877794365, 12.654281185323512, 11.714316978664355, 10.72024078494087, 9.77737145426861, 8.858200935298312, 7.9219118114887435, 8.812934455925328, 9.802160897356686, 10.731998732577894, 11.742162144406954, 12.641801472379422, 12.7811314358903, 11.968206351068504, 12.888932367178795, 13.777474994764715, 14.687623717961364, 15.612027903533974, 14.641139170903044, 13.610505607764845, 12.656220609437696, 11.709473015451342, 10.762026345220537, 9.760233593118357, 8.734193755151548, 7.805828288821729, 6.889142044130956, 7.756753339054009, 8.775751816875644, 9.788375999338387, 10.754227617690853, 11.676640984613169, 12.603266031381194, 12.902994760077442, 13.895366691587524, 14.845110440756304, 15.708165290556138, 16.57543077582506, 15.557760764782653, 14.556350273028318, 11.767920612747508, 10.699620461881647, 9.705892436308915, 8.763426094609924, 7.7366839995184336, 6.751942383789316, 5.887153751717923, 6.825381703579065, 7.803286783828833, 8.802799902362748, 9.728893734685503, 10.72242218910642, 11.59526734559541, 12.603260103803082, 13.565806684838027, 14.520431451473378, 15.521941145758282, 16.556305532710862, 16.544723984649274, 15.527158177161521, 10.835777017352626, 9.783152456902137, 8.737406796874732, 7.803295032452354, 6.765057169165882, 5.801714491106193, 4.835811266795507, 5.830610420579321, 6.846024270343447, 7.779399572637004, 8.712201450297243, 9.706089954453914, 10.670049222252857, 11.624258653579517, 12.643383898472543, 13.605631573532733, 14.577586417858901, 15.553693547982009, 16.488111802815105, 16.452516159572713, 9.783404336111738, 8.982297440819085, 7.944152539690968, 6.870696423680365, 5.865852590525078, 4.844389331653357, 3.8905430583733285, 4.886402382984536, 5.835637486999712, 6.7764094939379556, 7.826811335228481, 8.75465628464612, 9.772716132249629, 10.817160642054237, 11.687803625443841, 12.713432390266146, 13.630828044866815, 14.691862818223216, 15.636085376159476, 16.660562415607693, 8.803847954025292, 7.994684702018755, 6.954047929463063, 5.880600684999688, 4.913688956137741, 3.904939488838956, 2.9475609127602773, 3.8605588852892505, 4.8253118971018685, 5.8660731088639455, 6.937975834311834, 7.850503255504255, 8.809448728297486, 9.766494002636064, 10.702291190220139, 11.659988850826776, 12.699606733874498, 13.759991168345788, 14.709439190635592, 15.642235895458771, 7.823581560148175, 6.945713926189928, 5.88369988597753, 4.924573429196913, 3.897079831545323, 2.927233963394877, 1.9464609620927642, 2.8954703638443036, 3.963432263356614, 4.972698296015765, 5.9082641507439515, 6.870128122645191, 7.904490684078807, 8.889080845499535, 9.910491538027436, 10.883780178456433, 11.86635324165759, 12.770411667459246, 13.835472716244228, 14.73676913441243, 6.882781017845271, 5.9183490429330545, 4.9503929235773345, 3.99505000596658, 3.0010613883317134, 1.935225020157649, 0.9319761361050551, 1.9604368723058028, 2.9967609157884265, 3.973930964747437, 4.961720569030505, 5.952055927305975, 6.926400658748274, 7.919189758507856, 8.897895646816677, 9.924925645954097, 10.83074734944846, 11.7730481058798, 12.778413748818187, 13.698375789517199, 6.190384056184319, 5.146597619473325, 4.090939880528939, 3.079287566163683, 2.121152163386035, 1.0615525202580842, 0.0, 1.0095400012098952, 2.080712843798275, 3.008864026277304, 4.0099062379019355, 5.019776905559212, 5.999885738886499, 6.964569553472338, 7.956687978114937, 8.902067056884713, 9.83146065520704, 10.761096965688346, 11.750142200015352, 12.684816628581217, 6.988440643252834, 5.965449483765175, 5.0282961705209335, 4.021476380420767, 2.966799225003044, 1.9639494078389976, 1.020996230564213, 1.9493215200819844, 2.88636279333092, 3.82212937673889, 4.895147301767182, 5.878069057995726, 6.86567787527601, 7.85141474265633, 8.909705214470048, 9.835248638030187, 10.772125572307713, 11.735611113345417, 12.684636208635384, 13.637747996248063, 7.924481727345901, 6.912839991702508, 6.026177739872766, 5.010048229983255, 3.9352399915818754, 2.901505140604833, 2.0802259129109277, 2.913403103748988, 3.8139417679341645, 4.778940495281729, 5.734803491605926, 6.784145039409575, 7.794380846570152, 8.85028682156083, 9.803906431781032, 10.792905450706034, 11.807948187289888, 12.771977242145416, 13.656474243383, 14.589433643784913], [14.580936329071609, 13.588491611616776, 12.597409233850605, 11.537863649065907, 10.598346267468072, 9.547888109464338, 8.566812811746985, 7.600811320075079, 6.581581829826476, 5.642867077174763, 4.714127602650815, 3.8336323402616457, 2.8371304920326073, 3.846987963595783, 4.776293608801573, 5.733647944211172, 6.785061398898259, 7.7477898823516895, 8.766700655193555, 9.720796288486993, 13.578473001924326, 14.386427077946584, 13.413786498454245, 12.47344068819217, 11.491058476450283, 10.488087435718267, 9.521589186634046, 8.536183291587804, 7.521345779173043, 6.569704153763662, 5.761155271438865, 4.768515808688198, 3.8294530559307884, 4.781023170816983, 5.731669305450073, 6.698404567609785, 7.738341035781023, 8.728242306057599, 9.707545723728215, 8.8920628562513, 12.747848291432208, 13.748442922627559, 14.422891293854198, 13.422499883876213, 12.425107943945529, 11.453909009420771, 10.483881194257094, 9.482752806053185, 8.543523164728743, 7.618375940622687, 6.752084522822662, 5.714895700719013, 4.867282301015277, 5.819450618698079, 6.706098923237948, 7.728831338178548, 8.709390582544849, 9.67230008274392, 9.215179983137602, 8.193686763044191, 13.728189848501287, 14.706197273521745, 15.331694537657349, 14.279292533215758, 13.350141328496134, 12.380206186814714, 11.423816239451243, 10.484533435778987, 9.51874878548087, 8.663323917892706, 7.793764283937186, 6.766123490821814, 5.85284848393404, 6.761786656458677, 7.734290084621013, 8.678520199990482, 9.72020519065705, 10.648251448510889, 9.83300392097808, 8.893038060550023, 14.773481449589449, 15.698643288170153, 16.249849743649865, 15.186330306163514, 14.255635172464167, 13.328452610137887, 12.398774720564369, 11.501110206240655, 10.547254578111694, 9.676815273204511, 8.704953644158783, 7.701670450670128, 6.796447691268632, 7.737181552851099, 8.731774819204649, 9.695611678480875, 10.715689555323708, 11.579995013646066, 10.748341293939776, 9.802901045409737, 15.579000805630061, 16.597075836549738, 16.64442606857013, 15.641908347631697, 14.63656685246564, 13.83369040991049, 12.865883679800845, 11.850950413424291, 11.48542303309351, 10.644085004825653, 9.646741736451624, 8.713093289850239, 7.761491483321655, 8.73839510523733, 9.714755216546815, 10.657913262821703, 11.716761064642803, 12.6160094524923, 11.74947091749254, 10.819268685051892, 16.616748049894632, 16.562562302290836, 15.627601510383274, 14.633620740432873, 13.67062737667753, 12.871008343564263, 11.889095023971521, 10.841825581842842, 11.796240508169646, 11.630258473312415, 10.624878785985713, 9.658481903904779, 8.706453597305456, 9.730745143847766, 10.662053664032221, 11.714756489459907, 12.738418239616772, 13.66898447463581, 12.71804780330247, 11.788981974777938, 16.60282552282938, 15.565482123893627, 14.602149415589997, 13.635348496831663, 12.637401213641946, 11.844084349732086, 10.827175189139512, 9.88501262897595, 10.84329669741202, 11.862256774428126, 11.615986666310897, 10.639789910093278, 9.691716962149528, 10.62992159692464, 11.635622330000057, 12.655405513697232, 13.6028254330161, 14.587111023571376, 13.667663712949706, 12.769407352967612, 15.670406910436983, 14.614101343397788, 13.63408661871154, 12.667235691485573, 11.711577555226018, 10.807513520968046, 9.847175065547086, 8.911651160711656, 9.891919828279342, 10.87086169540475, 11.886232842390381, 11.6659147744352, 10.728646742603754, 11.59420485529115, 12.54894551030073, 13.476395396354313, 14.410409207768565, 15.37600547384062, 14.73026854380348, 13.737448080766322, 14.65537842786793, 13.643515735397077, 12.70355152873792, 11.709475335014435, 10.766606004342176, 9.829271921920189, 8.89298279811062, 7.957109633864896, 8.946336075296253, 9.876173910517462, 10.833377890977442, 11.707931008271988, 11.771591434680406, 12.586974564555502, 13.586207839028166, 14.474750466614086, 15.384899189810735, 16.309303375383347, 15.630373720976609, 14.59974015783841, 13.645455159511261, 12.698707565524908, 11.751260895294102, 10.749468143191923, 9.723428305225113, 8.795062838895294, 7.860213030752832, 6.9009285169935755, 7.919926994815211, 8.879591745908874, 9.84544336426134, 10.742770520505735, 11.650944043659232, 12.6216115757075, 13.613983507217581, 14.563727256386361, 15.506838465446755, 16.571756555789758, 16.54699531485622, 15.545584823101883, 12.757155162821073, 11.688855011955212, 10.69512698638248, 9.752660644683491, 8.725918549592, 7.741176933862882, 6.876388301791489, 5.969556881518632, 6.947461961768401, 7.894015648933236, 8.82010948125599, 9.788551724998985, 10.642945357873447, 11.65093811608112, 12.597231300681754, 13.5517857363596, 14.553295430644503, 15.557121248903329, 16.496072192187906, 16.516392727235086, 11.838423073716323, 10.772387006975702, 9.726641346948297, 8.792529582525919, 7.754291719239448, 6.790949041179759, 5.825045816869073, 4.974785598518888, 5.990199448283015, 6.8706153192074915, 7.80341719686773, 8.764065667117121, 9.717727234530894, 10.671936665857555, 11.633843897262649, 12.59609157232284, 13.568046416649008, 14.544153546772115, 15.47857180160521, 16.476418135494654, 10.792944337321634, 9.97153199089265, 8.933387089764533, 7.85993097375393, 6.855087140598643, 5.833623881726923, 4.8797776084468945, 3.9776181295550233, 4.926853233570199, 5.867625240508443, 6.889859714962743, 7.812631997309328, 8.770413105977731, 9.807620640844343, 10.678263624233947, 11.703892389056252, 12.621288043656921, 13.682322817013322, 14.626545374949583, 15.651022414397799, 9.813387955235187, 8.98391925209232, 7.943282479536629, 6.869835235073254, 5.902923506211307, 4.894174038912522, 3.9367954628338433, 2.9517746318597378, 3.9165276436723557, 4.957288855434433, 5.960584185961035, 6.840963254294361, 7.799908727087592, 8.75695400142617, 9.692751189010245, 10.650448849616883, 11.690066732664604, 12.750451167135894, 13.699899189425699, 14.632695894248878, 8.833121561358071, 7.947062851746906, 6.885048811534507, 5.913807979270478, 4.886314381618889, 3.916468513468443, 2.93569551216633, 1.9866861104147908, 3.0183860614191085, 4.02765209407826, 4.898724149534058, 5.860588121435297, 6.894950682868913, 7.879540844289641, 8.90095153681754, 9.874240177246538, 10.856813240447694, 11.76087166624935, 12.825932715034332, 13.727229133202535, 7.892321019055166, 6.92788904414295, 5.95993292478723, 5.004590007176476, 4.010601389541609, 2.9447650213675445, 1.9415161373149503, 0.989749991568753, 2.026074035051377, 3.003244084010387, 3.952180567820611, 4.94251592609608, 5.916860657538379, 6.909649757297961, 7.888355645606782, 8.915385644744202, 9.821207348238564, 10.763508104669905, 11.768873747608291, 12.688835788307303, 7.199924057394215, 6.156137620683221, 5.100479881738835, 4.088827567373578, 3.1306921645959296, 2.071092521467979, 1.0095400012098952, 0.0, 1.07117284258838, 1.9993240250674091, 3.000366236692041, 4.010236904349317, 4.990345737676604, 5.9550295522624435, 6.947147976905042, 7.892527055674818, 8.821920653997145, 9.75155696447845, 10.740602198805457, 11.675276627371321, 7.846121238748409, 6.82313007926075, 5.885976766016508, 4.879156975916342, 3.824479820498619, 2.8216300033345725, 1.8786768260597877, 0.9397815188720892, 1.876822792121025, 2.812589375528995, 3.885607300557286, 4.868529056785831, 5.856137874066114, 6.841874741446435, 7.900165213260151, 8.825708636820291, 9.762585571097818, 10.726071112135521, 11.675096207425488, 12.628207995038167, 8.782162322841476, 7.7705205871980825, 6.883858335368341, 5.86772882547883, 4.79292058707745, 3.7591857361004077, 2.937906508406502, 1.9038631025390926, 2.8044017667242693, 3.7694004940718338, 4.72526349039603, 5.774605038199679, 6.7848408453602564, 7.840746820350935, 8.794366430571136, 9.783365449496138, 10.798408186079993, 11.76243724093552, 12.646934242173105, 13.579893642575017], [13.509763486483228, 12.642239812815282, 11.682411929643704, 10.622866344859005, 9.683348963261171, 8.632890805257437, 7.651815507540084, 6.6858140158681785, 5.666584525619576, 4.727869772967863, 3.799130298443915, 2.9482779920037046, 3.8258586902725376, 4.835716161835713, 5.765021807041503, 6.722376142451102, 7.773789597138189, 8.73651808059162, 9.755428853433484, 10.709524486726922, 12.507300159335946, 13.437356602522406, 12.498789194247344, 11.558443383985269, 10.576061172243381, 9.573090131511366, 8.606591882427145, 7.621185987380904, 6.6063484749661425, 5.654706849556762, 4.869015127489453, 3.8831614604302565, 4.818181254170718, 5.769751369056913, 6.720397503690004, 7.687132765849715, 8.727069234020954, 9.71697050429753, 10.696273921968146, 9.88079105449123, 11.676675448843827, 12.677270080039179, 13.507893989647297, 12.507502579669312, 11.510110639738627, 10.53891170521387, 9.568883890050193, 8.567755501846285, 7.628525860521843, 6.703378636415787, 5.86673017456472, 4.829541352461071, 5.8560104992552064, 6.808178816938009, 7.6948271214778785, 8.717559536418477, 9.69811878078478, 10.661028280983851, 10.286352825725984, 9.264859605632573, 12.657017005912907, 13.635024430933365, 14.416697233450446, 13.364295229008857, 12.435144024289233, 11.465208882607813, 10.508818935244342, 9.569536131572088, 8.60375148127397, 7.748326613685805, 6.908409935679244, 5.880769142563872, 6.84157668217397, 7.750514854698606, 8.723018282860941, 9.667248398230411, 10.70893338889698, 11.63697964675082, 10.904176763566458, 9.964210903138401, 13.702308607001068, 14.627470445581773, 15.334852439442964, 14.271333001956611, 13.340637868257264, 12.413455305930986, 11.483777416357468, 10.586112902033756, 9.632257273904795, 8.76181796899761, 7.81959929590084, 6.816316102412186, 7.782832834636997, 8.723566696219462, 9.718159962573013, 10.68199682184924, 11.70441775356364, 12.568723211885997, 11.819514136528154, 10.874073887998115, 14.50782796304168, 15.525902993961358, 16.223332499896824, 15.22081477895839, 14.318185299831109, 13.41329949684534, 12.445492766735695, 11.631591914168169, 10.57042572888661, 9.729087700618752, 8.76138738819368, 7.8277389415922976, 8.74787662669002, 9.724780248605693, 10.701140359915177, 11.644298406190066, 12.703146208011166, 13.604737650732229, 12.820643760080918, 11.89044152764027, 15.545575207306252, 16.485532066915056, 16.698774352971657, 15.704793583021255, 14.741800219265912, 13.906393196327041, 12.9244798767343, 11.87721043460562, 11.11194358861261, 10.715261169105514, 9.739524437727772, 8.773127555646838, 9.692838740673821, 10.717130287216131, 11.648438807400586, 12.701141632828271, 13.724803382985137, 14.65771267287574, 13.789220645890849, 12.860154817366316, 16.357276102993506, 16.63665496648201, 15.673322258178379, 14.706521339420044, 13.708574056230328, 12.879469202494866, 11.86256004190229, 10.920397481738728, 10.158999777854984, 10.989921235180962, 10.730632318052956, 9.754435561835336, 10.678102105517892, 11.616306740293005, 12.622007473368422, 13.641790657065597, 14.589210576384465, 15.57349616693974, 14.738836555538084, 13.840580195555994, 16.741579753025366, 15.68527418598617, 14.705259461299923, 13.738408534073955, 12.7827503978144, 11.842898373730826, 10.882559918309864, 9.947036013474435, 9.156891528201612, 9.998526156157586, 10.869396540179043, 10.780560426177258, 11.715031885972119, 12.580589998659516, 13.535330653669096, 14.46278053972268, 15.396794351136931, 16.362390617208984, 15.801441386391858, 14.808620923354704, 15.726551270456312, 14.71468857798546, 13.774724371326302, 12.780648177602817, 11.837778846930558, 10.864656774682969, 9.9283676508734, 8.992494486627674, 8.210506987731371, 9.003838371270298, 9.816541588766103, 10.636758165683608, 11.62590063527, 12.485227142128057, 13.48664748025735, 14.414274449766557, 15.42419956282172, 16.404961236977062, 16.70154656356499, 15.670913000426792, 14.716628002099643, 13.76988040811329, 12.822433737882484, 11.820640985780305, 10.794601147813495, 9.866235681483676, 8.895597883515611, 7.936313369756355, 7.156484956727709, 8.002260273159838, 8.828607062050002, 9.671597677917354, 10.579771201070852, 11.550438733119119, 12.5428106646292, 13.49255441379798, 14.435665622858375, 15.500583713201378, 16.463645627578348, 16.616757665690265, 13.828328005409455, 12.760027854543594, 11.766299828970862, 10.823833487271871, 9.79709139218038, 8.812349776451263, 7.947561144379869, 7.004941734281411, 6.090450260837032, 7.0166841761841985, 7.803273179044652, 8.717378882410605, 9.571772515285067, 10.57976527349274, 11.526058458093374, 12.48061289377122, 13.482122588056123, 14.485948406314948, 15.424899349599526, 16.330603275317465, 12.909595916304704, 11.843559849564084, 10.797814189536679, 9.863702425114301, 8.825464561827829, 7.862121883768139, 6.896218659457453, 6.010170451281667, 5.133187747351646, 5.993283846458454, 6.7865808946563915, 7.692892824528742, 8.646554391942514, 9.600763823269174, 10.562671054674269, 11.524918729734459, 12.496873574060627, 13.472980704183735, 14.40739895901683, 15.405245292906274, 11.864117179910012, 11.042704833481032, 10.004559932352915, 8.931103816342311, 7.926259983187023, 6.904796724315303, 5.950950451035275, 5.013002982317802, 4.063767878302627, 4.990293767759406, 5.8186868723743626, 6.741459154720948, 7.699240263389351, 8.736447798255961, 9.607090781645567, 10.632719546467872, 11.550115201068541, 12.611149974424942, 13.555372532361202, 14.579849571809419, 10.884560797823566, 10.0550920946807, 9.01445532212501, 7.9410080776616345, 6.974096348799687, 5.965346881500902, 5.0079683054222235, 4.001004034819708, 3.0362510230070905, 4.060333786866268, 4.889411343372655, 5.769790411705981, 6.728735884499212, 7.685781158837789, 8.621578346421865, 9.579276007028502, 10.618893890076224, 11.679278324547514, 12.628726346837318, 13.561523051660497, 9.90429440394645, 9.018235694335285, 7.956221654122888, 6.9849808218588585, 5.957487224207269, 4.987641356056823, 4.00686835475471, 3.0578589530031706, 2.060540990656061, 3.036224499767083, 3.8275513069456775, 4.789415278846917, 5.823777840280533, 6.808368001701261, 7.829778694229161, 8.80306733465816, 9.785640397859314, 10.689698823660972, 11.754759872445954, 12.656056290614156, 8.963493861643546, 7.9990618867313295, 7.031105767375609, 6.075762849764855, 5.081774232129988, 4.015937863955924, 3.01268897990333, 2.060922834157133, 1.0682289642883291, 1.985405731511726, 2.8810077252322306, 3.8713430835077, 4.845687814949999, 5.838476914709581, 6.817182803018402, 7.844212802155822, 8.750034505650184, 9.692335262081524, 10.69770090501991, 11.617662945718923, 8.271096899982595, 7.227310463271601, 6.171652724327215, 5.160000409961958, 4.20186500718431, 3.1422653640563594, 2.080712843798275, 1.07117284258838, 0.0, 0.9281511824790291, 1.929193394103661, 2.939064061760937, 3.9191728950882236, 4.883856709674063, 5.875975134316662, 6.821354213086438, 7.750747811408765, 8.68038412189007, 9.669429356217076, 10.604103784782941, 8.834849436988339, 7.81185827750068, 6.874704964256439, 5.867885174156272, 4.81320801873855, 3.810358201574503, 2.8674050242997184, 1.9285097171120196, 0.9914684438630839, 1.8975920713220948, 2.9180248403662206, 3.9009465965947654, 4.879835700993346, 5.865572568373667, 6.886832495506428, 7.754535794231912, 8.691412728509437, 9.654898269547141, 10.603923364837108, 11.557035152449787, 9.770890521081405, 8.759248785438013, 7.8725865336082705, 6.85645702371876, 5.781648785317381, 4.747913934340338, 3.926634706646433, 2.892591300779023, 1.9190474184663282, 2.8544031898649336, 3.8102661861891303, 4.859607733992779, 5.808538672287488, 6.864444647278167, 7.818064257498367, 8.72852742418261, 9.727731050118116, 10.69126439834714, 11.575761399584724, 12.508720799986637], [12.5816123040042, 11.714088630336253, 10.754260747164675, 9.694715162379977, 8.755197780782142, 7.704739622778408, 6.723664325061055, 5.7576628333891495, 4.738433343140547, 3.799718590488834, 2.870979115964886, 3.828411178723993, 4.73959771866049, 5.7494551902236655, 6.678760835429455, 7.636115170839054, 8.687528625526141, 9.650257108979572, 10.669167881821437, 11.623263515114875, 11.579148976856917, 12.509205420043378, 11.570638011768315, 10.63029220150624, 9.647909989764353, 8.644938949032337, 7.678440699948116, 6.693034804901875, 5.678197292487114, 4.726555667077733, 3.9408639450104235, 4.763294647150545, 5.71148899509686, 6.683490397444865, 7.634136532077956, 8.600871794237667, 9.640808262408905, 10.630709532685481, 11.610012950356097, 10.794530082879184, 10.7485242663648, 11.749118897560152, 12.579742807168268, 11.579351397190283, 10.581959457259599, 9.610760522734841, 8.640732707571164, 7.639604319367256, 6.700374678042814, 5.775227453936758, 4.997726214625221, 5.70967453918136, 6.741443719271814, 7.710711360650171, 8.60856614986583, 9.63129856480643, 10.611857809172731, 11.574767309371802, 11.214504008205015, 10.193010788111604, 11.72886582343388, 12.706873248454338, 13.488546050971419, 12.436144046529828, 11.506992841810204, 10.537057700128784, 9.580667752765313, 8.641384949093057, 7.675600298794941, 6.820175431206776, 6.06397623768327, 6.760902329284161, 7.727009902190577, 8.653047398410768, 9.625550826573104, 10.580987426618364, 11.622672417284932, 12.550718675138771, 11.832327946045488, 10.892362085617432, 12.774157424522041, 13.699319263102746, 14.406701256963936, 13.343181819477584, 12.412486685778237, 11.485304123451957, 10.555626233878439, 9.657961719554725, 8.704106091425764, 7.833666786518581, 7.036638650837884, 7.696449289132475, 8.662966021357285, 9.60369988293975, 10.598293149293301, 11.562130008569527, 12.59392388575608, 13.482462240273948, 12.747665319007185, 11.802225070477146, 13.57967678056265, 14.597751811482327, 15.295181317417796, 14.292663596479363, 13.390034117352082, 12.485148314366311, 11.517341584256666, 10.703440731689138, 9.64227454640758, 8.800936518139723, 7.978426743130725, 8.707872128312586, 9.628009813410308, 10.604913435325983, 11.581273546635467, 12.524431592910355, 13.583279394731456, 14.51847667912018, 13.748794942559948, 12.818592710119301, 14.617424024827221, 15.557380884436025, 16.312500051934016, 15.300951203678187, 14.355973593140192, 13.45239463935791, 12.49413024008599, 11.65415943024037, 10.68455310844019, 9.787109986626485, 8.974502973472758, 9.653260742367126, 10.572971927394109, 11.597263473936419, 12.528571994120874, 13.58127481954856, 14.604936569705425, 15.54776291008028, 14.71737182836988, 13.788305999845347, 15.429124920514475, 16.50224678682853, 16.601473440657408, 15.634672521899072, 14.636725238709355, 13.807620384973895, 12.790711224381319, 11.848548664217759, 10.95401781413609, 10.061770052701933, 10.040651072726984, 10.634568748555624, 11.55823529223818, 12.496439927013293, 13.50214066008871, 14.521923843785885, 15.469343763104753, 16.453629353660027, 15.666987738017115, 14.768731378035021, 16.36154353290687, 16.613425368465197, 15.63341064377895, 14.666559716552982, 13.710901580293427, 12.771049556209855, 11.810711100788893, 10.875187195953464, 9.951909564482719, 9.070374973678557, 9.941245357700014, 10.71227807756179, 11.691851223203711, 12.549845668913381, 13.504586323922961, 14.432036209976545, 15.366050021390796, 16.33164628746285, 16.72959256887089, 15.736772105833731, 16.654702452935343, 15.642839760464488, 14.70287555380533, 13.708799360081844, 12.765930029409585, 11.792807957161997, 10.856518833352428, 9.920645669106703, 9.005525024012478, 8.07568718879127, 8.888390406287074, 9.708606983204579, 10.697749452790971, 11.557075959649028, 12.55849629777832, 13.486123267287526, 14.496048380342689, 15.476810054498031, 16.460864878910833, 16.59906418290582, 15.644779184578672, 14.698031590592318, 13.750584920361513, 12.748792168259332, 11.722752330292522, 10.794386863962703, 9.82374906599464, 8.864464552235383, 8.084636139206738, 7.074109090680809, 7.900455879570974, 8.743446495438326, 9.651620018591823, 10.62228755064009, 11.614659482150172, 12.564403231318952, 13.507514440379344, 14.572432530722347, 15.535494445099317, 16.373259996971637, 14.756479187888484, 13.688179037022623, 12.69445101144989, 11.751984669750899, 10.725242574659408, 9.74050095893029, 8.875712326858899, 7.93309291676044, 7.018601443316061, 6.0885329937051695, 6.875121996565623, 7.789227699931576, 8.643621332806038, 9.65161409101371, 10.597907275614343, 11.552461711292189, 12.553971405577093, 13.557797223835918, 14.496748167120495, 15.402452092838436, 13.837747098783732, 12.771711032043111, 11.725965372015708, 10.79185360759333, 9.753615744306856, 8.790273066247167, 7.824369841936482, 6.938321633760696, 6.061338929830675, 5.065132663979425, 5.8584297121773625, 6.764741642049712, 7.718403209463485, 8.672612640790145, 9.634519872195238, 10.596767547255428, 11.568722391581597, 12.544829521704704, 13.479247776537798, 14.477094110427243, 12.792268362389043, 11.970856015960063, 10.932711114831942, 9.85925499882134, 8.854411165666052, 7.832947906794332, 6.879101633514304, 5.941154164796831, 4.991919060781656, 4.062142585280377, 4.890535689895334, 5.813307972241918, 6.771089080910322, 7.808296615776931, 8.678939599166537, 9.704568363988841, 10.62196401858951, 11.682998791945911, 12.627221349882172, 13.651698389330388, 11.812711980302597, 10.983243277159731, 9.94260650460404, 8.869159260140664, 7.902247531278716, 6.893498063979931, 5.936119487901252, 4.929155217298737, 3.9644022054861194, 3.1321826043872387, 3.9612601608936258, 4.841639229226951, 5.800584702020182, 6.757629976358759, 7.693427163942834, 8.651124824549472, 9.690742707597193, 10.751127142068484, 11.700575164358288, 12.633371869181467, 10.83244558642548, 9.946386876814316, 8.884372836601917, 7.913132004337887, 6.885638406686298, 5.915792538535852, 4.935019537233739, 3.9860101354822, 2.9886921731350897, 2.108073317288054, 2.8994001244666485, 3.8612640963678877, 4.895626657801504, 5.880216819222232, 6.9016275117501324, 7.87491615217913, 8.857489215380285, 9.761547641181942, 10.826608689966923, 11.727905108135129, 9.891645044122576, 8.92721306921036, 7.959256949854639, 7.003914032243885, 6.009925414609018, 4.944089046434954, 3.9408401623823597, 2.9890740166361622, 1.996380146767358, 1.057254549032697, 1.9528565427532016, 2.943191901028671, 3.91753663247097, 4.910325732230552, 5.889031620539373, 6.9160616196767934, 7.821883323171155, 8.764184079602495, 9.769549722540882, 10.689511763239896, 9.199248082461626, 8.15546164575063, 7.099803906806244, 6.088151592440987, 5.130016189663339, 4.070416546535388, 3.0088640262773043, 1.9993240250674091, 0.9281511824790291, 0.0, 1.001042211624632, 2.010912879281908, 2.9910217126091947, 3.955705527195034, 4.947823951837633, 5.893203030607409, 6.822596628929736, 7.752232939411042, 8.74127817373805, 9.675952602303914, 9.748588465376292, 8.725597305888632, 7.78844399264439, 6.781624202544223, 5.726947047126501, 4.724097229962455, 3.7811440526876705, 2.8422487454999716, 1.905207472251036, 0.9694408888430659, 1.9898736578871916, 2.9727954141157364, 3.9516845185143175, 4.9374213858946385, 5.958681313027399, 6.826384611752883, 7.763261546030408, 8.726747087068112, 9.67577218235808, 10.628883969970758, 10.684629549469358, 9.672987813825966, 8.786325561996223, 7.770196052106712, 6.695387813705333, 5.66165296272829, 4.840373735034385, 3.806330329166975, 2.8327864468542803, 1.9262520073859046, 2.8821150037101013, 3.93145655151375, 4.880387489808459, 5.936293464799139, 6.88991307501934, 7.800376241703582, 8.799579867639087, 9.763113215868112, 10.647610217105695, 11.580569617507608], [11.580570092379567, 10.71304641871162, 9.784822085109306, 8.7437395859864, 7.804222204388566, 6.753764046384832, 5.772688748667479, 4.806687256995573, 3.9108312305534856, 2.9721164779017726, 3.8357396219172895, 4.7931716846763965, 5.740639930285122, 6.750497401848297, 7.679803047054087, 8.637157382463686, 9.688570837150772, 10.651299320604203, 11.67021009344607, 12.624305726739507, 10.578106765232285, 11.508163208418745, 10.619662435374739, 9.679316625112664, 8.696934413370776, 7.693963372638761, 6.7274651235545395, 5.865432692314814, 4.850595179900052, 3.8989535544906713, 4.899101313760373, 5.728055153102948, 6.676249501049264, 7.681304500503693, 8.631950635136784, 9.6019140058623, 10.641850474033538, 11.631751744310112, 12.611055161980728, 11.795572294503817, 9.747482054740168, 10.74807668593552, 11.628767230774692, 10.628375820796707, 9.630983880866022, 8.659784946341265, 7.689757131177588, 6.812002206780194, 5.872772565455753, 4.9476253413496964, 5.95596358337517, 6.674435045133763, 7.7062042252242176, 8.675471866602575, 9.606380252924659, 10.632340776431063, 11.612900020797364, 12.575809520996433, 12.215546219829644, 11.194052999736233, 10.727823611809248, 11.705831036829705, 12.53757047457784, 11.485168470136252, 10.556017265416628, 9.586082123735208, 8.629692176371737, 7.813782836505996, 6.84799818620788, 5.992573318619715, 6.949954390001093, 7.725662835236564, 8.69177040814298, 9.617807904363172, 10.590311332525507, 11.56097233838582, 12.613657324535842, 13.551760886763402, 12.833370157670121, 11.893404297242064, 11.773115212897409, 12.698277051478113, 13.455725680570358, 12.392206243084006, 11.46151110938466, 10.534328547058381, 9.604650657484862, 8.830359606967665, 7.876503978838703, 7.00606467393152, 7.922616803155707, 8.66120979508488, 9.62772652730969, 10.568460388892156, 11.563053655245707, 12.526890514521932, 13.558684391708486, 14.483504451898579, 13.748707530631817, 12.803267282101778, 12.578634568938018, 13.596709599857695, 14.344205741024219, 13.341688020085785, 12.439058540958504, 11.534172737972735, 10.56636600786309, 9.875838619102078, 8.814672433820519, 7.973334405552661, 8.864404895448548, 9.67263263426499, 10.592770319362714, 11.569673941278388, 12.546034052587872, 13.48919209886276, 14.548039900683861, 15.519518890744813, 14.749837154184581, 13.819634921743933, 13.616381813202588, 14.556338672811393, 15.361524475540437, 14.349975627284609, 13.404998016746614, 12.501419062964334, 11.543154663692414, 10.82655731765331, 9.85695099585313, 8.959507874039423, 9.86048112579058, 10.61802124831953, 11.537732433346514, 12.562023979888824, 13.49333250007328, 14.546035325500965, 15.56969707565783, 16.512523416032685, 15.718414039994512, 14.78934821146998, 14.428082708889843, 15.501204575203896, 16.386976570333715, 15.358935580406815, 14.4382241797822, 13.54315632229356, 12.605074498524424, 11.768178875046825, 10.809894806610755, 9.954144162902978, 9.960041432899507, 10.737360730279079, 11.727738792033305, 12.513086715655259, 13.498036096722798, 14.408797888879977, 15.356217808198846, 16.34050339875412, 16.668029949641745, 15.751561329709652, 15.36050132128224, 16.416806888321435, 16.494003647374434, 15.527152720148468, 14.571494583888914, 13.62349362347456, 12.592758851119378, 11.657234946283948, 10.676966278716263, 9.795431687912101, 8.940203146075381, 9.711235865937157, 10.690809011579079, 11.548803457288749, 12.503544112298329, 13.430993998351912, 14.365007809766164, 15.330604075838218, 16.375794518300182, 16.71960205750836, 16.402950630447986, 16.564090459054455, 15.563468557400816, 14.56939236367733, 13.626523033005071, 12.645252024426703, 11.708962900617134, 10.71980817967738, 9.730581738246022, 8.800743903024813, 7.887348194662442, 8.707564771579946, 9.696707241166338, 10.556033748024396, 11.557454086153687, 12.485081055662894, 13.495006168718056, 14.475767842873399, 15.459822667286199, 16.31806245061048, 16.6276091362533, 15.680861542266948, 14.733414872036143, 13.70542473529982, 12.67938489733301, 11.751019431003192, 10.676193133259346, 9.716908619500089, 8.829264741921413, 7.7991658049143515, 6.899413667946342, 7.742404283813693, 8.65057780696719, 9.621245339015458, 10.61361727052554, 11.56336101969432, 12.506472228754712, 13.571390319097715, 14.534452233474685, 15.372217785347006, 15.739309139563114, 14.671008988697253, 13.67728096312452, 12.717410645781378, 11.690668550689887, 10.70592693496077, 9.836143822355128, 8.785536984025146, 7.763230046030736, 6.813589707938712, 5.8740797849409905, 6.788185488306944, 7.642579121181406, 8.650571879389078, 9.59686506398971, 10.551419499667556, 11.55292919395246, 12.556755012211285, 13.495705955495863, 14.401409881213803, 14.820577050458363, 13.754540983717742, 12.708795323690337, 11.77468355926796, 10.719041720337335, 9.755699042277646, 8.785564854809216, 7.790765701025402, 6.80596753254535, 5.790189378212968, 4.85738750055273, 5.7636994304250795, 6.717360997838853, 7.671570429165512, 8.633477660570605, 9.595725335630796, 10.567680179956964, 11.543787310080072, 12.478205564913166, 13.476051898802611, 13.793310574013676, 12.971898227584692, 11.926052555130294, 10.852596439119692, 9.847752605964404, 8.826289347092683, 7.861919200211204, 6.793598232061537, 5.844363128046362, 4.903591121108119, 3.8894934782707007, 4.812265760617286, 5.770046869285689, 6.807254404152299, 7.677897387541904, 8.703526152364208, 9.620921806964878, 10.681956580321279, 11.62617913825754, 12.650656177705756, 12.813754191927229, 11.98428548878436, 10.943648716228669, 9.870201471765295, 8.903289742903347, 7.8868395042782815, 6.929460928199603, 5.899250929938596, 4.934497918125977, 3.973631140214981, 2.9602179492689933, 3.8405970176023185, 4.79954249039555, 5.756587764734126, 6.692384952318202, 7.650082612924839, 8.689700495972561, 9.750084930443851, 10.699532952733655, 11.632329657556834, 11.833487798050113, 10.947429088438948, 9.88541504822655, 8.91417421596252, 7.88668061831093, 6.916834750160484, 5.9360617488583705, 4.9870523471068315, 3.9587878857749477, 2.9495218531157965, 1.898357912842016, 2.8602218847432552, 3.8945844461768715, 4.8791746075976, 5.9005853001255, 6.873873940554498, 7.856447003755653, 8.760505429557309, 9.82556647834229, 10.726862896510497, 10.892687255747209, 9.928255280834993, 8.960299161479272, 8.004956243868516, 7.010967626233649, 5.945131258059584, 4.94188237400699, 3.990116228260794, 2.994028220694421, 2.016858171735411, 0.9518143311285695, 1.9421496894040389, 2.916494420846338, 3.90928352060592, 4.88798940891474, 5.915019408052161, 6.820841111546523, 7.763141867977863, 8.76850751091625, 9.688469551615263, 10.200290294086255, 9.15650385737526, 8.100846118430875, 7.089193804065618, 6.13105840128797, 5.07145875816002, 4.0099062379019355, 3.0003662366920407, 1.929193394103661, 1.001042211624632, 0.0, 1.0098706676572762, 1.9899795009845627, 2.954663315570402, 3.9467817402130008, 4.892160818982776, 5.821554417305103, 6.751190727786409, 7.740235962113417, 8.674910390679281, 10.749630677000924, 9.726639517513265, 8.789486204269023, 7.7826664141688555, 6.727989258751133, 5.725139441587086, 4.782186264312302, 3.8432909571246037, 2.906249683875668, 1.970483100467698, 0.9888314462625595, 1.9717532024911042, 2.9506423068896854, 3.936379174270006, 4.9576391014027665, 5.8253424001282506, 6.762219334405776, 7.725704875443481, 8.674729970733447, 9.627841758346126, 11.68567176109399, 10.674030025450598, 9.787367773620854, 8.771238263731343, 7.696430025329964, 6.662695174352922, 5.8414159466590165, 4.807372540791607, 3.8338286584789123, 2.891012513338308, 1.9351495170141113, 2.9844910648177603, 3.879345278183828, 4.935251253174506, 5.8888708633947076, 6.799334030078949, 7.798537656014455, 8.762071004243479, 9.646568005481063, 10.579527405882976], [10.570699424722292, 9.703175751054346, 8.774951417452032, 7.733868918329124, 6.794351536731289, 5.743893378727556, 4.762818081010202, 3.796816589338297, 3.007532784196897, 3.94624753684861, 4.835333626173413, 5.79276568893252, 6.750510597942397, 7.760368069505573, 8.689673714711363, 9.647028050120964, 10.69844150480805, 11.66116998826148, 12.680080761103346, 13.634176394396784, 9.56823609757501, 10.49829254076147, 9.609791767717462, 8.669445957455387, 7.6870637457135, 6.6840927049814844, 5.717594455897263, 4.866019787628944, 3.947296733543464, 4.873084613437509, 5.8732323727072115, 6.727649157359072, 7.675843505305387, 8.680898504759817, 9.631544639392908, 10.610270852309744, 11.650207320480982, 12.64162241196739, 13.620925829638006, 12.805442962161091, 8.737611387082893, 9.738206018278245, 10.618896563117415, 9.61850515313943, 8.621113213208746, 7.649914278683989, 6.679886463520312, 5.812589302094325, 4.969474119099164, 5.921756400296534, 6.9300946423220084, 7.674029049389887, 8.705798229480342, 9.675065870858699, 10.605974257180783, 11.640697622878507, 12.621256867244808, 13.585680188653711, 13.225416887486922, 12.20392366739351, 9.717952944151973, 10.69596036917243, 11.527699806920566, 10.475297802478975, 9.546146597759352, 8.576211456077932, 7.619821508714462, 6.814369931820126, 5.944699739851291, 6.930828041188221, 7.888209112569599, 8.725256839492689, 9.691364412399105, 10.617401908619296, 11.589905336781632, 12.560566342641945, 13.613251328791966, 14.56163155442068, 13.843240825327396, 12.903274964899339, 10.763244545240134, 11.688406383820839, 12.445855012913084, 11.382335575426731, 10.451640441727385, 9.524457879401105, 8.594779989827586, 7.85359080577783, 6.9732055324821145, 7.944319396500026, 8.860871525724212, 9.660803799341004, 10.627320531565815, 11.56805439314828, 12.562647659501831, 13.526484518778057, 14.55827839596461, 15.493375119555857, 14.758578198289092, 13.813137949759053, 11.593807898565034, 12.611882929484711, 13.334335073366944, 12.33181735242851, 11.42918787330123, 10.524302070315459, 9.556495340205814, 8.913276408767103, 7.91137398746393, 8.911589128121168, 9.802659618017053, 10.672226638521115, 11.592364323618838, 12.569267945534513, 13.545628056843997, 14.488786103118885, 15.547633904939985, 16.52938955840209, 15.759707821841856, 14.829505589401208, 12.631555142829605, 13.571512002438409, 14.351653807883162, 13.340104959627334, 12.39512734908934, 11.491548395307058, 10.533283996035138, 9.922401240348552, 8.95365254949654, 9.89776259660793, 10.798735848359085, 10.79502660839074, 11.78936002880054, 12.615684116731531, 13.546992636915986, 14.555238136724185, 15.399288963425475, 16.34211530380033, 16.728284707651785, 15.799218879127254, 13.504440580813005, 14.568592180835617, 15.377105902676439, 14.34906491274954, 13.428353512124925, 12.533285654636284, 11.595203830867147, 10.864880428690237, 9.906596360254166, 10.892398885471485, 10.789915358419861, 9.813718602202242, 10.804096663956468, 11.58944458757842, 12.574393968645959, 13.485155760803138, 14.432575680122007, 15.416861270677282, 16.372107095722903, 16.709152114681114, 14.436859193205402, 15.493164760244596, 16.276686234026375, 15.309835306800407, 14.354177170540853, 13.569856483400324, 12.575203954459573, 11.838241896954532, 10.908704609907538, 10.722406791599488, 9.782767784331616, 8.78759373786032, 9.767166883502242, 10.62516132921191, 11.57990198422149, 12.507351870275073, 13.441365681689325, 14.40696194776138, 15.452152390223343, 16.38843026202056, 15.47930850237115, 16.5353844922349, 16.521059342372276, 15.526983148648792, 14.584113817976533, 13.602842809398165, 12.666553685588596, 11.646783283364766, 10.657556841933408, 9.7277190067122, 8.729912832918677, 7.783922643503109, 8.773065113089501, 9.632391619947557, 10.633811958076848, 11.561438927586055, 12.571364040641217, 13.55212571479656, 14.536180539209363, 15.394420322533643, 16.34870532086079, 16.638452327238408, 15.691005657007604, 14.663015520271282, 13.636975682304472, 12.708610215974653, 11.633783918230808, 10.67449940447155, 9.756239845608802, 8.726140908601739, 7.826388771633729, 6.818762155736856, 7.726935678890352, 8.697603210938619, 9.6899751424487, 10.63971889161748, 11.582830100677876, 12.647748191020879, 13.61081010539785, 14.448575657270169, 16.696899924534577, 15.628599773668714, 14.634871748095982, 13.67500143075284, 12.648259335661349, 11.663517719932232, 10.79373460732659, 9.743127768996608, 8.690205149718123, 7.7405648116261, 6.801054888628378, 5.8645433602301065, 6.718936993104569, 7.72692975131224, 8.673222935912873, 9.627777371590721, 10.629287065875625, 11.633112884134448, 12.572063827419026, 13.477767753136966, 15.778167835429825, 14.712131768689204, 13.666386108661799, 12.732274344239421, 11.676632505308797, 10.713289827249108, 9.743155639780678, 8.748356485996863, 7.732942636232737, 6.7171644819003555, 5.784362604240117, 4.840057302348242, 5.7937188697620154, 6.747928301088675, 7.709835532493769, 8.67208320755396, 9.644038051880127, 10.620145182003235, 11.554563436836329, 12.552409770725774, 14.80318124167095, 13.98176889524197, 12.926138370855938, 11.852682254845334, 10.847838421690046, 9.826375162818325, 8.8251985023517, 7.756877534202033, 6.807642430186857, 5.8668704232486135, 4.816468581958088, 3.888623632540449, 4.846404741208852, 5.883612276075462, 6.754255259465068, 7.779884024287371, 8.69727967888804, 9.697129909948295, 10.641352467884555, 11.665829507332772, 13.823624859584504, 12.994156156441639, 11.953519383885947, 10.880072139422571, 9.913160410560623, 8.886925320003924, 7.929546743925245, 6.899336745664238, 5.934583733851619, 4.973716955940623, 3.9603037649946353, 2.916954889525482, 3.8759003623187134, 4.83294563665729, 5.768742824241365, 6.726440484848002, 7.766058367895724, 8.765258260070867, 9.714706282360671, 10.64750298718385, 12.843358465707388, 11.957299756096225, 10.895285715883826, 9.924044883619796, 8.896551285968206, 7.92670541781776, 6.945932416515647, 5.996923014764108, 4.95887370150059, 3.9496076688414385, 2.898443728567658, 1.936579756666419, 2.9540336797469005, 3.919223689233351, 4.8907146324682245, 5.864003272897222, 6.846576336098378, 7.750634761900035, 8.815695810685018, 9.716992228853222, 11.902557923404483, 10.938125948492267, 9.970169829136546, 9.014826911525791, 8.020838293890925, 6.955001925716861, 5.951753041664267, 4.99998689591807, 4.0016134519511075, 3.0244434029920972, 1.959399562385256, 0.9690642041097864, 1.9434089355520856, 2.899412852948644, 3.878118741257465, 4.9051487403948855, 5.810970443889248, 6.753271200320588, 7.758636843258976, 8.678598883957989, 11.210160961743533, 10.166374525032538, 9.110716786088151, 8.099064471722894, 7.140929068945247, 6.081329425817296, 5.019776905559212, 4.010236904349317, 2.939064061760937, 2.010912879281908, 1.0098706676572762, 0.0, 0.9801088333272865, 1.944792647913126, 2.9369110725557253, 3.882290151325501, 4.811683749647829, 5.7413200601291345, 6.730365294456142, 7.665039723022008, 11.7595013446582, 10.736510185170541, 9.7993568719263, 8.792537081826133, 7.73785992640841, 6.735010109244363, 5.7920569319695785, 4.85316162478188, 3.916120351532944, 2.980353768124974, 1.9884254505186831, 1.0055036942901383, 1.940771639232409, 2.9265085066127297, 3.947768433745491, 4.815471732470975, 5.752348666748501, 6.715834207786206, 7.664859303076172, 8.617971090688851, 12.695542428751267, 11.683900693107875, 10.797238441278132, 9.781108931388621, 8.706300692987242, 7.672565842010198, 6.851286614316293, 5.8172432084488825, 4.843699326136188, 3.8906065175944318, 2.934743521270235, 2.0752110505068377, 2.8694746105265514, 3.9253805855172295, 4.87900019573743, 5.789463362421674, 6.78866698835718, 7.752200336586204, 8.636697337823788, 9.569656738225701], [9.590590591395005, 8.723066917727058, 7.794842584124744, 6.753760085001838, 5.814242703404004, 4.76378454540027, 3.7827092476829165, 2.816707756011011, 3.835937246259614, 4.7746519989113265, 5.703391473435275, 6.660823536194382, 7.730619431269683, 8.740476902832858, 9.669782548038649, 10.62713688344825, 11.678550338135336, 12.641278821588767, 13.660189594430632, 14.61428522772407, 8.588127264247722, 9.518183707434183, 8.629682934390177, 7.6893371241281026, 6.706954912386214, 5.703983871654199, 4.737485622569977, 3.885910954301658, 4.775701195606181, 5.701489075500225, 6.7016368347699276, 7.595707004620934, 8.54390135256725, 9.54895635202168, 10.499602486654771, 11.478328699571607, 12.518265167742845, 13.54916692108636, 14.528470338756977, 13.785551795488377, 7.757502553755606, 8.758097184950957, 9.63878772979013, 8.638396319812145, 7.64100437988146, 6.669805445356703, 5.699777630193026, 4.832480468767039, 5.791298705326929, 6.75016086235925, 7.7584991043847245, 8.542086896651748, 9.573856076742203, 10.54312371812056, 11.474032104442646, 12.50875547014037, 13.489314714506671, 14.493224697772682, 14.205525720814208, 13.184032500720797, 8.737844110824685, 9.715851535845143, 10.54759097359328, 9.49518896915169, 8.566037764432066, 7.596102622750647, 6.639712675387176, 5.83426109849284, 6.766524326079056, 7.752652627415985, 8.710033698797364, 9.59331468675455, 10.559422259660966, 11.485459755881157, 12.457963184043493, 13.428624189903806, 14.481309176053827, 15.469176063539651, 14.823349658654685, 13.883383798226628, 9.783135711912847, 10.708297550493551, 11.465746179585798, 10.402226742099446, 9.471531608400099, 8.544349046073819, 7.614671156500301, 6.873481972450544, 7.795030118709879, 8.76614398272779, 9.682696111951978, 10.528861646602865, 11.495378378827676, 12.436112240410141, 13.430705506763692, 14.394542366039918, 15.426336243226471, 16.400919628674828, 15.738687031616381, 14.793246783086342, 10.613699065237746, 11.631774096157423, 12.354226240039658, 11.351708519101225, 10.449079039973943, 9.544193236988175, 8.57638650687853, 7.933167575439818, 8.733198573691695, 9.733413714348933, 10.624484204244819, 11.540284485782976, 12.029609576546425, 12.901433974595584, 13.755077917245076, 14.698235963519965, 15.703372056884612, 16.624595247390133, 16.739816655169143, 15.809614422728497, 11.651446309502317, 12.591403169111121, 13.371544974555876, 12.359996126300048, 11.415018515762053, 10.511439561979774, 9.553175162707854, 8.942292407021267, 9.775477135724305, 10.719587182835694, 11.620560434586851, 11.775135441718028, 11.084647462562625, 11.845189038177823, 12.776497558362278, 13.784743058170477, 14.628793884871767, 15.571620225246622, 16.542878052111735, 16.779327712454542, 12.546362819673835, 13.58848334750833, 14.396997069349153, 13.368956079422254, 12.44824467879764, 11.553176821309, 10.615094997539863, 9.899105359888159, 10.728420946481931, 11.714223471699249, 11.770024191747149, 10.79382743552953, 10.099384097718554, 10.818949509024712, 11.80389889009225, 12.71466068224943, 13.662080601568299, 14.646366192123574, 15.5932621424645, 16.398393228680096, 13.478781432066231, 14.535086999105426, 15.296577400699089, 14.329726473473121, 13.374068337213567, 12.58974765007304, 11.595095121132289, 10.872466828152454, 11.730529196135302, 11.702515624926773, 10.762876617658904, 9.767702571187607, 9.062454317264327, 9.854666250658202, 10.809406905667782, 11.736856791721365, 12.670870603135617, 13.624357768038905, 14.530657311610726, 15.430352500881387, 14.521230741231978, 15.57730673109573, 16.244039892489976, 15.26190921876967, 14.31903988809741, 13.535470304864107, 12.599181181054538, 11.827008354999215, 11.637665675260694, 10.707827840039485, 9.710021666245964, 8.764031476830397, 8.019509625187675, 8.861896541393849, 9.859026648013005, 10.786653617522212, 11.710298192340836, 12.691059866496179, 13.57810277807019, 14.436342561394472, 15.39062755972162, 16.337375153707974, 16.67111449033489, 15.643124353598571, 14.617084515631761, 13.688719049301943, 12.613892751558097, 11.65460823779884, 10.73634867893609, 9.706249741929025, 8.806497604961017, 7.7988709890641434, 6.973380190988526, 7.927108132384911, 8.822335478974328, 9.757170029032983, 10.689756619746063, 11.731576034320137, 12.652732344258677, 13.490497896130998, 16.322125169999417, 16.608708606996004, 15.61498058142327, 14.655110264080127, 13.628368168988636, 12.64362655325952, 11.773843440653877, 10.723236602323896, 9.67031398304541, 8.720673644953386, 7.781163721955665, 6.844652193557394, 5.965381505202743, 6.956434672758531, 7.781558891215794, 8.736113326893639, 9.736213584943812, 10.675035122995277, 11.613986066279855, 12.519689991997796, 16.758276668757112, 15.69224060201649, 14.646494941989086, 13.712383177566709, 12.656741338636085, 11.693398660576396, 10.723264473107966, 9.728465319324151, 8.713051469560025, 7.697273315227643, 6.764471437567405, 5.82016613567553, 5.040163381860189, 5.967949685776173, 6.818171487796689, 7.780419162856879, 8.734540238597676, 9.662067420864064, 10.596485675697158, 11.594332009586603, 15.78329007499824, 14.961877728569256, 13.906247204183224, 12.83279108817262, 11.827947255017332, 10.80648399614561, 9.805307335678988, 8.73698636752932, 7.787751263514145, 6.846979256575901, 5.796577415285376, 4.868732465867736, 4.092849253307026, 5.034709710180318, 5.8625912147679875, 6.87038621100492, 7.787781865605589, 8.717021076621007, 9.661243634557268, 10.685720674005484, 14.803733692911793, 13.974264989768924, 12.933628217213233, 11.860180972749857, 10.893269243887909, 9.86703415333121, 8.909655577252531, 7.879445578991524, 6.914692567178906, 5.95382578926791, 4.940412598321922, 3.897063722852769, 3.1223448744168865, 3.984043070762146, 4.877078779544285, 5.816942671565551, 6.856560554613273, 7.78514942674358, 8.734597449033384, 9.667394153856563, 13.823467299034677, 12.93740858942351, 11.875394549211112, 10.904153716947082, 9.876660119295492, 8.906814251145047, 7.926041249842934, 6.977031848091395, 5.938982534827876, 4.929716502168725, 3.878552561894945, 2.9166885899937056, 2.0720691650109444, 2.9391148559060642, 3.9106057991409378, 4.883894439569936, 5.866467502771091, 6.770525928572748, 7.83558697735773, 8.736883395525934, 12.882666756731773, 11.918234781819557, 10.950278662463836, 9.99493574485308, 9.000947127218213, 7.935110759044148, 6.931861874991554, 5.980095729245357, 4.981722285278394, 4.004552236319384, 2.9395083957125427, 1.949173037437073, 1.06144442081613, 1.9193040196213573, 2.898009907930178, 3.9250399070675988, 4.830861610561961, 5.773162366993301, 6.778528009931688, 7.698490050630702, 12.190269795070819, 11.146483358359824, 10.090825619415439, 9.079173305050181, 8.121037902272533, 7.061438259144584, 5.9998857388864995, 4.990345737676604, 3.9191728950882236, 2.9910217126091947, 1.9899795009845627, 0.9801088333272865, 0.0, 0.9646838145858393, 1.9568022392284385, 2.902181317998214, 3.8315749163205415, 4.761211226801847, 5.7502564611288545, 6.68493088969472, 12.739610177985487, 11.716619018497827, 10.779465705253585, 9.772645915153419, 8.717968759735696, 7.715118942571649, 6.772165765296864, 5.8332704581091654, 4.89622918486023, 3.9604626014522606, 2.931193379413951, 1.9482716231854063, 0.9606628059051227, 1.9463996732854434, 2.9676596004182043, 3.8353628991436883, 4.772239833421214, 5.7357253744589185, 6.684750469748884, 7.637862257361563, 13.675651262078553, 12.66400952643516, 11.777347274605418, 10.761217764715907, 9.686409526314527, 8.652674675337485, 7.831395447643579, 6.797352041776168, 5.811979555341435, 4.8333744464896995, 3.877511450165503, 2.9248497178256, 1.8893657771992651, 2.945271752189943, 3.898891362410144, 4.809354529094387, 5.808558155029893, 6.772091503258917, 7.656588504496501, 8.589547904898414], [8.625906776809165, 7.758383103141219, 6.830158769538905, 5.811828332406718, 4.872310950808884, 3.9235856401537204, 2.9837079342809214, 3.78139157059685, 4.800621060845453, 5.739335813497165, 6.668075288021114, 7.625507350780221, 8.695303245855523, 9.7051607174187, 10.634466362624488, 11.59182069803409, 12.643234152721176, 13.605962636174606, 14.624873409016471, 15.57896904230991, 7.623443449661883, 8.553499892848343, 7.719844186217263, 6.779498375955189, 5.801465164315482, 4.863784966407649, 3.9384843091679818, 4.850594768887497, 5.7403850101920195, 6.666172890086064, 7.666320649355766, 8.560390819206773, 9.50858516715309, 10.51364016660752, 11.46428630124061, 12.443012514157447, 13.482948982328685, 14.5138507356722, 15.493154153342816, 14.750235610074217, 6.792818739169767, 7.793413370365118, 8.74490173978635, 7.744510329808366, 6.747118389877682, 5.829606540110153, 4.90077631679103, 5.797164283352878, 6.755982519912767, 7.714844676945089, 8.723182918970563, 9.506770711237587, 10.538539891328043, 11.5078075327064, 12.438715919028486, 13.47343928472621, 14.45399852909251, 15.457908512358522, 15.170209535400048, 14.148716315306636, 7.773160296238846, 8.751167721259305, 9.682113103719564, 8.694893394189116, 7.765742189469492, 6.797101309348651, 5.84071136198518, 6.798944913078679, 7.7312081406648945, 8.717336442001825, 9.674717513383204, 10.55799850134039, 11.524106074246806, 12.450143570466997, 13.422646998629332, 14.393308004489645, 15.445992990639667, 16.433859878125492, 15.788033473240525, 14.848067612812468, 8.818451897327007, 9.743613735907713, 10.659885893085912, 9.603225428697451, 8.672530294998104, 7.745347732671824, 6.815669843098306, 7.838165787036383, 8.759713933295718, 9.73082779731363, 10.647379926537818, 11.493545461188704, 12.460062193413515, 12.937963712395977, 13.810798261372277, 14.774635120648503, 15.780090695143048, 16.695925871650527, 16.703370846202223, 15.757930597672182, 9.649015250651908, 10.667090281571586, 11.555224926637663, 10.55270720569923, 9.650077726571949, 8.745191923586178, 7.777385193476533, 8.809775739837843, 9.697882388277533, 10.698097528934772, 11.589168018830659, 12.504968300368816, 12.722695808041857, 11.936750160009744, 12.790394102659237, 13.733552148934125, 14.738688242298775, 15.659911432804293, 16.619481861959873, 16.774298237314337, 10.68676249491648, 11.626719354525283, 12.572543661153881, 11.560994812898054, 10.616017202360059, 9.712438248577778, 8.754173849305857, 9.805454987860294, 10.740160950310143, 11.684270997421534, 12.58524424917269, 12.739819256303868, 11.777733694058057, 10.880505223591983, 11.811813743776439, 12.82005924358464, 13.664110070285929, 14.606936410660785, 15.5781942375259, 16.422362332879274, 11.581679005087997, 12.623799532922492, 13.587132241226122, 12.56995476602026, 11.649243365395645, 10.754175507907004, 9.816093684137867, 10.762267940727186, 11.693104761067769, 12.678907286285089, 12.734708006332989, 11.758511250115369, 10.792470329213986, 9.854265694438872, 10.839215075506413, 11.749976867663593, 12.69739678698246, 13.681682377537737, 14.628578327878664, 15.43370941409426, 12.514097617480394, 13.570403184519588, 14.497576087297094, 13.530725160071126, 12.575067023811572, 11.790746336671043, 10.796093807730292, 11.731617712565722, 12.69521301072114, 12.667199439512615, 11.727560432244744, 10.732386385773447, 9.816483214594799, 8.889982436072364, 9.844723091081944, 10.772172977135527, 11.706186788549779, 12.659673953453066, 13.56597349702489, 14.46566868629555, 13.556546926646142, 14.612622916509894, 15.44503857908798, 14.462907905367675, 13.520038574695416, 12.736468991462111, 11.800179867652542, 12.686159239412483, 12.602349489846535, 11.672511654625326, 10.674705480831804, 9.728715291416236, 8.873569281285672, 7.89721272680801, 8.894342833427164, 9.821969802936371, 10.745614377754997, 11.72637605191034, 12.613418963484355, 13.471658746808634, 14.425943745135783, 15.372691339122136, 16.393793902270225, 15.502309377643241, 14.563216273812479, 13.804338771772791, 12.83294963501033, 12.61929205238468, 11.70103249352193, 10.670933556514866, 9.771181419546854, 8.763554803649983, 7.827439847086523, 6.962424317799073, 7.857651664388487, 8.792486214447143, 9.725072805160222, 10.766892219734299, 11.688048529672841, 12.52581408154516, 15.357441355413577, 16.38254389269183, 16.57966439600911, 15.619794078665969, 14.593051983574478, 13.60831036784536, 12.738527255239719, 11.687920416909737, 10.634997797631252, 9.685357459539228, 8.745847536541504, 7.809336008143234, 6.819441161300739, 5.9917508581726935, 6.816875076629954, 7.771429512307799, 8.77152977035797, 9.71035130840944, 10.649302251694017, 11.555006177411958, 16.364693693345547, 16.656924416602333, 15.611178756574928, 14.67706699215255, 13.621425153221926, 12.658082475162237, 11.687948287693807, 10.693149133909992, 9.677735284145866, 8.661957129813484, 7.7291552521532445, 6.7848499502613695, 5.894223037958186, 5.003265871190335, 5.853487673210849, 6.81573534827104, 7.769856424011834, 8.697383606278226, 9.63180186111132, 10.629648195000765, 16.74797388958408, 15.926561543155096, 14.870931018769063, 13.79747490275846, 12.792631069603171, 11.77116781073145, 10.769991150264827, 9.70167018211516, 8.752435078099985, 7.811663071161741, 6.761261229871216, 5.833416280453576, 4.946908909405023, 4.07002589559448, 4.897907400182148, 5.90570239641908, 6.823098051019748, 7.7523372620351685, 8.69655981997143, 9.721036859419646, 15.768417507497633, 14.938948804354764, 13.898312031799072, 12.824864787335697, 11.857953058473749, 10.831717967917049, 9.87433939183837, 8.844129393577363, 7.879376381764745, 6.918509603853749, 5.905096412907761, 4.8617475374386085, 3.976404530514884, 3.019359256176307, 3.9123949649584455, 4.85225885697971, 5.891876740027432, 6.820465612157742, 7.769913634447546, 8.702710339270725, 14.788151113620517, 13.90209240400935, 12.840078363796952, 11.868837531532922, 10.841343933881332, 9.871498065730886, 8.890725064428773, 7.941715662677234, 6.903666349413715, 5.894400316754564, 4.8432363764807835, 3.881372404579545, 2.959021202740953, 1.974431041320225, 2.945921984555098, 3.9192106249840957, 4.901783688185253, 5.805842113986909, 6.87090316277189, 7.772199580940095, 13.847350571317612, 12.882918596405396, 11.914962477049675, 10.95961955943892, 9.965630941804053, 8.899794573629988, 7.896545689577394, 6.9447795438311966, 5.946406099864233, 4.969236050905223, 3.9041922102983815, 2.9138568520229122, 1.994263786254125, 0.954620205035518, 1.9333260933443388, 2.960356092481759, 3.866177795976122, 4.808478552407462, 5.813844195345849, 6.733806236044862, 13.154953609656658, 12.111167172945663, 11.055509434001278, 10.043857119636021, 9.085721716858373, 8.026122073730424, 6.964569553472339, 5.9550295522624435, 4.883856709674063, 3.955705527195034, 2.954663315570402, 1.944792647913126, 0.9646838145858393, 0.0, 0.9921184246425991, 1.9374975034123747, 2.8668911017347023, 3.7965274122160078, 4.785572646543015, 5.7202470751088805, 13.704293992571326, 12.681302833083667, 11.744149519839425, 10.737329729739258, 9.682652574321535, 8.67980275715749, 7.736849579882704, 6.797954272695005, 5.86091299944607, 4.9251464160381, 3.8958771939997905, 2.9129554377712457, 1.925346620490962, 1.0260152901490394, 2.0029757858323647, 2.8706790845578487, 3.807556018835375, 4.77104155987308, 5.720066655163046, 6.673178442775725, 14.640335076664392, 13.628693341021, 12.742031089191258, 11.725901579301746, 10.651093340900367, 9.617358489923324, 8.79607926222942, 7.762035856362008, 6.776663369927275, 5.798058261075539, 4.842195264751342, 3.8895335324114395, 2.8540495917851043, 2.0248873690535394, 2.97850697927374, 3.8446707145085472, 4.843874340444054, 5.807407688673078, 6.691904689910662, 7.624864090312575], [7.633788352166565, 6.76626467849862, 5.838040344896306, 4.8197099077641194, 3.880192526166285, 2.939047921857413, 3.9064094364250157, 4.77350999523945, 5.7927394854880525, 6.731454238139765, 7.660193712663713, 8.617625775422821, 9.687421670498123, 10.6972791420613, 11.626584787267086, 12.583939122676687, 13.635352577363774, 14.598081060817204, 15.61699183365907, 16.57108746695251, 6.631325025019283, 7.561381468205743, 6.727725761574664, 5.78737995131259, 4.8093467396728835, 3.8792472481113416, 4.861185811312076, 5.842713193530097, 6.732503434834619, 7.658291314728664, 8.658439073998366, 9.552509243849373, 10.50070359179569, 11.50575859125012, 12.45640472588321, 13.435130938800047, 14.475067406971284, 15.505969160314802, 16.485272577985416, 15.742354034716815, 5.800700314527167, 6.8012949457225185, 7.752783315143751, 6.7523919051657675, 5.754999965235083, 4.845068821813846, 5.823477818935125, 6.789282707995477, 7.748100944555367, 8.70696310158769, 9.715301343613163, 10.498889135880187, 11.530658315970642, 12.499925957349, 13.430834343671085, 14.46555770936881, 15.44611695373511, 16.450026937001123, 16.16232796004265, 15.140834739949238, 6.781041871596246, 7.7590492966167055, 8.689994679076964, 7.702774969546516, 6.773623764826892, 5.822711424846093, 6.763412864129275, 7.791063337721279, 8.723326565307495, 9.709454866644425, 10.666835938025802, 11.550116925982989, 12.516224498889406, 13.442261995109597, 13.955906102491147, 14.92035582986459, 15.831077481784178, 16.683171858760176, 16.780151897883123, 15.840186037455066, 7.826333472684408, 8.751495311265113, 9.667767468443312, 8.683413418544026, 7.75271828484468, 6.825535722518401, 7.7383713452424, 8.77721063006161, 9.731066258190571, 10.70453580071632, 11.639498351180416, 12.485663885831304, 13.452180618056115, 13.72791395968352, 12.906531905500145, 13.870368764776371, 14.835593117117519, 15.751428293624997, 16.62849306087003, 16.75004902231478, 8.656896826009309, 9.674971856928986, 10.635412916484238, 9.632895195545805, 8.730265716418524, 7.838881625681717, 8.700086695620628, 9.732477241981938, 10.669234713172386, 11.671805532337462, 12.581286443473257, 13.497086725011416, 13.5126460553294, 12.726700407297287, 11.886127746787105, 12.829285793061993, 13.794190664273245, 14.715413854778763, 15.62736343731727, 16.39995719796272, 9.69464407027388, 10.634600929882684, 11.605794944601378, 10.641182802744629, 9.696205192206634, 8.806127950673316, 9.676875351449953, 10.72815649000439, 11.69776281180457, 12.657979000824223, 13.577362673815289, 13.561883306974874, 12.5676839413456, 11.670455470879526, 10.907547387904307, 11.876092715002658, 12.7196124922604, 13.662438832635255, 14.586075812883298, 15.430243908236674, 10.589560580445397, 11.631681108279892, 12.595013816583522, 11.650142755866835, 10.72943135524222, 9.847865210002542, 10.738795186281962, 11.684969442871282, 12.643253511307352, 13.652615289687779, 13.556772057003995, 12.580575300786375, 11.582420576501528, 10.644215941726415, 9.933978721936471, 10.806010339081611, 11.752899208956931, 12.73439634218282, 13.636459903236062, 14.44159098945166, 11.521979192837794, 12.578284759876988, 13.558299484563236, 12.610913149917701, 11.655255013658147, 10.884436038766582, 11.718795309874388, 12.654319214709817, 13.634587882277502, 13.577516377105736, 12.605772267295722, 11.586006607524263, 10.606433461882341, 9.679932683359906, 8.939486737512002, 9.828206448553546, 10.72798593515457, 11.667555528810468, 12.573855072382289, 13.47355026165295, 12.56442850200354, 13.620504491867292, 14.50576197635412, 13.54309589521425, 12.600226564541991, 11.86267763781444, 12.722881369796637, 13.608860741556578, 13.512666427439656, 12.582828592218448, 11.552917315882782, 10.606927126467214, 9.710283753009287, 8.687162974095553, 7.902224408784566, 8.829851378293773, 9.753495953112399, 10.734257627267741, 11.621300538841753, 12.479540322166034, 13.433825320493183, 14.380572914479536, 15.401675477627624, 14.582497367489816, 13.643404263659054, 12.93054741812512, 13.755651137154425, 13.529608989977802, 12.611349431115052, 11.581250494107987, 10.681498357139976, 9.641766638700961, 8.664154318810139, 7.752374565086615, 6.865533239745888, 7.800367789804543, 8.732954380517624, 9.774773795091697, 10.69593010503024, 11.53369565690256, 14.365322930770978, 15.390425468049232, 16.384153493621966, 15.638950254731931, 14.666419757226837, 13.984433323157532, 13.64884419283284, 12.598237354502858, 11.545314735224373, 10.595674397132349, 9.656164474134625, 8.687547843194212, 7.656155633024355, 6.781701105460236, 5.8247566519873555, 6.7793110876652, 7.779411345715372, 8.718232883766838, 9.657183827051417, 10.562887752769358, 15.372575268702949, 16.42662390153414, 16.52149569416805, 15.587383929745672, 14.531742090815047, 13.568399412755358, 12.598265225286928, 11.603466071503114, 10.588052221738987, 9.572274067406605, 8.639472189746366, 7.694896777480745, 6.730937509681802, 5.793216118477877, 4.86136924856825, 5.823616923628441, 6.777737999369236, 7.7052651816356255, 8.63968343646872, 9.637529770358165, 16.424947949943835, 16.918679967797694, 15.849033608968792, 14.775577492958188, 13.7707336598029, 12.749270400931179, 11.680308087857949, 10.611987119708282, 9.662752015693107, 8.721980008754862, 7.671578167464337, 6.743733218046697, 5.783623381128638, 4.859976142882022, 3.905788975539549, 4.913583971776481, 5.830979626377149, 6.760218837392569, 7.70444139532883, 8.728918434777047, 16.760535932140233, 15.931067228997362, 14.89043045644167, 13.816983211978297, 12.850071483116349, 11.823836392559649, 10.86645781648097, 9.836247818219963, 8.871494806407345, 7.8904096482166555, 6.818506922768767, 5.77206447503173, 4.813119002238499, 3.856073727899922, 2.9202765403158466, 3.8601404323371113, 4.899758315384833, 5.828347187515142, 6.777795209804946, 7.710591914628125, 15.780269538263115, 14.89421082865195, 13.832196788439552, 12.860955956175522, 11.833462358523931, 10.863616490373486, 9.882843489071373, 8.933834087319834, 7.895784774056315, 6.886518741397164, 5.835354801123383, 4.873490829222144, 3.9511396273835517, 2.966549465962824, 1.9538035599124992, 2.9270922003414968, 3.909665263542653, 4.813723689344309, 5.878784738129291, 6.780081156297495, 14.83946899596021, 13.875037021047994, 12.907080901692273, 11.951737984081518, 10.957749366446652, 9.891912998272588, 8.888664114219994, 7.936897968473796, 6.938524524506833, 5.9613544755478225, 4.896310634940981, 3.9059752766655116, 2.986382210896724, 1.946738629678117, 0.9412076687017397, 1.9682376678391602, 2.8740593713335225, 3.816360127764862, 4.8217257707032495, 5.7416878114022625, 14.14707203429926, 13.103285597588265, 12.04762785864388, 11.035975544278623, 10.077840141500975, 9.018240498373023, 7.956687978114939, 6.947147976905043, 5.875975134316663, 4.947823951837634, 3.9467817402130017, 2.9369110725557253, 1.9568022392284385, 0.9921184246425991, 0.0, 0.9453790787697756, 1.874772677092103, 2.8044089875734084, 3.7934542219004155, 4.728128650466281, 14.696412417213924, 13.673421257726265, 12.736267944482023, 11.729448154381856, 10.674770998964133, 9.671921181800087, 8.728968004525303, 7.790072697337605, 6.85303142408867, 5.9172648406807, 4.88799561864239, 3.905073862413845, 2.9174650451335613, 2.0181337147916385, 1.0108573611897655, 1.8785606599152498, 2.8154375941927756, 3.77892313523048, 4.727948230520446, 5.681060018133125, 15.63245350130699, 14.620811765663598, 13.734149513833856, 12.718020003944345, 11.643211765542965, 10.609476914565922, 9.788197686872017, 8.754154281004608, 7.7687817945698745, 6.790176685718139, 5.834313689393942, 4.881651957054038, 3.8461680164277037, 2.9475888711976337, 1.9939692609774327, 2.8525522898659483, 3.851755915801455, 4.815289264030478, 5.699786265268062, 6.632745665669975], [6.68840927339679, 5.820885599728844, 4.89266126612653, 3.874330828994344, 2.9348134473965093, 3.841250890901155, 4.808612405468758, 5.718889074009225, 6.738118564257828, 7.676833316909541, 8.605572791433488, 9.563004854192595, 10.632800749267899, 11.642658220831075, 12.571963866036862, 13.529318201446463, 14.58073165613355, 15.54346013958698, 16.562370912428847, 17.516466545722285, 5.685945946249507, 6.616002389435968, 5.782346682804889, 4.8420008725428145, 3.863967660903108, 4.781450217155084, 5.763388780355818, 6.788092272299872, 7.677882513604395, 8.60367039349844, 9.603818152768142, 10.497888322619147, 11.446082670565463, 12.451137670019893, 13.401783804652984, 14.38051001756982, 15.420446485741058, 16.451348239084574, 17.430651656755188, 16.68773311348659, 4.855321235757391, 5.855915866952743, 6.8074042363739755, 5.807012826395992, 4.809620886465307, 5.747271790857588, 6.725680787978867, 7.734661786765253, 8.693480023325144, 9.652342180357465, 10.660680422382939, 11.444268214649961, 12.476037394740416, 13.445305036118773, 14.376213422440859, 15.133476071764504, 15.920707938698065, 16.737939073328832, 17.107707038812425, 16.086213818719013, 5.83566279282647, 6.81367021784693, 7.744615600307188, 6.75739589077674, 5.828244686057117, 6.7249143938898355, 7.665615833173017, 8.695249405197332, 9.66870564407727, 10.6548339454142, 11.612215016795577, 12.495496004752763, 13.46160357765918, 14.38764107387937, 14.901285181260922, 14.18378720995257, 14.909893330585865, 15.761987707561863, 16.72548835708336, 16.78556511622484, 6.8809543939146325, 7.806116232495338, 8.722388389673537, 7.744573211433669, 6.813878077734323, 7.727738691562143, 8.640574314286141, 9.679413599105352, 10.633269227234313, 11.606738769760062, 12.584877429950192, 13.431042964601078, 14.397559696825889, 14.673293038453295, 13.85191098426992, 13.13380014486435, 13.914408965919206, 14.830244142426686, 15.683113982100258, 16.512134855825874, 7.711517747239532, 8.729592778159208, 9.696572709373882, 8.694054988435449, 7.791425509308167, 8.741084594725459, 9.602289664664369, 10.634680211025678, 11.571437682216128, 12.574008501381204, 13.526665522243032, 14.44246580378119, 14.458025134099175, 13.672079486067062, 12.83150682555688, 12.083975669503591, 12.873006513074932, 13.794229703580452, 14.681984358547494, 15.454578119192945, 8.749264991504104, 9.689221851112908, 10.660415865831602, 9.702342595634272, 8.757364985096276, 9.708330919717058, 10.579078320493693, 11.63035945904813, 12.59996578084831, 13.560181969867966, 14.522741752585064, 14.50726238574465, 13.513063020115375, 12.615834549649302, 11.852926466674083, 11.013463495858785, 11.798428341062086, 12.741254681436942, 13.640696734113522, 14.484864829466899, 9.644181501675622, 10.686302029510117, 11.649634737813747, 10.711302548756478, 9.79059114813186, 10.730327409542658, 11.640998155325702, 12.587172411915022, 13.545456480351092, 14.55481825873152, 14.50215113577377, 13.52595437955615, 12.527799655271304, 11.58959502049619, 10.879357800706247, 9.943381119937738, 10.831715057758618, 11.813212190984506, 12.691080824466287, 13.496211910681884, 10.576600114068018, 11.632905681107212, 12.61292040579346, 11.672072942807342, 10.716414806547787, 11.698668414639512, 12.620998278918128, 13.556522183753557, 14.536790851321243, 14.522895455875512, 13.551151346065497, 12.531385686294039, 11.551812540652117, 10.625311762129682, 9.884865816281778, 8.965577229409673, 9.806801783956256, 10.746371377612155, 11.628475993612513, 12.528171182883174, 11.619049423233765, 12.675125413097517, 13.560382897584345, 12.60425568810389, 11.661386357431631, 12.642657366009999, 13.578946489819568, 14.511063710600318, 14.458045506209432, 13.528207670988223, 12.498296394652558, 11.55230620523699, 10.655662831779063, 9.632542052865329, 8.847603487554341, 7.9672221591499, 8.832311801914086, 9.813073476069428, 10.675921460071978, 11.534161243396259, 12.488446241723407, 13.435193835709761, 14.456296398857848, 13.643657160379457, 12.704564056548694, 13.632929522878513, 14.611716257177356, 14.474988068747578, 13.556728509884827, 12.526629572877763, 11.626877435909751, 10.587145717470737, 9.609533397579915, 8.697753643856391, 7.810912318515664, 6.897619927164049, 7.811770229319312, 8.829394716321922, 9.750551026260464, 10.588316578132785, 13.419943852001202, 14.445046389279456, 15.438774414852189, 14.700110047621571, 13.727579550116477, 14.686815427910926, 14.594223271602615, 13.543616433272634, 12.490693813994149, 11.541053475902125, 10.6015435529044, 9.632926921963987, 8.60153471179413, 7.727080184230012, 6.770135730757131, 5.8765632250247055, 6.85822719451706, 7.772853804997062, 8.711804748281642, 9.617508673999582, 14.427196189933174, 15.481244822764362, 16.407260054286372, 15.67304635360182, 14.699206380469029, 14.513778491525134, 13.543644304056704, 12.54884515027289, 11.533431300508763, 10.51765314617638, 9.584851268516141, 8.64027585625052, 7.676316588451577, 6.738595197247653, 5.806748327338026, 4.920869060987946, 5.856553848170924, 6.75988610286585, 7.694304357698945, 8.69215069158839, 15.479568871174061, 16.451132888089187, 16.794412687738564, 15.720956571727962, 14.716112738572674, 13.694649479700953, 12.625687166627722, 11.557366198478055, 10.60813109446288, 9.667359087524636, 8.616957246234112, 7.6891122968164725, 6.729002459898414, 5.805355221651798, 4.8511680543093245, 3.995787003799795, 4.9097954751788375, 5.814839758622793, 6.759062316559055, 7.783539356007271, 16.45912525326051, 16.87644630776714, 15.835809535211446, 14.762362290748072, 13.795450561886124, 12.769215471329424, 11.811836895250746, 10.781626896989739, 9.81687388517712, 8.835788726986431, 7.763886001538543, 6.717443553801505, 5.758498081008274, 4.8014528066696975, 3.865655619085622, 2.942343464360426, 3.9785741641865213, 4.8829681087453665, 5.8324161310351705, 6.76521283585835, 16.725648617032892, 15.839589907421725, 14.777575867209327, 13.806335034945297, 12.778841437293707, 11.808995569143262, 10.828222567841149, 9.87921316608961, 8.84116385282609, 7.831897820166939, 6.780733879893159, 5.818869907991919, 4.896518706153327, 3.9119285447325995, 2.8991826386822748, 2.0092952323648112, 2.9642861847728774, 3.8683446105745336, 4.933405659359515, 5.834702077527719, 15.784848074729986, 14.82041609981777, 13.852459980462049, 12.897117062851294, 11.903128445216428, 10.837292077042363, 9.83404319298977, 8.882277047243571, 7.883903603276608, 6.906733554317598, 5.841689713710757, 4.851354355435287, 3.9317612896664995, 2.8921177084478926, 1.8865867474715152, 1.0504406998624747, 1.928680292563747, 2.8709810489950867, 3.876346691933474, 4.796308732632487, 15.092451113069036, 14.04866467635804, 12.993006937413655, 11.981354623048398, 11.02321922027075, 9.963619577142799, 8.902067056884714, 7.892527055674819, 6.821354213086439, 5.89320303060741, 4.892160818982777, 3.882290151325501, 2.902181317998214, 1.9374975034123747, 0.9453790787697756, 0.0, 0.9293935983223274, 1.8590299088036328, 2.84807514313064, 3.782749571696505, 15.6417914959837, 14.61880033649604, 13.681647023251799, 12.674827233151632, 11.620150077733909, 10.617300260569863, 9.674347083295078, 8.73545177610738, 7.798410502858445, 6.862643919450475, 5.833374697412165, 4.850452941183621, 3.862844123903337, 2.963512793561414, 1.952606402618036, 0.9331815811454741, 1.870058515423, 2.8335440564607044, 3.7825691517506703, 4.735680939363349, 16.577832580076766, 15.566190844433374, 14.679528592603631, 13.66339908271412, 12.58859084431274, 11.554855993335698, 10.733576765641793, 9.699533359774383, 8.714160873339651, 7.7355557644879145, 6.779692768163717, 5.827031035823815, 4.79154709519748, 3.8497918402413758, 2.896172230021175, 1.9071732110961728, 2.9063768370316794, 3.8699101852607027, 4.754407186498287, 5.6873665869001995], [5.759015675074463, 4.891492001406517, 3.963267667804203, 3.0173362391135603, 3.8642070457188367, 4.770644489223483, 5.738006003791085, 6.648282672331552, 7.667512162580155, 8.606226915231868, 9.534966389755816, 10.492398452514923, 11.562194347590225, 12.572051819153401, 13.501357464359188, 14.458711799768789, 15.510125254455875, 16.472853737909308, 17.491764510751167, 18.44586014404461, 4.7565523479271805, 5.686608791113641, 4.925352092924105, 3.985006282662031, 4.793361259225436, 5.7108438154774115, 6.692782378678146, 7.717485870622199, 8.607276111926721, 9.533063991820768, 10.53321175109047, 11.427281920941475, 12.375476268887791, 13.38053126834222, 14.331177402975312, 15.309903615892148, 15.962363887139565, 16.752603251692825, 17.683074334912295, 17.617126711808915, 3.925927637435064, 4.926522268630415, 5.968504275784183, 5.005461029630707, 5.739014484787635, 6.676665389179916, 7.6550743863011945, 8.66405538508758, 9.622873621647472, 10.581735778679793, 11.590074020705266, 12.373661812972289, 13.405430993062744, 14.374698634441101, 15.305607020763187, 15.979320839403014, 14.99131434037574, 15.808545475006504, 16.72457884183734, 17.015607417041338, 4.906269194504143, 5.884276619524602, 6.905715639717396, 6.0160330150069745, 6.7576382843794445, 7.654307992212163, 8.595009431495344, 9.62464300351966, 10.598099242399599, 11.584227543736528, 12.541608615117905, 13.42488960307509, 14.390997175981507, 15.317034672201698, 15.75529124808091, 15.02963197759108, 13.980499732263539, 14.832594109239535, 15.796094758761035, 16.534014677046116, 5.951560795592305, 6.87672263417301, 7.854561713258818, 7.054715721644996, 7.743271676056651, 8.657132289884471, 9.569967912608469, 10.60880719742768, 11.562662825556641, 12.53613236808239, 13.51427102827252, 14.360436562923406, 15.326953295148217, 15.602686636775623, 14.705917051089909, 13.979644912502861, 12.98501536759688, 13.900850544104358, 14.753720383777933, 15.582741257503546, 6.782124148917206, 7.800199179836883, 8.837631043641792, 8.004197498646775, 8.720819107630495, 9.670478193047787, 10.531683262986697, 11.564073809348006, 12.500831280538456, 13.503402099703532, 14.45605912056536, 15.371859402103517, 15.387418732421503, 14.60147308438939, 13.685512892376869, 12.929820437142101, 11.943612914752606, 12.864836105258124, 13.75259076022517, 14.525184520870617, 7.819871393181776, 8.75982825279058, 9.731022267509275, 9.012485105845599, 9.686758583418605, 10.637724518039386, 11.50847191881602, 12.559753057370457, 13.529359379170637, 14.489575568190293, 15.452135350907392, 15.436655984066977, 14.442456618437703, 13.54522814797163, 12.70693253349407, 11.859308263497294, 10.86903474273976, 11.811861083114616, 12.711303135791198, 13.55547123114457, 8.714787903353294, 9.756908431187789, 10.720241139491419, 10.021445058967805, 10.719984746454191, 11.65972100786499, 12.57039175364803, 13.51656601023735, 14.47485007867342, 15.484211857053849, 15.431544734096098, 14.455347977878478, 13.457193253593632, 12.518988618818518, 11.733363867526235, 10.789225887576247, 9.902321459436292, 10.88381859266218, 11.761687226143962, 12.566818312359556, 9.64720651574569, 10.703512082784885, 11.683526807471132, 11.010873907880438, 11.645808404870118, 12.628062012961843, 13.550391877240456, 14.485915782075885, 15.46618444964357, 15.45228905419784, 14.480544944387825, 13.460779284616367, 12.481206138974445, 11.55470536045201, 10.738871883101766, 9.811421997048182, 8.87740818563393, 9.816977779289829, 10.699082395290187, 11.598777584560846, 10.689655824911437, 11.745731814775189, 12.630989299262017, 12.057616446431098, 12.590779955753963, 13.57205096433233, 14.5083400881419, 15.440457308922646, 15.38743910453176, 14.457601269310551, 13.427689992974885, 12.481699803559318, 11.58505643010139, 10.561935651187657, 9.776997085876669, 8.896615757472226, 7.90291820359176, 8.883679877747102, 9.746527861749652, 10.604767645073931, 11.55905264340108, 12.505800237387433, 13.52690280053552, 13.097017918706664, 13.633957654871026, 14.562323121200844, 15.541109855499688, 15.404381667069906, 14.486122108207155, 13.45602317120009, 12.55627103423208, 11.516539315793064, 10.538926995902242, 9.627147242178719, 8.740305916837992, 7.827013525486375, 6.882376630996986, 7.9000011179995955, 8.821157427938138, 9.658922979810457, 12.490550253678874, 13.515652790957128, 14.50938081652986, 14.153470805948778, 14.656973148438809, 15.616209026233257, 15.523616869924943, 14.473010031594962, 13.420087412316477, 12.470447074224452, 11.530937151226729, 10.562320520286315, 9.530928310116458, 8.65647378255234, 7.699529329079459, 6.8059568233470324, 5.928833596194734, 6.843460206674736, 7.782411149959315, 8.688115075677254, 13.497802591610846, 14.551851224442034, 15.477866455964044, 15.126407111929026, 15.62859997879136, 15.443172089847462, 14.473037902379032, 13.478238748595217, 12.46282489883109, 11.447046744498708, 10.51424486683847, 9.569669454572848, 8.605710186773905, 7.667988795569981, 6.736141925660354, 5.850262659310273, 4.927160249848598, 5.830492504543523, 6.764910759376618, 7.762757093266062, 14.550175272851734, 15.52173928976686, 16.46302509066474, 16.059005720701016, 15.645506336895002, 14.62404307802328, 13.55508076495005, 12.486759796800383, 11.537524692785208, 10.596752685846964, 9.54635084455644, 8.6185058951388, 7.658396058220742, 6.734748819974126, 5.780561652631652, 4.925180602122122, 3.980401876856511, 4.885446160300466, 5.829668718236728, 6.854145757684944, 15.52973165493818, 16.50935202856719, 16.76520313353377, 15.691755889070397, 14.724844160208448, 13.698609069651754, 12.741230493573076, 11.711020495312068, 10.74626748349945, 9.765182325308759, 8.69327959986087, 7.646837152123833, 6.687891679330602, 5.730846404992025, 4.79504921740795, 3.871737062682753, 3.0491805658641944, 3.953574510423039, 4.903022532712844, 5.835819237536024, 16.509998048815298, 16.76898350574405, 15.706969465531651, 14.735728633267621, 13.708235035616031, 12.738389167465586, 11.757616166163473, 10.808606764411934, 9.77055745114842, 8.761291418489268, 7.710127478215487, 6.748263506314247, 5.825912304475656, 4.841322143054928, 3.828576237004602, 2.9386888306871386, 2.03489258645055, 2.9389510122522067, 4.004012061037189, 4.905308479205392, 16.714241673052314, 15.749809698140098, 14.781853578784377, 13.826510661173621, 12.832522043538754, 11.76668567536469, 10.763436791312095, 9.811670645565897, 8.813297201598935, 7.836127152639925, 6.771083312033084, 5.780747953757614, 4.861154887988827, 3.8215113067702204, 2.8159803457938426, 1.979834298184802, 0.9992866942414195, 1.9415874506727597, 2.946953093611147, 3.866915134310159, 16.02184471139136, 14.978058274680365, 13.92240053573598, 12.910748221370723, 11.952612818593074, 10.893013175465125, 9.83146065520704, 8.821920653997145, 7.750747811408765, 6.822596628929736, 5.821554417305104, 4.811683749647828, 3.8315749163205415, 2.8668911017347023, 1.874772677092103, 0.9293935983223274, 0.0, 0.9296363104813056, 1.9186815448083125, 2.853355973374178, 16.571185094306024, 15.548193934818364, 14.611040621574123, 13.604220831473956, 12.549543676056235, 11.546693858892189, 10.603740681617404, 9.664845374429706, 8.727804101180771, 7.792037517772801, 6.762768295734492, 5.7798465395059475, 4.792237722225664, 3.8929063918837414, 2.8820000009403635, 1.8625751794678016, 0.9406649171006727, 1.9041504581383772, 2.8531755534283434, 3.8062873410410223, 17.50722617839909, 16.495584442755696, 15.608922190925957, 14.592792681036446, 13.517984442635067, 12.484249591658024, 11.662970363964119, 10.62892695809671, 9.643554471661977, 8.66494936281024, 7.709086366486044, 6.756424634146142, 5.720940693519807, 4.779185438563703, 3.8255658283435023, 2.8365668094185, 1.9769832387093518, 2.940516586938376, 3.8250135881759597, 4.7579729885778725], [4.84001809148525, 3.9724944178173045, 3.0442700842149906, 3.946972549594866, 4.793843356200142, 5.700280799704789, 6.667642314272392, 7.577918982812857, 8.59714847306146, 9.535863225713172, 10.46460270023712, 11.422034762996226, 12.491830658071532, 13.501688129634708, 14.430993774840495, 15.388348110250096, 16.439761564937182, 16.990983036213024, 17.78105773067665, 18.553039273923353, 3.837554764337968, 4.767611207524428, 4.08057590487497, 4.914642593143337, 5.722997569706741, 6.640480125958717, 7.622418689159453, 8.647122181103505, 9.536912422408026, 10.462700302302071, 11.462848061571773, 12.356918231422778, 13.305112579369094, 14.310167578823524, 15.260813713456615, 16.239539926373453, 16.89200019762087, 16.010530612507115, 16.753438024430988, 17.534389933191846, 2.9962913269537585, 3.99688595814911, 5.038867965302878, 5.935097340112013, 6.66865079526894, 7.606301699661222, 8.584710696782501, 9.593691695568886, 10.552509932128777, 11.511372089161096, 12.51971033118657, 13.303298123453592, 14.335067303544047, 15.304334944922404, 16.23524333124449, 16.90895714988432, 15.920950650857044, 15.066472835820793, 15.79494253135603, 16.575122147784764, 3.976632884022838, 4.954640309043297, 5.976079329236091, 6.94566932548828, 7.6872745948607495, 8.58394430269347, 9.52464574197665, 10.554279314000967, 11.527735552880904, 12.513863854217833, 13.471244925599212, 14.354525913556394, 15.32063348646281, 16.246670982683003, 16.684927558562215, 15.959268288072384, 14.910136042744844, 14.090521470053824, 14.866458448279728, 15.60437836656481, 5.021924485111, 5.947086323691705, 6.924925402777513, 7.984352032126302, 8.672907986537956, 9.586768600365776, 10.499604223089776, 11.538443507908987, 12.492299136037948, 13.465768678563697, 14.443907338753826, 15.290072873404709, 16.256589605629518, 16.53232294725693, 15.635553361571214, 14.909281222984164, 13.914651678078185, 13.158777904918647, 13.824084073296627, 14.65310494702224, 5.852487838435899, 6.8705628693555765, 7.907994733160486, 8.91051245409892, 9.6504554181118, 10.600114503529092, 11.461319573468003, 12.493710119829313, 13.430467591019763, 14.433038410184839, 15.385695431046667, 16.30149571258482, 16.317055042902812, 15.531109394870697, 14.615149202858174, 13.859456747623405, 12.873249225233911, 12.122763466072414, 12.822954449743863, 13.59554821038931, 6.89023508270047, 7.830191942309274, 8.80138595702797, 9.819927586103185, 10.61639489389991, 11.567360828520691, 12.438108229297328, 13.489389367851764, 14.458995689651944, 15.4192118786716, 16.3817716613887, 16.366292294548284, 15.37209292891901, 14.474864458452936, 13.636568843975375, 12.788944573978599, 11.798671053221065, 11.069788443928905, 11.781666825309891, 12.625834920663264, 7.785151592871988, 8.827272120706482, 9.790604829010112, 10.828887539225391, 11.649621056935494, 12.589357318346293, 13.500028064129337, 14.446202320718657, 15.404486389154727, 16.413848167535157, 16.361181044577403, 15.384984288359785, 14.386829564074938, 13.448624929299825, 12.66300017800754, 11.718862198057552, 10.831957769917597, 10.030988518890453, 10.832050915662656, 11.63718200187825, 8.717570205264385, 9.77387577230358, 10.753890496989827, 11.720741424215795, 12.575444715351422, 13.557698323443146, 14.480028187721762, 15.415552092557192, 16.395820760124877, 16.381925364679145, 15.41018125486913, 14.390415595097672, 13.41084244945575, 12.484341670933315, 11.66850819358307, 10.741058307529487, 9.807044496115235, 8.964147705518101, 9.769446084808882, 10.66914127407954, 9.76001951443013, 10.816095504293882, 11.701352988780712, 12.695429182504197, 13.520416266235266, 14.501687274813634, 15.437976398623203, 16.370093619403953, 16.317075415013065, 15.387237579791856, 14.35732630345619, 13.411336114040623, 12.514692740582696, 11.491571961668962, 10.706633396357974, 9.826252067953533, 8.832554514073065, 8.030849803975375, 8.816891551268347, 9.675131334592624, 10.629416332919773, 11.576163926906126, 12.597266490054214, 13.627343616515134, 14.563593965352329, 15.491959431682147, 16.47074616598099, 16.33401797755121, 15.41575841868846, 14.385659481681396, 13.485907344713384, 12.44617562627437, 11.468563306383547, 10.556783552660024, 9.669942227319297, 8.756649835967682, 7.812012941478291, 6.970364807518289, 7.891521117456832, 8.72928666932915, 11.560913943197567, 12.586016480475822, 13.579744506048554, 14.598849120801356, 15.586609458920112, 16.54584533671456, 16.45325318040625, 15.402646342076267, 14.349723722797782, 13.400083384705757, 12.460573461708034, 11.49195683076762, 10.460564620597763, 9.586110093033644, 8.629165639560764, 7.735593133828338, 6.858469906676039, 5.9138238961934295, 6.852774839478009, 7.758478765195949, 12.568166281129539, 13.622214913960727, 14.548230145482737, 15.482341909905115, 16.53798374883574, 16.372808400328765, 15.402674212860337, 14.407875059076522, 13.392461209312396, 12.376683054980013, 11.443881177319774, 10.499305765054153, 9.53534649725521, 8.597625106051286, 7.665778236141659, 6.779898969791579, 5.856796560329903, 4.900856194062217, 5.835274448895312, 6.833120782784756, 13.620538962370427, 14.592102979285553, 15.533388780183431, 16.414940518677103, 16.575142647376307, 15.553679388504586, 14.484717075431355, 13.416396107281688, 12.467161003266513, 11.526388996328269, 10.475987155037744, 9.548142205620104, 8.588032368702047, 7.664385130455431, 6.710197963112957, 5.854816912603428, 4.910038187337816, 3.9558098498191603, 4.900032407755422, 5.924509447203638, 14.600095344456873, 15.579715718085883, 16.563662434060372, 16.621392199551703, 15.654480470689755, 14.628245380133057, 13.670866804054379, 12.640656805793371, 11.675903793980753, 10.694818635790064, 9.622915910342176, 8.576473462605138, 7.617527989811907, 6.66048271547333, 5.724685527889255, 4.801373373164059, 3.9788168763454994, 3.023938199941733, 3.9733862222315377, 4.906182927054717, 15.58036173833399, 16.526455138672752, 16.636605776012956, 15.665364943748928, 14.637871346097338, 13.668025477946893, 12.68725247664478, 11.73824307489324, 10.700193761629723, 9.690927728970573, 8.639763788696792, 7.677899816795552, 6.75554861495696, 5.770958453536232, 4.758212547485908, 3.868325141168444, 2.9645288969318555, 2.0093147017709008, 3.0743757505558826, 3.9756721687240866, 16.521162280636894, 16.679446008621404, 15.711489889265684, 14.756146971654928, 13.76215835402006, 12.696321985845996, 11.693073101793402, 10.741306956047204, 9.742933512080242, 8.765763463121232, 7.70071962251439, 6.71038426423892, 5.7907911984701315, 4.751147617251525, 3.745616656275148, 2.9094706086661075, 1.928923004722725, 1.011951140191454, 2.017316783129841, 2.937278823828854, 16.951481021872667, 15.907694585161671, 14.852036846217286, 13.84038453185203, 12.882249129074381, 11.822649485946432, 10.761096965688347, 9.751556964478452, 8.680384121890071, 7.7522329394110425, 6.75119072778641, 5.741320060129134, 4.761211226801847, 3.7965274122160073, 2.8044089875734084, 1.8590299088036328, 0.9296363104813056, 0.0, 0.9890452343270071, 1.9237196628928723, 17.50082140478733, 16.47783024529967, 15.54067693205543, 14.533857141955263, 13.479179986537542, 12.476330169373496, 11.533376992098711, 10.594481684911013, 9.657440411662078, 8.721673828254108, 7.692404606215797, 6.7094828499872525, 5.721874032706969, 4.8225427023650465, 3.811636311421669, 2.792211489949107, 1.8703012275819781, 0.9851528745491649, 1.9341779698391308, 2.8872897574518097, 18.436862488880397, 17.425220753237003, 16.538558501407262, 15.522428991517753, 14.447620753116373, 13.41388590213933, 12.592606674445426, 11.558563268578016, 10.573190782143282, 9.594585673291546, 8.63872267696735, 7.686060944627447, 6.650577004001112, 5.7088217490450095, 4.755202138824808, 3.7662031198998056, 2.9066195491906575, 2.0215190033491632, 2.906016004586747, 3.83897540498866], [3.920549202653148, 3.0546790811673192, 4.024504938144938, 4.936017783921873, 5.78288859052715, 6.6893260340317955, 7.656687548599399, 8.566964217139866, 9.586193707388468, 10.52490846004018, 11.453647934564128, 12.411079997323235, 13.480875892398538, 14.490733363961715, 15.420039009167501, 16.3773933445771, 17.428806799264187, 17.829507469868666, 16.95160001161489, 17.701398913926575, 2.9180858755058656, 3.848142318692326, 4.820782898184664, 5.761128708446738, 6.712042804033748, 7.629525360285724, 8.61146392348646, 9.636167415430513, 10.525957656735034, 11.45174553662908, 12.451893295898781, 13.345963465749787, 14.294157813696103, 15.299212813150532, 16.249858947783622, 17.228585160700458, 17.879956799506274, 16.849055046162757, 15.923980305369227, 16.682749573195068, 2.0072460926267515, 3.0078407238221025, 4.049822730975871, 5.050214140953854, 6.047606080884539, 7.0188050154092965, 8.064712553065329, 9.108823697385482, 10.067641933945373, 11.108329486143115, 12.176399590963289, 13.213588413066937, 14.245357593157392, 15.214625234535749, 16.15592557924812, 17.203751556562775, 16.90999588518405, 15.904997269476436, 14.96548481229427, 15.723481787787986, 2.987587649695831, 3.9655950747162896, 4.987034094909085, 6.039436099350675, 6.968587304070298, 7.938522445751718, 8.894912393115188, 9.924545965139504, 10.908353935822399, 11.894482237159329, 12.851863308540707, 13.87950410165608, 14.902774568140323, 15.878514073070773, 16.85101750123311, 16.948313522399392, 15.89918127707185, 14.957602075957562, 14.037000729217967, 14.752738006568029, 4.032879250783993, 4.958041089364698, 5.935880168450505, 6.999399605936857, 7.9300947396362025, 8.857277301962482, 9.786955191536, 10.825794476355211, 11.779650104484173, 12.753119647009921, 13.817821057624093, 14.815051061504395, 15.781567793729206, 16.72230165531167, 16.62459859589822, 15.898326457311173, 14.903696912405191, 14.025858510822385, 12.994626354234866, 13.801464587025459, 4.9549747648720475, 5.965219365682485, 6.928930279590844, 7.931448000529278, 8.907642171210046, 9.870623205125797, 10.748670541914228, 11.781061088275537, 12.717818559465988, 13.720389378631063, 14.724264382070983, 15.6684594610028, 16.679833683195117, 16.5201546291977, 15.60419443718518, 14.848501981950413, 13.862294459560918, 12.989844071976151, 11.993496730682102, 12.74390785039253, 5.992722009136617, 6.929215579349042, 7.900409594067737, 8.918951223142953, 9.873581646998156, 10.837869530117397, 11.725459197743552, 12.776740336297989, 13.746346658098169, 14.706562847117825, 15.720340612413015, 16.61384807505734, 16.361138163246014, 15.463909692779941, 14.625614078302382, 13.777989808305605, 12.787716287548072, 11.95687860416835, 10.95220910624813, 11.774194560666484, 6.923350641116977, 7.926295757746249, 8.88962846604988, 9.927911176265159, 10.90680781003374, 11.846544071444539, 12.787379032575561, 13.733553289164881, 14.691837357600951, 15.70119913598138, 16.7109492997832, 16.37402952268679, 15.375874798401943, 14.43767016362683, 13.652045412334546, 12.707907432384559, 11.821003004244604, 10.957839021646516, 10.002593196600895, 10.78554164188147, 7.855769253509374, 8.88038230550043, 9.857691262928336, 10.824542190154304, 11.780200326413858, 12.762453934505583, 13.767379156167987, 14.702903061003417, 15.683171728571102, 16.692594215004757, 16.39922648919614, 15.379460829424678, 14.399887683782756, 13.473386905260321, 12.657553427910077, 11.730103541856494, 10.796089730442242, 9.95319293984511, 8.93998836574712, 9.817500914082759, 8.90837915443335, 9.938961620871776, 10.805153754719221, 11.799229948442706, 12.7251718772977, 13.706442885876069, 14.642732009685638, 15.657444587850177, 16.629556269041345, 16.376282814118866, 15.346371537783197, 14.40038134836763, 13.503737974909702, 12.480617195995968, 11.69567863068498, 10.815297302280541, 9.821599748400072, 9.019895038302383, 7.987433832206584, 8.823490974595844, 9.777775972922992, 10.724523566909346, 11.745626130057433, 12.775703256518353, 13.768349576414764, 14.696715042744582, 15.675501777043426, 16.634786290802683, 16.404803653015467, 15.374704716008404, 14.474952579040393, 13.435220860601376, 12.457608540710554, 11.54582878698703, 10.658987461646303, 9.74569507029469, 8.801058175805297, 7.959410041845295, 7.06206339839507, 7.877646309332369, 10.709273583200787, 11.734376120479041, 12.728104146051773, 13.747208760804575, 14.773950855896066, 15.750600947776995, 16.67749006945646, 16.391691576403275, 15.33876895712479, 14.389128619032766, 13.449618696035042, 12.481002065094627, 11.44960985492477, 10.575155327360651, 9.61821087388777, 8.724638368155347, 7.847515141003045, 6.902869130520436, 6.023317120416247, 6.906838405199167, 11.716525921132758, 12.770574553963947, 13.696589785485957, 14.630701549908334, 15.686343388838958, 16.64968606689865, 16.391719447187345, 15.39692029340353, 14.381506443639404, 13.365728289307022, 12.432926411646783, 11.48835099938116, 10.524391731582217, 9.586670340378292, 8.654823470468665, 7.768944204118586, 6.845841794656909, 5.889901428389224, 5.00581672983355, 5.981480422787975, 12.768898602373646, 13.740462619288772, 14.68174842018665, 15.563300158680324, 16.568143991835612, 16.542724622831592, 15.473762309758364, 14.405441341608697, 13.456206237593522, 12.515434230655277, 11.465032389364753, 10.537187439947113, 9.577077603029053, 8.653430364782437, 7.699243197439964, 6.8438621469304355, 5.899083421664823, 4.944855084146167, 4.002519334191569, 5.026996373639785, 13.748454984460093, 14.728075358089104, 15.71202207406359, 16.63479379390462, 16.643525705016764, 15.617290614460066, 14.659912038381387, 13.62970204012038, 12.664949028307761, 11.683863870117072, 10.611961144669184, 9.565518696932147, 8.606573224138915, 7.649527949800337, 6.713730762216262, 5.790418607491066, 4.967862110672507, 4.01298343426874, 3.075873148667685, 4.008669853490865, 14.728721378337209, 15.67481477867597, 16.736828818888366, 16.654410178075935, 15.626916580424346, 14.657070712273901, 13.676297710971788, 12.72728830922025, 11.689238995956732, 10.679972963297582, 9.6288090230238, 8.66694505112256, 7.744593849283968, 6.7600036878632395, 5.747257781812914, 4.857370375495451, 3.9535741312588626, 2.9983599360979083, 2.113441016044759, 2.9866269343970795, 15.669521920640113, 16.63395389555233, 16.700535123592687, 15.745192205981933, 14.751203588347067, 13.685367220173003, 12.682118336120409, 11.73035219037421, 10.731978746407247, 9.754808697448237, 8.689764856841396, 7.6994294985659275, 6.77983643279714, 5.7401928515785325, 4.734661890602155, 3.8985158429931146, 2.917968239049732, 2.0009963745184614, 1.0500777907326244, 1.948233589501847, 16.717244493437963, 16.89673981948868, 15.841082080544295, 14.829429766179038, 13.87129436340139, 12.811694720273438, 11.750142200015354, 10.740602198805458, 9.669429356217078, 8.74127817373805, 7.740235962113418, 6.730365294456141, 5.7502564611288545, 4.785572646543015, 3.7934542219004155, 2.84807514313064, 1.9186815448083125, 0.9890452343270071, 0.0, 0.9346744285658654, 17.69451918961557, 17.46687547962668, 16.529722166382438, 15.522902376282271, 14.468225220864548, 13.465375403700502, 12.522422226425718, 11.58352691923802, 10.646485645989085, 9.710719062581115, 8.681449840542804, 7.69852808431426, 6.710919267033977, 5.811587936692054, 4.800681545748676, 3.781256724276114, 2.8593464619089852, 1.965387728479112, 1.016362633189146, 1.967820868619707, 18.630560273708635, 17.94778007961036, 17.527603735734267, 16.511474225844758, 15.43666598744338, 14.402931136466337, 13.581651908772432, 12.547608502905023, 11.562236016470289, 10.583630907618552, 9.627767911294356, 8.675106178954454, 7.639622238328119, 6.697866983372016, 5.744247373151815, 4.755248354226813, 3.895664783517664, 3.0017538572791107, 1.9882006679367623, 2.9195065161565568], [2.985874774087282, 3.8580236996763744, 4.849106077442545, 5.794124323429343, 6.7175630190930145, 7.62400046259766, 8.591361977165263, 9.50163864570573, 10.520868135954334, 11.459582888606047, 12.388322363129994, 13.345754425889101, 14.415550320964403, 15.42540779252758, 16.354713437733366, 17.312067773142967, 18.363481227830054, 18.597956580985635, 17.720049122731858, 16.814144887265424, 1.98341144694, 2.9134678901264603, 3.886108469618798, 4.826454279880872, 5.808836491622761, 6.811807532354777, 7.859324952639701, 8.900746011398248, 9.915583523813009, 10.920417320252328, 11.92056507952203, 12.913204542272696, 13.861398890219013, 14.866453889673442, 15.817100024306534, 16.79582623722337, 17.835762705394608, 17.617504157279726, 16.692429416486195, 15.795495546533916, 1.0725716640608862, 2.0731662952562377, 3.115148302410006, 4.1155397123879895, 5.112931652318674, 6.084130586843432, 7.130038124499463, 8.174149268819617, 9.132967505379508, 10.17365505757725, 11.241725162397424, 12.278913984501072, 13.310683164591527, 14.279950805969884, 15.221251150682253, 16.26907712799691, 17.332534028262767, 16.673446380593404, 15.733933923411238, 14.836227761126835, 2.052913221129965, 3.030920646150425, 4.05235966634322, 5.10476167078481, 6.033912875504433, 7.003848017185853, 7.960237964549324, 8.98987153657364, 9.973679507256534, 10.959807808593464, 11.91718887997484, 12.944829673090213, 13.968100139574457, 14.943839644504907, 15.916343072667242, 16.887004078527557, 16.828680378423954, 15.821399332239297, 14.805449840334935, 13.865483979906879, 3.0982048222181273, 4.023366660798833, 5.00120573988464, 6.064725177370992, 6.995420311070338, 7.922602873396617, 8.852280762970135, 9.891120047789347, 10.844975675918308, 11.818445218444056, 12.883146629058228, 13.880376632938528, 14.84689336516334, 15.787627226745805, 16.782220493099356, 16.827825558663275, 15.833196013757295, 14.88965576710412, 13.858423610516601, 12.914210560364308, 4.0284756892993, 5.03054493711662, 5.994255851024979, 6.996773571963413, 7.972967742644181, 8.935948776559933, 9.813996113348363, 10.846386659709673, 11.783144130900123, 12.785714950065199, 13.789589953505118, 14.733785032436936, 15.745159254629252, 16.72975679086774, 16.533693538537285, 15.778001083302517, 14.791793560913021, 13.853641328257886, 12.857293986963837, 11.85665382373138, 5.0726678327780395, 5.994541150783177, 6.965735165501872, 7.984276794577088, 8.938907218432291, 9.903195101551532, 10.790784769177687, 11.842065907732124, 12.811672229532304, 13.77188841855196, 14.78566618384715, 15.679173646491476, 16.690121368613053, 16.398584121345806, 15.555113179654485, 14.707488909657709, 13.717215388900176, 12.820675860450086, 11.816006362529865, 10.886940534005333, 6.0032964647583995, 6.991621329180385, 7.954954037484015, 8.993236747699294, 9.972133381467877, 10.911869642878676, 11.852704604009697, 12.798878860599016, 13.757162929035086, 14.766524707415515, 15.776274871217336, 16.660481652679977, 16.31054922696781, 15.372344592192697, 14.58154451368665, 13.637406533736662, 12.750502105596707, 11.854833622454448, 10.899587797408827, 9.898287615220319, 6.935715077150796, 7.945707876934564, 8.923016834362471, 9.88986776158844, 10.845525897847994, 11.827779505939718, 12.832704727602122, 13.768228632437552, 14.748497300005237, 15.75791978643889, 16.775833603273014, 16.314135257990543, 15.334562112348623, 14.408061333826188, 13.58705252926218, 12.659602643208597, 11.725588831794346, 10.862525277341792, 9.836982966555052, 8.930246887421609, 7.989457012985127, 9.004287192305911, 9.870479326153356, 10.864555519876841, 11.790497448731838, 12.771768457310205, 13.708057581119775, 14.722770159284313, 15.694881840475478, 16.62471967569669, 16.281045966349065, 15.335055776933496, 14.438412403475569, 13.415291624561835, 12.630353059250847, 11.749971730846406, 10.751098849752175, 9.929227375799066, 8.884428433014516, 7.9362369479346935, 8.890521946261842, 9.837269540248196, 10.858372103396283, 11.888449229857203, 12.8336751478489, 13.76204061417872, 14.740827348477563, 15.70011186223682, 16.719110340058457, 16.309379144574272, 15.40962700760626, 14.369895289167243, 13.39228296927642, 12.480503215552897, 11.59366189021217, 10.680369498860555, 9.7305572771574, 8.868742379341978, 7.959057999203003, 6.99039228267122, 9.822019556539637, 10.847122093817891, 11.840850119390623, 12.859954734143425, 13.856690641416684, 14.815926519211132, 15.742815640890596, 16.631483497711763, 16.273443385690655, 15.323803047598632, 14.384293124600909, 13.415676493660493, 12.384284283490636, 11.509829755926518, 10.552885302453637, 9.659312796721212, 8.777014242355149, 7.812201468017118, 6.92031172122418, 6.019584378538018, 10.829271894471608, 11.883320527302796, 12.809335758824806, 13.743447523247184, 14.799089362177808, 15.762432040237497, 16.732566227705927, 16.3315947219694, 15.31618087220527, 14.300402717872888, 13.36760084021265, 12.423025427947026, 11.459066160148083, 10.521344768944159, 9.589497899034532, 8.703618632684451, 7.775340896009013, 6.799233765885906, 5.902811330641483, 5.0942263961268255, 11.881644575712496, 12.853208592627622, 13.7944943935255, 14.676046132019174, 15.680889965174462, 16.70235322404618, 16.40843673832423, 15.340115770174563, 14.390880666159388, 13.450108659221144, 12.39970681793062, 11.47186186851298, 10.51175203159492, 9.588104793348304, 8.63391762600583, 7.7785365754963, 6.833757850230688, 5.854187421642849, 4.899513934999502, 4.139742346978636, 12.861200957798943, 13.840821331427954, 14.82476804740244, 15.747539767243472, 16.650624950165565, 16.551965043025934, 15.594586466947254, 14.564376468686246, 13.599623456873628, 12.618538298682939, 11.54663557323505, 10.500193125498013, 9.541247652704781, 8.584202378366204, 7.648405190782127, 6.725093036056931, 5.902536539238372, 4.9223157717654225, 3.9728677494756175, 3.082170777918117, 13.841467351676059, 14.78756075201482, 15.849574792227218, 16.70620371574355, 16.56159100899021, 15.591745140839764, 14.610972139537651, 13.661962737786112, 12.623913424522598, 11.614647391863446, 10.563483451589665, 9.601619479688425, 8.679268277849832, 7.694678116429104, 6.68193221037878, 5.792044804061316, 4.888248559824728, 3.933034364663773, 3.010435616852692, 2.0519525058312142, 14.782267893978963, 15.746699868891179, 16.7146559882469, 16.6798666345478, 15.685878016912932, 14.620041648738868, 13.616792764686274, 12.665026618940075, 11.666653174973113, 10.689483126014103, 9.624439285407263, 8.634103927131793, 7.714510861363005, 6.674867280144397, 5.66933631916802, 4.83319027155898, 3.8526426676155974, 2.935670803084326, 1.9847522192984899, 1.0135591609359815, 15.829990466776813, 16.797919056524616, 16.775756509110156, 15.7641041947449, 14.805968791967253, 13.746369148839303, 12.684816628581219, 11.675276627371323, 10.604103784782943, 9.675952602303914, 8.674910390679281, 7.665039723022006, 6.684930889694719, 5.72024707510888, 4.728128650466281, 3.782749571696505, 2.853355973374178, 1.9237196628928723, 0.9346744285658654, 0.0, 16.80726516295442, 17.808698145390178, 17.4643965949483, 16.457576804848134, 15.402899649430413, 14.400049832266367, 13.457096654991583, 12.518201347803885, 11.58116007455495, 10.64539349114698, 9.616124269108669, 8.633202512880125, 7.645593695599842, 6.746262365257919, 5.735355974314541, 4.715931152841979, 3.7940208904748505, 2.900062157044977, 1.9510370617550112, 1.0331464400538415, 17.743306247047485, 18.71622919072733, 18.462278164300134, 17.446148654410624, 16.371340416009247, 15.337605565032202, 14.516326337338297, 13.482282931470888, 12.496910445036153, 11.518305336184417, 10.56244233986022, 9.60978060752032, 8.574296666893984, 7.632541411937881, 6.67892180171768, 5.689922782792678, 4.83033921208353, 3.9364282858449755, 2.9228750965026276, 1.9848320875906915], [18.100097388672424, 18.666286932331126, 18.563967434854835, 17.504421850070134, 16.5649044684723, 15.514446310468566, 14.533371012751212, 13.567369521079307, 12.548140030830705, 11.609425278178993, 10.680685803655045, 9.800190541265877, 8.80368869303684, 7.9043912584436775, 6.971569890066121, 5.9798875976137875, 4.94448602289129, 3.9817575394378593, 2.942491061446864, 1.8746750497385842, 17.09763406152514, 17.72173112278121, 18.021535531762478, 17.081189721500404, 16.098807509758515, 15.0958364690265, 14.048319048741575, 13.00689798998303, 11.992060477568268, 10.987226681128949, 9.987078921859247, 8.99443945910858, 8.046245111162264, 7.041190111707835, 6.090543977074745, 5.111817764157909, 4.07188129598667, 3.0409795426431536, 2.0616761249725384, 1.0459416175028915, 16.091280399029987, 16.78869952930994, 17.731322396152716, 18.012077060880035, 17.014685120949352, 16.043486186424595, 14.997578648768563, 13.95346750444841, 13.014237863123968, 12.035898467987973, 10.978008173243042, 9.940819351139394, 8.975541580953346, 8.006273939574989, 7.06497359486262, 6.059184764300474, 4.995727864034615, 3.932043079103161, 2.992530621920994, 1.9710374018275822, 15.078961290389424, 15.830945178415755, 16.794111032219504, 17.801987343012918, 17.821953906767906, 16.852018765086488, 15.895628817723017, 14.8659952456987, 13.882187275015806, 12.896058973678876, 11.938677902297497, 10.911037109182125, 9.887766642697882, 8.912027137767431, 7.939523709605096, 6.968862703744782, 5.91617771759476, 4.901944711125267, 3.8817470434755954, 2.9417811830475387, 14.033669689301263, 14.838499163767347, 15.816338242853154, 16.763304636374897, 17.537127076483113, 17.742857677724288, 16.81317978815077, 15.77434050333156, 14.820484875202599, 13.84701533267685, 12.782313922062679, 11.779030728574025, 10.812513996349214, 9.871780134766748, 8.877186868413197, 7.9133500091369715, 6.881556131950418, 5.833688276260444, 4.838494851120149, 3.8930546025901096, 12.971559957652936, 13.831320887449559, 14.851129149101437, 15.813822859373117, 16.55957964490927, 17.509133851817204, 17.774895138528997, 16.819819515465973, 15.758653330184414, 14.727977017795439, 13.72410201435552, 12.788932010594554, 11.777557788402238, 10.87299368715298, 9.897591027126238, 8.95969385709958, 7.90084605527848, 6.835971815966961, 5.839624474672912, 4.950611339223039, 11.927367814174197, 12.867324673783001, 13.83381041458522, 14.805535252174293, 15.593640169121162, 16.541887526825604, 17.523800846418347, 17.707967980209908, 16.738361658409726, 15.7141504862822, 14.700717506730028, 13.734320624649094, 12.722519902386038, 11.8045593915377, 10.873250871353244, 9.820548045925559, 8.796886295768694, 7.854059955393838, 6.849390457473618, 5.920324628949086, 10.996739182193837, 11.90487699259449, 12.808358319791942, 13.796575299052087, 14.560414006085578, 15.500150267496377, 16.539622718625118, 17.46022101217602, 17.69130546916735, 16.691391048442934, 15.681640884641116, 14.705444128423496, 13.707289404138649, 12.769084769363536, 11.705740885737793, 10.685957702040618, 9.73853778272175, 8.754252192166474, 7.799006367120853, 6.9089775477341, 10.06432056980144, 10.95079044484031, 11.840295522913486, 12.807146450139454, 13.63459034766965, 14.616843955761375, 15.58305152804106, 16.486859543911727, 17.467128211479412, 17.50890087786788, 16.490987061033756, 15.452026057796203, 14.472452912154282, 13.545952133631847, 12.591211478622267, 11.663761592568683, 10.763451056524111, 9.821093005538826, 8.861611197974629, 7.87701827553281, 9.010578633967109, 9.892211129468963, 10.892833031122601, 11.77730477702471, 12.689618796785807, 13.642676344309242, 14.578965468118811, 15.532318017064965, 16.521544458496322, 17.451382293717533, 17.40168734156898, 16.455697152153412, 15.515397604230934, 14.5387218428962, 13.589743632337663, 12.662116662828456, 11.735152581236894, 10.754390907081552, 9.814165731515164, 8.871028215019725, 8.00065536561044, 8.947402959596793, 9.88546234922139, 10.737903304749144, 11.646441097668744, 12.574806563998562, 13.57415646383951, 14.476136900193644, 15.49513537801528, 16.53985950692208, 17.519802296487736, 17.420857639919667, 16.537246364362996, 15.473510251905138, 14.626434801376341, 13.731718894814307, 12.75569415383167, 11.757206176369083, 10.739536165326678, 9.8168728802832, 7.069157755332644, 8.008483823623584, 8.829328440309768, 9.68145041750703, 10.62342560410096, 11.556568792771593, 12.572168171426476, 13.5447652647187, 14.522670344968468, 15.580209326404551, 16.506303158727306, 17.499831613148224, 17.452176469739186, 16.444183711531515, 15.665371649554176, 14.710746882918825, 13.70923718863392, 12.797579339423342, 11.7782824433055, 10.787680784416402, 6.002842704699077, 6.972285390138677, 7.860842800875584, 8.708514111526782, 9.651798773748409, 10.606340900088469, 11.555194827935141, 12.549993981718956, 13.565407831483082, 14.556808996678807, 15.489610874339046, 16.48349937849572, 17.447458646294663, 17.432668698513876, 16.628688722015774, 15.666441046955585, 14.621410485673241, 13.645303355550134, 12.71088510071704, 11.713038766827594, 4.950470023458189, 5.922034040373315, 6.87568416617489, 7.775915502754793, 8.641068581383545, 9.649015740635633, 10.609926619512962, 11.66381180702634, 12.613046911041515, 13.55381891797976, 14.604220759270284, 15.532065708687924, 16.519677546286616, 17.556885081153222, 17.584268995044475, 16.561187902493373, 15.568168858665327, 14.59034969979319, 13.691999855424, 12.667522815975783, 3.9709136413717427, 5.009050132174487, 5.84541051229795, 6.7044218675304945, 7.671333596392442, 8.709565897821232, 9.66694447389991, 10.637968309331054, 11.602721321143672, 12.64348253290575, 13.709848626269919, 14.590227694603243, 15.549173167396475, 16.50621844173505, 17.442015629319126, 17.539008052705366, 16.499390169657644, 15.522221349670618, 14.618646040947883, 13.725094385036302, 2.9906472474946257, 3.9367406478333864, 4.77451708676639, 5.745757919030419, 6.773251516682009, 7.743097384832455, 8.723870386134568, 9.672879787886107, 10.740841687398417, 11.750107720057567, 12.64798858984294, 13.60985256174418, 14.644215123177796, 15.628805284598524, 16.650215977126425, 17.623504617555422, 17.51367814907129, 16.53684484784145, 15.581078173570809, 14.755312657123206, 2.049846705191721, 3.014278680103937, 3.8412101243661954, 4.79655304197695, 5.790541659611817, 6.8563780277858815, 7.859626911838475, 8.835871230317162, 9.872195273799786, 10.805843014408989, 11.701445008129493, 12.691780366404963, 13.666125097847262, 14.658914197606844, 15.637620085915666, 16.664650085053086, 17.570471788547447, 17.5342084094209, 16.644441398882943, 15.793706002018439, 0.9772746961776054, 2.0210611328886, 2.911408650961431, 3.923060965326688, 4.8811963681043355, 5.940796011232286, 6.988440643252835, 7.84612123874841, 8.83484943698834, 9.748588465376292, 10.749630677000924, 11.7595013446582, 12.739610177985487, 13.704293992571326, 14.696412417213926, 15.641791495983702, 16.571185094306028, 17.500821404787335, 17.69451918961557, 16.80726516295442, 0.0, 1.022991159487659, 1.9601444727319008, 2.966964262832068, 4.02164141824979, 5.024491235413837, 5.9674444126886215, 6.90633971987632, 7.8433809931252565, 8.779147576533227, 9.852165501561517, 10.835087257790061, 11.822696075070345, 12.808432942450667, 13.866723414264383, 14.886148235736945, 15.84732784179727, 16.810813382834976, 17.75983847812494, 17.84041160300826, 0.9360410840930669, 1.961621040025359, 2.9907121532731304, 4.006841663162641, 5.039160240480066, 5.962046968179672, 7.020571413575794, 7.870421303543324, 8.770959967728501, 9.735958695076064, 10.69182169140026, 11.74116323920391, 12.751399046364487, 13.807305021355166, 14.760924631575367, 15.749923650500369, 16.764966387084225, 17.745273979593268, 18.731676512872557, 18.79209725054511], [19.009983757455437, 18.02201979667161, 17.540976275367175, 16.481430690582474, 15.54191330898464, 14.491455150980906, 13.510379853263553, 12.544378361591647, 11.525148871343045, 10.586434118691333, 9.657694644167385, 8.777199381778217, 7.780697533549179, 6.881400098956019, 5.948578730578462, 4.956896438126129, 3.9302554908032636, 2.967527007349833, 1.9435705759328048, 2.8976662092262435, 18.007520430308155, 17.077463987121696, 17.817305165070003, 17.41700772970874, 16.43462551796685, 15.431654477234835, 14.465156228150613, 13.479750333104374, 12.464912820689612, 11.513271195280232, 10.704722312955436, 9.71208285020477, 8.77302009744736, 7.815435306177219, 6.900379274441578, 5.921653061524742, 4.890303266525654, 3.9479794310557432, 2.9711902821784673, 2.0689327769905503, 17.067863945249478, 16.144432393650426, 16.765638235021118, 17.7660296449991, 17.368674985462096, 16.39747605093734, 15.427448235773662, 14.426319847569754, 13.487090206245313, 12.561942982139257, 11.695651564339231, 10.658462742235583, 9.785376878320179, 8.816109236941822, 7.874808892229453, 6.924809713555339, 5.86135281328948, 4.869198232435591, 3.929685775253424, 2.9940285613152415, 16.055544836608917, 15.18667804275624, 15.828426871087906, 16.795897048961177, 17.499769308672665, 17.323773228331284, 16.36738328096781, 15.428100477295557, 14.46231582699744, 13.606890959409276, 12.737331325453757, 11.709690532338385, 10.73418477963287, 9.758445274702419, 8.845159581227588, 7.874498575367274, 6.859382604672053, 5.8451495982025605, 4.8581698583297275, 3.964772342535198, 15.010253235520755, 14.194232028107832, 14.850654081721558, 15.757214342323154, 16.514135916995457, 17.441318479321737, 17.342341762080935, 16.444677247757227, 15.490821619628264, 14.62038231472108, 13.647583912680927, 12.644300719192273, 11.677783986967462, 10.743019356421245, 9.82039175549049, 8.856554896214265, 7.8247610190277115, 6.776893163337737, 5.861486010607808, 4.916045762077768, 13.948143503872428, 13.187053751790044, 13.85760397058122, 14.807732565321375, 15.536588485421612, 16.486142692329544, 17.453949422439187, 17.490156259891638, 16.42899007461008, 15.587652046342223, 14.589372004973768, 13.654202001212802, 12.642827779020486, 11.744232908807476, 10.84079591420353, 9.906379371575024, 8.866163471871985, 7.81290760218397, 6.862615634160571, 5.953377917407942, 12.90395136039369, 12.223057538123486, 12.840285236065002, 13.799444958122551, 14.570649009633502, 15.518896367337943, 16.500809686930687, 17.39404280555525, 17.47126863664269, 16.573825514828982, 15.565987497348276, 14.599590615267342, 13.587789893004286, 12.750684793270784, 11.819376273086329, 10.823314624110461, 9.799652873953596, 8.85682653357874, 7.852157035658521, 6.9230912071339885, 11.97332272841333, 11.225977359726278, 11.814833141271725, 12.790485005000345, 13.537422846597918, 14.477159108008717, 15.51663155913746, 16.43722985268836, 17.395513921124433, 17.557154902152643, 16.547404738350824, 15.571207982133204, 14.573053257848358, 13.771851347548438, 12.708507463922695, 11.68872428022552, 10.741304360906652, 9.757018770351376, 8.801772945305755, 7.91041053016986, 11.040904116020933, 10.271890811972098, 10.846770344393269, 11.801056156087713, 12.61159918818199, 13.593852796273715, 14.560060368553401, 15.463868384424066, 16.44413705199175, 17.423078919117163, 17.493753639218657, 16.454792635981104, 15.475219490339184, 14.548718711816749, 13.593978056807169, 12.666528170753585, 11.766217634709013, 10.823859583723728, 9.864377776159529, 8.87845125796857, 9.987162180186601, 9.21331149660075, 9.899307852602384, 10.754313617537052, 11.666627637298147, 12.619685184821583, 13.555974308631152, 14.509326857577305, 15.498553299008663, 16.428391134229873, 17.484745663716176, 17.458463730338313, 16.518164182415838, 15.541488421081102, 14.592510210522565, 13.664883241013358, 12.737919159421796, 11.757157485266454, 10.816932309700064, 9.872461197455484, 8.977238911829932, 8.268503326728581, 8.862471189733732, 9.714912145261486, 10.623449938181084, 11.551815404510902, 12.55116530435185, 13.453145740705985, 14.472144218527621, 15.516868347434423, 16.496811137000076, 17.431059249167312, 17.540012942547897, 16.47627683009004, 15.629201379561243, 14.734485472999209, 13.75846073201657, 12.759972754553983, 11.742302743511578, 10.818305862718958, 8.045741301552138, 7.2586507731588865, 7.80633728082211, 8.658459258019372, 9.6004344446133, 10.533577633283933, 11.549177011938816, 12.521774105231042, 13.49967918548081, 14.557218166916893, 15.483311999239648, 16.476840453660564, 17.349685610149557, 17.44695028971642, 16.668138227739078, 15.713513461103725, 14.712003766818821, 13.800345917608242, 12.7810490214904, 11.78911376685216, 6.979426250918571, 6.22245233967398, 6.837851641387926, 7.685522952039124, 8.628807614260749, 9.58334974060081, 10.532203668447483, 11.527002822231298, 12.542416671995424, 13.53381783719115, 14.466619714851388, 15.460508219008059, 16.424467486807004, 17.378676918133664, 17.631455300200674, 16.669207625140483, 15.622843468109, 14.646736337985892, 13.712318083152798, 12.714471749263353, 5.927053569677684, 5.172200989908618, 5.852693006687232, 6.752924343267134, 7.618077421895885, 8.626024581147973, 9.586935460025304, 10.640820647538682, 11.590055751553857, 12.530827758492102, 13.581229599782626, 14.509074549200266, 15.496686386798954, 16.533893921665566, 17.404536905055174, 17.56262088492913, 16.569601841101086, 15.59178268222895, 14.693432837859758, 13.668955798411542, 4.947497187591237, 4.184588251108288, 4.822419352810291, 5.681430708042836, 6.648342436904783, 7.686574738333573, 8.643953314412252, 9.614977149843396, 10.579730161656014, 11.620491373418092, 12.686857466782259, 13.567236535115583, 14.526182007908815, 15.483227282247393, 16.41902446983147, 17.376722130438107, 17.500823152093403, 16.523654332106375, 15.620079023383642, 14.72652736747206, 3.96723079371412, 3.1122787667671883, 3.751525927278731, 4.72276675954276, 5.75026035719435, 6.720106225344796, 7.700879226646909, 8.649888628398449, 9.717850527910759, 10.727116560569911, 11.62499743035528, 12.58686140225652, 13.621223963690136, 14.605814125110864, 15.627224817638766, 16.600513458067763, 17.583086521268918, 17.538277830277206, 16.582511156006568, 15.756745639558964, 3.0264302514112154, 2.0619982764989992, 2.8182189648785365, 3.773561882489291, 4.767550500124157, 5.833386868298222, 6.836635752350816, 7.812880070829503, 8.849204114312126, 9.78285185492133, 10.678453848641833, 11.668789206917303, 12.643133938359602, 13.635923038119184, 14.614628926428006, 15.641658925565427, 16.547480629059788, 17.489781385491128, 17.645874381318702, 16.795138984454198, 2.0002658556652646, 1.010779088865561, 1.8884174914737724, 2.900069805839029, 3.858205208616677, 4.917804851744627, 5.965449483765175, 6.82313007926075, 7.811858277500681, 8.725597305888632, 9.726639517513265, 10.736510185170541, 11.716619018497827, 12.681302833083667, 13.673421257726266, 14.618800336496042, 15.54819393481837, 16.477830245299675, 17.466875479626683, 17.808698145390178, 1.022991159487659, 0.0, 0.9371533132442419, 1.9439731033444088, 2.998650258762131, 4.001500075926177, 4.944453253200962, 5.883348560388661, 6.820389833637597, 7.756156417045567, 8.829174342073857, 9.812096098302401, 10.799704915582685, 11.785441782963007, 12.843732254776723, 13.863157076249285, 14.82433668230961, 15.787822223347314, 16.73684731863728, 17.689959106249958, 1.959032243580726, 0.9473905079373329, 1.9764816211851044, 2.9926111310746153, 4.016169080992407, 4.939055808692013, 5.997580254088135, 6.847430144055664, 7.747968808240841, 8.712967535588405, 9.668830531912601, 10.71817207971625, 11.728407886876827, 12.784313861867506, 13.737933472087708, 14.72693249101271, 15.741975227596564, 16.722282820105605, 17.708685353384897, 18.641644753786807], [18.610289039256056, 17.594905339889106, 16.603822962122937, 15.544277377338236, 14.604759995740402, 13.554301837736668, 12.573226540019315, 11.60722504834741, 10.587995558098806, 9.649280805447093, 8.720541330923146, 7.840046068533976, 6.8435442203049375, 5.944246785711776, 5.01142541733422, 4.019743124881886, 2.9967396355072866, 2.034011152053856, 2.880723889177047, 3.834819522470485, 17.703070799891876, 17.68172520711341, 16.880151851825758, 16.4798544164645, 15.497472204722612, 14.494501163990597, 13.528002914906375, 12.542597019860134, 11.527759507445372, 10.576117882035991, 9.767568999711195, 8.774929536960528, 7.835866784203119, 6.878281992932976, 5.963225961197336, 4.984499748280499, 3.9567874112296777, 3.014463575759766, 3.9083435954227093, 3.0060860902347923, 17.74928824483749, 16.74869361364214, 15.828484921776875, 16.82887633175486, 16.43152167221786, 15.460322737693101, 14.490294922529424, 13.489166534325514, 12.549936893001073, 11.624789668895016, 10.75849825109499, 9.721309428991342, 8.848223565075937, 7.87895592369758, 6.937655578985211, 5.991293858259363, 4.927836957993504, 3.9585213524460885, 4.866839088497667, 3.931181874559483, 16.836695143843052, 15.790939262747953, 14.891273557843661, 15.858743735716933, 16.562615995428423, 16.386619915087046, 15.430229967723573, 14.490947164051317, 13.5251625137532, 12.669737646165034, 11.800178012209516, 10.772537219094144, 9.797031466388628, 8.821291961458178, 7.9116437259316115, 6.940982720071298, 5.938651566105704, 4.934472718213058, 5.754136647825144, 4.814170787397087, 15.797276730011772, 14.798493248099545, 13.913500768477313, 14.82006102907891, 15.576982603751215, 16.504165166077495, 16.405188448836697, 15.507523934512983, 14.553668306384022, 13.683229001476839, 12.710430599436686, 11.707147405948032, 10.74063067372322, 9.805866043177003, 8.909714875500988, 7.945878016224762, 6.914084139038209, 5.866216283348235, 6.66947402078684, 5.7240337722568, 14.735166998363445, 13.791314971781757, 12.920450657336975, 13.870579252077132, 14.59943517217737, 15.5489893790853, 16.516796109194946, 16.553002946647396, 15.491836761365837, 14.650498733097981, 13.652218691729527, 12.71704868796856, 11.705674465776244, 10.807079595563234, 9.930119034214028, 8.995702491585522, 7.955486591882483, 6.902230722194468, 7.670603644339603, 6.740401411898958, 13.690974854884706, 12.827318758115199, 11.903131922820757, 12.862291644878308, 13.63349569638926, 14.581743054093701, 15.563656373686444, 16.45688949231101, 16.53411532339845, 15.636672201584743, 14.628834184104035, 13.6624373020231, 12.650636579760045, 11.840007913281282, 10.908699393096827, 9.921693834869698, 8.898032084712833, 7.955205744337977, 8.639180530149536, 7.710114701625004, 12.760346222904346, 11.83023857971799, 10.87767982802748, 11.853331691756102, 12.600269533353677, 13.540005794764475, 14.579478245893219, 15.50007653944412, 16.458360607880188, 16.6200015889084, 15.610251425106583, 14.634054668888963, 13.635899944604116, 12.866247442434393, 11.831948471032344, 10.81216528733517, 9.864745368016301, 8.99400566937643, 9.588796439796772, 8.697434024660875, 11.82792761051195, 10.87615203196381, 9.909617031149024, 10.86390284284347, 11.67444587493775, 12.656699483029474, 13.62290705530916, 14.526715071179824, 15.50698373874751, 16.485925605872918, 16.617194646328308, 15.578233643090755, 14.598660497448833, 13.672159718926398, 12.717419063916818, 11.789969177863235, 10.889658641818663, 10.060846482748781, 10.651401270650545, 9.665474752459586, 10.774185674677618, 9.817572716592464, 8.962154539358139, 9.817160304292809, 10.729474324053905, 11.682531871577341, 12.61882099538691, 13.572173544333063, 14.561399985764421, 15.49123782098563, 16.547592350471934, 16.581904737447964, 15.641605189525485, 14.664929428190751, 13.715951217632215, 12.788324248123008, 11.864148623860833, 10.994144384291507, 11.60395580419108, 10.659484691946501, 9.764262406320949, 8.872764546720294, 7.925317876489488, 8.777758832017243, 9.686296624936842, 10.614662091266661, 11.614011991107608, 12.515992427461743, 13.53499090528338, 14.579715034190182, 15.559657823755835, 16.49390593592307, 16.663453949657548, 15.59971783719969, 14.752642386670892, 13.857926480108858, 12.884690196455608, 12.054629380748594, 12.529326238002595, 11.605329357209975, 8.832764796043154, 7.862911993150599, 6.869183967577866, 7.721305944775129, 8.66328113136906, 9.596424320039691, 10.612023698694575, 11.584620791986799, 12.562525872236566, 13.62006485367265, 14.546158685995405, 15.539687140416321, 16.41253229690531, 16.570391296826067, 15.793418974429425, 14.839742925542764, 13.83823323125786, 13.111170292073453, 13.568072515981417, 12.576137261343177, 7.766449745409587, 6.9464439881710875, 5.900698328143683, 6.74836963879488, 7.691654301016507, 8.646196427356568, 9.59505035520324, 10.589849508987054, 11.60526335875118, 12.596664523946906, 13.529466401607145, 14.523354905763815, 15.487314173562758, 16.44152360488942, 16.75680637784853, 15.795437089579524, 14.839906577603996, 14.124137994204666, 14.499341577643815, 13.50149524375437, 6.714077064168699, 5.913515550922072, 4.915539693442989, 5.8157710300228915, 6.680924108651642, 7.688871267903732, 8.64978214678106, 9.703667334294439, 10.652902438309614, 11.593674445247858, 12.644076286538382, 13.571921235956022, 14.559533073554713, 15.596740608421324, 16.46738359181093, 16.720519146767675, 15.786664950596082, 15.069184338447723, 15.480456332350775, 14.455979292902558, 5.734520682082253, 4.925902812121741, 3.885266039566049, 4.744277394798593, 5.7111891236605405, 6.749421425089331, 7.706800001168009, 8.677823836599153, 9.642576848411771, 10.683338060173849, 11.749704153538017, 12.630083221871342, 13.589028694664574, 14.546073969003151, 15.481871156587227, 16.439568817193862, 16.717886261588397, 16.00105598832515, 16.40710251787466, 15.513550861963077, 4.754254288205136, 3.876386654246887, 2.814372614034489, 3.7856134462985183, 4.813107043950108, 5.782952912100554, 6.763725913402667, 7.712735315154206, 8.780697214666516, 9.789963247325666, 10.68784411711104, 11.649708089012279, 12.684070650445895, 13.668660811866623, 14.690071504394524, 15.663360144823521, 16.64593320802468, 17.01567948649598, 17.369534650497584, 16.54376913404998, 3.813453745902231, 2.849021770990015, 1.8810656516342945, 2.836408569245049, 3.8303971868799156, 4.89623355505398, 5.899482439106574, 6.875726757585261, 7.912050801067885, 8.845698541677088, 9.741300535397592, 10.731635893673062, 11.70598062511536, 12.698769724874943, 13.677475613183764, 14.704505612321185, 15.610327315815548, 16.552628072246886, 17.557993715185273, 17.582162478945214, 2.937419168909506, 1.947932402109803, 0.9512641782295305, 1.962916492594787, 2.921051895372435, 3.9806515385003856, 5.0282961705209335, 5.885976766016508, 6.8747049642564395, 7.788443992644391, 8.789486204269023, 9.7993568719263, 10.779465705253585, 11.744149519839425, 12.736267944482025, 13.6816470232518, 14.611040621574128, 15.540676932055433, 16.52972216638244, 17.464396594948308, 1.9601444727319008, 0.9371533132442419, 0.0, 1.006819790100167, 2.061496945517889, 3.0643467626819354, 4.00729993995672, 4.946195247144419, 5.883236520393355, 6.819003103801325, 7.892021028829616, 8.87494278505816, 9.862551602338444, 10.848288469718765, 11.906578941532482, 12.926003763005044, 13.887183369065369, 14.850668910103073, 15.79969400539304, 16.752805793005717, 2.8961855568249675, 1.8845438211815748, 1.0429657658891274, 2.0590952757786383, 3.0790157677481647, 4.001902495447771, 5.060426940843893, 5.910276830811423, 6.810815494996599, 7.775814222344164, 8.731677218668361, 9.781018766472009, 10.791254573632585, 11.847160548623265, 12.800780158843466, 13.789779177768468, 14.804821914352322, 15.785129506861365, 16.771532040140656, 17.704491440542565], [17.60346924915589, 16.58808554978894, 15.597003172022768, 14.53745758723807, 13.597940205640235, 12.547482047636501, 11.566406749919148, 10.600405258247243, 9.581175767998639, 8.642461015346926, 7.713721540822979, 6.833226278433809, 5.836724430204771, 4.9374269956116095, 4.004605627234053, 3.0129233347817195, 2.068207743349556, 3.0309362268029867, 3.8875436792772136, 4.841639312570653, 16.69625100979171, 17.386021016118747, 16.413380436626408, 15.473034626364333, 14.490652414622446, 13.48768137389043, 12.521183124806209, 11.535777229759967, 10.520939717345206, 9.569298091935824, 8.760749209611028, 7.768109746860361, 6.829046994102952, 5.871462202832809, 4.95640617109717, 3.9776799581803326, 3.028255519071947, 4.011388650508897, 4.915163385522876, 4.0129058803349595, 17.530148468909026, 17.73003155511646, 16.809822863251195, 16.068870587493944, 15.424701882117692, 14.453502947592934, 13.483475132429257, 12.482346744225348, 11.543117102900906, 10.617969878794849, 9.751678460994823, 8.714489638891175, 7.84140377497577, 6.872136133597413, 5.9308357888850445, 5.008106728749095, 3.999305065835773, 4.955446427195219, 5.8736588785978325, 4.93800166465965, 17.81803308531737, 16.772277204222274, 15.872611499317983, 15.058298602117677, 15.762170861829164, 15.379800124986877, 14.423410177623406, 13.48412737395115, 12.518342723653033, 11.662917856064867, 10.79335822210935, 9.765717428993977, 8.790211676288461, 7.814472171358011, 6.928456596421343, 5.957795590561029, 5.0101196739479725, 5.931397792962189, 6.76095643792531, 5.820990577497254, 16.804096520111937, 15.779831189573866, 14.894838709951635, 14.019615895479655, 14.776537470151958, 15.703720032478238, 15.398368658736532, 14.500704144412817, 13.546848516283855, 12.676409211376672, 11.703610809336519, 10.700327615847865, 9.733810883623054, 8.799046253076837, 7.971619514925474, 7.007782655649248, 6.0056040386146305, 6.863141358097366, 7.676293810887007, 6.730853562356967, 15.741986788463612, 14.772652913256078, 13.901788598811297, 13.070134118477876, 13.798990038578113, 14.748544245486043, 15.716350975595688, 15.54618315654723, 14.48501697126567, 13.643678942997814, 12.64539890162936, 11.710228897868394, 10.698854675676078, 9.800259805463067, 8.992023673638514, 8.057607131010007, 7.047006491458904, 7.899155796943599, 8.67742343443977, 7.747221201999125, 14.697794644984873, 13.80865669958952, 12.88446986429508, 12.061846511279052, 12.833050562790003, 13.781297920494444, 14.763211240087186, 15.656444358711754, 15.52729553329828, 14.629852411484576, 13.622014394003868, 12.655617511922934, 11.643816789659878, 10.856504741880826, 9.970604032521312, 9.128119304654813, 8.121584663471749, 8.952130819087108, 9.646000320249703, 8.716934491725171, 13.767166013004513, 12.811576521192311, 11.859017769501802, 11.052886558156846, 11.799824399754419, 12.739560661165218, 13.77903311229396, 14.699631405844862, 15.657915474280932, 15.613181798808236, 14.603431635006416, 13.627234878788796, 12.62908015450395, 11.882744271033937, 10.944172698489147, 10.035717866094085, 9.088297946775217, 9.99093074412556, 10.595616229896939, 9.704253814761044, 12.834747400612116, 11.857489973438131, 10.890954972623346, 10.063457709244213, 10.874000741338492, 11.856254349430216, 12.822461921709902, 13.726269937580566, 14.706538605148252, 15.68548047227366, 15.623269921830541, 14.645583080600098, 13.666009934958176, 12.847027529400446, 11.938664682913616, 11.01352175662215, 10.113211220577579, 11.057771557497912, 11.658221060750712, 10.672294542559754, 11.781005464777785, 10.798910658066784, 9.943492480832461, 9.016715170693553, 9.929029190454647, 10.882086737978083, 11.818375861787652, 12.771728410733806, 13.760954852165163, 14.690792687386372, 15.670014608831298, 15.649254174957308, 14.708954627034828, 13.839797238664799, 12.939503796391131, 12.011876826881924, 11.08770120261975, 11.991069459040638, 12.610775594291248, 11.66630448204667, 10.771082196421116, 9.854102488194615, 8.90665581796381, 7.977313698417987, 8.885851491337585, 9.814216957667403, 10.813566857508352, 11.715547293862485, 12.734545771684122, 13.758748721825214, 14.682080082115197, 15.525070697982548, 15.755084061233976, 14.774585647673737, 13.976194965429809, 13.081479058867775, 12.108242775214524, 13.051554455497726, 13.536146028102761, 12.612149147310143, 9.83958458614332, 8.84424993462492, 7.850521909052187, 6.920860811175873, 7.8628359977698015, 8.795979186440436, 9.811578565095319, 10.784175658387541, 11.762080738637309, 12.773172624849575, 13.656746199109847, 14.570851902475798, 15.425245535350262, 15.745259107300116, 15.016971553188341, 14.06329550430168, 13.061785810016776, 14.096150196969354, 14.574892306081583, 13.582957051443346, 8.773269535509755, 7.927781929645407, 6.882036269618003, 5.947924505195624, 6.89120916741725, 7.845751293757311, 8.794605221603982, 9.789404375387797, 10.804818225151923, 11.749772295123831, 12.640053914721587, 13.546365844593934, 14.500027412007709, 15.45423684333437, 15.980358956607446, 15.01898966833844, 14.063459156362912, 15.03956628648602, 15.506161367743983, 14.508315033854538, 7.720896854268866, 6.920335341022239, 5.922359483543157, 5.015325896423635, 5.880478975052386, 6.888426134304475, 7.849337013181803, 8.856775105471364, 9.806010209486539, 10.746782216424783, 11.672159892439558, 12.594932174786141, 13.552713283454546, 14.589920818321158, 15.460563801710762, 15.944071725526591, 15.010217529354998, 15.984612630729076, 16.487276122450943, 15.462799083002727, 6.7413404721824195, 5.932722602221908, 4.892085829666216, 3.9438322611993364, 4.910743990061284, 5.948976291490074, 6.906354867568752, 7.830931607776079, 8.795684619588696, 9.836445831350774, 10.74288436343785, 11.623263431771175, 12.582208904564407, 13.539254178902985, 14.47505136648706, 15.432749027093697, 15.941438840347315, 16.916484280606504, 17.41392230797483, 16.520370652063246, 5.7610740783053025, 4.883206444347055, 3.8211924041346563, 2.985168312699261, 4.01266191035085, 4.982507778501296, 5.9632807798034095, 6.865843086331132, 7.897543037335449, 8.889697519832279, 9.681024327010872, 10.642888298912112, 11.677250860345728, 12.661841021766456, 13.683251714294357, 14.656540354723354, 15.639113417924511, 16.543171843726167, 17.60823289251115, 17.550588924150148, 4.820273536002398, 3.855841561090182, 2.8878854417344617, 2.0121582437090213, 2.995477586795583, 4.0613139549696475, 4.953452516525822, 5.868906967485095, 6.905231010967718, 7.838878751576921, 8.734480745297425, 9.724816103572895, 10.699160835015194, 11.691949934774776, 12.670655823083598, 13.697685822221018, 14.603507525715381, 15.545808282146721, 16.55117392508511, 17.471135965784118, 3.9442389590096734, 2.9547521922099698, 1.9580839683296976, 0.9949918998766594, 1.9531273026543075, 3.0095714112272907, 4.021476380420767, 4.879156975916342, 5.867885174156273, 6.781624202544224, 7.782666414168856, 8.792537081826133, 9.772645915153419, 10.737329729739258, 11.729448154381858, 12.674827233151634, 13.604220831473961, 14.533857141955266, 15.522902376282273, 16.457576804848138, 2.966964262832068, 1.9439731033444088, 1.006819790100167, 0.0, 1.0546771554177221, 2.0575269725817686, 3.0004801498565534, 3.9393754570442523, 4.8764167302931885, 5.8121833137011585, 6.885201238729449, 7.868122994957994, 8.855731812238277, 9.841468679618599, 10.899759151432315, 11.919183972904877, 12.880363578965202, 13.843849120002906, 14.792874215292873, 15.745986002905552, 3.903005346925135, 2.891363611281742, 2.0497855559892946, 1.0611794799230359, 2.072195977647998, 2.995082705347604, 4.053607150743726, 4.903457040711256, 5.803995704896432, 6.768994432243997, 7.724857428568194, 8.774198976371842, 9.784434783532419, 10.840340758523098, 11.7939603687433, 12.782959387668301, 13.798002124252156, 14.778309716761198, 15.764712250040489, 16.697671650442402], [16.548792093738168, 15.533408394371218, 14.542326016605047, 13.482780431820348, 12.543263050222514, 11.49280489221878, 10.511729594501427, 9.545728102829521, 8.526498612580918, 7.587783859929204, 6.659044385405256, 5.778549123016086, 4.782047274787048, 3.8827498401938874, 2.9499284718163308, 1.9582461793639974, 3.0096596340510846, 3.972388117504515, 4.942220834694936, 5.896316467988375, 15.641573854373988, 16.331343860701026, 15.358703281208687, 14.418357470946612, 13.435975259204724, 12.433004218472709, 11.466505969388487, 10.481100074342246, 9.466262561927484, 8.514620936518103, 7.706072054193305, 6.713432591442638, 5.774369838685229, 4.816785047415087, 3.901729015679447, 2.9230028027626105, 3.9629392709338487, 4.952840541210425, 5.93214395888104, 5.067583035752682, 16.4754713134913, 17.264375454172296, 16.36780807660864, 15.367416666630655, 14.37002472669997, 13.398825792175213, 12.428797977011536, 11.427669588807627, 10.488439947483185, 9.563292723377128, 8.697001305577102, 7.659812483473453, 6.786726619558047, 5.81745897817969, 4.8761586334673215, 3.953429573331373, 4.933988817697674, 5.896898317896747, 6.836410775078914, 5.992678820077373, 17.45581287056038, 17.735941796498505, 16.836276091594215, 15.877489393352485, 14.948338188632862, 14.325122969569156, 13.368733022205685, 12.429450218533429, 11.463665568235312, 10.608240700647146, 9.738681066691626, 8.711040273576254, 7.735534520870738, 6.759795015940288, 5.873779441003621, 4.903118435143307, 5.944803425809874, 6.872849683663717, 7.764894858155217, 6.8332154156857055, 17.792694509185367, 16.743495781850097, 15.858503302227867, 14.893399930655002, 13.962704796955656, 14.889887359281936, 14.34369150331881, 13.446026988995095, 12.492171360866134, 11.621732055958951, 10.648933653918796, 9.645650460430142, 8.679133728205331, 7.7443690976591135, 6.916942359507752, 5.953105500231526, 6.940287790476532, 7.804593248798894, 8.688518649075458, 7.743078400545419, 16.735419266499697, 15.73631750553231, 14.865453191087528, 13.990498860547868, 12.985157365381811, 13.934711572289741, 14.902518302399386, 14.491506001129508, 13.43033981584795, 12.589001787580093, 11.590721746211637, 10.65555174245067, 9.644177520258355, 8.745582650045346, 7.937346518220792, 7.002929975592286, 7.981690243320806, 8.840607687645127, 9.689648272628222, 8.759446040187576, 15.691227123020958, 14.772321291865753, 13.84813445657131, 12.982211253349044, 12.019217889593701, 12.967465247298142, 13.934717054838474, 14.664449628906324, 14.47261837788056, 13.575175256066855, 12.567337238586145, 11.60094035650521, 10.589139634242155, 9.801827586463105, 8.91592687710359, 8.073442149237092, 9.056268415333651, 9.893582709788635, 10.658225158438155, 9.729159329913623, 14.760598491040598, 13.775241113468544, 12.822682361778034, 11.983939009747834, 10.985991726558117, 11.925727987968916, 12.872797220006465, 13.707636676039431, 14.665920744475502, 14.558504643390513, 13.548754479588693, 12.572557723371073, 11.574402999086226, 10.828067115616216, 9.889495543071426, 9.143524525158139, 10.02298169863712, 10.932382634827087, 11.60784106808539, 10.716478652949496, 13.828179878648202, 12.821154565714364, 11.854619564899577, 11.015826204401744, 10.06016806814219, 10.994994759328007, 11.89279709641404, 12.734275207775136, 13.714543875342821, 14.69348574246823, 14.568592766412818, 13.590905925182375, 12.611332779540453, 11.792350373982725, 10.883987527495895, 10.121328415686204, 11.047894972439481, 11.999223448199439, 12.670445898939164, 11.684519380748206, 12.77443794281387, 11.762575250343017, 10.907157073108692, 9.980379762969786, 9.115196517258347, 10.01675316028015, 10.88871103649179, 11.779733680928375, 12.768960122359733, 13.698797957580942, 14.615337453413575, 14.594577019539585, 13.654277471617105, 12.785120083247078, 11.921249856223332, 11.119683485945977, 12.022384954481652, 12.932521349742165, 13.6230004324797, 12.678529320235121, 11.764514674457201, 10.817767080470848, 9.870320410240042, 8.94097829069422, 8.072018818141284, 8.94888337996947, 9.855941269134002, 10.723552564057055, 11.742551041878691, 12.70407156640749, 13.627402926697474, 14.470393542564825, 14.700406905816253, 13.719908492256016, 12.95794102526201, 12.189285717931828, 13.042926527076425, 13.993006346199252, 14.548370866291213, 13.624373985498595, 10.851809424331773, 9.807914526901152, 8.81418650132842, 7.884525403452106, 7.049003324573501, 7.894997474937057, 8.853952976720969, 9.79218092858211, 10.770086008831878, 11.718495469431852, 12.602069043692124, 13.516174747058075, 14.37056837993254, 14.690581951882395, 13.998717613020542, 13.210342420071171, 13.996469561878676, 15.030833948831255, 15.587117144270035, 14.595181889631798, 9.785494373698207, 8.89144652192164, 7.845700861894236, 6.9115890974718575, 6.077376494220949, 6.944769582253933, 7.802610491798552, 8.797409645582366, 9.812823495346493, 10.695095139706108, 11.585376759303864, 12.491688689176211, 13.445350256589986, 14.399559687916646, 14.962105016439647, 14.166036584107932, 14.998142908224812, 15.97425003834792, 16.518386205932433, 15.52053987204299, 8.733121692457319, 7.93256017921069, 6.9345843217316085, 5.978990488699868, 5.0666463018560846, 5.987444422801097, 6.857342283376373, 7.802097950053641, 8.751333054068816, 9.69210506100706, 10.617482737021835, 11.540255019368418, 12.498036128036823, 13.535243662903435, 14.40588664629304, 15.091118641296083, 15.944901281216898, 16.91929638259098, 17.499500960639395, 16.47502392119118, 7.753565310370871, 6.94494744041036, 5.904310667854668, 4.907496853475569, 4.096911316864983, 5.047994579986696, 5.914360137763322, 6.776254452358356, 7.741007464170973, 8.781768675933051, 9.688207208020128, 10.568586276353452, 11.527531749146684, 12.484577023485262, 13.420374211069337, 14.378071871675974, 15.417689754723696, 16.478074189194984, 17.42752221148479, 17.5325954902517, 6.773298916493754, 5.895431282535506, 4.833417242323108, 3.948832904975494, 3.0803021922725646, 4.050148060423011, 4.913260187095808, 5.811165930913409, 6.842865881917726, 7.8350203644145555, 8.62634717159315, 9.588211143494389, 10.622573704928005, 11.607163866348733, 12.628574558876634, 13.601863199305631, 14.584436262506788, 15.488494688308446, 16.55355573709343, 17.45485215526163, 5.83249837419085, 4.868066399278634, 3.9001102799229135, 2.9758228359852543, 2.04287137351652, 3.0074641184544766, 3.8987753611080995, 4.814229812067372, 5.850553855549995, 6.784201596159198, 7.679803589879703, 8.670138948155172, 9.64448367959747, 10.637272779357053, 11.615978667665875, 12.643008666803295, 13.548830370297658, 14.491131126728998, 15.496496769667385, 16.416458810366397, 4.998916114427396, 4.009429347627692, 2.9703088065181493, 1.9586564921528926, 1.0005210893752445, 1.9548942558095685, 2.966799225003044, 3.824479820498619, 4.81320801873855, 5.726947047126501, 6.727989258751133, 7.73785992640841, 8.717968759735696, 9.682652574321535, 10.674770998964135, 11.62015007773391, 12.549543676056238, 13.479179986537543, 14.46822522086455, 15.402899649430415, 4.02164141824979, 2.998650258762131, 2.061496945517889, 1.0546771554177221, 0.0, 1.0028498171640465, 1.945802994438831, 2.8846983016265297, 3.8217395748754655, 4.7575061582834355, 5.830524083311726, 6.813445839540271, 7.801054656820554, 8.786791524200876, 9.845081996014592, 10.864506817487154, 11.825686423547479, 12.789171964585183, 13.73819705987515, 14.691308847487829, 4.957682502342857, 3.946040766699464, 3.1044627114070162, 2.0923270606316553, 1.0175188222302758, 1.9404055499298818, 2.9989299953260042, 3.848779885293533, 4.749318549478709, 5.714317276826274, 6.670180273150471, 7.71952182095412, 8.729757628114697, 9.785663603105375, 10.739283213325576, 11.728282232250578, 12.743324968834433, 13.723632561343475, 14.710035094622766, 15.642994495024679], [15.54594227657412, 14.53055857720717, 13.539476199441, 12.4799306146563, 11.540413233058466, 10.489955075054732, 9.508879777337379, 8.542878285665473, 7.52364879541687, 6.584934042765157, 5.656194568241209, 4.77569930585204, 3.779197457623001, 2.8874849738445567, 1.9546636054670001, 2.9120179408765994, 3.9634313955636866, 4.926159879017117, 5.945070651858982, 6.899166285152421, 14.638724037209942, 15.328494043536978, 14.355853464044639, 13.415507653782564, 12.433125442040676, 11.430154401308661, 10.46365615222444, 9.478250257178198, 8.463412744763437, 7.511771119354056, 6.703222237029259, 5.710582774278592, 4.771520021521182, 3.8215201810657566, 2.9629197654983264, 3.8767745642752125, 4.91671103244645, 5.906612302723027, 6.885915720393642, 6.070432852916728, 15.472621496327255, 16.261525637008248, 15.364958259444592, 14.364566849466607, 13.367174909535922, 12.395975975011165, 11.425948159847488, 10.424819771643579, 9.485590130319137, 8.560442906213082, 7.6941514884130555, 6.656962666309407, 5.80934926660567, 4.859947628946852, 3.9373493832862008, 4.907201334843975, 5.887760579210276, 6.850670079409349, 7.790182536591516, 6.995528637241419, 16.452963053396335, 17.219279987902436, 16.27376150324774, 15.221359498806152, 14.292208294086528, 13.322273152405108, 12.365883205041637, 11.426600401369381, 10.460815751071264, 9.6053908834831, 8.73583124952758, 7.708190456412208, 6.7780231716379, 5.802283666707449, 4.972390255060354, 5.85689019665591, 6.898575187322476, 7.826621445176319, 8.718666619667818, 7.8360652328497515, 17.498254654484498, 17.695714555524646, 16.770306618474645, 15.706787180988295, 14.776092047288948, 14.062052297751476, 13.340841686154763, 12.443177171831048, 11.489321543702086, 10.618882238794905, 9.647020609749177, 8.643737416260523, 7.721622378972492, 6.786857748426275, 6.021764452051356, 6.906877261744129, 7.894059551989134, 8.758365010311497, 9.691368466239505, 8.745928217709466, 17.706611310126533, 16.688536279206858, 15.806403831819594, 14.80388611088116, 13.798544615715103, 13.04870639458816, 13.90865589350375, 13.48865618396546, 12.427489998683901, 11.586151970416047, 10.588808702042018, 9.655160255440634, 8.686666171025514, 7.788071300812507, 7.042168610764396, 7.956701737104889, 8.935462004833408, 9.79437944915773, 10.692498089792268, 9.76229585735162, 16.664496925149106, 15.7245400655403, 14.789579273632738, 13.795598503682337, 12.832605139926994, 12.081460069596561, 12.931867237674426, 13.661599811742276, 13.469768560716512, 12.572325438902809, 11.566945751576108, 10.600548869495174, 9.631628285009315, 8.844316237230267, 8.020748969647194, 9.027213910749696, 10.010040176846253, 10.84735447130124, 11.6610749756022, 10.732009147077667, 15.763448308204643, 14.727459887143091, 13.76412717883946, 12.797326260081126, 11.79937897689141, 11.039722810267335, 11.869947402842417, 12.704786858875384, 13.663070927311454, 13.566961727766364, 12.558053631901293, 11.581856875683673, 10.616891649853386, 9.870555766383378, 8.99431763561503, 10.014100819312205, 10.961520738631073, 11.886154396339693, 12.610690885249435, 11.71932847011354, 14.831029695812246, 13.776079106647252, 12.796064381961004, 11.829213454735036, 10.873555318475482, 10.003151981503295, 10.889947279249991, 11.731425390611088, 12.711694058178773, 13.690635925304182, 13.577891918725419, 12.607981740025595, 11.653821430307612, 10.834839024749886, 9.988809620039499, 10.916259506093082, 11.850273317507334, 12.815869583579389, 13.673295716103208, 12.68736919791225, 13.777287759977915, 12.765425067507062, 11.865529291987384, 10.871453098263899, 9.92858376759164, 9.024910382455438, 9.885861219327742, 10.776883863764327, 11.766110305195685, 12.695948140416894, 13.61248763624953, 13.611652834382806, 12.696766122384265, 11.82760873401424, 11.026071948766935, 11.914614576352855, 12.824763299549504, 13.749167485122115, 14.625850249643744, 13.681379137399166, 12.767364491621246, 11.820616897634892, 10.873170227404087, 9.911445906441386, 8.885406068474577, 7.957040602144758, 8.853091451969954, 9.720702746893007, 10.739701224714644, 11.701221749243444, 12.624553109533428, 13.467543725400779, 13.742895556583413, 12.762397143023177, 12.062763117805613, 12.984216808338706, 13.845304872144279, 14.809652481579203, 15.551220683455258, 14.62722380266264, 11.854659241495817, 10.810764344065197, 9.817036318492464, 8.887375220616152, 7.887896312841464, 6.903154697112346, 7.851103159556921, 8.789331111418063, 9.76723619166783, 10.715645652267806, 11.599219226528078, 12.51332492989403, 13.367718562768493, 13.733070602649557, 13.103539705564145, 14.00527351047805, 14.79884790694653, 15.83321229389911, 16.58996696143408, 15.598031706795842, 10.78834419086225, 9.894296339085685, 8.848550679058281, 7.9144389146359035, 6.916269482488912, 5.9529268044292225, 6.799760674634505, 7.794559828418318, 8.809973678182445, 9.692245322542062, 10.582526942139818, 11.488838872012165, 12.44250043942594, 13.3967098707526, 14.06692710898325, 14.96096767451481, 15.800521253292667, 16.776628383415773, 17.521236023096478, 16.523389689207033, 9.735971509621363, 8.935409996374737, 7.937434138895655, 6.981840305863914, 6.014495260332266, 4.995601644976387, 5.854492466212326, 6.799248132889595, 7.74848323690477, 8.689255243843014, 9.614632919857788, 10.537405202204372, 11.495186310872777, 12.532393845739389, 13.403036829128993, 14.428665593951298, 15.346061248551967, 16.407096021908366, 17.35131857984463, 17.47787373835522, 8.756415127534916, 7.947797257574406, 6.907160485018714, 5.9103466706396155, 5.044760275341164, 4.056151802161986, 4.911510320599275, 5.77340463519431, 6.738157647006927, 7.778918858769005, 8.685357390856081, 9.565736459189406, 10.524681931982638, 11.481727206321215, 12.41752439390529, 13.375222054511928, 14.41483993755965, 15.47522437203094, 16.424672394320744, 17.357469099143923, 7.7761487336578, 6.8982810996995525, 5.836267059487154, 4.95168272213954, 4.028151150748746, 3.0583052825983006, 3.9104103699317614, 4.808316113749363, 5.84001606475368, 6.832170547250509, 7.623497354429103, 8.585361326330343, 9.619723887763959, 10.604314049184687, 11.625724741712588, 12.599013382141585, 13.581586445342742, 14.485644871144398, 15.55070591992938, 16.452002338097582, 6.835348191354896, 5.87091621644268, 4.90296009708696, 3.978672653149301, 3.0457211906805663, 2.00461430129043, 2.8959255439440525, 3.8113799949033256, 4.847704038385949, 5.781351778995152, 6.676953772715657, 7.667289130991127, 8.641633862433427, 9.634422962193007, 10.613128850501829, 11.64015884963925, 12.545980553133612, 13.488281309564952, 14.493646952503338, 15.41360899320235, 6.001765931591442, 5.012279164791739, 3.973158623682196, 2.961506309316939, 2.003370906539291, 0.9520444386455221, 1.9639494078389976, 2.8216300033345725, 3.810358201574503, 4.724097229962455, 5.725139441587087, 6.735010109244364, 7.71511894257165, 8.67980275715749, 9.671921181800089, 10.617300260569865, 11.546693858892192, 12.476330169373497, 13.465375403700504, 14.400049832266369, 5.024491235413836, 4.001500075926177, 3.064346762681936, 2.0575269725817686, 1.0028498171640465, 0.0, 0.9429531772747846, 1.8818484844624832, 2.818889757711419, 3.754656341119389, 4.82767426614768, 5.810596022376225, 6.798204839656508, 7.783941707036829, 8.842232178850546, 9.861657000323108, 10.822836606383433, 11.786322147421137, 12.735347242711104, 13.688459030323783, 5.960532319506903, 4.94889058386351, 4.062228332033769, 3.0460988221442573, 1.9712905837428778, 0.9375557327658354, 1.9960801781619577, 2.8459300681294866, 3.7464687323146633, 4.711467459662227, 5.667330455986424, 6.716672003790073, 7.72690781095065, 8.782813785941329, 9.73643339616153, 10.725432415086532, 11.740475151670386, 12.720782744179429, 13.70718527745872, 14.640144677860633], [14.602989099299336, 13.587605399932386, 12.596523022166215, 11.536977437381516, 10.597460055783682, 9.547001897779948, 8.565926600062594, 7.599925108390688, 6.5806956181420855, 5.641980865490373, 4.713241390966425, 3.832746128577255, 2.836244280348217, 2.0070863603346067, 2.8976167827417845, 3.854971118151384, 4.906384572838471, 5.869113056291901, 6.8880238291337665, 7.842119462427205, 13.695770859935156, 14.385540866262193, 13.412900286769855, 12.47255447650778, 11.490172264765892, 10.487201224033877, 9.520702974949655, 8.535297079903414, 7.520459567488652, 6.568817942079272, 5.7602690597544735, 4.767629597003807, 3.828566844246398, 2.9411215675558067, 3.891767702188897, 4.819727741549998, 5.859664209721236, 6.849565479997811, 7.828868897668427, 7.013386030191512, 14.52966831905247, 15.318572459733463, 14.422005082169807, 13.421613672191823, 12.424221732261138, 11.45302279773638, 10.482994982572704, 9.481866594368794, 8.542636953044353, 7.617489728938296, 6.75119831113827, 5.714009489034622, 4.866396089330887, 3.9795490154369024, 4.866197319976772, 5.85015451211876, 6.830713756485062, 7.793623256684134, 8.7331357138663, 7.938481814516203, 15.51000987612155, 16.27632681062765, 15.330808325972956, 14.278406321531367, 13.349255116811744, 12.379319975130324, 11.422930027766853, 10.483647224094597, 9.51786257379648, 8.662437706208316, 7.792878072252795, 6.7652372791374225, 5.85196227224965, 4.9218850531975, 5.894388481359837, 6.7998433739306945, 7.841528364597262, 8.769574622451103, 9.661619796942603, 8.779018410124536, 16.555301477209714, 17.22680261105128, 16.248963531965472, 15.185444094479122, 14.254748960779775, 13.327566398453497, 12.397888508879978, 11.500223994556263, 10.546368366427302, 9.67592906152012, 8.70406743247439, 7.700784238985737, 6.795561479584242, 5.906459134916326, 6.901052401269877, 7.8498304390189135, 8.83701272926392, 9.70131818758628, 10.634321643514289, 9.68888139498425, 17.360820833250322, 17.558320196448044, 16.67618774906078, 15.673670028122347, 14.66832853295629, 13.90299317799525, 12.965702716228966, 12.545703006690676, 11.484536821409117, 10.643198793141263, 9.645855524767232, 8.712207078165848, 7.760605271637265, 6.907672687302558, 7.884032798612042, 8.82719084488693, 9.878415182108194, 10.737332626432512, 11.635451267067053, 10.705249034626405, 17.53428084239029, 16.594323982781486, 15.659363190873924, 14.665382420923523, 13.70238905716818, 12.93574685300365, 11.988914060399642, 12.718646634467492, 12.526815383441727, 11.629372261628024, 10.623992574301322, 9.657595692220388, 8.705567385621066, 7.9639176237203175, 8.86261315749484, 9.897703018531736, 10.921364768688601, 11.790307648576022, 12.604028152876984, 11.674962324352451, 16.63458720332003, 15.597243804384277, 14.633911096080647, 13.667110177322312, 12.669162894132596, 11.894009593674424, 10.926994225567633, 11.7618336816006, 12.72011775003667, 12.62400855049158, 11.615100454626507, 10.638903698408887, 9.690830750465137, 8.99015715287343, 9.836181823462676, 10.85596500715985, 11.803384926478719, 12.787670517033995, 13.553644062524219, 12.662281647388324, 15.702168590927633, 14.645863023888438, 13.66584829920219, 12.698997371976223, 11.743339235716668, 10.857438764910384, 9.946994101975207, 10.788472213336304, 11.768740880903989, 12.747682748029398, 12.634938741450632, 11.665028562750809, 10.727760530919364, 9.95444041123994, 10.830673807887145, 11.758123693940728, 12.69213750535498, 13.657733771427035, 14.616248893377993, 13.630322375187035, 14.687140108358578, 13.675277415887725, 12.735313209228568, 11.741237015505083, 10.798367684832824, 9.879197165862527, 8.942908042052958, 9.833930686489543, 10.8231571279209, 11.75299496314211, 12.669534458974743, 12.66869965710802, 11.770705222996016, 10.947210120504293, 11.867936136614581, 12.756478764200502, 13.66662748739715, 14.591031672969761, 15.568803426918528, 14.62433231467395, 13.67721684000191, 12.730469246015556, 11.78302257578475, 10.78122982368257, 9.755189985715761, 8.826824519385942, 7.91013827469517, 8.777749569618223, 9.79674804743986, 10.75826857196866, 11.681599932258642, 12.524590548125992, 12.816834657195164, 11.88199852951323, 12.874370461023313, 13.824114210192093, 14.687169059991923, 15.651516669426847, 16.494173860730044, 15.570176979937424, 12.788916843311721, 11.72061669244586, 10.726888666873128, 9.784422325174138, 8.757680230082647, 7.77293861435353, 6.908149982282136, 7.846377934143279, 8.824283014393046, 9.772692474993022, 10.656266049253292, 11.570371752619243, 12.424765385493707, 12.85267198913961, 13.815218570174554, 14.769843336809906, 15.640712094794175, 16.675076481746753, 17.532920138708867, 16.540984884070625, 11.731297368137035, 10.804148687466348, 9.758403027438945, 8.824291263016567, 7.786053399730095, 6.822710721670406, 5.85680749735972, 6.851606651143534, 7.86702050090766, 8.749292145267278, 9.639573764865032, 10.545885694737379, 11.499547262151154, 12.453756693477814, 13.415663924882908, 14.377911599943099, 15.349866444269267, 16.325973574392375, 17.26039182922547, 17.466342866481817, 10.678924686896147, 9.878363173649522, 8.880387316170438, 7.891692654244578, 6.886848821089291, 5.86538556221757, 4.911539288937542, 5.8562949556148105, 6.8055300596299855, 7.746302066568229, 8.671679742583002, 9.594452024929586, 10.55223313359799, 11.589440668464603, 12.460083651854207, 13.485712416676511, 14.403108071277181, 15.464142844633582, 16.408365402569842, 17.432842442018057, 9.6993683048097, 8.89075043484919, 7.850113662293499, 6.853299847914401, 5.934685186701954, 4.925935719403169, 3.9685571433244906, 4.8304514579195255, 5.795204469732143, 6.835965681494221, 7.742404213581295, 8.62278328191462, 9.581728754707852, 10.53877402904643, 11.474571216630505, 12.432268877237142, 13.471886760284864, 14.532271194756154, 15.481719217045958, 16.41451592186914, 8.719101910932585, 7.841234276974337, 6.7792202367619385, 5.894635899414325, 4.918076062109536, 3.9482301939590903, 2.967457192656977, 3.8653629364745785, 4.897062887478896, 5.889217369975725, 6.680544177154318, 7.642408149055557, 8.676770710489173, 9.661360871909901, 10.682771564437804, 11.656060204866801, 12.638633268067958, 13.542691693869614, 14.607752742654595, 15.509049160822798, 7.77830136862968, 6.8138693937174635, 5.8459132743617435, 4.921625830424086, 3.9886743679553507, 2.947567478565215, 1.9529723666692682, 2.868426817628541, 3.9047508611111645, 4.8383986017203675, 5.734000595440872, 6.724335953716341, 7.6986806851586405, 8.691469784918223, 9.670175673227044, 10.697205672364465, 11.603027375858828, 12.545328132290168, 13.550693775228554, 14.470655815927566, 6.944719108866226, 5.955232342066523, 4.91611180095698, 3.9044594865917235, 2.9463240838140754, 1.8949976159203068, 1.020996230564213, 1.8786768260597877, 2.8674050242997184, 3.78114405268767, 4.782186264312302, 5.7920569319695785, 6.772165765296865, 7.736849579882705, 8.728968004525305, 9.67434708329508, 10.603740681617408, 11.533376992098713, 12.52242222642572, 13.457096654991584, 5.967444412688621, 4.944453253200962, 4.00729993995672, 3.0004801498565534, 1.945802994438831, 0.9429531772747846, 0.0, 0.9388953071876986, 1.8759365804366344, 2.811703163844604, 3.884721088872895, 4.8676428451014395, 5.855251662381723, 6.840988529762043, 7.89927900157576, 8.918703823048322, 9.879883429108647, 10.84336897014635, 11.792394065436318, 12.745505853048996, 6.903485496781688, 5.891843761138294, 5.005181509308553, 3.9890519994190416, 2.9142437610176626, 1.88050891004062, 1.0592296823467144, 1.902976890854702, 2.8035155550398785, 3.768514282387443, 4.72437727871164, 5.773718826515289, 6.783954633675865, 7.839860608666544, 8.793480218886744, 9.782479237811746, 10.7975219743956, 11.777829566904643, 12.764232100183934, 13.697191500585847], [13.664093792111636, 12.648710092744686, 11.657627714978515, 10.598082130193816, 9.658564748595982, 8.608106590592248, 7.627031292874895, 6.661029801202989, 5.641800310954387, 4.703085558302674, 3.7743460837787257, 2.8938508213895564, 1.897348973160518, 2.907206444723694, 3.8365120899294833, 4.793866425339083, 5.84527988002617, 6.8080083634796, 7.826919136321465, 8.781014769614904, 12.756875552747458, 13.446645559074494, 12.474004979582155, 11.53365916932008, 10.551276957578192, 9.548305916846177, 8.581807667761955, 7.596401772715715, 6.581564260300953, 5.629922634891573, 4.8213737525667755, 3.8287342898161083, 2.889671537058699, 3.8412416519448938, 4.791887786577984, 5.758623048737696, 6.798559516908934, 7.78846078718551, 8.767764204856126, 7.952281337379211, 13.590773011864771, 14.379677152545764, 13.483109774982108, 12.482718365004123, 11.485326425073438, 10.514127490548681, 9.544099675385004, 8.542971287181096, 7.603741645856654, 6.6785944217505975, 5.812303003950571, 4.775114181846923, 3.9275007821431878, 4.879669099825989, 5.766317404365859, 6.789049819306458, 7.76960906367276, 8.732518563871832, 9.672031021053998, 8.877377121703901, 14.57111456893385, 15.33743150343995, 14.391913018785257, 13.339511014343667, 12.410359809624044, 11.440424667942624, 10.484034720579153, 9.544751916906899, 8.578967266608782, 7.723542399020616, 6.853982765065096, 5.826341971949724, 4.913066965061951, 5.822005137586586, 6.794508565748923, 7.7387386811183925, 8.78042367178496, 9.7084699296388, 10.6005151041303, 9.717913717312236, 15.616406170022012, 16.287907303863584, 15.310068224777774, 14.246548787291422, 13.315853653592075, 12.388671091265797, 11.458993201692278, 10.561328687368567, 9.607473059239606, 8.73703375433242, 7.765172125286693, 6.761888931798038, 5.856666172396543, 6.7974000339790095, 7.79199330033256, 8.755830159608786, 9.77590803645162, 10.640213494773977, 11.573216950701989, 10.62777670217195, 16.421925526062623, 17.235980149036543, 16.198548285231634, 15.196030564293201, 14.29340108516592, 13.388515282180151, 12.420708552070506, 11.60680769950298, 10.54564151422142, 9.704303485953563, 8.706960217579534, 7.7733117709781485, 6.821709964449566, 7.798613586365241, 8.774973697674726, 9.718131743949614, 10.776979545770715, 11.676227933620211, 12.574346574254752, 11.644144341814105, 17.45967277032719, 17.502343821162928, 16.567383029255367, 15.573402259304965, 14.610408895549622, 13.810789862436351, 12.82887654284361, 11.78160710071493, 11.587920076254031, 10.690476954440324, 9.685097267113623, 8.718700385032689, 7.766672078433367, 8.790963624975676, 9.722272145160131, 10.774974970587817, 11.798636720744682, 12.729202955763721, 13.542923460064683, 12.613857631540151, 17.542607041701473, 16.50526364276572, 15.541930934462089, 14.575130015703754, 13.577182732514038, 12.783865868604176, 11.7669567080116, 10.824794147848039, 11.783078216284109, 11.68511324330388, 10.676205147438807, 9.700008391221187, 8.751935443277437, 9.69014007805255, 10.695840811127967, 11.715623994825142, 12.66304391414401, 13.647329504699286, 14.492539369711919, 13.601176954576024, 16.610188429309076, 15.55388286226988, 14.573868137583633, 13.607017210357665, 12.65135907409811, 11.747295039840136, 10.786956584419174, 9.851432679583745, 10.83170134715143, 11.810643214276839, 11.696043434262933, 10.72613325556311, 9.788865223731664, 10.654423336419061, 11.609163991428641, 12.536613877482225, 13.470627688896476, 14.436223954968531, 15.481414397430495, 14.569217682374735, 15.595159946740022, 14.58329725426917, 13.64333304761001, 12.649256853886525, 11.706387523214266, 10.769053440792279, 9.83276431698271, 8.896891152736984, 9.886117594168342, 10.81595542938955, 11.730639151787045, 11.72980434992032, 10.831809915808316, 11.647193045683414, 12.646426320156078, 13.534968947741998, 14.445117670938647, 15.369521856511257, 16.43396893097103, 15.539521676710502, 14.585236678383353, 13.638489084397, 12.691042414166194, 11.689249662064013, 10.663209824097203, 9.734844357767384, 8.799994549624921, 7.840710035865665, 8.8597085136873, 9.819373264780962, 10.742704625070944, 11.585695240938296, 11.877939350007464, 12.581981454692352, 13.574353386202434, 14.524097135371214, 15.46565924353342, 16.430006852968344, 17.359339364782546, 16.485366341973975, 13.696936681693165, 12.628636530827304, 11.634908505254572, 10.69244216355558, 9.665700068464089, 8.680958452734972, 7.816169820663578, 6.9093384003907214, 7.887243480640489, 8.833797167805324, 9.717370742065594, 10.631476445431547, 11.485870078306009, 12.493862836513681, 13.440156021114316, 14.394710456792161, 15.396220151077065, 16.40004596933589, 17.33899691262047, 17.456174246107178, 12.670192675324735, 11.712168525847794, 10.666422865820389, 9.732311101398011, 8.694073238111537, 7.730730560051848, 6.764827335741162, 5.914567117390977, 6.929980967155103, 7.81039683807958, 8.700678457677334, 9.606990387549683, 10.560651954963456, 11.514861386290116, 12.47676861769521, 13.4390162927554, 14.41097113708157, 15.387078267204677, 16.321496522037773, 17.319342855927218, 11.617819994083847, 10.817258480837221, 9.819282623358138, 8.799712492626021, 7.794868659470733, 6.773405400599012, 5.819559127318984, 4.9173996484271125, 5.8666347524422875, 6.807406759380531, 7.732784435395304, 8.65555671774189, 9.613337826410293, 10.650545361276905, 11.521188344666509, 12.546817109488813, 13.464212764089483, 14.525247537445884, 15.469470095382144, 16.49394713483036, 10.6382636119974, 9.82964574203689, 8.789008969481198, 7.792195155102099, 6.842705025083396, 5.833955557784611, 4.876576981705933, 3.891556150731827, 4.856309162544445, 5.897070374306523, 6.8035089063935965, 7.683887974726923, 8.642833447520154, 9.599878721858731, 10.535675909442807, 11.493373570049444, 12.532991453097166, 13.593375887568456, 14.54282390985826, 15.47562061468144, 9.657997218120284, 8.780129584162037, 7.718115543949638, 6.833531206602023, 5.826095900490978, 4.856250032340532, 3.8754770310384195, 2.92646762928688, 3.9581675802911973, 4.950322062788025, 5.741648869966619, 6.703512841867859, 7.737875403301475, 8.722465564722203, 9.743876257250104, 10.717164897679101, 11.699737960880258, 12.603796386681914, 13.668857435466895, 14.570153853635098, 8.71719667581738, 7.752764700905163, 6.784808581549443, 5.860521137611784, 4.927569675143049, 3.8845465402396337, 2.88129765618704, 1.9295315104408421, 2.9658555539234657, 3.8995032945326686, 4.795105288253173, 5.7854406465286425, 6.759785377970942, 7.752574477730524, 8.731280366039345, 9.758310365176765, 10.664132068671128, 11.606432825102468, 12.611798468040854, 13.531760508739866, 7.883614416053925, 6.894127649254221, 5.8550071081446795, 4.843354793779422, 3.8852193910017743, 2.8338929231080052, 1.9493215200819844, 0.9397815188720892, 1.9285097171120196, 2.8422487454999716, 3.8432909571246037, 4.85316162478188, 5.833270458109166, 6.797954272695006, 7.790072697337605, 8.73545177610738, 9.664845374429708, 10.594481684911013, 11.58352691923802, 12.518201347803885, 6.9063397198763194, 5.883348560388661, 4.946195247144419, 3.939375457044252, 2.8846983016265297, 1.8818484844624832, 0.9388953071876986, 0.0, 0.9370412732489357, 1.8728078566569057, 2.9458257816851967, 3.9287475379137415, 4.916356355194025, 5.902093222574345, 6.960383694388062, 7.979808515860624, 8.940988121920949, 9.904473662958653, 10.85349875824862, 11.806610545861298, 7.8423808039693865, 6.830739068325993, 5.944076816496251, 4.9279473066067405, 3.853139068205361, 2.8194042172283185, 1.998124989534413, 0.9640815836670034, 1.86462024785218, 2.8296189751997445, 3.785481971523941, 4.83482351932759, 5.845059326488167, 6.900965301478846, 7.854584911699046, 8.843583930624048, 9.858626667207902, 10.838934259716945, 11.825336792996236, 12.758296193398149], [12.7270525188627, 11.71166881949575, 10.72058644172958, 9.661040856944881, 8.721523475347047, 7.671065317343313, 6.689990019625959, 5.723988527954054, 4.704759037705451, 3.7660442850537383, 2.83730481052979, 1.9568095481406207, 2.8343902464094537, 3.844247717972629, 4.773553363178419, 5.730907698588019, 6.782321153275106, 7.745049636728536, 8.7639604095704, 9.718056042863838, 11.819834279498522, 12.509604285825558, 11.53696370633322, 10.596617896071145, 9.614235684329257, 8.611264643597242, 7.64476639451302, 6.659360499466779, 5.644522987052018, 4.6928813616426375, 3.8843324793178398, 2.8916930165671726, 3.826712810307635, 4.778282925193829, 5.728929059826919, 6.695664321986632, 7.73560079015787, 8.725502060434446, 9.704805478105062, 8.889322610628145, 12.653731738615836, 13.442635879296828, 12.546068501733172, 11.545677091755188, 10.548285151824503, 9.577086217299746, 8.607058402136069, 7.60593001393216, 6.6667003726077185, 5.741553148501662, 4.875261730701636, 3.8380729085979874, 4.864542055392123, 5.816710373074924, 6.703358677614794, 7.726091092555395, 8.706650336921696, 9.669559837120767, 10.609072294302933, 9.814418394952838, 13.634073295684916, 14.400390230191014, 13.454871745536323, 12.402469741094732, 11.473318536375109, 10.503383394693689, 9.546993447330218, 8.607710643657962, 7.641925993359846, 6.7865011257716805, 5.916941491816161, 4.889300698700788, 5.850108238310886, 6.759046410835522, 7.731549838997858, 8.675779954367329, 9.717464945033896, 10.645511202887736, 11.537556377379236, 10.654954990561171, 14.679364896773077, 15.350866030614648, 14.373026951528841, 13.309507514042489, 12.378812380343142, 11.451629818016862, 10.521951928443343, 9.62428741411963, 8.670431785990669, 7.7999924810834855, 6.8281308520377575, 5.8248476585491025, 6.7913643907739125, 7.732098252356379, 8.726691518709929, 9.690528377986155, 10.712949309700555, 11.577254768022913, 12.510258223950924, 11.564817975420885, 15.484884252813687, 16.29893887578761, 15.261507011982701, 14.258989291044267, 13.356359811916986, 12.451474008931216, 11.48366727882157, 10.669766426254043, 9.608600240972484, 8.767262212704628, 7.769918944330598, 6.836270497729213, 7.756408182826935, 8.73331180474261, 9.709671916052095, 10.652829962326983, 11.711677764148083, 12.613269206869145, 13.511387847503688, 12.581185615063042, 16.522631497078258, 17.250019761217615, 16.27882574649892, 15.267276898243091, 14.322299287705096, 13.418720333922815, 12.460455934650895, 11.620485124805274, 10.650878803005094, 9.75343568119139, 8.748055993864687, 7.781659111783753, 8.701370296810737, 9.725661843353047, 10.656970363537502, 11.709673188965187, 12.733334939122052, 13.666244229012655, 14.47996473331362, 13.550898904789088, 17.33433239276551, 17.442304916014653, 16.478972207711024, 15.512171288952688, 14.514224005762971, 13.720907141853111, 12.703997981260535, 11.761835421096976, 11.150468221718068, 10.748071970054944, 9.739163874189872, 8.762967117972252, 9.686633661654808, 10.624838296429921, 11.630539029505337, 12.650322213202513, 13.59774213252138, 14.582027723076656, 15.429580642960856, 14.53821822782496, 17.54722970255801, 16.490924135518814, 15.510909410832566, 14.544058483606598, 13.588400347347044, 12.684336313089071, 11.72399785766811, 10.78847395283268, 10.148359972064696, 10.975582445929593, 10.759002161013997, 9.789091982314174, 10.723563442109034, 11.589121554796431, 12.543862209806012, 13.471312095859595, 14.405325907273847, 15.370922173345901, 16.416112615807865, 15.50625895562367, 16.53220121998896, 15.520338527518104, 14.580374320858946, 13.58629812713546, 12.643428796463201, 11.706094714041214, 10.769805590231645, 9.83393242598592, 9.201975431594455, 9.980894661042305, 10.79359787853811, 10.792763076671385, 11.766508134185687, 12.581891264060785, 13.581124538533448, 14.469667166119368, 15.379815889316017, 16.30422007488863, 17.3686671493484, 16.476562949959437, 15.522277951632288, 14.575530357645935, 13.62808368741513, 12.626290935312948, 11.600251097346138, 10.67188563101632, 9.737035822873857, 8.777751309114599, 8.147953400590794, 8.979316562931844, 9.805663351822009, 10.648653967689361, 11.556827490842858, 12.527495022891125, 13.519866954401207, 14.469610703569987, 15.412721912630381, 16.477640002973384, 17.440701917350356, 17.422407615222912, 14.6339779549421, 13.56567780407624, 12.571949778503507, 11.629483436804515, 10.602741341713024, 9.617999725983907, 8.753211093912515, 7.846379673639657, 7.081918704700116, 7.993740465956205, 8.780329468816658, 9.694435172182612, 10.548828805057074, 11.556821563264746, 12.50311474786538, 13.457669183543226, 14.45917887782813, 15.463004696086955, 16.401955639371533, 17.307659565089473, 13.60723394857367, 12.649209799096727, 11.603464139069324, 10.669352374646946, 9.631114511360472, 8.667771833300783, 7.7018686089900985, 6.851608390639912, 6.12465619121473, 6.970340136230461, 7.763637184428398, 8.669949114300747, 9.62361068171452, 10.57782011304118, 11.539727344446275, 12.501975019506466, 13.473929863832634, 14.450036993955742, 15.384455248788836, 16.38230158267828, 12.554861267332782, 11.754299754086155, 10.756323896607075, 9.736753765874957, 8.731909932719669, 7.710446673847948, 6.75660040056792, 5.854440921676048, 5.055236322165712, 5.967350057531412, 6.795743162146369, 7.7185154444929545, 8.676296553161357, 9.71350408802797, 10.584147071417574, 11.609775836239878, 12.527171490840548, 13.588206264196948, 14.532428822133209, 15.556905861581425, 11.575304885246336, 10.766687015285825, 9.726050242730134, 8.729236428351033, 7.779746298332332, 6.770996831033547, 5.813618254954869, 4.828597423980763, 4.027719466870175, 5.037390076638275, 5.866467633144661, 6.746846701477987, 7.7057921742712185, 8.662837448609796, 9.598634636193871, 10.556332296800509, 11.59595017984823, 12.65633461431952, 13.605782636609325, 14.538579341432504, 10.59503849136922, 9.717170857410972, 8.655156817198574, 7.770572479850959, 6.763137173739914, 5.793291305589468, 4.812518304287355, 3.863508902535816, 3.0520094345191446, 4.01328078953909, 4.804607596717684, 5.766471568618924, 6.8008341300525395, 7.785424291473268, 8.806834984001169, 9.780123624430166, 10.762696687631323, 11.66675511343298, 12.731816162217962, 13.633112580386165, 9.654237949066315, 8.6898059741541, 7.7218498547983785, 6.797562410860719, 5.864610948391984, 4.821587813488569, 3.818338929435975, 2.866572783689778, 2.059697408151413, 2.962462021283733, 3.8580640150042376, 4.848399373279707, 5.822744104722006, 6.815533204481588, 7.794239092790409, 8.82126909192783, 9.727090795422193, 10.669391551853533, 11.674757194791919, 12.594719235490931, 8.82065568930286, 7.831168922503156, 6.792048381393615, 5.780396067028358, 4.8222606642507095, 3.770934196356941, 2.88636279333092, 1.876822792121025, 0.9914684438630839, 1.905207472251036, 2.906249683875668, 3.9161203515329444, 4.896229184860231, 5.860912999446071, 6.85303142408867, 7.798410502858445, 8.727804101180773, 9.657440411662078, 10.646485645989085, 11.58116007455495, 7.843380993125255, 6.820389833637596, 5.883236520393354, 4.876416730293188, 3.8217395748754655, 2.818889757711419, 1.8759365804366344, 0.9370412732489357, 0.0, 0.93576658340797, 2.008784508436261, 2.991706264664806, 3.9793150819450895, 4.96505194932541, 6.023342421139127, 7.0427672426116885, 8.003946848672014, 8.967432389709717, 9.916457484999684, 10.869569272612363, 8.779422077218321, 7.7677803415749285, 6.881118089745188, 5.864988579855677, 4.790180341454297, 3.756445490477254, 2.9351662627833486, 1.901122856915939, 0.9275789746032442, 1.8925777019508088, 2.8484406982750055, 3.897782246078654, 4.908018053239232, 5.96392402822991, 6.917543638450111, 7.9065426573751125, 8.921585393958967, 9.90189298646801, 10.8882955197473, 11.821254920149213], [11.79128593545473, 10.77590223608778, 9.78481985832161, 8.725274273536911, 7.7857568919390765, 6.735298733935343, 5.754223436217989, 4.788221944546084, 3.7689924542974813, 2.8302777016457683, 1.90153822712182, 2.8589702898809275, 3.7701568298174237, 4.780014301380599, 5.709319946586389, 6.666674281995988, 7.718087736683075, 8.680816220136506, 9.69972699297837, 10.653822626271808, 10.884067696090552, 11.573837702417588, 10.60119712292525, 9.660851312663175, 8.678469100921287, 7.6754980601892715, 6.70899981110505, 5.723593916058809, 4.708756403644048, 3.757114778234667, 2.9714230561673576, 3.7938537583074794, 4.742048106253795, 5.714049508601799, 6.664695643234889, 7.631430905394601, 8.67136737356584, 9.661268643842416, 10.640572061513032, 9.825089194036117, 11.717965155207866, 12.506869295888858, 11.610301918325202, 10.609910508347218, 9.612518568416533, 8.641319633891776, 7.671291818728099, 6.67016343052419, 5.7309337891997485, 4.805786565093692, 4.0282853257821545, 4.740233650338294, 5.7720028304287485, 6.7412704718071055, 7.639125261022764, 8.661857675963363, 9.642416920329666, 10.605326420528737, 11.544838877710903, 10.750184978360807, 12.698306712276946, 13.464623646783044, 12.519105162128351, 11.466703157686762, 10.537551952967139, 9.567616811285719, 8.611226863922248, 7.6719440602499915, 6.7061594099518755, 5.8507345423637105, 5.094535348840203, 5.791461440441095, 6.757569013347512, 7.683606509567703, 8.656109937730038, 9.611546537775297, 10.653231528441866, 11.581277786295706, 12.473322960787206, 11.590721573969141, 13.743598313365107, 14.415099447206677, 13.437260368120869, 12.373740930634517, 11.44304579693517, 10.515863234608892, 9.586185345035373, 8.68852083071166, 7.734665202582699, 6.8642258976755155, 6.067197761994818, 6.727008400289409, 7.693525132514219, 8.634258994096685, 9.628852260450236, 10.592689119726462, 11.624482996913015, 12.513021351430883, 13.446024807358894, 12.500584558828855, 14.549117669405717, 15.36317229237964, 14.32574042857473, 13.323222707636296, 12.420593228509015, 11.515707425523246, 10.5479006954136, 9.733999842846073, 8.672833657564514, 7.831495629296657, 7.008985854287658, 7.73843123946952, 8.658568924567243, 9.635472546482916, 10.6118326577924, 11.554990704067288, 12.613838505888388, 13.549035790277117, 14.447154430911658, 13.51695219847101, 15.586864913670288, 16.314253177809643, 15.343059163090947, 14.33151031483512, 13.386532704297124, 12.482953750514845, 11.524689351242925, 10.684718541397304, 9.715112219597124, 8.817669097783417, 8.00506208462969, 8.68381985352406, 9.603531038551044, 10.627822585093353, 11.559131105277809, 12.611833930705494, 13.635495680862359, 14.578322021237215, 15.415731316721589, 14.486665488197056, 16.398565809357542, 17.311333356206852, 16.368511257884226, 15.340470267957325, 14.41975886733271, 13.524691009844071, 12.586609186074934, 11.62634009879082, 10.66805603035475, 9.812305386646972, 9.071210183883917, 9.665127859712559, 10.588794403395115, 11.526999038170228, 12.532699771245644, 13.55248295494282, 14.499902874261688, 15.484188464816963, 16.365347226368822, 15.47398481123293, 17.33098442174994, 17.426690718926782, 16.446675994240536, 15.47982506701457, 14.524166930755015, 13.620102896497043, 12.659764441076081, 11.724240536240652, 10.921350453325784, 10.039815862521623, 10.091048470708042, 10.69125272405448, 11.625724183849341, 12.491282296536738, 13.446022951546318, 14.373472837599902, 15.307486649014153, 16.273082915086206, 17.31827335754817, 16.44202553903164, 17.467967803396927, 16.456105110926075, 15.516140904266916, 14.52206471054343, 13.579195379871171, 12.641861297449186, 11.705572173639617, 10.769699009393891, 9.974965912855543, 9.045128077634335, 9.85783129513014, 10.678047872047644, 11.667190341634036, 12.526516848492093, 13.527937186621386, 14.455564156130594, 15.465489269185756, 16.4462509433411, 17.4303057677539, 17.412329533367405, 16.45804453504026, 15.511296941053905, 14.5638502708231, 13.562057518720918, 12.536017680754108, 11.60765221442429, 10.672802406281829, 9.713517892522571, 9.054077028049806, 8.043549979523874, 8.869896768414039, 9.712887384281391, 10.621060907434888, 11.591728439483155, 12.584100370993237, 13.533844120162016, 14.476955329222411, 15.541873419565414, 16.504935333942385, 17.342700885814704, 15.56974453835007, 14.50144438748421, 13.507716361911477, 12.565250020212485, 11.538507925120994, 10.553766309391877, 9.688977677320485, 8.782146257047627, 7.988042332159127, 7.057973882548235, 7.844562885408688, 8.758668588774642, 9.613062221649104, 10.621054979856776, 11.56734816445741, 12.521902600135256, 13.52341229442016, 14.527238112678985, 15.466189055963563, 16.3718929816815, 14.54300053198164, 13.5849763825047, 12.539230722477294, 11.605118958054916, 10.566881094768442, 9.603538416708753, 8.637635192398069, 7.787374974047882, 7.030779818673741, 6.034573552822491, 6.827870601020428, 7.734182530892778, 8.68784409830655, 9.64205352963321, 10.603960761038305, 11.566208436098496, 12.538163280424664, 13.514270410547772, 14.448688665380866, 15.44653499927031, 13.490627850740752, 12.690066337494127, 11.692090480015043, 10.672520349282927, 9.667676516127639, 8.646213257255917, 7.69236698397589, 6.790207505084018, 5.961359949624723, 5.031583474123442, 5.859976578738399, 6.782748861084984, 7.740529969753387, 8.777737504619997, 9.648380488009604, 10.674009252831908, 11.591404907432578, 12.652439680788978, 13.596662238725239, 14.621139278173455, 12.511071468654306, 11.702453598693795, 10.661816826138104, 9.665003011759003, 8.715512881740302, 7.706763414441517, 6.749384838362839, 5.764364007388733, 4.933843094329186, 4.101623493230305, 4.930701049736691, 5.811080118070017, 6.7700255908632485, 7.727070865201825, 8.662868052785901, 9.620565713392539, 10.66018359644026, 11.72056803091155, 12.670016053201355, 13.602812758024534, 11.53080507477719, 10.652937440818942, 9.590923400606544, 8.706339063258929, 7.698903757147884, 6.729057888997438, 5.748284887695325, 4.799275485943786, 3.9581330619781556, 3.07751420613112, 3.868841013309714, 4.830704985210954, 5.865067546644569, 6.849657708065298, 7.871068400593199, 8.844357041022196, 9.826930104223353, 10.730988530025009, 11.79604957880999, 12.697345996978193, 10.590004532474286, 9.62557255756207, 8.657616438206349, 7.733328994268689, 6.800377531799954, 5.757354396896539, 4.754105512843945, 3.802339367097748, 2.965821035610424, 2.026695437875763, 2.9222974315962675, 3.9126327898717372, 4.886977521314036, 5.879766621073618, 6.858472509382439, 7.88550250851986, 8.791324212014223, 9.733624968445563, 10.738990611383949, 11.658952652082961, 9.75642227271083, 8.766935505911126, 7.727814964801585, 6.716162650436328, 5.75802724765868, 4.706700779764911, 3.82212937673889, 2.812589375528995, 1.8975920713220948, 0.9694408888430659, 1.970483100467698, 2.9803537681249743, 3.960462601452261, 4.925146416038101, 5.9172648406807, 6.862643919450475, 7.792037517772803, 8.721673828254108, 9.710719062581115, 10.64539349114698, 8.779147576533225, 7.756156417045566, 6.819003103801324, 5.812183313701158, 4.7575061582834355, 3.7546563411193885, 2.811703163844604, 1.8728078566569057, 0.93576658340797, 0.0, 1.073017925028291, 2.055939681256836, 3.0435484985371195, 4.02928536591744, 5.087575837731157, 6.1070006592037185, 7.068180265264043, 8.031665806301747, 8.980690901591714, 9.933802689204393, 9.715188660626291, 8.703546924982899, 7.816884673153156, 6.800755163263646, 5.725946924862266, 4.692212073885224, 3.8709328461913186, 2.836889440323909, 1.8633455580112144, 0.9568111185428387, 1.9126741148670354, 2.962015662670684, 3.972251469831262, 5.02815744482194, 5.981777055042141, 6.9707760739671425, 7.985818810550998, 8.96612640306004, 9.95252893633933, 10.885488336741243], [10.813513098209542, 9.814255815156413, 8.823173437390242, 7.763627852605543, 6.8241104710077085, 5.773652313003975, 4.792577015286621, 3.826575523614716, 2.921999784290926, 1.983285031639213, 2.84690817565473, 3.804340238413837, 4.843174754845715, 5.8530322264088905, 6.78233787161468, 7.739692207024279, 8.791105661711367, 9.753834145164797, 10.772744918006662, 11.7268405513001, 9.81104977106226, 10.61219128148622, 9.639550701993882, 8.699204891731807, 7.716822679989919, 6.7138516392579035, 5.747353390173682, 4.876601246052254, 3.861763733637493, 2.9101221082281117, 3.9102698674978136, 4.739223706840389, 5.687418054786704, 6.692473054241133, 7.643119188874223, 8.62184540179106, 9.661781869962297, 10.692683623305815, 11.67198704097643, 10.89810711906441, 10.688695933169557, 11.54522287495749, 10.648655497393834, 9.64826408741585, 8.650872147485165, 7.679673212960408, 6.709645397796731, 5.823170760517635, 4.883941119193193, 3.958793895087137, 4.9671321371126105, 5.685603598871204, 6.717372778961658, 7.686640420340015, 8.617548806662098, 9.652272172359822, 10.632831416726123, 11.636741399992136, 12.576253857174303, 11.823202903389099, 11.669037490238637, 12.502977225851676, 11.557458741196985, 10.505056736755394, 9.57590553203577, 8.60597039035435, 7.649580442990881, 6.824951390243436, 5.85916673994532, 5.003741872357155, 5.961122943738533, 6.736831388974005, 7.702938961880421, 8.628976458100613, 9.601479886262949, 10.572140892123262, 11.624825878273283, 12.612692765759105, 13.504737940250605, 12.663739498997431, 12.714329091326798, 13.45345302627531, 12.475613947189503, 11.41209450970315, 10.481399376003804, 9.554216813677524, 8.624538924104005, 7.841528160705105, 6.887672532576143, 6.01723322766896, 6.933785356893147, 7.672378348822319, 8.63889508104713, 9.579628942629595, 10.574222208983146, 11.538059068259372, 12.569852945445925, 13.544436330894282, 14.519042732387184, 13.573602483857146, 13.5448924446517, 14.401525871448273, 13.364094007643363, 12.36157628670493, 11.458946807577648, 10.554061004591878, 9.586254274482233, 8.887007172839517, 7.825840987557958, 6.984502959290102, 7.875573449185988, 8.68380118800243, 9.603938873100153, 10.580842495015826, 11.55720260632531, 12.500360652600198, 13.559208454421299, 14.580450769740516, 15.520172355939948, 14.589970123499302, 14.58263968891627, 15.352606756878275, 14.381412742159581, 13.369863893903753, 12.424886283365758, 11.521307329583477, 10.563042930311557, 9.837725871390749, 8.868119549590569, 7.970676427776863, 8.871649679528021, 9.62918980205697, 10.548900987083954, 11.573192533626264, 12.504501053810719, 13.557203879238404, 14.58086562939527, 15.523691969770125, 16.48874924174988, 15.559683413225349, 15.416914155152401, 16.349686935275482, 15.406864836952858, 14.37882384702596, 13.458112446401344, 12.563044588912703, 11.624962765143566, 10.779347428784265, 9.821063360348194, 8.965312716640419, 9.937797778782247, 10.61049780824547, 11.534164351928025, 12.472368986703138, 13.478069719778555, 14.49785290347573, 15.445272822794598, 16.429558413349874, 17.384804238395496, 16.54700273626122, 16.349332767544798, 17.28645989298904, 16.306445168302794, 15.339594241076826, 14.383936104817272, 13.599615417676743, 12.604962888735992, 11.75270889704856, 10.823171610001566, 9.956707795663794, 9.92903459233794, 10.700067312199716, 11.679640457841638, 12.537634903551307, 13.492375558560887, 14.419825444614471, 15.353839256028722, 16.319435522100775, 17.364625964562737, 17.51504346405993, 17.391782076710545, 17.529123035954367, 16.552300003663376, 15.558223809939893, 14.615354479267634, 13.634083470689266, 12.697794346879697, 11.708639625939936, 10.719413184508578, 9.78957534928737, 8.876179640925, 9.696396217842505, 10.685538687428897, 11.544865194286954, 12.546285532416245, 13.473912501925453, 14.483837614980615, 15.464599289135958, 16.44865411354876, 17.30689389687304, 17.531062460068547, 16.584314866082195, 15.636868195851392, 14.63507544374921, 13.6090356057824, 12.680670139452582, 11.665024579521909, 10.705740065762651, 9.818096188183972, 8.78799725117691, 7.8882451142089005, 8.731235730076252, 9.639409253229749, 10.610076785278016, 11.602448716788098, 12.552192465956878, 13.495303675017272, 14.560221765360275, 15.523283679737244, 16.361049231609563, 16.64276246337836, 15.574462312512502, 14.58073428693977, 13.638267945240777, 12.611525850149286, 11.62678423442017, 10.761995602348776, 9.774368430287707, 8.752061492293294, 7.802421154201271, 6.862911231203549, 7.777016934569502, 8.631410567443965, 9.639403325651637, 10.585696510252271, 11.540250945930117, 12.54176064021502, 13.545586458473844, 14.484537401758422, 15.390241327476362, 15.61601845700993, 14.657994307532991, 13.612248647505586, 12.678136883083209, 11.639899019796735, 10.676556341737045, 9.710653117426359, 8.779597147287962, 7.794798978807909, 6.779020824475527, 5.846218946815289, 6.752530876687639, 7.706192444101411, 8.660401875428072, 9.622309106833166, 10.584556781893356, 11.556511626219523, 12.53261875634263, 13.467037011175725, 14.46488334506517, 14.563645775769043, 13.763084262522415, 12.765108405043335, 11.745538274311219, 10.74069444115593, 9.71923118228421, 8.76538490900418, 7.782429678324098, 6.833194574308922, 5.892422567370678, 4.87832492453326, 5.801097206879845, 6.758878315548248, 7.796085850414858, 8.666728833804465, 9.692357598626767, 10.609753253227437, 11.64821445603496, 12.592437013971221, 13.616914053419437, 13.584089393682596, 12.775471523722086, 11.734834751166394, 10.738020936787294, 9.788530806768591, 8.779781339469809, 7.822402763391129, 6.837381932417023, 5.923329364388537, 4.962462586477541, 3.949049395531553, 4.829428463864878, 5.788373936658109, 6.745419210996686, 7.681216398580761, 8.638914059187398, 9.67853194223512, 10.716342806157533, 11.665790828447337, 12.598587533270516, 12.60382299980548, 11.725955365847232, 10.663941325634834, 9.779356988287219, 8.771921682176174, 7.802075814025729, 6.821302812723616, 5.872293410972077, 4.947619332037507, 3.938353299378356, 2.8871893591045756, 3.849053331005815, 4.883415892439431, 5.868006053860159, 6.841799178554888, 7.815087818983885, 8.797660882185042, 9.7017193079867, 10.766780356771681, 11.668076774939884, 11.663022457502576, 10.69859048259036, 9.730634363234639, 8.80634691929698, 7.873395456828245, 6.8303723219248305, 5.8271234378722365, 4.875357292126039, 3.9828596669569807, 3.0056896179979704, 1.940645777391129, 2.9309811356665985, 3.9053258671088975, 4.850497399035308, 5.829203287344129, 6.856233286481549, 7.762054989975912, 8.704355746407252, 9.709721389345638, 10.629683430044652, 10.829440197739123, 9.839953430939419, 8.800832889829875, 7.789180575464618, 6.83104517268697, 5.779718704793202, 4.895147301767182, 3.885607300557286, 2.9180248403662206, 1.9898736578871916, 0.9888314462625595, 1.9884254505186831, 2.931193379413951, 3.89587719399979, 4.887995618642389, 5.8333746974121645, 6.762768295734492, 7.692404606215798, 8.681449840542806, 9.61612426910867, 9.852165501561517, 8.829174342073857, 7.892021028829615, 6.885201238729448, 5.830524083311726, 4.82767426614768, 3.8847210888728956, 2.9458257816851967, 2.008784508436261, 1.073017925028291, 0.0, 0.9829217562285447, 1.9705305735088283, 2.956267440889149, 4.014557912702866, 5.033982734175428, 5.995162340235752, 6.958647881273457, 7.907672976563423, 8.8607847641761, 10.788206585654583, 9.77656485001119, 8.889902598181449, 7.873773088291937, 6.798964849890558, 5.765229998913515, 4.94395077121961, 3.9099073653522, 2.8807861759274846, 1.9021810670757486, 0.9463180707515518, 1.9956596185552007, 2.8992335448029705, 3.955139519793649, 4.90875913001385, 5.897758148938852, 6.912800885522707, 7.89310847803175, 8.879511011311038, 9.812470411712951], [9.830591341980998, 8.831334058927869, 7.840251681161698, 6.780706096376999, 5.841188714779165, 4.790730556775431, 3.8096552590580774, 2.843653767386172, 2.0020290899067588, 2.9407438425584718, 3.8298299318832747, 4.787261994642382, 5.826096511074259, 6.8359539826374345, 7.765259627843225, 8.722613963252824, 9.77402741793991, 10.736755901393341, 11.755666674235208, 12.709762307528646, 8.828128014833716, 9.629269525257676, 8.656628945765338, 7.7162831355032635, 6.733900923761375, 5.73092988302936, 4.764431633945138, 3.912856965676819, 2.9417930392533256, 3.8675809191473705, 4.867728678417072, 5.722145463068934, 6.670339811015249, 7.675394810469678, 8.626040945102769, 9.604767158019605, 10.644703626190843, 11.67560537953436, 12.654908797204977, 11.881028875292955, 9.705774176941013, 10.562301118728946, 9.66573374116529, 8.665342331187306, 7.667950391256621, 6.696751456731864, 5.726723641568187, 4.8594264801422, 3.963970424809026, 4.916252706006396, 5.924590948031869, 6.6685253550997485, 7.700294535190203, 8.66956217656856, 9.600470562890644, 10.635193928588368, 11.615753172954669, 12.619663156220682, 13.559175613402848, 12.806124659617645, 10.686115734010093, 11.520055469623133, 10.57453698496844, 9.52213498052685, 8.592983775807227, 7.623048634125808, 6.666658686762337, 5.861207109868001, 4.939196045561153, 5.9253243468980825, 6.8827054182794605, 7.719753145202549, 8.685860718108966, 9.611898214329157, 10.584401642491493, 11.555062648351806, 12.607747634501827, 13.59561452198765, 14.48765969647915, 13.646661255225977, 11.731407335098254, 12.470531270046768, 11.49269219096096, 10.429172753474608, 9.498477619775262, 8.571295057448982, 7.641617167875462, 6.900427983825705, 5.967701838191976, 6.9388157022098875, 7.855367831434075, 8.655300105050864, 9.621816837275675, 10.562550698858141, 11.557143965211692, 12.520980824487918, 13.55277470167447, 14.527358087122828, 15.50196448861573, 14.556524240085691, 12.561970688423154, 13.41860411521973, 12.38117225141482, 11.378654530476387, 10.476025051349106, 9.571139248363336, 8.60333251825369, 7.960113586814979, 6.905870293173791, 7.906085433831029, 8.797155923726915, 9.666722944230976, 10.586860629328699, 11.563764251244372, 12.540124362553856, 13.483282408828744, 14.542130210649844, 15.563372525969061, 16.503094112168494, 15.572891879727848, 13.599717932687724, 14.369685000649733, 13.398490985931039, 12.386942137675211, 11.441964527137216, 10.538385573354935, 9.580121174083015, 8.917755177006581, 7.9481488552064015, 8.89225890231779, 9.793232154068948, 10.612111558285516, 11.5318227433125, 12.55611428985481, 13.487422810039265, 14.54012563546695, 15.563787385623815, 16.506613725998672, 17.471670997978425, 16.542605169453893, 14.494634442859242, 15.366765179046942, 14.423943080724316, 13.395902090797417, 12.475190690172802, 11.580122832684161, 10.642041008915024, 9.859376734400097, 8.901092665964027, 9.886895191181345, 10.859380253323174, 10.81922229649238, 11.809600358246607, 12.594948281868561, 13.5798976629361, 14.49065945509328, 15.438079374412148, 16.42236496496742, 17.377610790013044, 17.529924492489766, 15.427053055251639, 16.303538136760498, 15.323523412074252, 14.356672484848284, 13.40101434858873, 12.6166936614482, 11.62204113250745, 10.832738202664391, 9.903200915617399, 10.87829027020472, 10.788271478621756, 9.793097432150459, 10.77267057779238, 11.63066502350205, 12.58540567851163, 13.512855564565214, 14.446869375979466, 15.41246564205152, 16.457656084513484, 17.378624124066796, 16.469502364417387, 17.271607805518777, 16.27098590386514, 15.288855230144833, 14.345985899472574, 13.562416316239268, 12.6261271924297, 11.787279729511152, 10.84958545608764, 10.733222701002337, 9.735416527208816, 8.789426337793248, 9.77856880737964, 10.637895314237698, 11.639315652366989, 12.566942621876196, 13.576867734931358, 14.557629409086701, 15.5263744012556, 16.38461418457988, 17.338899182907028, 17.56723662231074, 16.619789952079934, 15.617997199977754, 14.591957362010945, 13.663591895681126, 12.639287612520949, 11.680003098761691, 10.76174353989894, 9.731644602891876, 8.831892465923868, 7.824265850026995, 8.732439373180492, 9.70310690522876, 10.695478836738841, 11.645222585907621, 12.588333794968014, 13.653251885311017, 14.601003967444086, 15.438769519316406, 17.62568421960691, 16.557384068741047, 15.563656043168313, 14.621189701469321, 13.59444760637783, 12.609705990648713, 11.744917358577322, 10.748631463286747, 9.695708844008262, 8.746068505916238, 7.806558582918517, 6.870047054520246, 7.724440687394708, 8.73243344560238, 9.678726630203013, 10.633281065880858, 11.634790760165762, 12.623306746180685, 13.562257689465262, 14.467961615183203, 16.59894021323848, 15.640916063761534, 14.59517040373413, 13.661058639311753, 12.622820776025279, 11.65947809796559, 10.693574873654905, 9.753860180287003, 8.738446330522876, 7.722668176190495, 6.7898662985302565, 5.8455609966383815, 6.799222564052155, 7.753431995378814, 8.715339226783907, 9.677586901844098, 10.649541746170266, 11.610339044049471, 12.544757298882566, 13.54260363277201, 15.546567531997589, 14.746006018750961, 13.748030161271881, 12.728460030539763, 11.723616197384475, 10.702152938512754, 9.748306665232725, 8.762381228492172, 7.813146124476996, 6.872374117538753, 5.8219722762482276, 4.894127326830588, 5.851908435498991, 6.889115970365601, 7.759758953755206, 8.78538771857751, 9.70278337317818, 10.665292699806415, 11.609515257742675, 12.633992297190892, 14.567011149911142, 13.758393279950631, 12.71775650739494, 11.72094269301584, 10.771452562997135, 9.762703095698352, 8.805324519619674, 7.820303688645568, 6.906251120617082, 5.9453843427060855, 4.931971151760098, 3.9224585838156205, 4.881404056608852, 5.838449330947428, 6.774246518531504, 7.731944179138141, 8.771562062185863, 9.733421049928987, 10.682869072218791, 11.61566577704197, 13.586744756034026, 12.708877122075778, 11.64686308186338, 10.762278744515765, 9.754843438404718, 8.784997570254273, 7.8042245689521605, 6.855215167200622, 5.930541088266052, 4.921275055606901, 3.8701111153331205, 2.942083450956557, 3.9595373740370383, 4.887386479091471, 5.858877422326344, 6.832166062755341, 7.814739125956498, 8.718797551758154, 9.783858600543136, 10.685155018711342, 12.645944213731122, 11.681512238818906, 10.713556119463185, 9.789268675525525, 8.85631721305679, 7.813294078153374, 6.8100451941007805, 5.858279048354584, 4.9657814231855255, 3.988611374226515, 2.9235675336196736, 1.9745678983999246, 2.9489126298422237, 3.867575642806764, 4.846281531115585, 5.873311530253005, 6.779133233747368, 7.721433990178708, 8.726799633117095, 9.646761673816108, 11.812361953967669, 10.822875187167964, 9.783754646058421, 8.772102331693164, 7.813966928915516, 6.762640461021747, 5.8780690579957255, 4.868529056785831, 3.900946596594765, 2.972795414115736, 1.9717532024911042, 1.0055036942901383, 1.9482716231854063, 2.9129554377712457, 3.905073862413845, 4.850452941183621, 5.779846539505948, 6.709482849987254, 7.698528084314262, 8.633202512880127, 10.835087257790063, 9.812096098302403, 8.874942785058161, 7.868122994957994, 6.813445839540272, 5.810596022376225, 4.86764284510144, 3.9287475379137415, 2.991706264664806, 2.055939681256836, 0.9829217562285447, 0.0, 0.9876088172802836, 1.9733456846606043, 3.0316361564743213, 4.051060977946883, 5.012240584007207, 5.975726125044912, 6.924751220334878, 7.877863007947557, 11.771128341883129, 10.759486606239737, 9.872824354409993, 8.856694844520481, 7.7818866061191025, 6.74815175514206, 5.926872527448155, 4.8928291215807445, 3.8637079321560295, 2.8851028233042935, 1.9292398269800966, 1.0697073562166994, 1.916311788574426, 2.972217763565104, 3.925837373785305, 4.914836392710307, 5.929879129294163, 6.910186721803205, 7.896589255082494, 8.829548655484407], [8.842982524700714, 7.843725241647585, 6.852642863881414, 5.793097279096715, 4.85357989749888, 3.8031217394951473, 2.8220464417777937, 1.8560449501058882, 2.8752744403544908, 3.8139891930062038, 4.742728667530152, 5.700160730289259, 6.7731052064428106, 7.782962678005986, 8.715784046383543, 9.707466338835877, 10.758879793522963, 11.721608276976394, 12.743275491515492, 13.69737112480893, 7.840519197553432, 8.641660707977394, 7.669020128485055, 6.728674318222981, 5.746292106481093, 4.743321065749076, 3.776822816664854, 2.925248148396535, 3.8150383897010576, 4.740826269595102, 5.740974028864804, 6.635044198715811, 7.583238546662126, 8.588293546116555, 9.538939680749646, 10.517665893666482, 11.55760236183772, 12.588504115181237, 13.567807532851853, 12.868637692573238, 8.71816535966073, 9.574692301448664, 8.678124923885006, 7.677733513907023, 6.680341573976338, 5.7091426394515805, 4.739114824287903, 3.8718176628619156, 4.8306358994218055, 5.789498056454127, 6.797836298479601, 7.5814240907466255, 8.61319327083708, 9.582460912215437, 10.513369298537521, 11.548092664235245, 12.528651908601546, 13.532561891867559, 14.472074349049725, 13.79373347689793, 9.698506916729809, 10.53244665234285, 9.586928167688157, 8.534526163246566, 7.6053749585269435, 6.6354398168455235, 5.679049869482053, 4.873598292587717, 5.8058615201739325, 6.791989821510862, 7.74937089289224, 8.632651880849426, 9.598759453755843, 10.524796949976034, 11.49730037813837, 12.467961383998682, 13.520646370148704, 14.508513257634528, 15.400558432126028, 14.634270072506261, 10.74379851781797, 11.482922452766482, 10.505083373680675, 9.441563936194322, 8.510868802494976, 7.583686240168697, 6.654008350595178, 5.912819166545421, 6.834367312804756, 7.805481176822667, 8.722033306046853, 9.568198840697741, 10.534715572922552, 11.475449434505018, 12.470042700858569, 13.433879560134795, 14.465673437321348, 15.440256822769705, 16.44293280710913, 15.544133057365976, 11.57436187114287, 12.430995297939445, 11.393563434134535, 10.391045713196101, 9.48841623406882, 8.583530431083052, 7.6157237009734065, 6.9725047695346944, 7.772535767786572, 8.77275090844381, 9.663821398339694, 10.579621679877853, 11.499759364975576, 12.476662986891249, 13.453023098200733, 14.396181144475621, 15.455028946296721, 16.47627126161594, 17.444062430661894, 16.56050069700813, 12.61210911540744, 13.382076183369447, 12.410882168650753, 11.399333320394925, 10.45435570985693, 9.55077675607465, 8.59251235680273, 7.981629601116143, 8.814814329819182, 9.75892437693057, 10.659897628681726, 11.525010293932393, 12.045310268467746, 12.805851844082946, 13.737160364267401, 14.7454058640756, 15.58945669077689, 16.532283031151746, 17.50354085801686, 17.530213986734175, 13.507025625578958, 14.379156361766656, 13.43633426344403, 12.408293273517131, 11.487581872892516, 10.592514015403877, 9.65443219163474, 8.938442553983036, 9.767758140576808, 10.753560665794126, 11.726045727935952, 11.75449024143465, 11.060046903623675, 11.779612314929835, 12.764561695997374, 13.675323488154554, 14.622743407473422, 15.607028998028698, 16.553924948369623, 17.35905603458522, 14.439444237971355, 15.315929319480214, 14.335914594793966, 13.369063667567998, 12.413405531308443, 11.629084844167917, 10.634432315227166, 9.911804022247331, 10.76986639023018, 11.744955744817501, 11.723539423564025, 10.728365377092729, 10.023117123169449, 10.815329056563325, 11.770069711572905, 12.697519597626489, 13.63153340904074, 14.585020573944028, 15.49132011751585, 16.39101530678651, 15.481893547137101, 16.28399898823849, 15.283377086584851, 14.301246412864547, 13.358377082192288, 12.574807498958984, 11.638518375149415, 10.866345549094092, 11.71625093070042, 11.668490645944608, 10.670684472151086, 9.724694282735518, 8.980172431092797, 9.822559347298972, 10.819689453918127, 11.747316423427334, 12.67096099824596, 13.651722672401302, 14.538765583975314, 15.397005367299595, 16.351290365626742, 17.228807158110662, 16.3202137494535, 15.340647885140113, 14.40155478130935, 13.642677279269664, 12.671288142507203, 11.922526665965412, 11.697011484841212, 10.666912547834148, 9.767160410866138, 8.759533794969265, 7.9340429968936474, 8.887770938290034, 9.782998284879449, 10.717832834938106, 11.650419425651185, 12.69223884022526, 13.6133951501638, 14.451160702036121, 17.282787975904537, 17.54499288602133, 16.551264860448597, 15.608798518749605, 14.582056423658114, 13.597314807928997, 12.732526175857606, 11.683899408229019, 10.630976788950534, 9.68133645085851, 8.741826527860788, 7.8053149994625155, 6.926044311107864, 7.9170974786636545, 8.742221697120916, 9.696776132798762, 10.696876390848933, 11.6356979289004, 12.574648872184978, 13.480352797902919, 17.58654903051876, 16.62852488104182, 15.582779221014414, 14.648667456592037, 13.610429593305563, 12.647086915245874, 11.681183690935189, 10.689128125229274, 9.673714275465148, 8.657936121132765, 7.725134243472527, 6.780828941580652, 6.000826187765311, 6.928612491681296, 7.778834293701811, 8.741081968762002, 9.695203044502797, 10.622730226769187, 11.557148481602281, 12.554994815491726, 16.534176349277875, 15.733614836031247, 14.735638978552164, 13.716068847820047, 12.711225014664759, 11.689761755793038, 10.73591548251301, 9.697649173434442, 8.748414069419267, 7.8076420624810225, 6.757240221190498, 5.829395271772858, 5.053512059212148, 5.995372516085442, 6.82325402067311, 7.8310490169100415, 8.748444671510711, 9.67768388252613, 10.621906440462391, 11.646383479910607, 15.554619967191426, 14.746002097230916, 13.705365324675224, 12.708551510296124, 11.759061380277421, 10.750311912978637, 9.792933336899958, 8.807912505925852, 7.875355373084028, 6.914488595173032, 5.901075404227044, 4.857726528757891, 4.083007680322009, 4.944705876667269, 5.8377415854494075, 6.777605477470672, 7.817223360518394, 8.745812232648703, 9.695260254938507, 10.628056959761686, 14.57435357331431, 13.696485939356062, 12.634471899143664, 11.749887561796049, 10.742452255685004, 9.772606387534559, 8.791833386232446, 7.842823984480906, 6.899645340732999, 5.890379308073848, 4.839215367800067, 3.877351395898828, 3.032731970916067, 3.899777661811187, 4.87126860504606, 5.844557245475057, 6.827130308676214, 7.731188734477871, 8.796249783262853, 9.697546201431056, 13.633553031011406, 12.66912105609919, 11.701164936743469, 10.77687749280581, 9.843926030337075, 8.800902895433659, 7.797654011381065, 6.845887865634868, 5.9423850911835165, 4.965215042224506, 3.900171201617665, 2.9098358433421954, 2.0221072267212525, 2.87996682552648, 3.8586727138353005, 4.885702712972721, 5.791524416467084, 6.733825172898424, 7.739190815836811, 8.659152856535824, 12.799970771247953, 11.810484004448249, 10.771363463338705, 9.759711148973448, 8.8015757461958, 7.750249278302031, 6.86567787527601, 5.856137874066115, 4.879835700993347, 3.9516845185143175, 2.9506423068896854, 1.940771639232409, 0.9606628059051227, 1.925346620490962, 2.917465045133561, 3.8628441239033364, 4.792237722225664, 5.72187403270697, 6.710919267033978, 7.645593695599843, 11.822696075070347, 10.799704915582687, 9.862551602338446, 8.855731812238279, 7.801054656820556, 6.798204839656509, 5.855251662381725, 4.916356355194026, 3.9793150819450895, 3.0435484985371195, 1.9705305735088283, 0.9876088172802836, 0.0, 0.9857368673803207, 2.0440273391940376, 3.0634521606665994, 4.024631766726924, 4.988117307764629, 5.937142403054595, 6.890254190667274, 12.758737159163413, 11.74709542352002, 10.860433171690278, 9.844303661800767, 8.769495423399388, 7.735760572422344, 6.914481344728439, 5.880437938861029, 4.851316749436313, 3.8727116405845767, 2.91684864426038, 1.9641869119204773, 0.9287029712941424, 1.9846089462848207, 2.9382285565050212, 3.9272275754300234, 4.9422703120138785, 5.922577904522921, 6.908980437802211, 7.841939838204124], [7.857245657320393, 6.938173852157119, 5.947091474390948, 4.8875458896062485, 3.948028508008414, 2.8975703500046808, 1.957692644131882, 2.8417818174862086, 3.8610113077348114, 4.799726060386524, 5.728465534910472, 6.685897597669579, 7.75884207382313, 8.768699545386307, 9.701520913763863, 10.693203206216197, 11.744616660903283, 12.707345144356713, 13.72901235889581, 14.683107992189248, 6.85478233017311, 7.736109318486926, 6.763468738994588, 5.823122928732514, 4.840740716990625, 3.8377696762586093, 2.9124690190189426, 3.9109850157768555, 4.800775257081378, 5.726563136975423, 6.726710896245125, 7.620781066096131, 8.568975414042447, 9.574030413496876, 10.524676548129968, 11.503402761046804, 12.543339229218041, 13.574240982561559, 14.553544400232175, 13.854374559953555, 7.818834029318807, 8.669140911958197, 7.772573534394539, 6.772182124416555, 5.7747901844858704, 4.803591249961113, 3.874761026641991, 4.857554530242236, 5.816372766802126, 6.775234923834447, 7.783573165859922, 8.567160958126946, 9.598930138217401, 10.568197779595758, 11.499106165917842, 12.533829531615567, 13.514388775981867, 14.51829875924788, 15.457811216430047, 14.779470344278248, 8.799175586387886, 9.626895262852383, 8.709784898327753, 7.6701723656006555, 6.741021160881032, 5.771086019199612, 4.814696071836141, 5.844329643860457, 6.791598387554253, 7.777726688891183, 8.73510776027256, 9.618388748229748, 10.584496321136164, 11.510533817356356, 12.483037245518691, 13.453698251379004, 14.506383237529025, 15.49425012501485, 16.38629529950635, 15.620006939886581, 9.844467187476047, 10.618568655120571, 9.640729576034763, 8.577210138548411, 7.646515004849064, 6.719332442522785, 5.7896545529492665, 6.828493837768477, 7.782349465897438, 8.755819008423186, 9.707770173427175, 10.553935708078063, 11.520452440302874, 12.46118630188534, 13.45577956823889, 14.419616427515116, 15.45141030470167, 16.425993690150026, 17.428669674489452, 16.529869924746293, 10.675030540800947, 11.566641500293533, 10.529209636488623, 9.52669191555019, 8.624062436422909, 7.719176633437139, 6.751369903327495, 7.783760449688804, 8.720517920879253, 9.723088740044329, 10.649558265720016, 11.565358547258175, 12.485496232355898, 12.962765450158784, 13.816409392808277, 14.759567439083165, 15.764703532447813, 16.685926722953333, 17.64549715210891, 17.546237564388452, 11.712777785065517, 12.517722385723536, 11.546528371004841, 10.534979522749014, 9.590001912211019, 8.68642295842874, 7.728158559156819, 8.779439697711256, 9.749046019511436, 10.70926220853109, 11.645634496062048, 12.510747161312715, 12.803748984207097, 11.906520513741023, 12.837829033925479, 13.846074533733677, 14.690125360434967, 15.632951700809823, 16.604209527674936, 17.44837762302831, 12.607694295237035, 13.514802564120744, 12.571980465798118, 11.54393947587122, 10.623228075246605, 9.728160217757965, 8.790078393988829, 9.736252650578148, 10.694536719014218, 11.703898497394645, 12.711782595316274, 12.740227108814972, 11.818485619363026, 10.880280984587912, 11.865230365655451, 12.775992157812631, 13.7234120771315, 14.707697667686775, 15.6545936180277, 16.459724704243296, 13.540112907629432, 14.451575521834302, 13.471560797148054, 12.504709869922086, 11.549051733662532, 10.764731046522005, 9.770078517581254, 10.705602422416684, 11.685871089984369, 12.69529357641802, 12.709276290944347, 11.71410224447305, 10.842498504743837, 9.915997726221402, 10.870738381230982, 11.798188267284566, 12.732202078698817, 13.685689243602106, 14.591988787173927, 15.491683976444588, 14.582562216795179, 15.419645190592577, 14.41902328893894, 13.436892615218635, 12.494023284546376, 11.710453701313073, 10.774164577503504, 11.660143949263444, 12.63225563045461, 12.654227513324932, 11.656421339531407, 10.71043115011584, 9.899584571434712, 8.923228016957049, 9.920358123576204, 10.847985093085411, 11.771629667904037, 12.75239134205938, 13.639434253633391, 14.497674036957672, 15.45195903528482, 16.364453360464747, 15.45585995180759, 14.476294087494201, 13.537200983663439, 12.778323481623753, 11.806934344861292, 12.716325066134765, 12.682748352221536, 11.652649415214471, 10.75289727824646, 9.745270662349586, 8.853455137235564, 7.988439607948111, 8.883666954537526, 9.818501504596183, 10.751088095309262, 11.792907509883337, 12.714063819821877, 13.551829371694199, 16.383456645562617, 17.37430591403444, 16.511993860719212, 15.532746974736316, 14.560216477231222, 13.824522015929208, 12.808922637274325, 12.669636275609342, 11.616713656330857, 10.667073318238833, 9.72756339524111, 8.791051866842837, 7.845456451449779, 7.017766148321732, 7.8428903667789935, 8.79744480245684, 9.79754506050701, 10.736366598558478, 11.675317541843055, 12.581021467560996, 17.390708983494584, 17.614261748422138, 16.568516088394734, 15.634404323972356, 14.596166460685883, 13.632823782626193, 12.666920558315509, 11.674864992609598, 10.659451142845471, 9.643672988513089, 8.71087111085285, 7.766565808960974, 6.920238328107226, 6.029281161339373, 6.879502963359888, 7.841750638420079, 8.795871714160874, 9.723398896427264, 10.657817151260359, 11.655663485149804, 17.519913216658193, 16.719351703411565, 15.721375845932485, 14.701805715200367, 13.696961882045079, 12.675498623173358, 11.72165234989333, 10.683386040814764, 9.734150936799589, 8.793378929861344, 7.74297708857082, 6.81513213915318, 5.972924199554063, 5.096041185743519, 5.923922690331187, 6.93171768656812, 7.849113341168788, 8.778352552184208, 9.722575110120468, 10.747052149568685, 16.540356834571746, 15.731738964611235, 14.691102192055544, 13.694288377676443, 12.74479824765774, 11.736048780358956, 10.778670204280278, 9.793649373306174, 8.86109224046435, 7.900225462553354, 6.886812271607366, 5.843463396138213, 5.002419820663923, 4.0453745463253465, 4.938410255107485, 5.87827414712875, 6.917892030176472, 7.84648090230678, 8.795928924596584, 9.728725629419763, 15.56009044069463, 14.682222806736382, 13.620208766523984, 12.735624429176369, 11.728189123065324, 10.758343254914879, 9.777570253612765, 8.828560851861226, 7.88538220811332, 6.876116175454169, 5.824952235180389, 4.863088263279149, 3.985036492889992, 3.000446331469264, 3.9719372747041377, 4.945225915133135, 5.927798978334291, 6.831857404135948, 7.89691845292093, 8.798214871089135, 14.619289898391726, 13.65485792347951, 12.686901804123789, 11.762614360186129, 10.829662897717395, 9.786639762813978, 8.783390878761384, 7.831624733015188, 6.928121958563837, 5.950951909604827, 4.885908068997986, 3.895572710722516, 3.007844094101573, 1.9806354951845573, 2.959341383493378, 3.9863713826307987, 4.892193086125161, 5.834493842556501, 6.839859485494888, 7.759821526193902, 13.78570763862827, 12.796220871828567, 11.757100330719025, 10.745448016353768, 9.78731261357612, 8.73598614568235, 7.851414742656329, 6.841874741446435, 5.865572568373667, 4.937421385894638, 3.936379174270006, 2.9265085066127297, 1.9463996732854434, 1.0260152901490394, 2.0181337147916385, 2.963512793561414, 3.8929063918837414, 4.822542702365047, 5.811587936692055, 6.746262365257921, 12.808432942450665, 11.785441782963005, 10.848288469718764, 9.841468679618597, 8.786791524200876, 7.783941707036829, 6.840988529762044, 5.902093222574345, 4.96505194932541, 4.02928536591744, 2.956267440889149, 1.9733456846606043, 0.9857368673803207, 0.0, 1.0582904718137167, 2.0777152932862784, 3.038894899346603, 4.002380440384307, 4.951405535674273, 5.904517323286952, 13.744474026543731, 12.732832290900339, 11.846170039070598, 10.830040529181087, 9.755232290779707, 8.721497439802665, 7.900218212108759, 6.866174806241348, 5.837053616816633, 4.858448507964898, 3.902585511640701, 2.949923779300798, 1.914439838674463, 0.9988720789044999, 1.9524916891247006, 2.941490708049703, 3.956533444633558, 4.9368410371426, 5.9232435704218895, 6.856202970823802], [6.798955185506676, 5.93143151183873, 4.977711685053914, 3.918166100269215, 2.9786487186713804, 1.9281905606676473, 2.89555207523525, 3.8615535669071557, 4.880783057155758, 5.819497809807471, 6.748237284331419, 7.705669347090526, 8.778613823244077, 9.788471294807254, 10.72129266318481, 11.712974955637144, 12.76438841032423, 13.72711689377766, 14.78696294818985, 15.741398464002964, 5.796491858359394, 6.726548301545854, 5.794088949657554, 4.85374313939548, 3.871360927653592, 2.868389886921576, 3.8503284501223103, 4.8917495088808565, 5.820547006502325, 6.74633488639637, 7.746482645666072, 8.64055281551708, 9.588747163463395, 10.593802162917825, 11.544448297550916, 12.523174510467753, 13.56311097863899, 14.594012731982506, 15.573316149653122, 14.912665031767272, 6.80284552085455, 7.659579895017124, 6.803193745057506, 5.802802335079522, 4.805410395148837, 3.83421146062408, 4.812620457745359, 5.838319023346237, 6.797137259906127, 7.795006673255394, 8.803344915280869, 9.586932707547893, 10.618701887638348, 11.587969529016705, 12.518877915338791, 13.553601281036515, 14.534160525402816, 15.538070508668827, 16.477582965850996, 15.837760816091965, 7.7882691954445065, 8.61733424591131, 7.7404051089907195, 6.710940410057371, 5.7817892053377475, 4.811854063656328, 5.752555502939509, 6.782189074963824, 7.765997045646719, 8.752125346983648, 9.709506418365027, 10.638160497650695, 11.604268070557112, 12.530305566777303, 13.502808994939638, 14.473470000799951, 15.526154986949972, 16.514021874435798, 17.406067048927298, 16.6782974117003, 8.833560796532668, 9.609780260559718, 8.718177898357068, 7.67255605735426, 6.741860923654914, 5.814678361328635, 6.727513984052634, 7.766353268871844, 8.720208897000806, 9.693678439526554, 10.682168831519641, 11.57370745749901, 12.540224189723821, 13.480958051306287, 13.917389266689911, 14.881226125966137, 15.846450478307283, 16.76228565481476, 17.635720384718297, 17.58816039656001, 9.66412414985757, 10.616958536877506, 9.624555555294473, 8.622037834356039, 7.719408355228758, 6.828024264491951, 7.689229334430863, 8.721619880792172, 9.65837735198262, 10.660948171147696, 11.623956923812482, 12.5681520027443, 13.505267981776845, 13.737557768487054, 12.896985107976871, 13.84014315425176, 14.805048025463009, 15.726271215968527, 16.634590761165533, 17.40718452181098, 10.70187139412214, 11.580954750544064, 10.64187428981069, 9.630325441554863, 8.685347831016868, 7.79527058948355, 8.666017990260187, 9.717299128814624, 10.686905450614804, 11.647121639634458, 12.620033154154514, 13.51354061679884, 13.578541302535367, 12.681312832069294, 11.918404749094073, 12.886950076192424, 13.730469853450163, 14.673296193825019, 15.59330313673156, 16.437471232084935, 11.596787904293658, 12.578034928941273, 11.667326384603967, 10.639285394677069, 9.718573994052452, 8.837007848812776, 9.727937825092196, 10.674112081681516, 11.632396150117586, 12.641757928498013, 13.651508092299833, 13.591432661976143, 12.593277937691296, 11.655073302916183, 10.944836083126237, 11.816867700271377, 12.763756570146695, 13.745253703372583, 14.643687227084325, 15.44881831329992, 12.529206516686054, 13.532121476695453, 12.566906715953902, 11.600055788727934, 10.64439765246838, 9.873578677576816, 10.707937948684622, 11.643461853520051, 12.623730521087737, 13.633153007521388, 13.616629628485487, 12.596863968714029, 11.617290823072107, 10.690790044549672, 9.950344098701768, 10.839063809743312, 11.738843296344333, 12.678412890000232, 13.581082396230551, 14.48077758550121, 13.571655825851803, 14.514991109398425, 13.514369207744787, 12.532238534024483, 11.589369203352224, 10.851820276624673, 11.712024008606871, 12.598003380366812, 13.570115061557978, 13.593685953408214, 12.563774677072548, 11.61778448765698, 10.721141114199053, 9.69802033528532, 8.913081769974331, 9.840708739483539, 10.764353314302163, 11.745114988457505, 12.628527862690015, 13.486767646014295, 14.441052644341443, 15.387800238327797, 14.551205870613437, 13.571640006300049, 12.632546902469286, 11.919690056935353, 12.74479377596466, 13.654184497238132, 13.622206792304818, 12.592107855297753, 11.692355718329742, 10.652623999890727, 9.675011679999905, 8.763231926276381, 7.876390600935654, 8.811225150994309, 9.74381174170739, 10.78200111893996, 11.703157428878502, 12.540922980750821, 15.372550254619238, 16.397652791897492, 15.60733977952506, 14.628092893542163, 13.65556239603707, 12.973575961967766, 13.746782068377692, 13.609094715692624, 12.556172096414139, 11.606531758322115, 10.667021835324391, 9.698405204383977, 8.66701299421412, 7.792558466650002, 6.835614013177121, 7.790168448854966, 8.790268706905138, 9.7254602076151, 10.664411150899678, 11.570115076617618, 16.379802592551208, 17.433851225382398, 16.53514096394479, 15.601029199522412, 14.627189226389621, 13.92380385465089, 13.609122586476694, 12.61432343269288, 11.598909582928753, 10.58313142859637, 9.650329550936132, 8.70575413867051, 7.741794870871567, 6.804073479667643, 5.872226609758016, 6.8344742848182065, 7.788595360559002, 8.712492505483887, 9.646910760316981, 10.644757094206426, 17.432175273792097, 17.77764217522528, 16.7796663177462, 15.760096187014083, 14.755252353858795, 13.733789094987074, 12.691165449047713, 11.622844480898046, 10.67360937688287, 9.732837369944626, 8.682435528654102, 7.754590579236463, 6.794480742318404, 5.870833504071788, 4.916646336729315, 5.924441332966246, 6.841836987566915, 7.767446161240829, 8.71166871917709, 9.736145758625307, 17.598647306385462, 16.790029436424952, 15.74939266386926, 14.75257884949016, 13.803088719471457, 12.794339252172673, 11.836960676093994, 10.847105179409729, 9.88235216759711, 8.901267009406421, 7.829364283958533, 6.782921836221496, 5.823976363428264, 4.866931089089688, 3.9311339015056124, 4.870997793526877, 5.910615676574599, 6.8355745113634026, 7.785022533653207, 8.717819238476386, 16.618380912508346, 15.740513278550099, 14.6784992383377, 13.793914900990085, 12.78647959487904, 11.816633726728595, 10.835860725426482, 9.886851323674943, 8.90664213524608, 7.89737610258693, 6.846212162313149, 5.8843481904119095, 4.9619969885733175, 3.9774068271525898, 2.964660921102265, 3.9379495615312625, 4.9168925873909135, 5.82095101319257, 6.886012061977551, 7.7873084801457555, 15.677580370205442, 14.713148395293226, 13.745192275937505, 12.820904831999846, 11.887953369531111, 10.844930234627695, 9.8416813505751, 8.889915204828904, 7.949381885696598, 6.972211836737587, 5.907167996130746, 4.9168326378552765, 3.9972395720864897, 2.957595990867883, 1.9520650298915052, 2.979095029028926, 3.881286695181783, 4.823587451613123, 5.82895309455151, 6.748915135250523, 14.843998110441987, 13.854511343642283, 12.815390802532741, 11.803738488167484, 10.845603085389836, 9.794276617496068, 8.909705214470046, 7.900165213260151, 6.886832495506427, 5.958681313027398, 4.9576391014027665, 3.94776843374549, 2.967659600418204, 2.0029757858323647, 1.0108573611897655, 1.952606402618036, 2.8820000009403635, 3.811636311421669, 4.800681545748676, 5.735355974314541, 13.866723414264381, 12.843732254776722, 11.90657894153248, 10.899759151432313, 9.845081996014592, 8.842232178850546, 7.899279001575761, 6.960383694388062, 6.023342421139127, 5.087575837731157, 4.014557912702866, 3.0316361564743213, 2.0440273391940376, 1.0582904718137167, 0.0, 1.0194248214725619, 1.9806044275328865, 2.944089968570591, 3.8931150638605567, 4.846226851473236, 14.802764498357448, 13.791122762714055, 12.904460510884315, 11.888331000994803, 10.813522762593424, 9.779787911616381, 8.958508683922474, 7.924465278055065, 6.895344088630351, 5.916738979778615, 4.960875983454418, 4.008214251114515, 2.97273031048818, 1.936731510007868, 0.9831118997876671, 1.9721109187126693, 2.9871536552965248, 3.9674612478055673, 4.864953098608173, 5.797912499010086], [5.779530364034114, 4.9120066903661685, 3.9837823567638546, 2.9411492478488697, 2.001631866251035, 2.908069309755681, 3.8754308243232836, 4.841432315995189, 5.860661806243792, 6.799376558895505, 7.728116033419453, 8.685548096178561, 9.758492572332113, 10.768350043895289, 11.701171412272846, 12.692853704725179, 13.744267159412265, 14.706995642865696, 15.766841697277886, 16.760823285475528, 4.777067036886832, 5.707123480073292, 4.849165101659414, 3.9088192913973403, 2.9307860797576337, 3.8482686360096094, 4.830207199210344, 5.87162825796889, 6.800425755590359, 7.726213635484403, 8.726361394754106, 9.620431564605113, 10.568625912551429, 11.573680912005859, 12.52432704663895, 13.503053259555786, 14.542989727727024, 15.57389148107054, 16.553194898741154, 15.932089853239834, 5.783420699381988, 6.6401550735445625, 5.874222655228501, 4.873831245250518, 3.876439305319833, 4.814090209712114, 5.7924992068333925, 6.818197772434271, 7.777016008994161, 8.774885422343429, 9.783223664368903, 10.566811456635927, 11.598580636726382, 12.567848278104739, 13.498756664426825, 14.533480030124549, 15.51403927449085, 16.51794925775686, 17.45746171493903, 16.857185637564527, 6.768844373971945, 7.5979094244387495, 6.811434019161714, 5.824214309631266, 4.895063104911642, 5.791732812744361, 6.732434252027542, 7.762067824051858, 8.745875794734753, 9.732004096071682, 10.68938516745306, 11.618039246738729, 12.584146819645145, 13.510184315865336, 14.482687744027672, 15.116968791098046, 15.843074911731339, 16.695169288707337, 17.658669938228833, 17.697722233172858, 7.814135975060107, 8.590355439087158, 7.789206808528062, 6.8113916302881945, 5.880696496588849, 6.794557110416669, 7.707392733140668, 8.746232017959878, 9.70008764608884, 10.673557188614588, 11.662047580607675, 12.553586206587044, 13.520102938811855, 14.46083680039432, 14.785092565415395, 14.066981726009827, 14.84759054706468, 15.763425723572158, 16.616295563245732, 17.445316436971346, 8.644699328385007, 9.597533715404946, 8.763391128228406, 7.760873407289973, 6.858243928162692, 7.807903013579985, 8.669108083518896, 9.701498629880206, 10.638256101070654, 11.64082692023573, 12.603835672900516, 13.548030751832334, 14.485146730864878, 14.605261067212538, 13.764688406702355, 13.017157250649067, 13.806188094220406, 14.727411284725925, 15.61516593969297, 16.387759700338417, 9.682446572649578, 10.561529929071504, 9.780709862744624, 8.769161014488798, 7.824183403950802, 8.775149338571584, 9.64589673934822, 10.697177877902657, 11.666784199702837, 12.627000388722491, 13.599911903242548, 14.493419365886874, 14.446244601260851, 13.549016130794778, 12.786108047819557, 11.94664507700426, 12.73160992220756, 13.674436262582416, 14.573878315258998, 15.418046410612373, 10.577363082821096, 11.558610107468713, 10.8061619575379, 9.778120967611004, 8.857409566986387, 9.797145828397186, 10.70781657418023, 11.65399083076955, 12.61227489920562, 13.621636677586046, 14.631386841387867, 14.459135960701627, 13.46098123641678, 12.522776601641667, 11.812539381851721, 10.876562701083213, 11.764896638904093, 12.74639377212998, 13.624262405611763, 14.429393491827359, 11.509781695213492, 12.512696655222893, 11.705742288887837, 10.738891361661869, 9.783233225402315, 10.76548683349404, 11.687816697772655, 12.623340602608085, 13.60360927017577, 14.613031756609422, 14.484332927210971, 13.464567267439513, 12.484994121797591, 11.558493343275156, 10.818047397427252, 9.898758810555147, 10.73998336510173, 11.679552958757629, 12.561657574757989, 13.461352764028648, 12.55223100437924, 13.57127597059424, 12.653204780678722, 11.671074106958418, 10.728204776286159, 11.709475784864527, 12.645764908674096, 13.577882129454846, 14.549993810646011, 14.461389252133698, 13.431477975798032, 12.485487786382464, 11.588844412924537, 10.565723634010803, 9.780785068699815, 8.900403740295374, 9.76549338305956, 10.746255057214903, 11.609103041217454, 12.467342824541733, 13.421627822868881, 14.368375416855235, 13.690041443547372, 12.710475579233984, 11.771382475403222, 12.69974794173304, 13.678534676031884, 14.634063246326166, 14.489910091030302, 13.459811154023237, 12.560059017055226, 11.52032729861621, 10.542714978725389, 9.630935225001865, 8.744093899661138, 7.8308015083095235, 8.744951810464785, 9.762576297467396, 10.68373260740594, 11.52149815927826, 14.353125433146676, 15.37822797042493, 14.746175352458994, 13.766928466476099, 12.794397968971005, 13.753633846765453, 14.680522968444917, 14.476798014418108, 13.423875395139623, 12.474235057047599, 11.534725134049875, 10.566108503109461, 9.534716292939605, 8.660261765375486, 7.703317311902605, 6.80974480617018, 7.791408775662534, 8.706035386142537, 9.644986329427116, 10.550690255145057, 15.360377771078648, 16.414426403909836, 15.673976536878724, 14.739864772456347, 13.766024799323556, 14.703861739448577, 14.476825885202178, 13.482026731418363, 12.466612881654237, 11.450834727321855, 10.518032849661616, 9.573457437395994, 8.609498169597051, 7.671776778393127, 6.7399299084835, 5.85405064213342, 6.789735429316398, 7.693067684011324, 8.62748593884442, 9.625332272733864, 16.412750452319536, 17.384314469234663, 16.65913517157942, 15.672463381228336, 14.77675499168842, 14.627831060846427, 13.558868747773197, 12.49054777962353, 11.541312675608355, 10.60054066867011, 9.550138827379586, 8.622293877961946, 7.662184041043888, 6.738536802797272, 5.784349635454799, 4.928968584945269, 5.842977056324312, 6.748021339768267, 7.692243897704529, 8.716720937152745, 17.392306834405982, 17.809454257897514, 16.76881748534182, 15.695543871893545, 14.728632143031597, 13.702397052474899, 12.74501847639622, 11.714808478135213, 10.750055466322594, 9.768970308131905, 8.697067582684017, 7.65062513494698, 6.691679662153748, 5.734634387815172, 4.798837200231096, 3.8755250455059, 4.9117557453319955, 5.816149689890841, 6.765597712180645, 7.698394417003824, 17.63780573398091, 16.75993810002266, 15.69792405981026, 14.73951661609077, 13.71202301843918, 12.742177150288734, 11.761404148986621, 10.812394747235082, 9.774345433971565, 8.765079401312414, 7.713915461038633, 6.7520514891373935, 5.829700287298802, 4.845110125878074, 3.832364219827749, 2.9424768135102854, 3.8974677659183516, 4.801526191720008, 5.866587240504989, 6.767883658673194, 16.697005191678002, 15.732573216765786, 14.764617097410065, 13.830298643996766, 12.8363100263619, 11.770473658187836, 10.767224774135242, 9.815458628389043, 8.817085184422082, 7.839915135463071, 6.77487129485623, 5.7845359365807605, 4.864942870811974, 3.825299289593367, 2.8197683286169895, 1.983622281007949, 2.861861873709221, 3.804162630140561, 4.809528273078948, 5.729490313777961, 15.863422931914549, 14.873936165114845, 13.834815624005302, 12.823163309640044, 11.865027906862396, 10.813701438968629, 9.835248638030187, 8.825708636820291, 7.754535794231911, 6.826384611752882, 5.8253424001282506, 4.815471732470974, 3.835362899143688, 2.8706790845578487, 1.8785606599152498, 0.9331815811454741, 1.8625751794678016, 2.792211489949107, 3.781256724276114, 4.715931152841979, 14.886148235736943, 13.863157076249284, 12.926003763005042, 11.919183972904875, 10.864506817487152, 9.861657000323106, 8.918703823048322, 7.979808515860624, 7.0427672426116885, 6.1070006592037185, 5.033982734175427, 4.051060977946882, 3.063452160666599, 2.0777152932862784, 1.0194248214725619, 0.0, 0.9611796060603245, 1.924665147098029, 2.873690242387995, 3.8268020300006738, 15.82218931983001, 14.810547584186617, 13.923885332356875, 12.907755822467363, 11.832947584065984, 10.799212733088941, 9.977933505395036, 8.943890099527627, 7.914768910102912, 6.936163801251176, 5.980300804926979, 5.0270204067444455, 3.9915364661181103, 2.9166102590959015, 1.9629906488757007, 0.9739916299506987, 1.989034366534554, 2.9610312758980273, 3.845528277135611, 4.778487677537524], [4.81835075797379, 3.9508270843058444, 3.0226027507035305, 2.0766713220128876, 2.9628114723113597, 3.8692489158160055, 4.836610430383608, 5.8026119220555135, 6.821841412304116, 7.760556164955829, 8.689295639479777, 9.646727702238884, 10.719672178392436, 11.729529649955612, 12.662351018333169, 13.654033310785502, 14.705446765472589, 15.668175248926019, 16.72802130333821, 17.72200289153585, 3.815887430826508, 4.745943874012968, 3.9846871758234323, 3.0443413655613583, 3.8919656858179588, 4.8094482420699345, 5.791386805270669, 6.832807864029215, 7.761605361650683, 8.687393241544727, 9.687541000814429, 10.581611170665436, 11.529805518611752, 12.534860518066182, 13.485506652699273, 14.46423286561611, 15.504169333787347, 16.535071087130863, 17.514374504801477, 16.893269459300157, 4.822241093321664, 5.678975467484238, 5.036354105872317, 4.0647961125300345, 4.837618911380158, 5.775269815772439, 6.7536788128937175, 7.779377378494596, 8.738195615054487, 9.736065028403752, 10.744403270429226, 11.52799106269625, 12.559760242786705, 13.529027884165062, 14.459936270487148, 15.494659636184872, 15.931979257476412, 16.749210392107177, 17.665243758938008, 17.81836524362485, 5.834560201962226, 6.636729818378425, 5.97356546980553, 5.075368097906302, 5.8562427109719675, 6.752912418804686, 7.6936138580878675, 8.723247430112183, 9.707055400795078, 10.693183702132007, 11.650564773513384, 12.579218852799052, 13.545326425705468, 14.47136392192566, 15.443867350087995, 15.970296894691753, 14.921164649364211, 15.773259026340208, 16.736759675861705, 17.47467959414679, 6.879851803050388, 7.629175833026833, 6.951338259171878, 6.114050804544323, 6.841876102649174, 7.755736716476994, 8.668572339200992, 9.707411624020203, 10.661267252149164, 11.634736794674913, 12.623227186667998, 13.514765812647367, 14.481282544872178, 15.422016406454643, 15.646581968190581, 14.920309829603534, 13.925680284697552, 14.84151546120503, 15.694385300878603, 16.52340617460422, 7.722789066017877, 8.636354109344621, 7.944388370312217, 7.063532581546102, 7.819423534223017, 8.76908261964031, 9.63028768957922, 10.662678235940529, 11.59943570713098, 12.602006526296055, 13.56501527896084, 14.509210357892657, 15.446326336925202, 15.542138001490063, 14.626177809477541, 13.870485354242774, 12.884277831853279, 13.805501022358797, 14.693255677325839, 15.46584943797129, 8.760536310282449, 9.60035032301118, 8.961707104828436, 8.071820188744926, 8.785363010011126, 9.736328944631909, 10.607076345408544, 11.65835748396298, 12.62796380576316, 13.588179994782816, 14.561091509302871, 15.454598971947197, 15.383121535538375, 14.485893065072302, 13.647597450594743, 12.799973180597966, 11.809699659840433, 12.752526000215289, 13.651968052891867, 14.496136148245244, 9.655452820453966, 10.597430501408388, 9.987159199621713, 9.080780141867132, 9.81858917304671, 10.75832543445751, 11.668996180240553, 12.615170436829873, 13.573454505265943, 14.582816283646372, 15.592566447448192, 15.396012894979151, 14.397858170694304, 13.459653535919191, 12.674028784626907, 11.72989080467692, 10.842986376536965, 11.824483509762853, 12.702352143244632, 13.50748322946023, 10.587871432846363, 11.551517049162568, 10.95522199650017, 10.070208990779765, 10.744412831462638, 11.726666439554362, 12.648996303832979, 13.584520208668408, 14.564788876236094, 15.574211362669747, 15.421209861488498, 14.40144420171704, 13.421871056075117, 12.495370277552682, 11.679536800202438, 10.752086914148855, 9.818073102734603, 10.757642696390501, 11.639747312390858, 12.539442501661519, 11.63032074201211, 12.610096364533915, 11.902684488291055, 11.116951529330425, 11.689384382346482, 12.67065539092485, 13.606944514734419, 14.539061735515169, 15.511173416706335, 15.398266186411224, 14.368354910075558, 13.42236472065999, 12.525721347202063, 11.50260056828833, 10.717662002977342, 9.8372806745729, 8.843583120692433, 9.824344794847775, 10.687192778850322, 11.545432562174604, 12.499717560501752, 13.446465154488106, 12.939521151159706, 12.156353001605991, 12.732562081463545, 13.660927547793364, 14.639714282092207, 15.59524285238649, 15.426787025307828, 14.396688088300763, 13.496935951332752, 12.457204232893737, 11.479591913002915, 10.567812159279391, 9.680970833938664, 8.76767844258705, 7.823041548097659, 8.840666035100266, 9.761822345038809, 10.59958789691113, 13.431215170779547, 14.456317708057801, 13.995655060071329, 13.212805888848106, 13.755577575031328, 14.714813452825776, 15.64170257450524, 15.413674948695634, 14.36075232941715, 13.411111991325125, 12.471602068327401, 11.502985437386988, 10.47159322721713, 9.597138699653012, 8.640194246180132, 7.746621740447706, 6.869498513295406, 7.784125123775407, 8.723076067059987, 9.628779992777927, 14.438467508711518, 15.492516141542707, 14.964140699505512, 14.185742194828354, 14.72720440538388, 15.6650413455089, 15.413702819479704, 14.41890366569589, 13.403489815931763, 12.387711661599381, 11.454909783939142, 10.51033437167352, 9.546375103874578, 8.608653712670653, 7.676806842761026, 6.7909275764109465, 5.86782516694927, 6.771157421644195, 7.70557567647729, 8.703422010366735, 15.490840189952406, 16.462404206867532, 15.949299334206206, 15.118340803600343, 15.737934597748744, 15.564707995123953, 14.495745682050723, 13.427424713901056, 12.47818960988588, 11.537417602947636, 10.487015761657112, 9.559170812239472, 8.599060975321414, 7.675413737074798, 6.721226569732325, 5.865845519222796, 4.921066793957183, 5.826111077401138, 6.7703336353373995, 7.794810674785616, 16.470396572038855, 17.450016945667862, 16.979572988083145, 16.18983443882464, 15.665509077309125, 14.639273986752427, 13.681895410673748, 12.651685412412741, 11.686932400600123, 10.705847242409432, 9.633944516961543, 8.587502069224506, 7.628556596431275, 6.671511322092698, 5.735714134508623, 4.812401979783426, 3.989845482964867, 4.894239427523711, 5.843687449813515, 6.7764841546366945, 17.45066296591597, 17.709648422844722, 16.647634382632326, 15.676393550368298, 14.648899952716707, 13.679054084566262, 12.698281083264149, 11.74927168151261, 10.711222368249093, 9.70195633558994, 8.65079239531616, 7.68892842341492, 6.766577221576328, 5.7819870601556, 4.769241154105275, 3.8793537477878113, 2.9755575035512227, 3.8796159293528794, 4.944676978137862, 5.845973396306064, 17.654906590152986, 16.69047461524077, 15.72251849588505, 14.767175578274294, 13.773186960639428, 12.707350592465364, 11.70410170841277, 10.752335562666572, 9.753962118699608, 8.776792069740598, 7.711748229133757, 6.721412870858288, 5.801819805089499, 4.762176223870893, 3.7566452628945153, 2.9204992152854747, 1.9399516113420923, 2.8822523677734324, 3.8876180107118197, 4.807580051410832, 16.824602537974872, 15.835115771175168, 14.795995230065627, 13.78434291570037, 12.826207512922721, 11.774881045028954, 10.772125572307715, 9.76258557109782, 8.69141272850944, 7.76326154603041, 6.762219334405778, 5.752348666748501, 4.772239833421215, 3.807556018835375, 2.8154375941927756, 1.870058515423, 0.9406649171006727, 1.8703012275819781, 2.8593464619089852, 3.7940208904748505, 15.847327841797267, 14.824336682309607, 13.887183369065365, 12.880363578965198, 11.825686423547477, 10.822836606383431, 9.879883429108647, 8.940988121920949, 8.003946848672014, 7.0681802652640435, 5.995162340235752, 5.012240584007207, 4.024631766726924, 3.0388948993466034, 1.9806044275328865, 0.9611796060603245, 0.0, 0.9634855410377046, 1.9125106363276707, 2.8656224239403496, 16.783368925890333, 15.77172719024694, 14.8850649384172, 13.868935428527688, 12.794127190126309, 11.760392339149266, 10.939113111455361, 9.905069705587952, 8.875948516163238, 7.897343407311501, 6.941480410987304, 5.98820001280477, 4.9527160721784345, 3.877789865156226, 2.9241702549360253, 1.9351712360110231, 1.036318321608679, 1.9998516698377031, 2.884348671075287, 3.8173080714772], [3.8548652169360853, 2.9873415432681396, 2.059117209665826, 3.0401568630505924, 3.926297013349064, 4.83273445685371, 5.800095971421313, 6.766097463093218, 7.785326953341821, 8.724041705993534, 9.652781180517481, 10.610213243276588, 11.68315771943014, 12.693015190993316, 13.625836559370873, 14.617518851823206, 15.668932306510293, 16.631660789963725, 17.691506844375915, 18.685488432573557, 2.852401889788803, 3.7824583329752635, 3.0954230303258052, 4.007826906599063, 4.855451226855663, 5.772933783107638, 6.754872346308373, 7.796293405066919, 8.725090902688388, 9.650878782582431, 10.651026541852133, 11.54509671170314, 12.493291059649456, 13.498346059103886, 14.448992193736977, 15.427718406653813, 16.46765487482505, 16.99568348705628, 17.738590898980153, 17.856755000337863, 3.8587555522839594, 4.7154899264465335, 4.14708996037469, 5.028281653567739, 5.801104452417862, 6.738755356810143, 7.717164353931421, 8.7428629195323, 9.70168115609219, 10.699550569441456, 11.70788881146693, 12.491476603733954, 13.52324578382441, 14.492513425202766, 15.423421811524852, 16.458145177222576, 16.895464798514112, 16.051625710369958, 16.780095405905197, 17.56027502233393, 4.871074660924521, 5.673244277340721, 5.084301324307903, 6.038853638944007, 6.819728252009671, 7.71639795984239, 8.65709939912557, 9.686732971149887, 10.670540941832781, 11.656669243169711, 12.61405031455109, 13.542704393836756, 14.508811966743172, 15.434849462963363, 16.4073528911257, 16.933782435729455, 15.884650190401914, 15.075674344602989, 15.851611322828893, 16.589531241113974, 5.916366262012683, 6.6656902919891285, 6.062074113674251, 7.077536345582028, 7.805361643686878, 8.719222257514698, 9.632057880238696, 10.670897165057907, 11.624752793186868, 12.598222335712617, 13.586712727705704, 14.47825135368507, 15.444768085909882, 16.385501947492347, 16.610067509228283, 15.883795370641236, 14.889165825735255, 14.143930779467812, 14.809236947845791, 15.638257821571404, 6.837640712985064, 7.6728685683069155, 7.05512422481459, 8.027018122583808, 8.782909075260722, 9.732568160678014, 10.593773230616923, 11.626163776978233, 12.562921248168683, 13.565492067333759, 14.528500819998545, 15.472695898930363, 16.409811877962905, 16.50562354252777, 15.589663350515243, 14.833970895280476, 13.84776337289098, 13.107916340621578, 13.808107324293028, 14.580701084938475, 7.875387957249635, 8.636864781973474, 8.07244295933081, 9.035305729782632, 9.748848551048832, 10.699814485669613, 11.570561886446248, 12.621843025000684, 13.591449346800864, 14.55166553582052, 15.524577050340577, 16.418084512984905, 16.34660707657608, 15.449378606110008, 14.611082991632445, 13.763458721635669, 12.773185200878135, 12.05494131847807, 12.766819699859056, 13.610987795212429, 8.770304467421152, 9.633944960370682, 9.097895054124086, 10.044265682904838, 10.782074714084416, 11.721810975495215, 12.632481721278257, 13.578655977867577, 14.536940046303647, 15.546301824684075, 16.556051988485894, 16.359498436016857, 15.36134371173201, 14.423139076956897, 13.63751432566461, 12.693376345714622, 11.806471917574667, 11.016141393439618, 11.81720379021182, 12.622334876427415, 9.702723079813548, 10.588031508124862, 10.065957851002542, 11.03280877822851, 11.707898372500344, 12.690151980592068, 13.612481844870683, 14.548005749706112, 15.528274417273797, 16.537696903707452, 16.3846954025262, 15.364929742754743, 14.385356597112821, 13.458855818590386, 12.64302234124014, 11.715572455186557, 10.781558643772305, 9.949300580067266, 10.754598959358047, 11.654294148628704, 10.745172388979295, 11.646610823496209, 11.013420342793427, 12.007496536516912, 12.652869923384188, 13.634140931962555, 14.570430055772125, 15.502547276552873, 16.47465895774404, 16.36175172744893, 15.331840451113262, 14.385850261697694, 13.489206888239767, 12.466086109326033, 11.681147544015046, 10.800766215610606, 9.807068661730135, 9.01600267852454, 9.802044425817511, 10.660284209141789, 11.614569207468938, 12.561316801455291, 12.050257005662079, 13.046898008792478, 13.69604762250125, 14.62441308883107, 15.603199823129913, 16.558728393424193, 16.390272566345534, 15.360173629338469, 14.460421492370457, 13.420689773931441, 12.443077454040619, 11.531297700317095, 10.644456374976368, 9.731163983624755, 8.786527089135362, 7.955517682067454, 8.876673992005998, 9.714439543878315, 12.546066817746732, 13.571169355024987, 13.106390914573701, 14.103350896034593, 14.719063116069034, 15.678298993863482, 16.605188115542948, 16.37716048973334, 15.324237870454855, 14.37459753236283, 13.435087609365107, 12.466470978424692, 11.435078768254835, 10.560624240690716, 9.603679787217835, 8.710107281485412, 7.83298405433311, 6.898976770742594, 7.837927714027174, 8.743631639745113, 13.553319155678704, 14.607367788509892, 14.074876554007885, 15.008988318430262, 15.690689946421585, 16.628526886546606, 16.37718836051741, 15.382389206733595, 14.36697535696947, 13.351197202637087, 12.418395324976848, 11.473819912711225, 10.509860644912282, 9.572139253708357, 8.64029238379873, 7.754413117448651, 6.831310707986974, 5.886009068611382, 6.820427323444477, 7.818273657333921, 14.605691836919592, 15.577255853834718, 15.060035188708579, 15.941586927202252, 16.70142013878645, 16.52819353616166, 15.459231223088429, 14.390910254938762, 13.441675150923587, 12.500903143985342, 11.450501302694818, 10.522656353277178, 9.562546516359118, 8.638899278112502, 7.684712110770029, 6.8293310602605, 5.884552334994887, 4.940962724368325, 5.885185282304587, 6.909662321752803, 15.585248219006038, 16.564868592635047, 16.090308842585518, 17.013080562426552, 16.628994618346827, 15.602759527790129, 14.64538095171145, 13.615170953450443, 12.650417941637825, 11.669332783447137, 10.597430057999249, 9.550987610262212, 8.59204213746898, 7.634996863130402, 6.699199675546327, 5.775887520821131, 4.953331024002571, 4.0090910744908985, 4.958539096780703, 5.891335801603882, 16.565514612883156, 17.511608013221917, 17.16120226811708, 16.639879091405998, 15.61238549375441, 14.642539625603964, 13.661766624301851, 12.712757222550312, 11.674707909286795, 10.665441876627645, 9.614277936353863, 8.652413964452624, 7.730062762614032, 6.7454726011933035, 5.732726695142979, 4.842839288825516, 3.939043044588927, 2.9944675763200657, 4.059528625105047, 4.952014662876191, 17.506315155186062, 17.653960156278472, 16.686004036922753, 15.730661119312, 14.736672501677132, 13.670836133503068, 12.667587249450474, 11.715821103704275, 10.717447659737314, 9.740277610778303, 8.675233770171461, 7.6848984118959915, 6.765305346127203, 5.725661764908597, 4.72013080393222, 3.883984756323179, 2.9034371523797966, 1.997104014740619, 3.002469657679006, 3.913621317980959, 17.788088079012578, 16.798601312212874, 15.75948077110333, 14.747828456738073, 13.789693053960425, 12.738366586066658, 11.735611113345419, 10.726071112135523, 9.654898269547143, 8.726747087068114, 7.725704875443482, 6.715834207786205, 5.7357253744589185, 4.771041559873079, 3.77892313523048, 2.8335440564607044, 1.9041504581383772, 0.9851528745491649, 1.965387728479112, 2.900062157044977, 16.810813382834972, 15.787822223347312, 14.85066891010307, 13.843849120002904, 12.789171964585181, 11.786322147421135, 10.84336897014635, 9.904473662958653, 8.967432389709717, 8.031665806301747, 6.958647881273456, 5.975726125044911, 4.988117307764628, 4.002380440384307, 2.944089968570591, 1.924665147098029, 0.9634855410377046, 0.0, 0.949025095289966, 1.9021368829026448, 17.74685446692804, 16.735212731284644, 15.848550479454904, 14.832420969565392, 13.757612731164013, 12.72387788018697, 11.902598652493065, 10.868555246625656, 9.839434057200942, 8.860828948349205, 7.904965952025008, 6.951685553842474, 5.916201613216139, 4.8412754061939305, 3.8876557959737297, 2.8986567770487275, 1.9998038626463837, 1.0363661287999986, 1.9208631300375822, 2.853822530439495], [2.9058401216461194, 2.0383164479781737, 3.0081423049557925, 3.9891819583405583, 4.875322108639031, 5.781759552143677, 6.749121066711279, 7.715122558383184, 8.734352048631788, 9.6730668012835, 10.601806275807448, 11.559238338566555, 12.632182814720107, 13.642040286283283, 14.57486165466084, 15.566543947113173, 16.61795740180026, 17.580685885253693, 17.967962644804036, 18.71776154711572, 1.9033767944988371, 2.8334332376852975, 3.8060738171776354, 4.7464196274397095, 5.728801839181598, 6.721958878397605, 7.70389744159834, 8.745318500356886, 9.674115997978355, 10.5999038778724, 11.600051637142101, 12.494121806993107, 13.442316154939423, 14.447371154393853, 15.398017289026944, 16.376743501943782, 17.41667997011502, 17.865417679351904, 16.940342938558373, 17.699112206384214, 2.9097304569939935, 3.7664648311565676, 4.808446838310336, 5.766874374408386, 6.674455064743797, 7.645653999268554, 8.666189449221388, 9.691888014822267, 10.650706251382157, 11.648575664731425, 12.656913906756898, 13.44050169902392, 14.472270879114376, 15.441538520492733, 16.37244690681482, 17.407170272512545, 17.844489893804077, 16.921359902665582, 15.981847445483416, 16.739844420977132, 3.922049565634555, 4.724219182050755, 5.745658202243549, 6.777446359784653, 7.693078864335607, 8.623296602300801, 9.579686549664272, 10.609320121688588, 11.593128092371483, 12.579256393708413, 13.53663746508979, 14.491729489126723, 15.45783706203314, 16.383874558253332, 17.35637798641567, 17.882807531019417, 16.83367528569188, 15.973964709146708, 15.053363362407113, 15.769100639757175, 4.967341166722717, 5.716665196699163, 6.69450427578497, 7.758023713271323, 8.678712256012814, 9.605894818339092, 10.53557270791261, 11.574411992731822, 12.528267620860783, 13.501737163386531, 14.509299878244404, 15.427276448975038, 16.393793181199847, 17.334527042782312, 17.55909260451825, 16.8328204659312, 15.83819092102522, 15.042221144011531, 14.010988987424012, 14.817827220214605, 5.971337398061194, 6.7238434730169505, 7.687554386925309, 8.690072107863742, 9.656259687586658, 10.619240721502408, 11.497288058290838, 12.529678604652148, 13.466436075842598, 14.469006895007674, 15.451087970537245, 16.395283049469064, 17.35883697325287, 17.45464863781773, 16.53868844580521, 15.782995990570441, 14.796788468180946, 14.006206705165297, 13.009859363871248, 13.760270483581676, 7.009084642325764, 7.687839686683508, 8.659033701402203, 9.677575330477419, 10.622199163374768, 11.586487046494007, 12.474076714120162, 13.525357852674599, 14.494964174474779, 15.455180363494435, 16.44716420087928, 17.340671663523604, 17.295632171866046, 16.39840370139997, 15.56010808692241, 14.712483816925634, 13.7222102961681, 12.973241237357497, 11.968571739437277, 12.79055719385563, 7.939713274306124, 8.684919865080715, 9.648252573384346, 10.686535283599625, 11.655425326410352, 12.595161587821151, 13.535996548952172, 14.482170805541491, 15.440454873977561, 16.449816652357992, 17.45956681615981, 17.30852353130682, 16.310368807021977, 15.372164172246862, 14.586539420954574, 13.642401441004587, 12.755497012864632, 11.965166488729583, 11.018955829790041, 11.801904275070616, 8.87213188669852, 9.639006412834895, 10.616315370262802, 11.58316629748877, 12.538824433748324, 13.521078041840049, 14.515996672544597, 15.451520577380027, 16.431789244947712, 17.44121173138137, 17.33372049781617, 16.313954838044708, 15.334381692402788, 14.407880913880353, 13.592047436530105, 12.664597550476522, 11.73058373906227, 10.898325675357231, 9.956350998936266, 10.833863547271905, 9.924741787622498, 10.697585728206242, 11.563777862053687, 12.557854055777172, 13.483795984632167, 14.465066993210534, 15.401356117020104, 16.406062104226788, 17.378173785417953, 17.310776822738898, 16.28086554640323, 15.334875356987661, 14.438231983529734, 13.415111204616, 12.630172639305012, 11.749791310900571, 10.7560937570201, 9.965027773814505, 9.00379646539573, 9.83985360778499, 10.794138606112138, 11.642393898078412, 12.600614524922339, 13.597255528052738, 14.52697368374923, 15.455339150079048, 16.43412588437789, 17.39341039813715, 17.3392976616355, 16.309198724628438, 15.409446587660424, 14.369714869221408, 13.392102549330586, 12.480322795607062, 11.593481470266335, 10.68018907891472, 9.735552184425327, 8.904542777357419, 8.078426031584216, 8.894008942521516, 11.725636216389933, 12.652246451648107, 13.64597447722084, 14.653708415294853, 15.549989177317013, 16.50922505511146, 17.436114176790927, 17.326185585023307, 16.27326296574482, 15.323622627652798, 14.384112704655074, 13.415496073714658, 12.384103863544802, 11.509649335980683, 10.552704882507802, 9.659132376775377, 8.782009149623075, 7.8480018660325594, 7.039679753605394, 7.923201038388314, 12.732888554321905, 13.688444885133013, 14.614460116655023, 15.5485718810774, 16.521616007669564, 17.459452947794585, 17.326213455807377, 16.331414302023564, 15.316000452259436, 14.300222297927053, 13.367420420266814, 12.422845008001191, 11.458885740202248, 10.521164348998324, 9.589317479088697, 8.703438212738616, 7.780335803276939, 6.835034163901347, 6.022179363022697, 6.997843055977121, 13.785261235562793, 14.738696234898374, 15.599618751355717, 16.48117048984939, 17.486014323004678, 17.477218631451624, 16.408256318378395, 15.339935350228728, 14.390700246213553, 13.449928239275309, 12.399526397984785, 11.471681448567145, 10.511571611649085, 9.587924373402469, 8.633737206059996, 7.7783561555504654, 6.833577430284853, 5.88998781965829, 5.0188819673807155, 6.043359006828932, 14.76481761764924, 15.726308973698703, 16.629892405232656, 17.55266412507369, 17.578019713636795, 16.5517846230801, 15.594406047001419, 14.564196048740412, 13.599443036927793, 12.618357878737104, 11.546455153289216, 10.500012705552178, 9.541067232758946, 8.584021958420369, 7.648224770836293, 6.724912616111096, 5.902356119292537, 4.958116169780864, 4.092235781856831, 5.025032486680011, 15.745084011526355, 16.691177411865116, 17.700785830764218, 17.588904186695967, 16.561410589044378, 15.591564720893933, 14.61079171959182, 13.66178231784028, 12.623733004576764, 11.614466971917611, 10.56330303164383, 9.60143905974259, 8.679087857903998, 7.69449769648327, 6.681751790432946, 5.791864384115481, 4.888068139878893, 3.9434926716100316, 3.1298036492339056, 4.0029895675862255, 16.68588455382926, 17.650316528741477, 17.63502913221272, 16.679686214601965, 15.685697596967099, 14.619861228793035, 13.61661234474044, 12.664846198994242, 11.666472755027279, 10.689302706068268, 9.624258865461428, 8.633923507185958, 7.71433044141717, 6.674686860198563, 5.669155899222186, 4.833009851613145, 3.852462247669763, 2.9461291100305846, 2.0664404239217706, 2.964596222690993, 17.73360712662711, 17.74762640750284, 16.708505866393295, 15.69685355202804, 14.738718149250392, 13.687391681356624, 12.684636208635386, 11.67509620742549, 10.60392336483711, 9.675772182358081, 8.674729970733448, 7.664859303076172, 6.684750469748885, 5.720066655163046, 4.727948230520447, 3.7825691517506708, 2.8531755534283434, 1.9341779698391308, 1.016362633189146, 1.9510370617550112, 17.759838478124937, 16.736847318637277, 15.799694005393036, 14.79287421529287, 13.738197059875148, 12.735347242711102, 11.792394065436318, 10.85349875824862, 9.916457484999684, 8.980690901591714, 7.907672976563423, 6.924751220334878, 5.937142403054595, 4.951405535674274, 3.893115063860557, 2.8736902423879953, 1.9125106363276707, 0.949025095289966, 0.0, 0.9531117876126787, 18.695879562218003, 17.68423782657461, 16.79757557474487, 15.78144606485536, 14.70663782645398, 13.672902975476937, 12.851623747783032, 11.817580341915622, 10.788459152490907, 9.80985404363917, 8.853991047314974, 7.90071064913244, 6.865226708506105, 5.790300501483896, 4.836680891263696, 3.847681872338694, 2.9488289579363496, 1.9853912240899647, 0.9718380347476163, 1.9047974351495287], [1.9527283340334407, 2.8248772596225327, 3.815959637388703, 4.760977883375501, 5.700495264973336, 6.718860418554863, 7.699935716272217, 8.665937207944122, 9.685166698192724, 10.623881450844436, 11.552620925368384, 12.510052988127491, 13.582997464281043, 14.592854935844219, 15.525676304221776, 16.517358596674107, 17.568772051361194, 18.531500534814626, 18.7531955627857, 17.84729132731926, 0.9502650068861584, 1.8803214500726186, 2.8529620295649565, 3.7933078398270306, 4.775690051568919, 5.7786610923009345, 6.826178512585859, 7.867599571344405, 8.882437083759166, 9.887270880198486, 10.887418639468187, 11.880058102218854, 12.82825245016517, 13.8333074496196, 14.783953584252691, 15.762679797169527, 16.802616265340767, 17.833518018684284, 17.725575856540036, 16.828641986587755, 1.9566186693813146, 2.8133530435438887, 3.855335050697657, 4.813762586795707, 5.721343277131118, 6.6925422116558755, 7.738449749311907, 8.782560893632061, 9.741379130191952, 10.782066682389694, 11.850136787209868, 12.826437994249668, 13.858207174340123, 14.82747481571848, 15.758383202040566, 16.79310656773829, 17.773665812104593, 17.70659282064725, 16.76708036346508, 15.869374201180676, 2.968937778021876, 3.7711073944380757, 4.79254641463087, 5.824334572171974, 6.7399670767229285, 7.670184814688123, 8.626574762051593, 9.65620833407591, 10.640016304758804, 11.626144606095734, 12.583525677477112, 13.611166470592485, 14.634436937076728, 15.610176442007178, 16.582679870169514, 17.55334087602983, 17.78678707330456, 16.85454577229314, 15.838596280388776, 14.89863041996072, 4.014229379110038, 4.763553409086484, 5.741392488172291, 6.804911925658644, 7.725600468400135, 8.652783030726415, 9.582460920299933, 10.621300205119145, 11.575155833248106, 12.548625375773854, 13.556188090631727, 14.5467134304408, 15.51323016266561, 16.453964024248076, 17.448557290601627, 17.78593225354388, 16.7913027086379, 15.922802207157961, 14.891570050570442, 13.94735700041815, 5.0616221293531405, 5.770731685404272, 6.73444259931263, 7.736960320251064, 8.70314789997398, 9.66612893388973, 10.544176270678161, 11.57656681703947, 12.51332428822992, 13.515895107394996, 14.497976182924567, 15.442171261856386, 16.453545484048703, 17.438143020287193, 17.491800233417887, 16.736107778183122, 15.749900255793627, 14.886787768311727, 13.890440427017678, 12.88980026378522, 6.10581427283188, 6.734727899070829, 7.705921913789524, 8.72446354286474, 9.66908737576209, 10.63337525888133, 11.520964926507485, 12.572246065061922, 13.541852386862102, 14.502068575881758, 15.4940524132666, 16.387559875910927, 17.398507598032506, 17.351515489012655, 16.51321987453509, 15.665595604538314, 14.675322083780781, 13.853822300503927, 12.849152802583706, 11.920086974059174, 7.03644290481224, 7.7318080774680364, 8.695140785771667, 9.733423495986946, 10.702313538797675, 11.642049800208474, 12.582884761339495, 13.529059017928814, 14.487343086364884, 15.496704864745313, 16.506455028547133, 17.368867882099426, 17.263480594634657, 16.325275959859542, 15.539651208567255, 14.595513228617268, 13.708608800477313, 12.887980062508289, 11.932734237462668, 10.93143405527416, 7.968861517204637, 8.685894625222216, 9.663203582650123, 10.630054509876091, 11.585712646135645, 12.56796625422737, 13.56288488493192, 14.49840878976735, 15.478677457335035, 16.488099943768688, 17.506013760602812, 17.26706662565739, 16.287493480015467, 15.360992701493032, 14.545159224142786, 13.617709338089202, 12.683695526674951, 11.851437462969912, 10.870129406608893, 9.96339332747545, 9.022603453038968, 9.744473940593563, 10.610666074441008, 11.604742268164493, 12.53068419701949, 13.511955205597857, 14.448244329407427, 15.45295031661411, 16.425061997805276, 17.354899833026487, 17.233977334015908, 16.28798714460034, 15.391343771142413, 14.368222992228679, 13.583284426917691, 12.702903098513252, 11.70920554463278, 10.918139561427186, 9.917574873068357, 8.969383387988534, 9.923668386315683, 10.689282110465733, 11.647502737309658, 12.64414374044006, 13.573861896136552, 14.502227362466371, 15.481014096765215, 16.440298610524472, 17.45929708834611, 17.262310512241115, 16.362558375273103, 15.322826656834087, 14.345214336943265, 13.433434583219741, 12.546593257879014, 11.633300866527401, 10.688663972038006, 9.857654564970098, 8.992204439256843, 8.02353872272506, 10.855165996593477, 11.699134664035428, 12.69286268960816, 13.700596627682174, 14.596877389704336, 15.556113267498784, 16.48300238917825, 17.371670245999415, 17.2263747533575, 16.276734415265476, 15.337224492267753, 14.368607861327337, 13.33721565115748, 12.462761123593362, 11.505816670120481, 10.612244164388057, 9.735120937235754, 8.801113653645238, 7.953458161278021, 7.052730818591859, 11.862418334525449, 12.735333097520334, 13.661348329042344, 14.595460093464721, 15.568504220056887, 16.506341160181908, 17.476475347650336, 17.28452608963624, 16.269112239872115, 15.253334085539732, 14.320532207879493, 13.37595679561387, 12.411997527814927, 11.474276136611003, 10.542429266701376, 9.656550000351297, 8.733447590889618, 7.788145951514026, 6.935957770695324, 6.127372836180666, 12.914791015766337, 13.785584447285697, 14.646506963743038, 15.528058702236711, 16.532902535391997, 17.463666319634743, 17.361368105991076, 16.29304713784141, 15.343812033826232, 14.403040026887988, 13.352638185597463, 12.424793236179823, 11.464683399261764, 10.541036161015148, 9.586848993672675, 8.731467943163146, 7.786689217897532, 6.843099607270969, 5.932660375053342, 5.172888787032477, 13.894347397852783, 14.773197186086026, 15.676780617619979, 16.59955233746101, 17.5026375203831, 17.504896410692776, 16.547517834614098, 15.517307836353089, 14.55255482454047, 13.571469666349783, 12.499566940901895, 11.453124493164857, 10.494179020371625, 9.537133746033048, 8.601336558448972, 7.678024403723777, 6.855467906905216, 5.9112279573935425, 5.006014189529458, 4.115317217971958, 14.8746137917299, 15.82070719206866, 16.74767404315154, 17.558216285961084, 17.514522376657055, 16.54467650850661, 15.563903507204497, 14.614894105452958, 13.57684479218944, 12.56757875953029, 11.516414819256509, 10.55455084735527, 9.632199645516677, 8.647609484095948, 7.634863578045625, 6.744976171728162, 5.841179927491572, 4.8966044592227105, 4.043582056906533, 3.0850989458850555, 15.815414334032804, 16.779846308945018, 17.680981005551736, 17.632798002214646, 16.63880938457978, 15.572973016405713, 14.56972413235312, 13.617957986606921, 12.61958454263996, 11.642414493680949, 10.577370653074107, 9.587035294798637, 8.667442229029849, 7.627798647811242, 6.622267686834865, 5.786121639225825, 4.805574035282442, 3.8992408976432635, 3.0178986593523316, 2.046705600989823, 16.863136906830654, 17.831065496578457, 17.661617654005973, 16.649965339640715, 15.69182993686307, 14.640503468969301, 13.637747996248065, 12.628207995038169, 11.557035152449789, 10.62888396997076, 9.627841758346127, 8.617971090688851, 7.637862257361564, 6.673178442775725, 5.681060018133126, 4.73568093936335, 3.8062873410410223, 2.8872897574518097, 1.967820868619707, 1.0331464400538415, 17.84041160300826, 17.689959106249955, 16.752805793005713, 15.745986002905546, 14.691308847487825, 13.688459030323779, 12.745505853048995, 11.806610545861297, 10.869569272612361, 9.933802689204391, 8.8607847641761, 7.877863007947557, 6.890254190667274, 5.904517323286953, 4.8462268514732365, 3.826802030000674, 2.8656224239403496, 1.9021368829026448, 0.9531117876126787, 0.0, 18.776452687101326, 18.637349614187286, 17.750687362357546, 16.734557852468036, 15.659749614066657, 14.626014763089614, 13.804735535395709, 12.7706921295283, 11.741570940103585, 10.762965831251849, 9.807102834927653, 8.853822436745121, 7.818338496118786, 6.743412289096577, 5.789792678876376, 4.800793659951373, 3.9019407455490285, 2.938503011702643, 1.924949822360295, 0.95168564753685], [19.036138472765487, 18.898960073756992, 17.907877695990823, 16.848332111206123, 15.908814729608288, 14.858356571604554, 13.877281273887201, 12.911279782215296, 11.892050291966694, 10.953335539314981, 10.024596064791034, 9.067164002031927, 7.994219525878376, 6.9843620543152, 6.051540685937644, 5.05985839348531, 4.008444938798223, 3.045716455344792, 2.006449977353797, 0.9386339656455174, 18.033675145618204, 18.657772206874277, 18.72425496059446, 17.783909150332388, 16.8015269385905, 15.798555897858483, 14.832057648774262, 13.846651753728022, 12.83181424131326, 11.864433830957514, 10.864286071687813, 9.871646608937146, 8.92345226099083, 7.9183972615364, 6.9871553956086885, 6.008429182691852, 4.968492714520615, 3.952321231517287, 2.973017813846672, 1.957283306377025, 17.02732148312305, 17.724740613403007, 18.66736348024578, 18.732968346016428, 17.735576406085745, 16.764377471560987, 15.79434965639731, 14.793221268193403, 13.853991626868961, 12.913105617816539, 11.855215323071608, 10.81802650096796, 9.87215299948729, 8.902885358108932, 7.961585013396563, 6.99522584839354, 5.931768948127681, 4.868084163196228, 3.9285717060140612, 2.9070784859206493, 16.01500237448249, 16.76698626250882, 17.730152116312567, 18.73802842710598, 18.66060979063635, 17.690674648954932, 16.73428470159146, 15.795001897919205, 14.815381533117904, 13.829253231780974, 12.871872160399596, 11.844231367284223, 10.82096090079998, 9.84522139586953, 8.875564793698164, 7.90490378783785, 6.852218801687828, 5.837985795218335, 4.8177881275686625, 3.8778222671406057, 14.969710773394327, 15.774540247860411, 16.75237932694622, 17.69934572046796, 18.47316816057618, 18.6389210722781, 17.709243182704583, 16.710381587424628, 15.756525959295667, 14.783056416769918, 13.718355006155747, 12.715071812667093, 11.748555080442282, 10.807821218859816, 9.813227952506265, 8.84939109323004, 7.817597216043486, 6.769729360353512, 5.774535935213216, 4.829095686683177, 13.907601041746, 14.767361971542623, 15.787170233194502, 16.74986394346618, 17.495620729002336, 18.44517493591027, 18.67095853308281, 17.75586059955904, 16.694694414277482, 15.664018101888507, 14.660143098448588, 13.724973094687622, 12.713598872495306, 11.809034771246047, 10.833632111219305, 9.895734941192648, 8.836887139371548, 7.772012900060028, 6.775665558765979, 5.886652423316106, 12.863408898267261, 13.803365757876065, 14.769851498678284, 15.741576336267357, 16.52968125321423, 17.47792861091867, 18.459841930511413, 18.644009064302974, 17.674402742502792, 16.650191570375267, 15.636758590823096, 14.670361708742162, 13.658560986479106, 12.740600475630767, 11.809291955446312, 10.756589130018627, 9.732927379861762, 8.790101039486906, 7.785431541566685, 6.856365713042153, 11.932780266286901, 12.840918076687554, 13.744399403885007, 14.732616383145151, 15.496455090178644, 16.436191351589443, 17.475663802718188, 18.396262096269083, 18.627346553260416, 17.627432132536, 16.617681968734182, 15.641485212516562, 14.643330488231715, 13.705125853456602, 12.641781969830859, 11.621998786133684, 10.674578866814816, 9.69029327625954, 8.73504745121392, 7.845018631827167, 11.000361653894505, 11.886831528933374, 12.77633660700655, 13.743187534232518, 14.570631431762717, 15.552885039854441, 16.51909261213413, 17.42290062800479, 18.403169295572475, 18.444941961960946, 17.427028145126823, 16.38806714188927, 15.408493996247348, 14.481993217724913, 13.527252562715333, 12.59980267666175, 11.699492140617178, 10.757134089631892, 9.797652282067695, 8.813059359625877, 9.946619718060173, 10.828252213562028, 11.828874115215665, 12.713345861117778, 13.625659880878874, 14.57871742840231, 15.51500655221188, 16.46835910115803, 17.45758554258939, 18.3874233778106, 18.337728425662046, 17.39173823624648, 16.451438688324, 15.474762926989266, 14.52578471643073, 13.598157746921522, 12.67119366532996, 11.690431991174618, 10.75020681560823, 9.807069299112792, 8.936696449703504, 9.883444043689858, 10.821503433314458, 11.673944388842212, 12.582482181761812, 13.51084764809163, 14.510197547932577, 15.41217798428671, 16.431176462108347, 17.475900591015147, 18.455843380580802, 18.356898724012733, 17.473287448456063, 16.409551335998202, 15.562475885469407, 14.667759978907373, 13.691735237924735, 12.69324726046215, 11.675577249419744, 10.752913964376265, 8.00519883942571, 8.94452490771665, 9.765369524402836, 10.617491501600098, 11.559466688194028, 12.49260987686466, 13.508209255519544, 14.480806348811768, 15.458711429061536, 16.51625041049762, 17.442344242820372, 18.43587269724129, 18.388217553832252, 17.38022479562458, 16.601412733647244, 15.64678796701189, 14.645278272726987, 13.733620423516408, 12.714323527398566, 11.723721868509468, 6.938883788792143, 7.908326474231743, 8.796883884968652, 9.64455519561985, 10.587839857841477, 11.542381984181537, 12.491235912028209, 13.486035065812024, 14.50144891557615, 15.492850080771873, 16.425651958432113, 17.419540462588785, 18.38349973038773, 18.368709782606942, 17.56472980610884, 16.60248213104865, 15.557451569766307, 14.5813444396432, 13.646926184810106, 12.64907985092066, 5.8865111075512555, 6.858075124466382, 7.8117252502679575, 8.71195658684786, 9.577109665476613, 10.585056824728701, 11.54596770360603, 12.599852891119406, 13.549087995134581, 14.489860002072826, 15.54026184336335, 16.46810679278099, 17.455718630379682, 18.49292616524629, 18.52031007913754, 17.49722898658644, 16.504209942758393, 15.526390783886256, 14.628040939517065, 13.603563900068849, 4.906954725464809, 5.945091216267553, 6.781451596391017, 7.640462951623562, 8.60737468048551, 9.6456069819143, 10.602985557992978, 11.57400939342412, 12.538762405236739, 13.579523616998816, 14.645889710362985, 15.52626877869631, 16.48521425148954, 17.442259525828117, 18.378056713412192, 18.475049136798432, 17.43543125375071, 16.458262433763682, 15.55468712504095, 14.661135469129368, 3.926688331587692, 4.872781731926453, 5.710558170859457, 6.681799003123486, 7.7092926007750755, 8.67913846892552, 9.659911470227634, 10.608920871979173, 11.676882771491483, 12.686148804150633, 13.584029673936007, 14.545893645837246, 15.580256207270862, 16.56484636869159, 17.58625706121949, 18.55954570164849, 18.449719233164355, 17.472885931934513, 16.517119257663875, 15.691353741216272, 2.9858877892847877, 3.950319764197004, 4.777251208459262, 5.732594126070016, 6.726582743704883, 7.792419111878948, 8.795667995931542, 9.771912314410228, 10.808236357892852, 11.741884098502055, 12.63748609222256, 13.627821450498029, 14.602166181940328, 15.59495528169991, 16.573661170008734, 17.600691169146153, 18.506512872640513, 18.47024949351396, 17.58048248297601, 16.729747086111505, 1.9133157802706724, 2.957102216981667, 3.8474497350544983, 4.859102049419755, 5.8172374521974035, 6.876837095325354, 7.924481727345901, 8.782162322841476, 9.770890521081407, 10.684629549469358, 11.68567176109399, 12.695542428751267, 13.675651262078553, 14.640335076664392, 15.632453501306992, 16.577832580076766, 17.507226178399094, 18.4368624888804, 18.630560273708635, 17.743306247047485, 0.9360410840930669, 1.959032243580726, 2.896185556824968, 3.903005346925135, 4.957682502342857, 5.960532319506903, 6.903485496781688, 7.8423808039693865, 8.779422077218323, 9.715188660626293, 10.788206585654583, 11.771128341883127, 12.758737159163411, 13.744474026543733, 14.80276449835745, 15.822189319830011, 16.783368925890336, 17.746854466928042, 18.695879562218007, 18.776452687101326, 0.0, 1.0255799559322922, 2.0546710691800634, 3.0708005790695743, 4.145608817470953, 5.179343668447996, 6.237868113844118, 7.273838643832714, 8.338027256471785, 9.316632365323521, 10.272495361647717, 11.321836909451367, 12.357320850077702, 13.43224705709991, 14.385866667320112, 15.374865686245114, 16.38990842282897, 17.370216015338013, 18.384404950052218, 19.452123547092423], [18.888763817191652, 17.873380117824702, 16.882297740058533, 15.822752155273832, 14.883234773675998, 13.832776615672264, 12.85170131795491, 11.885699826283005, 10.866470336034402, 9.92775558338269, 8.999016108858742, 8.041584046099635, 6.968639569946084, 5.958782098382908, 5.025960730005352, 4.034278437553018, 2.982864982865931, 2.0201364994125, 0.9961800679954719, 1.9642139215778096, 18.95491093824549, 18.02485449505903, 17.69867500466217, 16.758329194400098, 15.775946982658208, 14.772975941926193, 13.806477692841971, 12.82107179779573, 11.806234285380969, 10.83885387502522, 9.83870611575552, 8.846066653004852, 7.897872305058537, 6.892817305604108, 5.9615754396763965, 4.98284922675956, 3.942912758588322, 3.0005889231184097, 2.023799774241134, 2.9828632623093174, 18.015254453186813, 17.09182290158776, 17.71302874295845, 17.707388390084137, 16.709996450153454, 15.738797515628697, 14.76876970046502, 13.76764131226111, 12.828411670936669, 11.887525661884245, 10.829635367139314, 9.792446545035666, 8.846573043554997, 7.87730540217664, 6.936005057464271, 5.977419205618007, 4.913962305352149, 3.921807724498258, 2.982295267316091, 3.9326584418529413, 17.002935344546252, 16.134068550693573, 16.775817379025238, 17.74328755689851, 17.635029834704056, 16.66509469302264, 15.708704745659169, 14.769421941986913, 13.78980157718561, 12.80367327584868, 11.846292204467304, 10.818651411351931, 9.795380944867688, 8.819641439937238, 7.897769073290256, 6.927108067429942, 5.91199209673472, 4.897759090265228, 3.910779350392394, 4.850745210820451, 15.957643743458089, 15.141622536045166, 15.79804458965889, 16.704604850260488, 17.461526424932785, 17.61334111634581, 16.683663226772293, 15.700806659184627, 14.746951031055666, 13.773481488529917, 12.708780077915746, 11.705496884427092, 10.73898015220228, 9.804215521656063, 8.873001247553159, 7.909164388276933, 6.87737051109038, 5.829502655400405, 4.953153725375496, 5.802018630363022, 14.895534011809762, 14.134444259727378, 14.804994478518552, 15.755123073258709, 16.483978993358942, 17.433533200266876, 17.64537857715052, 16.74628567131904, 15.68511948603748, 14.654443173648506, 13.650568170208587, 12.71539816644762, 11.704023944255304, 10.805429074042294, 9.893405406266199, 8.958988863637693, 7.918772963934654, 6.865517094246638, 5.954283348928259, 6.859575366995951, 13.851341868331023, 13.17044804606082, 13.787675744002334, 14.746835466059885, 15.518039517570834, 16.466286875275276, 17.44820019486802, 17.634434136062975, 16.664827814262793, 15.640616642135267, 14.627183662583095, 13.66078678050216, 12.648986058239105, 11.803294285333452, 10.871985765148997, 9.884980206921869, 8.861318456765003, 7.918492116390147, 6.995570973362231, 7.829288656721998, 12.920713236350663, 12.173367867663611, 12.762223649209057, 13.737875512937679, 14.48481335453525, 15.424549615946049, 16.464022067074794, 17.384620360625696, 17.617771625020417, 16.61835106738746, 15.608600903585643, 14.632404147368023, 13.634249423083176, 12.829533814486563, 11.795234843084515, 10.77545165938734, 9.828031740068472, 8.900432708055087, 7.945186883009466, 8.817941575507012, 11.988294623958266, 11.219281319909431, 11.7941608523306, 12.748446664025046, 13.558989696119323, 14.541243304211047, 15.507450876490735, 16.411258892361403, 17.391527559929088, 17.598394835214602, 16.58048101838048, 15.541520015142925, 14.561946869501003, 13.635446090978569, 12.680705435968989, 11.753255549915405, 10.852945013870833, 9.967273521427439, 9.007791713863242, 9.785982303305722, 10.934552688123935, 10.160702004538084, 10.846698360539715, 11.701704125474386, 12.61401814523548, 13.567075692758916, 14.503364816568485, 15.45671736551464, 16.445943806945998, 17.375781642167208, 17.491181298915702, 16.545191109500134, 15.604891561577656, 14.628215800242922, 13.679237589684385, 12.751610620175178, 11.827434995913004, 10.900571422970165, 9.960346247403777, 10.779992242792638, 9.924629419767266, 9.215893834665914, 9.809861697671066, 10.66230265319882, 11.570840446118417, 12.499205912448236, 13.498555812289185, 14.40053624864332, 15.419534726464956, 16.464258855371757, 17.44420164493741, 17.51035159726639, 16.62674032170972, 15.56300420925186, 14.715928758723063, 13.821212852161029, 12.847976568507779, 11.903386692257696, 10.88571668121529, 11.725836908056111, 8.993131809489471, 8.206041281096219, 8.753727788759443, 9.605849765956705, 10.547824952550634, 11.480968141221268, 12.496567519876152, 13.469164613168376, 14.447069693418143, 15.504608674854225, 16.43070250717698, 17.4242309615979, 17.541670427085908, 16.533677668878237, 15.756705346481596, 14.803029297594934, 13.80151960331003, 12.943759855311955, 11.924462959194113, 12.696644812189314, 7.926816758855904, 7.169842847611314, 7.785242149325259, 8.632913459976457, 9.576198122198083, 10.530740248538144, 11.479594176384817, 12.474393330168631, 13.489807179932757, 14.481208345128481, 15.41401022278872, 16.40789872694539, 17.371857994744335, 17.522162655860598, 16.7200927499007, 15.758723461631694, 14.803192949656166, 13.876381604609904, 12.94196334977681, 13.622002794600506, 6.874444077615016, 6.119591497845952, 6.800083514624565, 7.7003148512044675, 8.565467929833218, 9.573415089085309, 10.534325967962637, 11.588211155476014, 12.537446259491189, 13.478218266429433, 14.528620107719957, 15.456465057137597, 16.444076894736288, 17.481284429602898, 17.675673022929402, 16.683805518819845, 15.749951322648252, 14.82142794885296, 13.945260745418791, 14.576486843748695, 5.89488769552857, 5.131978759045621, 5.769809860747625, 6.628821215980169, 7.5957329448421165, 8.633965246270908, 9.591343822349586, 10.562367657780728, 11.527120669593346, 12.567881881355424, 13.634247974719592, 14.514627043052917, 15.473572515846149, 16.430617790184726, 17.3664149777688, 17.72079051668829, 16.681172633640568, 15.753299598730388, 14.871906930942675, 15.634058412809214, 4.914621301651453, 4.059669274704521, 4.698916435216065, 5.670157267480094, 6.697650865131683, 7.667496733282129, 8.648269734584241, 9.59727913633578, 10.66524103584809, 11.674507068507243, 12.572387938292614, 13.534251910193854, 14.56861447162747, 15.553204633048198, 16.574615325576097, 17.547903966005094, 17.695460613054212, 16.76792309690122, 15.8343390635656, 16.664276684896116, 3.9738207593485484, 3.0093887844363323, 3.7656094728158696, 4.720952390426624, 5.714941008061491, 6.780777376235555, 7.784026260288149, 8.760270578766836, 9.79659462224946, 10.730242362858663, 11.625844356579167, 12.616179714854637, 13.590524446296936, 14.583313546056518, 15.56201943436534, 16.58904943350276, 17.494871136997123, 17.76528665848067, 16.897702288877735, 17.70267002979135, 2.9388957362029644, 1.958169596802894, 2.8358079994111054, 3.847460313776362, 4.80559571655401, 5.865195359681961, 6.9128399917025085, 7.770520587198083, 8.759248785438015, 9.672987813825966, 10.674030025450598, 11.683900693107875, 12.66400952643516, 13.628693341021, 14.6208117656636, 15.566190844433375, 16.495584442755703, 17.42522075323701, 17.94778007961036, 18.71622919072733, 1.961621040025359, 0.9473905079373329, 1.8845438211815748, 2.891363611281742, 3.946040766699464, 4.948890583863511, 5.891843761138295, 6.830739068325994, 7.76778034157493, 8.7035469249829, 9.77656485001119, 10.759486606239735, 11.747095423520019, 12.73283229090034, 13.791122762714057, 14.810547584186619, 15.771727190246944, 16.735212731284648, 17.684237826574613, 18.63734961418729, 1.0255799559322922, 0.0, 1.0290911132477714, 2.0452206231372823, 3.1200288615386613, 4.153763712515704, 5.212288157911826, 6.248258687900422, 7.3124473005394925, 8.291052409391229, 9.246915405715425, 10.296256953519073, 11.331740894145408, 12.406667101167617, 13.360286711387818, 14.34928573031282, 15.364328466896675, 16.344636059405715, 17.35882499411992, 18.426543591160126], [17.85967270394388, 16.84428900457693, 15.853206626810758, 14.79366104202606, 13.854143660428225, 12.803685502424491, 11.822610204707138, 10.856608713035232, 9.83737922278663, 8.898664470134918, 7.96992499561097, 7.012492932851863, 5.939548456698311, 4.929690985135136, 3.9968696167575795, 3.005187324305246, 1.9537738696181592, 0.9910453861647287, 2.025271181243243, 2.993305034825581, 18.572280914093195, 17.642224470906736, 16.669583891414398, 15.729238081152323, 14.746855869410435, 13.74388482867842, 12.777386579594198, 11.791980684547958, 10.777143172133197, 9.80976276177745, 8.809615002507748, 7.81697553975708, 6.868781191810765, 5.863726192356336, 4.932484326428625, 3.9537581135117885, 2.9138216453405503, 1.9714978098706384, 2.9508012275412536, 3.9665357350109005, 18.792254010726623, 17.79165937953127, 16.871450687666, 16.678297276836364, 15.680905336905681, 14.709706402380924, 13.739678587217247, 12.73855019901334, 11.799320557688898, 10.858434548636474, 9.800544253891543, 8.763355431787895, 7.817481930307226, 6.848214288928869, 5.9069139442165, 4.948328092370235, 3.8848711921043764, 2.9155555865569607, 3.8550680437391276, 4.8765612638325395, 17.87966090973218, 16.833905028637083, 15.93423932373279, 16.90170950160606, 16.605938721456287, 15.636003579774867, 14.679613632411396, 13.740330828739141, 12.76071046393784, 11.774582162600911, 10.817201091219532, 9.78956029810416, 8.766289831619916, 7.790550326689466, 6.868677960042484, 5.89801695418217, 4.895685800216576, 3.89150695232393, 4.78355212681543, 5.723517987243487, 16.840242495900895, 15.841459013988674, 14.956466534366442, 15.86302679496804, 16.61994836964034, 16.58425000309804, 15.654572113524521, 14.671715545936856, 13.717859917807894, 12.744390375282146, 11.679688964667974, 10.67640577117932, 9.70988903895451, 8.775124408408292, 7.866749109611861, 6.9029122503356355, 5.871118373149082, 4.823250517459107, 5.825926501798532, 6.674791406786058, 15.77813276425257, 14.834280737670886, 13.963416423226104, 14.91354501796626, 15.642400938066496, 16.591955144974428, 16.61628746390275, 15.717194558071268, 14.65602837278971, 13.625352060400735, 12.621477056960815, 11.68630705319985, 10.674932831007533, 9.776337960794525, 8.887153268324901, 7.952736725696395, 6.912520825993356, 5.85926495630534, 6.827056125351295, 7.732348143418988, 14.733940620773831, 13.870284524004328, 12.946097688709886, 13.905257410767437, 14.676461462278386, 15.624708819982827, 16.60662213957557, 16.6053430228152, 15.63573670101502, 14.611525528887496, 13.598092549335323, 12.63169566725439, 11.619894944991334, 10.797042147392155, 9.8657336272077, 8.878728068980571, 7.855066318823706, 6.9122399784488495, 7.868343749785267, 8.702061433145033, 13.803311988793471, 12.87320434560712, 11.920645593916609, 12.89629745764523, 13.643235299242802, 14.5829715606536, 15.622444011782344, 16.54304230533325, 16.588680511772644, 15.589259954139692, 14.579509790337871, 13.603313034120252, 12.605158309835405, 11.823281676545266, 10.788982705143217, 9.769199521446042, 8.821779602127174, 7.951039903487302, 8.817959659432502, 9.690714351930048, 12.870893376401074, 11.91911779785294, 10.952582797038152, 11.906868608732598, 12.717411640826874, 13.699665248918599, 14.665872821198287, 15.569680837068953, 16.549949504636636, 16.58065503316307, 15.57422888043918, 14.535267877201628, 13.555694731559706, 12.629193953037271, 11.674453298027691, 10.747003411974108, 9.846692875929536, 9.017880716859652, 9.880564490286275, 10.658755079728758, 11.817151440566743, 10.860538482481592, 10.005120305247267, 10.860126070181938, 11.772440089943032, 12.725497637466468, 13.661786761276037, 14.615139310222192, 15.60436575165355, 16.53420358687476, 16.484929160974406, 15.538938971558839, 14.598639423636358, 13.621963662301624, 12.672985451743088, 11.74535848223388, 10.821182857971706, 9.951178618402379, 10.83311902382681, 11.652765019215673, 10.807228172210074, 9.915730312609423, 8.968283642378617, 9.820724597906372, 10.72926239082597, 11.657627857155788, 12.656977756996735, 13.558958193350872, 14.577956671172508, 15.62268080007931, 16.602623589644963, 16.504099459325094, 15.62048818376842, 14.556752071310562, 13.709676620781766, 12.814960714219731, 11.84172443056648, 11.011663614859465, 11.758489457638325, 12.598609684479147, 9.87573056193228, 8.905877759039727, 7.912149733466995, 8.764271710664257, 9.706246897258186, 10.639390085928818, 11.654989464583702, 12.627586557875928, 13.605491638125695, 14.663030619561779, 15.589124451884533, 16.575553261927794, 16.535418289144612, 15.527425530936942, 14.750453208540298, 13.796777159653635, 12.795267465368731, 12.068204526184324, 12.797235735617146, 13.56941758861235, 8.809415511298713, 7.989409754060215, 6.943664094032811, 7.791335404684009, 8.734620066905634, 9.689162193245695, 10.638016121092368, 11.632815274876183, 12.64822912464031, 13.639630289836035, 14.572432167496274, 15.551067204045932, 16.504728771459707, 16.515910517919302, 15.713840611959403, 14.752471323690395, 13.796940811714867, 13.081172228315538, 13.814736126199843, 14.494775571023542, 7.757042830057826, 6.956481316811199, 5.958505459332117, 6.858736795912019, 7.72388987454077, 8.731837033792859, 9.692747912670189, 10.746633100183567, 11.695868204198742, 12.636640211136987, 13.676861251891555, 14.599633534238139, 15.557414642906544, 16.594622177773154, 16.669420884988106, 15.677553380878546, 14.743699184706953, 14.026218572558594, 14.818033521841825, 15.44925962017173, 6.77748644797138, 5.968868578010868, 4.928231805455177, 5.787243160687721, 6.754154889549668, 7.7923871909784586, 8.749765767057138, 9.720789602488281, 10.6855426143009, 11.726303826062978, 12.747585722889848, 13.627964791223173, 14.586910264016405, 15.543955538354982, 16.479752725939058, 16.714538378746994, 15.67492049569927, 14.958090222436022, 15.744679707365709, 16.50683118923225, 5.797220054094263, 4.919352420136015, 3.8573383799236165, 4.828579212187646, 5.856072809839235, 6.825918677989681, 7.806691679291794, 8.755701081043334, 9.823662980555644, 10.832929013214795, 11.68572568646287, 12.64758965836411, 13.681952219797726, 14.666542381218454, 15.687953073746355, 16.661241714175354, 16.689208475112913, 15.972713720606855, 16.707111839988634, 17.537049461319153, 4.8564195117913584, 3.8919875368791423, 2.924031417523422, 3.8793743351341763, 4.8733629527690425, 5.939199320943107, 6.942448204995701, 7.873608326937093, 8.909932370419718, 9.843580111028919, 10.739182104749423, 11.729517463024893, 12.703862194467192, 13.696651294226774, 14.675357182535596, 15.702387181673016, 16.60820888516738, 16.970077282186303, 17.77047506530077, 18.575442806214387, 3.9679868494507358, 2.9872607100506654, 1.9942299441186577, 3.0058822584839144, 3.9640176612615625, 5.01427277067929, 6.026177739872765, 6.88385833536834, 7.8725865336082705, 8.786325561996222, 9.787367773620854, 10.79723844127813, 11.777347274605416, 12.742031089191256, 13.734149513833856, 14.679528592603631, 15.60892219092596, 16.538558501407266, 17.527603735734274, 18.46227816430014, 2.9907121532731304, 1.9764816211851044, 1.0429657658891274, 2.0497855559892946, 3.1044627114070167, 4.062228332033768, 5.005181509308552, 5.944076816496251, 6.881118089745186, 7.816884673153156, 8.889902598181447, 9.87282435440999, 10.860433171690275, 11.846170039070596, 12.904460510884313, 13.923885332356875, 14.8850649384172, 15.848550479454904, 16.79757557474487, 17.750687362357546, 2.0546710691800634, 1.0290911132477714, 0.0, 1.016129509889511, 2.09093774829089, 3.1246725992679325, 4.1831970446640545, 5.2191675746526505, 6.283356187291721, 7.261961296143457, 8.217824292467654, 9.267165840271304, 10.302649780897639, 11.377575987919847, 12.331195598140049, 13.32019461706505, 14.335237353648905, 15.315544946157948, 16.329733880872155, 17.39745247791236], [16.870020975173738, 15.854637275806787, 14.863554898040617, 13.804009313255918, 12.864491931658083, 11.81403377365435, 10.832958475936996, 9.86695698426509, 8.847727494016487, 7.909012741364774, 6.980273266840825, 6.022841204081718, 4.9498967279281665, 3.940039256364991, 3.0072178879874345, 2.015535595535101, 1.00702826342652, 1.9697567468799506, 3.0296028012921403, 4.009434544715092, 17.582629185323054, 16.652572742136595, 15.679932162644256, 14.739586352382181, 13.757204140640294, 12.754233099908278, 11.787734850824057, 10.802328955777815, 9.787491443363054, 8.820111033007304, 7.819963273737602, 6.827323810986935, 5.87912946304062, 4.874074463586191, 3.959018431850551, 2.980292218933714, 1.967076039148911, 2.95020917058586, 3.9295125882564754, 4.945247095726122, 18.518720318471516, 17.585604335607865, 16.68903695804421, 15.688645548066225, 14.69125360813554, 13.720054673610782, 12.750026858447105, 11.748898470243196, 10.809668828918754, 9.868782819866329, 8.810892525121398, 7.77370370301775, 6.844016035729151, 5.874748394350794, 4.933448049638425, 4.001582486178596, 2.9381255859127373, 3.8942669472721825, 4.833779404454349, 5.855272624547761, 18.879212565240405, 17.833456684145307, 16.933790979241017, 16.11947808204071, 15.616286992686145, 14.646351851004725, 13.689961903641255, 12.750679099968998, 11.784894449670881, 10.801116268022835, 9.843735196641457, 8.816094403526085, 7.792823937041842, 6.8170844321113915, 5.921932353850845, 4.951271347990531, 3.948940194024937, 4.870218313039152, 5.762263487530652, 6.702229347958709, 17.856372005790412, 16.8410106694969, 15.95601818987467, 15.08079537540269, 15.837716950074991, 15.594598274327899, 14.66492038475438, 13.69824965135878, 12.74439402322982, 11.770924480704071, 10.7062230700899, 9.702939876601246, 8.736423144376435, 7.801658513830217, 6.940055295154375, 5.976218435878149, 4.944424558691595, 5.801961878174329, 6.804637862513754, 7.65350276750128, 16.794262274142085, 15.833832393179113, 14.962968078734331, 14.131313598400912, 14.860169518501147, 15.809723725409077, 15.626635735132608, 14.743728663493194, 13.682562478211635, 12.65188616582266, 11.64801116238274, 10.712841158621774, 9.701466936429458, 8.802872066216448, 7.960459453867415, 7.026042911238909, 5.985827011535869, 6.837976317020562, 7.805767486066517, 8.711059504134209, 15.750070130663344, 14.869836179512555, 13.945649344218113, 13.123025991202088, 13.894230042713037, 14.842477400417478, 15.82439072001022, 15.631877128237127, 14.662270806436947, 13.638059634309421, 12.624626654757249, 11.658229772676314, 10.646429050413259, 9.859117002634207, 8.939039812750213, 8.084066933705579, 7.060405183548713, 7.890951339164071, 8.84705511050049, 9.680772793860255, 14.819441498682984, 13.872756001115347, 12.920197249424836, 12.114066038079882, 12.861003879677453, 13.800740141088252, 14.840212592216995, 15.750885681019643, 15.615214617194573, 14.615794059561617, 13.606043895759797, 12.629847139542177, 11.63169241525733, 10.885356531787318, 9.912608478718049, 8.97453838617105, 8.027118466852182, 8.929751264202523, 9.796671020147725, 10.66942571264527, 13.887022886290588, 12.918669453361167, 11.95213445254638, 11.124637189167249, 11.935180221261525, 12.91743382935325, 13.883641401632937, 14.777524212755347, 15.757792880323032, 15.607189138584992, 14.625882182583922, 13.648195341353478, 12.668622195711556, 11.834532817762279, 10.879792162752699, 9.952342276699115, 9.052031740654543, 9.996592077574874, 10.859275851001499, 11.63746644044398, 12.833280950456256, 11.86009013798982, 11.004671960755495, 10.077894650616589, 10.990208670377683, 11.943266217901119, 12.879555341710688, 13.822982685908586, 14.812209127339944, 15.742046962561153, 15.597856625126257, 14.651866435710689, 13.711566887788209, 12.827302527026632, 11.878324316468095, 10.950697346958888, 10.026521722696714, 10.9298899791176, 11.811830384542034, 12.631476379930895, 11.823357682099587, 10.91528196811765, 9.967835297886845, 9.038493178341023, 9.94703097126062, 10.875396437590439, 11.874746337431386, 12.766801569037266, 13.785800046858903, 14.747320571387704, 15.670651931677686, 15.617026923476942, 14.757696321987357, 13.76209093603557, 12.915015485506773, 12.020299578944739, 11.047063295291487, 11.990374975574689, 12.737200818353548, 13.577321045194369, 10.891860071821792, 9.905429414547955, 8.911701388975223, 7.982040291098909, 8.924015477692837, 9.85715866636347, 10.872758045018353, 11.835429933562322, 12.81333501381209, 13.761744474412065, 14.645318048672335, 15.559423752038287, 15.740757153869621, 14.732764395661949, 13.955792073265306, 13.002116024378642, 12.000606330093738, 13.034970717046317, 13.77594709633237, 14.548128949327571, 9.825545021188224, 8.988961409568443, 7.9432157495410385, 7.00910398511866, 7.952388647340285, 8.906930773680346, 9.845859496778763, 10.840658650562577, 11.856072500326704, 12.738344144686321, 13.628625764284076, 14.534937694156422, 15.488599261570197, 15.721249382644308, 14.91917947668441, 13.957810188415403, 13.002279676439874, 13.978386806562982, 14.793447486915067, 15.473486931738764, 8.773172339947337, 7.97261082670071, 6.974634969221628, 6.07650537634667, 6.941658454975421, 7.949605614227511, 8.900591288356583, 9.845346955033854, 10.794582059049029, 11.735354065987273, 12.660731742002046, 13.58350402434863, 14.541285133017034, 15.578492667883646, 15.874759749713112, 14.882892245603554, 13.94903804943196, 14.923433150806039, 15.796744882557048, 16.427970980886954, 7.79361595786089, 6.9849980879003795, 5.944361315344688, 5.005011741122372, 5.971923469984319, 7.0101557714131095, 7.957609142743532, 8.819503457338568, 9.784256469151186, 10.825017680913264, 11.731456213000339, 12.611835281333663, 13.570780754126895, 14.527826028465473, 15.463623216049548, 15.919877243472, 14.880259360424278, 15.855304800683466, 16.723391068080932, 17.485542549947475, 6.813349563983773, 5.935481930025526, 4.873467889813128, 4.046347792622297, 5.073841390273886, 6.043687258424332, 6.956509192076019, 7.854414935893621, 8.886114886897937, 9.878269369394767, 10.66959617657336, 11.6314601484746, 12.665822709908216, 13.650412871328944, 14.671823563856845, 15.645112204285843, 15.894547339837922, 16.869928298854298, 17.685823200703858, 18.515760822034377, 5.872549021680869, 4.908117046768653, 3.940160927412933, 3.073337723632057, 4.056657066718619, 5.050713123434687, 5.94202436608831, 6.857478817047583, 7.893802860530206, 8.82745060113941, 9.723052594859913, 10.713387953135383, 11.687732684577682, 12.680521784337264, 13.659227672646086, 14.686257671783506, 15.59207937527787, 16.53438013170921, 17.539745774647596, 18.459707815346608, 4.9841163593402475, 4.003390219940176, 3.0103594540081686, 2.056171379799695, 3.0143067825773433, 3.9981432607897793, 5.010048229983255, 5.86772882547883, 6.856457023718761, 7.770196052106712, 8.771238263731345, 9.781108931388621, 10.761217764715907, 11.725901579301746, 12.718020003944346, 13.663399082714122, 14.59279268103645, 15.522428991517755, 16.51147422584476, 17.446148654410628, 4.006841663162642, 2.9926111310746153, 2.0590952757786383, 1.0611794799230359, 2.0923270606316553, 3.0460988221442573, 3.9890519994190416, 4.9279473066067405, 5.864988579855677, 6.800755163263647, 7.873773088291937, 8.856694844520481, 9.844303661800765, 10.830040529181087, 11.888331000994803, 12.907755822467365, 13.86893542852769, 14.832420969565394, 15.781446064855361, 16.73455785246804, 3.0708005790695747, 2.0452206231372823, 1.016129509889511, 0.0, 1.0748082384013793, 2.108543089378422, 3.167067534774544, 4.20303806476314, 5.26722667740221, 6.245831786253945, 7.2016947825781426, 8.25103633038179, 9.286520271008126, 10.361446478030334, 11.315066088250536, 12.304065107175537, 13.319107843759392, 14.299415436268434, 15.313604370982642, 16.381322968022847], [15.795212736772356, 14.779829037405406, 13.788746659639235, 12.729201074854537, 11.789683693256702, 10.739225535252968, 9.758150237535615, 8.79214874586371, 7.772919255615107, 6.834204502963394, 5.905465028439446, 4.948032965680339, 3.875088489526787, 2.8652310179636116, 1.932409649586055, 0.9407273571337217, 1.9921408118208088, 2.9548692952742392, 4.014715349686429, 5.082531361394708, 16.507820946921672, 15.577764503735214, 14.605123924242875, 13.6647781139808, 12.682395902238913, 11.679424861506897, 10.712926612422676, 9.727520717376434, 8.712683204961673, 7.745302794605925, 6.745155035336222, 5.752515572585556, 4.80432122463924, 3.7992662251848115, 2.8842101934491717, 1.9054839805323351, 2.9454204487035733, 3.9353217189801493, 4.9146251366507645, 5.930359644120411, 17.443912080070135, 16.510796097206484, 15.614228719642828, 14.613837309664843, 13.616445369734159, 12.645246435209401, 11.675218620045724, 10.674090231841815, 9.734860590517373, 8.79397458146495, 7.736084286720019, 6.6988954646163705, 5.7692077973277724, 4.7999401559494155, 3.858639811237046, 2.9359107511010976, 3.9164699954673994, 4.8793794956664716, 5.818891952848638, 6.84038517294205, 18.42425363713921, 17.46855044810067, 16.523031963445977, 15.470629959004388, 14.541478754284764, 13.571543612603344, 12.615153665239873, 11.675870861567617, 10.7100862112695, 9.726308029621457, 8.76892695824008, 7.741286165124707, 6.718015698640464, 5.742276193710014, 4.856260618773346, 3.8855996129130324, 4.927284603579599, 5.855330861433441, 6.747376035924941, 7.687341896352998, 18.810213331415643, 17.761014604080373, 16.876022124458142, 15.910918752885278, 14.980223619185931, 14.519790035926517, 13.590112146352999, 12.623441412957401, 11.66958578482844, 10.696116242302692, 9.63141483168852, 8.628131638199866, 7.661614905975056, 6.7268502754288395, 5.899423537277477, 4.935586678001251, 5.922768968246257, 6.787074426568618, 7.789750410908043, 8.638615315895569, 17.752938088729973, 16.753836327762585, 15.882972013317804, 15.008017682778144, 14.002676187612087, 14.952230394520017, 14.551827496731226, 13.668920425091814, 12.607754239810255, 11.57707792742128, 10.573202923981361, 9.638032920220395, 8.626658698028079, 7.728063827815071, 6.919827695990517, 5.985411153362011, 6.964171421090531, 7.823088865414851, 8.790880034460807, 9.696172052528498, 16.708745945251234, 15.789840114096027, 14.865653278801586, 13.99973007557932, 13.036736711823977, 13.984984069528418, 14.903157821417306, 14.557068889835746, 13.587462568035566, 12.563251395908042, 11.549818416355869, 10.583421534274935, 9.57162081201188, 8.784308764232831, 7.8984080548733155, 7.055923327006818, 8.038749593103375, 8.87606388755836, 9.832167658894779, 10.665885342254544, 15.778117313270872, 14.792759935698818, 13.84020118400831, 13.00145783197811, 12.003510548788393, 12.943246810199192, 13.841237986585297, 14.676077442618261, 14.540406378793191, 13.540985821160238, 12.531235657358417, 11.555038901140797, 10.55688417685595, 9.810548293385942, 8.87197672084115, 8.126005702927865, 9.005462876406844, 9.914863812596812, 10.781783568542014, 11.654538261039558, 14.845698700878476, 13.838673387944638, 12.872138387129853, 12.03334502663202, 11.077686890372465, 11.974442565246175, 12.861237862992871, 13.702715974353966, 14.682984641921651, 14.532380900183613, 13.551073944182543, 12.573387102952099, 11.593813957310177, 10.774831551752452, 9.86646870526562, 9.10380959345593, 10.030376150209205, 10.981704625969163, 11.84438839939579, 12.622578988838269, 13.791956765044144, 12.780094072573291, 11.924675895338968, 10.997898585200062, 10.132715339488623, 10.996200966198318, 11.857151803070622, 12.748174447507205, 13.737400888938563, 14.667238724159771, 14.523048386724877, 13.57705819730931, 12.63675864938683, 11.767601261016805, 10.903731033993056, 10.102164663715703, 11.004866132251376, 11.91500252751189, 12.796942932936325, 13.616588928325184, 12.782033496687475, 11.835285902701122, 10.887839232470316, 9.958497112924496, 9.08953764037156, 9.928331185887638, 10.824382035712834, 11.691993330635885, 12.710991808457521, 13.672512332986322, 14.595843693276306, 14.542218685075563, 13.682888083585977, 12.702389670025743, 11.940422203031734, 11.171766895701554, 12.025407704846149, 12.975487523968976, 13.722313366747839, 14.562433593588658, 11.869328246562048, 10.825433349131426, 9.831705323558694, 8.902044225682381, 8.066522146803777, 8.874445280855225, 9.8223937432998, 10.760621695160943, 11.73852677541071, 12.686936236010684, 13.570509810270956, 14.484615513636907, 14.681055887859795, 13.673063129652123, 12.981198790790266, 12.192823597840897, 12.9789507396484, 14.013315126600979, 14.76105964472666, 15.53324149772186, 10.80301319592848, 9.908965344151916, 8.86321968412451, 7.929107919702133, 7.0948953164512245, 7.924217388172101, 8.771051258377383, 9.765850412161198, 10.781264261925324, 11.66353590628494, 12.553817525882696, 13.460129455755043, 14.413791023168818, 14.661548116634481, 13.944586194209371, 13.148517761877658, 13.980624085994537, 14.956731216117644, 15.778560035309358, 16.458599480133053, 9.750640514687593, 8.950079001440965, 7.952103143961884, 6.9965093109301435, 6.08416512408636, 6.966892228719265, 7.825783049955204, 8.770538716632473, 9.719773820647648, 10.660545827585892, 11.585923503600666, 12.50869578594725, 13.466476894615655, 14.503684429482266, 14.900166467238073, 14.073599819065809, 14.927382458986623, 15.901777560360701, 16.78185743095134, 17.41308352928124, 8.771084132601146, 7.9624662626406355, 6.921829490084944, 5.925015675705845, 5.1144301390952585, 6.027442385904864, 6.882800904342153, 7.744695218937188, 8.709448230749805, 9.750209442511883, 10.65664797459896, 11.537027042932284, 12.495972515725516, 13.453017790064093, 14.388814977648169, 15.127043358505178, 15.85860376997894, 16.83364921023813, 17.708503616475227, 18.470655098341762, 7.790817738724029, 6.912950104765782, 5.850936064553384, 4.96635172720577, 4.09782101450284, 5.029595866341179, 5.881700953674639, 6.779606697492241, 7.811306648496558, 8.803461130993387, 9.594787938171981, 10.55665191007322, 11.591014471506837, 12.575604632927565, 13.597015325455466, 14.570303965884463, 15.55287702908562, 16.456935454887276, 17.52199650367226, 18.42329292184046, 6.850017196421125, 5.885585221508909, 4.917629102153189, 3.99334165821553, 3.0603901957467956, 3.975904885033308, 4.86721612768693, 5.782670578646203, 6.818994622128827, 7.75264236273803, 8.648244356458534, 9.638579714734004, 10.612924446176303, 11.605713545935885, 12.584419434244706, 13.611449433382127, 14.51727113687649, 15.45957189330783, 16.464937536246218, 17.384899576945227, 6.016434936657671, 5.026948169857967, 3.987827628748425, 2.9761753143831684, 2.0180399116055203, 2.9233350223884, 3.9352399915818754, 4.79292058707745, 5.7816487853173815, 6.695387813705333, 7.696430025329965, 8.706300692987242, 9.686409526314527, 10.651093340900367, 11.643211765542967, 12.588590844312742, 13.51798444263507, 14.447620753116375, 15.436665987443382, 16.371340416009247, 5.039160240480065, 4.016169080992406, 3.0790157677481647, 2.072195977647998, 1.0175188222302758, 1.9712905837428778, 2.914243761017662, 3.853139068205361, 4.790180341454297, 5.725946924862267, 6.798964849890558, 7.7818866061191025, 8.769495423399386, 9.755232290779707, 10.813522762593424, 11.832947584065986, 12.79412719012631, 13.757612731164015, 14.706637826453981, 15.65974961406666, 4.145608817470953, 3.1200288615386613, 2.09093774829089, 1.0748082384013793, 0.0, 1.0337348509770425, 2.0922592963731645, 3.1282298263617605, 4.19241843900083, 5.171023547852566, 6.126886544176763, 7.176228091980412, 8.211712032606746, 9.286638239628955, 10.240257849849156, 11.229256868774158, 12.244299605358012, 13.224607197867055, 14.238796132581262, 15.306514729621465], [14.879910959887466, 13.864527260520516, 12.873444882754345, 11.813899297969646, 10.874381916371812, 9.823923758368078, 8.842848460650725, 7.876846968978819, 6.857617478730217, 5.918902726078504, 4.990163251554556, 4.032731188795449, 2.959786712641897, 1.9499292410787212, 1.0171078727011647, 1.9744622081107641, 3.0258756627978514, 3.988604146251282, 5.0484502006634715, 6.116266212371751, 15.576279769975777, 14.662462726850324, 13.689822147357985, 12.74947633709591, 11.767094125354022, 10.764123084622007, 9.797624835537786, 8.812218940491544, 7.7973814280767835, 6.830001017721035, 5.829853258451332, 4.837213795700666, 3.8890194477543503, 2.883964448299921, 2.025364032732491, 2.9392188315093772, 3.9791552996806154, 4.969056569957192, 5.948359987627807, 6.964094495097454, 16.41017722909309, 15.595494320321594, 14.698926942757938, 13.698535532779953, 12.701143592849268, 11.729944658324511, 10.759916843160834, 9.758788454956925, 8.819558813632483, 7.878672804580059, 6.820782509835129, 5.78359368773148, 4.891659537559374, 3.9223918961810167, 2.9997936505203655, 3.9696456020781397, 4.950204846444441, 5.913114346643514, 6.852626803825681, 7.874120023919093, 17.39051878616217, 16.55324867121578, 15.607730186561088, 14.555328182119498, 13.626176977399874, 12.656241835718454, 11.699851888354983, 10.760569084682727, 9.79478443438461, 8.819843342331032, 7.862462270949654, 6.834821477834281, 5.840467438872064, 4.864727933941614, 4.034834522294519, 4.919334463890074, 5.961019454556641, 6.889065712410484, 7.781110886901984, 8.721076747330041, 18.43581038725033, 17.503724471639412, 16.525885392553604, 15.462365955067254, 14.531670821367907, 13.604488259041627, 12.674810369468108, 11.745893153189002, 10.79203752506004, 9.818567982534292, 8.75386657192012, 7.750583378431466, 6.784066646206656, 5.84930201566044, 5.08420871928552, 5.969321528978293, 6.956503819223299, 7.820809277545661, 8.823485261885086, 9.672350166872612, 18.64416704289237, 17.626092011972695, 16.74395956458543, 15.741441843646998, 14.73610034848094, 13.986262127353996, 13.636525719846336, 12.791372165323414, 11.730205980041855, 10.69952966765288, 9.695654664212961, 8.760484660451995, 7.749110438259679, 6.850515568046672, 6.1046128779985604, 7.019146004339053, 7.997906272067572, 8.856823716391894, 9.82461488543785, 10.699851590117458, 17.602052657914943, 16.662095798306137, 15.727135006398575, 14.733154236448174, 13.77016087269283, 13.019015802362397, 13.869422970440262, 13.679520630067346, 12.709914308267166, 11.685703136139642, 10.67227015658747, 9.705873274506535, 8.69407255224348, 7.906760504464431, 7.083193236881359, 8.08965817798386, 9.072484444080418, 9.909798738535404, 10.865902509871821, 11.669564879843504, 16.701004040970478, 15.665015619908928, 14.701682911605298, 13.734881992846963, 12.736934709657247, 11.97727854303317, 12.807503135608252, 13.642342591641217, 13.662858119024792, 12.663437561391838, 11.653687397590017, 10.677490641372398, 9.67933591708755, 8.933000033617542, 8.056761902849194, 9.07654508654637, 10.023965005865238, 10.948598663573856, 11.815518419519057, 12.656884202879375, 15.768585428578081, 14.71363483941309, 13.733620114726842, 12.766769187500874, 11.811111051241319, 10.94070771426913, 11.827503012015827, 12.668981123376922, 13.649249790944607, 13.654832640415213, 12.673525684414143, 11.695838843183699, 10.716265697541777, 9.897283291984053, 9.051253887273663, 9.978703773327247, 10.912717584741499, 11.878313850813553, 12.87812325037283, 13.624924930678086, 14.71484349274375, 13.702980800272897, 12.80308502475322, 11.809008831029734, 10.866139500357475, 9.962466115221273, 10.823416952093577, 11.71443959653016, 12.703666037961518, 13.633503873182727, 13.645500126956478, 12.69950993754091, 11.75921038961843, 10.890053001248406, 10.0885162160011, 10.97705884358702, 11.887207566783669, 12.81161175235628, 13.830677783913366, 14.618934870165, 13.704920224387081, 12.758172630400727, 11.810725960169922, 10.849001639207222, 9.822961801240412, 8.894596334910593, 9.79064718473579, 10.65825847965884, 11.677256957480477, 12.63877748200928, 13.562108842299264, 13.664670425307163, 12.805339823817578, 11.824841410257344, 11.125207385039777, 12.046661075572871, 12.907749139378442, 13.872096748813366, 14.75604821772488, 15.564779535428475, 12.792214974261654, 11.748320076831032, 10.7545920512583, 9.824930953381987, 8.8254520456073, 7.840710429878182, 8.788658892322756, 9.726886844183898, 10.704791924433666, 11.653201385033642, 12.536774959293913, 13.450880662659864, 13.803507628091396, 12.795514869883723, 12.16598397279831, 13.067717777712215, 13.861292174180694, 14.895656561133272, 15.794794495703702, 16.535587439561677, 11.725899923628086, 10.831852071851522, 9.786106411824116, 8.851994647401739, 7.853825215254747, 6.890482537195058, 7.73731640740034, 8.732115561184154, 9.74752941094828, 10.629801055307897, 11.520082674905654, 12.426394604778, 13.380056172191775, 13.783999856866082, 13.129371376217415, 14.023411941748975, 14.86296552052683, 15.839072650649937, 16.773490905483033, 17.46094542197287, 10.673527242387198, 9.87296572914057, 8.87498987166149, 7.91939603862975, 6.952050993098101, 5.933157377742222, 6.792048198978161, 7.73680386565543, 8.686038969670605, 9.62681097660885, 10.552188652623624, 11.474960934970207, 12.432742043638612, 13.469949578505224, 14.084951649246117, 14.948493998937126, 15.809723893518916, 16.784118994892996, 17.776788301125016, 18.415429471121058, 9.693970860300752, 8.885352990340241, 7.8447162177845495, 6.847902403405452, 5.9823160081069995, 4.993707534927821, 5.84906605336511, 6.710960367960145, 7.675713379772763, 8.71647459153484, 9.622913123621917, 10.503292191955241, 11.462237664748473, 12.41928293908705, 13.355080126671126, 14.312777787277764, 15.352395670325485, 16.412780104796774, 17.362228127086578, 18.295024831909757, 8.713704466423636, 7.835836832465388, 6.7738227922529894, 5.889238454905376, 4.9657068835145814, 3.995861015364136, 4.847966102697597, 5.7458718465151986, 6.777571797519515, 7.769726280016345, 8.561053087194939, 9.522917059096178, 10.557279620529794, 11.541869781950522, 12.563280474478423, 13.53656911490742, 14.519142178108577, 15.423200603910235, 16.48826165269522, 17.38955807086342, 7.7729039241207305, 6.808471949208514, 5.840515829852794, 4.916228385915137, 3.9832769234464016, 2.9421700340562653, 3.833481276709888, 4.748935727669161, 5.785259771151784, 6.718907511760987, 7.614509505481492, 8.604844863756961, 9.57918959519926, 10.571978694958842, 11.550684583267664, 12.577714582405084, 13.483536285899447, 14.425837042330787, 15.431202685269174, 16.351164725968186, 6.939321664357277, 5.949834897557574, 4.910714356448031, 3.8990620420827744, 2.9409266393051263, 1.8896001714113575, 2.901505140604833, 3.7591857361004077, 4.747913934340338, 5.66165296272829, 6.662695174352923, 7.672565842010199, 8.652674675337485, 9.617358489923324, 10.609476914565924, 11.5548559933357, 12.484249591658028, 13.413885902139333, 14.40293113646634, 15.337605565032204, 5.9620469681796715, 4.939055808692013, 4.001902495447771, 2.995082705347604, 1.9404055499298818, 0.9375557327658354, 1.88050891004062, 2.8194042172283185, 3.756445490477254, 4.692212073885225, 5.765229998913515, 6.74815175514206, 7.735760572422343, 8.721497439802665, 9.779787911616381, 10.799212733088943, 11.760392339149268, 12.723877880186972, 13.672902975476939, 14.626014763089618, 5.179343668447997, 4.153763712515705, 3.124672599267933, 2.108543089378422, 1.0337348509770425, 0.0, 1.0585244453961222, 2.0944949753847184, 3.1586835880237887, 4.137288696875524, 5.093151693199721, 6.14249324100337, 7.177977181629705, 8.252903388651914, 9.206522998872115, 10.195522017797117, 11.210564754380972, 12.190872346890014, 13.205061281604221, 14.272779878644425], [13.877838396796637, 12.862454697429687, 11.871372319663516, 10.811826734878817, 9.872309353280983, 8.82185119527725, 7.840775897559896, 6.87477440588799, 5.8555449156393875, 4.916830162987675, 3.9880906884637266, 3.0306586257046195, 1.9577141495510682, 0.9478566779878925, 1.880678046365449, 2.8723603388177823, 3.9237737935048695, 4.8865022769583, 5.94634833137049, 7.014164343078769, 14.590446606945955, 13.660390163759494, 12.687749584267156, 11.74740377400508, 10.765021562263193, 9.762050521531178, 8.795552272446956, 7.810146377400716, 6.795308864985954, 5.8279284546302055, 4.827780695360503, 3.8351412326098364, 2.886946884663521, 1.8818918852090922, 2.8325380198421826, 3.811264232759019, 4.851200700930257, 5.86695470066421, 6.846258118334825, 7.861992625804472, 15.588898001399185, 14.593421757230765, 13.696854379667109, 12.696462969689124, 11.69907102975844, 10.727872095233682, 9.757844280070005, 8.756715891866097, 7.817486250541655, 6.87660024148923, 5.8187099467443, 4.781521124640651, 3.889586974468545, 2.920319333090188, 3.806967637630057, 4.841691003327782, 5.822250247694083, 6.811012477350532, 7.750524934532699, 8.77201815462611, 16.569239558468265, 15.55117610812495, 14.605657623470258, 13.553255619028668, 12.624104414309045, 11.654169272627625, 10.697779325264154, 9.7584965215919, 8.792711871293783, 7.8177707792402025, 6.8603897078588245, 5.832748914743452, 4.838394875781236, 3.862655370850786, 4.835158799013122, 5.791379865139716, 6.833064855806283, 7.786963843117502, 8.679009017609001, 9.618974878037058, 17.550850635883855, 16.501651908548585, 15.523812829462775, 14.460293391976423, 13.529598258277076, 12.602415695950798, 11.67273780637728, 10.743820590098174, 9.789964961969213, 8.816495419443465, 7.751794008829293, 6.748510815340639, 5.781994083115828, 4.847229452569612, 5.841822718923162, 6.805659578199388, 7.828549220472941, 8.71870740825268, 9.721383392592102, 10.570248297579628, 18.420050515597037, 17.449724753721544, 16.412292889916635, 15.409775168978202, 14.50714568985092, 13.602259886865152, 12.634453156755507, 11.789299602232587, 10.728133416951028, 9.697457104562053, 8.693582101122134, 7.758412097361168, 6.747037875168851, 5.848443004955843, 6.824803116265327, 7.767961162540216, 8.826808964361316, 9.754721847098914, 10.722513016144866, 11.627805034212557, 18.593510524737006, 17.6535536651282, 16.71859287322064, 15.724612103270237, 14.761618739514894, 13.994976535350364, 13.048143742746356, 12.677448066976519, 11.707841745176339, 10.683630573048815, 9.670197593496642, 8.703800711415708, 7.691999989152652, 6.904687941373603, 7.8033834751481255, 8.838473336185022, 9.862135086341887, 10.804961426716742, 11.763800640578838, 12.597518323938603, 17.693816885666745, 16.65647348673099, 15.693140778427361, 14.726339859669027, 13.72839257647931, 12.953239276021138, 11.986223907914347, 12.821063363947314, 12.660785555933964, 11.66136499830101, 10.65161483449919, 9.67541807828157, 8.677263353996723, 7.930927470526714, 8.776952141115961, 9.796735324813136, 10.744155244132005, 11.72844083468728, 12.683686659732901, 13.586171242723617, 16.76139827327435, 15.705092706235153, 14.725077981548905, 13.758227054322937, 12.802568918063383, 11.916668447257099, 11.006223784321921, 11.847701895683018, 12.827970563250704, 12.652760077324386, 11.671453121323315, 10.693766280092872, 9.71419313445095, 8.895210728893224, 9.77144412554043, 10.698894011594014, 11.632907823008265, 12.59850408908032, 13.643694531542284, 14.554211970522328, 15.746369790705295, 14.734507098234442, 13.794542891575283, 12.800466697851798, 11.857597367179538, 10.938426848209241, 10.002137724399672, 10.893160368836257, 11.882386810267615, 12.812224645488824, 12.64342756386565, 11.697437374450082, 10.757137826527602, 9.887980438157577, 10.808706454267867, 11.697249081853787, 12.607397805050436, 13.531801990623046, 14.59624906508282, 15.548221910009243, 14.736446522348626, 13.789698928362272, 12.842252258131467, 11.840459506029285, 10.814419668062476, 9.886054201732657, 8.969367957041884, 9.836979251964937, 10.855977729786574, 11.817498254315375, 12.740829614605358, 12.662597862216336, 11.80326726072675, 10.822768847166515, 11.815140778676597, 12.764884527845375, 13.627939377645209, 14.592286987080133, 15.521619498894333, 16.49406657527272, 13.848146525658438, 12.779846374792577, 11.786118349219844, 10.843652007520852, 9.816909912429361, 8.832168296700244, 7.967379664628851, 8.905607616489993, 9.88351269673976, 10.831922157339736, 11.715495731600008, 12.62960143496596, 12.801435065000566, 11.793442306792894, 12.755988887827838, 13.71061365446319, 14.58148241244746, 15.615846799400039, 16.560365776873155, 17.46487447940592, 12.784424369024208, 11.863378369813066, 10.817632709785661, 9.883520945363284, 8.84528308207681, 7.88194040401712, 6.916037179706435, 7.9108363334902485, 8.926250183254375, 9.808521827613992, 10.698803447211748, 11.605115377084095, 12.55877694449787, 12.781927293775253, 13.719376291246943, 14.66630781849995, 15.583155758793596, 16.559262888916702, 17.493681143749797, 18.390232461817114, 11.73205168778332, 10.931490174536695, 9.933514317057615, 8.950922336591294, 7.946078503436006, 6.924615244564285, 5.970768971284256, 6.915524637961525, 7.8647597419767, 8.805531748914945, 9.730909424929719, 10.653681707276302, 11.611462815944707, 12.648670350811319, 13.519313334200923, 14.544942099023228, 15.462337753623897, 16.523372526980296, 17.46759508491656, 18.492072124364775, 10.752495305696874, 9.943877435736365, 8.903240663180673, 7.906426848801574, 6.993914869048669, 5.985165401749883, 5.027786825671205, 5.88968114026624, 6.854434152078857, 7.895195363840935, 8.801633895928012, 9.682012964261336, 10.640958437054568, 11.598003711393146, 12.533800898977221, 13.491498559583858, 14.53111644263158, 15.59150087710287, 16.540948899392674, 17.473745604215853, 9.772228911819758, 8.894361277861512, 7.832347237649113, 6.947762900301498, 5.977305744456251, 5.007459876305805, 4.0266868750036915, 4.924592618821293, 5.95629256982561, 6.9484470523224395, 7.7397738595010335, 8.701637831402273, 9.736000392835889, 10.720590554256617, 11.742001246784518, 12.715289887213515, 13.697862950414672, 14.601921376216328, 15.66698242500131, 16.568278843169512, 8.831428369516853, 7.866996394604638, 6.899040275248918, 5.974752831311259, 5.041801368842524, 4.000694479452388, 3.0122020490159827, 3.9276564999752552, 4.963980543457879, 5.897628284067082, 6.793230277787587, 7.783565636063057, 8.757910367505357, 9.750699467264937, 10.729405355573759, 11.75643535471118, 12.662257058205542, 13.604557814636882, 14.609923457575269, 15.52988549827428, 7.997846109753399, 7.008359342953696, 5.9692388018441545, 4.957586487478897, 3.9994510847012488, 2.9481246168074797, 2.0802259129109277, 2.937906508406502, 3.9266347066464324, 4.840373735034385, 5.841415946659017, 6.851286614316294, 7.8313954476435805, 8.79607926222942, 9.788197686872019, 10.733576765641795, 11.662970363964122, 12.592606674445427, 13.581651908772434, 14.516326337338299, 7.0205714135757935, 5.997580254088135, 5.060426940843893, 4.053607150743726, 2.9989299953260042, 1.9960801781619577, 1.0592296823467144, 1.998124989534413, 2.9351662627833486, 3.8709328461913186, 4.94395077121961, 5.926872527448155, 6.914481344728438, 7.900218212108759, 8.958508683922476, 9.977933505395038, 10.939113111455363, 11.902598652493067, 12.851623747783034, 13.804735535395713, 6.237868113844119, 5.212288157911827, 4.183197044664055, 3.167067534774544, 2.0922592963731645, 1.0585244453961222, 0.0, 1.0359705299885962, 2.1001591426276667, 3.0787642514794022, 4.034627247803599, 5.083968795607248, 6.119452736233583, 7.194378943255792, 8.147998553475993, 9.136997572400995, 10.15204030898485, 11.132347901493892, 12.1465368362081, 13.214255433248303], [12.853391636739083, 11.838007937372133, 10.846925559605962, 9.787379974821263, 8.847862593223429, 7.797404435219696, 6.8163291375023425, 5.850327645830437, 4.831098155581834, 3.892383402930122, 2.9636439284061735, 2.006211865647066, 0.9332673894935147, 1.9431248610566905, 2.875946229434247, 3.8676285218865805, 4.919041976573667, 5.881770460027098, 6.941616514439287, 8.009432526147567, 13.565999846888403, 12.635943403701942, 11.663302824209604, 10.722957013947529, 9.740574802205641, 8.737603761473625, 7.771105512389402, 6.7856996173431625, 5.770862104928401, 4.8192204795190206, 3.8664237640886783, 2.873784301338011, 1.9255899533916958, 2.8771600682778904, 3.827806202910981, 4.806532415827817, 5.846468883999055, 6.862222883733008, 7.841526301403623, 8.85726080887327, 14.554854595531776, 13.568974997173212, 12.672407619609556, 11.672016209631572, 10.674624269700887, 9.70342533517613, 8.733397520012451, 7.732269131808543, 6.793039490484102, 5.867892266378045, 4.857353015472475, 3.820164193368826, 2.963419198476184, 3.915587516158986, 4.802235820698856, 5.83695918639658, 6.817518430762881, 7.80628066041933, 8.745793117601497, 9.767286337694909, 15.535196152600856, 14.526729348067398, 13.581210863412704, 12.528808858971114, 11.59965765425149, 10.629722512570071, 9.6733325652066, 8.734049761534346, 7.768265111236229, 6.856413847968377, 5.899032776586999, 4.871391983471627, 3.948985381394947, 4.8579235539195835, 5.83042698208192, 6.786648048208515, 7.828333038875081, 8.7822320261863, 9.6742772006778, 10.614243061105856, 16.5264038758263, 15.477205148491029, 14.499366069405221, 13.435846631918869, 12.505151498219522, 11.577968935893244, 10.648291046319725, 9.750626531996014, 8.796770903867053, 7.869905203280182, 6.810222136808596, 5.806938943319941, 4.892584588729539, 5.833318450312006, 6.8279117166655565, 7.791748575941782, 8.823542453128336, 9.713975591321477, 10.7166515756609, 11.565516480648427, 17.386007109729626, 16.42527799366399, 15.387846129859081, 14.385328408920648, 13.482698929793367, 12.577813126807598, 11.610006396697953, 10.796105544130427, 9.734939358848868, 8.755885232541356, 7.752010229101437, 6.818361782500052, 5.857628380782562, 6.8345320026982375, 7.810892114007721, 8.75405016028261, 9.81289796210371, 10.749990030167709, 11.717781199213665, 12.608225925481108, 18.3163157387028, 17.376358879093996, 16.4051648643753, 15.393616016119472, 14.448638405581477, 13.545059451799197, 12.586795052527277, 11.735876194955823, 10.766269873155643, 9.742058701028117, 8.730147278635526, 7.763750396554592, 6.802590494766363, 7.826882041308673, 8.758190561493128, 9.810893386920814, 10.834555137077679, 11.777381477452534, 12.759068823647636, 13.577939215207154, 18.506688625368476, 17.46934522643272, 16.50601251812909, 15.539211599370757, 14.54126431618104, 13.74794745227118, 12.731038291678605, 11.788875731515045, 11.719213683913269, 10.731005322762531, 9.72125515896071, 8.74505840274309, 7.787853859610434, 8.726058494385548, 9.731759227460964, 10.75154241115814, 11.698962330477007, 12.683247921032283, 13.638493746077904, 14.565258538243027, 17.57427001297608, 16.517964445936883, 15.537949721250635, 14.571098794024667, 13.615440657765113, 12.71137662350714, 11.751038168086179, 10.81551426325075, 11.795782930818435, 11.722400401785906, 10.741093445784836, 9.771183267085013, 8.82478364006466, 9.690341752752058, 10.645082407761638, 11.572532293815222, 12.506546105229473, 13.472142371301528, 14.517332813763492, 15.533299266041737, 16.559241530407025, 15.547378837936172, 14.607414631277013, 13.613338437553528, 12.670469106881269, 11.733135024459283, 10.796845900649714, 9.860972736403989, 10.850199177835346, 11.780037013056555, 11.720844550857791, 10.774854361442223, 9.867728332141313, 10.683111462016411, 11.682344736489075, 12.570887364074995, 13.481036087271644, 14.405440272844254, 15.469887347304027, 16.500520910442226, 15.549318262050356, 14.602570668064002, 13.655123997833197, 12.653331245731016, 11.627291407764206, 10.698925941434387, 9.764076133291926, 8.804791619532669, 9.823790097354305, 10.783454848447965, 11.706786208737947, 11.740014849208476, 10.913857766340461, 11.61789987102535, 12.610271802535431, 13.560015551704211, 14.501577659866417, 15.46592526930134, 16.395257781115543, 17.396668272869878, 14.661018265360168, 13.592718114494307, 12.598990088921575, 11.656523747222582, 10.629781652131092, 9.645040036401975, 8.780251404330583, 7.873419984057724, 8.851325064307492, 9.797878751472327, 10.681452325732597, 11.595558029098548, 11.921856452126246, 12.588573330651728, 13.551119911686673, 14.505744678322024, 15.455120694668668, 16.489485081621247, 17.434004059094367, 18.36747617700308, 13.634274258991738, 12.676250109514797, 11.630504449487391, 10.696392685065014, 9.65815482177854, 8.69481214371885, 7.728908919408166, 6.87864870105798, 7.894062550822106, 8.774478421746583, 9.664760041344337, 10.571071971216684, 11.524733538630459, 12.478942969957119, 13.440850201362213, 14.403097876422404, 15.375052720748572, 16.351159850871678, 17.285578105704772, 18.283424439594217, 12.58190157775085, 11.781340064504224, 10.78336420702514, 9.763794076293024, 8.758950243137736, 7.737486984266016, 6.7836407109859875, 5.881481232094115, 6.83071633610929, 7.771488343047534, 8.696866019062307, 9.61963830140889, 10.577419410077296, 11.614626944943907, 12.485269928333512, 13.510898693155816, 14.428294347756486, 15.489329121112887, 16.433551679049145, 17.45802871849736, 11.602345195664403, 10.793727325703893, 9.753090553148201, 8.7562767387691, 7.8067866087504, 6.798037141451615, 5.840658565372936, 4.85563773439883, 5.820390746211448, 6.861151957973526, 7.7675904900606, 8.647969558393925, 9.606915031187157, 10.563960305525734, 11.49975749310981, 12.457455153716447, 13.497073036764169, 14.557457471235459, 15.506905493525263, 16.439702198348442, 10.622078801787287, 9.74421116782904, 8.682197127616641, 7.797612790269026, 6.790177484157982, 5.820331616007536, 4.839558614705423, 3.8905492129538835, 4.922249163958201, 5.91440364645503, 6.705730453633623, 7.667594425534862, 8.701956986968478, 9.686547148389206, 10.707957840917109, 11.681246481346106, 12.663819544547263, 13.56787797034892, 14.632939019133902, 15.534235437302105, 9.681278259484383, 8.716846284572167, 7.748890165216446, 6.8246027212787865, 5.891651258810052, 4.848628123906637, 3.8453792398540427, 2.8936130941078457, 3.9299371375904695, 4.8635848781996724, 5.759186871920177, 6.749522230195646, 7.723866961637945, 8.716656061397527, 9.69536194970635, 10.72239194884377, 11.628213652338133, 12.570514408769473, 13.575880051707859, 14.495842092406871, 8.847695999720928, 7.858209232921224, 6.819088691811682, 5.807436377446425, 4.849300974668777, 3.7979745067750086, 2.913403103748988, 1.9038631025390926, 2.892591300779023, 3.806330329166975, 4.807372540791607, 5.817243208448883, 6.79735204177617, 7.76203585636201, 8.75415428100461, 9.699533359774385, 10.628926958096713, 11.558563268578018, 12.547608502905025, 13.48228293147089, 7.870421303543322, 6.8474301440556635, 5.910276830811422, 4.903457040711255, 3.848779885293533, 2.8459300681294866, 1.902976890854702, 0.9640815836670034, 1.901122856915939, 2.836889440323909, 3.9099073653522, 4.8928291215807445, 5.880437938861028, 6.866174806241348, 7.924465278055065, 8.943890099527627, 9.905069705587952, 10.868555246625656, 11.817580341915622, 12.770692129528301, 7.273838643832715, 6.248258687900423, 5.219167574652651, 4.20303806476314, 3.128229826361761, 2.0944949753847184, 1.0359705299885962, 0.0, 1.0641886126390703, 2.0427937214908063, 2.998656717815003, 4.047998265618652, 5.083482206244987, 6.158408413267196, 7.112028023487397, 8.1010270424124, 9.116069778996254, 10.096377371505296, 11.110566306219503, 12.178284903259707], [11.813079925763628, 10.797696226396678, 9.806613848630507, 8.747068263845808, 7.807550882247973, 6.75709272424424, 5.776017426526886, 4.810015934854981, 3.7907864446063786, 2.8520716919546656, 1.9233322174307173, 1.0292305735373763, 1.997456002132585, 3.0073134736957607, 3.9401348420733173, 4.931817134525651, 5.983230589212738, 6.945959072666168, 8.005805127078357, 9.073621138786637, 12.525688135912945, 11.595631692726485, 10.622991113234146, 9.682645302972071, 8.700263091230184, 7.697292050498168, 6.730793801413947, 5.745387906367706, 4.730550393952945, 3.7789087685435643, 2.9567535047145954, 1.9641140419639282, 2.9123083899102435, 3.917363389364673, 4.868009523997763, 5.846735736914599, 6.886672205085837, 7.917573958429354, 8.896877376099969, 9.816901585231392, 13.529257917393107, 12.528663286197755, 11.6320959086341, 10.631704498656115, 9.63431255872543, 8.663113624200673, 7.693085809036996, 6.691957420833087, 5.752727779508645, 4.827580555402589, 3.9476827560983914, 2.910493933994743, 3.942263114085198, 4.911530755463555, 5.842439141785638, 6.877162507483362, 7.857721751849663, 8.861631735115676, 9.801144192297842, 10.741997369556081, 14.532173518187038, 13.486417637091941, 12.540899152437248, 11.488497147995659, 10.559345943276035, 9.589410801594616, 8.633020854231145, 7.693738050558888, 6.727953400260772, 5.872528532672607, 4.989362517212917, 3.9617217240975444, 4.927829297003961, 5.853866793224153, 6.826370221386489, 7.797031227246803, 8.849716213396825, 9.837583100882645, 10.729628275374145, 11.582533965164416, 15.486092164850843, 14.436893437515574, 13.459054358429766, 12.395534920943414, 11.464839787244067, 10.537657224917789, 9.60797933534427, 8.710314821020557, 7.756459192891596, 6.886019887984412, 5.900551877434513, 4.897268683945859, 5.8637854161706695, 6.804519277753136, 7.799112544106687, 8.762949403382914, 9.794743280569467, 10.769326666017822, 11.772002650357246, 12.49239695002413, 16.403041313608213, 15.384966282688536, 14.347534418883626, 13.345016697945193, 12.442387218817911, 11.537501415832143, 10.569694685722498, 9.75579383315497, 8.69462764787341, 7.846214973167274, 6.8423399697273535, 5.90869152312597, 6.828829208223692, 7.805732830139368, 8.782092941448852, 9.72525098772374, 10.78409878954484, 11.805341104864056, 12.77313227391001, 13.508764589666285, 17.276004027727346, 16.33604716811854, 15.364853153399844, 14.353304305144016, 13.408326694606021, 12.504747740823742, 11.546483341551822, 10.7065125317062, 9.73690620990602, 8.832388441654034, 7.820477019261444, 6.85408013718051, 7.773791322207494, 8.798082868749804, 9.729391388934259, 10.782094214361944, 11.80575596451881, 12.748582304893665, 13.753251802813885, 14.478477879392331, 18.206632659707708, 17.33312734651575, 16.390305248193123, 15.362264258266222, 14.441552857641607, 13.546485000152968, 12.608403176383831, 11.648134089099717, 10.689850020663647, 9.82133506338845, 8.811584899586629, 7.83538814336901, 8.759054687051565, 9.697259321826678, 10.702960054902094, 11.72274323859927, 12.670163157918138, 13.654448748473413, 14.609694573519034, 15.465797202428204, 18.474808677161253, 17.418503110122057, 16.43848838543581, 15.471637458209845, 14.51597932195029, 13.611915287692318, 12.651576832271356, 11.716052927435927, 11.075938946667941, 10.812730142411825, 9.831423186410754, 8.861513007710933, 9.795984467505791, 10.661542580193188, 11.616283235202769, 12.543733121256352, 13.477746932670604, 14.443343198742658, 15.488533641204622, 16.433837930226915, 17.459780194592202, 16.44791750212135, 15.50795329546219, 14.513877101738705, 13.571007771066446, 12.63367368864446, 11.697384564834891, 10.761511400589166, 10.1295544061977, 10.90847363564555, 10.811174291483711, 9.865184102068143, 10.838929159582444, 11.654312289457541, 12.653545563930205, 13.542088191516125, 14.452236914712774, 15.376641100285385, 16.441088174745158, 17.40414192456268, 16.449856926235533, 15.50310933224918, 14.555662662018374, 13.553869909916193, 12.527830071949383, 11.599464605619564, 10.664614797477103, 9.705330283717846, 9.075532375194038, 9.906895537535089, 10.733242326425252, 10.830344589834397, 11.822865444591198, 12.58910069846648, 13.581472629976561, 14.531216379145341, 15.472778487307547, 16.43712609674247, 17.366458608556673, 18.349986589826155, 15.561556929545345, 14.493256778679484, 13.499528753106752, 12.55706241140776, 11.530320316316269, 10.545578700587152, 9.68079006851576, 8.773958648242902, 8.00949767930336, 8.92131944055945, 9.707908443419901, 10.622014146785855, 11.476407779660317, 12.48440053786799, 13.430693722468623, 14.385248158146469, 15.386757852431373, 16.390583670690198, 17.329534613974776, 18.235238539692716, 14.534812923176915, 13.576788773699974, 12.531043113672569, 11.596931349250191, 10.558693485963717, 9.595350807904028, 8.629447583593343, 7.779187365243157, 7.052235165817974, 7.897919110833706, 8.691216159031642, 9.59752808890399, 10.551189656317764, 11.505399087644424, 12.467306319049518, 13.429553994109709, 14.401508838435877, 15.377615968558985, 16.31203422339208, 17.309880557281524, 13.482440241936027, 12.681878728689401, 11.683902871210318, 10.664332740478201, 9.659488907322913, 8.638025648451192, 7.684179375171164, 6.782019896279293, 5.982815296768956, 6.894929032134657, 7.723322136749612, 8.646094419096197, 9.6038755277646, 10.641083062631212, 11.511726046020817, 12.537354810843121, 13.45475046544379, 14.515785238800191, 15.460007796736452, 16.48448483618467, 12.50288385984958, 11.69426598988907, 10.653629217333378, 9.656815402954278, 8.707325272935575, 7.698575805636791, 6.741197229558113, 5.756176398584007, 4.955298441473419, 5.964969051241519, 6.794046607747905, 7.67442567608123, 8.633371148874462, 9.590416423213039, 10.526213610797114, 11.483911271403752, 12.523529154451474, 13.583913588922764, 14.533361611212568, 15.466158316035747, 11.522617465972465, 10.644749832014217, 9.582735791801818, 8.698151454454203, 7.690716148343158, 6.720870280192712, 5.740097278890599, 4.79108787713906, 3.979588409122389, 4.940859764142335, 5.732186571320928, 6.694050543222167, 7.7284131046557825, 8.71300326607651, 9.722585354482373, 10.69587399491137, 11.678447058112527, 12.582505483914183, 13.647566532699164, 14.548862950867367, 10.58181692366956, 9.617384948757344, 8.649428829401623, 7.725141385463964, 6.792189922995229, 5.749166788091814, 4.74591790403922, 3.7941517582930224, 2.9872763827546573, 3.8900409958869773, 4.7856429896074815, 5.775978347882951, 6.75032307932525, 7.731283574962792, 8.709989463271613, 9.737019462409034, 10.642841165903397, 11.585141922334737, 12.590507565273123, 13.510469605972135, 9.748234663906105, 8.758747897106401, 7.71962735599686, 6.707975041631602, 5.749839638853954, 4.698513170960186, 3.8139417679341645, 2.8044017667242693, 1.9190474184663282, 2.8327864468542803, 3.8338286584789123, 4.843699326136188, 5.811979555341435, 6.776663369927275, 7.768781794569874, 8.71416087333965, 9.643554471661977, 10.573190782143282, 11.562236016470289, 12.496910445036153, 8.7709599677285, 7.747968808240841, 6.810815494996599, 5.803995704896432, 4.74931854947871, 3.7464687323146633, 2.803515555039879, 1.86462024785218, 0.9275789746032442, 1.8633455580112144, 2.8807861759274846, 3.8637079321560295, 4.851316749436313, 5.837053616816633, 6.89534408863035, 7.914768910102912, 8.875948516163236, 9.83943405720094, 10.788459152490907, 11.741570940103585, 8.338027256471785, 7.3124473005394925, 6.283356187291721, 5.267226677402211, 4.192418439000831, 3.1586835880237887, 2.1001591426276667, 1.0641886126390703, 0.0, 0.9786051088517358, 1.9344681051759327, 2.9838096529795815, 4.019293593605917, 5.094219800628125, 6.047839410848326, 7.0368384297733275, 8.051881166357182, 9.032188758866225, 10.046377693580432, 11.114096290620635], [10.834474816911891, 9.819091117544941, 8.82800873977877, 7.7684631549940715, 6.828945773396237, 5.778487615392504, 4.797412317675151, 3.8314108260032453, 2.8121813357546426, 1.8734665831029296, 0.9447271085789813, 1.9021591713380888, 2.97510364749164, 3.984961119054816, 4.917782487432373, 5.909464779884706, 6.960878234571793, 7.923606718025224, 8.983452772437413, 10.051268784145693, 11.54708302706121, 10.61702658387475, 9.644386004382412, 8.704040194120337, 7.721657982378449, 6.718686941646433, 5.7521886925622105, 4.766782797515971, 3.7519452851012094, 2.8003036596918283, 2.014611937624519, 2.8370426397646407, 3.785236987710956, 4.790291987165385, 5.740938121798475, 6.719664334715311, 7.759600802886549, 8.790502556230066, 9.769805973900683, 10.781900312578955, 12.550652808541372, 11.55005817734602, 10.653490799782364, 9.65309938980438, 8.655707449873695, 7.684508515348937, 6.714480700185259, 5.713352311981351, 4.77412267065691, 3.8489754465508534, 3.0714742072393157, 3.7834225317954555, 4.81519171188591, 5.784459353264267, 6.71536773958635, 7.750091105284074, 8.730650349650375, 9.734560332916388, 10.674072790098554, 11.695566010191966, 13.553568409335304, 12.507812528240207, 11.562294043585513, 10.509892039143923, 9.580740834424299, 8.610805692742879, 7.654415745379409, 6.715132941707153, 5.749348291409037, 4.893923423820872, 4.137724230297365, 4.834650321898256, 5.800757894804673, 6.726795391024865, 7.699298819187201, 8.669959825047515, 9.722644811197537, 10.710511698683357, 11.602556873174857, 12.542522733602913, 14.507487055999109, 13.458288328663839, 12.480449249578031, 11.416929812091679, 10.486234678392332, 9.559052116066052, 8.629374226492533, 7.731709712168821, 6.77785408403986, 5.907414779132677, 5.110386643451979, 5.7701972817465705, 6.7367140139713815, 7.677447875553848, 8.672041141907398, 9.635878001183624, 10.667671878370177, 11.642255263818534, 12.644931248157958, 13.457395677371693, 15.424436204756478, 14.406361173836801, 13.368929310031891, 12.366411589093458, 11.463782109966177, 10.558896306980406, 9.591089576870761, 8.777188724303235, 7.716022539021676, 6.874684510753818, 6.05217473574482, 6.781620120926682, 7.701757806024404, 8.67866142794008, 9.655021539249564, 10.598179585524452, 11.657027387345552, 12.678269702664767, 13.646060871710722, 14.473763317013848, 16.297398918875608, 15.357442059266804, 14.38624804454811, 13.374699196292282, 12.429721585754287, 11.526142631972006, 10.567878232700085, 9.727907422854466, 8.758301101054286, 7.8608579792405795, 7.048250966086853, 7.727008734981222, 8.646719920008206, 9.671011466550516, 10.60231998673497, 11.655022812162656, 12.678684562319521, 13.621510902694377, 14.626180400614597, 15.443476606739894, 17.22802755085597, 16.35452223766401, 15.411700139341386, 14.383659149414488, 13.462947748789873, 12.567879891301232, 11.629798067532095, 10.669528980247982, 9.711244911811912, 8.855494268104135, 8.114399065341079, 8.708316741169721, 9.631983284852277, 10.57018791962739, 11.575888652702806, 12.595671836399982, 13.54309175571885, 14.527377346274125, 15.482623171319746, 16.430795929775766, 18.160446163248366, 17.291295195377568, 16.311280470691322, 15.344429543465354, 14.3887714072058, 13.604450720065271, 12.578414353347705, 11.642890448512276, 10.713353161465283, 9.84688934712751, 9.134237352165204, 9.734441605511643, 10.668913065306503, 11.5344711779939, 12.48921183300348, 13.416661719057064, 14.350675530471316, 15.31627179654337, 16.361462239005334, 17.398836657574474, 18.424778921939765, 17.412916229468916, 16.472952022809753, 15.47887582908627, 14.536006498414011, 13.598672415992024, 12.662383292182454, 11.726510127936729, 10.931777031398381, 10.001939196177172, 10.187092303578144, 10.738112699868854, 11.711857757383155, 12.527240887258253, 13.526474161730917, 14.415016789316837, 15.325165512513486, 16.2495696980861, 17.31401677254587, 18.34465033568407, 17.414855653583096, 16.468108059596744, 15.520661389365939, 14.518868637263758, 13.492828799296948, 12.56446333296713, 11.629613524824666, 10.670329011065409, 10.010888146592643, 9.000361098066712, 9.79042618128465, 10.633416797152002, 11.541590320305499, 12.512257852353766, 13.504629783863848, 14.454373533032626, 15.397484742093022, 16.462402832436027, 17.425464746813, 18.263230298685315, 16.52655565689291, 15.458255506027049, 14.464527480454317, 13.522061138755324, 12.495319043663834, 11.510577427934717, 10.645788795863323, 9.738957375590465, 8.944853450701965, 8.014785001091074, 8.7650922982793, 9.679198001645252, 10.533591634519714, 11.541584392727387, 12.487877577328021, 13.442432013005867, 14.44394170729077, 15.447767525549596, 16.386718468834175, 17.292422394552112, 15.499811650524478, 14.541787501047537, 13.496041841020133, 12.561930076597756, 11.523692213311282, 10.560349535251593, 9.594446310940906, 8.74418609259072, 7.987590937216579, 6.99138467136533, 7.748400013891039, 8.654711943763388, 9.608373511177161, 10.562582942503822, 11.524490173908916, 12.486737848969106, 13.458692693295275, 14.434799823418382, 15.369218078251476, 16.36706441214092, 14.44743896928359, 13.646877456036965, 12.648901598557881, 11.629331467825766, 10.624487634670478, 9.603024375798757, 8.649178102518727, 7.747018623626856, 6.9181710681675606, 5.988394592666281, 6.78050599160901, 7.703278273955595, 8.661059382623998, 9.69826691749061, 10.568909900880215, 11.594538665702519, 12.511934320303189, 13.550395523110708, 14.49461808104697, 15.519095120495185, 13.467882587197144, 12.659264717236633, 11.618627944680942, 10.621814130301841, 9.672324000283139, 8.663574532984356, 7.706195956905677, 6.721175125931571, 5.890654212872024, 5.058434611773143, 5.851230462607302, 6.731609530940628, 7.690555003733859, 8.647600278072437, 9.583397465656512, 10.54109512626315, 11.580713009310871, 12.618523873233281, 13.567971895523085, 14.500768600346264, 12.487616193320028, 11.60974855936178, 10.547734519149381, 9.663150181801766, 8.655714875690721, 7.685869007540276, 6.705096006238163, 5.756086604486624, 4.914944180520994, 4.034325324673959, 4.789370426180325, 5.751234398081564, 6.78559695951518, 7.770187120935908, 8.743980245630638, 9.717268886059635, 10.69984194926079, 11.603900375062448, 12.66896142384743, 13.570257842015632, 11.546815651017123, 10.582383676104907, 9.614427556749186, 8.690140112811527, 7.757188650342792, 6.714165515439378, 5.710916631386784, 4.759150485640586, 3.9226321541532627, 2.9835065564186016, 3.842826844466878, 4.833162202742347, 5.807506934184646, 6.752678466111057, 7.731384354419878, 8.7584143535573, 9.66423605705166, 10.606536813483, 11.611902456421387, 12.531864497120399, 10.71323339125367, 9.723746624453966, 8.684626083344423, 7.6729737689791655, 6.714838366201517, 5.66351189830775, 4.778940495281729, 3.7694004940718338, 2.8544031898649336, 1.9262520073859046, 2.891012513338308, 3.8906065175944318, 4.8333744464896995, 5.798058261075539, 6.790176685718138, 7.735555764487914, 8.66494936281024, 9.594585673291546, 10.583630907618552, 11.518305336184417, 9.735958695076064, 8.712967535588405, 7.775814222344162, 6.768994432243995, 5.714317276826273, 4.711467459662227, 3.768514282387443, 2.8296189751997445, 1.8925777019508088, 0.9568111185428387, 1.9021810670757486, 2.8851028233042935, 3.872711640584577, 4.858448507964898, 5.916738979778614, 6.936163801251176, 7.8973434073115, 8.860828948349205, 9.809854043639172, 10.76296583125185, 9.316632365323521, 8.291052409391229, 7.261961296143458, 6.245831786253946, 5.171023547852567, 4.137288696875524, 3.0787642514794022, 2.0427937214908063, 0.9786051088517358, 0.0, 0.9558629963241968, 2.0052045441278454, 3.04068848475418, 4.115614691776389, 5.069234301996589, 6.058233320921591, 7.0732760575054465, 8.053583650014488, 9.067772584728695, 10.135491181768899], [9.997975194696624, 8.982591495329673, 7.991509117563503, 6.931963532778804, 5.992446151180969, 4.941987993177236, 3.960912695459882, 2.994911203787977, 1.975681713539374, 1.0369669608876613, 1.9005901049031781, 2.8580221676622855, 3.930966643815837, 4.940824115379012, 5.873645483756569, 6.865327776208902, 7.9167412308959895, 8.87946971434942, 9.93931576876161, 11.007131780469889, 10.710583404845941, 9.780526961659481, 8.807886382167142, 7.867540571905068, 6.88515836016318, 5.882187319431164, 4.915689070346943, 3.930283175300702, 2.915445662885941, 1.96380403747656, 2.963951796746262, 3.7929056360888374, 4.741099984035153, 5.746154983489582, 6.696801118122672, 7.675527331039509, 8.715463799210747, 9.746365552554263, 10.725668970224879, 11.737763308903155, 11.635014003921107, 10.713558555130751, 9.816991177567095, 8.81659976758911, 7.819207827658426, 6.8480088931336685, 5.8779810779699915, 4.876852689766083, 3.9376230484416412, 3.012475824335585, 4.020814066361059, 4.739285528119652, 5.771054708210106, 6.740322349588463, 7.671230735910547, 8.705954101608272, 9.686513345974573, 10.690423329240584, 11.62993578642275, 12.651429006516162, 12.615355560990187, 11.671312906024937, 10.725794421370246, 9.673392416928655, 8.744241212209031, 7.774306070527612, 6.817916123164141, 5.878633319491884, 4.912848669193768, 4.057423801605603, 5.014804872986981, 5.790513318222453, 6.756620891128869, 7.682658387349061, 8.655161815511397, 9.62582282137171, 10.678507807521731, 11.666374695007553, 12.558419869499053, 13.49838572992711, 13.660647162078348, 12.621788706448571, 11.643949627362764, 10.580430189876411, 9.649735056177065, 8.722552493850785, 7.792874604277267, 6.895210089953553, 5.9413544618245915, 5.070915156917408, 5.987467286141595, 6.726060278070767, 7.692577010295578, 8.633310871878043, 9.627904138231594, 10.59174099750782, 11.623534874694373, 12.59811826014273, 13.600794244482154, 14.413258673695891, 14.491210515403251, 13.569861551621534, 12.532429687816624, 11.52991196687819, 10.62728248775091, 9.72239668476514, 8.754589954655495, 7.9406891020879655, 6.8795229168064065, 6.03818488853855, 6.929255378434436, 7.7374831172508785, 8.657620802348601, 9.634524424264274, 10.610884535573758, 11.554042581848647, 12.612890383669747, 13.634132698988964, 14.601923868034918, 15.429626313338048, 15.46089929666034, 14.520942437051536, 13.549748422332842, 12.538199574077014, 11.593221963539019, 10.68964300975674, 9.73137861048482, 8.891407800639197, 7.921801478839017, 7.024358357025311, 7.925331608776469, 8.682871731305418, 9.602582916332402, 10.626874462874712, 11.558182983059167, 12.610885808486852, 13.634547558643717, 14.577373899018573, 15.582043396938793, 16.399339603064092, 16.363232225903957, 15.518022615448745, 14.575200517126119, 13.54715952719922, 12.626448126574605, 11.731380269085966, 10.793298445316829, 9.833029358032713, 8.874745289596643, 8.018994645888867, 8.991479708030695, 9.664179737493917, 10.587846281176473, 11.526050915951586, 12.531751649027003, 13.551534832724178, 14.498954752043046, 15.483240342598322, 16.438486167643944, 17.386658926099965, 17.295650838296353, 16.4547955731623, 15.474780848476055, 14.507929921250087, 13.552271784990532, 12.767951097850005, 11.741914731132438, 10.806390826297008, 9.876853539250014, 9.010389724912242, 10.01131799485482, 10.69030460183584, 11.6247760616307, 12.490334174318097, 13.445074829327677, 14.37252471538126, 15.306538526795512, 16.272134792867565, 17.317325235329527, 18.354699653898674, 18.3381001474621, 17.42286524192058, 16.42224334026694, 15.440112666546636, 14.497243335874376, 13.682289914864256, 12.746000791054687, 11.760932353143769, 10.823238079720255, 10.00507750979953, 9.822497711676553, 10.642714288594057, 11.631856758180449, 12.491183265038506, 13.492603603167797, 14.420230572677005, 15.430155685732167, 16.41091735988751, 17.394972184300315, 18.253211967624594, 18.370718649907293, 17.42397105592094, 16.476524385690134, 15.474731633587954, 14.448691795621144, 13.520326329291326, 12.585476521148863, 11.626192007389605, 10.764414258935526, 9.734315321928461, 8.834563184960452, 9.677553800827804, 10.5857273239813, 11.556394856029568, 12.54876678753965, 13.49851053670843, 14.441621745768824, 15.506539836111827, 16.4696017504888, 17.30736730236112, 17.48241865321711, 16.414118502351247, 15.420390476778513, 14.47792413507952, 13.45118203998803, 12.466440424258913, 11.601651792187521, 10.694820371914663, 9.698379563044847, 8.748739224952823, 7.809229301955101, 8.723335005321054, 9.577728638195516, 10.585721396403189, 11.532014581003823, 12.486569016681669, 13.488078710966573, 14.491904529225398, 15.430855472509975, 16.336559398227916, 16.455674646848678, 15.497650497371733, 14.45190483734433, 13.517793072921952, 12.479555209635478, 11.516212531575789, 10.550309307265104, 9.700049088914918, 8.741117049559461, 7.725338895227079, 6.792537017566841, 7.698848947439191, 8.652510514852963, 9.606719946179624, 10.568627177584718, 11.530874852644908, 12.502829696971077, 13.478936827094184, 14.413355081927278, 15.411201415816723, 15.403301965607788, 14.60274045236116, 13.60476459488208, 12.585194464149962, 11.580350630994674, 10.558887372122953, 9.605041098842925, 8.702881619951054, 7.779512645060474, 6.83874063812223, 5.824642995284812, 6.747415277631397, 7.7051963862998, 8.74240392116641, 9.613046904556017, 10.63867566937832, 11.55607132397899, 12.594532526786512, 13.538755084722773, 14.56323212417099, 14.423745583521342, 13.615127713560831, 12.57449094100514, 11.577677126626039, 10.628186996607335, 9.619437529308552, 8.662058953229874, 7.677038122255768, 6.84651720919622, 5.908780657229093, 4.895367466283105, 5.77574653461643, 6.734692007409661, 7.691737281748238, 8.627534469332314, 9.585232129938952, 10.624850012986673, 11.662660876909085, 12.612108899198889, 13.544905604022068, 13.443479189644226, 12.565611555685978, 11.50359751547358, 10.619013178125964, 9.611577872014918, 8.641732003864472, 7.66095900256236, 6.711949600810821, 5.87080717684519, 4.884671370129908, 3.8335074298561276, 4.795371401757366, 5.829733963190982, 6.81432412461171, 7.78811724930644, 8.761405889735437, 9.743978952936594, 10.648037378738252, 11.713098427523233, 12.614394845691436, 12.502678647341321, 11.538246672429105, 10.570290553073384, 9.646003109135725, 8.71305164666699, 7.670028511763574, 6.66677962771098, 5.7150134819647835, 4.878495150477459, 3.9393695527427983, 2.8869638481426807, 3.87729920641815, 4.851643937860449, 5.79681546978686, 6.775521358095681, 7.802551357233101, 8.708373060727464, 9.650673817158804, 10.65603946009719, 11.576001500796202, 11.669096387577868, 10.679609620778164, 9.64048907966862, 8.628836765303364, 7.670701362525715, 6.619374894631947, 5.734803491605925, 4.72526349039603, 3.8102661861891303, 2.8821150037101013, 1.9351495170141113, 2.934743521270235, 3.877511450165503, 4.842195264751342, 5.834313689393941, 6.7796927681637165, 7.709086366486044, 8.63872267696735, 9.627767911294356, 10.56244233986022, 10.691821691400262, 9.668830531912603, 8.731677218668361, 7.7248574285681935, 6.670180273150471, 5.667330455986424, 4.72437727871164, 3.785481971523941, 2.8484406982750055, 1.9126741148670354, 0.9463180707515518, 1.9292398269800966, 2.91684864426038, 3.9025855116407007, 4.960875983454417, 5.980300804926979, 6.941480410987303, 7.904965952025008, 8.853991047314974, 9.807102834927653, 10.272495361647717, 9.246915405715425, 8.217824292467654, 7.201694782578143, 6.126886544176764, 5.093151693199721, 4.034627247803599, 2.998656717815003, 1.9344681051759327, 0.9558629963241968, 0.0, 1.0493415478036487, 2.084825488429984, 3.1597516954521927, 4.113371305672393, 5.102370324597395, 6.11741306118125, 7.097720653690293, 8.1119095884045, 9.179628185444702], [8.954615214847308, 7.939231515480358, 6.9481491377141875, 5.888603552929489, 4.949086171331654, 3.8986280133279214, 2.917552715610568, 1.951551223938662, 0.9323217336900592, 1.871036486341772, 2.7997759608657202, 3.7572080236248278, 4.830152499778379, 5.840009971341554, 6.772831339719111, 7.764513632171444, 8.815927086858531, 9.778655570311962, 10.838501624724152, 11.906317636432432, 9.667223424996628, 8.737166981810168, 7.764526402317829, 6.824180592055755, 5.8417983803138664, 4.83882733958185, 3.872329090497628, 2.886923195451387, 1.8720856830366257, 2.797873562930671, 3.7980213222003734, 4.69209149205138, 5.640285839997695, 6.645340839452124, 7.595986974085214, 8.57471318700205, 9.614649655173288, 10.645551408516805, 11.624854826187422, 12.640589333657068, 10.67079320647679, 9.670198575281438, 8.77363119771778, 7.773239787739796, 6.7758478478091115, 5.804648913284354, 4.834621098120676, 3.8334927099167677, 2.894263068592326, 3.8465453497896958, 4.85488359181517, 5.6384713840821945, 6.670240564172649, 7.639508205551006, 8.570416591873089, 9.605139957570813, 10.585699201937114, 11.589609185203127, 12.529121642385293, 13.550614862478705, 11.662693828650285, 10.627952926175624, 9.682434441520929, 8.63003243707934, 7.700881232359717, 6.730946090678297, 5.774556143314826, 4.835273339642569, 3.869488689344453, 4.855616990681383, 5.812998062062761, 6.689699174184995, 7.655806747091412, 8.581844243311604, 9.55434767147394, 10.525008677334252, 11.577693663484274, 12.565560550970096, 13.457605725461596, 14.397571585889652, 12.627627453934526, 11.578428726599256, 10.600589647513448, 9.537070210027096, 8.60637507632775, 7.67919251400147, 6.749514624427952, 5.8518501101042375, 4.897994481975276, 5.869108345993188, 6.785660475217375, 7.6252461340333095, 8.59176286625812, 9.532496727840586, 10.527089994194137, 11.490926853470363, 12.522720730656916, 13.497304116105273, 14.499980100444697, 15.348845005432223, 13.538548783063346, 12.526501571772219, 11.489069707967309, 10.486551987028875, 9.583922507901594, 8.679036704915825, 7.71122997480618, 6.89732912223865, 5.836162936957091, 6.836378077614329, 7.727448567510216, 8.636668973213421, 9.556806658311144, 10.533710280226817, 11.510070391536301, 12.45322843781119, 13.51207623963229, 14.533318554951506, 15.50110972399746, 16.406401742065153, 14.417539316811025, 13.477582457202221, 12.506388442483527, 11.494839594227699, 10.549861983689704, 9.646283029907424, 8.688018630635504, 7.848047820789882, 6.878441498989702, 7.82255154610109, 8.723524797852248, 9.582057587267961, 10.501768772294945, 11.526060318837255, 12.45736883902171, 13.510071664449395, 14.53373341460626, 15.476559754981116, 16.481229252901336, 17.376115031791198, 15.348167948791385, 14.47466263559943, 13.531840537276803, 12.503799547349905, 11.583088146725288, 10.68802028923665, 9.749938465467514, 8.789669378183397, 7.831385309747327, 8.817187834964646, 9.789672897106474, 10.56336559345646, 11.487032137139016, 12.425236771914129, 13.430937504989545, 14.45072068868672, 15.398140608005589, 16.382426198560864, 17.337672023606487, 18.347217989671783, 16.28058656118378, 15.411435593312985, 14.431420868626738, 13.46456994140077, 12.508911805141215, 11.72459111800069, 10.69855475128312, 9.763030846447691, 8.833493559400699, 9.80858291398802, 10.8095111839306, 10.862804788367159, 11.84237793400908, 12.70037237971875, 13.65511303472833, 14.582562920781914, 15.516576732196166, 16.48217299826822, 17.45550702943633, 18.35520221870699, 17.334328497018113, 16.379505262071262, 15.378883360417623, 14.396752686697319, 13.45388335602506, 12.63892993501494, 11.70264081120537, 10.717572373294452, 9.77987809987094, 10.709715935092149, 10.805123883425516, 9.859133694009948, 10.84827616359634, 11.707602670454397, 12.709023008583689, 13.636649978092896, 14.635147910166438, 15.61590958432178, 16.502952495895794, 17.361192279220074, 18.271061025929786, 17.324313431943434, 16.415720023286273, 15.436154158972885, 14.497061055142122, 13.70679971532562, 12.73303800392503, 11.773753490165772, 10.833900130874602, 10.783656869732111, 9.883904732764101, 8.893973206243695, 9.802146729397192, 10.77281426144546, 11.747185196799927, 12.682019746858584, 13.614606337571663, 14.656425752145736, 15.577582062084279, 16.415347613956598, 18.531760201020752, 17.463460050154893, 16.46973202458216, 15.527265682883169, 14.500523587791678, 13.51578197206256, 12.65099333999117, 11.744161919718312, 10.747721110848497, 9.798080772756473, 8.85857084975875, 7.9397544107369455, 8.794148043611408, 9.80214080181908, 10.706408609041395, 11.66096304471924, 12.661063302769412, 13.599884840820877, 14.538835784105455, 15.444539709823395, 17.505016194652327, 16.546992045175383, 15.501246385147978, 14.5671346207256, 13.528896757439126, 12.565554079379437, 11.599650855068752, 10.749390636718568, 9.790458597363111, 8.774680443030729, 7.84187856537049, 6.915268352855081, 7.8689299202688545, 8.823139351595515, 9.74302120562229, 10.70526888068248, 11.659389956423276, 12.586917138689664, 13.521335393522758, 14.519181727412203, 16.452643513411438, 15.65208200016481, 14.654106142685727, 13.63453601195361, 12.629692178798322, 11.608228919926601, 10.654382646646573, 9.752223167754703, 8.828854192864123, 7.888082185925879, 6.873984543088461, 5.9638346830472875, 6.921615791715691, 7.9588233265823005, 8.787440932593588, 9.79523592883052, 10.71263158343119, 11.641870794446607, 12.586093352382868, 13.610570391831084, 15.47308713132499, 14.664469261364479, 13.623832488808787, 12.627018674429687, 11.677528544410984, 10.6687790771122, 9.711400501033522, 8.726379670059417, 7.8958587569998695, 6.958122205032741, 5.944709014086754, 4.99216594003232, 5.951111412825552, 6.908156687164128, 7.801928497369885, 8.74179238939115, 9.781410272438873, 10.70999914456918, 11.659447166858984, 12.592243871682163, 14.492820737447873, 13.614953103489626, 12.552939063277227, 11.668354725929612, 10.660919419818567, 9.691073551668122, 8.710300550366009, 7.76129114861447, 6.92014872464884, 5.934012917933557, 4.882848977659776, 4.011790807173257, 4.996918882836544, 5.863964573731664, 6.835455516966538, 7.808744157395536, 8.79131722059669, 9.695375646398347, 10.760436695183328, 11.661733113351534, 13.55202019514497, 12.587588220232753, 11.619632100877032, 10.695344656939373, 9.762393194470638, 8.719370059567224, 7.71612117551463, 6.764355029768432, 5.927836698281109, 4.988711100546447, 3.93630539594633, 3.044275254616624, 3.98629413864173, 4.844153737446957, 5.822859625755778, 6.849889624893199, 7.7557113283875605, 8.6980120848189, 9.703377727757287, 10.623339768456301, 12.718437935381516, 11.728951168581812, 10.689830627472269, 9.678178313107011, 8.720042910329363, 7.668716442435596, 6.784145039409575, 5.774605038199679, 4.859607733992779, 3.93145655151375, 2.9844910648177603, 2.0752110505068377, 2.9248497178256, 3.889533532411439, 4.881651957054038, 5.827031035823814, 6.756424634146141, 7.686060944627447, 8.675106178954454, 9.60978060752032, 11.74116323920391, 10.71817207971625, 9.781018766472009, 8.774198976371842, 7.719521820954119, 6.716672003790073, 5.773718826515289, 4.83482351932759, 3.897782246078654, 2.962015662670684, 1.9956596185552007, 1.0697073562166994, 1.9641869119204773, 2.949923779300798, 4.008214251114515, 5.0270204067444455, 5.98820001280477, 6.951685553842474, 7.90071064913244, 8.85382243674512, 11.321836909451367, 10.296256953519075, 9.267165840271304, 8.251036330381792, 7.176228091980413, 6.14249324100337, 5.083968795607248, 4.047998265618652, 2.9838096529795815, 2.0052045441278454, 1.0493415478036487, 0.0, 1.035483940626335, 2.1104101476485435, 3.0640297578687443, 4.053028776793747, 5.068071513377602, 6.048379105886645, 7.062568040600852, 8.130286637641056], [7.930405969720393, 6.915022270353443, 5.923939892587272, 4.864394307802573, 3.924876926204738, 2.874418768201005, 1.8933434704836514, 0.9273419788117458, 1.9465714690603486, 2.8852862217120614, 3.8140256962360097, 4.771457758995117, 5.844402235148669, 6.8542597067118445, 7.787081075089401, 8.778763367541735, 9.830176822228822, 10.792905305682252, 11.852751360094441, 12.92056737180272, 8.64301417986971, 7.71295773668325, 6.740317157190912, 5.799971346928838, 4.8175891351869495, 3.8146180944549335, 2.8481198453707117, 1.9965451771023928, 2.886335418406915, 3.81212329830096, 4.812271057570662, 5.706341227421669, 6.6545355753679845, 7.659590574822413, 8.610236709455505, 9.58896292237234, 10.628899390543578, 11.659801143887094, 12.63910456155771, 13.654839069027357, 9.646583961349872, 8.64598933015452, 7.749421952590863, 6.749030542612879, 5.751638602682195, 4.780439668157437, 3.8104118529937603, 2.9431146915677737, 3.901932928127664, 4.860795085159985, 5.869133327185459, 6.652721119452484, 7.684490299542938, 8.653757940921295, 9.58466632724338, 10.619389692941104, 11.599948937307405, 12.603858920573416, 13.543371377755582, 14.564864597848993, 10.62720988802395, 9.603743681048707, 8.658225196394014, 7.605823191952425, 6.676671987232801, 5.706736845551381, 4.75034689818791, 3.9448953212935756, 4.877158548879791, 5.863286850216721, 6.8206679215980985, 7.703948909555285, 8.670056482461701, 9.596093978681893, 10.568597406844228, 11.539258412704541, 12.591943398854562, 13.579810286340384, 14.471855460831884, 15.411821321259941, 11.603418208807609, 10.55421948147234, 9.576380402386532, 8.51286096490018, 7.582165831200833, 6.654983268874554, 5.725305379301036, 4.984116195251279, 5.905664341510614, 6.876778205528526, 7.793330334752713, 8.6394958694036, 9.60601260162841, 10.546746463210876, 11.541339729564427, 12.505176588840653, 13.536970466027206, 14.511553851475561, 15.514229835814985, 16.363094740802513, 12.503064842437011, 11.502292326645302, 10.464860462840392, 9.462342741901958, 8.559713262774677, 7.654827459788907, 6.687020729679263, 6.043801798240553, 6.84383279649243, 7.844047937149667, 8.735118427045554, 9.650918708583712, 10.571056393681435, 11.54796001559711, 12.524320126906593, 13.467478173181481, 14.526325975002582, 15.547568290321795, 16.515359459367748, 17.42065147743544, 13.393330071684108, 12.453373212075304, 11.48217919735661, 10.470630349100782, 9.525652738562787, 8.622073784780508, 7.663809385508587, 7.052926629822002, 7.88611135852504, 8.830221405636427, 9.731194657387586, 10.596307322638252, 11.516018507665235, 12.540310054207545, 13.471618574392, 14.524321399819685, 15.54798314997655, 16.490809490351406, 17.49547898827163, 18.390364767161486, 14.323958703664468, 13.450453390472513, 12.507631292149886, 11.479590302222988, 10.558878901598373, 9.663811044109734, 8.725729220340597, 8.009739582688894, 8.839055169282666, 9.824857694499983, 10.797342756641813, 11.57761532882675, 11.988749874917819, 12.708315286223975, 13.693264667291515, 14.604026459448695, 15.551446378767563, 16.53573196932284, 17.482627919663766, 18.287759005879362, 15.256377316056865, 14.38722634818607, 13.407211623499823, 12.440360696273855, 11.4847025600143, 10.700381872873773, 9.705729343933022, 8.983101050953188, 9.841163418936038, 10.816252773523358, 11.817181043465938, 11.657068348386872, 10.951820094463592, 11.744032027857466, 12.698772682867046, 13.62622256892063, 14.560236380334882, 15.513723545238172, 16.42002308880999, 17.319718278080654, 16.310119251891194, 15.355296016944346, 14.354674115290708, 13.372543441570404, 12.429674110898144, 11.646104527664841, 10.709815403855272, 9.937642577799949, 10.787547959406279, 11.717385794627488, 11.599387443445229, 10.653397254029661, 9.90887540238694, 10.751262318593113, 11.74839242521227, 12.676019394721477, 13.599663969540103, 14.580425643695445, 15.467468555269457, 16.32570833859374, 17.246851780802867, 16.300104186816515, 15.391510778159358, 14.41194491384597, 13.472851810015207, 12.713974307975521, 11.74258517121306, 10.993823694671269, 11.84156999040994, 11.595615519128293, 10.695863382160281, 9.688236766263408, 8.862745968187792, 9.816473909584175, 10.711701256173592, 11.646535806232249, 12.579122396945328, 13.620941811519401, 14.542098121457943, 15.379863673330263, 18.178349391080662, 17.30995674038621, 16.44764468707098, 15.468397801088084, 14.49586730358299, 13.760172842280976, 12.744573463626093, 11.925195330146213, 11.559679760244679, 10.610039422152655, 9.67052949915493, 8.734017970756659, 7.854747282402007, 8.845800449957796, 9.67092466841506, 10.625479104092905, 11.625579362143077, 12.564400900194542, 13.50335184347912, 14.40905576919706, 18.515252001812904, 17.55722785233596, 16.511482192308556, 15.577370427886178, 14.539132564599704, 13.575789886540015, 12.60988666222933, 11.61783109652342, 10.602417246759293, 9.58663909242691, 8.653837214766671, 7.7095319128747954, 6.929529159059454, 7.857315462975437, 8.707537264995954, 9.669784940056145, 10.62390601579694, 11.551433198063329, 12.485851452896423, 13.483697786785868, 17.462879320572014, 16.662317807325387, 15.664341949846307, 14.644771819114188, 13.6399279859589, 12.61846472708718, 11.664618453807151, 10.626352144728585, 9.67711704071341, 8.736345033775166, 7.6859431924846415, 6.758098243067002, 5.982215030506291, 6.924075487379583, 7.751956991967252, 8.759751988204185, 9.677147642804854, 10.606386853820272, 11.550609411756533, 12.575086451204749, 16.483322938485568, 15.674705068525057, 14.634068295969366, 13.637254481590265, 12.687764351571563, 11.679014884272778, 10.7216363081941, 9.736615477219996, 8.804058344378172, 7.843191566467175, 6.829778375521188, 5.7864295000520345, 5.011710651616152, 5.873408847961411, 6.76644455674355, 7.7063084487648155, 8.745926331812537, 9.674515203942844, 10.623963226232648, 11.556759931055828, 15.503056544608452, 14.625188910650204, 13.563174870437805, 12.67859053309019, 11.671155226979145, 10.7013093588287, 9.720536357526587, 8.771526955775048, 7.828348312027142, 6.819082279367991, 5.76791833909421, 4.806054367192971, 3.9614349422102095, 4.828480633105329, 5.799971576340202, 6.7732602167692, 7.755833279970355, 8.659891705772012, 9.724952754556993, 10.626249172725199, 14.562256002305547, 13.597824027393331, 12.62986790803761, 11.70558046409995, 10.772629001631216, 9.7296058667278, 8.726356982675206, 7.7745908369290095, 6.871088062477659, 5.893918013518649, 4.828874172911807, 3.8385388146363377, 2.950810198015395, 3.8086697968206225, 4.787375685129443, 5.814405684266863, 6.720227387761225, 7.6625281441925654, 8.667893787130952, 9.587855827829966, 13.728673742542092, 12.739186975742388, 11.700066434632847, 10.68841412026759, 9.730278717489941, 8.678952249596172, 7.794380846570151, 6.7848408453602564, 5.808538672287488, 4.880387489808459, 3.879345278183828, 2.8694746105265514, 1.8893657771992651, 2.8540495917851043, 3.8461680164277032, 4.791547095197479, 5.720940693519806, 6.650577004001112, 7.639622238328119, 8.574296666893984, 12.751399046364487, 11.728407886876827, 10.791254573632585, 9.784434783532419, 8.729757628114697, 7.72690781095065, 6.783954633675866, 5.845059326488167, 4.908018053239232, 3.972251469831262, 2.899233544802971, 1.916311788574426, 0.9287029712941424, 1.914439838674463, 2.9727303104881795, 3.99153646611811, 4.9527160721784345, 5.916201613216139, 6.865226708506105, 7.818338496118784, 12.357320850077702, 11.33174089414541, 10.302649780897639, 9.286520271008127, 8.211712032606748, 7.177977181629705, 6.119452736233583, 5.083482206244987, 4.019293593605917, 3.0406884847541806, 2.084825488429984, 1.035483940626335, 0.0, 1.0749262070222085, 2.028545817242409, 3.0175448361674113, 4.032587572751266, 5.012895165260309, 6.027084099974516, 7.094802697014719], [6.954685472619568, 5.939301773252618, 4.948219395486448, 3.8886738107017487, 2.949156429103914, 1.898698271100181, 0.9588205652273821, 1.9248220568992878, 2.9440515471478905, 3.8827662997996035, 4.811505774323551, 5.7689378370826585, 6.84188231323621, 7.851739784799386, 8.784561153176941, 9.776243445629275, 10.827656900316361, 11.790385383769792, 12.850231438181982, 13.918047449890262, 7.667293682768886, 6.737237239582425, 5.7645966600900875, 4.824250849828013, 3.8418686380861256, 2.8388975973541095, 1.9135969401144424, 2.955017998872989, 3.8838154964944573, 4.809603376388502, 5.809751135658204, 6.70382130550921, 7.652015653455526, 8.657070652909955, 9.607716787543046, 10.586443000459882, 11.62637946863112, 12.657281221974635, 13.636584639645251, 14.652319147114898, 8.670863464249047, 7.6702688330536954, 6.773701455490039, 5.773310045512056, 4.775918105581371, 3.8047191710566137, 2.875888947737491, 3.9015875133383697, 4.86040574989826, 5.8582751632475265, 6.866613405273001, 7.650201197540025, 8.68197037763048, 9.651238019008836, 10.58214640533092, 11.616869771028645, 12.597429015394946, 13.601338998660957, 14.540851455843123, 15.562344675936535, 9.673779065042979, 8.628023183947882, 7.710912819423253, 6.671300286696155, 5.742149081976532, 4.772213940295112, 3.815823992931641, 4.845457564955956, 5.829265535638851, 6.8153938369757805, 7.7727749083571585, 8.701428987642826, 9.667536560549243, 10.593574056769434, 11.56607748493177, 12.536738490792082, 13.589423476942104, 14.577290364427926, 15.469335538919426, 16.409301399347484, 10.66889530355134, 9.61969657621607, 8.641857497130262, 7.57833805964391, 6.647642925944564, 5.720460363618285, 4.790782474044766, 5.829621758863977, 6.783477386992939, 7.756946929518687, 8.745437321511773, 9.636975947491141, 10.603492679715952, 11.544226541298418, 12.538819807651969, 13.502656666928194, 14.534450544114748, 15.509033929563103, 16.51170991390253, 17.360574818890054, 11.561309587480908, 10.567769421389032, 9.530337557584122, 8.527819836645689, 7.625190357518408, 6.720304554532638, 5.752497824422994, 6.784888370784303, 7.721645841974754, 8.72421666113983, 9.687225413804613, 10.631420492736432, 11.568536471768976, 12.54544009368465, 13.521800204994134, 14.464958251269023, 15.523806053090123, 16.545048368409336, 17.512839537455292, 18.418131555522983, 12.458807166427839, 11.518850306819035, 10.54765629210034, 9.536107443844513, 8.591129833306518, 7.687550879524237, 6.729286480252318, 7.780567618806755, 8.750173940606935, 9.71039012962659, 10.683301644146646, 11.576809106790972, 12.513498585752776, 12.905392592645521, 13.836701112829976, 14.82368158620029, 15.648220181303461, 16.59104652167832, 17.4904885743549, 18.334656669708274, 13.389435798408199, 12.515930485216243, 11.573108386893617, 10.545067396966719, 9.624355996342103, 8.729288138853464, 7.791206315084327, 8.737380571673647, 9.695664640109717, 10.705026418490146, 11.714776582291966, 12.55811711297947, 12.817357698267523, 11.87915306349241, 12.86410244455995, 13.753599210279244, 14.681506897999993, 15.663004031225881, 16.540872664707663, 17.34600375092326, 14.321854410800595, 13.452703442929801, 12.472688718243553, 11.505837791017585, 10.55017965475803, 9.765858967617504, 8.771206438676753, 9.706730343512183, 10.686999011079868, 11.696421497513521, 12.714335314347645, 12.71297432337755, 11.841370583648336, 10.914869805125901, 11.869610460135481, 12.775795319751179, 13.656593624197631, 14.59616321785353, 15.47826783385389, 16.37796302312455, 15.375596346634927, 14.420773111688076, 13.420151210034438, 12.438020536314134, 11.495151205641875, 10.711581622408572, 9.775292498599002, 10.661271870358943, 11.633383551550109, 12.563221386771318, 12.655293418435907, 11.709303229020339, 10.898456650339211, 9.922100095861548, 10.849813279982198, 11.777440249491406, 12.682103642155461, 13.662865316310803, 14.525713300313354, 15.383953083637634, 16.312328875546598, 15.365581281560246, 14.456987872903088, 13.4774220085897, 12.538328904758938, 11.779451402719252, 10.80806226595679, 11.717452987230264, 12.68740558255377, 12.65152149411897, 11.751769357150959, 10.744142741254086, 9.852327216140063, 8.98731168685261, 9.813122110943521, 10.747411767405426, 11.661562069560686, 12.679186556563298, 13.60034286650184, 14.43810841837416, 17.243826485824393, 16.37543383512994, 15.51312178181471, 14.533874895831815, 13.561344398326721, 12.825649937024707, 11.810050558369824, 12.648824622705206, 12.615585735235356, 11.665945397143332, 10.726435474145608, 9.789923945747336, 8.844328530354279, 8.016638227226231, 8.772345523184988, 9.726355065266082, 10.708019034758435, 11.622645645238439, 12.561596588523017, 13.467300514240957, 18.276988030174547, 17.411632268614845, 16.440922966234442, 15.506811201812063, 14.532971228679273, 13.77587782970783, 12.86139304329224, 12.673737071514097, 11.65832322174997, 10.642545067417588, 9.709743189757349, 8.765437887865472, 7.9191104070117255, 7.0281532402438724, 7.808958119765884, 8.770660901229322, 9.706345688412299, 10.609677943107226, 11.54409619794032, 12.541942531829765, 18.518785295562694, 17.718223782316066, 16.720247924836983, 15.700677794104864, 14.695833960949576, 13.674370702077855, 12.720524428797827, 11.682258119719263, 10.733023015704088, 9.792251008765843, 8.74184916747532, 7.814004218057679, 6.971796278458562, 6.094913264648018, 6.853377846737183, 7.845578844041171, 8.759587315420212, 9.664631598864169, 10.60885415680043, 11.633331196248646, 17.539228913476247, 16.730611043515736, 15.689974270960043, 14.693160456580943, 13.743670326562238, 12.734920859263454, 11.777542283184776, 10.792521452210671, 9.85996431936885, 8.899097541457852, 7.885684350511865, 6.842335475042712, 6.001291899568423, 5.044246625229846, 5.86786541151348, 6.792135304601802, 7.828366004427896, 8.732759948986741, 9.682207971276545, 10.615004676099725, 16.55896251959913, 15.681094885640881, 14.619080845428483, 13.734496508080868, 12.727061201969821, 11.757215333819376, 10.776442332517263, 9.827432930765724, 8.88425428701782, 7.8749882543586684, 6.823824314084888, 5.861960342183648, 4.983908571794492, 3.9993184103737645, 4.901392431110133, 5.8590870726061866, 6.814078025014252, 7.718136450815909, 8.783197499600892, 9.684493917769096, 15.618161977296225, 14.653730002384009, 13.685773883028288, 12.761486439090628, 11.828534976621894, 10.785511841718478, 9.782262957665884, 8.830496811919687, 7.926994037468337, 6.949823988509327, 5.884780147902486, 4.894444789627016, 4.006716173006073, 2.9795075740890575, 3.8887965398993734, 4.9002325401038505, 5.778472132805122, 6.720772889236462, 7.72613853217485, 8.646100572873863, 14.784579717532772, 13.795092950733068, 12.755972409623524, 11.744320095258267, 10.786184692480619, 9.734858224586851, 8.850286821560829, 7.840746820350934, 6.864444647278168, 5.936293464799139, 4.935251253174506, 3.92538058551723, 2.945271752189943, 2.0248873690535394, 2.9475888711976337, 3.8497918402413758, 4.779185438563703, 5.708821749045009, 6.697866983372016, 7.632541411937882, 13.807305021355166, 12.784313861867506, 11.847160548623265, 10.840340758523098, 9.785663603105375, 8.782813785941329, 7.839860608666544, 6.900965301478845, 5.9639240282299095, 5.0281574448219395, 3.955139519793649, 2.972217763565104, 1.9846089462848207, 0.9988720789044999, 1.936731510007868, 2.9166102590959015, 3.877789865156226, 4.8412754061939305, 5.790300501483896, 6.743412289096575, 13.432247057099909, 12.406667101167617, 11.377575987919846, 10.361446478030334, 9.286638239628955, 8.252903388651912, 7.19437894325579, 6.158408413267194, 5.0942198006281245, 4.115614691776389, 3.1597516954521923, 2.1104101476485435, 1.0749262070222085, 0.0, 0.9536196102202008, 1.942618629145203, 2.9576613657290585, 3.937968958238101, 4.952157892952308, 6.019876489992512], [6.0010658623993685, 4.9856821630324175, 3.994599785266247, 2.935054200481548, 1.9955368188837133, 0.9450786608799803, 1.9124401754475828, 2.878441667119488, 3.897671157368091, 4.8363859100198034, 5.765125384543752, 6.722557447302859, 7.79550192345641, 8.805359395019586, 9.738180763397143, 10.729863055849476, 11.781276510536562, 12.744004993989993, 13.803851048402183, 14.871667060110463, 6.713674072548685, 5.783617629362225, 4.810977049869887, 3.870631239607813, 2.8882490278659247, 1.885277987133909, 2.867216550334643, 3.90863760909319, 4.837435106714658, 5.763222986608702, 6.7633707458784045, 7.657440915729411, 8.605635263675726, 9.610690263130156, 10.561336397763247, 11.540062610680083, 12.579999078851321, 13.610900832194837, 14.590204249865453, 15.6059387573351, 7.717243854028847, 6.716649222833495, 5.820081845269838, 4.819690435291855, 3.8222984953611703, 2.851099560836413, 3.8295085579576917, 4.8552071235585705, 5.81402536011846, 6.811894773467727, 7.820233015493201, 8.603820807760226, 9.63558998785068, 10.604857629229038, 11.535766015551122, 12.570489381248846, 13.551048625615147, 14.554958608881158, 15.494471066063324, 16.515964286156738, 8.72015945482278, 7.674403573727682, 6.757293209203052, 5.7278285102697035, 4.79867730555008, 3.8287421638686605, 4.769443603151841, 5.799077175176157, 6.782885145859051, 7.769013447195981, 8.726394518577358, 9.655048597863027, 10.621156170769444, 11.547193666989635, 12.51969709515197, 13.490358101012283, 14.543043087162305, 15.530909974648127, 16.42295514913963, 17.362921009567685, 9.71604831571136, 8.66684958837609, 7.7350659985694, 6.689444157566593, 5.758749023867247, 4.831566461540968, 5.744402084264967, 6.783241369084177, 7.737096997213138, 8.710566539738887, 9.699056931731972, 10.590595557711342, 11.557112289936153, 12.497846151518619, 13.49243941787217, 14.456276277148396, 15.488070154334949, 16.462653539783304, 17.46532952412273, 18.314194429110255, 10.607689977260709, 9.674027864693878, 8.641443655506805, 7.6389259345683715, 6.7362964554410905, 5.8449123647042835, 6.706117434643195, 7.7385079810045045, 8.675265452194953, 9.677836271360029, 10.640845024024813, 11.585040102956631, 12.522156081989177, 13.499059703904852, 13.880097007764538, 14.823255054039427, 15.769178743096106, 16.690401933601624, 17.57815658856867, 18.350750349214117, 11.569913264350522, 10.629956404741717, 9.658762390023023, 8.647213541767195, 7.7022359312292, 6.812158689695883, 7.682906090472519, 8.734187229026956, 9.703793550827136, 10.66400973984679, 11.636921254366845, 12.530428717011171, 13.467118195972978, 13.66442473185696, 12.90151664888174, 13.870061975980091, 14.69460057108326, 15.637426911458116, 16.536868964134698, 17.381037059488072, 12.500541896330882, 11.627036583138926, 10.6842144848163, 9.656173494889401, 8.735462094264786, 7.853895949025109, 8.744825925304529, 9.691000181893848, 10.649284250329918, 11.658646028710345, 12.668396192512166, 13.51173672319967, 13.576389837478962, 12.638185202703848, 11.927947982913905, 12.799979600059045, 13.727887287779792, 14.70938442100568, 15.587253054487462, 16.392384140703058, 13.432960508723278, 12.563809540852484, 11.583794816166236, 10.616943888940268, 9.661285752680714, 8.890466777789149, 9.724826048896954, 10.660349953732384, 11.640618621300069, 12.65004110773372, 13.667954924567844, 13.579975868501695, 12.600402722859773, 11.673901944337338, 10.933455998489436, 11.82217570953098, 12.70297401397743, 13.642543607633328, 14.524648223633688, 15.42434341290435, 14.48670244455761, 13.531879209610759, 12.531257307957121, 11.549126634236817, 10.606257303564558, 9.868708376837006, 10.728912108819204, 11.614891480579145, 12.58700316177031, 13.516840996991519, 13.546886576860214, 12.600896387444646, 11.704253013986719, 10.681132235072985, 9.896193669761999, 10.823820639271206, 11.72848403193526, 12.709245706090602, 13.572093690093153, 14.430333473417434, 15.384618471744583, 14.476687379482929, 13.568093970825771, 12.588528106512383, 11.64943500268162, 10.936578157147686, 11.761681876176992, 12.671072597450465, 13.641025192773972, 13.57521975508542, 12.675467618117409, 11.635735899678393, 10.65812357978757, 9.746343826064047, 8.859502500723321, 9.793792157185225, 10.707942459340487, 11.725566946343099, 12.64672325628164, 13.48448880815396, 16.31611608202238, 15.486539933052624, 14.624227879737393, 13.644980993754498, 12.672450496249404, 11.990464062180099, 12.763670168590025, 13.602444232925407, 13.539283996201807, 12.589643658109782, 11.650133735112059, 10.681517104171643, 9.650124894001786, 8.775670366437668, 7.818725912964788, 8.772735455045881, 9.754399424538235, 10.66902603501824, 11.607976978302817, 12.513680904020758, 17.323368419954345, 16.52273836653753, 15.552029064157123, 14.617917299734746, 13.644077326601955, 12.940691954863222, 13.815012653512442, 13.597435332480547, 12.58202148271642, 11.566243328384038, 10.633441450723799, 9.688866038458176, 8.724906770659233, 7.787185379455309, 6.855338509545683, 7.817041291009121, 8.752726078192099, 9.656058332887026, 10.59047658772012, 11.588322921609565, 18.37574110119523, 17.572989716302892, 16.537187698857817, 15.550515908506735, 14.65480751896682, 13.898017114316058, 13.674144039018028, 12.605956380685713, 11.656721276670538, 10.715949269732294, 9.66554742844177, 8.73770247902413, 7.77759264210607, 6.853945403859455, 5.899758236516981, 6.8919592338209705, 7.805967705200013, 8.71101198864397, 9.65523454658023, 10.679711586028446, 18.49284852369645, 17.684230653735938, 16.643593881180244, 15.646780066801142, 14.69728993678244, 13.688540469483655, 12.731161893404977, 11.746141062430873, 10.813583929589052, 9.852717151678055, 8.8124761837462, 7.766033736009162, 6.807088263215931, 5.850042988877354, 4.914245801293279, 5.838515694381601, 6.874746394207697, 7.779140338766542, 8.728588361056346, 9.661385065879525, 17.512582129819332, 16.63471449586108, 15.572700455648683, 14.688116118301068, 13.680680812190023, 12.710834944039577, 11.730061942737464, 10.781052540985925, 9.837873897238023, 8.82860786457887, 7.777443924305089, 6.81557995240385, 5.9375281820146935, 4.952938020593965, 3.9477728208899316, 4.905467462385986, 5.860458414794053, 6.764516840595709, 7.82957788938069, 8.730874307548895, 16.571781587516426, 15.607349612604208, 14.639393493248487, 13.715106049310828, 12.782154586842093, 11.739131451938679, 10.735882567886085, 9.784116422139887, 8.880613647688538, 7.9034435987295275, 6.838399758122686, 5.848064399847217, 4.960335783226274, 3.933127184309258, 2.935176929679172, 3.9466129298836496, 4.824852522584922, 5.767153279016262, 6.772518921954649, 7.692480962653662, 15.73819932775297, 14.748712560953265, 13.709592019843724, 12.697939705478467, 11.739804302700819, 10.68847783480705, 9.80390643178103, 8.794366430571134, 7.818064257498367, 6.889913075019338, 5.888870863394707, 4.87900019573743, 3.898891362410144, 2.9785069792737398, 1.9939692609774327, 2.896172230021175, 3.8255658283435023, 4.755202138824808, 5.744247373151815, 6.678921801717681, 14.760924631575364, 13.737933472087704, 12.800780158843462, 11.793960368743296, 10.739283213325574, 9.736433396161528, 8.793480218886744, 7.854584911699046, 6.917543638450111, 5.981777055042141, 4.908759130013849, 3.925837373785305, 2.9382285565050212, 1.9524916891247006, 0.9831118997876671, 1.9629906488757007, 2.9241702549360253, 3.88765579597373, 4.836680891263696, 5.789792678876375, 14.38586666732011, 13.360286711387818, 12.331195598140047, 11.315066088250536, 10.240257849849156, 9.206522998872114, 8.147998553475992, 7.112028023487396, 6.047839410848326, 5.06923430199659, 4.113371305672393, 3.0640297578687443, 2.028545817242409, 0.9536196102202008, 0.0, 0.9889990189250022, 2.004041755508857, 2.9843493480178998, 3.998538282732107, 5.066256879772311], [5.024567487091845, 4.009183787724895, 3.0181014099587253, 1.9671576178981711, 1.0276402363003365, 1.9340776798049824, 2.901439194372585, 3.8674406860444908, 4.8866701762930935, 5.825384928944806, 6.754124403468754, 7.7115564662278615, 8.784500942381413, 9.79435841394459, 10.727179782322146, 11.71886207477448, 12.770275529461566, 13.733004012914996, 14.792850067327187, 15.860666079035466, 5.7510586668375305, 4.847814051201054, 3.875173471708716, 2.9348276614466418, 1.9567944498069354, 2.874277006058911, 3.8562155692596454, 4.897636628018192, 5.82643412563966, 6.752222005533705, 7.752369764803407, 8.646439934654413, 9.59463428260073, 10.59968928205516, 11.55033541668825, 12.529061629605087, 13.568998097776324, 14.59989985111984, 15.579203268790456, 16.594937776260103, 6.757412329332687, 5.780845644672324, 4.900231025277803, 3.899839615299819, 2.9024476753691344, 3.840098579761415, 4.818507576882694, 5.844206142483573, 6.803024379043463, 7.8008937923927295, 8.809232034418205, 9.592819826685227, 10.624589006775683, 11.59385664815404, 12.524765034476125, 13.55948840017385, 14.54004764454015, 15.543957627806162, 16.48347008498833, 17.50496330508174, 7.742836003922644, 6.738599995566511, 5.8374423892110165, 4.850222679680567, 3.9210714749609443, 4.817741182793663, 5.758442622076844, 6.788076194101159, 7.771884164784054, 8.758012466120984, 9.715393537502361, 10.64404761678803, 11.610155189694446, 12.536192685914637, 13.508696114076972, 14.479357119937285, 15.532042106087307, 16.519908993573132, 17.411954168064632, 18.35192002849269, 8.78024473755019, 7.731046010214919, 6.815215178577365, 5.837400000337497, 4.906704866638151, 5.82056548046597, 6.733401103189969, 7.77224038800918, 8.726096016138142, 9.69956555866389, 10.688055950656976, 11.579594576636344, 12.546111308861155, 13.48684517044362, 14.481438436797172, 15.040973355960523, 15.82158217701538, 16.737417353522858, 17.59028719319643, 18.419308066922046, 9.618690958335705, 8.738224286532706, 7.789399498277709, 6.786881777339276, 5.884252298211995, 6.833911383629285, 7.695116453568197, 8.727506999929506, 9.664264471119957, 10.666835290285032, 11.629844042949816, 12.574039121881635, 13.511155100914179, 14.488058722829852, 14.738680036653053, 13.991148880599763, 14.780179724171106, 15.701402914676624, 16.589157569643668, 17.361751330289117, 10.642177359808068, 9.702220500199264, 8.806718232793928, 7.7951693845381, 6.850191774000105, 7.8011577086208845, 8.671905109397521, 9.723186247951958, 10.692792569752138, 11.653008758771794, 12.625920273291849, 13.519427735936175, 14.45611721489798, 14.523007760745474, 13.760099677770254, 12.920636706954957, 13.70560155215826, 14.648427892533116, 15.547869945209694, 16.392038040563072, 11.551354712771793, 10.699300678596472, 9.832170327587205, 8.804129337660305, 7.88341793703569, 8.823154198446488, 9.73382494422953, 10.67999920081885, 11.63828326925492, 12.647645047635349, 13.65739521143717, 14.500735742124673, 14.434972866367476, 13.496768231592362, 12.786531011802419, 11.85055433103391, 12.738888268854792, 13.72038540208068, 14.598254035562459, 15.403385121778056, 12.48377332516419, 11.653387226350652, 10.73175065893714, 9.764899731711171, 8.809241595451617, 9.791495203543342, 10.713825067821956, 11.649348972657386, 12.62961764022507, 13.639040126658724, 14.656953943492848, 14.43855889739021, 13.458985751748289, 12.532484973225854, 11.79203902737795, 10.872750440505845, 11.71397499505243, 12.653544588708328, 13.535649204708685, 14.435344393979346, 13.526222634329937, 12.679835052381662, 11.679213150728025, 10.697082477007719, 9.75421314633546, 10.735484154913827, 11.671773278723396, 12.603890499504146, 13.576002180695312, 14.50584001591652, 14.40546960574873, 13.459479416333162, 12.562836042875235, 11.5397152639615, 10.754776698650513, 9.874395370246072, 10.73948501301026, 11.720246687165602, 12.58309467116815, 13.44133445449243, 14.395619452819579, 13.624643222253832, 12.716049813596676, 11.736483949283285, 10.797390845452522, 11.725756311782341, 12.704543046081184, 13.660071616375467, 14.630024211698974, 14.433802783973936, 13.534050647005925, 12.494318928566909, 11.516706608676087, 10.604926854952563, 9.718085529611836, 8.804793138260221, 9.718943440415485, 10.736567927418095, 11.657724237356636, 12.495489789228957, 15.327117063097374, 14.634495775823527, 13.772183722508299, 12.7929368365254, 11.820406339020305, 12.779642216814754, 13.706531338494218, 14.59144325185041, 14.397867025090322, 13.448226686998298, 12.508716764000575, 11.54010013306016, 10.508707922890302, 9.634253395326184, 8.677308941853303, 7.783736436120878, 8.765400405613233, 9.680027016093236, 10.618977959377814, 11.524681885095754, 16.334369401029345, 15.670694209308433, 14.699984906928025, 13.765873142505647, 12.792033169372857, 13.729870109497877, 14.700004296966307, 14.456018361369063, 13.440604511604937, 12.424826357272554, 11.492024479612315, 10.547449067346692, 9.583489799547749, 8.645768408343825, 7.713921538434199, 6.828042272084119, 7.763727059267097, 8.667059313962023, 9.601477568795117, 10.599323902684562, 17.38674208227023, 16.720945559073794, 15.685143541628719, 14.698471751277637, 13.802763361737721, 14.687195268950713, 14.532860377723896, 13.464539409574229, 12.515304305559054, 11.57453229862081, 10.524130457330285, 9.596285507912645, 8.636175670994586, 7.712528432747971, 6.758341265405497, 5.902960214895968, 6.81696868627501, 7.722012969718965, 8.666235527655227, 9.690712567103443, 18.366298464356678, 17.708558297874124, 16.71541719550566, 15.739410075590772, 14.772498346728824, 14.676388682425598, 13.71901010634692, 12.688800108085912, 11.724047096273294, 10.742961938082605, 9.671059212634717, 8.624616764897679, 7.665671292104447, 6.70862601776587, 5.772828830181795, 4.849516675456599, 5.885747375282694, 6.790141319841538, 7.739589342131342, 8.672386046954522, 18.501581148744332, 17.62371351478608, 16.561699474573683, 15.67711513722607, 14.669679831115022, 13.699833962964577, 12.719060961662464, 11.770051559910925, 10.748337063922264, 9.739071031263114, 8.687907090989333, 7.726043119088093, 6.8036919172495, 5.819101755828772, 4.8063558497784475, 3.916468443460984, 4.87145939586905, 5.775517821670706, 6.840578870455689, 7.741875288623893, 17.560780606441426, 16.59634863152921, 15.62839251217349, 14.70410506823583, 13.771153605767095, 12.72813047086368, 11.724881586811087, 10.773115441064888, 9.791076814372781, 8.81390676541377, 7.74886292480693, 6.75852756653146, 5.838934500762672, 4.799290919544065, 3.793759958567688, 2.9576139109586475, 3.8358535036599197, 4.778154260091259, 5.783519903029647, 6.703481943728661, 16.727198346677973, 15.737711579878269, 14.698591038768726, 13.686938724403468, 12.72880332162582, 11.677476853732053, 10.792905450706032, 9.783365449496136, 8.72852742418261, 7.800376241703582, 6.79933403007895, 5.789463362421674, 4.809354529094387, 3.8446707145085472, 2.8525522898659483, 1.9071732110961728, 2.8365668094185, 3.7662031198998056, 4.755248354226813, 5.689922782792679, 15.749923650500367, 14.726932491012708, 13.789779177768466, 12.7829593876683, 11.728282232250576, 10.72543241508653, 9.782479237811746, 8.843583930624048, 7.9065426573751125, 6.9707760739671425, 5.897758148938852, 4.914836392710307, 3.9272275754300234, 2.941490708049703, 1.9721109187126693, 0.9739916299506987, 1.9351712360110231, 2.8986567770487275, 3.8476818723386934, 4.800793659951372, 15.374865686245114, 14.349285730312822, 13.32019461706505, 12.30406510717554, 11.22925686877416, 10.195522017797117, 9.136997572400995, 8.1010270424124, 7.036838429773328, 6.058233320921593, 5.102370324597396, 4.053028776793747, 3.0175448361674118, 1.942618629145203, 0.9889990189250022, 0.0, 1.0150427365838552, 1.9953503290928976, 3.0095392638071043, 4.077257860847308], [4.009524750507991, 2.9941410511410402, 2.00305867337487, 1.0403530004042085, 1.9798703820020431, 2.9491204163888374, 3.91648193095644, 4.882483422628345, 5.901712912876948, 6.840427665528661, 7.769167140052609, 8.726599202811716, 9.799543678965268, 10.809401150528444, 11.742222518906, 12.733904811358334, 13.78531826604542, 14.748046749498851, 15.807892803911042, 16.875708815619323, 4.851065876893552, 3.9210094337070913, 2.9483688542147535, 2.0080230439526794, 2.909024595508642, 3.889319742642766, 4.871258305843501, 5.912679364602047, 6.841476862223515, 7.767264742117559, 8.76741250138726, 9.661482671238268, 10.609677019184584, 11.614732018639014, 12.565378153272105, 13.544104366188941, 14.584040834360179, 15.614942587703695, 16.59424600537431, 17.609980512843954, 5.854635658373713, 4.854041027178361, 4.0000357842636385, 3.0284777909213556, 3.8546778210708412, 4.825876755595599, 5.833550313466549, 6.859248879067428, 7.818067115627318, 8.815936528976584, 9.824274771002058, 10.607862563269082, 11.639631743359537, 12.608899384737894, 13.53980777105998, 14.574531136757704, 15.555090381124005, 16.559000364390016, 17.498512821572184, 18.520006041665596, 6.857551259167646, 5.811795378072548, 4.937247148196851, 4.039049776297623, 4.873301620662652, 5.803519358627846, 6.759909305991317, 7.789542878015633, 8.773350848698527, 9.759479150035457, 10.716860221416834, 11.659090353371884, 12.6251979262783, 13.551235422498491, 14.523738850660827, 15.49439985652114, 15.957482970972887, 16.809577347948885, 17.77307799747038, 18.510997915755468, 7.853440120056227, 6.804241392720956, 5.9150199375631995, 5.0777324829356445, 5.858935012339858, 6.786117574666137, 7.715795464239656, 8.754634749058866, 9.708490377187827, 10.681959919713576, 11.689522634571448, 12.594637313220199, 13.56115404544501, 14.501887907027475, 15.496481173381026, 15.95662815121221, 14.961998606306228, 15.877833782813706, 16.73070362248728, 17.559724496212898, 8.759107387626557, 7.811419669038743, 6.9080700487035385, 6.027214259937423, 6.8364824439137015, 7.799463477829452, 8.677510814617884, 9.709901360979194, 10.646658832169642, 11.649229651334718, 12.631310726864289, 13.575505805796107, 14.526197837498033, 15.503101459413706, 15.662496131086217, 14.90680367585145, 13.920596153461954, 14.841819343967472, 15.729573998934518, 16.50216775957997, 9.715372742314106, 8.775415882705301, 7.925388783219757, 7.035501867136247, 7.802421919701811, 8.766709802821051, 9.654299470447208, 10.705580609001645, 11.675186930801825, 12.63540311982148, 13.62738695720632, 14.520894419850647, 15.471159951481834, 15.522211386680981, 14.683915772203418, 13.836291502206642, 12.846017981449108, 13.788844321823964, 14.688286374500546, 15.532454469853922, 10.646001374294466, 9.77249606110251, 8.950840878013034, 8.044461820258453, 8.835648082737396, 9.775384344148195, 10.716219305279218, 11.662393561868537, 12.620677630304607, 13.630039408685034, 14.639789572486855, 15.502202426039146, 15.434176492302983, 14.49597185752787, 13.710347106235583, 12.766209126285595, 11.87930469814564, 12.860801831371528, 13.73867046485331, 14.543801551068908, 11.578419986686862, 10.72658260885669, 9.91890367489149, 9.033890669171086, 9.761471741153324, 10.743725349245048, 11.696219428871643, 12.631743333707073, 13.612012001274758, 14.62143448770841, 15.639348304542533, 15.437762523325718, 14.458189377683796, 13.531688599161361, 12.715855121811114, 11.78840523575753, 10.854391424343278, 11.793961017999177, 12.676065633999537, 13.575760823270198, 12.632161922521194, 11.785161924228037, 10.866366166682376, 10.080633207721746, 10.706443292037168, 11.687714300615536, 12.624003424425105, 13.586284860553834, 14.558396541745, 15.488234376966208, 15.404673231684237, 14.45868304226867, 13.562039668810742, 12.538918889897008, 11.75398032458602, 10.873598996181581, 9.879901442301108, 10.86066311645645, 11.723511100459001, 12.581750883783283, 13.536035882110431, 12.729970094100207, 11.903202829551027, 11.120034679997312, 11.74962099115423, 12.67798645748405, 13.656773191782893, 14.61605770554215, 15.61241857274866, 15.433006409909444, 14.533254272941432, 13.493522554502416, 12.515910234611594, 11.60413048088807, 10.717289155547343, 9.80399676419573, 8.859359869706335, 9.876984356708945, 10.798140666647488, 11.635906218519809, 14.467533492388226, 13.739822647669902, 12.95933673846265, 12.176487567239427, 12.772636484722014, 13.731872362516462, 14.658761484195926, 15.547429341017093, 15.39707065102583, 14.447430312933806, 13.507920389936082, 12.539303758995667, 11.50791154882581, 10.633457021261691, 9.67651256778881, 8.782940062056387, 7.905816834904083, 8.820443445384086, 9.759394388668666, 10.665098314386606, 15.474785830320197, 14.776021081154807, 13.927822377896833, 13.149423873219675, 13.744263315074566, 14.682100255199586, 15.652234442668016, 15.45522198730457, 14.439808137540444, 13.424029983208062, 12.491228105547822, 11.5466526932822, 10.582693425483257, 9.644972034279332, 8.713125164369705, 7.827245898019626, 6.904143488557947, 7.807475743252874, 8.741893998085969, 9.739740331975414, 16.527158511561083, 15.82627243092017, 14.912981012597527, 14.082022481991665, 14.75499350743943, 15.639425414652422, 15.532064003659404, 14.463743035509737, 13.514507931494562, 12.573735924556317, 11.523334083265793, 10.595489133848153, 9.635379296930093, 8.711732058683477, 7.757544891341004, 6.902163840831475, 5.957385115565861, 6.862429399009817, 7.806651956946078, 8.831128996394295, 17.50671489364753, 16.8138851697205, 15.943254666474466, 15.153516117215963, 15.724728492430533, 15.675592308361106, 14.718213732282427, 13.68800373402142, 12.723250722208801, 11.742165564018112, 10.670262838570224, 9.623820390833187, 8.664874918039954, 7.707829643701377, 6.7720324561173015, 5.848720301392106, 5.026163804573545, 5.93055774913239, 6.880005771422194, 7.812802476245373, 18.486981287524646, 17.8861946540616, 17.014148092006025, 16.11218006571604, 15.684722567698877, 14.714876699548432, 13.734103698246319, 12.78509429649478, 11.747540689857772, 10.73827465719862, 9.687110716924838, 8.725246745023599, 7.802895543185007, 6.8183053817642785, 5.805559475713954, 4.915672069396491, 4.011875825159901, 4.915934250961558, 5.9809952997465405, 6.882291717914744, 18.57582334302528, 17.611391368113065, 16.643435248757346, 15.719147804819684, 14.78619634235095, 13.743173207447535, 12.739924323394941, 11.788158177648743, 10.790280440308287, 9.813110391349277, 8.748066550742436, 7.7577311924669665, 6.838138126698178, 5.7984945454795715, 4.792963584503195, 3.956817536894154, 2.976269932950771, 3.9185706893821113, 4.9239363323204985, 5.8438983730195115, 17.742241083261828, 16.752754316462124, 15.71363377535258, 14.701981460987323, 13.743846058209675, 12.692519590315907, 11.807948187289886, 10.79840818607999, 9.727731050118118, 8.799579867639089, 7.798537656014457, 6.78866698835718, 5.8085581550298935, 4.843874340444054, 3.851755915801455, 2.9063768370316794, 1.9769832387093518, 2.9066195491906575, 3.8956647835176645, 4.83033921208353, 16.764966387084222, 15.741975227596562, 14.80482191435232, 13.798002124252154, 12.74332496883443, 11.740475151670385, 10.7975219743956, 9.858626667207902, 8.921585393958967, 7.985818810550997, 6.9128008855227066, 5.929879129294162, 4.9422703120138785, 3.956533444633558, 2.9871536552965243, 1.989034366534554, 1.036318321608679, 1.9998038626463837, 2.9488289579363496, 3.9019407455490285, 16.38990842282897, 15.364328466896676, 14.335237353648905, 13.319107843759394, 12.244299605358014, 11.210564754380972, 10.15204030898485, 9.116069778996254, 8.051881166357184, 7.073276057505447, 6.11741306118125, 5.0680715133776015, 4.032587572751266, 2.957661365729058, 2.004041755508857, 1.0150427365838552, 0.0, 0.9803075925090423, 1.9944965272232493, 3.062215124263453], [3.0292171579989486, 2.013833458631998, 1.0227510808658276, 2.020660592913251, 2.9601779745110854, 3.92942800889788, 4.896789523465483, 5.862791015137388, 6.882020505385991, 7.820735258037703, 8.749474732561652, 9.706906795320759, 10.77985127147431, 11.789708743037487, 12.722530111415043, 13.714212403867377, 14.765625858554463, 15.728354342007894, 16.788200396420084, 17.856016408128365, 3.888445711368372, 2.958389268181912, 2.059056901525807, 2.9883306364617215, 3.8893321880176845, 4.869627335151809, 5.851565898352543, 6.8929869571110896, 7.8217844547325575, 8.747572334626602, 9.747720093896303, 10.64179026374731, 11.589984611693627, 12.595039611148056, 13.545685745781148, 14.524411958697984, 15.564348426869222, 16.595250180212737, 17.57455359788335, 18.590288105352997, 4.892015492848534, 3.8914208616531827, 3.110723831574692, 4.008785383430398, 4.834985413579884, 5.806184348104641, 6.813857905975592, 7.83955647157647, 8.798374708136361, 9.796244121485627, 10.8045823635111, 11.588170155778124, 12.61993933586858, 13.589206977246937, 14.520115363569023, 15.554838729266747, 16.535397973633046, 17.08799183916996, 17.816461534705194, 18.59664115113393, 5.894931093642468, 4.84917521254737, 4.047935195507906, 5.0193573688066655, 5.853609213171694, 6.783826951136889, 7.74021689850036, 8.769850470524675, 9.75365844120757, 10.7397867425445, 11.697167813925876, 12.639397945880926, 13.605505518787343, 14.531543015007534, 15.50404644316987, 16.474707449030184, 16.92101631920191, 16.11204047340299, 16.887977451628892, 17.625897369913975, 6.8908199545310485, 5.841621227195778, 5.025707984874254, 6.058040075444687, 6.8392426048489, 7.766425167175179, 8.696103056748697, 9.734942341567908, 10.68879796969687, 11.662267512222618, 12.66983022708049, 13.574944905729241, 14.541461637954052, 15.482195499536518, 16.476788765890067, 16.92016149944123, 15.925531954535252, 15.18029690826781, 15.845603076645789, 16.674623950371405, 7.866874534433242, 6.848799503513565, 6.018758096014593, 7.007521852446466, 7.816790036422744, 8.779771070338494, 9.657818407126925, 10.690208953488234, 11.626966424678685, 12.62953724384376, 13.611618319373331, 14.55581339830515, 15.506505430007076, 16.48340905192275, 16.626029479315243, 15.870337024080474, 14.884129501690978, 14.144282469421576, 14.844473453093025, 15.617067213738475, 8.752752576788927, 7.812795717180122, 7.036076830530812, 8.01580945964529, 8.782729512210853, 9.747017395330094, 10.634607062956249, 11.685888201510686, 12.655494523310866, 13.615710712330522, 14.607694549715363, 15.50120201235969, 16.451467543990876, 16.485744734910007, 15.647449120432443, 14.799824850435666, 13.809551329678133, 13.091307447278067, 13.803185828659053, 14.647353924012428, 9.683381208769287, 8.80987589557733, 8.061528925324088, 9.024769412767496, 9.815955675246439, 10.755691936657238, 11.696526897788258, 12.642701154377578, 13.600985222813648, 14.610347001194077, 15.620097164995897, 16.48251001854819, 16.39770984053201, 15.459505205756894, 14.673880454464607, 13.72974247451462, 12.842838046374665, 12.052507522239615, 12.853569919011818, 13.658701005227414, 10.615799821161684, 9.76396244333151, 9.029591722202545, 9.996442649428513, 10.741779333662366, 11.724032941754091, 12.676527021380684, 13.612050926216114, 14.592319593783799, 15.601742080217452, 16.619655897051576, 16.40129587155474, 15.42172272591282, 14.495221947390386, 13.679388470040138, 12.751938583986554, 11.817924772572303, 10.985666708867264, 11.790965088158044, 12.690660277428703, 11.669541756996015, 10.822541758702856, 9.97705421399343, 10.971130407716915, 11.68675088454621, 12.668021893124578, 13.604311016934147, 14.566592453062874, 15.53870413425404, 16.46854196947525, 16.368206579913263, 15.422216390497693, 14.525573017039767, 13.502452238126033, 12.717513672815045, 11.837132344410604, 10.843434790530132, 10.052368807324537, 10.838410554617509, 11.696650337941788, 12.650935336268937, 11.767349928575026, 11.013890876862082, 12.010531879992481, 12.729928583663273, 13.658294049993092, 14.637080784291935, 15.596365298051193, 16.5927261652577, 16.39653975813847, 15.496787621170457, 14.45705590273144, 13.479443582840618, 12.567663829117095, 11.680822503776367, 10.767530112424753, 9.82289321793536, 8.991883810867451, 9.913040120805995, 10.750805672678315, 13.582432946546732, 12.777202482144721, 12.070024785773704, 13.066984767234596, 13.752944077231056, 14.712179955025505, 15.639069076704969, 16.527736933526135, 16.360603999254852, 15.41096366116283, 14.471453738165106, 13.50283710722469, 12.471444897054834, 11.596990369490715, 10.640045916017835, 9.74647341028541, 8.869350183133108, 7.935342899542592, 8.874293842827171, 9.779997768545112, 14.589685284478703, 13.813400915629627, 13.038510425207887, 13.972622189630265, 14.724570907583608, 15.662407847708629, 16.632542035177057, 16.418755335533596, 15.403341485769468, 14.387563331437086, 13.454761453776847, 12.510186041511224, 11.54622677371228, 10.608505382508357, 9.67665851259873, 8.790779246248649, 7.867676836786972, 6.922375197411379, 7.8567934522444745, 8.85463978613392, 15.64205796571959, 14.86365226539499, 14.023669059908581, 14.905220798402254, 15.735301099948472, 16.619733007161464, 16.495597351888428, 15.42727638373876, 14.478041279723586, 13.537269272785341, 12.486867431494817, 11.559022482077177, 10.598912645159118, 9.675265406912501, 8.721078239570028, 7.865697189060498, 6.9209184637948855, 5.977328853168323, 6.921551411104584, 7.9460284505528005, 16.621614347806037, 15.85126500419532, 15.05394271378552, 15.976714433626553, 16.705036084939575, 16.63912565659013, 15.681747080511451, 14.651537082250444, 13.686784070437826, 12.705698912247136, 11.633796186799248, 10.58735373906221, 9.628408266268979, 8.671362991930401, 7.735565804346326, 6.812253649621129, 5.989697152802569, 5.045457203290896, 5.9949052255807, 6.927701930403879, 17.601880741683154, 16.92357448853642, 16.124836139317082, 16.93537838212663, 16.64875162255441, 15.678905754403965, 14.698132753101852, 13.749123351350313, 12.711074038086796, 11.701808005427644, 10.650644065153863, 9.688780093252623, 8.76642889141403, 7.781838729993303, 6.769092823942978, 5.8792054176255135, 4.975409173388925, 4.030833705120064, 5.095894753905046, 5.98838079167619, 18.54268128398606, 17.97385497880461, 17.058143101717278, 16.699455397328727, 15.766503934859992, 14.707202262303067, 13.703953378250473, 12.752187232504275, 11.753813788537311, 10.7766437395783, 9.71159989897146, 8.72126454069599, 7.801671474927202, 6.762027893708596, 5.756496932732219, 4.920350885123177, 3.9398032811797954, 3.033470143540617, 4.038835786479004, 4.949987446780957, 18.72254867577087, 17.733061908971166, 16.693941367861623, 15.682289053496365, 14.724153650718717, 13.67282718282495, 12.771977242145418, 11.762437240935522, 10.691264398347142, 9.763113215868113, 8.76207100424348, 7.752200336586204, 6.772091503258918, 5.807407688673078, 4.815289264030479, 3.869910185260703, 2.940516586938376, 2.0215190033491632, 3.0017538572791107, 3.936428285844976, 17.745273979593264, 16.722282820105605, 15.785129506861363, 14.778309716761196, 13.723632561343473, 12.720782744179427, 11.777829566904643, 10.838934259716945, 9.90189298646801, 8.96612640306004, 7.893108478031749, 6.910186721803204, 5.922577904522921, 4.9368410371426, 3.967461247805567, 2.9610312758980277, 1.9998516698377031, 1.0363661287999986, 1.9853912240899647, 2.938503011702643, 17.370216015338013, 16.34463605940572, 15.315544946157948, 14.299415436268436, 13.224607197867057, 12.190872346890014, 11.132347901493892, 10.096377371505296, 9.032188758866226, 8.05358365001449, 7.097720653690293, 6.048379105886644, 5.012895165260309, 3.9379689582381006, 2.9843493480178998, 1.9953503290928976, 0.9803075925090423, 0.0, 1.014188934714207, 2.0819075317544105], [2.07868757315112, 1.0664784132305571, 2.0369400155800346, 3.0348495276274576, 3.9743669092252922, 4.943616943612087, 5.91097845817969, 6.876979949851595, 7.896209440100198, 8.834924192751911, 9.763663667275859, 10.721095730034966, 11.794040206188518, 12.803897677751694, 13.73671904612925, 14.728401338581584, 15.77981479326867, 16.742543276722103, 17.802389331134293, 18.870205342842574, 2.8752148292464534, 2.011034222780471, 2.983674802272809, 3.924020612534883, 4.903521122731891, 5.883816269866015, 6.865754833066751, 7.907175891825297, 8.835973389446764, 9.76176126934081, 10.76190902861051, 11.655979198461518, 12.604173546407834, 13.609228545862264, 14.559874680495355, 15.538600893412191, 16.57853736158343, 17.609439114926946, 17.91218097330599, 18.670950241131827, 3.88156849174161, 2.944065816251741, 3.9860478234055092, 4.944475359503559, 5.84917434829409, 6.8203732828188475, 7.828046840689799, 8.853745406290678, 9.812563642850568, 10.810433056199834, 11.818771298225307, 12.602359090492332, 13.634128270582787, 14.603395911961144, 15.53430429828323, 16.569027663980954, 17.549586908347255, 17.893197937413202, 16.953685480231034, 17.71168245572475, 4.893887600382172, 3.901820167145928, 4.923259187338722, 5.9550473448798265, 6.8677981478859, 7.798015885851095, 8.754405833214566, 9.784039405238882, 10.767847375921777, 11.753975677258707, 12.711356748640085, 13.653586880595133, 14.61969445350155, 15.545731949721741, 16.51823537788408, 17.488896383744393, 17.805513320439495, 16.945802743894326, 16.02520139715473, 16.740938674504793, 5.939179201470334, 4.894266181794336, 5.872105260880144, 6.935624698366496, 7.853431539563106, 8.780614101889384, 9.710291991462903, 10.749131276282114, 11.702986904411075, 12.676456446936823, 13.6840191617947, 14.589133840443449, 15.55565057266826, 16.496384434250725, 17.490977700604276, 17.804658500678816, 16.810028955772836, 16.014059178759148, 14.982827022171628, 15.789665254962221, 6.919519489031801, 5.901444458112124, 6.8651553720204825, 7.867673092958916, 8.83097897113695, 9.7939600050527, 10.67200734184113, 11.70439788820244, 12.64115535939289, 13.643726178557966, 14.62580725408754, 15.570002333019358, 16.520694364721283, 17.497597986636958, 17.510526480552823, 16.754834025318058, 15.768626502928562, 14.978044739912914, 13.981697398618865, 14.732108518329293, 7.805397531387485, 6.865440671778681, 7.836634686497376, 8.855176315572592, 9.79691844692506, 10.761206330044299, 11.648795997670454, 12.700077136224891, 13.669683458025071, 14.629899647044727, 15.621883484429572, 16.5153909470739, 17.465656478705085, 17.37024173614759, 16.531946121670025, 15.68432185167325, 14.694048330915717, 13.945079272105113, 12.940409774184893, 13.762395228603246, 8.736026163367846, 7.862520850175889, 8.825853558479519, 9.864136268694798, 10.830144609960644, 11.769880871371443, 12.710715832502464, 13.656890089091783, 14.615174157527854, 15.624535935908282, 16.634286099710103, 17.4966989532624, 17.282206841769593, 16.344002206994478, 15.55837745570219, 14.614239475752203, 13.727335047612248, 12.9370045234772, 11.990793864537657, 12.773742309818232, 9.668444775760243, 8.816607397930069, 9.793916355357975, 10.760767282583943, 11.716425418843498, 12.698679026935222, 13.69071595609489, 14.626239860930319, 15.606508528498004, 16.615931014931657, 17.63384483176578, 17.285792872792328, 16.306219727150406, 15.37971894862797, 14.563885471277722, 13.636435585224138, 12.702421773809887, 11.870163710104848, 10.928189033683884, 11.805701582019521, 10.722186711594574, 9.875186713301416, 10.74137884714886, 11.735455040872345, 12.661396969727342, 13.64266797830571, 14.578957102115279, 15.58078138777708, 16.552893068968245, 17.482730904189456, 17.252703581150847, 16.30671339173528, 15.41007001827735, 14.386949239363616, 13.602010674052629, 12.72162934564819, 11.727931791767716, 10.936865808562121, 9.975634500143348, 10.811691642532606, 11.732109979951243, 10.819994883173585, 11.77821551001751, 12.774856513147911, 13.704574668844405, 14.632940135174223, 15.611726869473067, 16.571011383232324, 17.59000986105396, 17.281036759376054, 16.381284622408042, 15.341552903969024, 14.363940584078202, 13.452160830354678, 12.565319505013951, 11.652027113662339, 10.707390219172943, 9.876380812105035, 9.050264066331835, 9.865846977269133, 12.663607590229038, 11.82984743674328, 12.823575462316013, 13.831309400390026, 14.727590162412188, 15.686826040206636, 16.613715161886102, 17.502383018707267, 17.245101000492436, 16.295460662400416, 15.35595073940269, 14.387334108462275, 13.355941898292418, 12.4814873707283, 11.524542917255419, 10.630970411522995, 9.753847184370692, 8.819839900780176, 8.01151778835301, 8.89503907313593, 13.704726589069521, 12.866045870228186, 13.792061101750196, 14.726172866172574, 15.69921699276474, 16.63705393288976, 17.607188120358188, 17.303252336771177, 16.28783848700705, 15.27206033267467, 14.33925845501443, 13.394683042748808, 12.430723774949865, 11.49300238374594, 10.561155513836313, 9.675276247486234, 8.752173838024556, 7.806872198648963, 6.994017397770313, 7.9696810907247375, 14.757099270310409, 13.916297219993549, 14.77721973645089, 15.658771474944563, 16.66361530809985, 17.594379092342596, 17.38009435312601, 16.311773384976345, 15.36253828096117, 14.421766274022925, 13.3713644327324, 12.44351948331476, 11.483409646396701, 10.559762408150085, 9.605575240807612, 8.750194190298084, 7.805415465032469, 6.8618258544059065, 5.990720002128332, 7.015197041576548, 15.736655652396855, 14.903909958793879, 15.807493390327831, 16.73026511016886, 17.633350293090952, 17.523622657827712, 16.566244081749034, 15.536034083488028, 14.57128107167541, 13.59019591348472, 12.518293188036832, 11.471850740299795, 10.512905267506563, 9.555859993167985, 8.62006280558391, 7.696750650858714, 6.874194154040153, 5.92995420452848, 5.064073816604448, 5.996870521427628, 16.71692204627397, 15.976219443134978, 16.878386815859393, 17.688929058668936, 17.533248623791994, 16.563402755641548, 15.582629754339436, 14.633620352587897, 13.59557103932438, 12.586305006665228, 11.535141066391446, 10.573277094490207, 9.650925892651616, 8.666335731230888, 7.653589825180562, 6.763702418863099, 5.859906174626509, 4.915330706357648, 4.101641683981522, 4.974827602333842, 17.657722588576878, 17.026499933403166, 17.81169377825959, 17.65152424934958, 16.657535631714715, 15.59169926354065, 14.588450379488057, 13.636684233741859, 12.638310789774895, 11.661140740815885, 10.596096900209044, 9.605761541933575, 8.686168476164786, 7.64652489494618, 6.640993933969803, 5.804847886360762, 4.824300282417379, 3.917967144778201, 3.038278458669387, 3.9364342574386093, 18.705445161374726, 18.077719121036605, 17.680343901140912, 16.668691586775655, 15.710556183998007, 14.659229716104239, 13.656474243383002, 12.646934242173106, 11.575761399584726, 10.647610217105697, 9.646568005481065, 8.636697337823788, 7.656588504496502, 6.691904689910662, 5.699786265268063, 4.7544071864982875, 3.8250135881759597, 2.906016004586747, 1.9882006679367623, 2.9228750965026276, 18.731676512872554, 17.708685353384894, 16.771532040140652, 15.764712250040485, 14.710035094622762, 13.707185277458716, 12.764232100183932, 11.825336792996234, 10.888295519747299, 9.952528936339329, 8.879511011311038, 7.896589255082494, 6.908980437802211, 5.92324357042189, 4.864953098608174, 3.8455282771356116, 2.884348671075287, 1.9208631300375822, 0.9718380347476163, 1.924949822360295, 18.38440495005222, 17.358824994119928, 16.329733880872155, 15.313604370982643, 14.238796132581264, 13.205061281604221, 12.1465368362081, 11.110566306219503, 10.046377693580434, 9.067772584728697, 8.111909588404501, 7.062568040600851, 6.027084099974516, 4.952157892952307, 3.9985382827321065, 3.0095392638071043, 1.9944965272232493, 1.014188934714207, 0.0, 1.0677185970402037], [1.010968976110916, 2.0263526754778667, 3.017435053244037, 4.076980638028736, 5.016498019626571, 6.011335540652292, 6.978697055219895, 7.9446985468918, 8.963928037140402, 9.902642789792115, 10.831382264316062, 11.788814327075169, 12.861758803228721, 13.871616274791897, 14.804437643169454, 15.796119935621787, 16.847533390308875, 17.810261873762308, 18.870107928174498, 18.79897697485611, 1.9019506544230085, 2.832007097609469, 3.8046476771018067, 4.744993487363881, 5.727375699105769, 6.730346739837785, 7.777864160122709, 8.819285218881255, 9.834122731296016, 10.829479866381014, 11.829627625650716, 12.723697795501721, 13.671892143448037, 14.676947142902467, 15.627593277535558, 16.606319490452396, 17.646255958623634, 18.67715771196715, 18.677261504076885, 17.780327634124603, 2.908304316918165, 3.765038691080739, 4.807020698234507, 5.765448234332557, 6.673028924667968, 7.644227859192726, 8.690135396848758, 9.734246541168911, 10.693064777728802, 11.733752329926544, 12.801822434746718, 13.670077687532535, 14.70184686762299, 15.671114509001347, 16.602022895323433, 17.63674626102116, 18.61730550538746, 18.658278468184097, 17.71876601100193, 16.821059848717525, 3.9206234255587264, 4.722793041974926, 5.74423206216772, 6.776020219708824, 7.691652724259779, 8.621870462224972, 9.578260409588443, 10.60789398161276, 11.591701952295654, 12.577830253632584, 13.535211325013961, 14.562852118129333, 15.586122584613577, 16.56186208954403, 17.534365517706366, 18.50502652356668, 18.738472720841408, 17.806231419829988, 16.790281927925626, 15.85031606749757, 4.965915026646888, 5.715239056623334, 6.693078135709142, 7.756597573195494, 8.677286115936985, 9.604468678263263, 10.534146567836782, 11.572985852655993, 12.526841480784954, 13.500311023310703, 14.507873738168575, 15.498399077977648, 16.46491581020246, 17.405649671784925, 18.400242938138476, 18.73761790108073, 17.74298835617475, 16.87448785469481, 15.843255698107292, 14.899042647955, 6.013307776889991, 6.722417332941122, 7.6861282468494805, 8.688645967787913, 9.65483354751083, 10.617814581426579, 11.49586191821501, 12.528252464576319, 13.46500993576677, 14.467580754931845, 15.449661830461416, 16.393856909393236, 17.405231131585552, 18.38982866782404, 18.44348588095474, 17.68779342571997, 16.701585903330475, 15.838473415848577, 14.842126074554528, 13.84148591132207, 7.0574999203687305, 7.686413546607679, 8.657607561326374, 9.67614919040159, 10.62077302329894, 11.585060906418178, 12.472650574044334, 13.52393171259877, 14.49353803439895, 15.453754223418606, 16.44573806080345, 17.339245523447776, 18.350193245569354, 18.303201136549504, 17.46490552207194, 16.617281252075163, 15.62700773131763, 14.805507948040777, 13.800838450120557, 12.871772621596024, 7.988128552349091, 8.683493725004887, 9.646826433308517, 10.685109143523796, 11.653999186334524, 12.593735447745322, 13.534570408876343, 14.480744665465663, 15.439028733901733, 16.448390512282163, 17.458140676083982, 18.320553529636275, 18.215166242171506, 17.27696160739639, 16.491336856104105, 15.547198876154116, 14.660294448014161, 13.839665710045137, 12.884419884999517, 11.88311970281101, 8.920547164741487, 9.637580272759067, 10.614889230186973, 11.581740157412941, 12.537398293672496, 13.51965190176422, 14.514570532468769, 15.450094437304198, 16.430363104871883, 17.43978559130554, 18.457699408139664, 18.218752273194237, 17.239179127552315, 16.31267834902988, 15.496844871679635, 14.569394985626051, 13.6353811742118, 12.803123110506764, 11.821815054145743, 10.9150789750123, 9.974289100575819, 10.696159588130413, 11.562351721977858, 12.556427915701343, 13.482369844556338, 14.463640853134706, 15.399929976944275, 16.40463596415096, 17.376747645342125, 18.306585480563335, 18.185662981552756, 17.23967279213719, 16.34302941867926, 15.319908639765528, 14.53497007445454, 13.6545887460501, 12.660891192169629, 11.869825208964038, 10.869260520605208, 9.921069035525385, 10.875354033852533, 11.640967758002583, 12.59918838484651, 13.59582938797691, 14.525547543673401, 15.45391301000322, 16.432699744302063, 17.39198425806132, 18.410982735882957, 18.21399615977796, 17.314244022809955, 16.274512304370933, 15.296899984480113, 14.38512023075659, 13.498278905415862, 12.58498651406425, 11.640349619574856, 10.80934021250695, 9.943890086793694, 8.97522437026191, 11.806851644130328, 12.650820311572279, 13.644548337145011, 14.652282275219024, 15.548563037241184, 16.507798915035632, 17.434688036715098, 18.323355893536263, 18.178060400894346, 17.22842006280232, 16.288910139804603, 15.320293508864186, 14.288901298694329, 13.41444677113021, 12.45750231765733, 11.563929811924906, 10.686806584772604, 9.75279930118209, 8.90514380881487, 8.004416466128708, 12.8141039820623, 13.687018745057184, 14.613033976579194, 15.547145741001572, 16.520189867593736, 17.458026807718756, 18.428160995187184, 18.236211737173086, 17.22079788740896, 16.20501973307658, 15.272217855416342, 14.327642443150719, 13.363683175351776, 12.425961784147852, 11.494114914238224, 10.608235647888145, 9.685133238426468, 8.739831599050877, 7.887643418232174, 7.079058483717517, 13.866476663303187, 14.737270094822545, 15.598192611279888, 16.47974434977356, 17.48458818292885, 18.415351967171592, 18.313053753527925, 17.244732785378257, 16.29549768136308, 15.354725674424836, 14.304323833134312, 13.376478883716672, 12.416369046798613, 11.492721808551996, 10.538534641209523, 9.683153590699995, 8.738374865434382, 7.794785254807819, 6.884346022590193, 6.124574434569327, 14.846033045389634, 15.724882833622875, 16.628466265156828, 17.55123798499786, 18.454323167919952, 18.45658205822962, 17.499203482150943, 16.468993483889935, 15.504240472077319, 14.523155313886631, 13.451252588438743, 12.404810140701706, 11.445864667908474, 10.488819393569896, 9.55302220598582, 8.629710051260625, 7.807153554442066, 6.862913604930393, 5.957699837066309, 5.067002865508808, 15.82629943926675, 16.772392839605512, 17.69935969068839, 18.509901933497936, 18.466208024193904, 17.496362156043457, 16.515589154741345, 15.566579752989806, 14.528530439726289, 13.519264407067137, 12.468100466793356, 11.506236494892116, 10.583885293053527, 9.599295131632799, 8.586549225582473, 7.69666181926501, 6.792865575028422, 5.848290106759561, 4.995267704443383, 4.036784593421905, 16.767099981569654, 17.73153195648187, 18.632666653088584, 18.58448364975149, 17.590495032116625, 16.52465866394256, 15.521409779889966, 14.569643634143768, 13.571270190176804, 12.594100141217794, 11.529056300610954, 10.538720942335484, 9.619127876566699, 8.579484295348092, 7.573953334371714, 6.737807286762673, 5.757259682819291, 4.850926545180114, 3.969584306889181, 2.998391248526673, 17.814822554367503, 18.78275114411531, 18.61330330154282, 17.601650987177564, 16.643515584399918, 15.59218911650615, 14.589433643784911, 13.579893642575016, 12.508720799986635, 11.580569617507606, 10.579527405882974, 9.569656738225698, 8.589547904898412, 7.624864090312573, 6.632745665669974, 5.687366586900199, 4.757972988577872, 3.8389754049886595, 2.9195065161565568, 1.9848320875906915, 18.79209725054511, 18.641644753786803, 17.70449144054256, 16.697671650442395, 15.642994495024674, 14.640144677860627, 13.697191500585843, 12.758296193398145, 11.82125492014921, 10.88548833674124, 9.81247041171295, 8.829548655484405, 7.841939838204122, 6.8562029708238015, 5.797912499010085, 4.778487677537523, 3.817308071477199, 2.8538225304394946, 1.9047974351495287, 0.95168564753685, 19.45212354709242, 18.426543591160126, 17.397452477912356, 16.381322968022847, 15.306514729621469, 14.272779878644426, 13.214255433248304, 12.178284903259708, 11.114096290620639, 10.135491181768902, 9.179628185444706, 8.130286637641056, 7.094802697014721, 6.019876489992512, 5.066256879772311, 4.0772578608473085, 3.062215124263453, 2.0819075317544105, 1.0677185970402037, 0.0]]}],
                            {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('1491d4c3-4a62-467c-8d75-747eb00a30b3');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Compute the adjacency matrix of the grid points, with boundaries identified as in the Klein bottle
    from sklearn.utils.graph_shortest_path import graph_shortest_path
    
    # This functions prepares the grid matrix with boundary identification
    def make_matrix(rows, cols):
        n = rows*cols
        M = np.zeros((n,n))
        for r in range(rows):
            for c in range(cols):
                i = r*cols + c
                # Two inner diagonals
                if c > 0: M[i-1,i] = M[i,i-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # Two outer diagonals
                if r > 0: M[i-cols,i] = M[i,i-cols] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # vertical boundary identification
                if c == 0: M[i+cols-1,i] = M[i,i+cols-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                # horizontal twisted boundary identification
                if r == 0: M[n-i-1,i] = M[i,n-i-1] = 1 + 0.15*(np.random.rand(1)[0]-0.5)
                    
        return M
    
    M = make_matrix(20,20)
    
    # computing the distance matrix of the points over the Klein bottle
    
    klein = graph_shortest_path(M)
    
    # Plot of the distance matrix
    plot_heatmap(klein, colorscale='viridis')



.. raw:: html

    <div>
    
    
                <div id="5caa447f-2b4c-4a56-a498-d7d279f96877" class="plotly-graph-div" style="height:525px; width:100%;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("5caa447f-2b4c-4a56-a498-d7d279f96877")) {
                        Plotly.newPlot(
                            '5caa447f-2b4c-4a56-a498-d7d279f96877',
                            [{"colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "type": "heatmap", "z": [[0.0, 0.9589752552729305, 1.9383122687101426, 2.929187410182724, 3.9574220498137724, 4.912535860860632, 5.939879674478609, 6.95476377920624, 7.89442091640534, 8.918847194150946, 9.972159870331948, 9.089328909612036, 8.023265395500529, 7.01487296256472, 6.008077052241767, 5.01959943212087, 4.062213953147279, 3.0378413559190034, 2.0369152283101473, 1.0101776319600404, 1.0189057776465762, 2.0142796012629542, 2.9288251470141464, 3.8773623682178373, 4.937212761995671, 5.891737779177887, 6.890006378098798, 7.882002191892444, 8.933764817685853, 9.955654791338773, 10.909050479768652, 9.96314842340528, 8.90433848367826, 7.887911311260988, 6.935205047812421, 6.0014909413500135, 4.987661630636583, 4.068166192383283, 3.0850052241426766, 2.0646861219069024, 2.0626284306803027, 3.003783570503194, 3.9081996083448107, 4.86714944656233, 5.864866028639095, 6.877679672982509, 7.892736477434318, 8.914624986861263, 9.930287975643642, 10.937542696174637, 11.83683445346512, 10.90604146467595, 9.853771235104707, 8.857796400667013, 7.8834976274052515, 6.983983470632506, 6.060595897156367, 5.025606344714268, 4.0104033752258434, 3.102718632162169, 3.0809764756775877, 4.014873509624397, 4.89204352965489, 5.82065254915954, 6.859912060708915, 7.861008819673885, 8.809489597126458, 9.80059813152868, 10.786148481686961, 11.762873872521425, 12.76332491821833, 11.771984421335645, 10.80808114023952, 9.84553269988377, 8.897483747947547, 7.853453418978669, 6.9249347925385365, 5.989816716731827, 4.996237563570288, 4.103606189623741, 4.006552127101202, 4.9538874316020465, 5.948025169199824, 6.885170984857114, 7.842173982469255, 8.90798215238446, 9.863459668186211, 10.804163067468085, 11.778274591811334, 12.722519064925303, 13.67215903431347, 12.711354121748196, 11.796416936397193, 10.817685900218962, 9.876312994177129, 8.851082751645032, 7.889373329437296, 6.960509979660094, 5.942100345433207, 5.060294946693176, 5.014654220497224, 5.994854545846467, 6.894025270179738, 7.819412187823578, 8.784736819089632, 9.812316606264918, 10.749492060055982, 11.718021821252803, 12.71022794944652, 13.637761761076234, 14.583908652731708, 13.672283745601778, 12.705976061371501, 11.777017113036377, 10.799206743111247, 9.819969220413443, 8.909613702329441, 7.942778943630513, 6.889782372890769, 5.964997279757901, 5.9586849632922725, 6.972857012248092, 7.9340394888402095, 8.846829848839073, 9.755508556740523, 10.782630048344037, 11.724251609539394, 12.756662584053586, 13.73073322538818, 14.579515668998196, 15.605372738699183, 14.696169352548292, 13.77167983232606, 12.781460620245545, 11.751686666540285, 10.88718302713221, 9.8718673469645, 8.835374824644207, 7.826982531087816, 6.894427609520742, 6.969916336576864, 7.9551396861684935, 8.916350565991646, 9.877906794420555, 10.78086440561992, 11.808780875281034, 12.700543056430273, 13.738044567986751, 14.6936529902735, 15.520989705608853, 16.47759075896837, 15.628098758513907, 14.804840803038902, 13.758349773086795, 12.708104051322955, 11.737106886414814, 10.807520286314176, 9.868564961962154, 8.817510746804972, 7.831513839395287, 7.939335477213738, 8.97573648061639, 9.95350024623546, 10.881537837413486, 11.711625034118951, 12.716169566613766, 13.652450663844405, 14.679708853229121, 15.644279489248627, 16.559204205658933, 17.48963395068014, 16.54133446590472, 15.602687630371989, 14.663289025314256, 13.63397785640728, 12.765528308400055, 11.865669960871827, 10.872743197267175, 9.805925580449962, 8.798952442880369, 8.877415179973964, 9.882554255236155, 10.85325788859658, 11.834382965095774, 12.675357485806263, 13.659808030907765, 14.632951962131871, 15.575086755736288, 16.618564643743504, 17.504964682971988, 18.40775175627501, 17.48257829753797, 16.543618062459103, 15.597009522128573, 14.628709760532603, 13.727646012864463, 12.86836530593193, 11.819101882916566, 10.794408716073834, 9.779640968063397, 9.92363715676487, 10.891753472801877, 11.8352237338932, 12.862127819817047, 13.609100133098675, 14.582728002734799, 15.651188034450517, 16.626895808178137, 17.547528441020603, 18.46567304472336, 18.27934933041254, 17.37821950061888, 16.52456117606054, 15.536745677061447, 14.471034114619641, 13.520225567924536, 12.535912167202014, 11.640107292884244, 10.675162445030256, 9.983610948056935, 9.78581483047244, 10.68204132891239, 11.699934203387334, 12.699939144617732, 13.568972143482924, 14.618448863841815, 15.474230299864708, 16.419676087636613, 17.447679211703328, 18.291614055895245, 17.327999772115014, 16.323250461869595, 15.45487713991088, 14.549631360105199, 13.514687500725426, 12.63846786548504, 11.597113407463617, 10.670299578950274, 9.739809521922124, 9.053323700263434, 8.79215784990409, 9.712477745990038, 10.749978406813668, 11.666632251139555, 12.551550515642012, 13.55943494426645, 14.526968333042289, 15.45346535434838, 16.422482070391663, 17.289266168092787, 16.321239529864503, 15.395713199724872, 14.408635868200363, 13.553973027458431, 12.483542013700177, 11.593833397698731, 10.653397227014851, 9.664696843720172, 8.753477111800446, 8.050444381269905, 7.792815386789133, 8.772210176416188, 9.70930293772262, 10.677422437481473, 11.598730953551659, 12.613393072123632, 13.562044795723311, 14.499719191821642, 15.551893621053054, 16.490928906573412, 15.46347478040654, 14.499052896237911, 13.47245014224474, 12.534252967212865, 11.547599132806612, 10.586194925491217, 9.602487418552549, 8.61380004146797, 7.774797335391664, 6.994868207302149, 6.8199334358878945, 7.761458816733455, 8.70634861425255, 9.702543443491479, 10.627904939476512, 11.623951197400277, 12.586874330264312, 13.611369289554514, 14.566659180653126, 15.450800727861141, 14.492155728789983, 13.471084277151217, 12.44835673897018, 11.51023248361373, 10.583433035961475, 9.666757200018985, 8.666075502302158, 7.651534775855502, 6.7076289965663785, 5.939760056724198, 5.760688803544712, 6.751337967950883, 7.711697447820201, 8.774707330239991, 9.748238580626868, 10.814144230226862, 11.702539318594987, 12.68408605319272, 13.687574023010226, 14.52931534979531, 13.488739872239297, 12.541879132098849, 11.511058886439653, 10.57285503468019, 9.63199414202145, 8.639420994680044, 7.680896769717898, 6.7219401374843795, 5.688529322702257, 4.931842765274242, 4.760354133491618, 5.706174962589063, 6.753801079943067, 7.812629146778474, 8.7444911386915, 9.76329170130003, 10.697828582413901, 11.720739437216043, 12.693183288099762, 13.60330346016559, 12.535175236952618, 11.513042422907764, 10.55251794956583, 9.62883690397382, 8.628802963369614, 7.6664846322322, 6.717638476063856, 5.702764372153924, 4.7174488322841635, 3.8830310805462025, 3.794247485222339, 4.854900735449601, 5.882784700981975, 6.829805225607444, 7.873637519128332, 8.79352103518372, 9.737809233514088, 10.759626016290746, 11.764657756289477, 12.677980001349743, 11.631030403904077, 10.668297663535135, 9.621036186436278, 8.660378951892243, 7.689254578375179, 6.713618929569081, 5.7624565685286315, 4.838787386633233, 3.7902035245232977, 2.844250176667664, 2.883817470523013, 3.941930941299576, 4.945241096882598, 5.92785958437001, 6.8919041102968555, 7.866388838006652, 8.873680690186204, 9.929259638959083, 10.930708841632681, 11.774152486557467, 10.702556227913524, 9.70916000473738, 8.764149881684798, 7.784907099151214, 6.779077651116393, 5.759661687066474, 4.740434703092445, 3.79958237364905, 2.8550154573146913, 1.8890172529398124, 2.011952180663762, 2.9744516676862567, 3.935103632352172, 4.982111603872218, 5.930406785976235, 6.948977517564487, 7.938760870040088, 8.958660006180148, 9.900415411665648, 10.945820899840855, 9.89288652500862, 8.868140572398076, 7.893847549608274, 6.964428713136528, 5.931264775165779, 4.978004720057957, 3.988739380971717, 2.93178960659152, 1.9289426116382313, 0.9621788122179693], [0.9589752552729305, 0.0, 0.9793370134372121, 1.9702121549097933, 2.9984467945408415, 3.9535606055877013, 4.980904419205679, 5.995788523933309, 6.93544566113241, 7.959871938878015, 9.013184615059018, 10.003601969410274, 8.98224065077346, 7.97384821783765, 6.967052307514697, 5.978574687393801, 5.02118920842021, 3.996816611191934, 2.9958904835830777, 1.9691528872329709, 1.9778810329195067, 1.0553043459900235, 1.9698498917412157, 2.918387112944907, 3.97823750672274, 4.932762523904956, 5.931031122825868, 6.923026936619514, 7.974789562412923, 8.996679536065841, 9.95007522449572, 10.91011729820087, 9.86331373895119, 8.84688656653392, 7.894180303085352, 6.960466196622944, 5.946636885909514, 5.027141447656214, 4.043980479415607, 3.023661377179833, 3.021603685953233, 2.089155799227913, 2.94922435307188, 3.908174191289399, 4.905890773366164, 5.918704417709579, 6.933761222161388, 7.955649731588331, 8.97131272037071, 9.978567440901704, 10.970920917960164, 11.86501671994888, 10.812746490377638, 9.816771655939943, 8.842472882678182, 7.942958725905436, 7.019571152429298, 5.984581599987198, 4.969378630498774, 4.0616938874351, 4.037659803369413, 3.100245738349116, 3.9330682743819594, 4.8616772938866095, 5.900936805435984, 6.902033564400955, 7.850514341853526, 8.841622876255748, 9.827173226414029, 10.803898617248493, 11.804349662945398, 12.730959676608576, 11.76705639551245, 10.8045079551567, 9.856459003220477, 8.8124286742516, 7.883910047811467, 6.9487919720047575, 5.9552128188432185, 5.060289517315566, 4.963235454793027, 4.039259660326766, 4.989049913926894, 5.926195729584183, 6.883198727196325, 7.949006897111528, 8.90448441291328, 9.845187812195155, 10.819299336538402, 11.76354380965237, 12.713183779040538, 13.670329377021126, 12.755392191670124, 11.776661155491892, 10.835288249450059, 9.810058006917963, 8.848348584710227, 7.919485234933025, 6.901075600706138, 6.016978274385002, 5.97133754818905, 5.080226774571187, 5.935050014906808, 6.860436932550647, 7.825761563816702, 8.85334135099199, 9.790516804783053, 10.759046565979874, 11.751252694173587, 12.678786505803302, 13.624933397458776, 14.57733479871642, 13.664951316644432, 12.735992368309308, 11.758181998384178, 10.778944475686373, 9.868588957602372, 8.901754198903443, 7.8487576281637, 6.921680607449726, 6.915368290984098, 6.07906211065716, 7.008870095819409, 7.887854593566143, 8.796533301467592, 9.823654793071109, 10.765276354266465, 11.797687328780658, 12.771757970115248, 13.620540413725264, 14.64639748342625, 15.5755051064973, 14.73065508759899, 13.740435875518475, 12.710661921813216, 11.84615828240514, 10.83084260223743, 9.792058152336033, 8.78366585877964, 7.851110937212567, 7.926599664268689, 7.061344784577562, 7.991181172970846, 8.918931539147625, 9.821889150346989, 10.849805620008105, 11.741567801157345, 12.779069312713823, 13.734677735000568, 14.562014450335921, 15.518615503695436, 16.507434512462915, 15.763816058311832, 14.715033100778621, 13.664787379014781, 12.69379021410664, 11.764203614006002, 10.82524828965398, 9.774194074496798, 8.788197167087112, 8.896018804905564, 8.081941579025461, 9.02833085321466, 9.956368444392686, 10.75264977884602, 11.757194311340836, 12.693475408571475, 13.72073359795619, 14.685304233975696, 15.600228950386, 16.530658695407208, 17.498017793596546, 16.559370958063816, 15.619972353006082, 14.590661184099107, 13.722211636091881, 12.82235328856365, 11.829426524959, 10.762608908141788, 9.755635770572194, 9.83409850766579, 9.06870414528986, 10.039407778650286, 10.951963546465711, 11.716382230533332, 12.700832775634835, 13.67397670685894, 14.616111500463358, 15.659589388470572, 16.545989427699055, 17.49924969221984, 17.486514026032577, 16.54755379095371, 15.600945250623178, 14.613958658390251, 13.704805308633356, 12.765421873331444, 11.93627702756922, 11.006905557648047, 10.736324295755223, 10.880320484456696, 10.077903362855583, 11.021373623946905, 11.979708401186985, 12.650124877825744, 13.623752747461868, 14.692212779177586, 15.667920552905208, 16.58855318574767, 17.506697789450428, 17.460725826980493, 16.559595997186833, 15.705937672628492, 14.722436991541919, 13.656725429100113, 12.785685680825953, 11.80137228010343, 10.905567405785659, 9.940622557931672, 10.918674711494914, 10.74479008574537, 11.024324922496891, 12.001717494791173, 12.957342375625537, 13.68969454107383, 14.579786423009812, 15.512449557540885, 16.45789534531279, 17.488996114651314, 17.472990552463195, 16.509376268682967, 15.504626958437546, 14.63625363647883, 13.731007856673148, 12.696063997293376, 11.852760950451565, 10.862573520365034, 9.935759691851691, 9.005269634823541, 9.991385898942958, 9.75113310517702, 10.671453001262968, 11.708953662086598, 12.625607506412486, 13.51052577091494, 14.518410199539378, 15.485943588315218, 16.412440609621306, 17.38145732566459, 16.470642664660737, 15.50261602643245, 14.577089696292822, 13.590012364768313, 12.73534952402638, 11.664918510268127, 10.781680121906838, 9.918857339916269, 8.93015695662159, 8.018937224701864, 8.98850657994943, 8.751790642062064, 9.731185431689118, 10.668278192995551, 11.636397692754404, 12.557706208824587, 13.57236832739656, 14.52102005099624, 15.45869444709457, 16.510868876325983, 15.672305403141362, 14.64485127697449, 13.680429392805861, 12.65382663881269, 11.715629463780814, 10.728975629374562, 9.774041649699324, 8.867947531453968, 7.879260154369388, 7.04025744829308, 7.95384346257508, 7.778908691160825, 8.720434072006386, 9.66532386952548, 10.661518698764409, 11.58688019474944, 12.582926452673206, 13.54584958553724, 14.570344544827442, 15.525634435926055, 14.63217722442909, 13.673532225357933, 12.652460773719167, 11.62973323553813, 10.69160898018168, 9.764809532529425, 8.848133696586935, 7.899536517551241, 6.9169948887569195, 5.973089109467795, 6.898735311997129, 6.719664058817642, 7.710313223223814, 8.670672703093132, 9.73368258551292, 10.7072138358998, 11.773119485499794, 12.661514573867919, 13.643061308465652, 14.646549278283159, 13.71069184636326, 12.670116368807246, 11.723255628666799, 10.692435383007602, 9.754231531248138, 8.813370638589399, 7.820797491247993, 6.898313893046436, 5.987400250385797, 4.953989435603673, 5.890818020547172, 5.719329388764549, 6.665150217861994, 7.712776335215998, 8.771604402051405, 9.703466393964431, 10.722266956572962, 11.656803837686834, 12.679714692488975, 13.652158543372694, 12.78467995673354, 11.716551733520568, 10.694418919475714, 9.73389444613378, 8.810213400541768, 7.810179459937562, 6.847861128800148, 5.899014972631804, 4.968224485055341, 3.98290894518558, 4.842006335819133, 4.75322274049527, 5.813875990722532, 6.841759956254905, 7.788780480880375, 8.832612774401262, 9.75249629045665, 10.696784488787019, 11.718601271563676, 12.70709866516867, 11.77667723294674, 10.729727635501074, 9.766994895132132, 8.802412683004228, 7.841755448460193, 6.870631074943128, 5.894995426137029, 4.94383306509658, 4.0508385224148675, 3.0556636374247144, 3.8032254319405947, 3.842792725795943, 4.900906196572507, 5.904216352155529, 6.88683483964294, 7.850879365569786, 8.825364093279584, 9.832655945459134, 10.888234894232014, 11.88041461108213, 10.872849718154464, 9.801253459510521, 8.807857236334376, 7.862847113281794, 6.920414161780805, 5.914584713745984, 4.941038183634424, 3.921811199660394, 2.980958870216999, 2.0363919538826405, 2.8479925082127426, 2.9709274359366926, 3.933426922959187, 4.894078887625103, 5.941086859145148, 6.889382041249165, 7.907952772837417, 8.897736125313019, 9.917635261453078, 10.859390666938578, 10.005478419600964, 8.93391126973569, 7.909165317125146, 6.934872294335343, 6.005453457863598, 4.972289519892849, 4.019029464785026, 3.0297641256987866, 1.9728143513185894, 0.969967356365301, 1.9211540674908998], [1.9383122687101426, 0.9793370134372121, 0.0, 0.9908751414725812, 2.0191097811036296, 2.9742235921504894, 4.001567405768467, 5.016451510496098, 5.956108647695198, 6.980534925440804, 8.033847601621806, 9.024264955973063, 9.96157766421067, 8.953185231274862, 7.9463893209519085, 6.957911700831013, 6.000526221857422, 4.976153624629147, 3.97522749702029, 2.9484899006701832, 2.9572180463567186, 2.010011940962967, 0.9905128783040036, 1.9390500995076947, 2.998900493285528, 3.9534255104677443, 4.951694109388656, 5.943689923182302, 6.995452548975711, 8.017342522628631, 8.97073821105851, 9.93078028476366, 10.8426507523884, 9.82622357997113, 8.873517316522562, 7.939803210060156, 6.925973899346726, 6.006478461093427, 5.0233174928528195, 4.002998390617044, 3.8678020712861496, 2.9266469314632584, 1.9698873396346677, 2.928837177852187, 3.926553759928952, 4.9393674042723665, 5.954424208724176, 6.97631271815112, 7.9919757069334985, 8.999230427464493, 9.991583904522955, 10.922376893312125, 11.791744694054502, 10.795769859616808, 9.821471086355047, 8.882838050828923, 7.932979317624178, 6.880283724029983, 5.865080754541559, 4.913251424869725, 4.875150935604759, 3.9377368705844615, 2.953731260944747, 3.882340280449397, 4.921599791998772, 5.922696550963742, 6.871177328416314, 7.862285862818536, 8.847836212976816, 9.82456160381128, 10.825012649508185, 11.893187979532685, 12.745159873735089, 11.782611433379339, 10.752161127263262, 9.708130798294384, 8.779612171854252, 7.844494096047542, 6.8509149428860034, 5.897780649550912, 5.800726587028373, 4.876750792562111, 4.009712900489681, 4.946858716146972, 5.903861713759112, 6.969669883674316, 7.925147399476067, 8.865850798757942, 9.839962323101188, 10.784206796215157, 11.733846765603325, 12.800966089934708, 13.733495669892763, 12.751325731263645, 11.730990373492844, 10.705760130960748, 9.744050708753011, 8.815187358975809, 7.796777724748923, 6.854469406620347, 6.808828680424395, 5.90495089790462, 4.955713001469595, 5.881099919113435, 6.846424550379489, 7.874004337554776, 8.81117979134584, 9.779709552542661, 10.771915680736374, 11.699449492366089, 12.645596384021562, 13.597997785279206, 14.560653440687217, 13.631694492352093, 12.653884122426962, 11.674646599729158, 10.764291081645156, 9.774911589845383, 8.721915019105639, 7.759171739685071, 7.752859423219443, 6.903786233990593, 6.029533082382198, 6.9085175801289305, 7.817196288030381, 8.844317779633895, 9.785939340829252, 10.818350315343444, 11.792420956678034, 12.64120340028805, 13.667060469989037, 14.596168093060086, 15.578335934231651, 14.63613799956126, 13.606364045856001, 12.694609666810877, 11.67061989768185, 10.629549284571377, 9.621156991014985, 8.688602069447912, 8.764090796504036, 7.886068907910995, 7.011844159533634, 7.9395945257104135, 8.842552136909777, 9.870468606570892, 10.762230787720132, 11.79973229927661, 12.755340721563355, 13.582677436898708, 14.539278490258223, 15.528097499025701, 16.482002105178285, 15.552524233013965, 14.502278511250125, 13.531281346341984, 12.601694746241346, 11.662739421889324, 10.611685206732142, 9.625688299322457, 9.73350993714091, 8.906665702358893, 8.048993839777449, 8.977031430955474, 9.773312765408809, 10.777857297903624, 11.714138395134263, 12.741396584518979, 13.705967220538485, 14.620891936948787, 15.551321681969995, 16.550460331643695, 16.498569703770666, 15.559171098712932, 14.63319591379101, 13.821540609320953, 12.922734814614737, 12.243434939105535, 11.600100040377132, 10.593126902807539, 10.671589639901136, 9.893428268623293, 9.081968805762743, 9.9726265330285, 10.73704521709612, 11.721495762197623, 12.69463969342173, 13.636774487026146, 14.68025237503336, 15.566652414261842, 16.519912678782628, 16.511019377308013, 15.572059142229147, 14.625450601898615, 13.638464009665688, 12.859422904856546, 11.920039469554634, 11.249147027930471, 11.920544741592202, 11.573815427990567, 11.717811616692043, 10.902627486189015, 10.063934651059363, 11.000371387749773, 11.670787864388533, 12.644415734024657, 13.712875765740375, 14.688583539467997, 15.60921617231046, 16.527360776013214, 16.48523117825593, 15.584101348462267, 14.730443023903929, 13.746942342817356, 12.68123078037555, 11.853614581629158, 10.95598987632662, 10.21843740614691, 10.854261741875828, 11.83231389543907, 11.724127099182581, 11.849049045830323, 11.04427852190363, 11.978005362188325, 12.71035752763662, 13.600449409572601, 14.533112544103673, 15.478558331875579, 16.509659101214105, 16.49749590373863, 15.533881619958404, 14.529132309712983, 13.660758987754267, 12.755513207948585, 11.720569348568812, 10.877266301727001, 10.017191116588224, 9.1857860092301, 9.918908818767697, 10.905025082887114, 10.730470118614232, 11.65079001470018, 12.10300420547423, 13.011312255666502, 13.727779155477533, 14.659463329147966, 15.480374510926092, 16.50752495371395, 16.514958662683927, 15.495148015936174, 14.527121377707887, 13.601595047568258, 12.61451771604375, 11.759854875301818, 10.689423861543563, 9.806185473182275, 8.995061054753496, 8.180183273999997, 8.93257640864602, 9.902145763893586, 9.731127655499275, 10.71052244512633, 11.647615206432766, 12.615734706191619, 13.537043222261804, 14.551705340833777, 15.500357064433457, 16.438031460531786, 15.689489297949576, 14.696810754416799, 13.669356628249927, 12.704934744081298, 11.678331990088127, 10.740134815056251, 9.753480980649998, 8.79854700097476, 7.940805105296045, 7.129286471747796, 7.953896632237236, 8.900466072771192, 8.758245704598037, 9.699771085443597, 10.644660882962695, 11.640855712201624, 12.566217208186657, 13.562263466110423, 14.525186598974457, 15.549681558264659, 14.625360398497952, 13.656682575704528, 12.69803757663337, 11.676966124994603, 10.654238586813566, 9.716114331457117, 8.789314883804861, 7.872639047862372, 6.92404186882668, 6.167021206135328, 6.8867282934119505, 7.861994909158965, 7.699001072254854, 8.689650236661027, 9.650009716530347, 10.713019598950137, 11.686550849337014, 12.752456498937008, 13.640851587305132, 14.622398321902866, 13.78419858575926, 12.735197197638696, 11.694621720082683, 10.747760979942235, 9.716940734283039, 8.778736882523576, 7.837875989864836, 6.845302842523431, 5.922819244321874, 5.1196541783476714, 5.867628619547829, 6.854077617709009, 6.698666402201761, 7.644487231299207, 8.692113348653212, 9.750941415488619, 10.682803407401645, 11.701603970010176, 12.636140851124047, 13.659051705926188, 12.789807850848796, 11.809185308008976, 10.741057084796005, 9.71892427075115, 8.758399797409217, 7.834718751817206, 6.834684811212999, 5.872366480075586, 4.923520323907242, 4.100478413017216, 4.8965481291297355, 5.821343349256345, 5.732559753932482, 6.793213004159744, 7.8210969696921175, 8.768117494317586, 9.811949787838474, 10.731833303893861, 11.67612150222423, 12.697938285000888, 11.727761651731461, 10.79734021950953, 9.750390622063865, 8.787657881694923, 7.8269180342796645, 6.866260799735629, 5.895136426218565, 4.919500777412467, 3.968338416372018, 3.0753438736903056, 3.9693028213688692, 4.782562445377807, 4.822129739233156, 5.880243210009719, 6.883553365592741, 7.866171853080153, 8.830216379006998, 9.804701106716795, 10.811992958896345, 11.867571907669225, 10.901077597644921, 9.893512704717253, 8.82191644607331, 7.828520222897165, 6.883510099844583, 5.9410771483435925, 4.935247700308771, 3.965543534909861, 2.9463165509358316, 2.0054642214924367, 2.9500311378267954, 3.827329521649955, 3.950264449373905, 4.9127639363963995, 5.873415901062315, 6.920423872582361, 7.868719054686378, 8.887289786274629, 9.87707313875023, 10.89697227489029, 10.064102163133295, 9.026141406163752, 7.9545742562984785, 6.929828303687935, 5.955535280898132, 5.026116444426386, 3.9929525064556364, 3.0396924513478134, 2.0504271122615743, 0.9934773378813772, 1.9493043698025132, 2.900491080928112], [2.929187410182724, 1.9702121549097933, 0.9908751414725812, 0.0, 1.0282346396310484, 1.9833484506779082, 3.0106922642958858, 4.025576369023517, 4.965233506222617, 5.989659783968222, 7.042972460149226, 8.033389814500483, 9.09945332861199, 9.944060372747442, 8.937264462424489, 7.948786842303593, 6.991401363330002, 5.967028766101727, 4.966102638492871, 3.9393650421427644, 3.9480931878293, 3.0008870824355482, 1.9813880197765847, 1.0418014009795464, 2.058264068810207, 2.962550368995163, 3.9608189679160746, 4.952814781709721, 6.00457740750313, 7.026467381156049, 7.979863069585928, 8.939905143291078, 9.998715083018098, 10.81709872144371, 9.864392457995143, 8.930678351532736, 7.916849040819306, 6.997353602566007, 6.014192634325401, 4.993873532089626, 4.858677212758731, 3.9175220729358395, 2.960762481107249, 2.0315884793240384, 2.9859173354536312, 3.998730979797046, 4.963549067251594, 5.985437576678538, 7.001100565460916, 8.008355285991911, 9.000708763050373, 9.931501751839543, 10.983771981410785, 11.78664500108939, 10.812346227827629, 9.873713192301505, 8.92385445909676, 7.871158865502564, 6.85595589601414, 5.904126566342306, 5.86602607707734, 4.928612012057043, 3.9446064024173286, 3.0961428464297636, 4.047754601856515, 4.982060126488422, 5.930540903940994, 6.921649438343215, 7.9071997885014955, 8.88392517933596, 9.884376225032867, 10.91986661766019, 11.883769898756317, 12.77348657485192, 11.743036268735844, 10.699005939766966, 9.770487313326834, 8.835369237520124, 7.841790084358585, 6.888655791023493, 6.791601728500954, 5.867625934034693, 5.0005880419622635, 4.160661282127338, 5.0300165236168555, 6.038018819652424, 6.984510975000747, 7.925214374282621, 8.899325898625868, 9.843570371739837, 10.793210341128004, 11.85923631807274, 12.87210569491399, 13.742200872736227, 12.721865514965426, 11.69663527243333, 10.734925850225594, 9.806062500448391, 8.787652866221505, 7.845344548092928, 7.799703821896976, 6.895826039377202, 5.946588142942177, 5.215708020118408, 5.972579360237233, 7.0001591474125195, 7.937334601203583, 8.887521241417085, 9.831279256261054, 10.758813067890769, 11.704959959546242, 12.657361360803886, 13.647880332342048, 14.576839280677172, 13.644759263899545, 12.66552174120174, 11.755166223117739, 10.765786731317965, 9.712790160578221, 8.750046881157653, 8.743734564692025, 7.894661375463175, 7.02040822385478, 6.243125681133903, 6.943351097888124, 7.970472589491638, 8.912094150686995, 9.926162004217868, 10.851784532202714, 11.70056697581273, 12.726424045513717, 13.655531668584766, 14.637699509756331, 15.590508449151956, 14.597239187328583, 13.685484808283459, 12.661495039154431, 11.620424426043959, 10.612032132487567, 9.679477210920494, 9.754965937976616, 8.876944049383576, 8.002719301006216, 7.274202626715386, 7.9687069467675204, 8.996623416428633, 9.888385597577875, 10.907543988151033, 11.814704297088035, 12.642041012423388, 13.598642065782903, 14.587461074550381, 15.541365680702963, 15.640568257200801, 14.612398724697647, 13.960192359042283, 13.168738905358865, 12.653614563361906, 11.602560348204724, 10.616563440795039, 10.72438507861349, 9.897540843831475, 9.03986898125003, 8.327843730839168, 8.899467575266552, 9.904012107761368, 10.840293204992006, 11.867551394376722, 12.832122030396228, 13.680255512473469, 14.610685257494675, 15.609823907168376, 15.551898709592976, 14.612500104535243, 13.686524919613321, 12.931770937057042, 12.110589230801214, 13.176440425265696, 12.590975181849714, 11.58400204428012, 11.662464781373716, 10.884303410095875, 10.072843947235326, 9.323438832912194, 9.863200026953864, 10.847650572055366, 11.820794503279473, 12.76292929688389, 13.806407184891103, 14.626015989786524, 15.579276254307306, 15.564348383130326, 14.625388148051458, 13.678779607720926, 12.691793015487999, 11.969653232592634, 11.107893885741111, 12.182152514090632, 12.911419883064784, 12.56469056946315, 12.708686758164623, 11.893502627661597, 11.054809792531945, 10.351183687633467, 10.796942674246276, 11.7705705438824, 12.839030575598118, 13.81473834932574, 14.735370982168202, 15.586724351537896, 15.514091516081075, 14.612961686287411, 13.759303361729073, 12.800271348639669, 11.734559786197861, 10.906943587451467, 10.143844292513098, 11.15546636864015, 11.84513688334841, 12.823189036911652, 12.715002240655163, 12.839924187302906, 12.035153663376212, 11.32881766207202, 11.836512337494362, 12.726604219430344, 13.659267353961416, 14.604713141733322, 15.635813911071848, 15.526356241563775, 14.562741957783548, 13.557992647538127, 12.689619325579411, 11.808842213770896, 10.773898354391124, 9.93059530754931, 9.205045532774701, 10.131859361288043, 10.909783960240278, 11.895900224359696, 11.721345260086814, 12.641665156172762, 13.093879346946812, 12.362124555550196, 12.853933965335274, 13.78561813900571, 14.606529320783835, 15.633679763571696, 15.543819000509073, 14.524008353761317, 13.555981715533031, 12.630455385393402, 11.643378053868894, 10.813183881124129, 9.742752867365875, 8.859514479004584, 8.182915470939973, 9.130159388394196, 9.9234515501186, 10.893020905366166, 10.722002796971857, 11.701397586598912, 12.638490347905345, 13.351334369208278, 13.806753527425627, 14.731660011148527, 15.571452858102813, 15.58991114957615, 14.71834963577472, 13.725671092241942, 12.698216966075071, 11.733795081906441, 10.70719232791327, 9.793463820878564, 8.80680998647231, 7.851876006797071, 7.128659521482522, 8.079262586141994, 8.944771773709817, 9.891341214243772, 9.74912084607062, 10.69064622691618, 11.635536024435273, 12.631730853674203, 13.557092349659236, 14.553138607583001, 15.516061740447036, 14.609510627421708, 13.654220736323095, 12.685542913529671, 11.726897914458513, 10.705826462819747, 9.68309892463871, 8.769443337279428, 7.842643889627173, 6.925968053684683, 6.111896285013157, 7.116997320529526, 7.877603434884532, 8.852870050631546, 8.689876213727436, 9.680525378133607, 10.640884858002925, 11.703894740422715, 12.677425990809592, 13.743331640409586, 14.63172672877771, 13.73472317623661, 12.793323444286678, 11.76405753546384, 10.723482057907827, 9.776621317767379, 8.745801072108183, 7.832065888345887, 6.891204995687146, 5.898631848345741, 5.110673660508351, 6.06963029274187, 6.85850376102041, 7.84495275918159, 7.689541543674342, 8.635362372771787, 9.68298849012579, 10.741816556961197, 11.673678548874223, 12.692479111482754, 13.627015992596625, 12.771376560259933, 11.798932709376214, 10.83804564583412, 9.769917422621148, 8.747784608576294, 7.78726013523436, 6.888047757639517, 5.88801381703531, 4.925695485897896, 4.111374740093719, 5.091353554489796, 5.887423270602317, 6.8122184907289265, 6.723434895405063, 7.784088145632325, 8.8119721111647, 9.758992635790168, 10.802824929311056, 11.722708445366443, 12.666996643696812, 11.74191825025761, 10.736886510258879, 9.806465078036949, 8.759515480591283, 7.796782740222341, 6.8557783721048065, 5.895121137560771, 4.923996764043706, 3.9728297832347774, 3.156192832558496, 4.066219015162886, 4.960177962841451, 5.773437586850388, 5.813004880705737, 6.8711183514823, 7.874428507065322, 8.857046994552734, 9.82109152047958, 10.795576248189377, 11.802868100368926, 10.96130818283159, 9.910202456172339, 8.90263756324467, 7.831041304600729, 6.837645081424584, 5.8926349583720015, 4.950202006871011, 3.94437255883619, 3.0173596667288427, 2.1341709671223095, 2.996339362965018, 3.9409062792993765, 4.818204663122536, 4.941139590846486, 5.903639077868981, 6.864291042534896, 7.911299014054942, 8.859594196158959, 9.878164927747209, 10.86794828022281, 10.014982427146215, 9.073227021660715, 8.035266264691172, 6.963699114825897, 5.938953162215354, 4.9646601394255505, 4.035241302953805, 3.002077364983055, 2.0488173098752327, 1.0595519707889933, 1.9843524793539582, 2.9401795112750944, 3.891366222400693], [3.957422049813772, 2.9984467945408415, 2.0191097811036296, 1.0282346396310484, 0.0, 0.9551138110468597, 1.9824576246648373, 2.997341729392468, 3.9369988665915683, 4.9614251443371735, 6.014737820518177, 7.005155174869435, 8.071218688980942, 9.07961112191675, 9.965499102055539, 8.977021481934642, 8.01963600296105, 6.995263405732775, 5.994337278123919, 4.967599681773812, 4.976327827460349, 4.029121722066597, 3.009622659407633, 2.070036040610595, 1.0300294291791587, 1.9343157293641147, 2.932584328285026, 3.924580142078672, 4.976342767872081, 5.998232741525, 6.95162842995488, 7.911670503660031, 8.970480443387052, 9.986907615804322, 10.892627097626193, 9.958912991163784, 8.945083680450354, 8.025588242197054, 7.042427273956449, 6.022108171720674, 5.820603580445049, 4.879448440622157, 3.922688848793567, 2.956523128629913, 1.9576826958225828, 2.9704963401659974, 3.935314427620546, 4.95720293704749, 5.972865925829868, 6.980120646360863, 7.972474123419325, 8.903267112208495, 9.955537341779737, 10.951512176217431, 11.774272595513947, 10.835639559987824, 9.885780826783078, 8.833085233188882, 7.817882263700458, 6.866052934028624, 6.827952444763658, 5.890538379743361, 4.906532770103646, 4.021077495735638, 3.0195199622254663, 3.9538254868573737, 4.902306264309946, 5.8934147987121674, 6.8789651488704475, 7.855690539704912, 8.856141585401819, 9.891631978029142, 10.855535259125269, 11.818083699481019, 12.704962636422161, 11.660932307453283, 10.732413681013151, 9.797295605206441, 8.803716452044902, 7.850582158709811, 7.753528096187272, 6.8295523017210105, 5.9625144096485805, 5.011284330241903, 4.001781883985807, 5.009784180021376, 5.956276335369699, 6.896979734651573, 7.87109125899482, 8.815335732108789, 9.764975701496956, 10.831001678441693, 11.843871055282943, 12.790236899816211, 13.683791882651743, 12.658561640119647, 11.69685221791191, 10.767988868134708, 9.749579233907822, 8.807270915779247, 8.761630189583295, 7.857752407063519, 6.908514510628494, 5.98317418164004, 4.944344720606184, 5.971924507781471, 6.909099961572535, 7.859286601786037, 8.803044616630006, 9.73057842825972, 10.676725319915194, 11.629126721172838, 12.619645692711, 13.548604641046124, 14.526415010971254, 13.627448108888057, 12.717092590804056, 11.727713099004283, 10.67471652826454, 9.711973248843972, 9.705660932378343, 8.856587743149491, 7.982334591541097, 6.984009523906341, 5.915116458257074, 6.942237949860589, 7.883859511055945, 8.89792736458682, 9.823549892571666, 10.672332336181682, 11.698189405882669, 12.627297028953718, 13.609464870125283, 14.562273809520908, 14.669502429934361, 13.997996781219666, 13.62342140684075, 12.582350793730278, 11.573958500173886, 10.641403578606813, 10.716892305662935, 9.838870417069893, 8.921906285084987, 7.912028782119077, 6.940472307136471, 7.9683887767975845, 8.860150957946825, 9.879309348519985, 10.786469657456987, 11.61380637279234, 12.570407426151855, 13.559226434919333, 14.513131041071915, 14.62431349432241, 13.596143961819255, 12.943937596163892, 13.781682425128388, 13.615540931048224, 12.564486715891043, 11.578489808481358, 11.68631144629981, 10.740235527466934, 9.746534844307497, 8.818497253129472, 7.871232935635502, 8.875777468130318, 9.812058565360957, 10.839316754745672, 11.803887390765178, 12.65202087284242, 13.582450617863627, 14.581589267537328, 14.535643946714584, 13.596245341656852, 12.67027015673493, 11.91551617417865, 12.723532750570739, 13.789383945035219, 13.552901549536033, 12.54592841196644, 12.624391149060035, 11.726998093731334, 10.773979346415885, 9.79285426991669, 8.834965387322814, 9.819415932424317, 10.792559863648423, 11.73469465725284, 12.778172545260054, 13.597781350155476, 14.551041614676258, 14.548093620251935, 13.609133385173067, 12.662524844842535, 11.675538252609607, 10.953398469714243, 11.720837405510636, 12.795096033860155, 13.720692116307102, 13.526616937149468, 13.670613125850942, 12.700064857795429, 11.755945191712504, 10.7693760735301, 9.768708034615226, 10.74233590425135, 11.810795935967068, 12.78650370969469, 13.707136342537153, 14.558489711906848, 14.485856876450027, 13.584727046656363, 12.731068722098025, 11.784016585761275, 10.71830502331947, 9.890688824573076, 10.756787812282623, 11.768409888409675, 12.654409116590728, 13.63246127015397, 13.702078937059012, 13.646486417436737, 12.736289062556772, 11.747010047968653, 10.808277697863314, 11.698369579799294, 12.631032714330367, 13.576478502102272, 14.607579271440798, 14.498121601932727, 13.5345073181525, 12.529758007907079, 11.661384685948363, 10.792587450892505, 9.757643591512732, 8.91434054467092, 9.817989052544226, 10.744802881057568, 11.719056193482595, 12.746473558666096, 12.7369585318233, 13.657278427909247, 13.795014746127372, 12.780316941446829, 11.825699325704226, 12.75738349937466, 13.578294681152785, 14.605445123940646, 14.515584360878025, 13.49577371413027, 12.527747075901983, 11.602220745762354, 10.615143414237846, 9.796929118245737, 8.726498104487483, 7.843259716126194, 8.795858990709498, 9.784559374004177, 10.827240523093444, 11.79680987834101, 11.737616068708343, 12.717010858335398, 13.666724987536396, 13.769526755104911, 12.77851888779458, 13.703425371517477, 14.543218218471763, 14.561676509945098, 13.690114996143668, 12.69743645261089, 11.66998232644402, 10.705560442275393, 9.678957688282223, 8.777209058000171, 7.790555223593918, 6.83562124391868, 7.8193287508573475, 8.808016127941928, 9.848560746684662, 10.795130187218616, 10.764734117807105, 11.706259498652665, 12.663770664066325, 13.659965493305254, 13.749344901869726, 14.745391159793492, 14.605770947080858, 13.581275987790656, 12.625986096692044, 11.65730827389862, 10.698663274827462, 9.677591823188699, 8.654864285007662, 7.753188574401037, 6.826389126748781, 5.909713290806291, 6.863224023009323, 7.868325058525693, 8.812230837814818, 9.817714904934403, 9.718110853358484, 10.708760017764657, 11.669119497633977, 12.732129380053767, 13.705660630440644, 14.72780656890663, 13.705906432172752, 12.706488536605558, 11.765088804655626, 10.735822895832788, 9.695247418276775, 8.74838667813633, 7.717566432477133, 6.815811125467495, 5.874950232808755, 4.88237708546735, 5.862001398504518, 6.820958030738036, 7.823348615323267, 8.809797613484447, 8.717776183305391, 9.663597012402837, 10.711223129756842, 11.770051196592249, 12.701913188505275, 13.653002931342868, 12.766052775431023, 11.743141920628881, 10.770698069745162, 9.809811006203068, 8.741682782990097, 7.719549968945244, 6.75902549560331, 5.871792994761125, 4.871759054156918, 3.9094407230195047, 4.862919288932059, 5.892813164617152, 6.852268124905174, 7.827491539162063, 7.751669535036111, 8.812322785263373, 9.840206750795746, 10.787227275421214, 11.831059568942102, 12.679788591733587, 11.735500393403218, 10.71368361062656, 9.708651870627829, 8.778230438405899, 7.731280840960234, 6.768548100591292, 5.827543732473757, 4.8668864979297215, 3.8957621244126575, 2.956575020356386, 3.9077373813968355, 4.963440492459829, 5.925022817144308, 6.801672226481436, 6.841239520336785, 7.899352991113348, 8.90266314669637, 9.88528163418378, 10.849326160110628, 11.823810887820425, 10.941566743801342, 9.933073543200543, 8.881967816541291, 7.874402923613623, 6.80280666496968, 5.809410441793535, 4.864400318740953, 3.9219673672399624, 2.9161379192051413, 2.001104903850451, 3.0203318878244807, 3.9611842172678755, 4.905751133602235, 5.846439302753584, 5.969374230477534, 6.931873717500029, 7.892525682165944, 8.93953365368599, 9.887828835790007, 10.906399567378259, 10.006646923655227, 8.986747787515167, 8.044992382029667, 7.007031625060122, 5.935464475194848, 4.910718522584305, 3.9364254997945016, 3.0070066633227563, 1.9738427253520068, 1.0325625469968411, 2.0218278860830803, 3.0125871189850066, 3.9684141509061424, 4.919600862031741], [4.912535860860632, 3.9535606055877013, 2.9742235921504894, 1.9833484506779082, 0.9551138110468597, 0.0, 1.0273438136179776, 2.042227918345608, 2.9818850555447085, 4.006311333290314, 5.059624009471317, 6.050041363822575, 7.116104877934082, 8.124497310869891, 9.131293221192845, 9.932135292981503, 8.974749814007911, 7.950377216779636, 6.949451089170779, 5.922713492820672, 5.9314416385072075, 4.9842355331134565, 3.964736470454493, 3.0251498516574546, 1.9684365448270649, 0.979201918317255, 1.9774705172381664, 2.9694663310318123, 4.0212289568252215, 5.0431189304781405, 5.996514618908019, 6.95655669261317, 8.015366632340191, 9.031793804757461, 9.984500068206028, 10.914026802210644, 9.900197491497215, 8.980702053243915, 7.997541085003308, 6.977221982767533, 6.759010696092955, 5.817855556270064, 4.861095964441473, 3.8949302442778193, 2.896089811470489, 2.0188016472168027, 2.9802006165736863, 4.00208912600063, 5.0177521147830095, 6.025006835314004, 7.017360312372464, 7.948153301161634, 9.000423530732876, 9.99639836517057, 10.932792647798857, 11.774046675635729, 10.824187942430983, 9.771492348836787, 8.756289379348363, 7.80446004967653, 7.766359560411564, 6.828945495391267, 5.844939885751552, 4.9594846113835445, 3.9579270778733724, 3.002130793908179, 3.9506115713607506, 4.941720105762973, 5.927270455921253, 6.903995846755717, 7.904446892452624, 8.936518166982282, 9.900421448078408, 10.862969888434158, 11.893420194550234, 12.599339423101188, 11.670820796661056, 10.735702720854347, 9.742123567692808, 8.788989274357718, 8.691935211835178, 7.767959417368917, 6.900921525296487, 5.949691445889809, 4.940188999633713, 4.0580894870721815, 5.004581642420504, 5.945285041702379, 6.919396566045625, 7.863641039159593, 8.81328100854776, 9.875887867394832, 10.888757244236082, 11.83512308876935, 12.855458446540151, 13.596968755767552, 12.635259333559816, 11.706395983782613, 10.687986349555727, 9.745678031427152, 9.7000373052312, 8.796159522711426, 7.8469216262764006, 6.921581297287946, 5.88275183625409, 5.10889401341654, 6.046069467207603, 6.907591908836842, 7.851349923680811, 8.778883735310526, 9.725030626966, 10.677432028223643, 11.667950999761805, 12.596909948096929, 13.57472031802206, 14.553957840719864, 13.65549970645196, 12.666120214652189, 11.613123643912445, 10.650380364491877, 10.644068048026249, 9.794994858797399, 8.920741707189002, 7.922416639554248, 6.853523573904981, 6.079207455495658, 7.020829016691016, 7.946232671637626, 8.871855199622471, 9.720637643232488, 10.746494712933474, 11.675602336004523, 12.657770177176088, 13.610579116571714, 13.78954575454016, 14.741243636388969, 14.561828522488655, 13.520757909378183, 12.51236561582179, 11.579810694254718, 11.65529942131084, 10.7772775327178, 9.860313400732894, 8.850435897766985, 7.878879422784378, 7.105358282432654, 7.997120463581894, 8.92761465557079, 9.834774964507792, 10.662111679843145, 11.61871273320266, 12.607531741970138, 13.561436348122722, 13.744356818928209, 12.716187286425054, 13.687184451333195, 14.616771051433833, 14.55394804669613, 13.502893831538948, 12.516896924129263, 12.624718561947715, 11.678642643114841, 10.684941959955404, 9.756904368777379, 8.80964005128341, 8.14768939190774, 9.06364935559188, 9.93166267757838, 10.854138777151116, 11.700326179893224, 12.630755924914432, 13.629894574588134, 13.655687271320383, 12.71628866626265, 11.790313481340728, 12.753525719383678, 13.6786465616176, 14.74449775608208, 14.491308665183938, 13.484335527614345, 13.56279826470794, 12.66540520937924, 11.71238646206379, 10.731261385564597, 9.773372502970721, 9.091327856201739, 10.046856519732989, 10.908342284646393, 11.922944576626227, 12.64608665720628, 13.599346921727063, 13.668136944857734, 12.729176709778866, 11.782568169448334, 10.795581577215406, 11.79140801491927, 12.675951216557497, 13.750209844907015, 14.675805927353963, 14.465024052797373, 14.609020241498847, 13.638471973443334, 12.69435230736041, 11.707783189178006, 10.707115150263133, 10.155091837110605, 11.095275719075989, 11.960151337088243, 12.851908373903326, 13.606795018957651, 13.530743065403167, 12.629613235609503, 11.775954911051164, 10.904059910367074, 9.838348347925269, 10.789156894620374, 11.711901623329483, 12.723523699456535, 13.609522927637588, 14.58757508120083, 14.657192748105873, 14.584893533084642, 13.674696178204677, 12.685417163616558, 11.74668481351122, 11.11112551265855, 12.043788647189622, 12.94985903703171, 13.802672379533329, 13.543007790885866, 12.579393507105639, 11.574644196860218, 10.706270874901502, 9.912630775498304, 8.877686916118531, 9.82687918150318, 10.773102863591086, 11.699916692104429, 12.674170004529456, 13.701587369712957, 13.692072342870159, 14.612392238956106, 14.733421861775277, 13.718724057094734, 12.764106441352132, 12.170139432233915, 12.99105061401204, 13.992274910713311, 13.560470549831164, 12.540659903083409, 11.572633264855122, 10.647106934715493, 9.660029603190985, 8.916972442851536, 7.846541429093282, 8.798373527173053, 9.750972801756358, 10.739673185051037, 11.782354334140303, 12.75192368938787, 12.692729879755202, 13.672124669382256, 14.621838798583257, 14.707933870752816, 13.716926003442484, 13.116181304376733, 13.955974151331018, 13.606562698898239, 12.73500118509681, 11.742322641564032, 10.71486851539716, 9.750446631228533, 8.723843877235362, 7.897252382605971, 6.910598548199717, 7.790735054965539, 8.774442561904207, 9.763129938988786, 10.80367455773152, 11.750243998265475, 11.719847928853964, 12.661373309699524, 13.618884475113186, 14.615079304352115, 14.687752017517631, 14.168932923805556, 13.650657136033999, 12.626162176743797, 11.670872285645185, 10.702194462851761, 9.743549463780603, 8.722478012141838, 7.699750473960801, 6.873231899006836, 5.94643245135458, 6.864827101853151, 7.818337834056182, 8.823438869572552, 9.767344648861677, 10.772828715981262, 10.673224664405344, 11.663873828811518, 12.624233308680838, 13.687243191100627, 14.660774441487504, 13.77269275785977, 12.750792621125894, 11.751374725558701, 10.809974993608769, 9.78070908478593, 8.740133607229916, 7.793272867089469, 6.762452621430273, 5.863941057330856, 4.994993557414554, 5.837490896514209, 6.8171152095513765, 7.776071841784895, 8.778462426370126, 9.764911424531306, 9.672889994352252, 10.618710823449698, 11.666336940803703, 12.72516500763911, 13.657026999552135, 12.69788912029601, 11.810938964384166, 10.788028109582024, 9.815584258698305, 8.85469719515621, 7.786568971943238, 6.764436157898384, 5.80391168455645, 4.919922926624486, 3.980190782607467, 4.8645545340663645, 5.818033099978919, 6.847926975664012, 7.807381935952033, 8.782605350208922, 8.706783346082972, 9.767436596310233, 10.795320561842606, 11.742341086468075, 12.719909933781711, 11.724674780686728, 10.780386582356359, 9.758569799579702, 8.75353805958097, 7.82311662735904, 6.776167029913374, 5.813434289544432, 4.872429921426897, 3.911772686882862, 2.9406483133657977, 3.9116888314032456, 4.862851192443695, 5.918554303506688, 6.880136628191167, 7.756786037528296, 7.796353331383645, 8.854466802160209, 9.85777695774323, 10.84039544523064, 11.804439971157485, 10.983632366346143, 9.986452932754482, 8.977959732153682, 7.926854005494429, 6.919289112566762, 5.84769285392282, 4.854296630746675, 3.909286507694093, 2.9668535561931026, 1.9610241081582818, 2.956218714897311, 3.9754456988713405, 4.916298028314735, 5.8608649446490935, 6.801553113800444, 6.924488041524394, 7.8869875285468884, 8.847639493212803, 9.894647464732849, 10.842942646836866, 10.041316465083968, 9.051533112608366, 8.031633976468306, 7.0898785709828065, 6.0519178140132635, 4.980350664147989, 3.955604711537445, 2.981311688747642, 2.0518928522758966, 1.018728914305147, 1.987676358043701, 2.97694169712994, 3.9677009300318664, 4.923527961953003, 5.874714673078601], [5.93987967447861, 4.98090441920568, 4.001567405768467, 3.0106922642958858, 1.9824576246648373, 1.0273438136179776, 0.0, 1.0148841047276305, 1.954541241926731, 2.978967519672336, 4.03228019585334, 5.022697550204597, 6.088761064316104, 7.097153497251914, 8.103949407574866, 9.092427027695763, 10.00209362762589, 8.977721030397614, 7.9767949027887575, 6.950057306438651, 6.958785452125186, 6.011579346731434, 4.992080284072471, 4.052493665275432, 2.9957803584450424, 2.0065457319352324, 0.9501267036201889, 1.9421225174138352, 2.9938851432072444, 4.015775116860163, 4.969170805290043, 5.929212878995194, 6.988022818722214, 8.004449991139484, 8.957156254588051, 10.025660800655336, 10.927541305115193, 10.008045866861893, 9.024884898621286, 8.004565796385512, 7.7863545097109315, 6.84519936988804, 5.88843977805945, 4.922274057895796, 3.9234336250884665, 2.984059405453431, 1.9528568029557087, 2.9747453123826526, 3.9904083011650315, 4.997663021696026, 5.990016498754487, 6.920809487543657, 7.973079717114898, 8.969054551552594, 9.90544883418088, 10.844081869707004, 11.79394060291175, 10.798836162454764, 9.78363319296634, 8.831803863294507, 8.79370337402954, 7.856289309009243, 6.872283699369529, 5.972628332390775, 4.9333688208414, 3.9079268619186927, 2.959446084466121, 3.950554618868343, 4.936104969026624, 5.912830359861088, 6.913281405557995, 7.909174353364305, 8.873077634460431, 9.835626074816181, 10.866076380932258, 11.855158138293383, 12.698164610279033, 11.763046534472323, 10.769467381310784, 9.816333087975694, 9.719279025453154, 8.795303230986892, 7.928265338914463, 6.925133188857837, 5.91563074260174, 4.963885555082695, 4.013416155525874, 4.954119554807749, 5.928231079150996, 6.872475552264964, 7.8221155216531315, 8.848544053776855, 9.861413430618105, 10.807779275151374, 11.828114632922174, 12.856118656325366, 13.662603147177794, 12.733739797400592, 11.715330163173704, 10.773021845045129, 10.727381118849177, 9.771647854334839, 8.822409957899813, 7.897023040255974, 6.858193579222117, 5.995267346178542, 5.058091892387479, 5.916426421942212, 6.860184436786182, 7.787718248415897, 8.73386514007137, 9.686266541329013, 10.676785512867175, 11.605744461202299, 12.58355483112743, 13.562792353825234, 14.490125354710225, 13.693464028270165, 12.640467457530422, 11.677724178109854, 11.671411861644225, 10.770483190420812, 9.896230038812416, 8.897858382522275, 7.828965316873008, 6.96558078825766, 6.120302568602419, 6.955067184742996, 7.880689712727843, 8.72947215633786, 9.755329226038844, 10.684436849109893, 11.666604690281458, 12.619413629677084, 13.536034754556468, 14.490213901813185, 15.452378999345283, 14.54810172299616, 13.539709429439768, 12.607154507872695, 12.682643234928817, 11.752765864341214, 10.83575514370092, 9.825877640735012, 8.854321165752404, 7.991731615194656, 7.096594015493298, 7.936449168676161, 8.843609477613164, 9.670946192948517, 10.627547246308032, 11.616366255075508, 12.570270861228092, 13.304192004857356, 13.722699378670534, 14.693696543578675, 15.623283143679313, 15.581291860314106, 14.530237645156925, 13.54424073774724, 13.652062375565691, 12.654084386082868, 11.660383702923431, 10.732346111745406, 9.785081794251436, 9.034062724669742, 8.163122907503283, 8.94049719068375, 9.862973290256488, 10.709160692998598, 11.639590438019804, 12.638729087693504, 12.808025783641588, 12.276123852191798, 12.796825573586208, 13.760037811629157, 14.687755394324721, 15.761330432658694, 15.518652478801915, 14.511679341232322, 14.590142078325917, 13.640846952347268, 12.687828205031817, 11.706703128532624, 10.748814245938748, 9.97770118896374, 9.146330071644392, 9.917176797751763, 10.931779089731599, 11.654921170311653, 12.608181434832435, 12.710329981319305, 11.822318540285622, 11.342403355377481, 11.802093669460886, 12.79792010716475, 13.703295030175475, 14.777553658524994, 15.703149740971941, 15.49236786641535, 15.636364055116823, 14.61391371641136, 13.669794050328436, 12.683224932146032, 11.68255689323116, 11.041465169872607, 10.194749270987392, 10.968985850193613, 11.860742887008698, 12.615629532063025, 12.553086110107461, 11.651956280313797, 10.798297955755459, 10.270746031310438, 10.844860440170748, 11.795668986865854, 12.739245436947462, 13.750867513074514, 14.636866741255567, 15.614918894818809, 15.684536561723851, 15.560335276052669, 14.650137921172703, 13.660858906584584, 12.722126556479246, 11.997498845420552, 11.156586837917903, 11.95869355013708, 12.8115068926387, 12.56535083559016, 11.601736551809934, 10.596987241564513, 9.728613919605797, 9.216440565697532, 9.88419900836401, 10.83339127374866, 11.800446677209065, 12.727260505722407, 13.701513818147435, 14.728931183330936, 14.719416156488137, 15.639736052574085, 15.708863604743303, 14.69416580006276, 13.739548184320158, 13.056512764995917, 12.103848804740322, 13.001109423818681, 12.582813594535457, 11.563002947787702, 10.594976309559417, 9.669449979419788, 8.68237264789528, 8.150727220076309, 8.853053521338762, 9.825717340791032, 10.778316615374337, 11.767016998669016, 12.809698147758281, 13.779267503005848, 13.72007369337318, 14.699468483000235, 15.649182612201232, 15.683375613720843, 14.692367746410511, 14.002554637138735, 13.0687723420593, 12.584665842447166, 11.713104328645736, 10.720425785112958, 9.692971658946087, 8.772789675932826, 7.746186921939656, 7.102261266076353, 7.9171106404451965, 8.818078868583518, 9.801786375522186, 10.790473752606765, 11.831018371349499, 12.777587811883453, 12.747191742471943, 13.688717123317502, 14.64622828873116, 15.509323514045873, 14.587729670370726, 13.59168341244696, 12.628760279582925, 11.604265320292724, 10.648975429194111, 9.680297606400687, 8.72165260732953, 7.744821056846131, 6.722093518665095, 6.078240782477218, 6.95294454360006, 7.892170915471128, 8.84568164767416, 9.85078268319053, 10.794688462479655, 11.80017252959924, 11.700568478023321, 12.691217642429494, 13.651577122298812, 14.578453198833047, 13.677672745948264, 12.745348944241794, 11.723448807507916, 10.724030911940723, 9.78263117999079, 8.758812228334856, 7.718236750778843, 6.815615911793763, 5.784795666134567, 5.003360535539247, 6.001505649660034, 6.864834710132187, 7.844459023169355, 8.803415655402874, 9.805806239988105, 10.792255238149284, 10.700233807970228, 11.646054637067675, 12.693680754421678, 13.605787295925921, 12.673925304012895, 11.670545306678033, 10.783595150766187, 9.760684295964046, 8.788240445080326, 7.832800338705136, 6.764672115492164, 5.786779202602678, 4.826254729260744, 4.0593424048328774, 5.007534596225445, 5.891898347684342, 6.845376913596896, 7.875270789281989, 8.834725749570012, 9.809949163826902, 9.734127159700948, 10.79478040992821, 11.822664375460583, 12.736398413684622, 11.692566120163734, 10.697330967068751, 9.753042768738382, 8.731225985961725, 7.7261942459629935, 6.7957728137410625, 5.7488232162953965, 4.786090475926454, 3.8947729661311907, 3.051192165091253, 3.9679921269837752, 4.939032645021223, 5.890195006061672, 6.945898117124665, 7.907480441809145, 8.784129851146274, 8.823697145001622, 9.881810615778186, 10.885120771361208, 11.86773925884862, 10.930773280437963, 9.956288552728166, 8.959109119136505, 7.950615918535704, 6.899510191876453, 5.8919452989487855, 4.820349040304842, 3.8269528171286975, 2.8819426940761157, 1.9999656927828995, 2.988367921776259, 3.9835625285152885, 5.0027895124893185, 5.943641841932713, 6.888208758267072, 7.828896927418422, 7.951831855142372, 8.914331342164866, 9.874983306830782, 10.921991278350827, 10.072843030366535, 9.013972651465991, 8.02418929899039, 7.00429016285033, 6.062534757364829, 5.024574000395285, 3.953006850530011, 2.9282608979194675, 1.9539678751296645, 1.0245490386579192, 2.0460727279231246, 3.0150201716616785, 4.004285510747918, 4.995044743649845, 5.950871775570981, 6.902058486696579], [6.954763779206241, 5.99578852393331, 5.016451510496098, 4.025576369023517, 2.997341729392468, 2.042227918345608, 1.0148841047276305, 0.0, 0.9396571371991005, 1.9640834149447055, 3.017396091125709, 4.007813445476966, 5.073876959588473, 6.082269392524283, 7.089065302847235, 8.077542922968131, 9.034928401941723, 9.992605135125245, 8.991679007516389, 7.964941411166281, 7.973669556852817, 7.026463451459065, 6.006964388800101, 5.067377770003063, 4.010664463172673, 3.021429836662863, 1.9650108083478193, 1.0496479558619909, 1.9952029435921899, 3.0008910121325325, 3.954286700562412, 4.914328774267563, 5.973138713994584, 6.989565886411854, 7.942272149860421, 9.010776695927706, 9.960376079431027, 10.888697924095204, 10.039769003348917, 9.019449901113143, 8.801238614438564, 7.860083474615672, 6.903323882787081, 5.937158162623428, 4.938317729816097, 3.9989435101810615, 2.967740907683339, 2.108940839336732, 3.011640135298295, 4.01889485582929, 4.975132394026856, 5.905925382816026, 6.958195612387267, 7.954170446824961, 8.890564729453251, 9.829197764979375, 10.77905649818412, 11.813720267182397, 10.798517297693973, 9.84668796802214, 9.808587478757172, 8.871173413736875, 7.88716780409716, 6.987512437118404, 5.9482529255690295, 4.922810966646323, 3.9743301891937515, 3.176008999326287, 4.027558589089589, 5.004283979924053, 6.00473502562096, 6.894290248636674, 7.8581935297328, 8.82074197008855, 9.851192276204626, 10.840274033565754, 11.708090408686779, 12.643208484493488, 11.784351486038418, 10.831217192703326, 10.734163130180786, 9.810187335714524, 8.943149443642096, 7.940017293585466, 6.93051484732937, 5.978769659810325, 5.028300260253505, 4.239876572028946, 5.019684699213961, 5.963929172327929, 6.9135691417160965, 7.833659949049224, 8.846529325890474, 9.792895170423742, 10.813230528194543, 11.841234551597735, 12.707186270440594, 13.636049620217797, 12.730214267901337, 11.78790594977276, 11.742265223576808, 10.786531959062469, 9.837294062627443, 8.911907144983603, 7.873077683949747, 7.010151450906173, 6.072975997115109, 5.202183439163409, 5.951638056849147, 6.879171868478862, 7.825318760134335, 8.77772016139198, 9.768239132930141, 10.697198081265265, 11.675008451190395, 12.6542459738882, 13.58157897477319, 14.63447460662541, 13.655351562258053, 12.692608282837485, 12.686295966371857, 11.785367295148442, 10.911114143540045, 9.912742487249904, 8.843849421600638, 7.9804648929852915, 7.135186673330049, 6.240824201964193, 6.972143332790807, 7.820925776400824, 8.84678284610181, 9.77589046917286, 10.758058310344424, 11.71086724974005, 12.627488374619434, 13.581667521876149, 14.54383261940825, 15.562985827723791, 14.554593534167399, 13.622038612600326, 13.697527339656448, 12.767649969068843, 11.85063924842855, 10.840761745462641, 9.869205270480034, 9.006615719922287, 8.111478120220928, 7.222206185897358, 7.935063097676128, 8.762399813011482, 9.719000866370997, 10.707819875138474, 11.661724481291056, 12.714552956854545, 13.70084684273454, 14.635726706931923, 15.56531330703256, 16.504268631384583, 15.545121749884556, 14.559124842474871, 14.666946480293323, 13.668968490810498, 12.67526780765106, 11.747230216473035, 10.799965898979066, 10.048946829397373, 9.178007012230914, 8.226254207904947, 8.954426910319452, 9.800614313061562, 10.73104405808277, 11.73018270775647, 11.896704981529796, 12.791326775318678, 13.649364098362806, 14.612576336405755, 15.54029391910132, 16.613868957435294, 16.533536583529546, 15.526563445959953, 15.605026183053548, 14.655731057074897, 13.702712309759448, 12.721587233260253, 11.763698350666377, 10.992585293691372, 10.145068608577377, 9.20293381497296, 10.023232709794563, 10.746374790374617, 11.699635054895401, 11.799009179207514, 10.91099773817383, 11.857606278504361, 12.654632194237484, 13.650458631941348, 14.589842067243259, 15.66410069559278, 16.626427392608996, 16.50725197114298, 16.651248159844453, 15.628797821138992, 14.684678155056067, 13.698109036873664, 12.69744099795879, 12.056349274600239, 11.193487807920377, 10.25474286741481, 10.952196507071662, 11.707083152125989, 11.641765307995671, 10.740635478202007, 9.886977153643668, 10.877208338480177, 11.697398964947347, 12.648207511642452, 13.632520912364974, 14.644142988492026, 15.56014439289262, 16.53819654645586, 16.607814213360907, 16.5752193807803, 15.665022025900335, 14.675743011312216, 13.737010661206877, 13.012382950148183, 12.155325374850886, 11.244450567358276, 11.902960512701664, 11.65403003347837, 10.690415749698143, 9.685666439452723, 8.817293117494007, 9.822902872867271, 10.736737533140609, 11.685929798525258, 12.72372432884612, 13.650538157359463, 14.62479146978449, 15.652208834967992, 15.69711351193525, 16.617433408021196, 16.723747709470935, 15.709049904790392, 14.75443228904779, 14.071396869723548, 13.102587341673305, 12.286866441039878, 11.671492792423669, 10.651682145675913, 9.683655507447627, 8.758129177307998, 7.7710518457834885, 8.813793969048785, 9.70559204611536, 10.748994992428088, 11.701594267011393, 12.690294650306072, 13.740013773255484, 14.70958312850305, 14.697771048820293, 15.677165838447348, 16.5624190419239, 15.594299542165045, 14.574333278605357, 13.559671160033384, 12.611019436433704, 11.673345040335374, 10.801783526533944, 9.809104983001166, 8.781650856834295, 7.861468873821035, 6.834866119827865, 7.849651040534097, 8.769649165221795, 9.769915644448893, 10.753623151387561, 11.74231052847214, 12.782855147214875, 13.729424587748829, 13.724889097919055, 14.666414478764615, 15.59419754117301, 14.59800271193408, 13.676408868258934, 12.680362610335168, 11.717439477471133, 10.692944518180932, 9.73765462708232, 8.768976804288895, 7.8103318052177375, 6.833500254734341, 5.810772716553304, 6.878683620724402, 7.805483068376658, 8.844007691336504, 9.797518423539534, 10.802619459055904, 11.74652523834503, 12.777869885046353, 12.7150439604309, 13.705693124837074, 14.666052604706392, 13.667132396721255, 12.766351943836472, 11.834028142130002, 10.812128005396126, 9.812710109828933, 8.871310377879, 7.847491426223064, 6.806915948667051, 5.904295109681971, 4.873474864022776, 5.871372964588732, 6.869518078709518, 7.816671485997562, 8.796295799034729, 9.755252431268248, 10.783503595435217, 11.769952593596397, 11.714709290377808, 12.660530119475254, 13.708156236829257, 12.69446649381413, 11.762604501901103, 10.759224504566241, 9.872274348654397, 8.849363493852255, 7.876919642968535, 6.921479536593344, 5.853351313380372, 4.875458400490887, 3.9149339271489527, 4.927354833882362, 5.927388774486569, 6.843735123549717, 7.7972136894622714, 8.827107565147363, 9.812423105017125, 10.787646519274015, 10.748602642108528, 11.80925589233579, 12.772098136198299, 11.82507761157283, 10.781245318051942, 9.78601016495696, 8.84172196662659, 7.819905183849933, 6.8148734438512015, 5.8844520116292705, 4.8375024141836045, 3.874769673814663, 2.9834521640193996, 3.944109398563435, 4.9152337720805, 5.890869420886598, 6.842031781927047, 7.89773489299004, 8.896645888993195, 9.798605333553853, 9.838172627409202, 10.896286098185765, 11.90000487608884, 10.940918194124842, 9.915889175710332, 8.941404448000535, 7.9442250144088735, 6.9600056909016335, 5.988189389764661, 4.9806244968369935, 3.9090282381930503, 2.915632015016906, 1.9706218919643241, 2.9474825636145985, 3.9533120116494196, 4.972727975699338, 5.991954959673368, 6.932807289116763, 7.8773742054511215, 8.843372409826001, 8.966715959870003, 9.929215446892497, 10.889867411558413, 10.006254107742919, 9.057958925638902, 7.999088546738359, 7.009305194262757, 5.989406058122698, 5.047650652637198, 4.026583441302995, 3.0265515705608985, 2.001805617950355, 1.042647073017873, 1.9720659094896182, 3.0401039917106, 4.029904276389309, 5.019169615475548, 6.009928848377475, 6.9657558802986115, 7.91694259142421], [7.894420916405341, 6.935445661132411, 5.956108647695198, 4.965233506222617, 3.9369988665915683, 2.9818850555447085, 1.954541241926731, 0.9396571371991005, 0.0, 1.024426277745605, 2.0777389539266085, 3.0681563082778656, 4.1342198223893725, 5.142612255325182, 6.1494081656481345, 7.137885785769031, 8.095271264742623, 9.119643861970898, 9.931336144715488, 8.904598548365382, 8.913326694051918, 7.966120588658166, 6.946621525999202, 6.007034907202163, 4.950321600371773, 3.9610869738619634, 2.9046679455469198, 1.9893050930610914, 1.0555458063930894, 2.061233874933432, 3.0146295633633113, 3.9746716370684623, 5.033481576795483, 6.049908749212753, 7.00261501266132, 8.071119558728604, 9.020718942231927, 9.949040786896104, 10.979426140548016, 9.959107038312244, 9.740895751637664, 8.799740611814773, 7.842981019986182, 6.876815299822528, 5.8779748670151974, 4.938600647380162, 3.9073980448824397, 3.0485979765358326, 2.0719829980991946, 3.079237718630189, 4.035475256827755, 4.966268245616925, 6.0185384751881665, 7.014513309625861, 7.95090759225415, 8.889540627780274, 9.83939936098502, 10.892094954579216, 11.738174434893073, 10.78634510522124, 10.748244615956272, 9.810830550935975, 8.82682494129626, 7.927169574317505, 6.88791006276813, 5.862468103845424, 4.913987326392852, 4.073451802048768, 3.087901451890488, 4.064626842724953, 5.065077888421859, 5.954633111437573, 6.918536392533699, 7.881084832889449, 8.911535139005526, 9.900616896366653, 10.768433271487678, 11.703551347294388, 12.697130500455927, 11.770874329902426, 11.673820267379886, 10.749844472913626, 9.882806580841194, 8.879674430784567, 7.87017198452847, 6.918426797009426, 5.967957397452605, 5.137319374751426, 4.080027562014861, 5.024272035128829, 5.973912004516996, 6.8940028118501235, 7.906872188691373, 8.853238033224642, 9.873573390995443, 10.901577414398634, 11.767529133241492, 12.696392483018695, 13.642993282318846, 12.72756308697186, 12.681922360775909, 11.72618909626157, 10.776951199826543, 9.851564282182704, 8.812734821148847, 7.9276656874380524, 6.990490233646989, 6.021960472450169, 5.011980919650046, 5.939514731279761, 6.885661622935235, 7.838063024192879, 8.82858199573104, 9.757540944066164, 10.735351313991295, 11.7145888366891, 12.64192183757409, 13.694817469426308, 14.590675309776408, 13.632265420036585, 13.625953103570957, 12.725024432347542, 11.850771280739146, 10.852399624449005, 9.783506558799738, 8.897979129517172, 8.05270090986193, 7.042451861315033, 6.032486195591707, 6.881268639201724, 7.90712570890271, 8.836233331973759, 9.818401173145324, 10.771210112540949, 11.687831237420333, 12.64201038467705, 13.604175482209149, 14.64524609531962, 15.4942506713665, 14.561695749799426, 14.637184476855548, 13.707307106267944, 12.79029638562765, 11.780418882661742, 10.808862407679134, 9.924129956454168, 9.02899235675281, 8.023833845248198, 6.995405960477028, 7.822742675812382, 8.779343729171897, 9.768162737939374, 10.722067344091958, 11.774895819655445, 12.76118970553544, 13.696069569732824, 14.625656169833462, 15.564611494185485, 16.484778887083657, 15.498781979673971, 15.606603617492423, 14.608625628009598, 13.614924944850161, 12.686887353672136, 11.739623036178166, 10.942879695755211, 10.006598598524572, 8.979340409139857, 8.014769773120351, 8.860957175862463, 9.791386920883669, 10.790525570557369, 11.6859536053277, 12.625352210385433, 13.654663379292408, 14.642340605751532, 15.570058188447096, 16.635976805184516, 17.473193720728645, 16.466220583159053, 16.54468332025265, 15.595388194273998, 14.642369446958547, 13.661244370459354, 12.703355487865478, 11.871298741036393, 10.898154809812286, 9.95602001620787, 9.083575572595462, 9.806717653175518, 10.7599779176963, 11.096881092312314, 11.850654875372928, 12.79726341570346, 13.594289331436585, 14.590115769140448, 15.52949920444236, 16.603757832791878, 17.566084529808098, 17.446909108342084, 17.590905297043555, 16.56845495833809, 15.624335292255166, 14.637766174072762, 13.63709813515789, 12.93506272194526, 11.946574009155286, 10.978418821756511, 10.012539369872561, 10.76742601492689, 10.93963722110047, 10.038507391306807, 10.826634290842767, 11.816865475679275, 12.637056102146447, 13.587864648841553, 14.572178049564075, 15.583800125691127, 16.499801530091723, 17.477853683654963, 17.54747135056001, 17.5148765179794, 16.604679163099433, 15.615400148511315, 14.676667798405976, 13.84107471061687, 12.908411576085797, 11.968126521699977, 10.963303375502564, 10.876077649895628, 9.988287662802943, 8.983538352557522, 9.756950254693106, 10.76256001006637, 11.67639467033971, 12.625586935724359, 13.663381466045221, 14.590195294558564, 15.564448606983591, 16.591865972167092, 16.636770649134352, 17.557090545220294, 16.7365948314829, 15.714273696178637, 14.648964908020861, 13.639213352644157, 12.709443294220637, 11.760591523330067, 10.893540408840925, 9.87372976209317, 8.974603099018326, 8.056001090412797, 8.710708982982588, 9.753451106247885, 10.64524918331446, 11.688652129627188, 12.641251404210493, 13.629951787505172, 14.679670910454584, 15.64924026570215, 15.637428186019394, 16.616822975646446, 15.695919362391855, 14.727799862633002, 13.707833599073313, 12.69317148050134, 11.74451975690166, 10.80684536080333, 9.9352838470019, 8.942605303469122, 7.915151177302251, 7.075426631035458, 7.774523257026965, 8.789308177733197, 9.709306302420895, 10.709572781647992, 11.69328028858666, 12.68196766567124, 13.722512284413973, 14.669081724947928, 14.664546235118156, 15.606071615963716, 14.727697861640968, 13.731503032402038, 12.80990918872689, 11.813862930803124, 10.85093979793909, 9.826444838648888, 8.871154947550275, 7.902477124756851, 6.943832125685693, 6.0474580119487635, 6.750429853752404, 7.818340757923503, 8.745140205575758, 9.783664828535603, 10.737175560738635, 11.742276596255005, 12.68618237554413, 13.717527022245454, 13.654701097630001, 14.645350262036175, 13.844691248994629, 12.800632717189213, 11.89985226430443, 10.96752846259796, 9.945628325864082, 8.946210430296889, 8.004810698346956, 6.98099174669102, 5.940416269135007, 5.063884603254847, 5.813132001221876, 6.811030101787832, 7.809175215908619, 8.756328623196662, 9.73595293623383, 10.694909568467349, 11.723160732634318, 12.709609730795497, 12.654366427576909, 13.600187256674355, 12.886794881117494, 11.827966814282087, 10.896104822369061, 9.892724825034199, 9.005774669122353, 7.982863814320211, 7.010419963436492, 6.054979857061301, 4.986851633848329, 4.020230931428761, 4.854591064348053, 5.867011971081462, 6.867045911685669, 7.783392260748817, 8.736870826661372, 9.766764702346464, 10.752080242216225, 11.727303656473115, 11.688259779307629, 12.74891302953489, 11.905598456666256, 10.958577932040788, 9.9147456385199, 8.919510485424917, 7.975222287094548, 6.953405504317891, 5.948373764319158, 5.017952332097227, 3.9710027346515613, 3.008269994282619, 3.9231093012185, 4.883766535762535, 5.8548909092796, 6.830526558085698, 7.781688919126148, 8.837392030189141, 9.836303026192297, 10.738262470752954, 10.777829764608303, 11.835943235384866, 10.983879544413153, 10.001261056925742, 8.976232038511231, 8.001747310801434, 7.004567877209773, 6.020348553702533, 5.121689710232617, 4.114124817304949, 3.042528558661007, 2.0491323354848623, 2.9102790291634246, 3.887139700813699, 4.89296914884852, 5.912385112898439, 6.931612096872469, 7.872464426315863, 8.817031342650223, 9.783029547025102, 9.906373097069103, 10.868872584091596, 10.07361566694419, 9.066596970543818, 8.118301788439801, 7.0594314095392585, 6.069648057063657, 5.049748920923598, 4.107993515438097, 3.0869263041038946, 2.086894433361798, 1.0621484807512545, 1.9823042102169735, 2.911723046688719, 3.9797611289097006, 4.969561413588409, 5.958826752674648, 6.949585985576576, 7.905413017497712, 8.85659972862331], [8.918847194150946, 7.959871938878015, 6.980534925440803, 5.9896597839682215, 4.9614251443371735, 4.006311333290314, 2.978967519672336, 1.9640834149447055, 1.024426277745605, 0.0, 1.0533126761810034, 2.0437300305322608, 3.109793544643768, 4.118185977579578, 5.12498188790253, 6.113459508023427, 7.070844986997018, 8.095217584225294, 9.09614371183415, 9.929024826110986, 9.937752971797522, 8.99054686640377, 7.971047803744806, 7.0314611849477675, 5.974747878117379, 4.985513251607569, 3.929094223292525, 3.0137313708066964, 2.0799720841386944, 1.0368075971878268, 1.990203285617706, 2.950245359322857, 4.009055299049878, 5.025482471467148, 5.978188734915715, 7.046693280983, 7.9962926644863215, 8.9246145091505, 9.979865433397016, 10.983533316057848, 10.765322029383269, 9.824166889560377, 8.867407297731786, 7.901241577568133, 6.902401144760803, 5.963026925125767, 4.931824322628045, 4.073024254281438, 3.0666594958944096, 2.059404775363415, 3.0110489790821506, 3.941841967871321, 4.994112197442562, 5.990087031880257, 6.926481314508545, 7.865114350034669, 8.814973083239414, 9.86766867683361, 10.882871646322034, 11.810771382966845, 11.772670893701877, 10.83525682868158, 9.851251219041865, 8.951595852063111, 7.912336340513736, 6.886894381591029, 5.938413604138457, 5.068128299843983, 4.082577949685703, 3.11808049500823, 4.070107791835525, 4.930206833691969, 5.894110114788095, 6.856658555143845, 7.887108861259922, 8.876190618621049, 9.744006993742072, 10.679125069548782, 11.67270422271032, 12.681286906632401, 12.69824654512549, 11.77427075065923, 10.907232858586799, 9.904100708530173, 8.894598262274076, 7.942853074755031, 6.9923836751982105, 6.131995872546641, 5.074704059810076, 4.184619130852925, 5.125323519167577, 5.869576534104519, 6.882445910945768, 7.8288117554790375, 8.849147113249838, 9.87715113665303, 10.743102855495888, 11.67196620527309, 12.61856700457324, 13.651505722578433, 13.706348638521513, 12.750615374007175, 11.80137747757215, 10.87599055992831, 9.837161098894454, 8.922342185233267, 7.985166731442204, 7.016636970245384, 6.006657417445261, 5.23356051878084, 6.09728841175301, 6.8305061579581015, 7.821025129496262, 8.749984077831387, 9.727794447756517, 10.707031970454322, 11.634364971339313, 12.670391191680704, 13.566249032030802, 14.52899231145137, 14.650379381316561, 13.749450710093148, 12.875197558484752, 11.87682590219461, 10.807932836545344, 9.892655627312386, 9.047377407657144, 8.037128359110248, 7.027162693386922, 6.175314426702803, 7.118752497720485, 7.854391764904616, 8.83655960607618, 9.763653246306172, 10.680274371185556, 11.634453518442271, 12.596618615974371, 13.637689229084843, 14.585804457727193, 15.458422641214211, 15.661610754601153, 14.73173338401355, 13.814722663373256, 12.804845160407348, 11.83328868542474, 10.918806454249383, 10.023668854548024, 9.018510343043413, 7.9900824582722425, 7.116788463313461, 8.073389516672975, 8.786321170870231, 9.740225777022815, 10.767338953420667, 11.753632839300662, 12.688512703498045, 13.618099303598683, 14.557054627950706, 15.608108843107887, 16.395508871088754, 16.631029895238026, 15.633051905755204, 14.639351222595767, 13.711313631417742, 12.764049313923772, 11.937556193550426, 11.001275096319787, 9.974016906935072, 9.009446270915566, 8.155002963363541, 9.085432708384747, 9.808684003488226, 10.704112038258558, 11.64351064331629, 12.672821812223265, 13.660499038682389, 14.588216621377953, 15.628419938949738, 16.596523676752877, 17.362947474573836, 17.569109597998253, 16.619814472019605, 15.666795724704155, 14.68567064820496, 13.727781765611084, 12.865975238831608, 11.892831307607501, 10.950696514003084, 10.031418376096077, 9.100763440676596, 10.054023705197379, 10.798193756863858, 11.689819281614524, 12.577231140130607, 13.564217732363534, 14.560044170067398, 15.49942760536931, 16.573686233718828, 17.598379400561562, 18.343635999756867, 18.61533157478916, 17.592881236083702, 16.648761570000776, 15.66219245181837, 14.661524412903496, 13.929739219740474, 12.91780442594469, 11.926261625257126, 10.960382173373176, 10.061471802427969, 10.108809601078791, 11.016025222748807, 11.851060568588373, 12.841291753424883, 13.661482379892051, 14.612290926587157, 15.596604327309679, 16.60822640343673, 17.524227807837324, 18.502279961400564, 18.53277277700218, 17.60481966505654, 16.767423134165767, 15.72880337664757, 14.792505655952196, 13.722757888270971, 12.790094753739899, 11.936396889708512, 10.934588472844476, 10.00946714259247, 9.157460042781263, 9.961056183999522, 10.781376532438712, 11.786986287811978, 12.700820948085314, 13.650013213469963, 14.687807743790826, 15.614621572304168, 16.588874884729194, 17.616292249912693, 17.64122063903807, 16.635256082134187, 15.71508163836121, 14.695496483169393, 13.782354400717704, 12.772602845341, 11.84283278691748, 10.89398101602691, 10.026929901537768, 9.007119254790013, 8.107992591715169, 9.033518921854798, 9.735135260728194, 10.777877383993491, 11.669675461060065, 12.713078407372793, 13.665677681956097, 14.654378065250777, 15.704097188200189, 16.673666543447755, 16.661854463765, 15.694988512560338, 14.674406169270164, 13.70628666951131, 12.841223091770155, 11.826560973198182, 10.877909249598503, 9.940234853500172, 9.068673339698742, 8.075994796165965, 7.048540669999094, 8.09198203558971, 8.798949534772571, 9.813734455478803, 10.7337325801665, 11.733999059393597, 12.717706566332264, 13.706393943416844, 14.746938562159578, 15.693508002693532, 15.68897251286376, 14.752645949538545, 13.706184668519276, 12.709989839280347, 11.87408789711962, 10.878041639195855, 9.984329290635932, 8.95983433134573, 8.004544440247118, 7.035866617453694, 6.077221618382536, 7.071884289694369, 7.77485613149801, 8.842767035669107, 9.769566483321363, 10.808091106281207, 11.76160183848424, 12.76670287400061, 13.710608653289734, 14.741953299991058, 14.679127375375606, 13.875654702809786, 12.823178055872937, 11.779119524067521, 10.878339071182738, 9.946015269476268, 9.017184353921811, 8.017766458354618, 7.1382001910438, 6.114381239387862, 5.073805761831849, 6.088310881000452, 6.837558278967482, 7.835456379533436, 8.833601493654223, 9.780754900942267, 10.760379213979434, 11.719335846212953, 12.747587010379922, 13.734036008541102, 13.678792705322513, 12.84318856342772, 11.865281687995802, 10.806453621160395, 9.87459162924737, 8.871211631912507, 8.027565645508634, 7.054419842377941, 6.143809456133335, 5.188369349758144, 4.120241126545172, 5.044657209174367, 5.8790173420936584, 6.8914382488270665, 7.891472189431274, 8.807818538494422, 9.761297104406976, 10.791190980092068, 11.77650651996183, 12.75172993421872, 12.712686057053233, 11.911969229076938, 10.884085263544565, 9.937064738919096, 8.893232445398208, 7.897997292303225, 6.953709093972855, 5.991986861747165, 5.081763257016001, 4.15134182479407, 3.104392227348404, 4.0326962720282244, 4.947535578964105, 5.9081928135081405, 6.879317187025205, 7.854952835831303, 8.806115196871753, 9.861818307934746, 10.860729303937902, 11.762688748498558, 11.802256042353907, 10.982841469296687, 9.959453266667548, 8.976834779180138, 7.951805760765627, 6.97732103305583, 5.980141599464169, 4.995922275956929, 4.113860667659527, 3.1354186838412224, 2.089647518614841, 3.0735586132304675, 3.93470530690903, 4.911565978559304, 5.917395426594125, 6.936811390644044, 7.956038374618073, 8.896890704061468, 9.841457620395827, 10.807455824770706, 10.930799374814708, 10.009841353864502, 9.049189389198586, 8.042170692798214, 7.093875510694197, 6.035005131793654, 5.0452217793180525, 4.025322643177994, 3.0835672376924927, 2.0625000263582898, 1.070164145367303, 2.0865747584968597, 3.0067304879625785, 3.9361493244343237, 5.004187406655305, 5.993987691334015, 6.983253030420254, 7.97401226332218, 8.929839295243315, 9.881026006368915], [9.972159870331947, 9.013184615059016, 8.033847601621805, 7.042972460149224, 6.014737820518176, 5.0596240094713165, 4.032280195853339, 3.017396091125709, 2.0777389539266085, 1.0533126761810034, 0.0, 0.9904173543512573, 2.0564808684627645, 3.064873301398574, 4.071669211721527, 5.060146831842424, 6.017532310816015, 7.041904908044291, 8.042831035653148, 9.069568632003254, 10.991065647978523, 10.043859542584771, 9.024360479925807, 8.08477386112877, 7.028060554298381, 6.038825927788571, 4.982406899473528, 4.020612471369283, 2.968849845575874, 1.8964635411925181, 0.9430678527626387, 1.9031099264677898, 2.9619198661948105, 3.9783470386120805, 4.931053302060648, 5.9995578481279335, 6.942979988305319, 7.871301832969497, 8.926552757216013, 9.971678004369263, 11.81863470556427, 10.877479565741378, 9.920719973912789, 8.954554253749135, 7.9557138209418055, 6.9950695406061465, 5.963866938108424, 4.94197842868148, 3.926315439899101, 2.9190607193681064, 1.9639135462270834, 2.8947065350162537, 3.946976764587495, 4.942951599025189, 5.879345881653478, 6.817978917179602, 7.767837650384347, 8.820533243978543, 9.835736213466967, 10.7875655431388, 12.656781187723489, 11.88354139158198, 10.8606840456802, 9.93207502617555, 8.892815514626175, 7.867373555703468, 6.918892778250896, 5.9277842438486745, 4.9422338936903945, 3.9777364390129213, 3.022972358980458, 3.883071400836901, 4.846974681933027, 5.809523122288777, 6.8399734284048535, 7.829055185765981, 8.696871560887006, 9.631989636693715, 10.625568789855254, 11.634151473777335, 13.582356839147103, 12.82255531355963, 11.913635711782735, 10.884579882642612, 9.875077436386515, 8.923332248867471, 7.932355215833207, 6.991651816551332, 5.934360003814767, 5.027828055700677, 4.07818808631251, 4.822441101249451, 5.8353104780907, 6.781676322623969, 7.80201168039477, 8.830015703797962, 9.69596742264082, 10.624830772418022, 11.571431571718174, 12.604370289723366, 14.43219993785698, 13.723032191525968, 12.773794295090942, 11.848407377447103, 10.809577916413247, 9.781998129237959, 8.844822675446895, 7.876292914250075, 6.8663133614499525, 5.9962998705534165, 5.050152978897943, 5.783370725103033, 6.773889696641194, 7.702848644976318, 8.680659014901448, 9.659896537599252, 10.587229538484243, 11.623255758825636, 12.519113599175736, 13.481856878596304, 15.376230680652029, 14.721867527611941, 13.847614376003545, 12.849242719713404, 11.780349654064137, 10.752311571317078, 9.907033351661836, 8.89678430311494, 7.886818637391613, 6.938053778475379, 6.071617064865418, 6.807256332049548, 7.7894241732211125, 8.716517813451102, 9.633138938330486, 10.587318085587203, 11.549483183119301, 12.590553796229774, 13.538669024872128, 14.411287208359145, 16.376336998540925, 15.704150201532343, 14.78713948089205, 13.777261977926141, 12.805705502943534, 11.778462398254074, 10.883324798552716, 9.878166287048105, 8.84452869931135, 7.879527815086037, 7.032922769839536, 7.739185738015162, 8.693090344167745, 9.720203520565597, 10.706497406445592, 11.641377270642977, 12.570963870743615, 13.509919195095637, 14.560973410252819, 15.34837343823369, 17.345756139177798, 16.605468723273997, 15.61176804011456, 14.683730448936535, 13.736466131442565, 12.785801568095055, 11.849520470864416, 10.8222622814797, 9.857691645460195, 8.917742315136117, 8.044965961551307, 8.761548570633156, 9.656976605403488, 10.59637521046122, 11.625686379368195, 12.613363605827319, 13.541081188522883, 14.58128450609467, 15.549388243897809, 16.31581204171877, 18.283835841938025, 17.592231289538397, 16.639212542222946, 15.658087465723753, 14.700198583129877, 13.714220613376236, 12.74107668215213, 11.798941888547713, 10.794157727868654, 9.863502792449172, 9.013556958363939, 9.751058324008788, 10.642683848759454, 11.530095707275537, 12.517082299508465, 13.512908737212328, 14.45229217251424, 15.52655080086376, 16.551243967706494, 17.296500566901802, 18.435517937467786, 17.497928548516843, 16.687235128997447, 15.617869467806216, 14.617201428891342, 13.643573559255218, 12.71671431610671, 11.89088658508828, 11.060087022576576, 10.206197367162522, 9.988946759423223, 10.809432025014296, 11.666704433289617, 12.60175303134258, 13.474315528798602, 14.425124075493708, 15.40943747621623, 16.421059552343284, 17.386004400197272, 18.31320529957416, 17.47946010082118, 16.551506988875534, 15.714110457984763, 14.675490700466565, 13.757287651388499, 12.687539883707274, 11.754876749176201, 10.901178885144814, 10.109323016946574, 9.184201686694568, 10.16407106456309, 10.971646538674781, 11.834689208619714, 12.840298963992979, 13.754133624266318, 14.703325889650968, 15.74112041997183, 16.667934248485174, 17.6421875609102, 18.435065479214096, 16.587907962857066, 15.581943405953183, 14.661768962180206, 13.642183806988388, 12.744420797104116, 11.737384840777302, 10.807614782353783, 9.858763011463212, 9.201664445639866, 8.18185379889211, 9.118582946390427, 10.044109276530056, 10.788447936909197, 11.831190060174494, 12.72298813724107, 13.766391083553797, 14.718990358137102, 15.707690741431781, 16.75740986438119, 17.630819398358664, 15.613740605104338, 14.641675836379333, 13.621093493089159, 12.652973993330306, 11.791601235013763, 10.791342968634485, 9.842691245034805, 8.905016848936475, 8.221420375171494, 7.250729340268064, 8.059131024674352, 9.10257239026497, 9.852262210953574, 10.867047131659806, 11.787045256347504, 12.787311735574601, 13.771019242513269, 14.759706619597848, 15.800251238340582, 16.591217054601053, 14.6408586542031, 13.69933327335754, 12.652871992338271, 11.656677163099342, 10.820775220938616, 9.82472896301485, 8.937935597807716, 7.924616326782032, 7.1572914757198705, 6.1886136529264455, 7.087811973057795, 8.090809983850614, 8.828168807679013, 9.896079711850112, 10.822879159502367, 11.861403782462212, 12.814914514665242, 13.820015550181612, 14.763921329470737, 15.587877867075802, 13.736031386397254, 12.822342026628782, 11.769865379691932, 10.725806847886517, 9.825026395001734, 8.892702593295263, 7.9638716777408085, 6.9644537821736145, 6.104914612960023, 5.183457848178368, 6.084396116507108, 7.107236575156697, 7.890870955148484, 8.88876905571444, 9.886914169835226, 10.83406757712327, 11.813691890160436, 12.772648522393956, 13.800899686560923, 14.78187508297311, 12.735696716344162, 11.789875887246716, 10.811969011814798, 9.75314094497939, 8.821278953066365, 7.817898955731502, 6.9742529693276305, 6.001107166196936, 5.110523878049558, 4.184384112215218, 5.130831481220429, 6.0635829033306115, 6.932330018274661, 7.944750925008069, 8.944784865612275, 9.861131214675424, 10.814609780587977, 11.84450365627307, 12.82981919614283, 13.75739493825403, 11.919309803123195, 10.858656552895933, 9.83077258736356, 8.883752062738091, 7.839919769217204, 6.844684616122221, 5.900396417791851, 4.9386741855661604, 4.048477678932224, 3.1180562467102937, 4.114982582023662, 5.051621966184469, 6.000848255145108, 6.961505489689143, 7.932629863206207, 8.908265512012305, 9.859427873052754, 10.915130984115747, 11.914041980118904, 12.81600142467956, 10.97944056131189, 9.929528793115685, 8.906140590486546, 7.923522102999135, 6.898493084584623, 5.924008356874826, 4.926828923283164, 3.942609599775924, 3.0605479914785225, 2.0821060076602187, 3.100237873290099, 4.092484307386712, 4.988017983090033, 5.964878654740307, 6.970708102775128, 7.990124066825047, 9.009351050799076, 9.95020338024247, 10.89477029657683, 11.860768500951709, 9.968213663418675, 8.9565286776835, 7.995876713017584, 6.988858016617211, 6.040562834513194, 4.9816924556126505, 3.991909103137049, 2.9720099669969895, 2.030254561511489, 1.0091873501772861, 2.0807545000425605, 3.1055004526531045, 4.060043164143582, 4.989462000615327, 6.057500082836309, 7.047300367515017, 8.036565706601257, 9.027324939503181, 9.983151971424316, 10.934338682549916], [9.089328909612036, 10.003601969410274, 9.024264955973063, 8.033389814500483, 7.005155174869434, 6.050041363822574, 5.0226975502045965, 4.007813445476966, 3.0681563082778656, 2.0437300305322608, 0.9904173543512573, 0.0, 1.0660635141115071, 2.0744559470473165, 3.0812518573702694, 4.069729477491165, 5.027114956464756, 6.051487553693033, 7.052413681301889, 8.079151277651995, 10.02704099427833, 11.03427689693603, 10.014777834277066, 9.075191215480029, 8.01847790864964, 7.029243282139829, 5.972824253824785, 5.011029825720541, 3.9592671999271314, 2.8868808955437752, 1.933485207113896, 1.0622797888130622, 2.1031376382219094, 3.0369195373746893, 3.989625800823257, 5.058130346890541, 5.95256263395406, 6.880884478618238, 7.936135402864754, 8.981260650018005, 10.85881223720333, 11.79996737702622, 10.911137328264049, 9.944971608100396, 8.946131175293065, 7.985486894957403, 6.954284292459681, 5.932395783032737, 4.916732794250358, 3.9094780737193635, 2.9543309005783405, 2.0620650987529214, 3.114335328324163, 4.092795459022575, 4.937918380416087, 5.8765514159422105, 6.826410149146956, 7.879105742741151, 8.86153355394792, 9.813362883619753, 11.715353686486099, 12.652767751506396, 11.851101400031457, 10.922492380526807, 9.883232868977432, 8.857790910054725, 7.909310132602153, 6.918201598199931, 5.932651248041651, 4.968153793364179, 4.013389713331716, 3.050429964573569, 4.014333245669695, 4.976881686025445, 5.95782433635768, 6.88762768452859, 7.755444059649616, 8.690562135456325, 9.684141288617864, 10.692723972539945, 12.640929337909713, 13.589890957773237, 12.904053066133992, 11.874997236993869, 10.865494790737772, 9.913749603218728, 8.922772570184463, 7.982069170902589, 6.924777358166024, 6.006558958705668, 5.0569189893175, 3.9897996649861187, 5.002669041827368, 5.9490348863606375, 6.936653582587263, 7.948772546634378, 8.754539921403431, 9.683403271180634, 10.630004070480783, 11.662942788485976, 13.49077243661959, 14.552512127098746, 13.684292327023522, 12.758905409379683, 11.720075948345826, 10.69249616117054, 9.755320707379477, 8.786790946182656, 7.776811393382532, 6.849277581752817, 5.903130690097344, 4.9507292888397005, 5.941248260377861, 6.870207208712985, 7.848017578638116, 8.82725510133592, 9.75458810222091, 10.681828257588247, 11.577686097938345, 12.540429377358913, 14.434803179414638, 15.448975228370458, 14.758112407936125, 13.759740751645984, 12.690847685996717, 11.66280960324966, 10.817531383594417, 9.77428614653614, 8.764320480812813, 7.79103148967478, 6.903722518857264, 5.974614895786214, 6.956782736957779, 7.883876377187769, 8.800497502067154, 9.75467664932387, 10.71684174685597, 11.657690194988142, 12.597241523634736, 13.469859707121755, 15.434909497303535, 16.43125790229086, 15.69763751282463, 14.68776000985872, 13.716203534876113, 12.688960430186656, 11.793822830485297, 10.755668130469305, 9.697506410510751, 8.732505526285438, 7.8650282238313824, 6.906544301751828, 7.860448907904411, 8.887562084302264, 9.87385597018226, 10.808735834379643, 11.738322434480281, 12.677277758832304, 13.647803223072222, 14.4069459369963, 16.40432863794041, 17.451854696738756, 16.518625720461266, 15.59058812928324, 14.643323811789271, 13.638779279294456, 12.702498182063817, 11.675239992679101, 10.710669356659595, 9.770720026335518, 8.877071415543154, 7.9289071343698225, 8.824335169140154, 9.763733774197886, 10.793044943104862, 11.780722169563985, 12.70843975225955, 13.748643069831337, 14.636218056717212, 15.374384540481381, 17.342408340700636, 17.470244314285992, 16.499540680925566, 15.518415604426371, 14.560526721832495, 13.716920185812826, 12.774716161098452, 11.952278283178872, 11.195573365181211, 10.716480503648572, 9.843590346482497, 8.918416887745455, 9.81004241249612, 10.697454271012203, 11.68444086324513, 12.680267300948994, 13.619650736250906, 14.693909364600426, 15.6731148005214, 16.35507306566441, 17.445100583116528, 16.507511194165588, 15.696817774646188, 14.627452113454957, 13.626784074540083, 12.65315620490396, 11.726296961755452, 10.900469230737022, 10.266609567904112, 11.141628614782048, 10.818980147541781, 9.976790588750962, 10.834062997026283, 11.769111595079247, 12.641674092535268, 13.592482639230374, 14.576796039952896, 15.588418116079948, 16.553362963933935, 17.37177779833677, 16.48904274646992, 15.561089634524278, 14.723693103633504, 13.685073346115306, 12.76687029703724, 11.697122529356015, 10.764459394824943, 9.910761530793556, 9.31584556227411, 10.119632934314094, 11.099502312182617, 11.031759627500247, 11.903747033175945, 12.823417060692153, 13.602335524342006, 14.551527789726656, 15.515594799691293, 16.442408628204635, 17.416661940629663, 17.444648124862837, 15.597490608505808, 14.591526051601925, 13.671351607828948, 12.65176645263713, 11.75400344275286, 10.746967486426044, 9.817197428002524, 8.868345657111954, 8.290648420962446, 9.117285046511636, 10.08531168473992, 11.01083801487955, 11.778865291260452, 12.821607414525749, 13.713405491592324, 14.756808437905052, 15.709407712488357, 16.698108095783034, 17.52604891719253, 16.640402044007406, 14.62332325075308, 13.651258482028075, 12.6306761387379, 11.662556638979048, 10.801183880662506, 9.800925614283226, 8.852273890683547, 7.914599494585216, 7.303676710995278, 8.186160587887588, 9.044585534426174, 10.088026900016791, 10.84267956530483, 11.857464486011061, 12.777462610698759, 13.77772908992586, 14.761436596864527, 15.750123973949107, 16.547369140783747, 15.600799700249793, 13.650441299851842, 12.708915919006282, 11.662454637987013, 10.666259808748084, 9.83035786658736, 8.834311608663594, 7.947518243456459, 6.934198972430774, 6.2395478115436545, 7.12404490054597, 8.073266482809617, 9.08122733820187, 9.818586162030268, 10.886497066201366, 11.813296513853622, 12.85182113681347, 13.8053318690165, 14.81043290453287, 15.634621166498114, 14.597460512724544, 12.745614032045996, 11.831924672277523, 10.779448025340674, 9.735389493535259, 8.834609040650475, 7.902285238944006, 6.973454323389551, 5.974036427822357, 5.179502996135686, 6.1188890957978925, 7.06985062625893, 8.097653929507954, 8.881288309499741, 9.879186410065698, 10.877331524186484, 11.824484931474528, 12.804109244511695, 13.763065876745214, 14.713281488577755, 13.791457728621852, 11.745279361992903, 10.799458532895457, 9.821551657463539, 8.762723590628132, 7.8308615987151065, 6.827481601380245, 5.983835614976373, 5.010689811845679, 4.185112261225221, 5.1198153598347425, 6.116285990972252, 7.054000257681868, 7.922747372625919, 8.935168279359328, 9.935202219963534, 10.851548569026683, 11.805027134939236, 12.834921010624328, 13.742200998159662, 12.766977583902772, 10.928892448771936, 9.868239198544675, 8.840355233012302, 7.893334708386833, 6.849502414865946, 5.854267261770963, 4.909979063440593, 3.9482568312149025, 3.1230660621078874, 4.0534874943298185, 5.100437091775484, 6.042039320535726, 6.991265609496366, 7.951922844040401, 8.923047217557466, 9.898682866363563, 10.849845227404012, 11.905548338467005, 12.824843105182245, 11.878889757326611, 9.989023206960631, 8.939111438764426, 7.915723236135288, 6.933104748647876, 5.9080757302333655, 4.933591002523569, 3.936411568931907, 2.9521922454246665, 2.0701306371272654, 3.0725233620114762, 4.0906552276413555, 5.082901661737969, 5.97843533744129, 6.9552960090915645, 7.961125457126386, 8.980541421176305, 9.999768405150334, 10.940620734593729, 11.885187650928088, 10.963481729836879, 8.977796309067417, 7.966111323332241, 7.005459358666325, 5.998440662265953, 5.050145480161936, 3.991275101261393, 3.0014917487857913, 1.9815926126457322, 1.0398372071602318, 1.9996047045285434, 3.0711718543938176, 4.095917807004361, 5.050460518494839, 5.9798793549665845, 7.047917437187566, 8.037717721866276, 9.026983060952515, 10.01774229385444, 10.973569325775575, 10.036643289115036], [8.02326539550053, 8.982240650773461, 9.961577664210672, 9.09945332861199, 8.071218688980942, 7.116104877934082, 6.088761064316104, 5.073876959588474, 4.134219822389373, 3.109793544643768, 2.0564808684627645, 1.0660635141115071, 0.0, 1.0083924329358094, 2.015188343258762, 3.003665963379658, 3.9610514423532495, 4.985424039581526, 5.986350167190382, 7.013087763540489, 8.960977480166823, 10.030434486360837, 10.952090542514675, 10.141254729591536, 9.084541422761149, 8.095306796251338, 7.038887767936293, 6.0770933398320475, 5.025330714038638, 3.9529444096552826, 2.9995487212254033, 2.095884063837423, 1.0370741241104025, 1.970856023263182, 2.923562286711749, 3.992066832779034, 4.886499119842553, 5.8148209645067315, 6.870071888753247, 7.915197135906497, 9.792748723091824, 10.733903862914715, 11.690663454743305, 11.011035122211904, 10.012194689404573, 9.05155040906891, 8.020347806571188, 6.998459297144244, 5.982796308361865, 4.975541587830871, 4.020394414689848, 3.0956693737772825, 2.052289749785935, 3.0267319449110675, 3.8718548663045786, 4.810487901830703, 5.760346635035448, 6.8130422286296435, 7.795470039836414, 8.747299369508248, 10.64929017237459, 11.586704237394887, 12.609561583296667, 11.988555894638315, 10.94929638308894, 9.923854424166233, 8.975373646713662, 7.984265112311439, 6.998714762153159, 6.034217307475686, 5.0438912508345695, 3.975715920810069, 3.0118126397139435, 3.974361080069694, 4.891760822246172, 5.821564170417082, 6.689380545538107, 7.6244986213448165, 8.618077774506355, 9.626660458428436, 11.574865823798204, 12.523827443661729, 13.552132499691371, 12.941060751105377, 11.93155830484928, 10.933097481740544, 9.887799984716432, 8.947096585434558, 7.876089388056137, 6.931844914942169, 5.982204945554002, 4.9150856212226195, 4.000148435871617, 4.946514280404886, 5.870590068475755, 6.882709032522869, 7.688476407291922, 8.617339757069123, 9.563940556369275, 10.596879274374468, 12.424708922508081, 13.486448612987237, 14.435686509422263, 13.684191365616186, 12.64536190458233, 11.617782117407042, 10.680606663615979, 9.712076902419158, 8.702097349619034, 7.774563537989319, 6.828416646333846, 5.876015245076202, 5.026921404594779, 5.955880352929903, 6.7964516834932365, 7.775689206191042, 8.703022207076033, 9.615764743476737, 10.511622583826837, 11.474365863247405, 13.36873966530313, 14.382911714258949, 15.344094190851067, 14.685026707882487, 13.61613364223322, 12.588095559486161, 11.74281733983092, 10.69957210277264, 9.689606437049314, 8.716317445911281, 7.829008475093766, 6.899900852022716, 6.092625175549338, 6.969549521404686, 7.748931606922275, 8.70311075417899, 9.665275851711092, 10.591626680876631, 11.531178009523227, 12.403796193010246, 14.368845983192026, 15.36519438817935, 16.326405268002503, 15.613045966095225, 14.641489491112617, 13.614246386423158, 12.7191087867218, 11.680954086705805, 10.622792366747252, 9.657791482521938, 8.790314180067885, 7.83183025798833, 7.12578614626218, 7.973235228519182, 8.822290075037381, 9.757169939234764, 10.686756539335402, 11.625711863687425, 12.581739708960713, 13.34088242288479, 15.3382651238289, 16.385791182627248, 16.37015252728187, 15.442114936103845, 14.494850618609876, 13.631150095196894, 12.72851477032963, 11.899549335336953, 11.635955312896096, 10.696005982572018, 9.802357371779657, 8.854193090606325, 8.089672407497924, 9.001303381184739, 9.748163880121707, 10.73584110658083, 11.663558689276394, 12.697077174686457, 13.570154542605703, 14.308321026369873, 16.276344826589128, 16.44083575937606, 15.470132126015635, 14.48900704951644, 13.531118166922564, 12.687511630902895, 11.74530760618852, 10.92286972826894, 11.712878762464072, 11.641766459885073, 10.768876302718999, 9.843702843981957, 9.07537965085389, 9.935023877999056, 10.742895784247029, 11.697958811045238, 12.63734224634715, 13.691365085861522, 14.607051286409892, 15.289009551552901, 16.38004785866635, 15.44245846971541, 14.638984250027596, 13.597654596103682, 12.597375519630152, 11.623747649994028, 10.69688840684552, 9.87106067582709, 10.783914965186973, 11.780267970276931, 11.744266103778283, 10.902076544987464, 10.099400235384053, 11.0066812020661, 11.700129013537167, 12.650937560232272, 13.601391839575163, 14.613013915702215, 15.577958763556202, 16.30571428422526, 15.423990022019744, 14.496036910074102, 13.658640379183328, 12.62002062166513, 11.706372346143596, 10.667713974446084, 9.735050839915012, 8.881352975883624, 9.83315095955697, 10.758272289808977, 11.7381416676775, 11.957045583736749, 11.169084271533714, 12.060986667679005, 12.660790445343904, 13.609982710728554, 14.54019059931356, 15.467004427826902, 16.441257740251928, 16.37959540041266, 14.532437884055632, 13.526473327151749, 12.606298883378772, 11.586713728186954, 10.688950718302683, 9.717558931516113, 8.787788873092593, 7.8389371022020224, 8.807953818245307, 9.821998277378544, 10.790024915606828, 11.715551245746457, 12.215325543244232, 13.126700013300228, 13.691935932369153, 14.68106353927328, 15.562320661148288, 16.472607163057006, 16.460996192742353, 15.57534931955723, 13.558270526302904, 12.586205757577899, 11.565623414287725, 10.597503914528872, 9.73613115621233, 8.771517059373295, 7.822865335773615, 6.885190939675285, 7.924209208071078, 8.890873818754498, 9.758722182100595, 10.802163547691212, 11.75640138950723, 12.771186310213462, 13.69118443490116, 14.709779090898028, 15.693486597836696, 16.475739486949532, 15.482316416333571, 14.535746975799617, 12.585388575401666, 11.643863194556106, 10.597401913536837, 9.601207084297908, 8.765305142137183, 7.769258884213417, 6.897557546774191, 5.904790417520843, 6.860080308619454, 7.828758131412879, 8.787403130484037, 9.839009722689704, 10.73230798623267, 11.800218890403768, 12.727018338056023, 13.783871137785638, 14.73738186998867, 15.513474221337063, 14.569568442047938, 13.532407788274368, 11.68056130759582, 10.766871947827347, 9.714395300890498, 8.670336769085083, 7.769556316200298, 6.837232514493829, 5.923493626707283, 4.944627872912426, 5.948115842729932, 6.919703049993708, 7.870664580454745, 8.919065488172055, 9.79501013370214, 10.792908234268097, 11.791053348388884, 12.756534932446698, 13.736159245483865, 14.681639578909703, 13.648228764127579, 12.726405004171676, 10.680226637542727, 9.734405808445281, 8.756498933013363, 7.697670866177956, 6.76580887426493, 5.762428876930068, 4.918782890526197, 3.9812812569357474, 4.953725107819467, 5.920629314030558, 6.917099945168068, 7.875944723486384, 8.836469196828318, 9.848890103561727, 10.848924044165933, 11.783598569998853, 12.737077135911406, 13.662463813579247, 12.677148273709486, 11.701924859452596, 9.86383972432176, 8.803186474094499, 7.775302508562127, 6.828281983936657, 5.784449690415769, 4.789214537320786, 3.8449263389904167, 2.918848276304971, 3.923880016303703, 4.854301448525634, 5.9012510459713, 6.863983786340242, 7.923315610468537, 8.883972845012572, 9.855097218529636, 10.830732867335733, 11.781895228376182, 12.808374242842003, 11.759790380732069, 10.813837032876435, 8.922959692849124, 7.87405871431425, 6.850670511685112, 5.8680520241977, 4.843023005783189, 3.868538278073392, 2.87135884448173, 1.922783690514735, 2.9242328931883343, 3.9317977861160016, 5.003394044759944, 5.996790267936089, 6.937925895608581, 7.914786567258855, 8.920616015293676, 9.940031979343596, 10.959258963317625, 11.80798333643461, 10.86341642010025, 9.897418215725372, 7.91173279495591, 6.900047809220734, 5.939395844554818, 4.933387937815777, 3.9850927557117592, 2.926222376811216, 1.9364390243356144, 0.9521840577358004, 1.893939463221301, 2.939344951396509, 4.010912101261783, 5.035658053872327, 6.00995107666213, 6.939369913133875, 8.007407995354857, 9.055037515485004, 10.044302854571244, 10.955055002092049, 9.952208007138761, 8.970579775003529], [7.014872962564719, 7.9738482178376495, 8.953185231274862, 9.944060372747444, 9.07961112191675, 8.124497310869891, 7.097153497251914, 6.0822693925242834, 5.142612255325183, 4.118185977579578, 3.064873301398574, 2.0744559470473165, 1.0083924329358094, 0.0, 1.006795910322953, 1.995273530443849, 2.9526590094174403, 3.977031606645716, 4.977957734254572, 6.004695330604679, 7.952585047231013, 9.022042053425027, 9.943698109578865, 10.892235330782556, 10.092933855696955, 9.103699229187146, 8.047280200872104, 7.075287394783459, 6.0235247689900495, 4.951138464606694, 3.9977427761768145, 3.0377007024716636, 1.9788907627446428, 0.9624635903273727, 1.9151698537759398, 2.983674399843225, 3.878106686906744, 4.806428531570922, 5.861679455817438, 6.906804702970687, 8.784356290156014, 9.725511429978905, 10.682271021807495, 11.648436741971148, 11.02058712234038, 10.049744464020321, 9.0185418615226, 7.996653352095656, 6.980990363313277, 5.973735642782282, 4.968279001200693, 4.037486012411523, 2.9941063884201755, 2.0183395119752583, 2.8634624333687695, 3.802095468894893, 4.751954202099639, 5.804649795693834, 6.7870776069006045, 7.738906936572438, 9.640897739438781, 10.578311804459078, 11.601169150360858, 12.529778169865509, 11.913465946935965, 10.888023988013257, 9.939543210560686, 8.948434676158463, 7.962884326000182, 6.986158935165718, 5.985707889468811, 4.91753255944431, 3.953629278348184, 3.006075811192015, 3.883368389310363, 4.813171737481273, 5.680988112602298, 6.616106188409008, 7.609685341570547, 8.618268025492627, 10.566473390862395, 11.51543501072592, 12.543740066755563, 13.572795895895686, 12.895727868696305, 11.874914120374784, 10.829616623350672, 9.888913224068798, 8.817906026690377, 7.873661553576409, 6.9240215841882415, 5.856902259856859, 4.941965074505857, 3.978229011527207, 4.862197635539945, 5.87431659958706, 6.680083974356113, 7.6089473241333145, 8.555548123433466, 9.588486841438659, 11.416316489572273, 12.478056180051428, 13.427294076486454, 14.352680994130294, 13.58717854321657, 12.559598756041282, 11.622423302250219, 10.653893541053398, 9.643913988253274, 8.71638017662356, 7.770233284968086, 6.817831883710442, 5.925327475110509, 4.9963685267753855, 5.788059250557428, 6.767296773255233, 7.694629774140225, 8.607372310540928, 9.503230150891028, 10.465973430311596, 12.360347232367321, 13.37451928132314, 14.335701757915258, 15.342696235822833, 14.55795028086746, 13.529912198120401, 12.68463397846516, 11.64138874140688, 10.631423075683553, 9.658134084545521, 8.770825113728005, 7.841717490656956, 6.991031246065068, 6.010037695250169, 6.740539173986466, 7.694718321243182, 8.656883418775283, 9.583234247940823, 10.52278557658742, 11.395403760074437, 13.360453550256217, 14.356801955243542, 15.318012835066694, 15.503002889059555, 14.531446414076948, 13.77931637164002, 12.900878829307658, 12.622770725340045, 11.564609005381492, 10.599608121156178, 9.732130818702124, 8.773646896622571, 8.02419221677791, 7.013723402364665, 7.813897642101573, 8.748777506298955, 9.678364106399593, 10.617319430751616, 11.573347276024906, 12.332489989948982, 14.329872690893092, 15.37739874969144, 15.47598769424991, 14.547950103071885, 13.600685785577916, 12.736985262164934, 11.834349937297672, 12.769957173828992, 12.577771951530336, 11.637822621206258, 10.744174010413897, 9.796009729240566, 8.981190160087955, 8.041791555030223, 8.739771447185898, 9.727448673645021, 10.655166256340586, 11.688684741750649, 12.561762109669896, 13.299928593434064, 15.267952393653317, 15.443265254345322, 14.575967292983673, 13.59484221648448, 12.636953333890604, 11.793346797870935, 10.851142773156562, 11.79327756676098, 12.652381174990367, 12.583583098519313, 11.71069294135324, 10.785519482616198, 9.922120592175071, 8.97551205184454, 9.73450335131122, 10.68956637810943, 11.62894981341134, 12.682972652925713, 13.598658853474085, 14.280617118617092, 15.37165542573054, 14.4340660367796, 13.630591817091785, 12.589262163167872, 11.703210686598192, 10.729582816962068, 9.802723573813562, 10.776039494598423, 11.723417377713268, 12.719770382803226, 12.686082742412525, 11.843893183621706, 10.946141176705233, 10.047169375911583, 10.691736580601358, 11.642545127296463, 12.592999406639354, 13.604621482766406, 14.569566330620393, 15.297321851289452, 14.415597589083934, 13.487644477138291, 12.650247946247518, 11.61162818872932, 10.697979913207785, 9.773549141414124, 8.840886006883052, 9.786331794654958, 10.772653372083266, 11.697774702335272, 12.677644080203795, 12.89886222237099, 12.015825212854894, 11.101474841524489, 11.652398012408096, 12.601590277792745, 13.531798166377751, 14.458611994891093, 15.43286530731612, 15.371202967476849, 13.524045451119822, 12.518080894215938, 11.597906450442961, 10.578321295251143, 9.680558285366873, 8.759659942849249, 7.893624040060632, 8.778439514728316, 9.7474562307716, 10.761500689904839, 11.729527328133123, 12.655053658272752, 13.062066484565412, 12.167188187145712, 12.683543499433345, 13.672671106337472, 14.55392822821248, 15.464214730121196, 15.452603759806543, 14.56695688662142, 12.549878093367093, 11.577813324642088, 10.557230981351914, 9.589111481593061, 8.72773872327652, 7.813618070706431, 6.9287005027416555, 7.824693352201578, 8.863711620597371, 9.830376231280791, 10.698224594626888, 11.741665960217505, 12.695903802033522, 13.215654141145667, 13.61948638032691, 14.643751324386223, 15.60818417766993, 15.46734705401372, 14.47392398339776, 13.527354542863806, 11.576996142465855, 10.635470761620295, 9.589009480601026, 8.592814651362097, 7.756912709201374, 6.760866451277607, 5.889165113838382, 6.844292830047136, 7.799582721145748, 8.768260543939173, 9.72690554301033, 10.778512135215998, 11.67181039875896, 12.739721302930059, 13.666520750582315, 14.723373550311933, 15.519622514847908, 14.505081788401252, 13.561176009112128, 12.524015355338557, 10.672168874660011, 9.758479514891537, 8.706002867954687, 7.661944336149273, 6.761163883264488, 5.8288400815580195, 4.9151011937714735, 5.884130285438719, 6.887618255256225, 7.859205462520001, 8.810166992981038, 9.858567900698349, 10.734512546228434, 11.73241064679439, 12.730555760915177, 13.696037344972991, 14.632203778207414, 13.673247145973894, 12.63983633119177, 11.718012571235867, 9.671834204606919, 8.726013375509472, 7.748106500077553, 6.689278433242146, 5.75741644132912, 4.754036443994258, 3.910390457590387, 4.920783669462041, 5.89322752034576, 6.860131726556851, 7.856602357694361, 8.815447136012677, 9.775971609354611, 10.78839251608802, 11.788426456692227, 12.723100982525146, 13.676579548437699, 12.654071380643439, 11.668755840773677, 10.693532426516787, 8.855447291385952, 7.794794041158689, 6.766910075626316, 5.819889551000847, 4.77605725747996, 3.780822104384977, 2.836533906054607, 3.858350688831264, 4.863382428829996, 5.793803861051927, 6.840753458497593, 7.803486198866535, 8.86281802299483, 9.823475257538865, 10.79459963105593, 11.770235279862026, 12.721397640902476, 11.799981809906194, 10.75139794779626, 9.805444599940627, 7.9145672599133166, 6.86566628137844, 5.842278078749302, 4.85965959126189, 3.834630572847379, 2.8601458451375823, 1.8629664115459208, 2.9185453603187987, 3.919994562992398, 4.927559455920065, 5.999155714564008, 6.992551937740153, 7.933687565412645, 8.910548237062919, 9.91637768509774, 10.935793649147659, 11.740443232942196, 10.799590903498801, 9.855023987164442, 8.889025782789563, 6.903340362020101, 5.891655376284924, 4.931003411619009, 3.924995504879967, 2.9767003227759496, 1.9178299438754065, 0.928046591399805, 1.9479457275398642, 2.8897011330253646, 3.9351066212005725, 5.006673771065847, 6.0314197236763905, 7.005712746466194, 7.935131582937939, 9.003169665158921, 10.050799185289069, 11.003612343536437, 9.946662569156238, 8.94381557420295, 7.962187342067721], [6.008077052241767, 6.967052307514697, 7.946389320951909, 8.93726446242449, 9.965499102055539, 9.131293221192845, 8.103949407574866, 7.089065302847236, 6.149408165648135, 5.12498188790253, 4.0716692117215265, 3.081251857370269, 2.015188343258762, 1.006795910322953, 0.0, 0.988477620120896, 1.9458630990944874, 2.970235696322763, 3.9711618239316193, 4.997899420281726, 6.94578913690806, 8.015246143102075, 8.936902199255913, 9.885439420459605, 10.945289814237437, 10.048082581767217, 8.984653877268954, 7.992658063475308, 6.940895437681899, 5.868509133298543, 4.9151134448686635, 3.9550713711635126, 2.896261431436492, 1.8798342590192219, 0.9271279955706547, 1.9943584246695325, 2.8713107765837913, 3.7996326212479694, 4.854883545494485, 5.900008792647735, 7.777560379833061, 8.718715519655953, 9.675475111484545, 10.641640831648198, 11.640481264455529, 10.924979492213662, 9.893776889715939, 8.871888380288995, 7.856225391506617, 6.848970670975622, 5.828757401223352, 4.897964412434182, 3.8456941828629407, 2.8497193484252463, 1.8754205751634845, 2.814053610689608, 3.7639123438943534, 4.813034466273238, 5.780281696577652, 6.732111026249486, 8.652855881233496, 9.590269946253793, 10.613127292155573, 11.541736311660223, 12.580995823209598, 11.734398797662827, 10.785918020210255, 9.794809485808033, 8.809259135649752, 7.832533744815287, 6.832082699118381, 5.76390736909388, 4.8000040879977535, 3.837455647642003, 2.895326531105078, 3.8251298792759876, 4.692946254397013, 5.628064330203722, 6.621643483365261, 7.630226167287342, 9.57843153265711, 10.527393152520634, 11.555698208550277, 12.5847540376904, 13.563257744969938, 12.721288930024352, 11.67599143300024, 10.735288033718366, 9.664280836339946, 8.720036363225978, 7.770396393837811, 6.703277069506429, 5.788339884155427, 4.809608847977195, 3.8741557773346607, 4.886274741381775, 5.6920421161508274, 6.620905465928029, 7.567506265228181, 8.600444983233373, 10.428274631366987, 11.490014321846143, 12.439252218281169, 13.364639135925009, 14.403468596958865, 13.405973565690852, 12.468798111899789, 11.500268350702967, 10.490288797902844, 9.562754986273129, 8.616608094617655, 7.664206693360011, 6.706786710612397, 5.777827762277273, 4.800017392352142, 5.779254915049948, 6.706587915934939, 7.619330452335642, 8.515188292685743, 9.47793157210631, 11.372305374162035, 12.386477423117855, 13.347659899709972, 14.354654377617548, 14.62066761219101, 13.88011837896449, 13.531008788114729, 12.48776355105645, 11.477797885333123, 10.50450889419509, 9.617199923377575, 8.688092300306526, 7.7724904815669555, 6.78227126948644, 5.752497315781181, 6.706676463037897, 7.668841560569997, 8.595192389735537, 9.534743718382135, 10.407361901869152, 12.372411692050932, 13.368760097038257, 14.329970976861409, 14.566868238294221, 13.595311763311614, 12.853967552027493, 13.708588156202381, 13.469145534989615, 12.410983815031061, 11.445982930805748, 10.578505628351694, 9.62002170627214, 8.805651452279799, 7.785956976600936, 6.825855783896287, 7.76073564809367, 8.690322248194308, 9.62927757254633, 10.58530541781962, 11.344448131743697, 13.341830832687807, 14.389356891486155, 14.539853043484577, 13.611815452306551, 12.664551134812582, 11.811636442552407, 12.642059264192396, 13.577666500723716, 13.424146761179907, 12.48419743085583, 11.590548820063466, 10.642384538890136, 9.72043936294532, 8.781040757887588, 7.751729588980613, 8.739406815439736, 9.6671243981353, 10.700642883545363, 11.57372025146461, 12.311886735228779, 14.279910535448032, 14.472791713722309, 13.627658553765325, 12.646533477266132, 11.70081868312527, 10.867997978258408, 11.658852100051286, 12.600986893655703, 13.472608144815581, 13.429957908168884, 12.525503488848347, 11.600330030111305, 10.661369795032437, 9.714761254701905, 8.746461493105935, 9.701524519904144, 10.640907955206055, 11.694930794720428, 12.6106169952688, 13.292575260411807, 14.401181885107526, 13.463592496156586, 12.66011827646877, 11.618788622544859, 10.767076035832858, 9.804233997349542, 10.610432900708286, 11.583748821493149, 12.543644347538482, 13.53999735262844, 13.500893289907632, 12.63160614972815, 11.685390379562598, 10.769406284837878, 9.703694722396072, 10.654503269091178, 11.604957548434069, 12.61657962456112, 13.581524472415108, 14.309279993084166, 13.44512404846092, 12.517170936515278, 11.679774405624503, 10.641154648106307, 9.72750637258477, 8.848200321801597, 9.648595333777777, 10.594041121549683, 11.59288034190848, 12.518001672160485, 13.497871050029008, 13.686575188477434, 12.704909768955847, 11.699300013582583, 10.66435615420281, 11.61354841958746, 12.543756308172465, 13.470570136685808, 14.444823449110835, 14.400729426853836, 12.553571910496808, 11.547607353592925, 10.627432909819948, 9.60784775462813, 8.710084744743858, 7.789186402226232, 8.701333366955359, 9.59866648455353, 10.567683200596814, 11.581727659730053, 12.549754297958337, 13.475280628097966, 13.751151040666365, 12.765013359203806, 11.69550164122806, 12.684629248132186, 13.565886370007194, 14.47617287191591, 14.48213021918353, 13.596483345998406, 11.57940455274408, 10.607339784019075, 9.586757440728901, 8.618637940970048, 7.757265182653504, 6.843144530083415, 7.736409829636382, 8.644920322026792, 9.683938590422587, 10.650603201106005, 11.518451564452102, 12.561892930042719, 13.597761913685988, 13.655378076218774, 12.631444522121624, 13.655709466180937, 14.620142319464644, 14.496873513390707, 13.503450442774747, 12.556881002240793, 10.606522601842842, 9.664997220997282, 8.618535939978013, 7.622341110739083, 6.786439168578358, 5.7903929106545915, 6.696874440733108, 7.66451979987235, 8.619809690970962, 9.588487513764386, 10.547132512835544, 11.598739105041211, 12.589913254796684, 13.657824158967783, 13.595610618966761, 14.581617419293327, 14.549148974224895, 13.53460824777824, 12.590702468489114, 11.553541814715544, 9.701695334036994, 8.788005974268522, 7.735529327331672, 6.691470795526258, 5.790690342641473, 4.858366540935004, 5.7228105206662, 6.704357255263933, 7.707845225081439, 8.712930470754365, 9.728269849018764, 10.776670756736074, 11.652615402266157, 12.650513502832114, 13.6486586169529, 14.614140201010715, 13.661730237584397, 12.702773605350878, 11.669362790568753, 10.74753903061285, 8.701360663983902, 7.755539834886457, 6.777632959454538, 5.718804892619131, 4.786942900706105, 3.783562903371243, 4.718099784485114, 5.741010639287254, 6.713454490170974, 7.713856734791216, 8.774705213732085, 9.733549992050401, 10.694074465392335, 11.706495372125744, 12.70652931272995, 13.64120383856287, 12.710851095590654, 11.683597840020422, 10.69828230015066, 9.72305888589377, 7.884973750762937, 6.824320500535674, 5.796436535003301, 4.849416010377832, 3.805583716856945, 2.810348563761962, 3.7546367620923315, 4.776453544868989, 5.7814852848677205, 6.711906717089652, 7.7588563145353175, 8.721589054904259, 9.780920879032553, 10.741578113576589, 11.712702487093653, 12.68833813589975, 11.75566918805543, 10.82950826928318, 9.780924407173245, 8.834971059317612, 6.907771349590363, 5.888736802825754, 4.865348600196615, 3.8827301127092038, 2.8577010942946925, 1.8832163665848958, 2.865603637944437, 3.921182586717315, 4.922631789390914, 5.930196682318582, 7.001792940962524, 7.995189164138669, 8.93632479181116, 9.913185463461435, 10.919014911496255, 11.752874306593274, 10.733647322619245, 9.79279499317585, 8.84822807684149, 7.882229872466611, 5.896544451697148, 4.884859465961971, 3.9242075012960553, 2.9465872381148346, 1.998292056010817, 0.94090046532272, 1.9306838177983214, 2.9505829539383805, 3.892338359423881, 4.937743847599089, 6.009310997464363, 7.034056950074906, 8.008349972864709, 8.937768809336454, 10.005806891557436, 10.986081772299723, 9.996816433213484, 8.939866658833287, 7.937019663879998, 6.955391431744768], [5.01959943212087, 5.978574687393801, 6.957911700831013, 7.948786842303594, 8.977021481934642, 9.932135292981501, 9.092427027695763, 8.077542922968131, 7.137885785769032, 6.113459508023427, 5.060146831842423, 4.069729477491165, 3.0036659633796585, 1.995273530443849, 0.988477620120896, 0.0, 0.9573854789735913, 1.9817580762018672, 2.9826842038107233, 4.00942180016083, 5.957311516787164, 7.026768522981178, 7.9484245791350165, 8.896961800338708, 9.95681219411654, 10.911337211298756, 9.97313149738985, 8.981135683596204, 7.929373057802795, 6.85698675341944, 5.90359106498956, 4.943548991284409, 3.8847390515573883, 2.8683118791401183, 1.9156056156915509, 1.0058808045486365, 1.8828331564628953, 2.811155001127073, 3.8664059253735887, 4.911531172526838, 6.789082759712165, 7.730237899535056, 8.686997491363647, 9.6531632115273, 10.65200364433463, 11.664817288678044, 10.882254509836836, 9.860366000409892, 8.844703011627512, 7.837448291096519, 6.817235021344248, 5.886442032555078, 4.834171802983837, 3.8381969685461423, 2.8638981952843805, 1.9883733338311282, 2.938232067035874, 3.8245568461523414, 4.7918040764567555, 5.743633406128589, 7.80743080470945, 8.74132783865626, 9.670841412673726, 10.599450432178376, 11.63870994372775, 12.648146435369421, 11.77439564033115, 10.783287105928927, 9.797736755770647, 8.821011364936183, 7.820560319239275, 6.752384989214775, 5.788481708118649, 4.825933267762899, 3.883804151225974, 2.9994496024175077, 3.867265977538533, 4.802384053345242, 5.7776382648012, 6.78622094872328, 8.733006456133063, 9.680341760633908, 10.708646816663551, 11.66396886787595, 12.620971865488091, 13.686780035403295, 12.664469053121136, 11.723765653839262, 10.652758456460843, 9.708513983346874, 8.758874013958707, 7.6917546896273254, 6.776817504276322, 5.7980864680980915, 4.862633397455556, 4.060594464523295, 4.866361839292347, 5.795225189069549, 6.723501046664119, 7.756439764669311, 9.584269412802925, 10.646009103282081, 11.595246999717107, 12.520633917360946, 13.559463378394803, 14.394451185811748, 13.457275732020685, 12.488745970823864, 11.47876641802374, 10.551232606394025, 9.605085714738552, 8.652684313480908, 7.695264330733293, 6.766305382398169, 5.788495012473039, 5.0294809332917065, 5.886602212184492, 6.793650175477162, 7.671183074121681, 8.633926353542249, 10.528300155597973, 11.542472204553793, 12.50365468114591, 13.510649159053486, 13.880167786181897, 14.868595999085386, 14.519486408235625, 13.476241171177346, 12.46627550545402, 11.492986514315987, 10.605677543498471, 9.676569920427422, 8.760968101687851, 7.7707488896073365, 6.740974935902077, 6.096694740010474, 6.84885585681955, 7.769512112877058, 8.690738499818073, 9.56335668330509, 11.52840647348687, 12.524754878474194, 13.485965758297347, 13.826368412285108, 12.8548119373025, 13.84244517214839, 14.697065776323281, 14.457623155110511, 13.399461435151958, 12.434460550926644, 11.56698324847259, 10.608499326393037, 9.794129072400693, 8.774434596721832, 7.814333404017184, 7.1507539250662475, 7.905430121587892, 8.831557649990696, 9.741300199255559, 10.500442913179635, 12.497825614123744, 13.545351672922092, 13.799353217475463, 12.871315626297438, 11.924051308803469, 12.800114062673304, 13.630536884313296, 14.566144120844616, 14.412624381300803, 13.472675050976726, 12.579026440184363, 11.630862159011032, 10.708916983066217, 9.769518378008485, 8.74020720910151, 8.179175347051489, 8.963579796145542, 9.902922960989729, 10.729715032900549, 11.467881516664717, 13.43590531688397, 13.702112339116784, 12.8569791791598, 11.875854102660607, 10.960318857116157, 11.856475598379305, 12.647329720172186, 13.589464513776603, 14.461085764936477, 14.41843552828978, 13.513981108969244, 12.588807650232201, 11.649847415153333, 10.703238874822802, 9.734939113226831, 9.141293051515897, 9.966275141205644, 10.897210872164793, 11.766611776704739, 12.448570041847745, 13.630502510502001, 12.692913121551062, 11.889438901863246, 10.848109247939334, 10.026576209823745, 10.792711617470438, 11.598910520829186, 12.572226441614047, 13.532121967659378, 14.528474972749336, 14.489370910028528, 13.620083769849046, 12.673867999683495, 11.757883904958774, 10.692172342516969, 10.204002696657064, 10.930324734433658, 11.927920493948355, 12.832894776421114, 13.465274774520104, 12.674444673855396, 11.746491561909753, 10.909095031018978, 9.870475273500782, 8.987006546575657, 9.836677941922494, 10.637072953898675, 11.582518741670581, 12.581357962029376, 13.506479292281382, 14.486348670149905, 14.67505280859833, 13.693387389076744, 12.68777763370348, 11.652833774323707, 11.18035097655922, 11.869123494172054, 12.795937322685397, 13.768247699529244, 13.630050052248311, 11.782892535891284, 10.7769279789874, 9.856753535214423, 8.837168380022606, 7.969584918734745, 8.777664022347128, 9.689810987076257, 10.587144104674426, 11.556160820717711, 12.57020527985095, 13.538231918079234, 14.463758248218863, 14.739628660787261, 13.753490979324702, 12.683979261348956, 12.251431805103946, 12.891253556006783, 13.8015400579155, 13.711410855868431, 12.825803971392881, 10.808685189428981, 9.83666040941355, 8.816078066123376, 7.8479585663645235, 7.016765356644393, 7.8316221502043115, 8.72488744975728, 9.633397942147688, 10.672416210543483, 11.639080821226901, 12.506929184572998, 13.550370550163615, 14.586239533806884, 14.64385569633967, 13.61992214224252, 13.25907027731146, 13.945509505464234, 13.618535040873871, 12.732731079459649, 11.786161638925694, 9.835803238527744, 8.894277857682184, 7.847816576662915, 6.851661736133559, 6.0459393425692465, 6.778870530775488, 7.6853520608540045, 8.652997419993246, 9.608287311091859, 10.576965133885283, 11.53561013295644, 12.587216725162108, 13.57839087491758, 14.64630177908868, 14.584088239087658, 14.18497823042385, 13.67081050170806, 12.656269775261404, 11.712363995972279, 10.782822451400445, 8.815380271154236, 7.905642057167416, 6.853165410230567, 5.920791420920734, 5.020010968035949, 5.8468441610559, 6.711288140787096, 7.692834875384829, 8.696322845202335, 9.701408090875262, 10.71674746913966, 11.76514837685697, 12.641093022387054, 13.63899112295301, 14.63672914142735, 13.644155994085946, 12.685631769123802, 11.726675136890282, 10.693264322108158, 9.861223967730092, 7.8150456011011435, 6.869224772003697, 5.895269042353433, 4.948125518013607, 4.016263526100581, 4.772040523492139, 5.70657740460601, 6.729488259408151, 7.70193211029187, 8.702334354912113, 9.763182833852982, 10.722027612171297, 11.682552085513231, 12.69497299224664, 13.633537962775515, 12.6712196316381, 11.722373475469755, 10.707499371559827, 9.722183831690066, 8.836743823011012, 6.932151634074808, 5.938005437652915, 4.910121472120542, 3.9631009474950725, 3.0349043422514206, 3.798826183882858, 4.743114382213228, 5.764931164989885, 6.769962904988617, 7.700384337210548, 8.747333934656213, 9.710066675025155, 10.76939849915345, 11.730055733697485, 12.693989577781078, 11.718353928974981, 10.767191567934532, 9.843522386039133, 8.794938523929199, 7.848985176073566, 5.919293729469467, 4.963680067703177, 3.9416985109123637, 2.959080023424952, 1.9713117602105417, 2.871693986705792, 3.854081258065333, 4.909660206838211, 5.911109409511809, 6.918674302439476, 7.990270561083419, 8.983666784259563, 9.924802411932056, 10.901663083582331, 11.783812650522295, 10.764396686472375, 9.745169702498346, 8.804317373054952, 7.859750456720593, 6.893752252345714, 4.908066831576251, 3.8963818458410753, 2.9357298811751598, 1.9581096179939383, 1.009814435889921, 1.929378085443616, 2.9191614379192172, 3.939060574059276, 4.880815979544776, 5.926221467719984, 6.9977886175852575, 8.022534570195802, 8.996827592985605, 9.92624642945735, 10.950864207286648, 9.997604152178827, 9.008338813092587, 7.9513890387123904, 6.948542043759102, 5.966913811623871], [4.062213953147279, 5.02118920842021, 6.000526221857422, 6.991401363330003, 8.019636002961052, 8.974749814007911, 10.00209362762589, 9.034928401941723, 8.095271264742623, 7.070844986997018, 6.017532310816014, 5.027114956464756, 3.9610514423532495, 2.9526590094174403, 1.9458630990944874, 0.9573854789735913, 0.0, 1.0243725972282758, 2.025298724837132, 3.0520363211872388, 4.999926037813573, 6.069383044007587, 6.991039100161426, 7.9395763213651165, 8.999426715142949, 9.953951732325166, 10.930516976363442, 9.938521162569796, 8.886758536776385, 7.81437223239303, 6.860976543963151, 5.900934470258, 4.842124530530979, 3.8256973581137093, 2.8729910946651422, 1.939276988202734, 0.9254476774893039, 1.8537695221534818, 2.909020446399998, 3.9541456935532473, 5.831697280738574, 6.772852420561465, 7.729612012390056, 8.69577773255371, 9.69461816536104, 10.707431809704456, 11.738634412202178, 10.817751479383483, 9.802088490601104, 8.79483377007011, 7.774620500317839, 6.843827511528669, 5.791557281957428, 4.795582447519734, 3.821283674257972, 2.9217695174852256, 1.9983819440090882, 2.86717136717875, 3.8344185974831646, 4.7862479271549985, 6.850045325735859, 7.783942359682668, 8.713455933700136, 9.642064953204786, 10.68132446475416, 11.690760956395833, 12.639241733848404, 11.74067258490252, 10.755122234744238, 9.778396843909775, 8.777945798212867, 7.709770468188367, 6.745867187092241, 5.78331874673649, 4.841189630199565, 3.855934480951879, 2.9274158545117475, 3.8625339303184565, 4.820252785827609, 5.82883546974969, 7.775620977159473, 8.722956281660318, 9.75126133768996, 10.70658338890236, 11.6635863865145, 12.729394556429703, 13.621854532094728, 12.681151132812854, 11.610143935434435, 10.665899462320466, 9.716259492932299, 8.649140168600917, 7.734202983249914, 6.7554719470716815, 5.820018876429148, 4.888221138473298, 3.926511716265562, 4.855375066042764, 5.7661155676905285, 6.799054285695721, 8.626883933829335, 9.688623624308491, 10.637861520743517, 11.563248438387356, 12.602077899421213, 13.629657686596499, 14.414661210994277, 13.446131449797456, 12.436151896997332, 11.508618085367617, 10.562471193712144, 9.6100697924545, 8.652649809706885, 7.723690861371761, 6.745880491446631, 5.857107607241709, 4.946752089157707, 5.853800052450377, 6.71379759514809, 7.6765408745686585, 9.570914676624383, 10.585086725580203, 11.54626920217232, 12.553263680079896, 13.572849637072103, 14.599971128675618, 15.476871887209217, 14.433626650150938, 13.423660984427611, 12.450371993289579, 11.563063022472063, 10.633955399401014, 9.718353580661443, 8.728134368580928, 7.698360414875669, 6.9243214139604765, 5.909005733792765, 6.829661989850273, 7.733353020844482, 8.6059712043315, 10.57102099451328, 11.567369399500604, 12.528580279323757, 13.085206718859673, 13.746012236854103, 14.79600726646997, 15.654451255296873, 15.415008634084103, 14.35684691412555, 13.391846029900236, 12.524368727446182, 11.565884805366629, 10.751514551374285, 9.731820075695424, 8.771718882990776, 7.895166598661746, 6.965579998561107, 7.891707526963912, 8.783914720281967, 9.543057434206045, 11.540440135150154, 12.587966193948503, 12.959603205913917, 12.031565614735891, 12.815251608355071, 13.757499541646895, 14.587922363286888, 15.523529599818207, 15.370009860274395, 14.430060529950318, 13.536411919157954, 12.588247637984624, 11.666302462039809, 10.726903856982076, 9.697592688075101, 8.923588020646987, 8.023729673118757, 8.963072837962944, 9.772329553926957, 10.510496037691127, 12.47851983791038, 12.808003736193413, 11.983680332002539, 11.035970512662866, 11.85151915666776, 12.813861077352897, 13.604715199145778, 14.546849992750195, 15.41847124391007, 15.375821007263372, 14.471366587942835, 13.546193129205793, 12.607232894126925, 11.660624353796393, 10.692324592200423, 9.885705725111395, 9.026425018178859, 9.957360749138008, 10.809226297731147, 11.491184562874155, 12.73639390757863, 11.79880451862769, 11.00171448670592, 10.008225657941592, 10.917776509375347, 11.75009709644403, 12.556295999802778, 13.529611920587639, 14.48950744663297, 15.485860451722928, 15.44675638900212, 14.577469248822638, 13.631253478657086, 12.715269383932366, 11.64955782149056, 10.948415370252562, 9.990474611406873, 10.98807037092157, 11.875509297447522, 12.507889295546514, 11.780336070932025, 10.852382958986382, 10.021370615861652, 9.03059168350304, 9.878206846127261, 10.794063420896086, 11.594458432872267, 12.539904220644173, 13.538743441002968, 14.463864771254974, 15.443734149123497, 15.632438287571922, 14.650772868050336, 13.645163112677071, 12.610219253297299, 11.924763650154718, 10.92927337114527, 11.856087199658612, 12.810862220555652, 12.73594144932494, 10.879226215610958, 9.88281937606403, 8.962644932291052, 7.997284790024864, 8.860785218286349, 9.73504950132072, 10.647196466049849, 11.544529583648018, 12.513546299691303, 13.527590758824541, 14.495617397052825, 15.421143727192455, 15.697014139760853, 14.710876458298294, 13.641364740322548, 12.904002707563302, 11.951403432979998, 12.861689934888714, 12.78260941893545, 11.91293637596047, 9.879883752496001, 8.94255180649018, 7.921969463200005, 7.008074976366782, 7.907965656195996, 8.789007629177902, 9.682272928730871, 10.59078342112128, 11.629801689517075, 12.596466300200493, 13.46431466354659, 14.507756029137207, 15.543625012780476, 15.601241175313262, 14.577307621216113, 13.911641179770816, 13.005659382437448, 12.66114956190028, 11.803929642526668, 10.857360201992714, 8.907001801594763, 7.965476420749203, 6.919015139729934, 6.011778146135818, 6.93713964212085, 7.73625600974908, 8.642737539827596, 9.610382898966838, 10.56567279006545, 11.534350612858875, 12.492995611930032, 13.5446022041357, 14.535776353891173, 15.55758200404604, 14.630782556393784, 13.714106720451294, 12.713425022734468, 11.698884296287812, 10.754978516998687, 9.854021014467465, 7.862651674147225, 6.961659180358506, 5.924363973297586, 5.0809078309229925, 5.97739644700954, 6.804229640029492, 7.668673619760688, 8.65022035435842, 9.653708324175927, 10.658793569848857, 11.674132948113252, 12.722533855830562, 13.598478501360646, 14.596376601926602, 13.679343662453759, 12.686770515112354, 11.72824629015021, 10.76928965791669, 9.735878843134566, 8.908495370723081, 6.862317004094132, 5.916496174996686, 4.966467605420452, 4.1082419280158655, 4.973649005074172, 5.729426002465731, 6.663962883579602, 7.686873738381743, 8.659317589265463, 9.659719833885706, 10.720568312826574, 11.67941309114489, 12.639937564486823, 13.652358471220232, 12.676152483801923, 11.713834152664509, 10.764987996496163, 9.750113892586235, 8.764798352716474, 7.884015226004001, 5.974766155101216, 4.985276840645904, 3.981320035187561, 3.034299510562092, 3.992289821225012, 4.756211662856449, 5.700499861186819, 6.7223166439634765, 7.727348383962209, 8.657769816184139, 9.704719413629805, 10.667452153998747, 11.726783978127042, 12.687441212671077, 11.736604098807486, 10.76096845000139, 9.80980608896094, 8.886136907065543, 7.837553044955608, 6.891599697099974, 4.961908250495875, 4.0062945887295855, 2.988481866731994, 2.0302785864919715, 2.928697239184133, 3.829079465679383, 4.811466737038925, 5.867045685811803, 6.868494888485401, 7.876059781413068, 8.94765604005701, 9.941052263233155, 10.882187890905648, 11.832256619583523, 10.826427171548703, 9.807011207498784, 8.787784223524755, 7.84693189408136, 6.902364977747001, 5.936366773372122, 3.95068135260266, 2.9389963668674834, 1.9783444022015682, 1.029308181060958, 1.9671999148635124, 2.8867635644172074, 3.876546916892809, 4.896446053032868, 5.838201458518368, 6.883606946693575, 7.955174096558849, 8.979920049169394, 9.954213071959197, 10.883631908430942, 9.993478728313058, 9.040218673205237, 8.050953334118997, 6.9940035597387995, 5.991156564785511, 5.009528332650279], [3.0378413559190034, 3.996816611191934, 4.976153624629146, 5.967028766101727, 6.995263405732775, 7.950377216779635, 8.977721030397612, 9.992605135125242, 9.119643861970898, 8.095217584225294, 7.04190490804429, 6.051487553693033, 4.985424039581526, 3.977031606645716, 2.970235696322763, 1.9817580762018672, 1.0243725972282758, 0.0, 1.0009261276088561, 2.027663723958963, 4.05674713356558, 5.052120957181957, 5.966666502933149, 6.91520372413684, 7.975054117914674, 8.92957913509689, 9.927847734017801, 10.919843547811448, 9.911131134004663, 8.838744829621307, 7.885349141191427, 6.925307067486276, 5.8664971277592555, 4.8500699553419855, 3.897363691893418, 2.9636495854310096, 1.9498202747175797, 1.03032483646428, 2.049016123441385, 3.0864253318462085, 4.971692957779961, 5.912848097602852, 6.869607689431443, 7.835773409595096, 8.834613842402426, 9.84742748674584, 10.878630089243561, 11.84212407661176, 10.826461087829381, 9.819206367298387, 8.798993097546116, 7.8682001087569455, 6.815929879185704, 5.81995504474801, 4.845656271486248, 3.9461421147135014, 3.022754541237364, 2.0437266814895483, 2.974414274524552, 3.9262436041963857, 5.990041002777247, 6.9239380367240555, 7.853451610741522, 8.782060630246171, 9.821320141795546, 10.830756633437217, 11.779237410889788, 12.765045182130795, 11.779494831972514, 10.80276944113805, 9.802318395441143, 8.734143065416642, 7.770239784320516, 6.807691343964766, 5.865562227427841, 4.880307078180155, 3.9517884517400232, 3.071434715282776, 3.960248462868997, 4.968831146791077, 6.915616654200861, 7.862951958701705, 8.891257014731348, 9.846579065943745, 10.803582063555886, 11.86939023347109, 12.833207481949541, 13.70552373004113, 12.63451653266271, 11.690272059548741, 10.740632090160574, 9.673512765829193, 8.75857558047819, 7.779844544299959, 6.844391473657423, 5.912593735701574, 4.950884313493837, 4.121086341405098, 4.906111244731917, 5.9390499627371085, 7.766879610870722, 8.828619301349878, 9.777857197784904, 10.703244115428744, 11.7420735764626, 12.769653363637886, 13.70682881742895, 14.470504047025731, 13.460524494225607, 12.532990682595893, 11.586843790940419, 10.634442389682775, 9.67702240693516, 8.748063458600036, 7.770253088674906, 6.881480204469985, 5.971124686385982, 5.119511327812711, 5.8537932721894785, 6.816536551610047, 8.71091035366577, 9.72508240262159, 10.686264879213708, 11.693259357121283, 12.71284531411349, 13.739966805717005, 14.681588366912361, 15.457999247379213, 14.448033581655887, 13.474744590517854, 12.587435619700338, 11.65832799662929, 10.742726177889718, 9.752506965809204, 8.722733012103944, 7.948694011188752, 6.93337833102104, 6.095373265212606, 6.87334869788587, 7.745966881372888, 9.711016671554667, 10.707365076541992, 11.668575956365144, 12.678453459331052, 13.65000993431366, 14.700004963929528, 15.657879813803241, 16.439381231312378, 15.381219511353825, 14.416218627128512, 13.548741324674458, 12.590257402594904, 11.77588714860256, 10.7561926729237, 9.79609148021905, 8.919539195890021, 7.989952595789382, 7.157418802326245, 7.923910397323356, 8.683053111247432, 10.680435812191542, 11.72796187098989, 12.019908523039884, 12.916832826380018, 13.71254588265806, 14.703331782778973, 15.612294960515163, 16.547902197046483, 16.394382457502672, 15.454433127178593, 14.56078451638623, 13.6126202352129, 12.690675059268084, 11.751276454210352, 10.721965285303376, 9.947960617875262, 9.048102270347032, 8.228784113325277, 8.912325230968346, 9.650491714732514, 11.618515514951767, 11.811256961245464, 10.98693355705459, 11.921237724306993, 12.748813430970749, 13.759693318484974, 14.629087796374053, 15.57122258997847, 16.442843841138345, 16.400193604491648, 15.49573918517111, 14.570565726434069, 13.6316054913552, 12.684996951024669, 11.716697189428698, 10.91007832233967, 10.050797615407134, 9.223072024500341, 9.949221974772534, 10.631180239915542, 11.739647132630681, 10.802057743679741, 10.00496771175797, 10.89349286958572, 11.815070783678337, 12.774469693672305, 13.580668597031053, 14.553984517815914, 15.513880043861246, 16.510233048951203, 16.471128986230397, 15.601841846050913, 14.655626075885362, 13.739641981160641, 12.673930418718836, 11.972787967480837, 11.014847208635148, 10.253781646283903, 11.015504974488909, 11.647884972587901, 10.783589295984076, 9.855636184038433, 9.024623840913703, 9.915858895147167, 10.77550112043025, 11.81843601812436, 12.618831030100543, 13.564276817872448, 14.563116038231243, 15.488237368483249, 16.468106746351772, 16.656810884800198, 15.67514546527861, 14.669535709905347, 13.634591850525574, 12.949136247382993, 11.953645968373545, 11.286433043200713, 11.95085789759704, 11.739194674376991, 9.869748123278328, 8.88607260111608, 7.965898157343103, 8.88255200166899, 9.758079492589339, 10.759422098548995, 11.671569063278124, 12.568902180876293, 13.537918896919578, 14.551963356052816, 15.5199899942811, 16.44551632442073, 16.72138673698913, 15.73524905552657, 14.665737337550823, 13.928375304791578, 12.975776030208273, 12.292035778430815, 11.77313132660282, 10.903458283627838, 8.870405660163371, 7.94580503154223, 6.925222688252056, 7.893342188010909, 8.805259930498986, 9.813380226406178, 10.706645525959146, 11.615156018349555, 12.65417428674535, 13.620838897428769, 14.488687260774865, 15.532128626365482, 16.495427065448773, 15.557229890416899, 14.570576056010646, 13.60917184869525, 12.625464341756583, 11.636776964672004, 10.794451550194038, 9.847882109660084, 7.897523709262132, 6.968729645801254, 5.922268364781985, 6.9090724204388065, 7.834433916423839, 8.760628606977354, 9.667110137055872, 10.634755496195114, 11.590045387293726, 12.55872321008715, 13.517368209158308, 14.568974801363975, 15.471333662174214, 14.533209406817765, 13.606409959165509, 12.689734123223019, 11.689052425506192, 10.674511699059536, 9.730605919770412, 8.844542922134833, 6.838279076918949, 5.937286583130231, 4.927617198349637, 5.978202105225981, 6.941145636167248, 7.828602237257767, 8.693046216988964, 9.674592951586696, 10.678080921404202, 11.683166167077133, 12.698505545341527, 13.746906453058838, 14.534035809643685, 13.595831957884224, 12.654971065225483, 11.662397917884078, 10.703873692921935, 9.744917060688415, 8.71150624590629, 7.8841227734948065, 5.837944406865857, 4.892123577768411, 3.969720830472503, 5.005536202318854, 5.93739819423188, 6.753798599694006, 7.688335480807877, 8.711246335610019, 9.683690186493738, 10.684092431113982, 11.744940910054849, 12.703785688373165, 13.575494872769863, 12.651813827177854, 11.651779886573648, 10.689461555436234, 9.740615399267888, 8.72574129535796, 7.740425755488198, 6.859642628775726, 4.950393557872941, 3.9609042434176285, 2.984573260239612, 3.931593784865081, 4.974364864958854, 5.780584260084725, 6.724872458415095, 7.746689241191752, 8.751720981190484, 9.682142413412414, 10.72909201085808, 11.691824751227022, 12.64401310964031, 11.683355875096275, 10.712231501579211, 9.736595852773114, 8.785433491732665, 7.861764309837268, 6.813180447727333, 5.867227099871699, 3.9375356532675996, 2.98192199150131, 1.9641092695037183, 2.94672775699113, 3.910772282917976, 4.8534520629076585, 5.835839334267201, 6.891418283040078, 7.892867485713676, 8.900432378641344, 9.972028637285288, 10.965424860461432, 11.787126804888832, 10.807884022355248, 9.802054574320428, 8.782638610270508, 7.763411626296479, 6.822559296853084, 5.877992380518726, 4.911994176143847, 2.926308755374384, 1.9146237696392079, 0.9539718049732924, 2.000979776493338, 2.9492749585973552, 3.911136161645483, 4.900919514121084, 5.920818650261143, 6.862574055746643, 7.907979543921851, 8.979546693787125, 10.00429264639767, 10.931688905527277, 10.002270069055532, 8.969106131084782, 8.01584607597696, 7.02658073689072, 5.969630962510523, 4.966783967557235, 3.985155735422004], [2.0369152283101473, 2.9958904835830777, 3.97522749702029, 4.966102638492871, 5.99433727812392, 6.94945108917078, 7.9767949027887575, 8.991679007516389, 9.93133614471549, 9.096143711834149, 8.042831035653146, 7.052413681301888, 5.986350167190381, 4.977957734254572, 3.9711618239316193, 2.9826842038107233, 2.025298724837132, 1.0009261276088561, 0.0, 1.0267375963501069, 3.0558210059567235, 4.0511948295731015, 4.965740375324294, 5.914277596527985, 6.974127990305817, 7.928653007488035, 8.926921606408946, 9.918917420202593, 10.912057261613517, 9.839670957230162, 8.886275268800283, 7.926233195095132, 6.867423255368111, 5.850996082950841, 4.898289819502274, 3.9645757130398662, 2.950746402326436, 2.031250964073136, 1.0480899958325292, 2.085499204237352, 3.9707668301711054, 4.911921969993997, 5.868681561822587, 6.8348472819862405, 7.833687714793571, 8.846501359136987, 9.877703961634708, 10.899592471061652, 11.827387215438238, 10.820132494907243, 9.799919225154973, 8.869126236365803, 7.816856006794561, 6.8208811723568665, 5.846582399095104, 4.9470682423223575, 4.02368066884622, 2.9886911164041203, 1.9734881469156957, 2.9253174765875296, 4.989114875168391, 5.9230119091152, 6.852525483132666, 7.781134502637316, 8.820394014186691, 9.829830505828363, 10.778311283280935, 11.769419817683158, 12.754970167841439, 11.803695568746907, 10.80324452305, 9.735069193025499, 8.771165911929373, 7.808617471573623, 6.860568519637399, 5.8165381906685205, 4.888019564228389, 3.95290148842168, 2.9593223352601408, 3.9679050191822207, 5.914690526592005, 6.86202583109285, 7.8903308871224915, 8.84565293833489, 9.802655935947032, 10.868464105862234, 11.832281354340688, 12.772984753622563, 13.635442660271567, 12.691198187157598, 11.74155821776943, 10.67443889343805, 9.759501708087047, 8.780770671908815, 7.839397765866981, 6.814167523334885, 5.852458101127149, 4.923594751349947, 3.9051851171230605, 4.938123835128253, 6.7659534832618675, 7.827693173741024, 8.77693107017605, 9.702317987819889, 10.741147448853745, 11.768727236029033, 12.705902689820096, 13.674432451016918, 14.461450621834464, 13.53391681020475, 12.587769918549276, 11.635368517291631, 10.669060833061355, 9.740101884726231, 8.7622915148011, 7.783053992103296, 6.872698474019293, 5.905863715320367, 4.852867144580623, 5.815610424001191, 7.709984226056916, 8.724156275012735, 9.685338751604853, 10.692333229512428, 11.711919186504636, 12.739040678108152, 13.680662239303508, 14.713073213817701, 15.448959709264743, 14.475670718126711, 13.588361747309195, 12.659254124238146, 11.734764604015913, 10.744545391935398, 9.714771438230139, 8.850267798822063, 7.834952118654351, 6.880814863833406, 5.872422570277014, 6.745040753764032, 8.710090543945812, 9.706438948933137, 10.66764982875629, 11.677527331722198, 12.649083806704805, 13.699078836320673, 14.656953686194388, 15.694455197750866, 16.38214563896268, 15.417144754737368, 14.549667452283314, 13.591183530203761, 12.767925574728755, 11.748231099049894, 10.782399490307848, 9.811402325399706, 8.881815725299068, 7.942860400947045, 6.9229842697145, 7.682126983638577, 9.679509684582687, 10.727035743381034, 11.704799509000104, 12.63283710017813, 13.579844435203837, 14.584388967698652, 15.520670064929291, 16.54792825431401, 17.39530858511153, 16.45535925478745, 15.561710643995086, 14.613546362821756, 13.676983069356881, 12.737584464299148, 11.708273295392173, 10.839823747384948, 9.939965399856717, 8.978216720176702, 7.911399103359489, 8.649565587123659, 10.617589387342912, 10.87062506349577, 11.787511357309592, 12.768636433808787, 13.693030030039484, 14.703909917553709, 15.6051093431629, 16.547244136767315, 17.41886538792719, 17.401119732100504, 16.48204719525991, 15.556873736522865, 14.617913501443997, 13.671304961113465, 12.703005199517495, 11.801941451849356, 10.94266074491682, 9.972504631351766, 8.948295847163678, 9.630254112306687, 10.799015234880988, 9.861425845930048, 10.805545512012973, 11.837709468654452, 12.759287382747072, 13.72522811540582, 14.5566901438199, 15.53000606460476, 16.489901590650092, 17.48625459574005, 17.457436996319196, 16.58814985613971, 15.64193408597416, 14.72594999124944, 13.660238428807633, 12.864651096990523, 11.906710338144833, 10.97952369473404, 10.014578846880053, 10.646958844979046, 9.842957398234383, 8.91500428628874, 9.932897160763684, 10.8600754942159, 11.719717719498984, 12.769194439857875, 13.594852576889389, 14.540298364661295, 15.53913758502009, 16.464258915272097, 17.44412829314062, 17.643118894888996, 16.66145347536741, 15.655843719994143, 14.62089986061437, 13.840999376892679, 12.84550909788323, 11.92418508241321, 10.949931769988183, 10.798562776627298, 8.892660793015228, 7.945440703366387, 8.910114756411835, 9.826768600737724, 10.702296091658072, 11.71018052028251, 12.64759061006697, 13.54492372766514, 14.513940443708425, 15.527984902841663, 16.496011541069947, 17.421537871209576, 16.44555109651051, 15.59088825576858, 14.520457242010325, 13.630748626008879, 12.690312455325, 11.70161207203032, 10.790392340110593, 9.926370953364739, 7.893318329900271, 7.005173133792537, 7.869439287320788, 8.837558787079642, 9.749476529567719, 10.764138648139692, 11.682667072747993, 12.591177565138402, 13.630195833534197, 14.596860444217615, 15.464708807563712, 16.508150173154327, 15.509365370554887, 14.571168195523015, 13.58451436111676, 12.623110153801365, 11.639402646862697, 10.650715269778118, 9.81171256370181, 8.870794779396984, 6.920436378999033, 5.994421774109805, 6.866484963850717, 7.85328901950754, 8.778650515492572, 9.7366501537662, 10.643131683844718, 11.61077704298396, 12.566066934082572, 13.534744756875996, 14.493389755947154, 15.507999505461363, 14.485271967280326, 13.547147711923879, 12.620348264271623, 11.703672428329135, 10.702990730612306, 9.68845000416565, 8.744544224876526, 7.8674555918717335, 5.86119174665585, 4.960199252867131, 5.871833797418369, 6.9224187042947145, 7.885362235235982, 8.804623784046614, 9.66906776377781, 10.650614498375543, 11.654102468193049, 12.659187713865979, 13.674527092130374, 14.578794360408995, 13.547974114749799, 12.609770262990338, 11.668909370331598, 10.676336222990193, 9.717811998028047, 8.758855365794528, 7.725444551012404, 6.907035443231707, 4.860857076602757, 3.915036247505312, 4.913937429541235, 5.9497528013875876, 6.8816147933006135, 7.729820146482853, 8.664357027596724, 9.687267882398865, 10.659711733282585, 11.660113977902828, 12.720962456843695, 13.54995765121791, 12.589433177875977, 11.665752132283968, 10.665718191679762, 9.703399860542348, 8.754553704374002, 7.739679600464071, 6.754364060594311, 5.882555298512626, 3.973306227609842, 2.98381691315453, 3.9287898593083446, 4.875810383933814, 5.918581464027588, 6.756605806873571, 7.700894005203941, 8.7227107879806, 9.72774252797933, 10.65816396020126, 11.705113557646927, 12.667846298015869, 11.657951414746424, 10.69729418020239, 9.726169806685325, 8.750534157879228, 7.799371796838778, 6.87570261494338, 5.827118752833445, 4.8811654049778115, 2.960448323004501, 2.0048346612382115, 2.908325868572451, 3.8909443560598627, 4.854988881986708, 5.829473609696505, 6.836765461876057, 7.892344410648935, 8.893793613322533, 9.901358506250201, 10.972954764894144, 11.746075233047526, 10.801065109994944, 9.82182232746136, 8.81599287942654, 7.796576915376621, 6.777349931402592, 5.836497601959197, 4.891930685624838, 3.9259324812499594, 1.9492214251112856, 0.9375364393761092, 1.8981884040420247, 2.9451963755620705, 3.8934915576660876, 4.912062289254339, 5.901845641729941, 6.92174477787, 7.8635001833555, 8.908905671530707, 9.980472821395981, 10.905055800708226, 9.930762777918423, 9.001343941446677, 7.968180003475927, 7.014919948368103, 6.025654609281864, 4.968704834901668, 3.9658578399483786, 2.9990940405281163], [1.0101776319600404, 1.9691528872329709, 2.9484899006701832, 3.9393650421427644, 4.967599681773812, 5.922713492820672, 6.95005730643865, 7.96494141116628, 8.904598548365382, 9.929024826110986, 9.069568632003254, 8.079151277651997, 7.013087763540489, 6.0046953306046795, 4.997899420281726, 4.00942180016083, 3.0520363211872388, 2.027663723958963, 1.0267375963501069, 0.0, 2.0290834096066166, 3.0244572332229946, 3.939002778974187, 4.887540000177878, 5.947390393955711, 6.901915411137927, 7.9001840100588385, 8.892179823852485, 9.943942449645895, 10.866408553580268, 9.913012865150389, 8.952970791445239, 7.894160851718218, 6.877733679300948, 5.925027415852381, 4.991313309389973, 3.9774839986765427, 3.057988560423243, 2.0748275921826362, 1.0587616078872453, 3.072806062640343, 4.013961202463235, 4.918377240304851, 5.87732707852237, 6.875043660599135, 7.88785730494255, 8.902914109394358, 9.924802618821301, 10.94046560760368, 11.846870091257351, 10.82665682150508, 9.89586383271591, 8.843593603144669, 7.847618768706973, 6.873319995445211, 5.973805838672465, 5.050418265196327, 4.015428712754227, 3.000225743265803, 2.096794118142512, 4.091154107637628, 5.025051141584438, 5.90222116161493, 6.83083018111958, 7.870089692668955, 8.871186451633926, 9.819667229086498, 10.81077576348872, 11.796326113647002, 12.773051504481465, 11.829982119400107, 10.761806789375607, 9.79790350827948, 8.83535506792373, 7.887306115987506, 6.843275787018628, 5.914757160578496, 4.9796390847717875, 3.986059931610248, 3.1573337260754455, 5.016729759061242, 5.964065063562088, 6.958202801159865, 7.895348616817154, 8.852351614429296, 9.9181597843445, 10.873637300146251, 11.814340699428126, 12.788452223771374, 13.717935783507707, 12.76829581411954, 11.701176489788157, 10.786239304437155, 9.807508268258923, 8.866135362217088, 7.840905119684993, 6.879195697477257, 5.950332347700055, 4.931922713473168, 4.127552542021477, 6.024831852457265, 7.005032177806509, 7.904202902139779, 8.82958981978362, 9.794914451049673, 10.822494238224959, 11.759669692016022, 12.728199453212843, 13.72040558140656, 14.560654406554857, 13.614507514899383, 12.66210611364174, 11.695798429411463, 10.766839481076339, 9.789029111151208, 8.809791588453404, 7.899436070369401, 6.9326013116704726, 5.87960474093073, 5.188224042075044, 6.968862595252313, 7.983034644208132, 8.94421712080025, 9.857007480799115, 10.765686188700563, 11.792807680304078, 12.734429241499434, 13.766840216013627, 14.74091085734822, 15.502408314476819, 14.615099343659303, 13.685991720588254, 12.76150220036602, 11.771282988285506, 10.741509034580247, 9.877005395172171, 8.86168971500446, 7.9075524601835125, 6.899160166627121, 6.117654371837885, 7.980093968536904, 8.965317318128534, 9.926528197951686, 10.888084426380598, 11.79104203757996, 12.818958507241074, 13.710720688390314, 14.748222199946792, 15.703830622233541, 16.443882351087478, 15.576405048633422, 14.617921126553869, 13.794663171078863, 12.774968695400002, 11.809137086657953, 10.838139921749812, 9.908553321649174, 8.969597997297152, 7.949721866064607, 7.05474060171243, 8.949513109173779, 9.985914112576431, 10.9636778781955, 11.891715469373526, 12.721802666078991, 13.726347198573807, 14.662628295804446, 15.689886485189161, 16.654457121208665, 17.48209685113756, 16.588448240345194, 15.640283959171864, 14.703720665706987, 13.764322060649254, 12.735010891742279, 11.866561343735054, 10.966702996206823, 10.00495431652681, 8.938136699709597, 8.022179205197512, 9.887592811934004, 10.892731887196195, 11.86343552055662, 12.844560597055814, 13.685535117766303, 14.669985662867806, 15.643129594091912, 16.585264387696327, 17.62874227570354, 18.427857328450614, 17.50878479161001, 16.58361133287297, 15.644651097794103, 14.698042557463571, 13.729742795867601, 12.828679048199461, 11.969398341266926, 10.999242227701874, 9.975033443513787, 9.00286773038054, 9.973484533098985, 10.860074754533638, 11.804194420616565, 12.864447065004558, 13.786024979097178, 14.751965711755926, 15.583427740170006, 16.55674366095487, 17.516639187000198, 18.51299219209016, 18.484174592669298, 17.614887452489818, 16.668671682324266, 15.752687587599546, 14.686976025157739, 13.891388693340629, 12.93344793449494, 11.962569464470128, 10.997624616616141, 10.0195724630529, 9.017426696452379, 9.91365319489233, 10.931546069367274, 11.886813090566006, 12.74645531584909, 13.795932036207981, 14.621590173239495, 15.5670359610114, 16.565875181370195, 17.490996511622203, 18.338177404075058, 17.33342809382964, 16.46505477187092, 15.55980899206524, 14.524865132685466, 13.64864549744508, 12.607291039423657, 11.680477210910315, 10.749987153882165, 9.973032074845294, 8.023769715884029, 8.944089611969977, 9.936852352761942, 10.85350619708783, 11.729033688008178, 12.736918116632616, 13.674328206417076, 14.571661324015245, 15.54067804005853, 16.55472249919177, 17.331417161824543, 16.405890831684914, 15.418813500160404, 14.564150659418472, 13.493719645660217, 12.604011029658771, 11.663574858974892, 10.674874475680213, 9.763654743760487, 9.05747987623354, 7.0244272527690725, 8.003822042396127, 8.896176883670895, 9.864296383429748, 10.776214125917825, 11.790876244489798, 12.709404669098099, 13.617915161488508, 14.656933429884303, 15.623598040567721, 16.47365241236658, 15.509230528197952, 14.482627774204781, 13.544430599172905, 12.557776764766652, 11.596372557451257, 10.61266505051259, 9.62397767342801, 8.784974967351705, 8.001903702265786, 6.051545301867834, 6.993070682713395, 7.893222560200824, 8.880026615857647, 9.805388111842678, 10.763387750116307, 11.669869280194824, 12.637514639334066, 13.592804530432678, 14.561482353226102, 15.502333360750022, 14.481261909111257, 13.45853437093022, 12.520410115573771, 11.593610667921515, 10.676934831979025, 9.676253134262199, 8.661712407815543, 7.717806628526419, 6.949937688684239, 4.992300669524651, 5.982949833930823, 6.898571393768476, 7.949156300644821, 8.912099831586088, 9.83136138039672, 10.695805360127917, 11.677352094725649, 12.680840064543155, 13.685925310216085, 14.498917504199335, 13.552056764058888, 12.521236518399691, 11.58303266664023, 10.64217177398149, 9.649598626640085, 8.69107440167794, 7.73211776944442, 6.698706954662297, 5.942020397234282, 3.9919659994715575, 4.937786828569003, 5.940675025891342, 6.976490397737694, 7.90835238965072, 8.756557742832959, 9.69109462394683, 10.714005478748971, 11.68644932963269, 12.686851574252934, 13.545352868912657, 12.523220054867803, 11.562695581525869, 10.63901453593386, 9.638980595329654, 8.67666226419224, 7.7278161080238945, 6.712942004113964, 5.727626464244204, 4.893208712506243, 3.0258593512022784, 4.010554509504637, 4.955527455658451, 5.902547980283921, 6.9453190603776935, 7.783343403223678, 8.727631601554048, 9.749448384330705, 10.754480124329437, 11.684901556551367, 12.641208035864118, 11.678475295495176, 10.631213818396317, 9.670556583852282, 8.699432210335218, 7.72379656152912, 6.772634200488671, 5.848965018593273, 4.800381156483338, 3.8544278086277046, 2.0130014465969372, 3.0315722575883184, 3.9350634649225578, 4.9176819524099695, 5.881726478336815, 6.856211206046612, 7.863503058226163, 8.91908200699904, 9.92053120967264, 10.928096102600307, 11.712733859873564, 10.71933763669742, 9.774327513644838, 8.795084731111254, 7.789255283076433, 6.769839319026515, 5.750612335052485, 4.80976000560909, 3.8651930892747313, 2.8991948848998526, 1.001774548703722, 1.964274035726216, 2.924926000392132, 3.9719339719121773, 4.920229154016194, 5.938799885604446, 6.928583238080048, 7.948482374220107, 8.890237779705608, 9.935643267880815, 10.903064156968663, 9.878318204358118, 8.904025181568315, 7.974606345096569, 6.94144240712582, 5.988182352017997, 4.9989170129317575, 3.9419672385515603, 2.9391202435982717, 1.9723564441780097], [1.0189057776465762, 1.9778810329195067, 2.9572180463567186, 3.9480931878292997, 4.976327827460349, 5.931441638507208, 6.958785452125186, 7.973669556852816, 8.913326694051918, 9.937752971797522, 10.991065647978525, 10.027040994278329, 8.960977480166822, 7.952585047231013, 6.9457891369080595, 5.957311516787164, 4.999926037813573, 4.05674713356558, 3.0558210059567235, 2.0290834096066166, 0.0, 1.069457006194014, 2.0889560688529776, 3.037493290056669, 4.097343683834502, 5.086578310344312, 6.150007014842575, 7.142002828636221, 8.19376545442963, 9.266151758812986, 10.144797666402994, 9.184755592697844, 8.125945652970822, 7.109518480553552, 6.156812217104985, 5.0883076710376995, 4.074478360324269, 3.146156515660091, 2.0909055914135752, 1.045780344260326, 1.0437226530337265, 1.9848777928566177, 2.941637384685208, 3.907803104848862, 4.906643537656192, 5.919457181999607, 6.950659784497329, 7.972548293924273, 8.988211282706652, 9.995466003237647, 10.9260309003701, 9.99523791158093, 8.942967682009687, 7.946992847571993, 6.972694074310231, 6.034061038784107, 5.084202305579361, 4.031506711985166, 3.016303742496742, 2.0838128545155925, 2.062070698031012, 2.995967731977821, 3.9254813059952878, 4.8540903254999375, 5.893349837049312, 6.902786328690983, 7.851267106143554, 8.842375640545777, 9.827925990704058, 10.804651381538523, 11.805102427235429, 10.860286142786398, 9.896382861690272, 8.933834421334522, 7.903384115218445, 6.859353786249567, 5.930835159809435, 4.995717084002726, 4.002137930841187, 3.084700411977165, 2.987646349454626, 3.9349816539554707, 4.963286709985113, 5.918608761197511, 6.875611758809653, 7.941419928724856, 8.905237177203308, 9.845940576485182, 10.82005210082843, 11.7642965739424, 12.713936543330567, 11.799655843198948, 10.884718657847946, 9.902548719218828, 8.882213361448027, 7.856983118915931, 6.895273696708195, 5.966410346930993, 4.948000712704106, 4.0413891690466, 3.9957484428506485, 4.975948768199892, 5.9092868109650265, 6.834673728608866, 7.81817459543003, 8.845754382605318, 9.78292983639638, 10.751459597593202, 11.752005458463616, 12.679539270093331, 13.625686161748805, 12.702395400180562, 11.7118764286424, 10.782917480307276, 9.805107110382146, 8.825869587684341, 7.91551406960034, 6.9486793109014116, 5.895682740161668, 4.946091502111324, 4.939779185645697, 5.953951234601516, 6.915133711193634, 7.862091389624362, 8.78894633308092, 9.816067824684437, 10.757689385879793, 11.790100360393986, 12.772510734405277, 13.621293178015293, 14.64715024771628, 13.726281007127076, 12.777580199596958, 11.787360987516443, 10.757587033811184, 9.88152942923713, 8.857539660108102, 7.81646904699763, 6.808076753441239, 5.875521831874165, 5.951010558930289, 6.936233908521918, 7.89744478834507, 8.893168335205845, 9.814302181960317, 10.842218651621433, 11.733980832770673, 12.77148234432715, 13.735430499290597, 14.56276721462595, 15.519368267985465, 14.658210413092691, 13.794312872311366, 12.739443995440219, 11.689198273676379, 10.718201108768238, 9.7886145086676, 8.849659184315577, 7.798604969158395, 6.81260806174871, 6.920429699567163, 7.956830702969816, 8.934594468588886, 9.862632059766911, 10.745062810459348, 11.749607342954164, 12.685888440184803, 13.713146629569518, 14.677717265589024, 15.600981714676031, 16.531411459697235, 15.522428688258142, 14.583781852725412, 13.64438324766768, 12.615072078760704, 11.746622530753479, 10.84676418322525, 9.853837419620598, 8.787019802803385, 7.780046665233792, 7.858509402327388, 8.86364847758958, 9.834352110950006, 10.8154771874492, 11.70879526214666, 12.693245807248163, 13.666389738472269, 14.608524532076686, 15.6520024200839, 16.546742191989086, 17.38884597862844, 16.463672519891396, 15.524712284812528, 14.578103744481997, 13.609803982886026, 12.708740235217887, 11.849459528285353, 10.80019610526999, 9.775502938427257, 8.76073519041682, 8.904731379118294, 9.872847695155302, 10.816317956246625, 11.843222042170474, 12.642537909439072, 13.616165779075196, 14.684625810790914, 15.660333584518536, 16.580966217361, 17.50745055374046, 18.364235779687725, 17.49494863950824, 16.54873286934269, 15.63274877461797, 14.567037212176164, 13.716372401355983, 12.73205900063346, 11.720436924506409, 10.755492076652422, 9.77743992308918, 9.8607892157649, 10.788742327710542, 11.796661827090892, 12.820856016609026, 13.682107572687158, 14.57219945462314, 15.504862589154213, 16.450308376926117, 17.481409146264642, 18.40653047651665, 18.346905549761594, 17.342156239516175, 16.473782917557457, 15.568537137751775, 14.533593278372003, 13.657373643131617, 12.616019185110193, 11.689205356596851, 10.758715299568701, 10.07222947791001, 9.811063627550666, 10.731383523636614, 11.768884184460244, 12.685538028786132, 13.570456293288588, 14.578340721913026, 15.545874110688866, 16.472371131994954, 17.44138784803824, 18.308171945739364, 17.34014530751108, 16.41461897737145, 15.42754164584694, 14.572878805105008, 13.502447791346754, 12.612739175345308, 11.672303004661428, 10.683602621366749, 9.772382889447023, 9.069350158916482, 8.81172116443571, 9.791115954062764, 10.728208715369197, 11.69632821512805, 12.617636731198235, 13.632298849770208, 14.580950573369888, 15.518624969468219, 16.57079939869963, 17.50983468421999, 16.482380558053116, 15.517958673884488, 14.491355919891317, 13.553158744859441, 12.566504910453189, 11.605100703137794, 10.621393196199126, 9.632705819114546, 8.79370311303824, 8.013773984948726, 7.838839213534471, 8.780364594380032, 9.725254391899126, 10.721449221138055, 11.646810717123088, 12.642856975046854, 13.605780107910888, 14.61030893678041, 15.565598827879022, 16.469706505507716, 15.511061506436558, 14.489990054797794, 13.467262516616756, 12.529138261260307, 11.602338813608052, 10.685662977665562, 9.684981279948735, 8.670440553502079, 7.726534774212955, 6.958665834370775, 6.779594581191288, 7.77024374559746, 8.730603225466778, 9.793613107886568, 10.767144358273447, 11.804155677843063, 12.668599657574259, 13.650146392171992, 14.653634361989498, 15.548221127441884, 14.507645649885871, 13.560784909745424, 12.529964664086227, 11.591760812326767, 10.650899919668026, 9.658326772326621, 8.699802547364476, 7.740845915130956, 6.7074351003488335, 5.9507485429208185, 5.779259911138195, 6.72508074023564, 7.772706857589644, 8.831534924425052, 9.763396916338078, 10.729352040279302, 11.663888921393173, 12.686799776195315, 13.659243627079034, 14.622209237812164, 13.554081014599193, 12.53194820055434, 11.571423727212405, 10.647742681620397, 9.64770874101619, 8.685390409878776, 7.736544253710431, 6.7216701498005005, 5.73635460993074, 4.901936858192779, 4.813153262868916, 5.873806513096178, 6.901690478628551, 7.848711003254021, 8.892543296774909, 9.75613770067002, 10.70042589900039, 11.722242681777047, 12.727274421775778, 13.657695853997708, 12.649936181550654, 11.687203441181712, 10.639941964082853, 9.679284729538818, 8.708160356021754, 7.732524707215656, 6.781362346175207, 5.85769316427981, 4.809109302169874, 3.863155954314241, 3.9027232481695893, 4.960836718946153, 5.964146874529174, 6.946765362016586, 7.910809887943431, 8.829005503492954, 9.811392774852497, 10.866971723625376, 11.868420926298974, 12.793058264204044, 11.7214620055601, 10.728065782383956, 9.783055659331374, 8.80381287679779, 7.7979834287629695, 6.778567464713051, 5.759340480739021, 4.818488151295626, 3.8739212349612675, 2.907923030586389, 3.0308579583103388, 3.9933574453328324, 4.954009409998748, 6.0010173815187935, 6.949312563622811, 7.8866896022307795, 8.876472954706381, 9.896372090846441, 10.838127496331941, 11.883532984507148, 10.911792302655199, 9.887046350044654, 8.912753327254851, 7.983334490783105, 6.950170552812356, 5.9969104977045316, 5.007645158618293, 3.9506953842380956, 2.9478483892848075, 1.9810845898645455], [2.0142796012629542, 1.0553043459900235, 2.010011940962967, 3.0008870824355482, 4.029121722066597, 4.9842355331134565, 6.011579346731434, 7.0264634514590645, 7.966120588658165, 8.99054686640377, 10.043859542584773, 11.03427689693603, 10.030434486360836, 9.022042053425027, 8.015246143102074, 7.026768522981178, 6.069383044007587, 5.052120957181957, 4.0511948295731015, 3.0244572332229946, 1.069457006194014, 0.0, 1.0194990626589635, 1.9680362838626546, 3.0278866776404874, 4.017121304150297, 5.08055000864856, 6.072545822442206, 7.124308448235615, 8.19669475261897, 9.15009044104885, 10.110132514754, 9.195402659164836, 8.178975486747566, 7.226269223298999, 6.157764677231714, 5.143935366518283, 4.215613521854105, 3.1603625976075893, 2.11523735045434, 1.975006593060781, 1.0338514532378895, 1.99061104506648, 2.9567767652301336, 3.9555399442839114, 4.968353588627326, 5.999556191125048, 7.021444700551992, 8.037107689334372, 9.044362409865366, 10.064575679617636, 10.951219445400378, 9.898949215829136, 8.902974381391441, 7.928675608129679, 6.9900425726035555, 6.04018383939881, 4.987488245804615, 3.9722852763161907, 3.020455946644357, 2.9823554573793896, 2.0449413923590924, 2.9744549663765594, 3.9030639858812095, 4.942323497430584, 5.951682735318702, 6.9001635127712735, 7.891272047173495, 8.876822397331775, 9.853547788166239, 10.853998833863145, 11.816267676605847, 10.85236439550972, 9.88981595515397, 8.859365649037894, 7.815335320069016, 6.886816693628884, 5.951698617822174, 4.958119464660635, 4.004985171325543, 3.9079311088030035, 2.9839553143367423, 4.012260370366384, 4.967582421578784, 5.924585419190924, 6.9903935891061275, 7.954133583831027, 8.894836983112901, 9.868948507456148, 10.813192980570117, 11.762832949958284, 12.755637377018397, 11.840700191667395, 10.858530253038277, 9.838194895267476, 8.81296465273538, 7.851255230527643, 6.922391880750442, 5.9039822465235545, 4.961673928394978, 4.916033202199026, 4.024922428581164, 4.958260471346298, 5.883647388990138, 6.867148255811301, 7.894728042986588, 8.831903496777652, 9.800433257974474, 10.800901865091333, 11.728435676721048, 12.674582568376522, 13.626983969634166, 12.667857962461849, 11.738899014126725, 10.761088644201594, 9.78185112150379, 8.871495603419788, 7.8821161116200145, 6.829119540880271, 5.866376261459703, 5.860063944994074, 5.0237577646671365, 5.984940241259254, 6.911065050005633, 7.837919993462192, 8.865041485065706, 9.806663046261063, 10.839074020775257, 11.821407141032994, 12.67018958464301, 13.696046654343997, 14.625154277415046, 13.733561733416407, 12.743342521335892, 11.713568567630633, 10.801814188585507, 9.777824419456481, 8.736753806346009, 7.7283615127896175, 6.795806591222544, 6.871295318278666, 6.006040438587538, 6.967251318410691, 7.942141995587116, 8.863275842341588, 9.891192312002703, 10.782954493151943, 11.820456004708422, 12.784326905918315, 13.611663621253667, 14.568264674613182, 15.557083683380661, 14.714597631659744, 13.659728754788597, 12.609483033024757, 11.638485868116616, 10.708899268015978, 9.769943943663955, 8.718889728506774, 7.732892821097089, 7.8407144589155395, 7.026637233035436, 8.004400998654505, 8.93243858983253, 9.79403647084062, 10.798581003335435, 11.734862100566074, 12.76212028995079, 13.726690925970296, 14.649878121303747, 15.580307866324954, 16.442713447606522, 15.50406661207379, 14.564668007016058, 13.535356838109083, 12.666907290101857, 11.767048942573627, 10.774122178968977, 9.707304562151764, 8.70033142458217, 8.778794161675766, 8.013399799299837, 8.984103432660262, 9.928033691905556, 10.757768922527932, 11.742219467629434, 12.71536339885354, 13.657498192457957, 14.700976080465171, 15.595638598616802, 16.548898863137588, 17.383957279239773, 16.444997044160907, 15.498388503830375, 14.530088742234405, 13.629024994566265, 12.76974428763373, 11.720480864618368, 10.695787697775636, 9.681019949765199, 9.825016138466673, 9.02259901686556, 9.966069277956882, 10.95577854662683, 11.691511569820344, 12.665139439456468, 13.733599471172186, 14.709307244899808, 15.62993987774227, 16.556346960368174, 17.524288664196874, 17.594113289425234, 16.740454964866895, 15.756954283780324, 14.691242721338517, 13.840990026815977, 12.856676626093455, 11.960871751775683, 10.995926903921696, 10.697724682437558, 10.781073975113278, 9.969020576506868, 10.946413148801149, 11.933412521065382, 12.73108123306843, 13.621173115004412, 14.553836249535484, 15.49928203730739, 16.530382806645914, 17.455504136897922, 17.54389356092137, 16.53914425067595, 15.670770928717236, 14.765525148911552, 13.730581289531779, 12.88727824268997, 11.917877866355058, 10.991064037841715, 10.060573980813565, 11.046690244932982, 10.806437451167044, 10.93858415942922, 11.991969153905954, 12.966719414543558, 13.748502860909342, 14.680187034579777, 15.501098216357903, 16.528248659145763, 17.49726537518905, 17.505159956899142, 16.537133318670858, 15.611606988531227, 14.624529657006718, 13.769866816264784, 12.69943580250653, 11.816197414145243, 10.974161685906292, 9.985461302611613, 9.074241570691887, 10.043810925939454, 9.807094988052087, 10.786489777679142, 11.723582538985577, 12.69170203874443, 13.613010554814615, 14.627672673386588, 15.576324396986267, 16.513998793084596, 17.566173222316007, 16.706822695379767, 15.679368569212894, 14.714946685044266, 13.688343931051095, 12.75014675601922, 11.763492921612965, 10.80855894193773, 9.92325187744399, 8.93456450035941, 8.095561794283105, 9.009147808565103, 8.83421303715085, 9.77573841799641, 10.720628215515505, 11.716823044754435, 12.642184540739468, 13.638230798663233, 14.601153931527268, 15.62564889081747, 16.580938781916082, 15.666694516667494, 14.708049517596336, 13.686978065957572, 12.664250527776534, 11.726126272420084, 10.799326824767828, 9.88265098882534, 8.934053809789646, 7.972299234746943, 7.028393455457819, 7.954039657987153, 7.774968404807666, 8.765617569213838, 9.725977049083157, 10.788986931502947, 11.762518181889824, 12.828423831489818, 13.716818919857943, 14.698365654455676, 15.701853624273182, 14.745209138601663, 13.70463366104565, 12.757772920905202, 11.726952675246006, 10.788748823486543, 9.847887930827802, 8.855314783486397, 7.932831185284841, 7.04270459637582, 6.009293781593698, 6.946122366537196, 6.774633734754572, 7.720454563852018, 8.768080681206023, 9.82690874804143, 10.758770739954455, 11.777571302562986, 12.712108183676857, 13.735019038478999, 14.707462889362718, 13.819197248971943, 12.751069025758971, 11.728936211714117, 10.768411738372183, 9.844730692780173, 8.844696752175967, 7.882378421038553, 6.933532264870209, 6.023528831045365, 5.038213291175604, 5.897310681809157, 5.808527086485293, 6.869180336712556, 7.897064302244929, 8.844084826870398, 9.887917120391286, 10.807800636446672, 11.752088834777041, 12.773905617553698, 13.737773592694426, 12.807352160472496, 11.76040256302683, 10.797669822657888, 9.836929975242631, 8.876272740698596, 7.905148367181532, 6.929512718375434, 5.9783503573349845, 5.085355814653273, 4.110967983414739, 4.8585297779306185, 4.898097071785967, 5.9562105425625305, 6.959520698145552, 7.942139185632964, 8.906183711559809, 9.880668439269606, 10.88084978104651, 11.93642872981939, 12.911089538607886, 11.90352464568022, 10.831928387036276, 9.838532163860132, 8.89352204080755, 7.95108908930656, 6.945259641271739, 5.975555475872827, 4.956328491898798, 4.015476162455403, 3.0916962998726643, 3.9032968542027664, 4.026231781926716, 4.988731268949211, 5.949383233615126, 6.996391205135172, 7.944686387239189, 8.956146608424794, 9.945929960900395, 10.965829097040455, 11.907584502525955, 11.036153347126719, 9.964586197261445, 8.9398402446509, 7.965547221861098, 7.036128385389353, 6.002964447418604, 5.049704392310781, 4.060439053224542, 3.003489278844344, 2.0252717023553246, 2.9764584134809233], [2.9288251470141464, 1.9698498917412157, 0.9905128783040036, 1.9813880197765847, 3.009622659407633, 3.964736470454493, 4.99208028407247, 6.0069643888001005, 6.946621525999201, 7.971047803744806, 9.024360479925809, 10.014777834277066, 10.952090542514673, 9.943698109578865, 8.936902199255911, 7.948424579135016, 6.991039100161425, 5.966666502933149, 4.965740375324294, 3.939002778974187, 2.0889560688529776, 1.0194990626589635, 0.0, 0.9485372212036911, 2.0083876149815243, 2.9976222414913343, 4.061050945989597, 5.053046759783243, 6.104809385576652, 7.177195689960008, 8.130591378389887, 9.090633452095037, 10.149443391822057, 9.19847454940653, 8.245768285957963, 7.177263739890678, 6.163434429177247, 5.235112584513069, 4.179861660266553, 3.1347364131133038, 2.877289192982146, 1.9361340531592546, 0.9793744613306641, 1.9383242995481833, 2.9360408816249484, 3.948854525968363, 4.980057128466085, 6.001945637893029, 7.017608626675408, 8.024863347206402, 9.045076616958672, 9.975869605747842, 10.8012318157505, 9.805256981312805, 8.830958208051044, 7.89232517252492, 6.9424664393201745, 5.889770845725979, 4.874567876237555, 3.9227385465657214, 3.8846380573007546, 2.9472239922804575, 1.9632183826407434, 2.8918274021453936, 3.9310869136947684, 4.932183672659739, 5.88066445011231, 6.871772984514532, 7.857323334672812, 8.834048725507277, 9.834499771204182, 10.902675101228683, 11.754646995431084, 10.792098555075334, 9.761648248959258, 8.71761791999038, 7.789099293550247, 6.853981217743539, 5.860402064582, 4.907267771246908, 4.810213708724368, 3.8862379142581074, 3.019200022185678, 3.9563458378429677, 4.913348835455109, 5.979157005370312, 6.934634521172064, 7.875337920453938, 8.849449444797186, 9.793693917911154, 10.743333887299322, 11.810453211630705, 12.742982791588759, 11.76081285295964, 10.74047749518884, 9.715247252656745, 8.753537830449009, 7.824674480671806, 6.806264846444919, 5.863956528316343, 5.818315802120391, 4.914438019600617, 3.9652001231655913, 4.890587040809431, 5.855911672075486, 6.883491459250773, 7.820666913041837, 8.789196674238658, 9.781402802432371, 10.708936614062086, 11.65508350571756, 12.607484906975204, 13.570140562383214, 12.64118161404809, 11.66337124412296, 10.684133721425155, 9.773778203341154, 8.784398711541378, 7.7314021408016345, 6.768658861381066, 6.762346544915439, 5.91327335568659, 5.039020204078193, 5.918004701824927, 6.826683409726376, 7.853804901329891, 8.795426462525247, 9.827837437039442, 10.801908078374032, 11.650690521984048, 12.676547591685035, 13.605655214756084, 14.587823055927648, 13.645625121257257, 12.615851167551998, 11.70409678850687, 10.680107019377845, 9.639036406267373, 8.63064411271098, 7.698089191143907, 7.773577918200031, 6.8955560296069915, 6.02133128122963, 6.94908164740641, 7.852039258605773, 8.879955728266888, 9.771717909416127, 10.809219420972607, 11.764827843259352, 12.592164558594705, 13.54876561195422, 14.537584620721699, 15.491489226874283, 14.562011354709961, 13.51176563294612, 12.54076846803798, 11.611181867937342, 10.67222654358532, 9.621172328428138, 8.635175421018452, 8.742997058836906, 7.9161528240548895, 7.058480961473444, 7.98651855265147, 8.782799887104805, 9.78734441959962, 10.723625516830259, 11.750883706214974, 12.71545434223448, 13.630379058644785, 14.560808803665992, 15.559947453339694, 16.406349211995156, 15.466950606937422, 14.437639438030446, 13.569189890023221, 12.66933154249499, 11.67640477889034, 10.609587162073128, 9.602614024503534, 9.681076761597131, 8.90291539031929, 8.091455927458739, 8.982113654724495, 9.746532338792116, 10.730982883893619, 11.704126815117725, 12.646261608722142, 13.689739496729356, 14.57613953595784, 15.529399800478624, 16.454573259215667, 16.56257202053315, 15.61596348020262, 14.628976887969692, 13.849935783160548, 12.910552347858637, 12.239659906234474, 11.598070297697, 10.583302549686563, 10.727298738388038, 9.912114607885012, 9.073421772755358, 10.009858509445769, 10.680274986084529, 11.653902855720652, 12.72236288743637, 13.698070661163992, 14.618703294006455, 15.536847897709212, 16.504789601537908, 16.574614226766275, 15.720955902207935, 14.737455221121362, 13.671743658679555, 12.844127459933162, 11.946502754630623, 11.208950284450912, 11.84477462017983, 11.600007282358922, 11.683356575034644, 10.85853616752632, 10.053765643599625, 10.98749248388432, 11.719844649332614, 12.609936531268596, 13.542599665799669, 14.488045453571575, 15.5191462229101, 16.444267553162106, 16.52439449826241, 15.51964518801699, 14.651271866058273, 13.74602608625259, 12.711082226872817, 11.867779180031006, 11.007703994892227, 10.176298887534102, 10.9094216970717, 11.895537961191117, 11.720982996918236, 11.828099750448674, 11.112491327170225, 12.020799377362497, 12.737266277173527, 13.668950450843962, 14.489861632622087, 15.517012075409948, 16.486028791453233, 16.48566089424018, 15.517634256011894, 14.592107925872265, 13.605030594347756, 12.750367753605822, 11.679936739847568, 10.79669835148628, 9.985573933057498, 9.170696152304, 9.923089286950022, 10.892658642197588, 10.72164053380328, 11.701035323430334, 12.153166796261273, 13.010009191020579, 13.69008583926388, 14.61499232298678, 15.454785169941065, 16.392459566039395, 16.68000217625358, 15.687323632720803, 14.659869506553932, 13.695447622385304, 12.668844868392133, 11.730647693360257, 10.743993858954003, 9.789059879278765, 8.931317983600048, 8.119799350051798, 8.94440951054124, 9.890978951075194, 9.748758582902042, 10.690283963747602, 11.635173761266698, 12.631368590505627, 13.55673008649066, 14.552776344414426, 15.51569947727846, 16.54019443656866, 15.615873276801956, 14.647195454008532, 13.688550454937374, 12.66747900329861, 11.644751465117572, 10.706627209761121, 9.779827762108866, 8.863151926166376, 7.9145547471306825, 7.15753408443933, 7.877241171715954, 8.852507787462969, 8.689513950558858, 9.68016311496503, 10.64052259483435, 11.70353247725414, 12.677063727641016, 13.74296937724101, 14.631364465609135, 15.612911200206868, 14.774711464063262, 13.7257100759427, 12.685134598386687, 11.73827385824624, 10.707453612587043, 9.769249760827579, 8.82838886816884, 7.835815720827434, 6.913332122625877, 6.110167056651674, 6.8581414978518325, 7.844590496013012, 7.689179280505765, 8.63500010960321, 9.682626226957215, 10.741454293792621, 11.673316285705647, 12.692116848314178, 13.62665372942805, 14.649564584230191, 13.780320729152798, 12.79969818631298, 11.731569963100009, 10.709437149055155, 9.748912675713221, 8.825231630121209, 7.825197689517003, 6.8628793583795895, 5.914033202211245, 5.0909912913212185, 5.887061007433739, 6.811856227560349, 6.7230726322364855, 7.783725882463748, 8.81160984799612, 9.758630372621589, 10.802462666142477, 11.722346182197864, 12.666634380528233, 13.68845116330489, 12.718274530035464, 11.787853097813533, 10.740903500367867, 9.778170759998925, 8.817430912583669, 7.856773678039634, 6.885649304522569, 5.910013655716471, 4.9588512946760215, 4.065856751994309, 4.959815699672873, 5.773075323681811, 5.8126426175371595, 6.870756088313723, 7.874066243896745, 8.856684731384156, 9.820729257311001, 10.795213985020798, 11.802505837200348, 12.858084785973228, 11.891590475948924, 10.884025583021256, 9.812429324377312, 8.819033101201168, 7.874022978148585, 6.931590026647596, 5.925760578612775, 4.956056413213865, 3.936829429239835, 2.9959770997964403, 3.940544016130799, 4.817842399953959, 4.940777327677909, 5.903276814700403, 6.863928779366319, 7.910936750886364, 8.859231932990381, 9.877802664578631, 10.867586017054233, 11.887485153194293, 11.054615041437298, 10.016654284467755, 8.945087134602481, 7.920341181991938, 6.946048159202134, 6.016629322730389, 4.98346538475964, 4.030205329651817, 3.040939990565578, 1.9839902161853806, 2.939817248106517, 3.8910039592321155], [3.8773623682178373, 2.918387112944907, 1.9390500995076947, 1.0418014009795464, 2.070036040610595, 3.0251498516574546, 4.052493665275432, 5.067377770003063, 6.007034907202163, 7.031461184947768, 8.084773861128772, 9.075191215480029, 10.141254729591536, 10.892235330782558, 9.885439420459605, 8.896961800338708, 7.9395763213651165, 6.915203724136841, 5.914277596527985, 4.887540000177878, 3.037493290056669, 1.9680362838626546, 0.9485372212036911, 0.0, 1.059850393777833, 2.049085020287643, 3.112513724785905, 4.104509538579551, 5.15627216437296, 6.228658468756316, 7.1820541571861956, 8.142096230891347, 9.200906170618367, 10.14701177061022, 9.194305507161653, 8.125800961094368, 7.111971650380938, 6.18364980571676, 5.128398881470244, 4.083273634316995, 3.825826414185837, 2.8846712743629457, 1.9279116825343552, 0.9897870783444921, 1.987503660421257, 3.0003173047646716, 4.031519907262394, 5.053408416689338, 6.069071405471718, 7.076326126002712, 8.096539395754982, 9.027332384544152, 10.079602614115394, 10.753794202516495, 9.779495429254734, 8.84086239372861, 7.891003660523865, 6.83830806692967, 5.823105097441246, 4.871275767769412, 4.833175278504446, 3.895761213484149, 2.9117556038444348, 2.054341445450217, 3.049340926824141, 3.983646451456048, 4.9321272289086195, 5.923235763310841, 6.908786113469121, 7.885511504303586, 8.885962550000492, 9.954137880024993, 10.918041161121119, 11.740635776279026, 10.71018547016295, 9.666155141194071, 8.73763651475394, 7.80251843894723, 6.808939285785691, 5.855804992450599, 5.75875092992806, 4.834775135461799, 3.967737243389369, 3.1188598811477912, 4.031602848584481, 5.03960514462005, 5.986097299968373, 6.926800699250247, 7.900912223593494, 8.845156696707463, 9.79479666609563, 10.861915990427011, 11.89653412644336, 12.709350074163332, 11.689014716392531, 10.663784473860435, 9.702075051652699, 8.773211701875496, 7.75480206764861, 6.812493749520034, 6.7668530233240825, 5.862975240804308, 4.913737344369283, 4.173906619138861, 4.974165685204858, 6.001745472380145, 6.938920926171209, 7.889107566384711, 8.83286558122868, 9.760399392858394, 10.706546284513868, 11.658947685771512, 12.649466657309674, 13.578425605644798, 12.61190846532665, 11.632670942628845, 10.722315424544844, 9.73293593274507, 8.679939362005326, 7.717196082584758, 7.710883766119131, 6.861810576890281, 5.987557425281885, 5.201324280154356, 5.94493742285575, 6.9720589144592635, 7.913680475654621, 8.927748329185494, 9.85337085717034, 10.702153300780356, 11.728010370481343, 12.657117993552392, 13.639285834723957, 14.592094774119582, 13.564388388755688, 12.652634009710564, 11.628644240581536, 10.587573627471064, 9.579181333914672, 8.646626412347599, 8.722115139403723, 7.844093250810682, 6.969868502433322, 6.232401225735839, 6.970293271735146, 7.998209741396259, 8.8899719225455, 9.90913031311866, 10.81629062205566, 11.643627337391013, 12.600228390750528, 13.589047399518007, 14.542952005670589, 15.510548575913653, 14.460302854149813, 13.489305689241672, 12.559719089141034, 11.620763764789011, 10.56970954963183, 9.583712642222144, 9.691534280040598, 8.86469004525858, 8.007018182677136, 7.286042329859622, 7.901053900234178, 8.905598432728993, 9.841879529959632, 10.869137719344348, 11.833708355363854, 12.681841837441095, 13.6122715824623, 14.611410232136002, 15.506838266906332, 15.65430150551479, 14.728326320592867, 13.97357233803659, 13.152390631780762, 12.624942000094032, 11.55812438327682, 10.551151245707226, 10.629613982800823, 9.85145261152298, 9.03999314866243, 8.281637431932648, 8.86478635192149, 9.849236897022992, 10.822380828247098, 11.764515621851515, 12.80799350985873, 13.62760231475415, 14.580862579274932, 15.506036038011974, 15.667189549031004, 14.720581008700472, 13.733594416467545, 13.011454633572182, 12.14969528672066, 13.188197127438166, 12.546607518900691, 11.531839770890254, 11.67583595959173, 10.860651829088702, 10.02195899395905, 9.309382286653921, 9.798528999213902, 10.772156868850026, 11.840616900565744, 12.816324674293366, 13.736957307135828, 14.588310676505522, 15.556252380334216, 15.654763087266955, 14.801104762708617, 13.842072749619213, 12.776361187177407, 11.948744988431015, 11.185645693492646, 12.157487505654604, 12.79331184138352, 12.548544503562614, 12.631893796238336, 11.80707338873001, 11.002302864803317, 10.287016261092473, 10.838098662461988, 11.72819054439797, 12.660853678929042, 13.606299466700948, 14.637400236039474, 15.56252156629148, 15.604543358763092, 14.599794048517671, 13.731420726558955, 12.850643614750442, 11.81569975537067, 10.972396708528859, 10.246846933754249, 11.124836108737794, 11.857958918275388, 12.844075182394807, 12.669520218121926, 12.776636971652364, 12.061028548373917, 11.32032315457065, 11.8555202903029, 12.787204463973335, 13.608115645751461, 14.635266088539321, 15.604282804582606, 15.565809754740862, 14.597783116512575, 13.672256786372946, 12.685179454848438, 11.854985282103675, 10.78455426834542, 9.901315879984132, 9.22471687191952, 10.119233373507692, 10.87162650815371, 11.841195863401277, 11.67017775500697, 12.649572544634024, 13.101704017464964, 12.309532968228732, 12.808339852393253, 13.733246336116153, 14.573039183070438, 15.510713579168769, 15.760151036754264, 14.767472493221486, 13.740018367054615, 12.775596482885986, 11.748993728892815, 10.835265221858108, 9.848611387451855, 8.893677407776618, 8.17046092246207, 9.06833657125549, 9.892946731744928, 10.839516172278882, 10.697295804105732, 11.638821184951292, 12.583710982470388, 13.305829798459696, 13.7791658664684, 14.775212124392166, 15.612574571973713, 15.651312028401252, 14.69602213730264, 13.727344314509216, 12.768699315438058, 11.747627863799291, 10.724900325618254, 9.811244738258974, 8.884445290606719, 7.9677694546642295, 7.153697685992705, 8.106071305643022, 8.825778392919643, 9.801045008666659, 9.638051171762548, 10.628700336168722, 11.58905981603804, 12.65206969845783, 13.625600948844706, 14.6915065984447, 15.579901686812825, 14.776524577216154, 13.835124845266222, 12.805858936443384, 11.765283458887371, 10.818422718746923, 9.787602473087727, 8.873867289325434, 7.933006396666693, 6.940433249325288, 6.152475061487899, 7.058704277855366, 7.8066787190555225, 8.793127717216702, 8.637716501709455, 9.583537330806902, 10.631163448160905, 11.689991514996311, 12.621853506909337, 13.640654069517868, 14.57519095063174, 13.813177961239477, 12.840734110355758, 11.879847046813664, 10.811718823600692, 9.789586009555839, 8.829061536213905, 7.929849158619064, 6.9298152180148564, 5.967496886877443, 5.153176141073267, 6.03952851252491, 6.835598228637429, 7.76039344876404, 7.671609853440176, 8.732263103667439, 9.760147069199812, 10.70716759382528, 11.750999887346168, 12.670883403401557, 13.615171601731927, 12.783719651237156, 11.778687911238425, 10.848266479016495, 9.801316881570829, 8.838584141201887, 7.897579773084352, 6.936922538540317, 5.965798165023252, 5.014631184214324, 4.197994233538043, 5.0143939731980005, 5.908352920876563, 6.7216125448855015, 6.76117983874085, 7.8192933095174135, 8.822603465100435, 9.805221952587846, 10.769266478514695, 11.743751206224491, 12.751043058404042, 12.003109583811135, 10.952003857151883, 9.944438964224217, 8.872842705580274, 7.87944648240413, 6.9344363593515475, 5.992003407850557, 4.986173959815736, 4.05916106770839, 3.1759723681018563, 3.944514321000131, 4.88908123733449, 5.7663796211576495, 5.889314548881599, 6.851814035904094, 7.8124660005700095, 8.859473972090056, 9.807769154194073, 10.826339885782325, 11.816123238257926, 11.056783828125761, 10.115028422640261, 9.077067665670718, 8.005500515805444, 6.9807545631949, 6.0064615404050965, 5.077042703933351, 4.043878765962601, 3.090618710854779, 2.10135337176854, 2.932527437389072, 3.8883544693102077, 4.839541180435806], [4.937212761995671, 3.9782375067227402, 2.998900493285528, 2.058264068810207, 1.0300294291791587, 1.9684365448270649, 2.9957803584450424, 4.010664463172673, 4.950321600371773, 5.974747878117379, 7.028060554298382, 8.01847790864964, 9.084541422761147, 10.092933855696955, 10.945289814237437, 9.95681219411654, 8.999426715142949, 7.975054117914674, 6.974127990305818, 5.947390393955711, 4.097343683834502, 3.027886677640488, 2.0083876149815243, 1.059850393777833, 0.0, 0.98923462650981, 2.0526633310080724, 3.0446591448017184, 4.096421770595128, 5.168808074978483, 6.122203763408363, 7.082245837113514, 8.141055776840535, 9.157482949257805, 10.110189212706372, 9.185651354872201, 8.171822044158771, 7.243500199494593, 6.1882492752480776, 5.143124028094828, 4.79057415126589, 3.8494190114429987, 2.892659419614408, 1.9264936994507544, 0.9276532666434242, 1.9404669109868387, 2.971669513484561, 3.993558022911505, 5.009221011693883, 6.016475732224878, 7.036689001977148, 7.967481990766318, 9.01975222033756, 10.015727054775255, 10.744243166334789, 9.805610130808665, 8.85575139760392, 7.803055804009723, 6.787852834521299, 5.836023504849465, 5.797923015584499, 4.860508950564202, 3.876503340924488, 2.9910480665564796, 1.989490533046308, 2.923796057678215, 3.8722768351307866, 4.863385369533009, 5.848935719691289, 6.825661110525753, 7.82611215622266, 8.89428748624716, 9.858190767343286, 10.820739207699036, 11.674933207243003, 10.630902878274124, 9.702384251833992, 8.767266176027283, 7.773687022865744, 6.820552729530652, 6.723498667008113, 5.799522872541852, 4.932484980469422, 3.9812549010627443, 2.971752454806648, 3.9797547508422175, 4.92624690619054, 5.866950305472415, 6.841061829815661, 7.785306302929629, 8.734946272317796, 9.802065596649179, 10.836683732665527, 11.792892408034229, 12.653762453472584, 11.628532210940488, 10.666822788732752, 9.73795943895555, 8.719549804728663, 7.777241486600087, 7.7316007604041355, 6.827722977884361, 5.878485081449336, 4.953144752460881, 3.914315291427025, 4.941895078602312, 5.879070532393376, 6.829257172606878, 7.773015187450847, 8.700548999080562, 9.646695890736035, 10.59909729199368, 11.589616263531841, 12.518575211866965, 13.496385581792095, 12.597418679708898, 11.687063161624897, 10.697683669825123, 9.64468709908538, 8.681943819664811, 8.675631503199185, 7.826558313970334, 6.952305162361938, 5.953980094727182, 4.885087029077916, 5.91220852068143, 6.8538300818767866, 7.867897935407662, 8.793520463392507, 9.642302907002524, 10.66815997670351, 11.59726759977456, 12.579435440946124, 13.53224438034175, 14.448865505221134, 13.617381746790617, 12.59339197766159, 11.552321364551117, 10.543929070994725, 9.611374149427652, 9.686862876483776, 8.808840987890735, 7.891876855905827, 6.881999352939919, 5.910442877957312, 6.938359347618426, 7.830121528767665, 8.849279919340827, 9.756440228277828, 10.58377694361318, 11.540377996972696, 12.529197005740174, 13.483101611892756, 14.535930087456245, 14.626173390998414, 13.973967025343052, 13.524466826221087, 12.585511501869064, 11.534457286711882, 10.548460379302197, 10.65628201712065, 9.710206098287776, 8.716505415128339, 7.788467823950313, 6.841203506456344, 7.84574803895116, 8.7820291361818, 9.809287325566515, 10.773857961586021, 11.621991443663262, 12.552421188684468, 13.55155983835817, 14.4469878731285, 14.62627477083601, 13.700299585914088, 12.945545603357811, 13.753562179749899, 13.589689737174085, 12.522872120356872, 11.515898982787279, 11.594361719880876, 10.696968664552175, 9.743949917236726, 8.762824840737531, 7.804935958143655, 8.78938650324516, 9.762530434469266, 10.704665228073683, 11.748143116080897, 12.567751920976317, 13.5210121854971, 14.446185644234141, 14.639162814352225, 13.692554274021694, 12.705567681788766, 11.983427898893403, 12.750866834689797, 13.825125463039317, 13.511355255980744, 12.496587507970307, 12.640583696671783, 11.67003542861627, 10.725915762533345, 9.739346644350942, 8.738678605436068, 9.712306475072191, 10.78076650678791, 11.756474280515533, 12.677106913357996, 13.52846028272769, 14.496401986556384, 14.598049780436567, 13.744391455878228, 12.814046014940434, 11.748334452498629, 10.920718253752236, 11.786817241461783, 12.798439317588835, 13.684438545769886, 13.513292240642667, 13.544410100203221, 12.616456988257578, 11.706259633377613, 10.716980618789494, 9.778248268684155, 10.668340150620136, 11.601003285151208, 12.546449072923114, 13.57754984226164, 14.502671172513645, 14.547830051932703, 13.543080741687282, 12.674707419728566, 11.822616880071664, 10.78767302069189, 9.94436997385008, 10.848018481723386, 11.774832310236729, 12.749085622661756, 13.776502987845257, 13.72937061189976, 13.586020571179931, 12.764985316948213, 11.75028751226767, 10.795669896525068, 11.727354070195501, 12.548265251973627, 13.575415694761487, 14.544432410804772, 14.509096447910473, 13.541069809682186, 12.615543479542557, 11.628466148018049, 10.826958547424896, 9.756527533666642, 8.873289145305353, 9.825888419888658, 10.814588803183337, 11.857269952272603, 12.826839307520169, 12.730028148784804, 13.709422938411858, 13.707616825684605, 12.739497325925752, 11.74848945861542, 12.673395942338319, 13.513188789292604, 14.450863185390935, 14.703437729923875, 13.710759186391098, 12.683305060224226, 11.718883176055597, 10.692280422062426, 9.80723848717933, 8.820584652773077, 7.865650673097838, 8.849358180036507, 9.838045557121086, 10.87859017586382, 11.825159616397775, 11.757146197883566, 12.698671578729126, 13.643561376248224, 13.6446769686756, 12.719315472690568, 13.715361730614333, 14.552724178195879, 14.594598721570863, 13.63930883047225, 12.670631007678827, 11.711986008607669, 10.690914556968902, 9.668187018787865, 8.783218003580195, 7.85641855592794, 6.93974271998545, 7.893253452188482, 8.898354487704852, 9.842260266993977, 10.847744334113562, 10.697901565540382, 11.688550729946556, 12.648910209815876, 13.711920092235665, 13.745243847223865, 14.64738810033392, 14.719229165952958, 13.719811270385765, 12.778411538435833, 11.749145629612995, 10.708570152056982, 9.761709411916534, 8.730889166257338, 7.832377602157921, 6.904979661987913, 5.912406514646508, 6.892030827683676, 7.850987459917195, 8.853378044502426, 9.839827042663606, 9.69756689548729, 10.643387724584736, 11.69101384193874, 12.749841908774147, 13.681703900687173, 14.666325665123074, 13.77937550921123, 12.756464654409088, 11.784020803525369, 10.823133739983275, 9.755005516770304, 8.73287270272545, 7.772348229383515, 6.888359471451551, 5.901788483336077, 4.9394701521986635, 5.892948718111217, 6.92284259379631, 7.8822975540843325, 8.820243842541872, 8.73146024721801, 9.792113497445271, 10.819997462977645, 11.767017987603113, 12.810850281124, 13.693111325513792, 12.748823127183423, 11.727006344406766, 10.721974604408034, 9.791553172186104, 8.744603574740438, 7.781870834371497, 6.840866466253962, 5.880209231709927, 4.9090848581928626, 3.9866044495355446, 4.937766810575994, 5.993469921638987, 6.955052246323467, 7.781462938663335, 7.821030232518684, 8.879143703295247, 9.882453858878268, 10.865072346365679, 11.829116872292527, 12.803601600002324, 11.954889477581547, 10.946396276980746, 9.895290550321494, 8.887725657393828, 7.816129398749885, 6.82273317557374, 5.877723052521158, 4.9352901010201675, 3.9294606529853464, 3.03113433302961, 4.05036131700364, 4.991213646447035, 5.935780562781393, 6.826230014935483, 6.949164942659433, 7.911664429681927, 8.872316394347843, 9.919324365867888, 10.867619547971906, 11.886190279560157, 11.019969657435432, 10.000070521295372, 9.058315115809872, 8.020354358840327, 6.9487872089750535, 5.92404125636451, 4.949748233574707, 4.020329397102961, 2.987165459132212, 2.062591976176, 3.051857315262239, 3.992377831166905, 4.9482048630880415, 5.89939157421364], [5.891737779177887, 4.932762523904956, 3.9534255104677443, 2.962550368995163, 1.9343157293641147, 0.979201918317255, 2.0065457319352324, 3.021429836662863, 3.9610869738619634, 4.985513251607569, 6.038825927788572, 7.02924328213983, 8.095306796251338, 9.103699229187146, 10.048082581767215, 10.911337211298758, 9.953951732325166, 8.92957913509689, 7.928653007488034, 6.901915411137927, 5.086578310344311, 4.017121304150297, 2.9976222414913343, 2.049085020287643, 0.98923462650981, 0.0, 1.0634287044982622, 2.0554245182919084, 3.1071871440853176, 4.179573448468673, 5.132969136898552, 6.093011210603703, 7.151821150330724, 8.168248322747994, 9.12095458619656, 10.17488598138201, 9.16105667066858, 8.232734826004403, 7.177483901757887, 6.132358654604637, 5.7798087777757, 4.838653637952809, 3.881894046124218, 2.9157283259605644, 1.916887893153234, 1.0395997288995475, 2.066158803833782, 3.0880473132607262, 4.103710302043105, 5.110965022574099, 6.13117829232637, 7.0619712811155395, 8.114241510686782, 9.110216345124476, 10.06924716578939, 10.794844757318476, 9.84498602411373, 8.792290430519534, 7.777087461031109, 6.825258131359275, 6.787157642094309, 5.849743577074012, 4.865737967434297, 3.9802826930662896, 2.9787251595561175, 2.0229288755909236, 2.9714096530434952, 3.9625181874457174, 4.948068537603998, 5.924793928438462, 6.925244974135369, 7.993420304159869, 8.957323585255995, 9.919872025611745, 10.950322331727822, 11.620137504783935, 10.691618878343803, 9.756500802537094, 8.762921649375555, 7.809787356040462, 7.712733293517923, 6.788757499051662, 5.921719606979232, 4.970489527572554, 3.9609870813164574, 3.0788875687549258, 4.0253797241032485, 4.966083123385123, 5.9401946477283705, 6.884439120842338, 7.834079090230506, 8.901198414561888, 9.935816550578238, 10.892025225946938, 11.912360583717739, 12.6177668374503, 11.656057415242564, 10.727194065465362, 9.708784431238474, 8.766476113109897, 8.720835386913945, 7.816957604394171, 6.867719707959146, 5.94237937897069, 4.903549917936834, 4.129692095099285, 5.0668675488903485, 5.9283899905195865, 6.872148005363556, 7.799681816993271, 8.745828708648745, 9.698230109906389, 10.68874908144455, 11.617708029779674, 12.595518399704805, 13.574755922402609, 12.67629778813471, 11.686918296334934, 10.63392172559519, 9.671178446174622, 9.664866129708994, 8.815792940480144, 7.941539788871747, 6.943214721236991, 5.874321655587725, 5.100005537178403, 6.041627098373761, 6.96703075332037, 7.892653281305217, 8.741435724915233, 9.76729279461622, 10.696400417687268, 11.678568258858833, 12.631377198254459, 13.547998323133843, 14.50217747039056, 13.5826266041714, 12.541555991060928, 11.533163697504536, 10.600608775937463, 10.676097502993585, 9.798075614400545, 8.881111482415637, 7.871233979449728, 6.899677504467121, 6.126156364115399, 7.0179185452646395, 7.948412737253534, 8.855573046190537, 9.68290976152589, 10.639510814885405, 11.628329823652884, 12.582234429805467, 13.635062905368954, 13.695389204742309, 14.66638636965045, 14.513701452730897, 13.574746128378875, 12.523691913221693, 11.537695005812008, 11.64551664363046, 10.699440724797585, 9.705740041638148, 8.777702450460122, 7.830438132966153, 7.168487473590485, 8.084447437274624, 8.952460759261124, 9.87493685883386, 10.72112426157597, 11.651554006597177, 12.650692656270879, 13.54612069104121, 13.695490584579906, 12.769515399657983, 13.732727637700933, 14.657848479934854, 14.578924363683896, 13.512106746866683, 12.50513360929709, 12.583596346390685, 11.686203291061984, 10.733184543746535, 9.75205946724734, 8.794170584653465, 8.112125937884484, 9.067654601415734, 9.929140366329136, 10.943742658308972, 11.666884738889024, 12.620145003409808, 13.54531846214685, 13.70837862809612, 12.761770087765589, 11.774783495532661, 12.770609933236525, 13.655153134874752, 14.72941176322427, 14.500589882490555, 13.485822134480118, 13.629818323181592, 12.659270055126079, 11.715150389043155, 10.72858127086075, 9.727913231945877, 9.17588991879335, 10.116073800758734, 10.980949418770987, 11.872706455586071, 12.627593100640397, 13.595534804469093, 13.608815153926757, 12.755156829368419, 11.88326182868433, 10.817550266242524, 11.76835881293763, 12.691103541646738, 13.70272561777379, 14.588724845954843, 14.502526867152477, 14.53364472671303, 13.605691614767387, 12.695494259887422, 11.706215245299303, 10.767482895193965, 10.131923594341295, 11.064586728872367, 11.970657118714453, 12.823470461216074, 13.649588781108351, 13.558595425422894, 12.553846115177473, 11.685472793218757, 10.891832693815559, 9.856888834435786, 10.806081099820435, 11.752304781908341, 12.679118610421684, 13.653371922846711, 14.680789288030212, 14.671274261187413, 14.57525519768974, 13.754219943458022, 12.73952213877748, 11.784904523034877, 11.19093751391666, 12.011848695694786, 13.013072992396054, 13.848667602527737, 13.519861821400664, 12.551835183172377, 11.626308853032748, 10.63923152150824, 9.896174361168791, 8.825743347410537, 9.777575445490308, 10.730174720073613, 11.718875103368292, 12.761556252457558, 13.731125607705124, 13.671931798072457, 14.651326587699511, 14.696851452194414, 13.728731952435561, 12.73772408512523, 12.136979386059478, 12.976772233013763, 13.914446629112094, 13.714203103414064, 12.721524559881287, 11.694070433714415, 10.729648549545788, 9.703045795552617, 8.876454300923225, 7.889800466516972, 8.769936973282794, 9.753644480221462, 10.742331857306041, 11.782876476048775, 12.72944591658273, 12.699049847171219, 13.640575228016779, 14.598086393430437, 14.63391159518541, 13.708550099200377, 13.189731005488301, 14.016307621917038, 13.605364095061052, 12.65007420396244, 11.681396381169016, 10.722751382097858, 9.701679930459093, 8.678952392278056, 7.852433817324091, 6.925634369671835, 7.844029020170406, 8.797539752373437, 9.802640787889807, 10.746546567178932, 11.752030634298517, 11.652426582722597, 12.643075747128771, 13.603435226998089, 14.666445109417879, 14.734478473733674, 14.121757375207888, 13.72999453944315, 12.730576643875956, 11.789176911926024, 10.759911003103184, 9.719335525547171, 8.772474785406725, 7.741654539747529, 6.843142975648112, 5.9741954757318085, 6.816692814831464, 7.796317127868631, 8.75527376010215, 9.757664344687381, 10.74411334284856, 10.652091912669505, 11.597912741766951, 12.645538859120954, 13.70436692595636, 14.636228917869387, 13.677091038613264, 12.79014088270142, 11.767230027899279, 10.79478617701556, 9.833899113473464, 8.765770890260493, 7.74363807621564, 6.783113602873706, 5.899124844941742, 4.959392700924722, 5.843756452383619, 6.797235018296174, 7.827128893981267, 8.786583854269288, 9.761807268526178, 9.685985264400225, 10.746638514627486, 11.77452248015986, 12.721543004785328, 13.699111852098966, 12.703876699003983, 11.759588500673614, 10.737771717896957, 9.732739977898225, 8.802318545676295, 7.755368948230629, 6.792636207861687, 5.851631839744153, 4.8909746052001175, 3.9198502316830526, 4.8908907497205005, 5.84205311076095, 6.8977562218239425, 7.859338546508422, 8.73598795584555, 8.775555249700899, 9.833668720477462, 10.836978876060485, 11.819597363547896, 12.78364188947474, 11.93129894835211, 10.965654851071736, 9.957161650470937, 8.906055923811685, 7.898491030884017, 6.826894772240075, 5.83349854906393, 4.888488426011348, 3.9460554745103575, 2.9402260264755364, 3.935420633214566, 4.954647617188595, 5.89549994663199, 6.840066862966348, 7.780755032117699, 7.903689959841649, 8.866189446864142, 9.826841411530058, 10.873849383050104, 11.82214456515412, 10.988983047089935, 10.030735030925621, 9.010835894785561, 8.069080489300061, 7.031119732330518, 5.9595525824652436, 4.9348066298547, 3.9605136070648967, 3.0310947705931515, 1.997930832622402, 2.966878276360956, 3.956143615447195, 4.946902848349121, 5.9027298802702575, 6.853916591395856], [6.890006378098799, 5.9310311228258685, 4.951694109388656, 3.9608189679160746, 2.932584328285026, 1.9774705172381664, 0.9501267036201889, 1.9650108083478193, 2.9046679455469198, 3.929094223292525, 4.982406899473529, 5.972824253824786, 7.038887767936293, 8.047280200872102, 8.984653877268952, 9.973131497389849, 10.93051697636344, 9.927847734017803, 8.926921606408946, 7.900184010058839, 6.150007014842574, 5.08055000864856, 4.061050945989597, 3.1125137247859054, 2.0526633310080724, 1.0634287044982622, 0.0, 0.9919958137936462, 2.043758439587055, 3.116144743970411, 4.06954043240029, 5.029582506105441, 6.088392445832461, 7.104819618249731, 8.057525881698298, 9.126030427765583, 10.139859738479013, 9.296163530502666, 8.240912606256149, 7.1957873591029, 6.843237482273962, 5.902082342451071, 4.945322750622481, 3.979157030458827, 2.9803165976514965, 2.0339327018332423, 1.0027300993355197, 2.024618608762464, 3.0402815975448427, 4.047536318075837, 5.067749587828107, 5.998542576617277, 7.050812806188518, 8.046787640626214, 9.005818461291128, 9.944451496817251, 10.894310230021997, 9.855719135017795, 8.84051616552937, 7.888686835857538, 7.850586346592571, 6.913172281572274, 5.92916667193256, 5.022501628770586, 3.9832421172212107, 2.957800158298504, 2.009319380845932, 3.0004279152481543, 3.9859782654064344, 4.962703656240899, 5.963154701937806, 6.986907442437925, 7.950810723534051, 8.913359163889801, 9.943809470005878, 10.95552776540363, 11.755047582842064, 10.819929507035354, 9.826350353873815, 8.873216060538725, 8.776161998016185, 7.852186203549924, 6.985148311477494, 5.975006485237647, 4.965504038981551, 4.013758851462506, 3.0632894519056855, 4.00399285118756, 4.978104375530807, 5.922348848644775, 6.871988818032943, 7.926277142850475, 8.939146519691725, 9.885512364224994, 10.905847721995794, 11.933851745398986, 12.719486119740825, 11.790622769963623, 10.772213135736735, 9.82990481760816, 9.784264091412208, 8.821521150714648, 7.8722832542796235, 6.946896336635784, 5.908066875601928, 5.045140642558353, 4.10796518876729, 4.966299718322023, 5.910057733165993, 6.837591544795708, 7.783738436451181, 8.736139837708825, 9.726658809246986, 10.65561775758211, 11.63342812750724, 12.612665650205045, 13.539998651090036, 12.750347000833196, 11.697350430093453, 10.734607150672884, 10.728294834207256, 9.820356486800621, 8.946103335192225, 7.947731678902086, 6.878838613252819, 6.015454084637471, 5.17017586498223, 6.004940481122807, 6.930563009107654, 7.779345452717671, 8.805202522418655, 9.734310145489705, 10.71647798666127, 11.669286926056895, 12.585908050936279, 13.540087198192996, 14.502252295725095, 13.60498469555919, 12.596592402002798, 11.664037480435725, 11.739526207491847, 10.802639160721023, 9.885628440080731, 8.875750937114823, 7.9041944621322155, 7.041604911574467, 6.146467311873109, 6.986322465055972, 7.893482773992975, 8.720819489328328, 9.677420542687843, 10.66623955145532, 11.620144157607903, 12.67297263317139, 13.659266519051386, 14.59414638324877, 15.523732983349408, 14.638174832877137, 13.587120617719956, 12.60112371031027, 12.708945348128722, 11.70395768246268, 10.710256999303242, 9.782219408125217, 8.834955090631247, 8.083936021049553, 7.212996203883094, 7.9903704870635615, 8.912846586636299, 9.759033989378409, 10.689463734399615, 11.688602384073315, 12.584030418843646, 13.226250555811987, 13.746952277206397, 14.710164515249346, 15.63788209794491, 15.642353068182159, 14.575535451364946, 13.568562313795352, 13.647025050888947, 12.690720248727079, 11.737701501411628, 10.756576424912435, 9.798687542318559, 9.027574485343552, 8.196203368024204, 8.967050094131574, 9.98165238611141, 10.704794466691464, 11.658054731212246, 12.583228189949288, 12.77244524390581, 12.29253005899767, 12.752220373081075, 13.748046810784938, 14.653421733795664, 15.727680362145183, 15.564018586988817, 14.54925083897838, 14.693247027679854, 13.663787012791172, 12.719667346708247, 11.733098228525844, 10.732430189610971, 10.091338466252418, 9.244622567367204, 10.018859146573424, 10.910616183388509, 11.665502828442836, 12.63344453227153, 12.602082983933986, 11.748424659375647, 11.220872734930627, 11.794987143790937, 12.745795690486043, 13.68937214056765, 14.700994216694703, 15.586993444875755, 15.56595557165074, 15.538161684378123, 14.61020857243248, 13.700011217552515, 12.710732202964396, 11.771999852859057, 11.047372141800363, 10.206460134297714, 11.00856684651689, 11.861380189018512, 12.68749850891079, 12.551863255430122, 11.547113945184702, 10.678740623225986, 10.16656726931772, 10.8343257119842, 11.783517977368849, 12.750573380829254, 13.677387209342596, 14.651640521767623, 15.679057886951124, 15.669542860108326, 15.579772155354833, 14.758736901123115, 13.744039096442572, 12.78942148069997, 12.106386061375728, 11.153722101120133, 12.050982720198492, 12.886577330330176, 12.51312965140789, 11.545103013179606, 10.619576683039977, 9.632499351515468, 9.100853923696498, 9.80318022495895, 10.77584404441122, 11.728443318994525, 12.717143702289205, 13.75982485137847, 14.729394206626036, 14.67020039699337, 15.649595186620424, 15.701368409859507, 14.733248910100654, 13.742241042790322, 13.052427933518546, 12.11864563843911, 13.00472888272523, 12.663231032265925, 11.670552488733147, 10.643098362566276, 9.722916379553016, 8.696313625559846, 8.052387969696543, 8.867237344065385, 9.768205572203707, 10.751913079142374, 11.740600456226954, 12.781145074969688, 13.727714515503642, 13.697318446092131, 14.638843826937691, 15.596354992351353, 15.638428552850502, 14.71306705686547, 14.10517955294737, 13.158181027342385, 12.554392023912913, 11.5991021328143, 10.630424310020876, 9.671779310949718, 8.694947760466322, 7.672220222285285, 7.028367486097407, 7.9030712472202485, 8.842297619091317, 9.79580835129435, 10.80090938681072, 11.744815166099844, 12.75029923321943, 12.650695181643512, 13.641344346049685, 14.601703825919005, 15.528579902453236, 14.627799449568453, 13.695475647861983, 12.673575511128105, 11.674157615560912, 10.73275788361098, 9.708938931955045, 8.668363454399032, 7.765742615413952, 6.734922369754757, 5.953487239159436, 6.951632353280223, 7.814961413752376, 8.794585726789544, 9.753542359023063, 10.755932943608293, 11.742381941769473, 11.650360511590419, 12.596181340687865, 13.64380745804187, 14.55591399954611, 13.624052007633084, 12.620672010298222, 11.733721854386376, 10.710810999584234, 9.738367148700515, 8.782927042325326, 7.714798819112354, 6.736905906222868, 5.7763814328809335, 5.009469108453066, 5.9576612998456335, 6.842025051304531, 7.795503617217085, 8.825397492902177, 9.7848524531902, 10.76007586744709, 10.684253863321139, 11.7449071135484, 12.772791079080774, 13.68652511730481, 12.642692823783923, 11.64745767068894, 10.70316947235857, 9.681352689581914, 8.676320949583182, 7.745899517361252, 6.698949919915586, 5.736217179546644, 4.84489966975138, 4.001318868711442, 4.918118830603964, 5.889159348641412, 6.840321709681861, 7.896024820744854, 8.857607145429334, 9.734256554766464, 9.773823848621813, 10.831937319398376, 11.835247474981397, 12.817865962468808, 11.842354971563644, 10.867870243853847, 9.909235822756694, 8.900742622155894, 7.849636895496642, 6.842072002568974, 5.770475743925032, 4.777079520748887, 3.832069397696305, 2.9500923964030883, 3.938494625396448, 4.933689232135477, 5.952916216109507, 6.893768545552902, 7.838335461887261, 8.779023631038612, 8.901958558762562, 9.864458045785055, 10.82511001045097, 11.872117981971016, 10.982945933279769, 9.925554342591672, 8.974316002610578, 7.954416866470519, 7.012661460985018, 5.974700704015474, 4.9031335541502, 3.8783876015396563, 2.9040945787498536, 1.9746757422781083, 2.9961994315433134, 3.9651468752818673, 4.954412214368107, 5.945171447270034, 6.90099847919117, 7.852185190316768], [7.882002191892445, 6.9230269366195145, 5.943689923182302, 4.952814781709721, 3.9245801420786726, 2.969466331031813, 1.9421225174138352, 1.0496479558619909, 1.9893050930610914, 3.0137313708066964, 4.020612471369283, 5.011029825720541, 6.0770933398320475, 7.075287394783458, 7.992658063475307, 8.981135683596204, 9.938521162569796, 10.91984354781145, 9.918917420202593, 8.892179823852485, 7.142002828636219, 6.072545822442205, 5.053046759783242, 4.104509538579551, 3.0446591448017184, 2.0554245182919084, 0.9919958137936462, 0.0, 1.0517626257934092, 2.124148930176765, 3.077544618606644, 4.037586692311795, 5.096396632038815, 6.112823804456085, 7.065530067904652, 8.134034613971938, 9.147863924685367, 10.076185769349545, 9.232908420049794, 8.187783172896545, 7.835233296067607, 6.894078156244716, 5.937318564416126, 4.971152844252472, 3.9723124114451425, 3.0259285156268882, 1.994725913129166, 1.0592928834747415, 2.068199817499514, 3.0754545380305087, 4.095667807782779, 5.026460796571949, 6.07873102614319, 7.074705860580885, 8.013822647497483, 8.952455683023606, 9.902314416228352, 10.84771494881144, 9.832511979323016, 8.880682649651183, 8.842582160386216, 7.905168095365919, 6.921162485726205, 6.014497442564231, 4.975237931014856, 3.94979597209215, 3.001315194639578, 2.1263610434642963, 3.0841182712908077, 4.060843662125272, 5.061294707822179, 6.014825662392597, 6.978728943488723, 7.941277383844474, 8.97172768996055, 9.963531951609985, 10.83134832673101, 11.76646640253772, 10.81834616766746, 9.86521187433237, 9.76815781180983, 8.84418201734357, 7.977144125271139, 6.967002299031293, 5.957499852775197, 5.005754665256152, 4.0552852656993315, 3.1902286161669546, 4.07624438141518, 5.020488854529148, 5.970128823917316, 6.954195362805146, 7.967064739646396, 8.913430584179666, 9.933765941950467, 10.961769965353659, 11.830444188484826, 12.759307538262028, 11.76420894953038, 10.821900631401805, 10.776259905205853, 9.813516964508295, 8.86427906807327, 7.93889215042943, 6.900062689395574, 6.037136456352, 5.099961002560936, 4.152535483301418, 5.008197739050366, 5.935731550680081, 6.8818784423355535, 7.8342798435931975, 8.82479881513136, 9.753757763466483, 10.731568133391614, 11.710805656089418, 12.638138656974409, 13.694499863671249, 12.689346243887098, 11.72660296446653, 11.720290648000901, 10.812352300594268, 9.938099148985872, 8.93972749269573, 7.870834427046464, 7.007449898431118, 6.162171678775875, 5.191176246102201, 6.028703014992027, 6.8774854586020435, 7.903342528303028, 8.832450151374077, 9.814617992545642, 10.767426931941268, 11.684048056820652, 12.638227204077367, 13.600392301609467, 14.596980509352836, 13.588588215796443, 12.65603329422937, 12.731522021285492, 11.79463497451467, 10.877624253874377, 9.867746750908468, 8.89619027592586, 8.033600725368114, 7.138463125666754, 6.172558230035365, 6.991622779877348, 7.8189594952127015, 8.775560548572216, 9.764379557339693, 10.718284163492275, 11.771112639055763, 12.757406524935758, 13.692286389133141, 14.621872989233779, 15.560828313585802, 14.5791164315136, 13.593119524103916, 13.700941161922367, 12.695953496256324, 11.702252813096887, 10.774215221918862, 9.826950904424892, 9.0759318348432, 8.20386444142767, 7.176606252042955, 8.010986592520672, 8.857173995262782, 9.787603740283988, 10.786742389957688, 11.682170424728017, 12.62156902978575, 13.650880198692725, 14.638557425151848, 15.566275007847413, 16.632193624584833, 15.56753126515859, 14.560558127588997, 14.639020864682593, 13.682716062520724, 12.729697315205275, 11.74857223870608, 10.790683356112204, 10.019570299137198, 9.095420652715385, 8.153285859110968, 9.079792391995783, 9.802934472575837, 10.756194737096619, 11.681368195833661, 11.960645694035819, 12.90725423436635, 13.704280150099475, 14.700106587803338, 15.63949002310525, 16.713748651454768, 16.556014400782463, 15.541246652772026, 15.6852428414735, 14.655782826584819, 13.711663160501894, 12.72509404231949, 11.724426003404616, 11.083334280046065, 10.143839852058385, 9.205094911552818, 10.008756189272882, 10.763642834327209, 11.731584538155904, 11.790283434063996, 10.936625109505657, 11.926856294342166, 12.747046920809337, 13.697855467504443, 14.681367954361296, 15.692990030488348, 16.5789892586694, 16.557951385444383, 16.530157498171768, 15.602204386226127, 14.692007031346161, 13.702728016758043, 12.763995666652704, 12.038340553519966, 11.105677418988893, 10.194802611496284, 10.959520194902884, 11.785638514795163, 11.740063705560132, 10.735314395314711, 9.866941073355996, 10.87255082872926, 11.7863854890026, 12.735577754387249, 13.742569194622899, 14.669383023136241, 15.643636335561268, 16.671053700744768, 16.661538673901976, 16.57176796914848, 15.750732714916762, 14.736034910236219, 13.781417294493616, 13.036248335342338, 12.052939385811312, 11.237218485177886, 11.984717336214548, 11.701330101537902, 10.733303463309616, 9.807777133169987, 8.820699801645478, 9.863441924910775, 10.75524000197735, 11.767839858204866, 12.72043913278817, 13.70913951608285, 14.751820665172115, 15.721390020419681, 15.662196210787018, 16.64159100041407, 16.693364223653155, 15.725244723894301, 14.73423685658397, 13.96651464672997, 13.01786292313029, 12.190964647704623, 11.851431482395935, 10.858752938863157, 9.831298812696286, 8.911116829683026, 7.8845140756898555, 8.899298996396087, 9.819297121083785, 10.760201385997352, 11.74390889293602, 12.732596270020599, 13.773140888763333, 14.719710329297287, 14.68931425988578, 15.63083964073134, 16.588350806144994, 15.61499917421439, 14.726056824120924, 13.730010566197159, 12.767087433333124, 11.742592474042922, 10.78730258294431, 9.818624760150886, 8.859979761079728, 7.883148210596332, 6.8604206724152945, 7.928331576586393, 8.855131024238649, 9.834293432884962, 10.787804165087994, 11.792905200604364, 12.73681097989349, 13.742295047013078, 13.642690995437157, 14.63334015984333, 15.593699639712648, 14.684128859001564, 13.783348406116781, 12.851024604410311, 11.861775961258116, 10.862358065690923, 9.920958333740991, 8.897139382085054, 7.856563904529041, 6.953943065543962, 5.9231228198847665, 6.921020920450722, 7.919166034571509, 8.806957227546022, 9.786581540583189, 10.745538172816708, 11.747928757401942, 12.734377755563122, 12.642356325384064, 13.58817715448151, 14.635803271835513, 13.711462956094438, 12.779600964181412, 11.77622096684655, 10.921922304516388, 9.899011449714246, 8.926567598830527, 7.971127492455336, 6.902999269242364, 5.925106356352877, 4.964581883010943, 5.977002789744352, 6.94965711363928, 7.834020865098178, 8.787499431010731, 9.817393306695823, 10.77684826698385, 11.75207168124074, 11.676249677114784, 12.736902927342046, 13.764786892874419, 12.842074073853139, 11.798241780332251, 10.803006627237268, 9.891369922488582, 8.869553139711925, 7.864521399713193, 6.934099967491262, 5.887150370045596, 4.924417629676654, 4.03310011988139, 4.993314682505089, 5.910114644397611, 6.881155162435059, 7.832317523475508, 8.8880206345385, 9.849602959222983, 10.72625236856011, 10.765819662415458, 11.823933133192021, 12.827243288775044, 11.87538817618451, 10.850359157769999, 9.875874430060202, 8.938253806329378, 7.963222071145207, 7.037837345626651, 6.030272452698984, 4.958676194055041, 3.9652799708788966, 3.020269847826315, 3.9420882101967347, 4.930490439190095, 5.925685045929124, 6.944912029903154, 7.885764359346549, 8.830331275680908, 9.771019444832257, 9.893954372556207, 10.856453859578702, 11.817105824244617, 10.939245301590143, 9.990950119486126, 8.933558528798027, 8.003333986183263, 6.992622438366272, 6.050867032880772, 5.029799821546569, 4.076199526422889, 3.0514535738123456, 2.092295028879864, 2.9666715560717547, 3.98819524533696, 4.957142689075514, 5.946408028161754, 6.93716726106368, 7.892994292984816, 8.844181004110414], [8.933764817685853, 7.974789562412923, 6.9954525489757104, 6.004577407503129, 4.976342767872081, 4.0212289568252215, 2.993885143207244, 1.9952029435921899, 1.0555458063930894, 2.0799720841386944, 2.9688498455758743, 3.9592671999271314, 5.025330714038638, 6.0235247689900495, 6.940895437681899, 7.929373057802795, 8.886758536776387, 9.911131134004663, 10.91205726161352, 9.943942449645894, 8.193765454429629, 7.124308448235615, 6.104809385576652, 5.156272164372961, 4.096421770595128, 3.1071871440853176, 2.043758439587055, 1.0517626257934092, 0.0, 1.072386304383356, 2.0257819928132355, 2.9858240665183864, 4.044634006245407, 5.061061178662677, 6.013767442111244, 7.08227198817853, 8.09610129889196, 9.024423143556136, 10.079674067802653, 9.239545798689955, 8.886995921861018, 7.945840782038126, 6.989081190209536, 6.0229154700458825, 5.024075037238552, 4.077691141420297, 3.046488538922575, 2.032100180488484, 1.016437191706105, 2.0236919122370995, 3.04390518198937, 3.9746981707785403, 5.026968400349782, 6.022943234787476, 6.962060021704074, 7.900693057230198, 8.850551790434944, 9.90324738402914, 10.884274605116428, 9.932445275444595, 9.894344786179627, 8.95693072115933, 7.950805797487204, 7.022196777982554, 5.982937266433179, 4.957495307510472, 4.0090145300579, 3.0179059956556786, 2.0323556454973986, 3.009081036331863, 4.00953208202877, 4.963063036599188, 5.926966317695314, 6.889514758051064, 7.91996506416714, 8.911769325816577, 9.779585700937602, 10.714703776744312, 11.70828292990585, 10.91697450012578, 10.81992043760324, 9.895944643136978, 9.00375746358974, 7.974701634449616, 6.96519918819352, 6.013454000674474, 5.022476967640211, 4.0817735683583365, 3.0244817556217716, 3.96872622873574, 4.918366198123907, 5.902432737011738, 6.915302113852987, 7.861667958386256, 8.882003316157057, 9.910007339560249, 10.778681562691418, 11.70754491246862, 12.65414571176877, 11.873663257195215, 11.828022530999263, 10.813153943332974, 9.863916046897948, 8.938529129254109, 7.899699668220252, 6.872119881044965, 5.9349444272539005, 4.96641466605708, 3.9564351132569575, 4.8839689248866724, 5.830115816542145, 6.782517217799789, 7.77303618933795, 8.701995137673075, 9.679805507598205, 10.65904303029601, 11.586376031181, 12.64273723787784, 13.601827739226332, 12.77836559025994, 12.772053273794311, 11.811989279418947, 10.93773612781055, 9.93936447152041, 8.870471405871143, 7.842433323124083, 6.99715510346884, 5.9869060549219455, 4.976940389198619, 5.825722832808635, 6.85157990250962, 7.78068752558067, 8.762855366752236, 9.71566430614786, 10.632285431027244, 11.586464578283959, 12.54862967581606, 13.589700288926531, 14.598092582482924, 13.70779592002278, 13.783284647078903, 12.794271953339349, 11.877261232699055, 10.867383729733147, 9.89582725475054, 8.868584150061078, 7.973446550359719, 6.9682880388551105, 5.93986015408394, 6.767196869419293, 7.723797922778807, 8.712616931546284, 9.666521537698866, 10.719350013262355, 11.70564389914235, 12.640523763339733, 13.57011036344037, 14.509065687792393, 15.560119902949575, 14.644882149897326, 14.752703787715777, 13.695590475081003, 12.701889791921566, 11.77385220074354, 10.826587883249571, 9.887333889362123, 8.951052792131485, 7.923794602746769, 6.959223966727263, 7.805411369469374, 8.73584111449058, 9.73497976416428, 10.630407798934609, 11.569806403992342, 12.599117572899317, 13.58679479935844, 14.514512382054004, 15.580430998791426, 16.548534736594565, 15.612320753382408, 15.687492116607594, 14.682353041345403, 13.729334294029954, 12.748209217530759, 11.790320334936883, 10.815752934643305, 9.842609003419199, 8.900474209814782, 8.028029766202375, 8.751171846782428, 9.70443211130321, 10.629605570040253, 11.568565805119121, 12.503526900806659, 13.490513493039586, 14.48633993074345, 15.42572336604536, 16.49998199439488, 17.524675161237614, 16.593009278565436, 16.690092339233104, 15.655419805409498, 14.711300139326573, 13.72473102114417, 12.724062982229295, 11.879516915552172, 10.891028202762199, 9.922873015363423, 8.956993563479474, 9.7118802085338, 10.679821912362495, 11.094053197699896, 11.882180097235857, 12.872411282072367, 13.692601908539537, 14.643410455234642, 15.627723855957164, 16.63934593208422, 17.55534733648481, 17.609714011237795, 17.52979447699645, 16.601841365050806, 15.69164401017084, 14.702364995582721, 13.763632645477383, 12.785528904223781, 11.852865769692709, 10.91258071530689, 9.907757569109476, 10.733875889001755, 11.043833469196032, 10.039084158950612, 10.812496061086195, 11.818105816459461, 12.731940476732799, 13.681132742117448, 14.718927272438311, 15.645741100951653, 16.61999441337668, 17.64741177856018, 17.69231645552744, 17.571404947973157, 16.75036969374144, 15.735671889060898, 14.781054273318295, 13.783436686046153, 12.800127736515128, 11.901971426464424, 10.93295471042114, 10.929275568486258, 10.030148905411416, 9.111546896805887, 9.766254789375678, 10.808996912640975, 11.70079498970755, 12.744197936020278, 13.696797210603583, 14.685497593898262, 15.735216716847674, 16.70478607209524, 16.692973992412483, 17.54823522170097, 16.527652878410798, 15.559533378651945, 14.698160620335402, 13.74871728689443, 12.80006556329475, 11.862391167196419, 10.99082965339499, 9.998151109862212, 8.97069698369534, 8.130972437428547, 8.830069063420055, 9.844853984126287, 10.764852108813985, 11.765118588041084, 12.748826094979751, 13.73751347206433, 14.778058090807065, 15.724627531341019, 15.720092041511245, 16.60589265867918, 15.55943137765991, 14.563236548420981, 13.727334606260255, 12.73128834833649, 11.906485604332179, 10.881990645041977, 9.926700753943365, 8.95802293114994, 7.999377932078783, 7.103003818341853, 7.805975660145494, 8.873886564316592, 9.800686011968848, 10.839210634928694, 11.792721367131724, 12.797822402648094, 13.74172818193722, 14.773072828638544, 14.694453621230565, 15.685102785636738, 14.676424765013572, 13.632366233208156, 12.731585780323373, 11.799261978616903, 10.932721523316681, 9.933303627749488, 9.060356504740046, 8.03653755308411, 6.995962075528096, 6.119430409647936, 6.868677807614966, 7.866575908180922, 8.864721022301708, 9.811874429589752, 10.791498742626919, 11.750455374860438, 12.778706539027407, 13.765155537188587, 13.694118951177472, 14.639939780274918, 13.718528397136437, 12.65970033030103, 11.727838338388004, 10.724458341053142, 9.933915226580435, 8.969957011772811, 8.065965769829582, 7.110525663454391, 6.042397440241419, 5.075776737821851, 5.910136870741143, 6.922557777474552, 7.922591718078759, 8.838938067141907, 9.792416633054462, 10.822310508739553, 11.807626048609315, 12.782849462866205, 12.728012302908192, 13.765215938217572, 12.7373319726852, 11.79031144805973, 10.746479154538843, 9.75124400144386, 8.860058675044655, 7.907524031142035, 7.003919570712248, 6.073498138490317, 5.026548541044651, 4.063815800675709, 4.97865510761159, 5.939312342155625, 6.91043671567269, 7.886072364478788, 8.837234725519238, 9.892937836582231, 10.891848832585387, 11.778014994353518, 11.817582288208866, 12.829632240507651, 11.806244037878512, 10.823625550391101, 9.79859653197659, 8.824111804266794, 7.88649118053597, 6.911459445351799, 6.029397837054397, 5.050955853236093, 4.098074365054097, 3.104678141877952, 3.965824835556514, 4.942685507206789, 5.94851495524161, 6.967930919291528, 7.987157903265558, 8.928010232708953, 9.872577149043313, 10.822782070625665, 10.945716998349615, 11.82575490364387, 10.865102938977955, 9.887482675796734, 8.939187493692717, 7.881795903004619, 6.951571360389854, 5.940859812572864, 4.999104407087363, 3.9780371957531604, 3.1424402397548876, 2.117694287144344, 3.037850016610063, 3.967268853081808, 5.03530693530279, 6.008905314868922, 6.998170653955162, 7.988929886857088, 8.944756918778223, 9.895943629903822], [9.955654791338773, 8.996679536065843, 8.017342522628631, 7.026467381156049, 5.998232741525, 5.0431189304781405, 4.015775116860163, 3.0008910121325325, 2.061233874933432, 1.0368075971878268, 1.8964635411925181, 2.8868808955437757, 3.9529444096552826, 4.951138464606694, 5.868509133298543, 6.85698675341944, 7.814372232393031, 8.838744829621307, 9.839670957230163, 10.866408553580271, 9.266151758812985, 8.19669475261897, 7.177195689960008, 6.228658468756317, 5.168808074978483, 4.179573448468673, 3.116144743970411, 2.124148930176765, 1.072386304383356, 0.0, 0.9533956884298793, 1.9134377621350303, 2.972247701862051, 3.988674874279321, 4.9413811377278885, 6.009885683795174, 7.023714994508604, 7.9520368391727825, 9.0072877634193, 10.052413010572549, 9.959382226244374, 9.018227086421483, 8.061467494592891, 7.095301774429238, 6.096461341621907, 5.098605999413628, 4.067403396915906, 3.0455148874889617, 2.029851898706583, 1.0225971781755883, 1.9742413818943239, 2.9050343706834942, 3.9573046002547354, 4.95327943469243, 5.8896737173207185, 6.828306752846842, 7.778165486051588, 8.830861079645784, 9.846064049134208, 10.797893378806041, 10.924491915409758, 9.987077850389461, 8.964220504487681, 8.035611484983031, 6.996351973433656, 5.97091001451095, 5.022429237058378, 4.031320702656156, 3.0457703524978763, 2.081272897820403, 3.0333001946476985, 3.8933992365041417, 4.857302517600267, 5.819850957956017, 6.850301264072094, 7.839383021433221, 8.707199396554246, 9.642317472360956, 10.635896625522495, 11.644479309444575, 11.850067566833372, 10.926091772367112, 10.017172170590216, 8.988116341450093, 7.978613895193996, 7.026868707674952, 6.035891674640689, 5.095188275358815, 4.037896462622249, 3.1478115336650982, 4.0885159219797504, 4.8327689369166915, 5.845638313757941, 6.79200415829121, 7.812339516062011, 8.840343539465202, 9.70629525830806, 10.635158608085263, 11.581759407385414, 12.614698125390607, 12.858169660229395, 11.826568650333451, 10.877330753898425, 9.951943836254586, 8.91311437522073, 7.8855345880454415, 6.948359134254377, 5.979829373057557, 4.969849820257434, 4.1967529215930135, 5.060480814565183, 5.793698560770274, 6.784217532308435, 7.7131764806435585, 8.690986850568688, 9.670224373266493, 10.597557374151483, 11.633583594492876, 12.529441434842976, 13.492184714263544, 13.802200403024443, 12.825403986419424, 11.951150834811028, 10.952779178520887, 9.88388611287162, 8.85584803012456, 8.010569810469317, 7.000320761922422, 5.990355096199096, 5.138506829514976, 6.081944900532658, 6.817584167716788, 7.799752008888353, 8.726845649118342, 9.643466773997726, 10.597645921254443, 11.559811018786542, 12.600881631897014, 13.548996860539368, 14.421615044026385, 14.808145659756361, 13.807686660339826, 12.890675939699532, 11.880798436733624, 10.909241961751016, 9.881998857061557, 8.986861257360196, 7.981702745855587, 6.953274861084417, 6.079980866125634, 7.036581919485149, 7.749513573682402, 8.703418179834985, 9.730531356232838, 10.716825242112833, 11.651705106310217, 12.581291706410855, 13.520247030762878, 14.57130124592006, 15.35870127390093, 15.772189979391218, 14.70900518208148, 13.715304498922043, 12.787266907744018, 11.840002590250048, 10.9007485963626, 9.964467499131962, 8.937209309747246, 7.97263867372774, 7.118195366175715, 8.048625111196921, 8.771876406300397, 9.667304441070728, 10.60670304612846, 11.636014215035436, 12.62369144149456, 13.551409024190123, 14.59161234176191, 15.55971607956505, 16.326139877386012, 16.700906823608072, 15.69576774834588, 14.742749001030429, 13.761623924531236, 12.80373504193736, 11.829167641643782, 10.856023710419676, 9.913888916815258, 8.99461077890825, 8.063955843488769, 9.017216108009553, 9.761386159676029, 10.653011684426694, 11.540423542942778, 12.527410135175705, 13.523236572879568, 14.46262000818148, 15.536878636531, 16.561571803373734, 17.306828402569042, 17.70350704623358, 16.668834512409973, 15.724714846327048, 14.738145728144644, 13.737477689229772, 12.892931622552648, 11.880996828756862, 10.889454028069299, 9.923574576185349, 9.024664205240141, 9.992605909068837, 10.819759860681536, 11.677032268956857, 12.612080867009821, 13.484643364465843, 14.435451911160948, 15.41976531188347, 16.431387388010524, 17.396332235864513, 18.3235331352414, 18.54320918399692, 17.61525607205128, 16.705058717171315, 15.715779702583196, 14.777047352477858, 13.757270650315743, 12.82460751578467, 11.879161728012765, 10.874338581815351, 10.046659885708095, 10.194267639969091, 10.99786378118735, 11.818184129626538, 12.823793884999802, 13.737628545273141, 14.68682081065779, 15.724615340978653, 16.651429169491998, 17.625682481917025, 18.653099847100524, 18.422081043795348, 17.416116486891465, 16.49594204311849, 15.476356887926672, 14.5785938780424, 13.63384838196982, 12.7040783235463, 11.75522655265573, 11.063737498725596, 10.04392685197784, 9.144800188902996, 10.070326519042625, 10.77194285791602, 11.814684981181317, 12.706483058247892, 13.74988600456062, 14.702485279143925, 15.691185662438604, 16.740904785388015, 17.71047414063558, 17.447913686042625, 16.475848917317617, 15.455266574027442, 14.48714707426859, 13.625774315952047, 12.687806509827002, 11.739154786227322, 10.801480390128992, 10.10548093688657, 9.112802393353792, 8.085348267186921, 9.128789632777538, 9.835757131960397, 10.85054205266663, 11.770540177354327, 12.770806656581424, 13.754514163520092, 14.743201540604671, 15.783746159347405, 16.73031559988136, 16.475031735141386, 15.533506354295824, 14.487045073276555, 13.490850244037626, 12.6549483018769, 11.658902043953134, 10.834399139000233, 9.82107986797455, 9.041352037434946, 8.072674214641522, 7.114029215570364, 8.108691886882195, 8.811663728685836, 9.879574632856935, 10.80637408050919, 11.844898703469035, 12.798409435672067, 13.803510471188437, 14.747416250477562, 15.778760897178884, 15.570204467335538, 14.656515107567065, 13.604038460630216, 12.5599799288248, 11.659199475940017, 10.726875674233547, 9.860335218933326, 8.860917323366133, 8.00137815415254, 7.079921389370885, 6.110613359019677, 7.125118478188279, 7.874365876155308, 8.872263976721264, 9.87040909084205, 10.817562498130094, 11.797186811167261, 12.75614344340078, 13.784394607567748, 14.770843605728928, 14.569869797282445, 13.624048968184999, 12.646142092753081, 11.587314025917674, 10.655452034004648, 9.652072036669786, 8.861528922197081, 7.897570707389455, 7.006987419242076, 6.080847653407735, 5.1570487237329985, 6.081464806362193, 6.915824939281485, 7.928245846014894, 8.9282797866191, 9.84462613568225, 10.798104701594802, 11.827998577279894, 12.813314117149655, 13.788537531406545, 13.74949365424106, 12.692829633834217, 11.664945668301844, 10.717925143676375, 9.674092850155487, 8.678857697060504, 7.7876723706613005, 6.8351377267586795, 5.9449412201247425, 5.014519787902811, 4.141199824536231, 5.069503869216051, 5.984343176151932, 6.945000410695967, 7.916124784213032, 8.89176043301913, 9.842922794059579, 10.898625905122572, 11.89753690112573, 12.799496345686386, 12.776280482888906, 11.757245936124297, 10.733857733495158, 9.751239246007747, 8.726210227593237, 7.751725499883439, 6.814104876152614, 5.839073140968443, 4.957011532671041, 3.978569548852737, 3.126455115802668, 4.110366210418294, 4.971512904096857, 5.948373575747131, 6.954203023781952, 7.973618987831871, 8.9928459718059, 9.933698301249295, 10.878265217583655, 11.844263421958534, 11.765053584995691, 10.753368599260515, 9.7927166345946, 8.815096371413379, 7.866801189309361, 6.809409598621263, 5.879185056006499, 4.868473508189508, 3.9267181027040072, 2.9056508913698043, 2.10697174255513, 3.1233823556846865, 4.043538085150406, 4.972956921622151, 6.040995003843133, 7.030795288521841, 8.02006062760808, 9.010819860510008, 9.966646892431143, 10.917833603556742], [10.909050479768652, 9.950075224495722, 8.97073821105851, 7.979863069585928, 6.951628429954879, 5.996514618908019, 4.969170805290042, 3.9542867005624114, 3.014629563363311, 1.990203285617706, 0.9430678527626387, 1.933485207113896, 2.999548721225403, 3.9977427761768145, 4.9151134448686635, 5.903591064989559, 6.86097654396315, 7.885349141191426, 8.886275268800283, 9.913012865150389, 10.144797666402994, 9.150090441048851, 8.130591378389887, 7.1820541571861956, 6.122203763408363, 5.132969136898553, 4.069540432400291, 3.0775446186066446, 2.0257819928132355, 0.9533956884298793, 0.0, 0.9600420737051509, 2.0188520134321717, 3.0352791858494417, 3.9879854492980087, 5.056489995365293, 6.070319306078724, 6.998641150742902, 8.053892074989419, 9.099017322142668, 10.889947043959737, 9.971622774851362, 9.01486318302277, 8.048697462859117, 7.049857030051787, 6.052001687843507, 5.020799085345785, 3.998910575918841, 2.983247587136462, 1.9759928666054676, 1.0208456934644445, 1.951638682253615, 3.0039089118248565, 3.999883746262551, 4.936278028890839, 5.874911064416962, 6.824769797621708, 7.877465391215903, 8.892668360704327, 9.84449769037616, 11.71371333496085, 10.940473538819342, 9.917616192917562, 8.989007173412912, 7.949747661863537, 6.9243057029408295, 5.975824925488258, 4.984716391086036, 3.999166040927756, 3.034668586250283, 2.079904506217819, 2.9400035480742623, 3.903906829170388, 4.8664552695261385, 5.896905575642215, 6.885987333003342, 7.753803708124368, 8.688921783931077, 9.682500937092616, 10.691083621014696, 12.639288986384464, 11.879487460796991, 10.970567859020097, 9.941512029879974, 8.932009583623877, 7.980264396104832, 6.989287363070568, 6.048583963788694, 4.991292151052129, 4.084760202938039, 3.1351202335498716, 3.879373248486812, 4.892242625328062, 5.838608469861331, 6.858943827632132, 7.886947851035323, 8.752899569878181, 9.681762919655384, 10.628363718955535, 11.661302436960728, 13.489132085094342, 12.77996433876333, 11.830726442328304, 10.905339524684464, 9.866510063650608, 8.83893027647532, 7.901754822684257, 6.933225061487437, 5.923245508687314, 5.053232017790778, 4.1070851261353045, 4.840302872340394, 5.830821843878555, 6.759780792213679, 7.737591162138809, 8.716828684836614, 9.644161685721604, 10.680187906062997, 11.576045746413097, 12.538789025833665, 14.43316282788939, 13.778799674849303, 12.904546523240906, 11.906174866950765, 10.837281801301499, 9.80924371855444, 8.963965498899197, 7.953716450352301, 6.943750784628975, 5.994985925712741, 5.128549212102779, 5.8641884792869075, 6.846356320458472, 7.773449960688462, 8.690071085567848, 9.644250232824565, 10.606415330356663, 11.647485943467135, 12.59560117210949, 13.468219355596506, 15.433269145778286, 14.761082348769705, 13.844071628129411, 12.834194125163503, 11.862637650180895, 10.835394545491436, 9.940256945790077, 8.935098434285466, 7.901460846548711, 6.936459962323399, 6.089854917076898, 6.796117885252522, 7.750022491405105, 8.777135667802959, 9.763429553682954, 10.698309417880338, 11.627896017980976, 12.566851342332999, 13.61790555749018, 14.405305585471051, 16.40268828641516, 15.662400870511359, 14.668700187351922, 13.740662596173896, 12.793398278679927, 11.842733715332418, 10.90645261810178, 9.879194428717064, 8.914623792697558, 7.974674462373479, 7.10189810878867, 7.818480717870516, 8.713908752640847, 9.65330735769858, 10.682618526605555, 11.670295753064678, 12.598013335760243, 13.638216653332032, 14.60632039113517, 15.372744188956133, 17.340767989175387, 16.64916343677576, 15.696144689460308, 14.715019612961115, 13.757130730367239, 12.7711527606136, 11.798008829389493, 10.855874035785076, 9.851089875106016, 8.920434939686533, 8.070489105601302, 8.807990471246148, 9.699615995996814, 10.587027854512897, 11.574014446745824, 12.569840884449688, 13.509224319751599, 14.583482948101118, 15.60817611494385, 16.353432714139164, 18.3125222477993, 17.622230200839855, 16.67811053475693, 15.691541416574523, 14.690873377659651, 13.805935956670346, 12.737475924954628, 11.745933124267065, 10.780053672383115, 9.881143301437906, 9.045878906660587, 9.866364172251656, 10.723636580526975, 11.65868517857994, 12.531247676035962, 13.482056222731067, 14.46636962345359, 15.477991699580642, 16.44293654743463, 17.370137446811523, 18.360237493329578, 17.432284381383937, 16.594887850493166, 15.55626809297497, 14.642619817453433, 13.630607736469912, 12.69794460193884, 11.844246737907453, 11.052390869709212, 10.127269539457206, 9.997228464958114, 10.92133321100094, 11.793320616676636, 12.712990644192846, 13.4919091078427, 14.44110137322735, 15.405168383191986, 16.33198221170533, 17.306235524130358, 18.300424694605024, 17.46868535536547, 16.462720798461586, 15.54254635468861, 14.522961199496793, 13.62519818961252, 12.68045269353994, 11.750682635116421, 10.80183086422585, 10.144732298402504, 9.124921651654748, 10.061650799153066, 10.987177129292695, 11.725338546345899, 12.768080669611196, 13.659878746677771, 14.7032816929905, 15.655880967573804, 16.64458135086848, 17.694300473817894, 18.511596790867067, 16.494517997612743, 15.522453228887738, 14.501870885597564, 13.53375138583871, 12.672378627522168, 11.734410821397123, 10.785759097797444, 9.848084701699113, 9.164488227934132, 8.193797193030703, 9.00219887743699, 10.045640243027607, 10.789152820390276, 11.803937741096508, 12.723935865784206, 13.724202345011303, 14.707909851949971, 15.69659722903455, 16.737141847777284, 17.471994447109456, 15.521636046711505, 14.580110665865945, 13.533649384846676, 12.537454555607747, 11.70155261344702, 10.705506355523255, 9.881003450570354, 8.867684179544671, 8.100359328482508, 7.131681505689084, 8.030879825820433, 9.033877836613254, 9.765059417115715, 10.832970321286814, 11.75976976893907, 12.798294391898914, 13.751805124101946, 14.756906159618316, 15.70081193890744, 16.468655259584207, 14.616808778905659, 13.703119419137186, 12.650642772200337, 11.606584240394922, 10.705803787510138, 9.773479985803668, 8.906939530503447, 7.907521634936253, 7.047982465722662, 6.126525700941007, 7.027463969269746, 8.050304427919336, 8.827761564585186, 9.825659665151143, 10.82380477927193, 11.770958186559973, 12.75058249959714, 13.70953913183066, 14.737790295997627, 15.662652475481515, 13.616474108852566, 12.67065327975512, 11.692746404323202, 10.633918337487795, 9.70205634557477, 8.698676348239907, 7.9081332337672015, 6.944175018959575, 6.053591730812197, 5.1274519649778565, 6.073899333983068, 7.00665075609325, 7.869220627711364, 8.881641534444773, 9.88167547504898, 10.798021824112128, 11.751500390024681, 12.781394265709773, 13.766709805579534, 14.638172330762435, 12.8000871956316, 11.739433945404338, 10.711549979871965, 9.764529455246496, 8.720697161725608, 7.725462008630625, 6.834276682231422, 5.881742038328799, 4.991545531694864, 4.0611240994729325, 5.0580504347863, 5.994689818947108, 6.937738864581811, 7.898396099125846, 8.869520472642911, 9.845156121449008, 10.796318482489458, 11.85202159355245, 12.850932589555608, 13.750084504186274, 11.822884794459025, 10.803850247694417, 9.780462045065278, 8.797843557577867, 7.772814539163356, 6.798329811453559, 5.860709187722735, 4.8856774525385624, 4.0036158442411605, 3.0251738604228575, 4.043305726052737, 5.035552160149351, 5.9249085925267355, 6.90176926417701, 7.907598712211831, 8.92701467626175, 9.94624166023578, 10.887093989679174, 11.831660906013534, 12.797343317335272, 10.81165789656581, 9.799972910830634, 8.839320946164719, 7.861700682983497, 6.91340550087948, 5.8560139101913835, 4.92578936757662, 3.915077819759628, 2.9733224142741275, 1.952255202939925, 3.0238223528051993, 4.048568305415743, 4.996933773580285, 5.92635261005203, 6.9943906922730115, 7.98419097695172, 8.973456316037959, 9.964215548939887, 10.920042580861022, 11.87050487661343], [9.96314842340528, 10.910117298200872, 9.93078028476366, 8.939905143291078, 7.91167050366003, 6.95655669261317, 5.929212878995193, 4.914328774267562, 3.974671637068462, 2.950245359322857, 1.9031099264677898, 1.0622797888130622, 2.095884063837423, 3.0377007024716636, 3.9550713711635126, 4.943548991284409, 5.900934470258, 6.925307067486276, 7.926233195095133, 8.952970791445239, 9.184755592697844, 10.110132514754003, 9.09063345209504, 8.142096230891347, 7.082245837113514, 6.093011210603704, 5.0295825061054416, 4.037586692311796, 2.9858240665183864, 1.9134377621350303, 0.9600420737051509, 0.0, 1.0588099397270208, 2.0752371121442907, 3.0279433755928578, 4.096447921660143, 5.110277232373574, 6.038599077037752, 7.093850001284268, 8.138975248437518, 9.929904970254587, 10.871060110077478, 9.974905256727922, 9.008739536564269, 8.009899103756938, 7.012043761548658, 5.980841159050936, 4.958952649623992, 3.943289660841613, 2.9360349403106185, 1.9305782987290294, 0.9997853099398591, 2.0520555395111004, 3.0480303739487953, 3.9762359551856874, 4.9148689907118115, 5.864727723916557, 6.917423317510752, 7.932626286999176, 8.88445561667101, 10.753671261255699, 11.691085326275996, 10.877658266622712, 9.949049247118062, 8.909789735568687, 7.88434777664598, 6.935866999193409, 5.944758464791187, 4.959208114632907, 3.9900881571793105, 2.989637111482404, 1.9881501757605067, 2.9520534568566323, 3.914601897212383, 4.9450522033284585, 5.9259452592981905, 6.793761634419216, 7.728879710225925, 8.722458863387464, 9.731041547309545, 11.679246912679313, 12.628208532542837, 11.930609932725247, 10.901554103585124, 9.892051657329027, 8.940306469809983, 7.900234239666868, 6.959530840384994, 5.8885236430065735, 4.944279169892606, 3.9946392005044387, 2.9275198761730565, 3.9403892530143056, 4.886755097547574, 5.907090455318375, 6.935094478721567, 7.79285749617303, 8.721720845950232, 9.668321645250384, 10.701260363255576, 12.52909001138919, 13.571250434645487, 12.62201253821046, 11.696625620566621, 10.657796159532765, 9.630216372357477, 8.693040918566414, 7.7245111573695935, 6.714531604569471, 5.786997792939756, 4.840850901284282, 3.8884495000266384, 4.878968471564799, 5.807927419899923, 6.7857377898250535, 7.764975312522859, 8.69230831340785, 9.720145832357845, 10.616003672707945, 11.578746952128514, 13.473120754184238, 14.487292803140058, 13.695832619123063, 12.697460962832922, 11.628567897183656, 10.600529814436596, 9.755251594781354, 8.712006357723077, 7.702040691999751, 6.728751700861719, 5.841442730044203, 4.912335106973153, 5.8945029481447175, 6.821596588374707, 7.738217713254092, 8.692396860510808, 9.654561958042908, 10.69563257115338, 11.635559098404336, 12.508177281891355, 14.473227072073135, 15.46957547706046, 14.635357724011568, 13.62548022104566, 12.653923746063052, 11.626680641373593, 10.731543041672234, 9.693388341656242, 8.63522662169769, 7.670225737472377, 6.802748435018321, 5.844264512938767, 6.79816911909135, 7.8252822954892025, 8.8115761813692, 9.746456045566582, 10.67604264566722, 11.614997970019243, 12.666052185176424, 13.4452635117659, 15.44264621271001, 16.45004661480764, 15.456345931648205, 14.52830834047018, 13.58104402297621, 12.576499490481394, 11.640218393250755, 10.61296020386604, 9.648389567846534, 8.708440237522456, 7.814791626730093, 6.866627345556761, 7.7620553803270935, 8.701453985384827, 9.730765154291802, 10.718442380750925, 11.64615996344649, 12.686363281018275, 13.654467018821414, 14.412702115250982, 16.380725915470236, 17.38586499073243, 16.45481238236987, 15.473687305870676, 14.5157984232768, 13.504918535762576, 12.53177460453847, 11.589639810934052, 10.584855650254994, 9.654200714835511, 8.781310557669435, 7.856137098932393, 8.747762623683059, 9.635174482199144, 10.622161074432071, 11.617987512135935, 12.557370947437846, 13.631629575787365, 14.656322742630097, 15.39339064043401, 17.352480174094147, 17.418663867320095, 16.61518964763228, 15.57385999370837, 14.689063863353146, 13.715435993717023, 12.788576750568517, 11.962749019550085, 11.328889356717177, 10.614909076586883, 9.75670035872872, 8.9145107999379, 9.771783208213222, 10.706831806266187, 11.579394303722209, 12.530202850417314, 13.514516251139836, 14.526138327266889, 15.491083175120876, 16.41009537310637, 17.40019541962443, 16.472242307678787, 15.634845776788016, 14.596226019269817, 13.682577743748283, 12.759402318169078, 11.826739183638006, 10.973041319606619, 10.378125351087174, 11.087311613162356, 10.708049917026248, 9.969479838687185, 10.841467244362883, 11.761137271879093, 12.540055735528947, 13.489248000913596, 14.453315010878233, 15.380128839391576, 16.3543821518166, 17.34038262089987, 16.50864328166032, 15.502678724756436, 14.582504280983459, 13.562919125791641, 12.66515611590737, 11.744257773389746, 10.879477216815587, 9.930625445925017, 9.35292820977551, 10.084963725359898, 11.021692872858216, 10.89701710083191, 11.884094432356418, 12.826850617500316, 13.571201222554196, 14.560328829458323, 15.475445072712962, 16.38573157462168, 17.34071456193828, 17.551554717161917, 15.534475923907591, 14.562411155182586, 13.541828811892412, 12.573709312133559, 11.712336553817018, 10.798215901246929, 9.91455367949661, 8.97687928339828, 8.365956499808341, 9.153839266735853, 9.96224095114214, 11.005682316732758, 11.749194894095426, 12.763979814801658, 13.683977939489356, 14.684244418716453, 15.667951925655121, 16.656639302739702, 17.458521813938262, 16.511952373404306, 14.561593973006353, 13.620068592160793, 12.573607311141524, 11.577412481902595, 10.74151053974187, 9.745464281818105, 8.926865816310045, 7.996478761243837, 7.301827600356717, 8.091723579394234, 8.990921899525583, 9.993919910318404, 10.725101490820865, 11.793012394991964, 12.71981184264422, 13.758336465604064, 14.711847197807096, 15.716948233323466, 16.545773839652625, 15.508613185879055, 13.656766705200507, 12.743077345432035, 11.690600698495185, 10.64654216668977, 9.745761713804987, 8.813437912098518, 7.9528018962431375, 7.036316216635419, 6.241782784948748, 7.0865677746461575, 7.987506042974896, 9.010346501624486, 9.787803638290336, 10.785701738856293, 11.78384685297708, 12.731000260265123, 13.71062457330229, 14.66958120553581, 15.624434161732266, 14.702610401776363, 12.656432035147414, 11.710611206049968, 10.73270433061805, 9.673876263782644, 8.742014271869618, 7.738634274534756, 6.948091160062051, 6.072969600658741, 5.247392050038283, 6.087494038683007, 7.033941407688219, 7.966692829798401, 8.829262701416514, 9.841683608149923, 10.84171754875413, 11.758063897817278, 12.711542463729831, 13.741436339414923, 14.653353671314173, 13.678130257057283, 11.840045121926448, 10.779391871699186, 9.751507906166813, 8.804487381541344, 7.7606550880204574, 6.765419934925474, 5.8742346085262716, 5.010536620027965, 4.18534585092095, 5.0211661731780834, 6.018092508491451, 6.9547318926522586, 7.897780938286962, 8.858438172830997, 9.829562546348061, 10.805198195154158, 11.756360556194608, 12.8120636672576, 13.735995778336756, 12.790042430481122, 10.862842720753875, 9.843808173989267, 8.820419971360128, 7.837801483872717, 6.812772465458205, 5.838287737748408, 4.900667114017585, 4.014472034237729, 3.132410425940327, 3.9852159341280085, 5.003347799757888, 5.995594233854502, 6.8849506662318865, 7.861811337882161, 8.867640785916981, 9.8870567499669, 10.90628373394093, 11.847136063384324, 12.791702979718684, 11.837301243630122, 9.85161582286066, 8.839930837125484, 7.879278872459569, 6.901658609278347, 5.95336342717433, 4.895971836486233, 3.965747293871469, 3.043872401458794, 2.1021169959732937, 2.912297276645076, 3.98386442651035, 5.008610379120894, 5.9569758472854355, 6.886394683757181, 7.954432765978162, 8.944233050656871, 9.93349838974311, 10.924257622645037, 11.880084654566172, 10.91046280290828], [8.90433848367826, 9.86331373895119, 10.842650752388401, 9.9987150830181, 8.970480443387052, 8.015366632340193, 6.988022818722214, 5.973138713994584, 5.0334815767954835, 4.009055299049878, 2.9619198661948105, 2.1031376382219094, 1.0370741241104025, 1.9788907627446428, 2.896261431436492, 3.884739051557388, 4.842124530530979, 5.866497127759255, 6.867423255368111, 7.894160851718218, 8.125945652970822, 9.195402659164836, 10.149443391822059, 9.200906170618367, 8.141055776840535, 7.151821150330725, 6.088392445832462, 5.096396632038816, 4.044634006245407, 2.972247701862051, 2.0188520134321717, 1.0588099397270208, 0.0, 1.01642717241727, 1.9691334358658372, 3.0376379819331225, 4.051467292646553, 4.979789137310731, 6.035040061557247, 7.080165308710496, 8.871095030527565, 9.812250170350456, 10.769009762179046, 10.06754947629129, 9.06870904348396, 8.07085370127568, 7.0396510987779575, 6.017762589351014, 5.002099600568634, 3.9948448800376393, 2.9893882384560504, 2.05859524966688, 1.0152156256755327, 2.0111904601132276, 2.917426015458667, 3.8560590509847907, 4.805917784189536, 5.8586133777837315, 6.873816347272156, 7.8256456769439895, 9.694861321528679, 10.632275386548976, 11.655132732450756, 10.973834695740694, 9.934575184191319, 8.909133225268612, 7.96065244781604, 6.969543913413818, 5.983993563255538, 5.007268172421074, 4.006817126724167, 2.9386417966996667, 1.974738515603541, 2.9372869559592916, 3.9373319714002606, 4.867135319571171, 5.734951694692196, 6.670069770498905, 7.663648923660444, 8.672231607582525, 10.620436972952293, 11.569398592815817, 12.59770364884546, 11.926339552207756, 10.91683710595166, 9.89602335763014, 8.850725860606028, 7.910022461324154, 6.839015263945734, 5.894770790831766, 4.945130821443598, 3.8780114971122166, 2.9630743117612144, 3.9094401562944836, 4.916161217629843, 5.928280181676958, 6.7340475564460105, 7.662910906223212, 8.609511705523364, 9.642450423528556, 11.47028007166217, 12.532019762141326, 13.481257658576352, 12.647117241505782, 11.608287780471926, 10.580707993296638, 9.643532539505575, 8.675002778308754, 7.66502322550863, 6.737489413878915, 5.791342522223442, 4.838941120965798, 3.9898472804843754, 4.918806228819499, 5.842022832647325, 6.821260355345131, 7.748593356230122, 8.661335892630825, 9.557193732980926, 10.519937012401494, 12.414310814457219, 13.428482863413038, 14.389665340005156, 13.647952583772083, 12.579059518122817, 11.551021435375757, 10.705743215720515, 9.662497978662238, 8.652532312938911, 7.679243321800878, 6.791934350983362, 5.862826727912312, 5.055551051438934, 5.932475397294283, 6.794502756076364, 7.74868190333308, 8.710847000865181, 9.63719783003072, 10.576749158677316, 11.449367342164335, 13.414417132346115, 14.41076553733344, 15.371976417156592, 14.57597184198482, 13.604415367002213, 12.577172262312754, 11.682034662611395, 10.643879962595403, 9.58571824263685, 8.620717358411536, 7.75324005595748, 6.794756133877926, 6.0887120221517765, 6.936161104408779, 7.86786122419147, 8.802741088388853, 9.732327688489491, 10.671283012841513, 11.627310858114802, 12.38645357203888, 14.38383627298299, 15.431362331781337, 16.406837552587366, 15.47879996140934, 14.53153564391537, 13.526991111420555, 12.590710014189916, 11.5634518248052, 10.598881188785695, 9.658931858461617, 8.765283247669252, 7.81711896649592, 7.05259828338752, 7.9642292570743365, 8.793735029275796, 9.781412255734919, 10.709129838430483, 11.742648323840546, 12.615725691759792, 13.353892175523962, 15.321915975743215, 16.327055051005406, 16.507206250126035, 15.526081173626842, 14.568192291032966, 13.724585755013297, 12.782381730298924, 11.959943852379343, 11.535347271194155, 10.604692335774672, 9.731802178608595, 8.806628719871552, 8.038305526743486, 8.897949753888653, 9.788466933401118, 10.743529960199327, 11.682913395501238, 12.73693623501561, 13.65262243556398, 14.33458070070699, 16.293670234367127, 16.359853927593075, 15.55637970790526, 14.515050053981348, 13.634449643740554, 12.66082177410443, 11.733962530955925, 10.908134799937493, 11.820989089297377, 11.565400697526044, 10.70719197966788, 9.86500242087706, 9.062326111273649, 9.969607077955697, 10.745700162691255, 11.696508709386361, 12.646962988729252, 13.658585064856304, 14.623529912710291, 15.35128543337935, 16.34138547989741, 15.413432367951767, 14.576035837060992, 13.537416079542796, 12.623767804021261, 11.704788098556486, 10.772124964025414, 9.918427099994027, 10.870225083667375, 11.79534641391938, 11.658541537965407, 10.919971459626344, 10.13201014742331, 11.023912543568603, 11.706361594497993, 12.655553859882643, 13.585761748467649, 14.512575576980991, 15.486828889406018, 16.28157268117285, 15.449833341933298, 14.443868785029414, 13.523694341256437, 12.50410918606462, 11.606346176180349, 10.685447833662725, 9.824862997202995, 8.876011226312425, 9.84502794235571, 10.859072401488948, 11.827099039717233, 11.847508721771069, 11.178251419133828, 12.089625889189826, 12.737507081523242, 13.72663468842737, 14.607891810302377, 15.518178312211093, 16.473161299527696, 16.492744777434893, 14.47566598418057, 13.503601215455564, 12.48301887216539, 11.514899372406537, 10.653526614089996, 9.739405961519907, 8.859939459884018, 7.922265063785687, 8.96128333218148, 9.9279479428649, 10.795796306210997, 11.839237671801614, 12.11443714508945, 13.129222065795682, 13.673449962416807, 14.69771490647612, 15.662147759759828, 16.569075114463296, 16.39971187421124, 15.453142433677282, 13.502784033279331, 12.561258652433771, 11.514797371414502, 10.518602542175573, 9.682700600014849, 8.686654342091083, 7.868055876583024, 6.9418645416312454, 7.897154432729857, 8.865832255523282, 9.82447725459444, 10.876083846800107, 11.76938211034307, 12.837293014514168, 13.764092462166424, 14.817146405331087, 15.770657137534117, 16.430869679214727, 15.486963899925604, 14.449803246152033, 12.597956765473487, 11.684267405705013, 10.631790758768163, 9.587732226962748, 8.686951774077965, 7.754627972371496, 6.893991956516116, 5.981701997022828, 6.985189966840334, 7.9567771741041105, 8.907738704565148, 9.956139612282458, 10.832084257812543, 11.8299823583785, 12.828127472499286, 13.789810199992145, 14.769434513029312, 15.59903503678737, 14.565624222005246, 13.643800462049343, 11.597622095420395, 10.651801266322948, 9.673894390891029, 8.615066324055622, 7.683204332142597, 6.679824334807735, 5.88928122033503, 5.01835538104615, 5.990799231929869, 6.95770343814096, 7.95417406927847, 8.913018847596787, 9.87354332093872, 10.88596422767213, 11.885998168276336, 12.8168738375443, 13.770352403456853, 14.579859271456915, 13.594543731587153, 12.619320317330263, 10.781235182199428, 9.720581931972166, 8.692697966439793, 7.745677441814324, 6.701845148293437, 5.706609995198454, 4.81542466879925, 3.9559224004153735, 4.960954140414105, 5.891375572636036, 6.938325170081702, 7.901057910450644, 8.956590878013984, 9.917248112558019, 10.888372486075083, 11.86400813488118, 12.81517049592163, 13.72576970071967, 12.677185838609736, 11.731232490754103, 9.804032781026853, 8.784998234262245, 7.761610031633107, 6.778991544145695, 5.753962525731184, 4.779477798021388, 3.841857174290564, 2.9598578146251375, 3.961307017298737, 4.9688719102264045, 6.040468168870348, 7.0338643920464925, 7.943760605958908, 8.920621277609182, 9.926450725644003, 10.945866689693922, 11.965093673667951, 12.689056424612339, 11.74448950827798, 10.7784913039031, 8.792805883133639, 7.781120897398463, 6.820468932732547, 5.842848669551326, 4.894553487447309, 3.837161896759212, 2.906937354144448, 1.989258181846203, 2.9310135873317034, 3.9711072163720966, 5.042674366237371, 6.0674203188479146, 7.015785787012457, 7.945204623484202, 9.013242705705185, 10.003042990383893, 10.992308329470132, 11.836128090269778, 10.83328109531649, 9.851652863181258], [7.887911311260988, 8.846886566533918, 9.82622357997113, 10.81709872144371, 9.986907615804322, 9.031793804757463, 8.004449991139484, 6.989565886411854, 6.0499087492127535, 5.025482471467148, 3.9783470386120805, 3.036919537374689, 1.970856023263182, 0.9624635903273727, 1.8798342590192219, 2.868311879140118, 3.8256973581137093, 4.850069955341985, 5.850996082950841, 6.877733679300948, 7.109518480553552, 8.178975486747566, 9.19847454940653, 10.147011770610222, 9.157482949257805, 8.168248322747994, 7.104819618249732, 6.112823804456086, 5.061061178662677, 3.988674874279321, 3.0352791858494417, 2.0752371121442907, 1.01642717241727, 0.0, 0.9527062634485672, 2.0212108095158525, 3.035040120229283, 3.963361964893461, 5.018612889139977, 6.063738136293226, 7.854667858110295, 8.795822997933186, 9.752582589761776, 10.718748309925429, 10.08513621590123, 9.08728087369295, 8.056078271195227, 7.034189761768284, 6.018526772985904, 5.01127205245491, 4.00581541087332, 3.07502242208415, 2.0316427980928027, 1.0558759216478857, 1.900998843041397, 2.8396318785675208, 3.7894906117722664, 4.8421862053664615, 5.857389174854886, 6.8092185045267195, 8.678434149111409, 9.615848214131706, 10.638705560033486, 11.567314579538136, 10.951002356608589, 9.925560397685881, 8.97707962023331, 7.985971085831088, 7.000420735672808, 6.023695344838344, 5.023244299141437, 3.9550689691169367, 2.991165688020811, 2.043612220864642, 2.9209047989829906, 3.8507081471539, 4.718524522274926, 5.653642598081635, 6.647221751243174, 7.655804435165255, 9.604009800535023, 10.552971420398547, 11.58127647642819, 12.610332305568313, 11.93326427836893, 10.91245053004741, 9.867153033023298, 8.926449633741424, 7.855442436363004, 6.911197963249037, 5.961557993860869, 4.894438669529487, 3.9795014841784844, 3.015765421199834, 3.8997340452125733, 4.911853009259688, 5.7176203840287405, 6.646483733805942, 7.593084533106094, 8.626023251111286, 10.4538528992449, 11.515592589724056, 12.464830486159082, 13.390217403802922, 12.624714952889196, 11.59713516571391, 10.659959711922847, 9.691429950726025, 8.681450397925902, 7.753916586296187, 6.807769694640713, 5.855368293383069, 4.962863884783137, 4.033904936448013, 4.825595660230055, 5.804833182927861, 6.732166183812852, 7.6449087202135555, 8.540766560563656, 9.503509839984224, 11.397883642039949, 12.412055690995768, 13.373238167587886, 14.380232645495461, 13.595486690540087, 12.567448607793029, 11.722170388137787, 10.678925151079508, 9.668959485356181, 8.695670494218149, 7.808361523400634, 6.879253900329584, 6.028567655737696, 5.047574104922797, 5.778075583659094, 6.73225473091581, 7.69441982844791, 8.62077065761345, 9.560321986260046, 10.432940169747065, 12.397989959928845, 13.39433836491617, 14.355549244739322, 15.36542674770523, 14.620842539419483, 13.593599434730026, 12.698461835028667, 11.660307135012673, 10.60214541505412, 9.637144530828806, 8.769667228374752, 7.811183306295198, 7.061728626450538, 6.0512598120372925, 6.8514340517742, 7.786313915971583, 8.715900516072221, 9.654855840424243, 10.610883685697532, 11.37002639962161, 13.36740910056572, 14.414935159364067, 15.392698924983137, 15.491649711325774, 14.544385393831805, 13.69147070157163, 12.796813527625043, 12.57987899722247, 11.615308361202965, 10.675359030878887, 9.781710420086524, 8.833546138913192, 8.018726569760583, 7.07932796470285, 7.777307856858526, 8.764985083317649, 9.692702666013213, 10.726221151423276, 11.599298519342522, 12.337465003106692, 14.305488803325945, 15.310627878588136, 15.507492812784548, 14.526367736285353, 13.580652942144493, 12.747832237277631, 11.813606363483933, 12.75574115708835, 12.551774443611425, 11.621119508191942, 10.748229351025866, 9.823055892288824, 8.959657001847699, 8.013048461517167, 8.772039760983848, 9.727102787782057, 10.666486223083968, 11.72050906259834, 12.63619526314671, 13.31815352828972, 15.277243061949857, 15.343426755175807, 14.539952535487993, 13.49862288156408, 12.64691029485208, 11.684068256368764, 10.765187164140933, 11.738503084925796, 12.685880968040639, 12.581827869943314, 11.723619152085151, 10.881429593294332, 9.983677586377862, 9.08470578558421, 9.729272990273985, 10.680081536969091, 11.630535816311982, 12.642157892439034, 13.607102740293021, 14.33485826096208, 15.324958307480141, 14.397005195534499, 13.559608664643726, 12.520988907125528, 11.607340631603993, 10.72803458082082, 9.803349597210424, 10.74879538498233, 11.735116962410636, 12.660238292662642, 12.674968710382679, 11.936398632043616, 11.053361622527524, 10.139011251197116, 10.689934422080723, 11.639126687465373, 12.569334576050379, 13.496148404563721, 14.470401716988748, 15.26514550875558, 14.43340616951603, 13.427441612612146, 12.507267168839169, 11.487682013647351, 10.58991900376308, 9.669020661245455, 8.856087630388005, 9.740903105055688, 10.709919821098973, 11.72396428023221, 12.691990918460494, 12.86393589418834, 12.099602894238041, 11.20472459681834, 11.721079909105972, 12.7102075160101, 13.591464637885107, 14.501751139793823, 15.456734127110426, 15.476317605017627, 13.459238811763301, 12.487174043038296, 11.466591699748122, 10.49847219998927, 9.637099441672728, 8.722978789102637, 7.891164093069028, 8.78715694252895, 9.826175210924745, 10.792839821608164, 11.66068818495426, 12.704129550544877, 13.035788620193664, 12.253190550818296, 12.657022789999537, 13.68128773405885, 14.645720587342558, 15.552647942046026, 15.383284701793968, 14.436715261260014, 12.486356860862063, 11.544831480016503, 10.498370198997234, 9.502175369758305, 8.66627342759758, 7.670227169673814, 6.851628704165754, 7.806756420374509, 8.76204631147312, 9.730724134266545, 10.689369133337703, 11.74097572554337, 12.634273989086335, 13.27721103441743, 13.621188886844674, 14.60719568717124, 15.621348397796899, 15.41444250679746, 14.470536727508335, 13.433376073734765, 11.581529593056217, 10.667840233287745, 9.615363586350895, 8.57130505454548, 7.670524601660695, 6.738200799954226, 5.877564784098846, 6.846593875766091, 7.850081845583597, 8.821669052847374, 9.772630583308413, 10.821031491025723, 11.696976136555806, 12.694874237121763, 13.69301935124255, 14.658500935300363, 15.54156449660362, 14.5826078643701, 13.549197049587976, 12.627373289632073, 10.581194923003125, 9.635374093905678, 8.65746721847376, 7.598639151638353, 6.666777159725327, 5.663397162390465, 4.87285404791776, 5.883247259789413, 6.855691110673132, 7.822595316884224, 8.819065948021734, 9.77791072634005, 10.738435199681984, 11.750856106415393, 12.750890047019599, 13.685564572852519, 14.590685354609873, 13.563432099039645, 12.578116559169883, 11.602893144912994, 9.764808009782158, 8.704154759554896, 7.676270794022524, 6.729250269397054, 5.685417975876167, 4.690182822781184, 3.79899749638198, 4.820814279158637, 5.825846019157369, 6.7562674513793, 7.803217048824966, 8.765949789193908, 9.825281613322202, 10.785938847866237, 11.757063221383302, 12.732698870189399, 13.63550344707465, 12.7093425283024, 11.660758666192466, 10.714805318336833, 8.787605608609583, 7.768571061844975, 6.745182859215837, 5.762564371728425, 4.737535353313914, 3.7630506256041176, 2.8254300018732934, 3.8810089506461716, 4.882458153319771, 5.890023046247438, 6.96161930489138, 7.955015528067525, 8.896151155740018, 9.873011827390293, 10.878841275425113, 11.898257239475033, 12.613481581638464, 11.672629252195069, 10.72806233586071, 9.76206413148583, 7.776378710716369, 6.764693724981193, 5.804041760315277, 4.826421497134056, 3.878126315030039, 2.820734724341942, 1.8905101817271777, 2.910409317867237, 3.8521647233527374, 4.897570211527945, 5.969137361393219, 6.993883314003763, 7.968176336793566, 8.897595173265312, 9.965633255486294, 11.013262775616441, 11.876650692232703, 10.819700917852506, 9.816853922899218, 8.835225690763988], [6.935205047812421, 7.894180303085352, 8.873517316522564, 9.864392457995145, 10.892627097626193, 9.984500068206028, 8.95715625458805, 7.94227214986042, 7.00261501266132, 5.978188734915714, 4.931053302060647, 3.989625800823256, 2.923562286711749, 1.9151698537759398, 0.9271279955706547, 1.9156056156915509, 2.8729910946651422, 3.897363691893418, 4.898289819502274, 5.925027415852381, 6.156812217104984, 7.226269223298998, 8.245768285957961, 9.194305507161653, 10.11018921270637, 9.12095458619656, 8.057525881698298, 7.065530067904652, 6.013767442111243, 4.941381137727888, 3.9879854492980087, 3.0279433755928578, 1.9691334358658372, 0.9527062634485672, 0.0, 1.068504546067285, 2.082333856780715, 3.010655701444893, 4.065906625691409, 5.111031872844658, 6.901961594661727, 7.843116734484618, 8.799876326313209, 9.766042046476862, 10.764882479284193, 9.997851496643008, 8.966648894145285, 7.944760384718341, 6.929097395935963, 5.921842675404968, 4.901629405652698, 3.970836416863528, 2.9185661872922863, 1.9225913528545917, 0.9482925795928298, 1.8869256151189533, 2.8367843483236985, 3.8894799419178936, 4.904682911406318, 5.856512241078152, 7.725727885662839, 8.663141950683137, 9.685999296584917, 10.614608316089567, 11.653867827638942, 10.807270802092171, 9.8587900246396, 8.867681490237377, 7.882131140079096, 6.905405749244632, 5.904954703547725, 4.836779373523225, 3.8728760924270986, 2.910327652071348, 1.9681985355344231, 2.8980018837053327, 3.7658182588263576, 4.700936334633067, 5.694515487794606, 6.703098171716686, 8.651303537086452, 9.600265156949977, 10.62857021297962, 11.657626042119743, 12.636129749399283, 11.794160934453698, 10.748863437429586, 9.808160038147712, 8.737152840769292, 7.792908367655325, 6.843268398267157, 5.776149073935775, 4.861211888584772, 3.88248085240654, 2.947027781764006, 3.95914674581112, 4.764914120580173, 5.693777470357374, 6.640378269657525, 7.673316987662718, 9.501146635796331, 10.562886326275487, 11.512124222710513, 12.437511140354353, 13.476340601388209, 12.478845570120198, 11.541670116329135, 10.573140355132313, 9.56316080233219, 8.635626990702475, 7.689480099047001, 6.737078697789357, 5.779658715041743, 4.850699766706619, 3.872889396781488, 4.852126919479293, 5.779459920364284, 6.692202456764988, 7.588060297115087, 8.550803576535655, 10.44517737859138, 11.459349427547199, 12.420531904139317, 13.427526382046892, 14.4471123390391, 13.449159012199317, 12.603880792544075, 11.560635555485796, 10.550669889762469, 9.577380898624437, 8.69007192780692, 7.760964304735872, 6.845362485996302, 5.855143273915785, 4.825369320210526, 5.779548467467242, 6.741713564999341, 7.668064394164883, 8.607615722811477, 9.480233906298496, 11.445283696480276, 12.4416321014676, 13.402842981290753, 14.412720484256662, 14.522439758882268, 13.781095547598149, 13.580172239434955, 12.54201753941896, 11.483855819460407, 10.518854935235094, 9.65137763278104, 8.692893710701487, 7.878523456709144, 6.858828981030281, 5.898727788325632, 6.833607652523016, 7.763194252623654, 8.702149576975676, 9.658177422248963, 10.417320136173041, 12.41470283711715, 13.462228895915498, 14.439992661534568, 14.538943447877205, 13.591679130383236, 12.738764438123063, 13.569187259763053, 13.461589401628759, 12.497018765609253, 11.557069435285175, 10.663420824492812, 9.715256543319482, 8.793311367374667, 7.853912762316934, 6.824601593409958, 7.812278819869081, 8.739996402564646, 9.77351488797471, 10.646592255893953, 11.384758739658123, 13.352782539877376, 14.357921615139567, 14.55478654933598, 13.573661472836786, 12.627946678695924, 11.795125973829064, 12.585980095621943, 13.52811488922636, 13.433484848017713, 12.50282991259823, 11.598375493277693, 10.673202034540651, 9.734241799461783, 8.787633259131251, 7.819333497535281, 8.774396524333488, 9.7137799596354, 10.767802799149774, 11.683488999698142, 12.365447264841151, 14.324536798501288, 14.39072049172724, 13.587246272039424, 12.545916618115513, 11.694204031403512, 10.731361992920197, 11.537560896278944, 12.510876817063806, 13.470772343109136, 13.463538274349602, 12.573765294336978, 11.704478154157496, 10.758262383991944, 9.842278289267224, 8.776566726825418, 9.727375273520524, 10.677829552863413, 11.689451628990465, 12.654396476844452, 13.38215199751351, 14.372252044031574, 13.444298932085932, 12.606902401195157, 11.56828264367696, 10.654634368155426, 9.775328317372253, 10.575723329348435, 11.52116911712034, 12.520008337479133, 13.44512966773114, 13.525114852634506, 12.75944719290678, 11.777781773385193, 10.77217201801193, 9.737228158632156, 10.686420424016806, 11.61662831260181, 12.543442141115152, 13.51769545354018, 14.312439245307012, 13.480699906067462, 12.474735349163579, 11.554560905390602, 10.534975750198784, 9.637212740314514, 8.716314397796888, 9.628461362526016, 10.525794480124185, 11.49481119616747, 12.508855655300707, 13.476882293528991, 13.686984455051505, 12.82402304509571, 11.837885363633152, 10.768373645657405, 11.757501252561532, 12.638758374436538, 13.549044876345254, 14.504027863661857, 14.52361134156906, 12.506532548314734, 11.534467779589729, 10.513885436299555, 9.545765936540702, 8.68439317822416, 7.770272525654071, 8.663537825207039, 9.572048317597448, 10.611066585993242, 11.57773119667666, 12.445579560022757, 13.489020925613374, 13.743035001354352, 12.72825008064812, 11.70431652655097, 12.728581470610283, 13.693014323893989, 14.599941678597457, 14.430578438345401, 13.484008997811447, 11.533650597413496, 10.592125216567936, 9.545663935548667, 8.549469106309738, 7.713567164149014, 6.717520906225247, 7.624002436303764, 8.591647795443006, 9.546937686541618, 10.515615509335042, 11.4742605084062, 12.525867100611867, 13.517041250367342, 13.595282071048363, 12.668482623396107, 13.654489423722673, 14.668642134348332, 14.461736243348893, 13.517830464059768, 12.480669810286198, 10.628823329607652, 9.715133969839176, 8.662657322902326, 7.618598791096913, 6.717818338212128, 5.785494536505659, 6.649938516236856, 7.631485250834588, 8.634973220652094, 9.640058466325023, 10.65539784458942, 11.70379875230673, 12.579743397836813, 13.57764149840277, 13.619921517336133, 14.612494664677538, 14.588858233155054, 13.629901600921535, 12.59649078613941, 11.674667026183508, 9.62848865955456, 8.682667830457113, 7.7047609550251925, 6.645932888189786, 5.71407089627676, 4.710690898941898, 5.6452277800557695, 6.66813863485791, 7.640582485741629, 8.640984730361872, 9.701833209302741, 10.660677987621057, 11.62120246096299, 12.6336233676964, 13.633657308300606, 14.568331834133526, 13.637979091161306, 12.61072583559108, 11.625410295721318, 10.650186881464428, 8.812101746333592, 7.75144849610633, 6.723564530573957, 5.776544005948487, 4.7327117124276, 3.7374765593326167, 4.681764757662987, 5.703581540439644, 6.708613280438376, 7.639034712660307, 8.685984310105972, 9.648717050474914, 10.70804887460321, 11.668706109147244, 12.639830482664308, 13.615466131470406, 12.682797183626082, 11.756636264853835, 10.7080524027439, 9.762099054888267, 7.834899345161017, 6.815864798396408, 5.79247659576727, 4.809858108279858, 3.7848290898653474, 2.8103443621555506, 3.778136265321861, 4.833715214094738, 5.835164416768338, 6.842729309696005, 7.914325568339947, 8.907721791516092, 9.848857419188583, 10.825718090838858, 11.831547538873679, 12.680002302163926, 11.660775318189897, 10.719922988746502, 9.775356072412142, 8.809357868037264, 6.823672447267802, 5.811987461532626, 4.85133549686671, 3.8737152336854894, 2.925420051581472, 1.8680284608933748, 2.843216445175745, 3.863115581315804, 4.804870986801305, 5.850276474976512, 6.921843624841786, 7.94658957745233, 8.920882600242132, 9.850301436713877, 10.918339518934859, 11.913209767870377, 10.923944428784138, 9.86699465440394, 8.864147659450653, 7.8825194273154215], [6.0014909413500135, 6.960466196622944, 7.939803210060156, 8.930678351532737, 9.958912991163785, 10.914026802210644, 10.025660800655338, 9.010776695927706, 8.071119558728606, 7.046693280983001, 5.999557848127933, 5.058130346890541, 3.9920668327790345, 2.9836743998432254, 1.9943584246695325, 1.0058808045486365, 1.939276988202734, 2.9636495854310096, 3.964575713039866, 4.991313309389973, 5.0883076710376995, 6.157764677231714, 7.177263739890677, 8.125800961094368, 9.185651354872201, 10.174885981382012, 9.126030427765585, 8.134034613971938, 7.08227198817853, 6.009885683795174, 5.056489995365294, 4.096447921660143, 3.0376379819331225, 2.0212108095158525, 1.068504546067285, 0.0, 1.0138293107134302, 1.942151155377608, 2.9974020796241243, 4.042527326777374, 5.9200789139627, 6.861234053785592, 7.817993645614182, 8.784159365777835, 9.782999798585166, 10.79581344292858, 9.93948187936107, 8.917593369934126, 7.901930381151748, 6.894675660620753, 5.874462390868483, 4.943669402079313, 3.8913991725080717, 2.8954243380703772, 1.9211255648086154, 0.9824925292824918, 1.9323512624872372, 2.955553000402876, 3.922800230707291, 4.874629560379125, 6.821294799826378, 7.7587088648466755, 8.781566210748455, 9.710175230253105, 10.74943474180248, 11.774876700725187, 10.831623009855386, 9.840514475453164, 8.854964125294883, 7.878238734460418, 6.877787688763512, 5.8096123587390105, 4.845709077642884, 3.883160637287134, 2.941031520750209, 1.9935687978688712, 2.8613851729898965, 3.7965032487966055, 4.790082401958145, 5.798665085880225, 7.746870451249992, 8.695832071113516, 9.724137127143159, 10.753192956283282, 11.73169666356282, 12.766993919669483, 11.72169642264537, 10.780993023363497, 9.709985825985077, 8.765741352871109, 7.816101383482942, 6.74898205915156, 5.834044873800558, 4.855313837622326, 3.9198607669797916, 3.0547136599746585, 3.860481034743711, 4.789344384520913, 5.735945183821064, 6.768883901826257, 8.59671354995987, 9.658453240439027, 10.607691136874053, 11.533078054517892, 12.571907515551748, 13.451678555335983, 12.51450310154492, 11.545973340348098, 10.535993787547975, 9.60845997591826, 8.662313084262786, 7.709911683005142, 6.7524917002575275, 5.823532751922404, 4.845722381997273, 4.02360012874307, 4.880721407635855, 5.787769370928526, 6.683627211278626, 7.646370490699194, 9.540744292754919, 10.554916341710738, 11.516098818302856, 12.523093296210432, 13.542679253202639, 14.421991997415102, 13.57671377775986, 12.53346854070158, 11.523502874978254, 10.550213883840222, 9.662904913022706, 8.733797289951656, 7.8181954712120865, 6.827976259131571, 5.798202305426312, 5.090813935461837, 5.842975052270913, 6.763631308328421, 7.703182636975018, 8.575800820462035, 10.540850610643815, 11.53719901563114, 12.498409895454293, 13.508287398420201, 13.860692741851139, 14.848325976697026, 14.55300522465074, 13.514850524634745, 12.456688804676192, 11.491687920450879, 10.624210617996825, 9.665726695917272, 8.85135644192493, 7.831661966246067, 6.871560773541418, 6.144873120517611, 6.899549317039255, 7.82567684544206, 8.753744336412502, 9.51288705033658, 11.51026975128069, 12.557795810079039, 13.535559575698107, 13.877196430846077, 12.929932113352107, 13.80599486722194, 14.63641768886193, 14.434422386844544, 13.469851750825038, 12.52990242050096, 11.636253809708597, 10.688089528535267, 9.766144352590452, 8.82674574753272, 7.797434578625744, 7.173294542502852, 7.957698991596905, 8.897042156441092, 9.742159170057493, 10.480325653821662, 12.448349454040915, 13.453488529303106, 13.86285998370844, 12.881734907209244, 11.966199661664795, 12.862356402927942, 13.653210524720821, 14.595345318325238, 14.406317833233498, 13.475662897814015, 12.571208478493478, 11.646035019756436, 10.707074784677568, 9.760466244347036, 8.792166482751066, 8.13541224696726, 8.960394336657007, 9.891330067616156, 10.779055913861683, 11.46101417900469, 13.420103712664828, 13.698793926099698, 12.895319706411884, 11.85399005248797, 11.032457014372383, 11.798592422019075, 12.604791325377821, 13.578107246162684, 14.538002772208014, 14.436371259565387, 13.546598279552763, 12.67731113937328, 11.731095369207729, 10.815111274483009, 9.749399712041203, 9.198121892108427, 9.92444392988502, 10.922039689399718, 11.845338913578058, 12.47771891167705, 13.680325478404033, 12.75237236645839, 11.914975835567617, 10.876356078049419, 9.992887351124295, 10.84255874647113, 11.642953758447312, 12.588399546219218, 13.587238766578011, 14.512360096830017, 14.49794783785029, 13.732280178122565, 12.750614758600978, 11.745005003227714, 10.710061143847941, 10.174470172010583, 10.863242689623418, 11.79005651813676, 12.764309830561787, 13.408006159470553, 12.78877334043992, 11.782808783536037, 10.86263433976306, 9.843049184571242, 8.975465723283383, 9.783544826895765, 10.695691791624894, 11.593024909223063, 12.562041625266348, 13.576086084399584, 14.544112722627869, 14.65981744026729, 13.796856030311496, 12.810718348848937, 11.74120663087319, 11.24555100055531, 11.885372751458146, 12.795659253366862, 13.750642240683465, 13.831684775941518, 11.814565993977618, 10.842541213962187, 9.821958870672013, 8.85383937091316, 8.02264616119303, 8.837502954752948, 9.730768254305916, 10.639278746696325, 11.67829701509212, 12.644961625775538, 13.512809989121635, 14.556251354712252, 14.715867986570137, 13.701083065863905, 12.677149511766755, 12.253189472762823, 12.939628700915597, 13.846556055619065, 13.738611884008286, 12.792042443474331, 10.84168404307638, 9.90015866223082, 8.853697381211552, 7.8575425406821955, 7.051820147117883, 7.784751335324125, 8.691232865402641, 9.658878224541883, 10.614168115640496, 11.58284593843392, 12.541490937505078, 13.593097529710745, 14.58427167946622, 14.568115056264148, 13.641315608611892, 13.179097425875213, 13.95639193738496, 13.638161284490547, 12.694255505201422, 11.788703255949082, 9.801928662349958, 8.90093616856124, 7.8590462147792035, 6.92667222546937, 6.025891772584585, 6.852724965604537, 7.717168945335733, 8.698715679933466, 9.702203649750972, 10.7072888954239, 11.722628273688297, 12.771029181405607, 13.64697382693569, 14.644871927501647, 14.592754502551918, 14.206433631214153, 13.667523278352945, 12.708566646119426, 11.675155831337301, 10.847772358925814, 8.801593992296866, 7.85577316319942, 6.90114984690207, 5.954006322562243, 5.022144330649217, 5.777921328040776, 6.712458209154647, 7.735369063956788, 8.707812914840508, 9.708215159460751, 10.769063638401619, 11.727908416719934, 12.688432890061868, 13.700853796795277, 14.61542947200466, 13.653111140867246, 12.7042649846989, 11.68939088078897, 10.704075340919209, 9.823292214206734, 7.914043143303951, 6.924553828848638, 5.916002276669179, 4.968981752043709, 4.040785146800057, 4.804706988431494, 5.7489951867618645, 6.770811969538522, 7.775843709537254, 8.706265141759184, 9.75321473920485, 10.715947479573792, 11.775279303702087, 12.735936538246122, 13.675881087010223, 12.700245438204126, 11.749083077163677, 10.825413895268277, 9.776830033158342, 8.830876685302709, 6.90118523869861, 5.94557157693232, 4.927758854934728, 3.964960827973589, 2.977192564759178, 3.8775747912544283, 4.846640811389147, 5.9022197601620245, 6.9036689628356225, 7.91123385576329, 8.982830114407232, 9.976226337583377, 10.91736196525587, 11.894222636906145, 12.76570415975144, 11.74628819570152, 10.727061211727491, 9.786208882284097, 8.841641965949737, 7.875643761574858, 5.889958340805395, 4.878273355070218, 3.9176213904043022, 2.963990422542575, 2.0156952404385575, 2.9352588899922525, 3.9117209912430306, 4.9316201273830895, 5.8733755328685895, 6.918781021043797, 7.990348170909071, 9.015094123519615, 9.989387146309419, 10.918805982781164, 11.932755716515791, 10.97949566140797, 9.99023032232173, 8.933280547941534, 7.930433552988245, 6.9488053208530145], [4.987661630636583, 5.946636885909514, 6.925973899346726, 7.916849040819307, 8.945083680450356, 9.900197491497215, 10.927541305115192, 9.960376079431027, 9.020718942231927, 7.9962926644863215, 6.942979988305318, 5.95256263395406, 4.886499119842553, 3.878106686906744, 2.8713107765837913, 1.8828331564628953, 0.9254476774893039, 1.9498202747175797, 2.950746402326436, 3.9774839986765427, 4.074478360324269, 5.143935366518283, 6.163434429177247, 7.111971650380938, 8.171822044158771, 9.161056670668582, 10.139859738479014, 9.147863924685367, 8.09610129889196, 7.0237149945086035, 6.070319306078724, 5.110277232373573, 4.051467292646552, 3.035040120229282, 2.082333856780715, 1.0138293107134302, 0.0, 0.9283218446641779, 1.983572768910694, 3.0286980160639434, 4.90624960324927, 5.847404743072161, 6.804164334900752, 7.770330055064405, 8.769170487871735, 9.78198413221515, 10.813186734712872, 9.931422680647557, 8.915759691865178, 7.9085049713341835, 6.888291701581913, 5.957498712792743, 4.905228483221502, 3.909253648783807, 2.9349548755220454, 1.996321839995922, 1.0729342665197843, 1.941723689689446, 2.9089709199938607, 3.8608002496656946, 5.924597648246555, 6.858494682193364, 7.788008256210831, 8.716617275715482, 9.755876787264857, 10.765313278906527, 11.713794056359099, 10.854343786166591, 9.86879343600831, 8.892068045173847, 7.891616999476941, 6.823441669452441, 5.859538388356315, 4.896989948000564, 3.954860831463639, 2.9304868034625753, 2.0019681770224436, 2.9370862528291526, 3.8948051083383057, 4.903387792260386, 6.850173299670169, 7.797508604171014, 8.825813660200657, 9.781135711413055, 10.738138709025197, 11.803946878940401, 12.735525733358804, 11.79482233407693, 10.72381513669851, 9.779570663584542, 8.829930694196374, 7.762811369864991, 6.847874184513988, 5.8691431483357555, 4.933690077693221, 3.9627734609839944, 3.001064038776258, 3.9299273885534602, 4.8406678902012255, 5.873606608206417, 7.701436256340031, 8.763175946819187, 9.712413843254213, 10.637800760898052, 11.676630221931909, 12.704210009107197, 13.52833241225835, 12.55980265106153, 11.549823098261406, 10.622289286631691, 9.676142394976218, 8.723740993718573, 7.766321010970957, 6.837362062635833, 5.859551692710703, 4.9316599297524055, 4.021304411668403, 4.928352374961074, 5.788349917658787, 6.7510931970793555, 8.64546699913508, 9.659639048090899, 10.620821524683016, 11.627816002590592, 12.6474019595828, 13.674523451186316, 14.590543088473291, 13.547297851415012, 12.537332185691685, 11.564043194553653, 10.676734223736137, 9.747626600665088, 8.832024781925515, 7.841805569845, 6.812031616139741, 5.998873736471173, 4.983558056303461, 5.904214312360969, 6.807905343355179, 7.6805235268421965, 9.645573317023976, 10.6419217220113, 11.603132601834453, 12.613010104800361, 13.584566579782969, 14.634561609398837, 15.56683453536417, 14.528679835348177, 13.470518115389623, 12.50551723116431, 11.638039928710256, 10.679556006630703, 9.865185752638357, 8.845491276959496, 7.885390084254848, 6.969718921172442, 6.040132321071803, 6.966259849474608, 7.858467042792665, 8.61760975671674, 10.61499245766085, 11.662518516459198, 12.640282282078267, 12.957013292225195, 13.740699285844377, 14.6829472191362, 15.51337004077619, 15.448251697557973, 14.483681061538467, 13.54373173121439, 12.650083120422028, 11.701918839248698, 10.779973663303881, 9.840575058246149, 8.811263889339173, 7.998140343157683, 7.098281995629453, 8.03762516047364, 8.846881876437655, 9.585048360201823, 11.553072160421076, 12.558211235683267, 12.909128009491843, 11.96141819015217, 12.776966834157065, 13.7393087548422, 14.53016287663508, 15.472297670239497, 15.420147143946927, 14.489492208527444, 13.585037789206908, 12.659864330469865, 11.720904095390997, 10.774295555060466, 9.805995793464495, 8.96025804762209, 8.100977340689555, 9.031913071648704, 9.883778620241845, 10.565736885384851, 12.524826419044988, 12.724252196116995, 11.927162164195224, 10.933673335430896, 11.843224186864653, 12.675544773933334, 13.48174367729208, 14.455059598076941, 15.414955124122272, 15.450200570278817, 14.560427590266192, 13.69114045008671, 12.744924679921159, 11.828940585196438, 10.763229022754633, 10.022967692763258, 9.065026933917569, 10.062622693432266, 10.95006161995822, 11.58244161805721, 12.705783748421329, 11.777830636475686, 10.946818293350956, 9.956039360992344, 10.803654523616565, 11.71951109838539, 12.51990611036157, 13.465351898133475, 14.46419111849227, 15.389312448744276, 15.51177714856372, 14.746109488835994, 13.764444069314408, 12.758834313941144, 11.72389045456137, 10.999315972665414, 10.003825693655966, 10.930639522169308, 11.88541454306635, 12.512728865850711, 11.804673893100261, 10.808267053553333, 9.888092609780356, 8.922732467514168, 9.786232895775653, 10.660497178810024, 11.57264414353915, 12.469977261137322, 13.438993977180607, 14.453038436313843, 15.421065074542128, 15.67364675098072, 14.810685341024925, 13.824547659562366, 12.75503594158662, 11.978555030073998, 11.025955755490694, 11.93624225739941, 12.871746953188028, 12.838384053449772, 10.805331429985305, 9.867999483979483, 8.84741714068931, 7.933522653856086, 8.8334133336853, 9.714455306667206, 10.607720606220173, 11.516231098610584, 12.555249367006379, 13.521913977689797, 14.389762341035894, 15.43320370662651, 15.729697297283566, 14.714912376577335, 13.690978822480185, 12.986193502281512, 12.080211704948145, 12.987139059651613, 12.729377320015972, 11.782807879482018, 9.832449479084067, 8.890924098238507, 7.844462817219238, 6.937225823625122, 7.862587319610154, 8.661703687238383, 9.568185217316898, 10.535830576456142, 11.491120467554754, 12.459798290348179, 13.418443289419336, 14.470049881625004, 15.461224031380478, 15.581944366977577, 14.655144919325322, 13.912101455393902, 13.09697494141751, 12.624331973777116, 11.68042619448799, 10.779468691956769, 8.788099351636529, 7.88710685784781, 6.84981165078689, 6.006355508412296, 6.902844124498844, 7.729677317518796, 8.594121297249991, 9.575668031847725, 10.57915600166523, 11.58424124733816, 12.599580625602556, 13.647981533319866, 14.52392617884995, 15.521824279415906, 14.604791339943063, 13.612218192601658, 12.653693967639514, 11.694737335405994, 10.66132652062387, 9.833943048212385, 7.787764681583436, 6.84194385248599, 5.891915282909756, 5.033689605505169, 5.899096682563476, 6.654873679955035, 7.589410561068906, 8.612321415871047, 9.584765266754767, 10.58516751137501, 11.646015990315878, 12.604860768634193, 13.565385241976127, 14.577806148709536, 13.601600161291227, 12.639281830153813, 11.690435673985467, 10.675561570075539, 9.690246030205778, 8.809462903493305, 6.90021383259052, 5.910724518135208, 4.906767712676865, 3.959747188051396, 4.917737498714316, 5.681659340345753, 6.625947538676123, 7.64776432145278, 8.652796061451513, 9.583217493673443, 10.630167091119109, 11.592899831488051, 12.652231655616346, 13.61288889016038, 12.66205177629679, 11.686416127490693, 10.735253766450244, 9.811584584554845, 8.763000722444911, 7.817047374589278, 5.887355927985179, 4.9317422662188894, 3.913929544221298, 2.9557262639812754, 3.854144916673437, 4.754527143168687, 5.736914414528229, 6.792493363301107, 7.793942565974705, 8.801507458902371, 9.873103717546314, 10.86649994072246, 11.807635568394952, 12.757704297072827, 11.751874849038007, 10.732458884988088, 9.713231901014058, 8.772379571570664, 7.827812655236305, 6.861814450861426, 4.876129030091963, 3.8644440443567873, 2.903792079690872, 1.9547558585502618, 2.8926475923528163, 3.8122112419065113, 4.801994594382113, 5.821893730522172, 6.763649136007672, 7.809054624182879, 8.880621774048153, 9.905367726658698, 10.879660749448501, 11.809079585920246, 10.918926405802361, 9.96566635069454, 8.976401011608301, 7.919451237228103, 6.916604242274815, 5.934976010139583], [4.068166192383283, 5.027141447656214, 6.006478461093426, 6.997353602566007, 8.025588242197056, 8.980702053243915, 10.008045866861892, 10.888697924095204, 9.949040786896104, 8.9246145091505, 7.871301832969496, 6.880884478618238, 5.8148209645067315, 4.806428531570922, 3.799632621247969, 2.811155001127073, 1.8537695221534818, 1.03032483646428, 2.031250964073136, 3.057988560423243, 3.146156515660091, 4.215613521854105, 5.235112584513068, 6.183649805716759, 7.2435001994945925, 8.232734826004403, 9.296163530502666, 10.076185769349546, 9.024423143556136, 7.952036839172781, 6.998641150742902, 6.038599077037751, 4.97978913731073, 3.96336196489346, 3.010655701444893, 1.942151155377608, 0.9283218446641779, 0.0, 1.055250924246516, 2.1003761713997653, 3.977927758585092, 4.919082898407983, 5.875842490236574, 6.842008210400227, 7.840848643207558, 8.853662287550971, 9.884864890048693, 10.859744525311735, 9.844081536529355, 8.83682681599836, 7.816613546246091, 6.885820557456921, 5.83355032788568, 4.837575493447986, 3.8632767201862235, 2.9246436846601, 2.001256111183962, 1.0134018450252682, 1.9806490753296826, 2.9324784050015165, 4.996275803582377, 5.930172837529186, 6.859686411546653, 7.788295431051303, 8.827554942600678, 9.836991434242348, 10.78547221169492, 11.776580746097142, 10.79711528067249, 9.820389889838026, 8.819938844141118, 7.751763514116618, 6.787860233020492, 5.825311792664742, 4.8831826761278165, 3.858808648126753, 2.9302900216866212, 2.041109878818496, 2.9664832636741276, 3.9750659475962076, 5.921851455005991, 6.869186759506836, 7.897491815536478, 8.852813866748876, 9.809816864361018, 10.875625034276222, 11.839442282754673, 12.723144178741105, 11.652136981362686, 10.707892508248717, 9.75825253886055, 8.691133214529168, 7.776196029178165, 6.7974649929999345, 5.862011922357399, 4.8910953056481725, 3.929385883440436, 3.090761504940818, 3.9123460455370473, 4.945284763542239, 6.773114411675854, 7.834854102155011, 8.784091998590036, 9.709478916233875, 10.748308377267731, 11.775888164443018, 12.71306361823408, 13.488124495725707, 12.478144942925583, 11.550611131295868, 10.604464239640395, 9.65206283838275, 8.694642855635136, 7.765683907300012, 6.787873537374882, 5.859981774416584, 4.94962625633258, 4.089186491348432, 4.860028072994609, 5.822771352415177, 7.717145154470902, 8.731317203426721, 9.69249968001884, 10.699494157926415, 11.719080114918622, 12.746201606522137, 13.687823167717493, 14.475619696079189, 13.465654030355863, 12.49236503921783, 11.605056068400314, 10.675948445329265, 9.760346626589694, 8.77012741450918, 7.74035346080392, 6.927195581135351, 5.911879900967638, 5.065048428748327, 5.879583498691001, 6.752201682178018, 8.717251472359798, 9.713599877347123, 10.674810757170276, 11.684688260136184, 12.656244735118792, 13.70623976473466, 14.664114614608373, 15.457001680012354, 14.3988399600538, 13.433839075828487, 12.566361773374433, 11.60787785129488, 10.793507597302536, 9.773813121623675, 8.813711928919027, 7.898040765836619, 6.96845416573598, 6.127093965861966, 6.9301451981284865, 7.6892879120525635, 9.686670612996673, 10.734196671795022, 11.71196043741409, 12.639998028592116, 13.587005363617823, 14.591549896112639, 15.527830993343278, 16.37657354222215, 15.412002906202646, 14.472053575878569, 13.578404965086206, 12.630240683912875, 11.70829550796806, 10.768896902910328, 9.739585734003352, 8.92646218782186, 8.02660384029363, 7.198459276860998, 7.918560031773476, 8.656726515537645, 10.624750315756899, 11.62988939101909, 12.017258393518869, 12.889740034816349, 13.705288678821244, 14.66763059950638, 15.458484721299259, 16.400619514903674, 16.348468988611106, 15.417814053191623, 14.513359633871087, 13.588186175134044, 12.649225940055176, 11.702617399724645, 10.734317638128674, 9.888579892286268, 9.029299185353732, 8.192747188036062, 8.955456775577666, 9.637415040720674, 11.59650457438081, 11.83238258014402, 11.03529254822225, 11.861995180095075, 12.771546031528832, 13.603866618597513, 14.410065521956259, 15.38338144274112, 16.34327696878645, 16.378522414942996, 15.488749434930371, 14.619462294750889, 13.673246524585338, 12.757262429860617, 11.691550867418812, 10.951289537427435, 9.993348778581746, 9.223456809819623, 10.02173977529404, 10.654119773393033, 11.813914132448355, 10.885961020502712, 10.054948677377983, 10.884361205656523, 11.731976368280744, 12.647832943049568, 13.448227955025748, 14.393673742797654, 15.392512963156449, 16.317634293408457, 16.4400989932279, 15.674431333500173, 14.692765913978587, 13.687156158605323, 12.65221229922555, 11.927637817329591, 10.932147538320143, 10.256108206736434, 10.957092698402171, 11.584407021186536, 10.900072959742607, 9.91639743758036, 8.996222993807383, 9.851054312178347, 10.714554740439832, 11.588819023474203, 12.50096598820333, 13.398299105801499, 14.367315821844784, 15.381360280978022, 16.349386919206307, 16.601968595644898, 15.739007185689104, 14.752869504226545, 13.683357786250799, 12.906876874738176, 11.954277600154871, 11.261710941966536, 11.943425108523849, 11.93378312009212, 9.90073049662765, 8.97612986800651, 7.955547524716335, 8.861844498520265, 9.761735178349479, 10.642777151331385, 11.536042450884352, 12.444552943274761, 13.483571211670556, 14.450235822353974, 15.318084185700071, 16.36152555129069, 16.658019141947747, 15.643234221241514, 14.619300667144364, 13.91451534694569, 13.008533549612322, 12.312607744218738, 11.824776386658318, 10.878206946124363, 8.927848545726413, 7.999054482265533, 6.952593201246264, 7.8655476682893, 8.790909164274332, 9.590025531902562, 10.496507061981077, 11.46415242112032, 12.419442312218932, 13.388120135012356, 14.346765134083514, 15.39837172628918, 16.389545876044654, 15.563534243282044, 14.636734795629788, 13.7200589596873, 12.719377261970473, 11.704836535523818, 10.760930756234693, 9.874867758599114, 7.868603913383229, 6.96761141959451, 5.957942034813916, 6.9346773530764745, 7.831165969163022, 8.657999162182975, 9.52244314191417, 10.503989876511902, 11.507477846329408, 12.512563092002338, 13.527902470266733, 14.576303377984043, 15.452248023514127, 14.626156794348503, 13.685295901689763, 12.692722754348358, 11.734198529386216, 10.775241897152696, 9.741831082370572, 8.914447609959085, 6.868269243330136, 5.922448414232691, 5.000045666936782, 5.9620114501693475, 6.827418527227654, 7.583195524619213, 8.517732405733083, 9.540643260535225, 10.513087111418944, 11.513489356039187, 12.574337834980055, 13.53318261329837, 14.493707086640304, 13.682138663642133, 12.682104723037927, 11.719786391900513, 10.770940235732168, 9.75606613182224, 8.77075059195248, 7.889967465240005, 5.980718394337221, 4.991229079881909, 4.014898096703892, 4.888069032715574, 5.846059343378494, 6.609981185009931, 7.554269383340301, 8.576086166116959, 9.58111790611569, 10.51153933833762, 11.558488935783286, 12.521221676152228, 13.580553500280523, 12.713680711560555, 11.74255633804349, 10.766920689237393, 9.815758328196944, 8.892089146301547, 7.843505284191613, 6.897551936335979, 4.96786048973188, 4.0122468279655905, 2.9944341059679984, 3.8840481086454535, 4.782466761337615, 5.682848987832865, 6.665236259192406, 7.720815207965284, 8.722264410638884, 9.72982930356655, 10.801425562210493, 11.794821785386638, 12.73595741305913, 11.838208858819527, 10.832379410784707, 9.812963446734788, 8.793736462760759, 7.852884133317365, 6.908317216983006, 5.942319012608127, 3.9566335918386644, 2.944948606103488, 1.9842966414375725, 2.8830777032144397, 3.820969437016994, 4.740533086570689, 5.730316439046291, 6.75021557518635, 7.691970980671851, 8.737376468847058, 9.808943618712332, 10.833689571322877, 11.80798259411268, 11.032594905519812, 9.999430967549062, 9.04617091244124, 8.056905573355001, 6.999955798974804, 5.997108804021515, 5.015480571886284], [3.0850052241426766, 4.043980479415607, 5.0233174928528195, 6.014192634325401, 7.042427273956449, 7.997541085003308, 9.024884898621286, 10.039769003348916, 10.979426140548016, 9.979865433397014, 8.926552757216012, 7.936135402864754, 6.870071888753247, 5.861679455817438, 4.854883545494485, 3.866405925373589, 2.909020446399998, 2.049016123441385, 1.0480899958325292, 2.0748275921826362, 2.0909055914135752, 3.1603625976075893, 4.179861660266553, 5.128398881470244, 6.1882492752480776, 7.1774839017578875, 8.240912606256149, 9.232908420049796, 10.079674067802653, 9.007287763419297, 8.053892074989419, 7.093850001284268, 6.035040061557247, 5.018612889139977, 4.06590662569141, 2.9974020796241243, 1.983572768910694, 1.055250924246516, 0.0, 1.0451252471532495, 2.922676834338576, 3.8638319741614673, 4.820591565990058, 5.786757286153711, 6.785597718961041, 7.798411363304456, 8.829613965802178, 9.851502475229122, 10.862593299239789, 9.855338578708794, 8.835125308956524, 7.904332320167353, 6.852062090596112, 5.856087256158418, 4.881788482896655, 3.9431554473705317, 2.993296714165786, 1.940601120571591, 0.9253981510831667, 1.8772274807550005, 3.9410248793358615, 4.87492191328267, 5.804435487300137, 6.733044506804787, 7.772304018354162, 8.781740509995831, 9.730221287448403, 10.721329821850626, 11.706880172008907, 10.83800692709423, 9.837555881397323, 8.769380551372823, 7.805477270276697, 6.842928829920947, 5.81247852380487, 4.768448194835992, 3.83992956839586, 2.904811492589151, 1.9112323394276116, 2.919815023349692, 4.8666005307594755, 5.81393583526032, 6.842240891289962, 7.797562942502362, 8.754565940114501, 9.820374110029704, 10.784191358508156, 11.72489475779003, 12.66975401861889, 11.725509545504922, 10.775869576116754, 9.708750251785373, 8.793813066434371, 7.811643127805253, 6.791307770034453, 5.766077527502357, 4.80436810529462, 3.8755047555174182, 2.857095121290531, 3.890033839295724, 5.717863487429337, 6.779603177908494, 7.728841074343519, 8.654227991987359, 9.693057453021215, 10.720637240196503, 11.657812693987566, 12.626342455184387, 13.43757191330982, 12.510038101680106, 11.563891210024632, 10.611489808766988, 9.620970837228827, 8.692011888893703, 7.714201518968573, 6.734963996270768, 5.824608478186764, 4.857773719487836, 3.804777148748093, 4.767520428168661, 6.6618942302243855, 7.676066279180205, 8.637248755772323, 9.644243233679898, 10.663829190672105, 11.690950682275622, 12.632572243470978, 13.66498321798517, 14.4250810007401, 13.451792009602068, 12.564483038784552, 11.635375415713503, 10.686674608183385, 9.69645539610287, 8.66668144239761, 7.802177802989535, 6.786862122821822, 5.832724868000876, 4.824332574444485, 5.696950757931502, 7.662000548113282, 8.658348953100607, 9.619559832923759, 10.629437335889667, 11.600993810872275, 12.650988840488143, 13.608863690361858, 14.646365201918336, 15.358266930438038, 14.393266046212725, 13.525788743758671, 12.567304821679118, 11.719835578896227, 10.700141103217366, 9.734309494475317, 8.763312329567176, 7.833725729466538, 6.8947704051145156, 5.874894273881971, 6.634036987806047, 8.631419688750157, 9.678945747548504, 10.656709513167574, 11.584747104345599, 12.531754439371307, 13.536298971866122, 14.472580069096761, 15.499838258481477, 16.371429876586884, 15.431480546262804, 14.537831935470443, 13.567539909057082, 12.62889307352435, 11.689494468466618, 10.660183299559643, 9.791733751552417, 8.891875404024187, 7.930126724344173, 6.86330910752696, 7.601475591291129, 9.569499391510382, 10.574638466772573, 11.545342100132999, 12.526467176632192, 13.484356059226068, 14.479937436160121, 15.453081367384227, 16.395216160988642, 17.307895958995342, 16.37724102357586, 15.433957199427377, 14.508783740690335, 13.569823505611467, 12.623214965280935, 11.654915203684965, 10.753851456016825, 9.89457074908429, 8.924414635519238, 7.900205851331149, 8.582164116474157, 10.541253650134294, 10.909515841762579, 11.853635507845503, 12.885799464486979, 13.807377378579599, 14.659117542844028, 15.465316446202774, 16.438632366987637, 17.398527893032966, 17.33794938532723, 16.40934700048666, 15.540059860307181, 14.59384409014163, 13.67785999541691, 12.612148432975102, 11.816561101157992, 10.858620342312303, 9.931433698901513, 8.966488851047526, 9.598868849146516, 10.891047394066913, 9.96309428212127, 10.980987156596214, 11.908165490048427, 12.76780771533151, 13.703083867296083, 14.503478879272263, 15.44892466704417, 16.447763887402964, 17.37288521765497, 17.360696558784188, 16.595028899056466, 15.613363479534879, 14.607753724161613, 13.57280986478184, 12.792909381060149, 11.7974191020507, 10.876095086580683, 9.901841774155656, 10.529156096940017, 9.940750788847758, 8.993530699198917, 9.958204752244363, 10.87485859657025, 11.750386087490599, 12.644069947720718, 13.556216912449845, 14.453550030048016, 15.4225667460913, 16.436611205224537, 17.40463784345282, 17.52256616120119, 16.659604751245396, 15.673467069782836, 14.60395535180709, 13.772148438468733, 12.819549163885428, 11.881697821810786, 10.888174184277334, 10.974460949197269, 8.941408325732802, 8.053263129625067, 8.917529283153316, 9.885648782912169, 10.797566525400246, 11.6980280755779, 12.591293375130867, 13.499803867521278, 14.538822135917073, 15.505486746600491, 16.373335109946588, 17.416776475537205, 16.557455366387416, 15.619258191355541, 14.632604356949289, 13.671200149633894, 12.687492642695226, 11.698805265610646, 10.85980255953434, 9.918884775229515, 7.968526374831563, 7.042511769942335, 7.914574959683246, 8.901379015340067, 9.826740511325099, 10.645276456149077, 11.551757986227592, 12.519403345366836, 13.474693236465448, 14.443371059258872, 15.40201605833003, 16.4536226505357, 15.533361963112856, 14.595237707756407, 13.668438260104152, 12.751762424161662, 11.751080726444835, 10.736539999998179, 9.792634220709054, 8.915545587704264, 6.90928174248838, 6.008289248699661, 6.919923793250898, 7.970508700127243, 8.886416893409537, 9.71325008642949, 10.577694066160685, 11.559240800758419, 12.562728770575925, 13.567814016248853, 14.583153394513248, 15.626884356241524, 14.596064110582327, 13.657860258822867, 12.716999366164126, 11.724426218822721, 10.765901993860576, 9.806945361627056, 8.773534546844934, 7.955125439064237, 5.9089470724352875, 4.963126243337841, 5.962027425373764, 6.997842797220116, 7.882669451474169, 8.638446448865729, 9.5729833299796, 10.595894184781741, 11.56833803566546, 12.568740280285704, 13.62958875922657, 14.588433537544885, 13.637523173708505, 12.713842128116497, 11.71380818751229, 10.751489856374876, 9.80264370020653, 8.7877695962966, 7.80245405642684, 6.930645294345156, 5.0213962234423715, 4.031906908987059, 4.976879855140873, 5.9239003797663425, 6.901310267625009, 7.665232109256447, 8.609520307586816, 9.631337090363473, 10.636368830362205, 11.566790262584135, 12.613739860029801, 13.576472600398743, 12.706041410578953, 11.745384176034918, 10.774259802517854, 9.798624153711756, 8.847461792671307, 7.92379261077591, 6.875208748665974, 5.929255400810341, 4.00853831883703, 3.0529246570707405, 3.95641586440498, 4.939034351892391, 5.83771768558413, 6.738099912079381, 7.720487183438923, 8.7760661322118, 9.777515334885399, 10.785080227813065, 11.856676486457008, 12.794165228880056, 11.849155105827474, 10.86991232329389, 9.86408287525907, 8.844666911209151, 7.825439927235121, 6.884587597791726, 5.9400206814573675, 4.974022477082489, 2.9973114209438148, 1.9856264352086384, 2.946278399874554, 3.9383286274609555, 4.87622036126351, 5.795784010817205, 6.785567363292807, 7.805466499432866, 8.747221904918366, 9.792627393093573, 10.864194542958847, 11.888940495569392, 10.978852773750951, 10.049433937279206, 9.016269999308456, 8.063009944200633, 7.073744605114394, 6.016794830734197, 5.013947835780908, 4.047184036360646], [2.0646861219069024, 3.023661377179833, 4.002998390617045, 4.993873532089626, 6.022108171720674, 6.977221982767534, 8.004565796385512, 9.019449901113141, 9.959107038312242, 10.983533316057846, 9.971678004369261, 8.981260650018005, 7.915197135906497, 6.906804702970687, 5.900008792647734, 4.911531172526838, 3.9541456935532473, 3.086425331846208, 2.085499204237352, 1.0587616078872453, 1.045780344260326, 2.11523735045434, 3.1347364131133033, 4.083273634316995, 5.143124028094828, 6.132358654604638, 7.1957873591029005, 8.187783172896546, 9.239545798689957, 10.052413010572547, 9.099017322142668, 8.138975248437518, 7.080165308710496, 6.063738136293226, 5.111031872844659, 4.042527326777374, 3.0286980160639434, 2.1003761713997653, 1.0451252471532495, 0.0, 2.083481863838842, 3.0246370036617334, 3.981396595490324, 4.947562315653977, 5.946402748461308, 6.959216392804723, 7.990418995302445, 9.012307504729389, 10.027970493511768, 10.900463825862044, 9.880250556109774, 8.949457567320604, 7.8971873377493615, 6.901212503311667, 5.926913730049905, 4.988280694523781, 4.0384219613190355, 2.9857263677248405, 1.9705233982364163, 1.0380325102552668, 3.1018299088361276, 4.0357269427829365, 4.965240516800403, 5.893849536305053, 6.933109047854428, 7.942545539496098, 8.89102631694867, 9.882134851350893, 10.867685201509174, 11.844410592343639, 10.882681128550573, 9.814505798526072, 8.850602517429946, 7.888054077074196, 6.85760377095812, 5.8135734419892415, 4.885054815549109, 3.949936739742401, 2.9563575865808613, 2.0985721181882004, 4.027405560259742, 4.974740864760586, 6.003045920790228, 6.958367972002627, 7.915370969614768, 8.98117913952997, 9.944996388008423, 10.885699787290298, 11.859811311633546, 12.770634792658173, 11.820994823270006, 10.753875498938623, 9.83893831358762, 8.856768374958502, 7.836433017187702, 6.811202774655606, 5.84949335244787, 4.920630002670668, 3.902220368443781, 3.0687909341342325, 5.035507653655764, 6.015707979005008, 6.949046021770142, 7.874432939413982, 8.857933806235145, 9.885513593410433, 10.822689047201496, 11.791218808398318, 12.791764669268732, 13.555163348833355, 12.609016457177882, 11.656615055920238, 10.666096084382076, 9.737137136046952, 8.759326766121822, 7.780089243424017, 6.869733725340014, 5.902898966641086, 4.849902395901343, 4.129462434187799, 5.979538396450812, 6.993710445406632, 7.954892921998749, 8.901850600429476, 9.828705543886036, 10.855827035489552, 11.797448596684909, 12.829859571199101, 13.812269945210392, 14.496917256755317, 13.609608285937801, 12.680500662866752, 11.731799855336634, 10.74158064325612, 9.71180668955086, 8.847303050142784, 7.831987369975072, 6.877850115154126, 5.869457821597734, 5.05889276395064, 6.9907697697354045, 7.9759931193270335, 8.937203999150187, 9.932927546010959, 10.854061392765432, 11.881977862426549, 12.773740043575788, 13.811241555132266, 14.775189710095713, 15.438391293365974, 14.57091399091192, 13.612430068832367, 12.764960826049476, 11.745266350370615, 10.779434741628567, 9.808437576720426, 8.878850976619788, 7.939895652267765, 6.92001952103522, 5.995978993825185, 7.9601889103722785, 8.996589913774931, 9.974353679394001, 10.902391270572027, 11.784822021264464, 12.78936655375928, 13.725647650989918, 14.752905840374634, 15.71747647639414, 16.476605793416056, 15.582957182623693, 14.61266515621033, 13.6740183206776, 12.734619715619868, 11.705308546712892, 10.836858998705667, 9.937000651177438, 8.975251971497423, 7.908434354680209, 6.963417597310267, 8.898268613132505, 9.903407688394696, 10.874111321755121, 11.855236398254316, 12.748554472951776, 13.733005018053278, 14.706148949277384, 15.648283742881802, 16.691761630889015, 17.42236627072911, 16.479082446580627, 15.553908987843585, 14.614948752764716, 13.668340212434185, 12.700040450838214, 11.798976703170075, 10.93969599623754, 9.969539882672487, 8.945331098484399, 7.944106122493295, 9.903195656153432, 10.912606905960418, 11.85607716705174, 12.88298125297559, 13.682297120244188, 14.655924989880312, 15.72438502159603, 16.700092795323652, 17.620725428166114, 18.383074632480483, 17.454472247639913, 16.58518510746043, 15.638969337294878, 14.722985242570157, 13.657273680128352, 12.861686348311242, 11.903745589465554, 10.903807856582883, 9.938863008728896, 8.960810855165654, 10.076188304339624, 10.972414802779575, 11.990307677254519, 12.945574698453251, 13.805216923736335, 14.748209114449331, 15.548604126425511, 16.494049914197415, 17.49288913455621, 18.41801046480822, 18.40582180593744, 17.640154146209714, 16.658488726688127, 15.652878971314863, 14.61793511193509, 13.816637530796822, 12.775283072775398, 11.848469244262056, 10.874215931837028, 9.891098102959155, 9.082531323771274, 10.002851219857222, 10.995613960649187, 11.912267804975075, 12.787795295895423, 13.689195194873966, 14.601342159603092, 15.498675277201263, 16.467691993244546, 17.48173645237779, 18.385925651771405, 17.460399321631776, 16.473321990107266, 15.618659149365334, 14.54822813560708, 13.658519519605633, 12.718083348921754, 11.729382965627074, 10.818163233707349, 10.115130503176808, 8.083188860656318, 9.062583650283372, 9.95493849155814, 10.923057991316993, 11.83497573380507, 12.743153322731148, 13.636418622284115, 14.544929114674526, 15.58394738307032, 16.55061199375374, 17.418460357099836, 16.563739018144815, 15.537136264151643, 14.598939089119767, 13.612285254713514, 12.65088104739812, 11.667173540459451, 10.678486163374872, 9.839483457298567, 9.059554329209051, 7.110306909755079, 8.05183229060064, 8.95198416808807, 9.93878822374489, 10.864149719729923, 11.690401703302324, 12.59688323338084, 13.564528592520084, 14.519818483618696, 15.48849630641212, 16.447141305483278, 15.53577039905812, 14.513042860877082, 13.574918605520633, 12.648119157868377, 11.731443321925887, 10.73076162420906, 9.716220897762405, 8.77231511847328, 8.0044461786311, 6.051062277411896, 7.041711441818068, 7.957333001655721, 9.007917908532065, 9.931542140562788, 10.758375333582737, 11.622819313313933, 12.604366047911666, 13.607854017729172, 14.612939263402101, 15.553425994146197, 14.60656525400575, 13.575745008346553, 12.637541156587092, 11.696680263928352, 10.704107116586947, 9.745582891624801, 8.786626259391282, 7.753215444609159, 6.996528887181144, 5.0507276073588026, 5.996548436456248, 6.999436633778587, 8.035252005624939, 8.92779469862742, 9.683571696018976, 10.618108577132848, 11.64101943193499, 12.613463282818708, 13.613865527438952, 14.599861358859519, 13.577728544814665, 12.617204071472731, 11.693523025880722, 10.693489085276516, 9.731170754139102, 8.782324597970756, 7.767450494060826, 6.782134954191066, 5.947717202453105, 4.0846209590895235, 5.069316117391882, 6.0142890635456965, 6.961309588171166, 7.946435514778258, 8.710357356409695, 9.654645554740064, 10.676462337516721, 11.681494077515453, 12.611915509737383, 13.658865107183049, 12.732983785442038, 11.685722308343179, 10.725065073799144, 9.75394070028208, 8.778305051475982, 7.827142690435533, 6.903473508540135, 5.8548896464302, 4.908936298574567, 3.0717630544841823, 4.090333865475563, 4.993825072809803, 5.976443560297215, 6.88284293273738, 7.78322515923263, 8.76561243059217, 9.82119137936505, 10.822640582038648, 11.830205474966316, 12.767242349820426, 11.773846126644282, 10.8288360035917, 9.849593221058116, 8.843763773023296, 7.824347808973377, 6.805120824999347, 5.864268495555952, 4.919701579221593, 3.9537033748467145, 2.0605361565909672, 3.0230356436134613, 3.983687608279377, 4.983453874614205, 5.921345608416759, 6.840909257970454, 7.8306926104460555, 8.850591746586115, 9.792347152071615, 10.837752640246823, 11.909319790112097, 10.93282669430498, 9.958533671515177, 9.029114835043432, 7.995950897072682, 7.042690841964859, 6.0534255028786195, 4.996475728498423, 3.9936287335451337, 3.0268649341248715], [2.0626284306803027, 3.021603685953233, 3.8678020712861496, 4.858677212758731, 5.820603580445049, 6.759010696092955, 7.786354509710932, 8.801238614438564, 9.740895751637664, 10.765322029383269, 11.818634705564271, 10.85881223720333, 9.792748723091822, 8.784356290156014, 7.77756037983306, 6.789082759712165, 5.831697280738574, 4.971692957779961, 3.9707668301711054, 3.072806062640343, 1.0437226530337265, 1.975006593060781, 2.877289192982146, 3.825826414185837, 4.79057415126589, 5.7798087777757, 6.843237482273962, 7.835233296067608, 8.886995921861018, 9.959382226244374, 10.889947043959737, 9.929904970254587, 8.871095030527565, 7.854667858110295, 6.901961594661728, 5.9200789139627, 4.90624960324927, 3.977927758585092, 2.922676834338576, 2.083481863838842, 0.0, 0.9411551398228913, 1.8979147316514817, 2.8640804518151355, 3.862920884622466, 4.87573452896588, 5.906937131463603, 6.928825640890547, 7.944488629672925, 8.95174335020392, 9.907005841128766, 8.976212852339597, 7.9239426227683545, 6.92796778833066, 5.953669015068898, 5.015035979542774, 4.0651772463380285, 3.0124816527438334, 1.9972786832554092, 1.0454493535835756, 1.0183480449972853, 1.9522450789440944, 2.8817586529615613, 3.8103676724662114, 4.849627184015587, 5.859063675657256, 6.807544453109828, 7.79865298751205, 8.78420333767033, 9.760928728504794, 10.7613797742017, 9.841261083545065, 8.87735780244894, 7.914809362093189, 6.884359055977113, 5.8403287270082345, 4.911810100568102, 3.9766920247613937, 2.9831128715998543, 2.0409777589434386, 1.943923696420899, 2.8912590009217443, 3.919564056951386, 4.8748861081637855, 5.831889105775927, 6.89769727569113, 7.861514524169581, 8.802217923451456, 9.776329447794703, 10.720573920908672, 11.67021389029684, 10.780630783957616, 9.865693598606613, 8.883523659977495, 7.863188302206695, 6.837958059674599, 5.876248637466863, 4.947385287689661, 3.928975653462774, 2.997666516012874, 2.952025789816922, 3.932226115166165, 4.8655641579313, 5.79095107557514, 6.774451942396304, 7.802031729571591, 8.739207183362655, 9.707736944559477, 10.708282805429889, 11.635816617059604, 12.581963508715077, 11.68337034093923, 10.692851369401069, 9.763892421065945, 8.786082051140815, 7.80684452844301, 6.896489010359007, 5.918108699237909, 4.865112128498166, 3.902368849077598, 3.8960565326119707, 4.9102285815677895, 5.871411058159907, 6.818368736590635, 7.745223680047195, 8.77234517165071, 9.713966732846066, 10.74637770736026, 11.72878808137155, 12.577570524981565, 13.603427594682552, 12.707255947885745, 11.758555140355627, 10.768335928275112, 9.738561974569853, 8.837806776203404, 7.813817007074377, 6.772746393963905, 5.764354100407513, 4.8317991788404395, 4.907287905896562, 5.892511255488191, 6.853722135311344, 7.849445682172118, 8.770579528926591, 9.798495998587706, 10.690258179736945, 11.727759691293425, 12.69170784625687, 13.519044561592223, 14.475645614951738, 13.63918535385136, 12.75059021927764, 11.695721342406493, 10.645475620642653, 9.674478455734512, 8.744891855633874, 7.805936531281851, 6.75488231612467, 5.768885408714985, 5.876707046533436, 6.913108049936089, 7.890871815555158, 8.818909406733184, 9.701340157425623, 10.705884689920438, 11.642165787151077, 12.669423976535793, 13.633994612555298, 14.557259061642302, 15.48768880666351, 14.478706035224416, 13.540059199691687, 12.600660594633954, 11.571349425726979, 10.702899877719753, 9.803041530191525, 8.810114766586873, 7.743297149769659, 6.7363240122000665, 6.814786749293662, 7.8199258245558525, 8.790629457916278, 9.771754534415471, 10.665072609112935, 11.649523154214437, 12.622667085438543, 13.56480187904296, 14.608279767050174, 15.503019538955357, 16.345123325594713, 15.41994986685767, 14.480989631778803, 13.534381091448271, 12.5660813298523, 11.665017582184161, 10.805736875251627, 9.756473452236264, 8.731780285393532, 7.717012537383095, 7.861008726084568, 8.829125042121575, 9.772595303212897, 10.799499389136745, 11.598815256405347, 12.57244312604147, 13.640903157757188, 14.61661093148481, 15.537243564327273, 16.46372790070673, 17.320513126654, 16.451225986474515, 15.505010216308964, 14.589026121584244, 13.523314559142438, 12.672649748322257, 11.688336347599735, 10.676714271472683, 9.711769423618696, 8.733717270055454, 8.817066562731174, 9.745019674676817, 10.752939174057165, 11.777133363575297, 12.638384919653433, 13.528476801589415, 14.461139936120487, 15.406585723892393, 16.437686493230917, 17.362807823482925, 18.271862684951525, 17.5061950252238, 16.524529605702213, 15.518919850328949, 14.483975990949176, 13.589543945686621, 12.548189487665198, 11.621375659151855, 10.647122346726828, 9.664004517848955, 9.810723543299524, 10.71458325759917, 11.767968252075903, 12.810440257053473, 13.655806547494345, 14.58749072116478, 15.408401902942906, 16.435552345730766, 17.40456906177405, 18.365155711285382, 18.331643960948078, 17.40611763080845, 16.41904029928394, 15.616601458138735, 14.546170444380481, 13.656461828379035, 12.716025657695155, 11.727325274400476, 10.816105542480749, 10.113072811950207, 9.855443817469435, 10.83483860709649, 11.771931368402926, 12.740050868161779, 13.661359384231964, 14.620704909916475, 15.513970209469441, 16.422480701859854, 17.461498970255647, 18.428163580939064, 17.473879211490114, 16.509457327321485, 15.482854573328316, 14.59688139789317, 13.610227563486916, 12.64882335617152, 11.665115849232853, 10.676428472148274, 9.837425766071966, 9.057496637982451, 8.882561866568198, 9.824087247413757, 10.768977044932855, 11.765171874171784, 12.690533370156817, 13.567953290487651, 14.474434820566167, 15.44208017970541, 16.397370070804023, 17.366047893597447, 16.502560159873557, 15.481488708234792, 14.458761170053755, 13.572860914294035, 12.646061466641779, 11.72938563069929, 10.728703932982462, 9.714163206535806, 8.770257427246682, 8.0023884874045, 7.823317234225014, 8.813966398631187, 9.774325878500507, 10.837335760920297, 11.809093727748115, 12.635926920768064, 13.50037090049926, 14.481917635096993, 15.485405604914499, 16.490490850587427, 15.49914430332287, 14.552283563182423, 13.521463317523226, 12.622951753423811, 11.694622572701753, 10.702049425360348, 9.743525200398203, 8.784568568164683, 7.75115775338256, 6.994471195954545, 6.822982564171921, 7.768803393269367, 8.816429510623372, 9.875257577458779, 10.805346285812746, 11.561123283204303, 12.495660164318174, 13.518571019120316, 14.491014870004035, 15.491417114624278, 14.545579668036192, 13.523446853991338, 12.562922380649404, 11.678933622717441, 10.691431394049918, 9.729113062912504, 8.780266906744158, 7.765392802834227, 6.7800772629644666, 5.945659511226506, 5.856875915902642, 6.9175291661299045, 7.89955668947945, 8.846577214104919, 9.823987101963585, 10.587908943595021, 11.53219714192539, 12.554013924702048, 13.559045664700779, 14.48946709692271, 13.535177726006328, 12.572444985637386, 11.631440617519852, 10.670783382975817, 9.699659009458752, 8.776247360249384, 7.825084999208934, 6.901415817313536, 5.852831955203601, 4.906878607347967, 4.946445901203316, 5.975601491409317, 6.879092698743556, 7.861711186230968, 8.760394519922706, 9.660776746417955, 10.643164017777497, 11.698742966550377, 12.700192169223975, 13.678299808659718, 12.606703550015775, 11.61330732683963, 10.668297203787048, 9.725864252286057, 8.720034804251236, 7.8217084842955, 6.803063133772747, 5.862210804329353, 4.917643887994994, 3.9516456836201153, 4.074580611344065, 4.908303269547215, 5.86895523421313, 6.8610054617995315, 7.798897195602086, 8.71846084515578, 9.708244197631382, 10.728143333771442, 11.669898739256942, 12.71530422743215, 11.739361360240945, 10.7146154076304, 9.740322384840598, 8.810903548368852, 7.777739610398102, 6.85316612744189, 5.918229183547724, 4.861279409167527, 3.991571042318534, 3.024807242898272], [3.003783570503194, 2.089155799227913, 2.9266469314632584, 3.9175220729358395, 4.879448440622157, 5.817855556270064, 6.845199369888041, 7.860083474615672, 8.799740611814773, 9.824166889560377, 10.87747956574138, 11.799967377026222, 10.733903862914715, 9.725511429978907, 8.718715519655953, 7.730237899535057, 6.772852420561466, 5.912848097602852, 4.911921969993997, 4.013961202463234, 1.9848777928566177, 1.0338514532378895, 1.9361340531592546, 2.8846712743629457, 3.8494190114429987, 4.838653637952809, 5.902082342451071, 6.894078156244717, 7.945840782038126, 9.018227086421483, 9.971622774851362, 10.87106011007748, 9.812250170350458, 8.795822997933188, 7.84311673448462, 6.8612340537855925, 5.847404743072162, 4.919082898407984, 3.8638319741614677, 3.024637003661734, 0.9411551398228913, 0.0, 0.9567595918285905, 1.9229253119922443, 2.9217657447995746, 3.934579389142989, 4.9657819916407115, 5.987670501067655, 7.003333489850034, 8.010588210381028, 9.030801480133299, 9.91736799216249, 8.865097762591247, 7.869122928153552, 6.89482415489179, 5.956191119365666, 5.006332386160921, 3.9536367925667255, 2.938433823078301, 1.986604493406467, 1.9485040041415, 1.011089939121203, 1.94060351313867, 2.86921253264332, 3.908472044192695, 4.917908535834365, 5.866389313286937, 6.857497847689158, 7.8430481978474385, 8.819773588681903, 9.82022463437881, 10.782416223367957, 9.81851294227183, 8.85596450191608, 7.825514195800004, 6.781483866831126, 5.8529652403909935, 4.917847164584285, 3.924268011422746, 2.9711337180876534, 2.874079655565114, 1.9501038610988528, 2.978408917128495, 3.9337309683408943, 4.890733965953035, 5.956542135868238, 6.92035938434669, 7.861062783628564, 8.835174307971812, 9.77941878108578, 10.729058750473948, 11.721785923780507, 10.806848738429505, 9.824678799800386, 8.804343442029586, 7.77911319949749, 6.817403777289754, 5.888540427512552, 4.870130793285665, 3.9278224751570887, 3.8821817489611368, 2.9910709753432734, 3.9244090181084084, 4.849795935752248, 5.833296802573412, 6.860876589748699, 7.798052043539762, 8.766581804736584, 9.767127665606997, 10.694661477236712, 11.640808368892186, 12.59320977014983, 11.63400650922396, 10.705047560888836, 9.727237190963706, 8.747999668265901, 7.837644150181898, 6.848264658382124, 5.7952680876423806, 4.832524808221812, 4.826212491756185, 3.9899063114292463, 4.951088788021364, 5.877213596767744, 6.8040685402243035, 7.831190031827817, 8.772811593023174, 9.805222567537367, 10.787632941548658, 11.636415385158674, 12.66227245485966, 13.59138007793071, 12.699710280178518, 11.709491068098004, 10.679717114392744, 9.767962735347616, 8.74397296621859, 7.702902353108119, 6.694510059551727, 5.761955137984653, 5.837443865040777, 4.972188985349648, 5.933399865172801, 6.908290542349227, 7.8294243891037, 8.857340858764813, 9.749103039914054, 10.786604551470532, 11.750552706433979, 12.577889421769331, 13.534490475128846, 14.523309483896325, 13.680746178421854, 12.625877301550707, 11.575631579786867, 10.604634414878726, 9.675047814778088, 8.736092490426065, 7.685038275268884, 6.6990413678591985, 6.806863005677651, 5.992785779797546, 6.970549545416615, 7.8985871365946405, 8.760185017602732, 9.764729550097547, 10.701010647328186, 11.728268836712902, 12.692839472732407, 13.616103921819413, 14.546533666840618, 15.408861994368632, 14.4702151588359, 13.530816553778168, 12.501505384871193, 11.633055836863967, 10.733197489335737, 9.740270725731087, 8.673453108913874, 7.66647997134428, 7.744942708437876, 6.9795483460619465, 7.950251979422371, 8.894182238667666, 9.723917469290043, 10.708368014391546, 11.681511945615652, 12.623646739220069, 13.667124627227283, 14.561864399132467, 15.51512466365325, 16.350105826001883, 15.411145590923017, 14.464537050592485, 13.496237288996515, 12.595173541328375, 11.73589283439584, 10.686629411380478, 9.661936244537745, 8.647168496527309, 8.791164685228782, 7.988747563627669, 8.932217824718991, 9.92192709338894, 10.657660116582456, 11.63128798621858, 12.699748017934297, 13.67545579166192, 14.596088424504382, 15.52257276088384, 16.490514464712536, 17.38138194561873, 16.43516617545318, 15.51918208072846, 14.453470518286652, 13.602805707466471, 12.61849230674395, 11.606870230616897, 10.64192538276291, 9.663873229199668, 9.747222521875388, 8.935169123268977, 9.912561695563259, 10.899561067827491, 11.697229779830543, 12.587321661766524, 13.519984796297596, 14.465430584069502, 15.496531353408027, 16.421652683660035, 17.401522061528556, 17.39249975313028, 16.524126431171563, 15.672035891514662, 14.63709203213489, 13.79378898529308, 12.943838048051482, 12.024915491079604, 11.094425434051454, 10.59416047699317, 10.740879502443738, 9.90473270619133, 10.958117700668064, 11.932867961305668, 12.714651407671456, 13.646335581341889, 14.467246763120015, 15.494397205907875, 16.463413921951158, 17.424000571462493, 17.390488821125185, 16.464962490985556, 15.477885159461046, 14.676377558867895, 13.60594654510964, 12.722708156748354, 11.921707986216754, 11.019312755849501, 10.108093023929776, 11.054227951773097, 10.796598957292327, 10.84500027576518, 11.865582619055354, 12.833702118814207, 13.667470969761808, 14.592377453484707, 15.432170300438992, 16.36984469653732, 17.42201912576873, 17.560178197834095, 16.53272407166722, 15.568302187498594, 14.541699433505423, 13.65665749862233, 12.670003664216075, 11.71506968454084, 10.867452036759303, 9.9684159535973, 9.129413247520993, 9.998651777805343, 9.823717006391089, 10.765242387236649, 11.710132184755745, 12.706327013994674, 13.631688509979707, 14.509108430310544, 15.41558996038906, 16.383235319528303, 17.338525210626916, 16.520050019121822, 15.561405020050666, 14.5403335684119, 13.517606030230862, 12.632637015023194, 11.705837567370939, 10.78916173142845, 9.850688800289937, 9.006150687984832, 8.062244908695707, 8.943543627227392, 8.764472374047905, 9.755121538454079, 10.715481018323397, 11.778490900743186, 12.750248867571008, 13.577082060590957, 14.441526040322152, 15.423072774919886, 16.426560744737394, 15.598564641055992, 14.557989163499979, 13.611128423359531, 12.580308177700335, 11.68179661360092, 10.754398673430913, 9.761825526089508, 8.849466175785132, 8.04630110981093, 7.043145234831586, 7.935626335777436, 7.7641377039948125, 8.709958533092259, 9.757584650446262, 10.816412717281668, 11.746501425635639, 12.502278423027196, 13.436815304141067, 14.459726158943209, 15.432170009826928, 14.672552751426272, 13.6044245282133, 12.582291714168447, 11.621767240826513, 10.73777848289455, 9.751207494779077, 8.788889163641663, 7.850167255370501, 7.027125344480474, 6.072064744413493, 6.886814651049397, 6.7980310557255335, 7.858684305952796, 8.840711829302341, 9.78773235392781, 10.765142241786478, 11.529064083417914, 12.473352281748284, 13.49516906452494, 14.500200804523672, 13.640972183629104, 12.594022586183439, 11.631289845814496, 10.69028547769696, 9.729628243152925, 8.758503869635861, 7.836023460978543, 6.894985347835276, 6.001990805153564, 5.144819436652627, 5.8480337471708586, 5.887601041026207, 6.916756631232208, 7.820247838566448, 8.80286632605386, 9.701549659745599, 10.601931886240848, 11.58431915760039, 12.63989810637327, 13.641347309046868, 12.737144668836827, 11.665548410192883, 10.672152187016739, 9.727142063964157, 8.784709112463167, 7.778879664428346, 6.880553344472609, 5.87296348239909, 4.932111152955695, 4.1255477531105536, 4.8928008234430065, 5.015735751166956, 5.849458409370106, 6.810110374036022, 7.802160601622424, 8.740052335424977, 9.659615984978673, 10.649399337454275, 11.669298473594335, 12.611053879079835, 11.869773370283328, 10.798206220418054, 9.77346026780751, 8.799167245017706, 7.86974840854596, 6.836584470575211, 5.912010987618999, 4.977074043724833, 3.9201242693446354, 3.059123155593214, 3.9659623827211634], [3.9081996083448103, 2.94922435307188, 1.9698873396346677, 2.960762481107249, 3.922688848793567, 4.861095964441473, 5.888439778059451, 6.903323882787081, 7.842981019986182, 8.867407297731786, 9.920719973912789, 10.911137328264045, 11.690663454743305, 10.682271021807496, 9.675475111484543, 8.686997491363647, 7.729612012390056, 6.869607689431444, 5.868681561822587, 4.918377240304851, 2.941637384685208, 1.99061104506648, 0.9793744613306641, 1.9279116825343552, 2.892659419614408, 3.881894046124218, 4.945322750622481, 5.937318564416127, 6.989081190209536, 8.061467494592891, 9.01486318302277, 9.974905256727922, 10.769009762179046, 9.752582589761776, 8.799876326313209, 7.817993645614182, 6.804164334900752, 5.875842490236574, 4.820591565990058, 3.981396595490324, 1.8979147316514817, 0.9567595918285905, 0.0, 0.9661657201636537, 1.9650061529709841, 2.9778197973143987, 4.009022399812121, 5.030910909239065, 6.046573898021444, 7.053828618552439, 8.07404188830471, 9.004834877093879, 9.821857354419835, 8.825882519982141, 7.8515837467203795, 6.912950711194256, 5.96309197798951, 4.910396384395315, 3.895193414906891, 2.943364085235057, 2.9052635959700908, 1.9678495309497934, 0.9838439213100795, 1.9124529408147297, 2.9517124523641045, 3.961148944005775, 4.909629721458347, 5.900738255860569, 6.886288606018849, 7.863013996853313, 8.86346504255022, 9.931640372574721, 10.77527253410042, 9.81272409374467, 8.782273787628593, 7.738243458659715, 6.809724832219583, 5.8746067564128746, 4.881027603251336, 3.927893309916244, 3.8308392473937047, 2.9068634529274435, 2.039825560855014, 2.976971376512304, 3.9339743741244444, 4.999782544039648, 5.9635997925181, 6.904303191799975, 7.878414716143221, 8.82265918925719, 9.772299158645357, 10.83941848297674, 11.763608330258094, 10.781438391628976, 9.761103033858175, 8.73587279132608, 7.774163369118344, 6.845300019341142, 5.826890385114255, 4.884582066985679, 4.838941340789727, 3.9350635582699525, 2.9858256618349275, 3.911212579478767, 4.8765372107448215, 5.9041169979201085, 6.841292451711173, 7.809822212907993, 8.810368073778408, 9.737901885408123, 10.684048777063596, 11.63645017832124, 12.59076610105255, 11.661807152717426, 10.683996782792295, 9.704759260094491, 8.794403742010488, 7.805024250210716, 6.752027679470972, 5.789284400050404, 5.7829720835847755, 4.933898894355925, 4.059645742747529, 4.938630240494263, 5.847308948395712, 6.874430439999227, 7.816052001194583, 8.848462975708777, 9.830873349720068, 10.679655793330085, 11.705512863031071, 12.63462048610212, 13.616788327273685, 12.666250659926593, 11.636476706221334, 10.72472232717621, 9.700732558047182, 8.65966194493671, 7.651269651380319, 6.718714729813245, 6.794203456869367, 5.916181568276327, 5.0419568198989655, 5.969707186075746, 6.8726647972751085, 7.900581266936222, 8.792343448085463, 9.829844959641942, 10.79379311460539, 11.621129829940742, 12.577730883300257, 13.566549892067735, 14.520454498220317, 13.582636893379298, 12.532391171615458, 11.561394006707317, 10.63180740660668, 9.692852082254657, 8.641797867097475, 7.65580095968779, 7.763622597506241, 6.936778362724225, 6.07910650014278, 7.007144091320805, 7.80342542577414, 8.807969958268956, 9.744251055499594, 10.77150924488431, 11.736079880903816, 12.659344329990823, 13.589774075012029, 14.58891272468573, 15.426974750664492, 14.48757614560676, 13.458264976699784, 12.589815428692559, 11.68995708116433, 10.697030317559678, 9.630212700742465, 8.623239563172872, 8.701702300266467, 7.923540928988626, 7.112081466128075, 8.00273919339383, 8.767157877461452, 9.751608422562954, 10.72475235378706, 11.666887147391478, 12.710365035398691, 13.605104807303878, 14.55836507182466, 15.483538530561702, 16.367905182751606, 15.421296642421076, 14.452996880825106, 13.551933133156966, 12.692652426224432, 11.64338900320907, 10.618695836366337, 9.6039280883559, 9.747924277057374, 8.932740146554348, 8.094047311424694, 9.030484048115104, 9.700900524753864, 10.674528394389988, 11.742988426105706, 12.718696199833328, 13.63932883267579, 14.56581316905525, 15.533754872883945, 16.512581044303914, 16.637050875492633, 15.706705434554841, 14.640993872113036, 13.813377673366643, 12.92587721596129, 12.188324745781577, 11.598684974591501, 10.62063282102826, 10.70398211370398, 9.879161706195656, 9.074391182268961, 10.008118022553656, 10.74047018800195, 11.630562069937932, 12.563225204469004, 13.50867099224091, 14.539771761579436, 15.464893091831442, 16.444762469699963, 16.435740161301688, 15.567366839342974, 14.71527629968607, 13.680332440306298, 12.837029393464487, 11.987078456222893, 11.155673348864767, 11.888796158402362, 11.55092006882176, 11.69763909427233, 10.84872528911801, 10.133116865839561, 11.041424916031833, 11.757891815842862, 12.689575989513298, 13.510487171291423, 14.537637614079284, 15.506654330122569, 16.4672409796339, 16.433729229296596, 15.508202899156965, 14.521125567632456, 13.719617967039303, 12.649186953281049, 11.76594856491976, 10.964948394388164, 10.150070613634664, 10.902463748280685, 11.872033103528251, 11.701014995133944, 11.78899285869186, 11.173792334930608, 12.030634729689915, 12.710711377933215, 13.635617861656115, 14.4754107086104, 15.413085104708731, 16.46525953394014, 16.603418606005505, 15.575964479838634, 14.611542595670004, 13.584939841676833, 12.699897906793737, 11.713244072387484, 10.758310092712247, 9.910692444930714, 9.099173811382462, 9.923783971871902, 10.870353412405857, 10.728133044232706, 11.669658425078266, 12.17674665840068, 13.026931559920879, 13.681537392008362, 14.677583649932128, 15.514946097513675, 16.393485626863175, 16.53196825008666, 15.563290427293234, 14.604645428222076, 13.58357397658331, 12.560846438402272, 11.675877423194603, 10.749077975542347, 9.832402139599857, 8.893929208461348, 8.136908545769995, 8.856615633046617, 9.831882248793633, 9.668888411889522, 10.659537576295696, 11.619897056165014, 12.682906938584804, 13.65643818897168, 14.533841652419547, 15.398285632150742, 16.379832366748477, 15.67107095805024, 14.641805049227402, 13.60122957167139, 12.654368831530942, 11.623548585871745, 10.72503702177233, 9.797639081602322, 8.805065934260917, 7.892706583956541, 7.0895415179823384, 7.837515959182497, 8.823964957343676, 8.66855374183643, 9.614374570933876, 10.662000688287879, 11.720828755123286, 12.652690747036312, 13.459038014855786, 14.393574895969657, 15.416485750771798, 14.676680223139776, 13.715793159597682, 12.647664936384711, 11.625532122339857, 10.665007648997923, 9.78101889106596, 8.794447902950486, 7.832129571813072, 6.893407663541909, 6.070365752651883, 6.866435468764403, 7.791230688891013, 7.70244709356715, 8.763100343794411, 9.790984309326785, 10.738004833952253, 11.721901833615068, 12.485823675246504, 13.430111873576873, 14.45192865635353, 13.614634024022441, 12.684212591800511, 11.637262994354845, 10.674530253985903, 9.73352588586837, 8.772868651324336, 7.801744277807271, 6.879263869149953, 5.938225756006686, 5.045231213324973, 5.939190161003538, 6.752449785012475, 6.792017078867824, 7.850130549644387, 8.777007430395038, 9.759625917882449, 10.658309251574188, 11.558691478069438, 12.54107874942898, 13.59665769820186, 12.787949969935902, 11.780385077008235, 10.708788818364292, 9.715392595188147, 8.770382472135566, 7.827949520634576, 6.822120072599755, 5.923793752644018, 4.9162038905704994, 3.9753515611271046, 4.919918477461463, 5.797216861284623, 5.920151789008573, 6.806218001198697, 7.766869965864612, 8.758920193451013, 9.696811927253567, 10.616375576807263, 11.606158929282865, 12.626058065422924, 11.950974535424278, 10.913013778454737, 9.841446628589463, 8.816700675978918, 7.842407653189115, 6.91298881671737, 5.87982487874662, 4.955251395790408, 4.020314451896242, 2.963364677516045, 3.9191917094371806, 4.87037842056278], [4.86714944656233, 3.9081741912893992, 2.928837177852187, 2.0315884793240384, 2.956523128629913, 3.8949302442778193, 4.922274057895796, 5.937158162623427, 6.876815299822527, 7.901241577568133, 8.954554253749135, 9.944971608100392, 11.011035122211899, 11.648436741971151, 10.641640831648198, 9.653163211527302, 8.69577773255371, 7.835773409595097, 6.834847281986241, 5.87732707852237, 3.907803104848862, 2.956776765230134, 1.9383242995481833, 0.9897870783444921, 1.9264936994507544, 2.9157283259605644, 3.9791570304588264, 4.971152844252472, 6.022915470045882, 7.095301774429237, 8.048697462859117, 9.008739536564267, 10.067549476291287, 10.71874830992543, 9.766042046476864, 8.784159365777835, 7.770330055064406, 6.842008210400228, 5.786757286153712, 4.947562315653978, 2.8640804518151355, 1.9229253119922443, 0.9661657201636537, 0.0, 0.9988404328073304, 2.011654077150745, 3.0428566796484673, 4.064745189075412, 5.080408177857791, 6.0876628983887855, 7.107876168141056, 8.038669156930226, 9.090939386501468, 9.792048240145796, 8.817749466884035, 7.87911643135791, 6.929257698153164, 5.876562104558969, 4.861359135070545, 3.9095298053987113, 3.871429316133744, 2.934015251113447, 1.9500096414737331, 1.0645543671057252, 2.0606776992102143, 2.9949832238421212, 3.943464001294693, 4.934572535696915, 5.920122885855195, 6.896848276689659, 7.897299322386566, 8.965474652411066, 9.929377933507192, 10.778889813908325, 9.748439507792249, 8.70440917882337, 7.775890552383238, 6.840772476576529, 5.84719332341499, 4.894059030079897, 4.797004967557358, 3.873029173091097, 3.0059912810186677, 2.1290728028032992, 3.042939620970554, 4.050941917006123, 4.997434072354446, 5.93813747163632, 6.912248995979567, 7.856493469093535, 8.806133438481702, 9.873252762813085, 10.907870898829433, 11.747604111792631, 10.72726875402183, 9.702038511489734, 8.740329089281998, 7.811465739504796, 6.793056105277909, 5.8507477871493325, 5.805107060953381, 4.901229278433607, 3.9519913819985812, 3.1841195407943688, 3.9855024575909312, 5.013082244766219, 5.950257698557282, 6.900444338770784, 7.844202353614753, 8.771736165244468, 9.717883056899941, 10.670284458157585, 11.660803429695747, 12.589762378030871, 11.650162502955949, 10.670924980258144, 9.760569462174143, 8.771189970374369, 7.718193399634625, 6.755450120214057, 6.749137803748429, 5.90006461451958, 5.025811462911183, 4.211537201809865, 4.956274195241822, 5.983395686845337, 6.925017248040694, 7.9390851015715675, 8.864707629556413, 9.71349007316643, 10.739347142867416, 11.668454765938465, 12.65062260711003, 13.603431546505655, 12.602642426384987, 11.690888047339861, 10.666898278210835, 9.625827665100363, 8.617435371543971, 7.684880449976898, 7.76036917703302, 6.8823472884399814, 6.00812254006262, 5.242614147391348, 5.981630044121219, 7.0095465137823325, 7.901308694931573, 8.920467085504733, 9.827627394441734, 10.654964109777087, 11.611565163136602, 12.60038417190408, 13.554288778056662, 14.548802613542952, 13.498556891779112, 12.52755972687097, 11.597973126770333, 10.65901780241831, 9.607963587261128, 8.621966679851443, 8.729788317669895, 7.902944082887879, 7.045272220306435, 6.296255251515131, 6.91239067262025, 7.916935205115067, 8.853216302345706, 9.880474491730421, 10.845045127749927, 11.693178609827168, 12.623608354848374, 13.622747004522076, 14.518175039292405, 15.453741865770413, 14.424430696863437, 13.555981148856212, 12.656122801327982, 11.663196037723331, 10.596378420906118, 9.589405283336525, 9.66786802043012, 8.889706649152279, 8.07824718629173, 7.291850353588156, 7.876123124307561, 8.860573669409066, 9.833717600633172, 10.775852394237589, 11.819330282244803, 12.638939087140223, 13.592199351661005, 14.517372810398047, 15.456333045476915, 15.619047973472448, 14.63206138123952, 13.909921598344159, 13.13948236506515, 12.609554723372723, 11.58486155652999, 10.570093808519553, 10.714089997221027, 9.898905866718001, 9.060213031588349, 8.31959520830943, 8.809865771599974, 9.783493641236097, 10.851953672951815, 11.82766144667944, 12.748294079521902, 13.599647448891595, 14.56758915272029, 15.546415324140257, 15.670885155328984, 14.74053971439119, 13.674828151949383, 12.847211953202992, 12.175432771837137, 13.147274583999096, 12.564850694755155, 11.586798541191913, 11.670147833867633, 10.84532742635931, 10.040556902432616, 9.297229182747982, 9.849435434848061, 10.739527316784041, 11.672190451315114, 12.61763623908702, 13.648737008425545, 14.573858338677551, 15.518938711017817, 15.469574441138038, 14.601201119179322, 13.749110579522418, 12.714166720142645, 11.870863673300835, 11.23663401209874, 12.114623187082286, 12.847745996619883, 12.517085788985415, 12.663804814435982, 11.814891009281663, 11.099282586003216, 10.330536076226158, 10.866857062688974, 11.798541236359407, 12.619452418137532, 13.646602860925393, 14.615619576968678, 15.576206226480009, 15.467563509132942, 14.542037178993313, 13.554959847468805, 12.75345224687565, 11.683021233117396, 10.799782844756109, 10.214503950264012, 11.109020451852183, 11.861413586498205, 12.830982941745772, 12.659964833351463, 12.755158578855513, 12.139958055094263, 11.31974588988424, 11.819676624779326, 12.744583108502225, 13.58437595545651, 14.52205035155484, 15.574224780786253, 15.637252885841852, 14.60979875967498, 13.645376875506352, 12.618774121513182, 11.733732186630085, 10.74707835222383, 9.792144372548595, 9.160248000806561, 10.058123649599981, 10.882733810089423, 11.829303250623378, 11.687082882450225, 12.628608263295785, 13.142912378564334, 12.316042720115204, 12.790502638854473, 13.786548896778239, 14.623911344359785, 15.502450873709282, 15.565802529923005, 14.59712470712958, 13.638479708058423, 12.617408256419658, 11.594680718238621, 10.70971170303095, 9.782912255378694, 8.866236419436206, 8.143484764337195, 9.095858383987514, 9.815565471264136, 10.790832087011152, 10.627838250107041, 11.618487414513215, 12.578846894382535, 13.24691303532803, 13.81643101338777, 14.718575266497826, 15.597975264426694, 15.646304969836521, 14.704905237886589, 13.675639329063749, 12.635063851507736, 11.688203111367288, 10.657382865708092, 9.758871301608677, 8.831473361438668, 7.838900214097263, 7.142262139832391, 8.048491356199857, 8.796465797400016, 9.782914795561195, 9.627503580053949, 10.573324409151395, 11.6209505265054, 12.679778593340806, 13.611640585253832, 14.42520373501944, 15.359740616133312, 14.682958353859844, 13.710514502976125, 12.749627439434029, 11.681499216221058, 10.659366402176204, 9.69884192883427, 8.814853170902307, 7.828282182786832, 6.865963851649418, 6.142963219417759, 7.029315590869402, 7.825385306981922, 8.750180527108531, 8.661396931784669, 9.72205018201193, 10.749934147544304, 11.696954672169772, 12.688067553778723, 13.451989395410159, 14.396277593740528, 13.653500043857521, 12.64846830385879, 11.71804687163686, 10.671097274191194, 9.708364533822252, 8.767360165704718, 7.806702931160682, 6.835578557643617, 5.9130981489862995, 5.187781311882534, 6.004181051542492, 6.898139999221057, 7.711399623229994, 7.750966917085343, 8.809080387861906, 9.743173150558693, 10.725791638046104, 11.624474971737843, 12.524857198233093, 13.507244469592635, 12.872889976431502, 11.82178424977225, 10.814219356844582, 9.742623098200639, 8.749226875024494, 7.804216751971912, 6.861783800470922, 5.855954352436101, 4.957628032480365, 4.165759446446348, 4.934301399344624, 5.878868315678982, 6.756166699502142, 6.879101627226092, 7.772383721362351, 8.733035686028266, 9.725085913614668, 10.662977647417222, 11.582541296970918, 12.57232464944652, 11.926564220746124, 10.984808815260624, 9.946848058291081, 8.875280908425808, 7.850534955815264, 6.876241933025461, 5.946823096553715, 4.913659158582966, 3.9890856756267543, 3.0911404501130315, 3.922314515733564, 4.8781415476547005, 5.829328258780299], [5.864866028639095, 4.905890773366164, 3.926553759928952, 2.9859173354536312, 1.9576826958225828, 2.896089811470489, 3.9234336250884665, 4.938317729816097, 5.8779748670151974, 6.902401144760803, 7.955713820941806, 8.946131175293063, 10.01219468940457, 11.020587122340379, 11.640481264455527, 10.65200364433463, 9.694618165361039, 8.834613842402428, 7.833687714793571, 6.875043660599135, 4.906643537656192, 3.955539944283912, 2.9360408816249484, 1.987503660421257, 0.9276532666434242, 1.916887893153234, 2.9803165976514965, 3.9723124114451425, 5.024075037238552, 6.096461341621907, 7.049857030051786, 8.009899103756936, 9.068709043483956, 10.085136215901226, 10.764882479284193, 9.782999798585164, 8.769170487871735, 7.840848643207558, 6.785597718961042, 5.946402748461308, 3.862920884622466, 2.9217657447995746, 1.9650061529709841, 0.9988404328073304, 0.0, 1.0128136443434146, 2.044016246841137, 3.065904756268081, 4.08156774505046, 5.088822465581455, 6.109035735333725, 7.039828724122895, 8.092098953694137, 9.088073788131831, 9.816589899691364, 8.87795686416524, 7.928098130960494, 6.875402537366299, 5.860199567877875, 4.908370238206041, 4.870269748941075, 3.932855683920778, 2.9488500742810637, 2.0633947999130555, 1.0618372664028837, 1.9961427910347909, 2.9446235684873625, 3.9357321028895846, 4.921282453047865, 5.898007843882329, 6.898458889579236, 7.966634219603737, 8.930537500699863, 9.893085941055613, 10.747279940599578, 9.7032496116307, 8.774730985190567, 7.839612909383859, 6.84603375622232, 5.892899462887228, 5.795845400364689, 4.871869605898428, 4.004831713825999, 3.05360163441932, 2.044099188163224, 3.0521014841987935, 3.998593639547116, 4.9392970388289905, 5.913408563172237, 6.857653036286205, 7.807293005674373, 8.874412330005754, 9.909030466022102, 10.865239141390806, 11.72610918682916, 10.700878944297065, 9.739169522089329, 8.810306172312126, 7.791896538085239, 6.849588219956663, 6.803947493760711, 5.9000697112409375, 4.9508318148059125, 4.025491485817457, 2.986662024783601, 4.014241811958888, 4.951417265749951, 5.901603905963454, 6.845361920807423, 7.772895732437138, 8.71904262409261, 9.671444025350254, 10.661962996888416, 11.59092194522354, 12.56873231514867, 11.669765413065475, 10.759409894981474, 9.7700304031817, 8.717033832441956, 7.754290553021388, 7.74797823655576, 6.8989050473269105, 6.024651895718515, 5.026326828083759, 3.957433762434492, 4.984555254038006, 5.926176815233363, 6.940244668764238, 7.865867196749084, 8.7146496403591, 9.740506710060085, 10.669614333131134, 11.6517821743027, 12.604591113698325, 13.521212238577709, 12.689728480147192, 11.665738711018166, 10.624668097907694, 9.616275804351302, 8.683720882784229, 8.759209609840351, 7.881187721247312, 6.964223589262403, 5.9543460862964945, 4.982789611313888, 6.010706080975002, 6.902468262124242, 7.921626652697402, 8.828786961634405, 9.656123676969758, 10.612724730329273, 11.60154373909675, 12.555448345249332, 13.60827682081282, 14.497397324586442, 13.526400159678301, 12.596813559577663, 11.65785823522564, 10.60680402006846, 9.620807112658774, 9.728628750477226, 8.78255283164435, 7.788852148484914, 6.860814557306889, 5.91355023981292, 6.918094772307736, 7.854375869538376, 8.881634058923092, 9.846204694942598, 10.694338177019837, 11.624767922041045, 12.623906571714745, 13.519334606485074, 14.458733211542807, 14.627952852557511, 13.873198870001234, 13.654963234135312, 12.662036470530662, 11.59521885371345, 10.588245716143856, 10.666708453237451, 9.76931539790875, 8.816296650593301, 7.835171574094106, 6.8772826915002305, 7.861733236601735, 8.83487716782584, 9.777011961430258, 10.820489849437472, 11.640098654332892, 12.593358918853676, 13.518532377590718, 14.457492612669586, 14.620207540665117, 13.63322094843219, 12.911081165536826, 13.67852010133322, 13.608395156180054, 12.583701989337321, 11.568934241326884, 11.712930430028358, 10.742382161972845, 9.79826249588992, 8.811693377707517, 7.811025338792643, 8.784653208428766, 9.853113240144484, 10.828821013872108, 11.74945364671457, 12.600807016084264, 13.56874871991296, 14.547574891332928, 14.672044722521653, 13.741699281583859, 12.675987719142052, 11.84837152039566, 12.714470508105206, 13.726092584232259, 13.563691127562485, 12.585638973999243, 12.616756833559796, 11.688803721614153, 10.778606366734188, 9.789327352146069, 8.85059500204073, 9.74068688397671, 10.673350018507783, 11.618795806279689, 12.649896575618214, 13.57501790587022, 14.520098278210488, 14.470734008330707, 13.602360686371991, 12.750270146715087, 11.715326287335314, 10.872023240493503, 11.77567174836681, 12.702485576880152, 13.67673888930518, 13.515926221792746, 13.610413814128146, 12.658367304536506, 11.837332050304788, 10.822634245624245, 9.868016629881643, 10.799700803552076, 11.620611985330202, 12.647762428118062, 13.616779144161347, 14.577365793672678, 14.468723076325611, 13.543196746185982, 12.556119414661474, 11.75461181406832, 10.684180800310065, 9.800942411948776, 10.753541686532081, 11.74224206982676, 12.784923218916026, 13.754492574163592, 13.657681415428227, 13.598634874110356, 12.77996355904118, 11.811844059282327, 10.820836191971996, 11.745742675694894, 12.58553552264918, 13.52320991874751, 14.575384347978922, 14.63841245303452, 13.61095832686765, 12.646536442699022, 11.619933688705851, 10.734891753822755, 9.7482379194165, 8.793303939741262, 9.77701144667993, 10.76569882376451, 11.806243442507244, 12.752812883041198, 12.68479946452699, 13.62632484537255, 13.713218531271105, 12.717023702032176, 11.791662206047143, 12.787708463970908, 13.625070911552454, 14.503610440901952, 14.566962097115674, 13.59828427432225, 12.639639275251092, 11.618567823612327, 10.59584028543129, 9.710871270223619, 8.784071822571363, 7.867395986628874, 8.820906718831905, 9.826007754348275, 10.7699135336374, 11.775397600756985, 11.625554832183806, 12.616203996589979, 13.576563476459297, 13.647894017245001, 12.81759058058044, 13.719734833690495, 14.599134831619363, 14.64746453702919, 13.706064805079258, 12.676798896256418, 11.636223418700405, 10.689362678559958, 9.658542432900761, 8.760030868801346, 7.832632928631337, 6.840059781289932, 7.8196840943270995, 8.778640726560619, 9.78103131114585, 10.767480309307029, 10.625220162130713, 11.571040991228159, 12.618667108582162, 13.677495175417569, 13.821338022515809, 14.794538471254256, 14.707028775854655, 13.684117921052513, 12.711674070168794, 11.750787006626698, 10.682658783413727, 9.660525969368873, 8.700001496026939, 7.816012738094976, 6.829441749979501, 5.8671234188420875, 6.820601984754642, 7.850495860439735, 8.809950820727757, 9.747897109185296, 9.659113513861433, 10.719766764088694, 11.747650729621068, 12.694671254246536, 13.686907986586053, 14.450829828217488, 13.676476393826848, 12.65465961105019, 11.64962787105146, 10.719206438829529, 9.672256841383863, 8.709524101014921, 7.768519732897387, 6.8078624983533516, 5.836738124836287, 4.914257716178969, 5.865420077219418, 6.921123188282411, 7.88270551296689, 8.709116205306758, 8.748683499162107, 9.80679696993867, 10.74201358336602, 11.724632070853431, 12.623315404545174, 13.523697631040422, 12.88254274422497, 11.87404954362417, 10.82294381696492, 9.815378924037251, 8.743782665393308, 7.750386442217164, 6.805376319164582, 5.862943367663592, 4.8571139196287705, 3.958787599673034, 4.978014583647063, 5.918866913090458, 6.8634338294248165, 7.753883281578907, 7.876818209302857, 8.77122415416968, 9.731876118835595, 10.723926346421997, 11.661818080224553, 12.581381729778247, 11.947622924078855, 10.927723787938795, 9.985968382453295, 8.948007625483752, 7.876440475618478, 6.851694523007934, 5.877401500218131, 4.9479826637463855, 3.914818725775636, 2.990245242819424, 3.979510581905663, 4.920031097810329, 5.875858129731466, 6.827044840857064], [6.877679672982509, 5.918704417709579, 4.9393674042723665, 3.998730979797046, 2.9704963401659974, 2.0188016472168027, 2.984059405453431, 3.9989435101810615, 4.938600647380162, 5.963026925125767, 6.995069540606146, 7.985486894957403, 9.051550409068911, 10.049744464020321, 10.92497949221366, 11.664817288678046, 10.707431809704454, 9.847427486745842, 8.846501359136985, 7.88785730494255, 5.919457181999607, 4.968353588627327, 3.948854525968363, 3.0003173047646716, 1.9404669109868387, 1.0395997288995475, 2.0339327018332423, 3.0259285156268882, 4.077691141420297, 5.0986059994136275, 6.052001687843507, 7.012043761548658, 8.070853701275679, 9.087280873692949, 9.997851496643007, 10.79581344292858, 9.78198413221515, 8.853662287550973, 7.7984113633044565, 6.959216392804723, 4.87573452896588, 3.934579389142989, 2.9778197973143987, 2.011654077150745, 1.0128136443434146, 0.0, 1.0312026024977223, 2.053091111924666, 3.068754100707045, 4.076008821238039, 5.0962220909903095, 6.0270150797794795, 7.079285309350721, 8.075260143788416, 9.049558917050177, 9.890770508508655, 8.94091177530391, 7.888216181709714, 6.87301321222129, 5.921183882549456, 5.8830833932844895, 4.945669328264192, 3.9616637186244783, 3.048030617163458, 2.008771105614083, 0.9833291466913762, 1.931809924143948, 2.92291845854617, 3.90846880870445, 4.8851941995389145, 5.885645245235821, 6.9538205752603215, 7.917723856356448, 8.880272296712198, 9.910722602828274, 10.716063255974115, 9.787544629533983, 8.852426553727273, 7.858847400565734, 6.905713107230643, 6.8086590447081035, 5.884683250241842, 5.017645358169412, 4.00053547363052, 2.991033027374423, 2.0392878398553784, 2.9857799952037016, 3.926483394485576, 4.900594918828823, 5.844839391942791, 6.794479361330958, 7.86159868566234, 8.896216821678689, 9.85242549704739, 10.87276085481819, 11.71369258864048, 10.751983166432744, 9.823119816655542, 8.804710182428654, 7.862401864300078, 7.816761138104126, 6.847050139107521, 5.897812242672496, 4.972425325028657, 3.9335958639948, 3.0900923661997375, 4.027267819990801, 4.88879026162004, 5.832548276464008, 6.760082088093723, 7.706228979749197, 8.65863038100684, 9.649149352545003, 10.578108300880126, 11.555918670805257, 12.535156193503061, 11.772223539324889, 10.782844047525113, 9.72984747678537, 8.767104197364802, 8.760791880899175, 7.845885475193494, 6.971632323585098, 5.973260667294958, 4.904367601645691, 4.060405808278856, 5.002027369474213, 5.927431024420823, 6.853053552405669, 7.701835996015686, 8.727693065716672, 9.65680068878772, 10.638968529959286, 11.591777469354911, 12.508398594234295, 13.46257774149101, 12.67855235536158, 11.637481742251108, 10.629089448694716, 9.696534527127643, 9.772023254183766, 8.828168149113896, 7.911157428473603, 6.901279925507694, 5.9297234505250875, 5.086556635215851, 5.978318816365092, 6.908813008353988, 7.8159733172909895, 8.643310032626344, 9.599911085985859, 10.588730094753336, 11.542634700905918, 12.595463176469407, 13.581757062349402, 14.516636926546784, 13.609627203921077, 12.670671879569054, 11.619617664411873, 10.633620757002188, 10.741442394820641, 9.72948667085555, 8.735785987696113, 7.807748396518089, 6.860484079024119, 6.128887744690937, 7.044847708375077, 7.912861030361578, 8.835337129934313, 9.681524532676423, 10.611954277697631, 11.611092927371331, 12.50652096214166, 13.445919567199393, 13.809115128557531, 14.77232736660048, 14.667776878478726, 13.674850114874076, 12.608032498056863, 11.60105936048727, 11.679522097580866, 10.71624923711995, 9.7632304898045, 8.782105413305306, 7.82421653071143, 7.072526208984936, 8.028054872516186, 8.88954063742959, 9.904142929409424, 10.627285009989478, 11.580545274510262, 12.505718733247305, 13.444678968326173, 13.801369816665137, 12.81438322443221, 13.810209662136073, 14.691333745676635, 14.621208800523467, 13.596515633680735, 12.581747885670298, 12.723988535007651, 11.689316001184043, 10.745196335101118, 9.758627216918715, 8.757959178003842, 8.136290189893803, 9.076474071859186, 9.94134968987144, 10.833106726686523, 11.58799337174085, 12.555935075569547, 13.534761246989515, 13.78235736120889, 12.922861557583879, 11.857149995142072, 12.807958541837177, 13.727284152448622, 14.738906228575674, 14.576504771905899, 13.598452618342657, 13.563690672770994, 12.635737560825351, 11.725540205945386, 10.736261191357267, 9.797528841251928, 9.092323865441747, 10.02498699997282, 10.931057389814907, 11.783870732316526, 12.609989052208805, 13.507284633867075, 13.581046647017944, 12.712673325059228, 11.931432422715107, 10.896488563335334, 11.845680828719983, 12.788485392710225, 13.715299221223567, 14.689552533648595, 14.51929605116391, 14.557347653339344, 13.605301143747704, 12.784265889515986, 11.769568084835443, 10.81495046909284, 10.151337785017112, 10.972248966795238, 11.973473263496508, 12.80906787362819, 13.612336940011263, 13.579035715012848, 12.65350938487322, 11.66643205334871, 10.935774090068339, 9.865343076310085, 10.813756056292192, 11.766355330875497, 12.755055714170176, 13.797736863259441, 14.767306218507008, 14.670495059771643, 14.545568713321554, 13.726897398252378, 12.758777898493525, 11.767770031183193, 11.09737965715993, 11.937172504114216, 12.874846900212546, 13.796039583595359, 13.70448519056639, 12.677031064399518, 11.756849081386259, 10.730246327393088, 9.916054029822774, 8.92940019541652, 9.806117584084678, 10.789825091023346, 11.778512468107925, 12.819057086850659, 13.765626527384613, 13.697613108870405, 14.639138489715965, 14.660152370482303, 13.663957541243374, 12.73859604525834, 12.150131276588754, 12.97670789301749, 13.855247422366988, 13.633034834647543, 12.664357011854118, 11.70571201278296, 10.728880462299564, 9.706152924118527, 8.892033546223638, 7.965234098571383, 8.880209630972288, 9.83372036317532, 10.83882139869169, 11.782727177980815, 12.7882112451004, 12.638368476527221, 13.629017640933395, 14.589377120802714, 14.594827856456199, 13.764524419791638, 13.08215764630834, 13.950771813084398, 13.708090317394152, 12.76669058544422, 11.742871633788287, 10.702296156232274, 9.799675317247194, 8.768855071587998, 7.88274270454766, 7.013795204631356, 7.852873425633347, 8.832497738670515, 9.791454370904034, 10.793844955489265, 11.780293953650444, 11.638033806474128, 12.583854635571575, 13.63148075292558, 14.690308819760986, 14.768271861727007, 14.156961283872102, 13.767654556219616, 12.744743701417475, 11.772299850533756, 10.816859744158567, 9.748731520945595, 8.77083860805611, 7.810314134714175, 6.93872457384129, 5.99899242982427, 6.879937063185502, 7.833415629098056, 8.863309504783148, 9.822764465071172, 10.760710753528711, 10.671927158204848, 11.73258040843211, 12.760464373964483, 13.707484898589952, 14.676625525617164, 13.68139037252218, 12.737102174191811, 11.715285391415154, 10.710253651416423, 9.779832219194493, 8.732882621748827, 7.7701498813798855, 6.878832371584622, 5.930574334099665, 4.9594499605826, 5.927071360522383, 6.878233721562832, 7.933936832625825, 8.895519157310305, 9.721929849650174, 9.761497143505522, 10.819610614282086, 11.754827227709434, 12.737445715196845, 13.636129048888588, 12.808195858798555, 11.912710875566242, 10.934675323989136, 9.883569597329885, 8.876004704402217, 7.804408445758273, 6.811012222582129, 5.866002099529546, 4.98402509823633, 3.979825755375084, 4.9716012440164485, 5.9908282279904785, 6.931680557433873, 7.876247473768232, 8.766696925922322, 8.889631853646272, 9.784037798513094, 10.744689763179009, 11.736739990765413, 12.674631724567966, 11.86587995753638, 10.977791055420127, 9.967079507603135, 9.025324102117635, 8.00425689078343, 6.937066255983442, 5.912320303372899, 4.938027280583095, 4.00860844411135, 3.0375305615219497, 4.0030588871628385, 4.992324226249078, 5.932844742153744, 6.88867177407488, 7.8398584852004785], [7.892736477434319, 6.9337612221613885, 5.954424208724176, 4.963549067251595, 3.935314427620546, 2.9802006165736863, 1.9528568029557087, 2.967740907683339, 3.9073980448824397, 4.931824322628045, 5.963866938108424, 6.954284292459682, 8.02034780657119, 9.0185418615226, 9.893776889715939, 10.882254509836836, 11.738634412202176, 10.878630089243563, 9.877703961634706, 8.90291410939436, 6.950659784497329, 5.999556191125048, 4.980057128466085, 4.031519907262394, 2.971669513484561, 2.066158803833782, 1.0027300993355197, 1.994725913129166, 3.046488538922575, 4.067403396915906, 5.020799085345786, 5.980841159050937, 7.0396510987779575, 8.056078271195227, 8.966648894145285, 9.939481879361072, 10.813186734712872, 9.884864890048695, 8.829613965802178, 7.990418995302445, 5.906937131463603, 4.9657819916407115, 4.009022399812121, 3.0428566796484673, 2.044016246841137, 1.0312026024977223, 0.0, 1.021888509426944, 2.0375514982093232, 3.0448062187403178, 4.065019488492588, 4.995812477281758, 6.048082706852999, 7.044057541290694, 8.018356314552456, 8.95698935007858, 9.906848083283325, 8.919418784207437, 7.904215814719012, 6.952386485047178, 6.908651959861793, 5.9712378948414955, 4.948380548939716, 4.019771529435066, 2.980512017885691, 1.9550700589629844, 1.0065892815104125, 1.9976978159126344, 2.9832481660709145, 3.959973556905379, 4.960424602602286, 5.984177343102406, 6.948080624198532, 7.910629064554282, 8.941079370670359, 9.968065618664959, 10.818747232031706, 9.883629156224996, 8.890050003063457, 7.931281673807946, 7.834227611285407, 6.910251816819145, 6.001332215042252, 4.972276385902128, 3.962773939646031, 3.011028752126987, 2.060559352570166, 3.0012627518520407, 3.9753742761952875, 4.919618749309255, 5.869258718697423, 6.923547043514956, 7.936416420356205, 8.882782264889475, 9.903117622660275, 10.931121646063467, 11.783185768930466, 10.854322419153263, 9.835912784926377, 8.887970430877381, 8.842329704681429, 7.8187910513791286, 6.869553154944104, 5.944166237300264, 4.905336776266408, 4.042410543222834, 3.105235089431771, 3.9635696189865044, 4.907327633830473, 5.834861445460188, 6.7810083371156615, 7.733409738373306, 8.723928709911467, 9.652887658246591, 10.630698028171722, 11.609935550869526, 12.537268551754517, 11.808412614102417, 10.755416043362674, 9.792672763942106, 9.786360447476477, 8.8176263874651, 7.943373235856706, 6.945001579566565, 5.876108513917298, 5.012723985301952, 4.167445765646711, 5.002210381787288, 5.927832909772134, 6.776615353382151, 7.802472423083136, 8.731580046154185, 9.71374788732575, 10.666556826721376, 11.58317795160076, 12.537357098857477, 13.499522196389576, 12.663050308828412, 11.65465801527202, 10.722103093704947, 10.797591820761069, 9.799909061385502, 8.88289834074521, 7.873020837779301, 6.901464362796695, 6.038874812238948, 5.14373721253759, 5.983592365720453, 6.890752674657454, 7.718089389992809, 8.674690443352324, 9.6635094521198, 10.617414058272384, 11.670242533835872, 12.656536419715867, 13.59141628391325, 14.521002884013889, 13.696240446146358, 12.645186230989177, 11.659189323579492, 11.764412380436896, 10.701227583127158, 9.707526899967721, 8.779489308789696, 7.8322249912957265, 7.081205921714034, 6.210266104547575, 6.987640387728042, 7.910116487300778, 8.75630389004289, 9.686733635064096, 10.685872284737796, 11.581300319508127, 12.52069892456586, 13.550010093472835, 14.537687319931958, 15.465404902627522, 14.70041868145138, 13.633601064634167, 12.626627927064574, 12.693129224653749, 11.687990149391558, 10.73497140207611, 9.753846325576914, 8.795957442983038, 8.024844386008033, 7.193473268688685, 7.964319994796056, 8.978922286775889, 9.702064367355945, 10.655324631876727, 11.58049809061377, 12.519458325692638, 13.295260158333189, 13.754950472416596, 14.750776910120459, 15.656151833131185, 15.646777367100771, 14.622084200258039, 13.607316452247602, 13.69572944727926, 12.661056913455653, 11.716937247372728, 10.730368129190325, 9.72970009027545, 9.0886083669169, 8.241892468031685, 9.016129047237905, 9.907886084052988, 10.662772729107317, 11.630714432936012, 12.60954060435598, 12.751154758711166, 12.223602834266146, 12.797717243126458, 13.748525789821564, 14.692102239903171, 15.703724316030224, 15.602073338483203, 14.624021184919961, 14.535431585042604, 13.607478473096961, 12.697281118216996, 11.708002103628877, 10.769269753523538, 10.044642042464844, 9.203730034962195, 10.005836747181371, 10.85865008968299, 11.684768409575272, 12.58206399123354, 12.54984404452022, 11.681470722561505, 11.16929736865324, 11.83705581131972, 12.78624807670437, 13.753303480164774, 14.680117308678117, 15.654370621103144, 15.49103696343552, 15.529088565610953, 14.577042056019314, 13.756006801787596, 12.741308997107053, 11.78669138136445, 11.103655962040209, 10.150992001784614, 11.048252620862973, 11.883847230994654, 12.68711629737773, 12.547833112515125, 11.622306782375496, 10.635229450850987, 10.103584023032017, 10.805910324294471, 11.778574143746741, 12.731173418330046, 13.719873801624725, 14.76255495071399, 15.732124305961557, 15.67293049632889, 15.517309625593164, 14.698638310523988, 13.730518810765135, 12.739510943454803, 12.049697834183027, 11.115915539103591, 12.00199878338971, 12.870818940961822, 12.673282588068668, 11.645828461901797, 10.725646478888535, 9.699043724895365, 9.055118069032062, 9.869967443400906, 10.770935671539227, 11.754643178477895, 12.743330555562475, 13.783875174305209, 14.730444614839163, 14.700048545427652, 15.641573926273212, 15.631893282753913, 14.635698453514983, 13.71033695752995, 13.10244945361185, 12.155450928006866, 12.982399305544153, 12.601832232149821, 11.633154409356397, 10.67450941028524, 9.697677859801841, 8.674950321620804, 8.031097585432928, 8.90580134655577, 9.845027718426838, 10.798538450629868, 11.803639486146238, 12.747545265435363, 13.75302933255495, 13.65342528097903, 14.644074445385204, 15.604433925254524, 15.566568768727809, 14.736265332063248, 14.034475823331437, 13.129514848073775, 12.67688771489643, 11.735487982946498, 10.711669031290565, 9.671093553734552, 8.768472714749471, 7.737652469090276, 6.956217338494956, 7.954362452615743, 8.817691513087896, 9.797315826125063, 10.756272458358582, 11.758663042943814, 12.745112041104994, 12.653090610925938, 13.598911440023384, 14.646537557377389, 15.55864409888163, 14.626782106968603, 13.62340210963374, 12.736451953721895, 11.713541098919753, 10.741097248036034, 9.785657141660845, 8.717528918447874, 7.739636005558387, 6.779111532216453, 6.012199207788586, 6.9603913991811535, 7.844755150640051, 8.798233716552605, 9.828127592237697, 10.787582552525722, 11.762805966782611, 11.686983962656658, 12.74763721288392, 13.775521178416293, 14.68925521664033, 13.645422923119442, 12.65018777002446, 11.70589957169409, 10.684082788917433, 9.679051048918701, 8.748629616696771, 7.701680019251105, 6.738947278882163, 5.8476297690868995, 5.004048968046962, 5.920848929939484, 6.891889447976932, 7.843051809017381, 8.898754920080375, 9.860337244764855, 10.736986654101983, 10.776553947957332, 11.834667418733895, 12.786029830207156, 13.768648317694566, 12.75147798401063, 11.776993256300834, 10.88150827306852, 9.903472721491411, 8.85236699483216, 7.844802101904493, 6.773205843260551, 5.779809620084406, 4.834799497031824, 3.9528224957386078, 4.941224724731968, 5.936419331470997, 6.955646315445026, 7.896498644888421, 8.84106556122278, 9.781753730374131, 9.904688658098081, 10.815240401010815, 11.77589236567673, 12.767942593263134, 11.892068945726756, 10.834677355038659, 9.946588452922406, 8.935876905105413, 7.994121499619913, 6.97305428828571, 5.90586365348572, 4.881117700875176, 3.906824678085373, 2.9774058416136278, 3.9989295308788333, 4.967876974617387, 5.957142313703626, 6.947901546605554, 7.90372857852669, 8.854915289652288], [8.914624986861263, 7.955649731588332, 6.97631271815112, 5.985437576678539, 4.95720293704749, 4.00208912600063, 2.9747453123826526, 2.108940839336732, 3.0485979765358326, 4.073024254281438, 4.941978428681479, 5.932395783032737, 6.998459297144244, 7.996653352095655, 8.871888380288997, 9.860366000409893, 10.817751479383485, 11.84212407661176, 10.89959247106165, 9.924802618821303, 7.972548293924273, 7.021444700551992, 6.001945637893029, 5.053408416689338, 3.993558022911505, 3.0880473132607262, 2.024618608762464, 1.0592928834747415, 2.032100180488484, 3.0455148874889617, 3.998910575918841, 4.958952649623992, 6.017762589351013, 7.034189761768283, 7.944760384718342, 8.917593369934128, 9.931422680647557, 10.859744525311735, 9.851502475229122, 9.012307504729389, 6.928825640890547, 5.987670501067655, 5.030910909239065, 4.064745189075412, 3.065904756268081, 2.053091111924666, 1.021888509426944, 0.0, 1.015662988782379, 2.0229177093133734, 3.0431309790656433, 3.9739239678548137, 5.026194197426055, 6.02216903186375, 6.996467805125512, 7.935100840651636, 8.884959573856381, 9.937655167450577, 8.926104324145955, 7.974274994474122, 7.9305404692887365, 6.993126404268439, 5.97026905836666, 5.04166003886201, 4.002400527312635, 2.9769585683899282, 2.0284777909373566, 1.067068159989555, 2.031581442573673, 3.0083068334081373, 4.008757879105044, 4.962288833675461, 5.926192114771587, 6.888740555127338, 7.919190861243415, 8.946177109238015, 9.81399348435904, 10.74911156016575, 9.9119385124904, 8.95317018323489, 8.85611612071235, 7.932140326246089, 7.023220724469196, 5.994164895329072, 4.984662449072975, 4.032917261553931, 3.071639131974088, 2.1309357326922136, 3.023707552698046, 3.9679520258120142, 4.917591995200182, 5.9016585340880106, 6.914527910929261, 7.860893755462531, 8.881229113233331, 9.909233136636523, 10.813089346112854, 11.741952695890056, 10.857801294353319, 9.909858940304325, 9.864218214108373, 8.840679560806073, 7.891441664371048, 6.966054746727209, 5.9272252856933525, 4.998947814814562, 4.061772361023498, 3.0932425998266773, 3.955660910333232, 4.883194721962947, 5.8293416136184195, 6.781743014876064, 7.772261986414224, 8.70122093474935, 9.67903130467448, 10.658268827372284, 11.585601828257275, 12.641963034954115, 11.777304552789618, 10.81456127336905, 10.808248956903421, 9.839514896892046, 8.96526174528365, 7.966890088993511, 6.897997023344244, 5.96926125689368, 5.123983037238437, 4.131883362627461, 4.976166186274893, 5.82494862988491, 6.850805699585894, 7.779913322656944, 8.76208116382851, 9.714890103224134, 10.631511228103518, 11.585690375360233, 12.547855472892333, 13.588926086002806, 12.676546524698963, 11.74399160313189, 11.819480330188012, 10.821797570812448, 9.904786850172156, 8.894909347206248, 7.92335287222364, 6.995412083830676, 6.100274484129316, 5.113265346560626, 5.939085951160214, 6.766422666495568, 7.723023719855082, 8.711842728622559, 9.66574733477514, 10.71857581033863, 11.704869696218624, 12.639749560416007, 13.569336160516645, 14.508291484868668, 13.66707474041612, 12.681077833006436, 12.786300889863842, 11.723116092554104, 10.729415409394667, 9.801377818216642, 8.854113500722672, 8.037743193305761, 7.144571557952931, 6.117313368568215, 6.958449763803538, 7.804637166545648, 8.735066911566854, 9.734205561240554, 10.629633596010883, 11.569032201068616, 12.598343369975591, 13.586020596434714, 14.513738179130279, 15.5796567958677, 14.65548957406111, 13.648516436491517, 13.715017734080694, 12.709878658818504, 11.756859911503053, 10.77573483500386, 9.817845952409984, 8.98138165759976, 8.036127769240645, 7.093992975636229, 8.027255563278649, 8.750397643858703, 9.703657908379485, 10.628831367116527, 11.567791602195395, 12.502752697882933, 13.48973929011586, 14.485565727819724, 15.424949163121635, 16.499207791471154, 15.643972709684983, 14.629204961674546, 14.717617956706205, 13.682945422882597, 12.738825756799672, 11.752256638617268, 10.751588599702396, 10.045145638508627, 9.084546968583645, 8.145802028078078, 8.956219360555748, 9.711106005610075, 10.67904770943877, 11.657873880858737, 11.995917992980399, 12.986149177816909, 13.806339804284079, 14.757148350979184, 15.713990749330115, 16.72561282545717, 16.623961847910145, 15.645909694346905, 15.557320094469548, 14.629366982523905, 13.71916962764394, 12.72989061305582, 11.791158262950482, 10.979047670045226, 10.046384535514154, 9.135509728021544, 9.90698336618575, 10.73310168607803, 11.630397267736297, 11.794607278789453, 10.926233956830737, 11.931843712204003, 12.845678372477341, 13.79487063786199, 14.775191989591718, 15.70200581810506, 16.676259130530088, 16.512925472862463, 16.550977075037896, 15.598930565446258, 14.77789531121454, 13.763197506533997, 12.808579890791394, 11.976955451867598, 10.993646502336572, 10.177925601703146, 10.932180507497414, 11.735449573880487, 11.792596346784357, 10.867070016644728, 9.87999268512022, 10.922734808385517, 11.814532885452092, 12.800462653173685, 13.75306192775699, 14.74176231105167, 15.784443460140935, 16.7540128153885, 16.694819005755836, 16.539198135020108, 15.720526819950932, 14.752407320192079, 13.761399452881747, 12.90722176325523, 11.95857003965555, 11.131671764229884, 11.919152217464582, 11.918045822337898, 10.890591696171027, 9.970409713157768, 8.943806959164597, 9.958591879870829, 10.878590004558527, 11.792824180966171, 12.77653168790484, 13.765219064989418, 14.805763683732152, 15.752333124266107, 15.721937054854596, 16.663462435700158, 16.653781792180858, 15.657586962941927, 14.732225466956894, 13.959973382684053, 12.998105428558825, 12.112072286384326, 11.846595466419052, 10.877917643625628, 9.91927264455447, 8.942441094071073, 7.919713555890036, 8.987624460061134, 9.91442390771339, 10.866916227853782, 11.820426960056812, 12.825527995573182, 13.769433774862307, 14.774917841981894, 14.675313790405975, 15.665962954812148, 16.60741770762067, 15.563359175815254, 14.662578722930471, 13.730254921224, 12.905850106422287, 11.906432210855094, 10.98025121721573, 9.956432265559796, 8.915856788003783, 8.013235949018704, 6.982415703359508, 7.9781058479219, 8.976250962042688, 9.83958002251484, 10.819204335552007, 11.778160967785526, 12.780551552370758, 13.767000550531938, 13.674979120352882, 14.620799949450328, 15.649521339743535, 14.590693272908128, 13.658831280995102, 12.65545128366024, 11.90704380968604, 10.943085594878417, 9.985860482305267, 9.030420375930078, 7.962292152717105, 6.984399239827619, 6.023874766485685, 7.03408771721553, 7.982279908608097, 8.866643660066995, 9.82012222597955, 10.850016101664641, 11.809471061952665, 12.784694476209555, 12.708872472083602, 13.769525722310863, 14.668324915292297, 13.721304390666829, 12.677472097145941, 11.682236944050958, 10.83318725815026, 9.88065261424764, 8.923814283187934, 7.9933928509660035, 6.9464432535203375, 5.9837105131513955, 5.092393003356132, 6.025937477473906, 6.942737439366428, 7.913777957403876, 8.864940318444326, 9.920643429507319, 10.882225754191799, 11.758875163528927, 11.798442457384276, 12.856555928160839, 13.73723698048561, 12.7546184929982, 11.729589474583689, 10.755104746873892, 9.859619763641575, 8.884588028457404, 8.002526420160002, 7.024084436341698, 6.017969077529783, 5.0245728543536385, 4.079562731301056, 4.974711005165552, 5.963113234158912, 6.958307840897941, 7.97753482487197, 8.918387154315365, 9.862954070649725, 10.803642239801075, 10.926577167525025, 11.837128910437759, 12.796095881585053, 11.818475618403832, 10.870180436299815, 9.812788845611717, 8.92469994349546, 7.913988395678469, 6.9722329901929685, 5.9511657788587655, 5.135492409897631, 4.110746457287087, 3.1515879123546053, 3.9992943510405716, 5.020818040305777, 5.989765484044331, 6.97903082313057, 7.9697900560324975, 8.925617087953633, 9.876803799079232], [9.930287975643642, 8.971312720370712, 7.991975706933499, 7.001100565460918, 5.972865925829869, 5.0177521147830095, 3.990408301165032, 3.011640135298295, 2.0719829980991946, 3.0666594958944096, 3.926315439899101, 4.9167327942503585, 5.982796308361865, 6.980990363313277, 7.8562253915066185, 8.844703011627514, 9.802088490601106, 10.826461087829381, 11.827387215438238, 10.940465607603683, 8.988211282706652, 8.037107689334372, 7.0176086266754085, 6.069071405471718, 5.009221011693884, 4.103710302043106, 3.040281597544843, 2.068199817499514, 1.016437191706105, 2.029851898706583, 2.983247587136462, 3.943289660841613, 5.002099600568634, 6.018526772985904, 6.929097395935964, 7.9019303811517485, 8.915759691865178, 9.844081536529355, 10.862593299239789, 10.027970493511768, 7.944488629672926, 7.003333489850035, 6.046573898021444, 5.080408177857791, 4.08156774505046, 3.0687541007070456, 2.0375514982093232, 1.015662988782379, 0.0, 1.0072547205309945, 2.027467990283265, 2.9582609790724352, 4.010531208643677, 5.006506043081371, 5.9808048163431335, 6.919437851869257, 7.869296585074003, 8.921992178668198, 9.937195148156622, 8.989937983256501, 8.894640016703175, 7.9572259516828785, 6.934368605781099, 6.005759586276449, 4.966500074727074, 3.941058115804368, 2.992577338351796, 2.001468803949574, 1.0159184537912938, 1.9926438446257582, 2.9930948903226646, 3.9466258448930827, 4.910529125989209, 5.873077566344959, 6.903527872461035, 7.930514120455637, 8.798330495576662, 9.733448571383372, 10.72702772454491, 9.917269730649329, 9.820215668126789, 8.896239873660528, 7.987320271883634, 6.958264442743511, 5.9487619964874145, 4.99701680896837, 4.006039775934107, 3.0653363766522324, 2.0080445639156665, 2.952289037029635, 3.9019290064178023, 4.885995545305633, 5.898864922146882, 6.845230766680151, 7.865566124450952, 8.893570147854144, 9.797426357330476, 10.726289707107679, 11.67289050640783, 10.873958487718763, 10.828317761522811, 9.79671675162687, 8.847478855191843, 7.922091937548003, 6.883262476514147, 5.85568268933886, 4.9185072355477955, 3.949977474350975, 2.9399979215508525, 3.8675317331805674, 4.81367862483604, 5.766080026093684, 6.756598997631845, 7.685557945966969, 8.6633683158921, 9.642605838589905, 10.569938839474895, 11.626300046171735, 12.620572533865392, 11.778660820783488, 11.77234850431786, 10.795552087712842, 9.921298936104446, 8.922927279814305, 7.854034214165038, 6.825996131417978, 5.980717911762735, 4.9704688632158405, 3.9605031974925136, 4.80928564110253, 5.835142710803515, 6.764250333874565, 7.74641817504613, 8.699227114441753, 9.615848239321139, 10.570027386577856, 11.532192484109954, 12.573263097220426, 13.581655390776818, 12.708091150546329, 12.77829376104978, 11.777834761633244, 10.86082404099295, 9.850946538027042, 8.879390063044434, 7.8521469583549734, 6.957009358653614, 5.9518508471490055, 4.923422962377834, 5.750759677713188, 6.707360731072702, 7.696179739840179, 8.650084345992763, 9.702912821556248, 10.689206707436245, 11.62408657163363, 12.553673171734268, 13.49262849608629, 14.543682711243472, 13.645177380420874, 13.742338080684636, 12.679153283374898, 11.685452600215461, 10.757415009037436, 9.810150691543466, 8.870896697656017, 7.934615600425378, 6.907357411040662, 5.942786775021157, 6.788974177763269, 7.719403922784474, 8.718542572458174, 9.613970607228506, 10.553369212286238, 11.582680381193214, 12.570357607652337, 13.498075190347901, 14.563993807085323, 15.532097544888462, 14.612615983905956, 14.671054924901489, 13.665915849639298, 12.712897102323847, 11.731772025824654, 10.773883143230778, 9.799315742937198, 8.826171811713092, 7.884037018108676, 7.0115925744962695, 7.7347346550763225, 8.687994919597106, 9.613168378334148, 10.552128613413016, 11.487089709100555, 12.474076301333483, 13.469902739037346, 14.409286174339258, 15.483544802688776, 16.50823796953151, 15.593304509088984, 15.673655147526999, 14.63898261370339, 13.694862947620466, 12.708293829438063, 11.70762579052319, 10.863079723846065, 9.874591011056092, 8.906435823657318, 7.9405563717733685, 8.695443016827694, 9.66338472065639, 10.642210892076358, 11.576149197943177, 12.558747033167599, 13.43130953062362, 14.382118077318726, 15.366431478041248, 16.3780535541683, 17.34299840202229, 16.610009241761343, 16.51335728529034, 15.585404173344699, 14.675206818464734, 13.685927803876615, 12.747195453771276, 11.769091712517675, 10.836428577986602, 9.896143523600784, 8.891320377403371, 9.717438697295648, 10.614734278953918, 11.055521350656717, 11.8289332527923, 12.834543008165564, 13.748377668438904, 14.697569933823553, 15.735364464144416, 16.66217829265776, 17.636431605082787, 17.468962663683257, 17.50701426585869, 16.55496775626705, 15.733932502035334, 14.719234697354791, 13.764617081612188, 12.766999494340046, 11.783690544809021, 10.885534234758321, 9.916517518715036, 10.719786585098106, 11.04658609711752, 10.127984088511992, 10.782691981081783, 11.82543410434708, 12.717232181413655, 13.760635127726383, 14.713234402309688, 15.701934785604367, 16.751653908553777, 17.721223263801342, 17.709411184118586, 17.4952353258409, 16.676564010771727, 15.708444511012873, 14.711927924299651, 13.697265805727678, 12.748614082127999, 11.839280397285059, 10.903489228682204, 11.014588301568317, 9.987134175401446, 9.147409629134652, 9.84650625512616, 10.861291175832392, 11.78128930052009, 12.781555779747187, 13.765263286685855, 14.753950663770434, 15.794495282513168, 16.741064723047124, 16.736529233217347, 17.5212226125039, 16.474761331484633, 15.478566502245702, 14.642664560084976, 13.64661830216121, 12.864251037706815, 11.850931766681132, 10.94313794564947, 9.974460122856046, 9.015815123784888, 8.119441010047957, 8.822412851851599, 9.890323756022697, 10.817123203674953, 11.855647826634797, 12.80915855883783, 13.8142595943542, 14.758165373643324, 15.789510020344647, 15.690976779188354, 16.64423136577514, 15.591754718838292, 14.547696187032876, 13.646915734148093, 12.714591932441623, 11.890187117639908, 10.890769222072715, 10.031230052859124, 9.052974744790214, 8.012399267234201, 7.135867601354041, 7.885114999321071, 8.883013099887027, 9.881158214007813, 10.828311621295857, 11.807935934333024, 12.766892566566543, 13.79514373073351, 14.78159272889469, 14.690642109135261, 15.611765226393075, 14.633858350961157, 13.57503028412575, 12.643168292212724, 11.639788294877862, 10.891380820903663, 9.927422606096037, 9.03683931794866, 8.110699552114319, 7.058834631947524, 6.092213929527956, 6.926574062447248, 7.938994969180657, 8.939028909784863, 9.855375258848012, 10.808853824760565, 11.838747700445657, 12.824063240315418, 13.799286654572308, 13.724535460865981, 14.680545892042293, 13.65266192650992, 12.705641401884451, 11.661809108363563, 10.66657395526858, 9.817524269367883, 8.864989625465261, 7.974793118831326, 7.044371686609395, 6.042985732750756, 5.080252992381814, 5.995092299317695, 6.95574953386173, 7.926873907378795, 8.902509556184892, 9.853671917225341, 10.909375028288334, 11.897888742974178, 12.774538152311306, 12.814105446166655, 13.744962194332372, 12.721573991703233, 11.738955504215822, 10.713926485801311, 9.739441758091514, 8.843956774859198, 7.868925039675025, 6.986863431377623, 6.00842144755932, 5.114511556760202, 4.121115333584057, 4.982262027262619, 5.959122698912894, 6.964952146947715, 7.9739708296803204, 8.99319781365435, 9.934050143097744, 10.878617059432104, 11.819305228583454, 11.942240156307404, 12.74108485746859, 11.780432892802674, 10.802812629621451, 9.854517447517434, 8.79712585682934, 7.909036954713081, 6.89832540689609, 5.95657000141059, 4.935502790076387, 4.136823641261713, 3.134131478850449, 4.054287208316168, 4.983706044787914, 6.036481029088156, 7.00542847282671, 7.994693811912949, 8.985453044814877, 9.941280076736012, 10.892466787861611], [10.937542696174635, 9.978567440901704, 8.999230427464493, 8.008355285991913, 6.980120646360864, 6.025006835314004, 4.9976630216960265, 4.01889485582929, 3.079237718630189, 2.059404775363415, 2.9190607193681064, 3.909478073719364, 4.975541587830871, 5.973735642782282, 6.848970670975623, 7.8374482910965195, 8.794833770070111, 9.819206367298387, 10.820132494907243, 11.846870091257351, 9.995466003237649, 9.044362409865368, 8.024863347206404, 7.076326126002712, 6.016475732224879, 5.1109650225741, 4.047536318075838, 3.0754545380305087, 2.0236919122370995, 1.0225971781755883, 1.9759928666054676, 2.9360349403106185, 3.9948448800376393, 5.01127205245491, 5.921842675404968, 6.894675660620754, 7.908504971334184, 8.836826815998363, 9.855338578708794, 10.900463825862044, 8.951743350203921, 8.01058821038103, 7.053828618552439, 6.0876628983887855, 5.088822465581455, 4.07600882123804, 3.0448062187403178, 2.0229177093133734, 1.0072547205309945, 0.0, 1.0202132697522701, 1.9510062585414403, 3.0032764881126814, 3.999251322550376, 4.973550095812138, 5.912183131338262, 6.8620418645430075, 7.9147374581372025, 8.929940427625628, 9.88176975729746, 9.901894737234171, 8.964480672213874, 7.941623326312094, 7.0130143068074435, 5.973754795258069, 4.948312836335362, 3.9998320588827903, 3.008723524480568, 2.023173174322288, 1.058675719644815, 2.0591267653417216, 2.9393711243620877, 3.9032744054582134, 4.865822845813964, 5.896273151930041, 6.923259399924641, 7.791075775045666, 8.726193850852376, 9.719773004013915, 10.728355687935995, 10.827470388657785, 9.903494594191525, 8.994574992414629, 7.9655191632745055, 6.956016717018409, 6.0042715294993645, 5.0132944964651, 4.072591097183226, 3.015299284446661, 2.1252143554895104, 3.074854324877678, 3.8787408247746376, 4.891610201615887, 5.837976046149157, 6.8583114039199575, 7.886315427323149, 8.790171636799482, 9.719034986576684, 10.665635785876834, 11.698574503882027, 11.835572482053808, 10.803971472157864, 9.854733575722838, 8.929346658078998, 7.890517197045141, 6.862937409869854, 5.92576195607879, 4.9572321948819695, 3.947252642081847, 3.174155743417426, 4.046819217463111, 4.839670448628219, 5.83018942016638, 6.759148368501504, 7.736958738426634, 8.71619626112444, 9.64352926200943, 10.69989046870627, 11.613317813334396, 12.576061092754964, 12.779603224848856, 11.802806808243837, 10.92855365663544, 9.9301820003453, 8.861288934696033, 7.833250851948972, 6.9879726322937294, 5.977723583746835, 4.9677579180235085, 4.115909651339389, 5.068283303430586, 5.863556055574733, 6.845723896746298, 7.772817536976287, 8.689438661855672, 9.643617809112389, 10.605782906644489, 11.646853519754961, 12.632873239030786, 13.505491422517805, 13.785548481580774, 12.785089482164238, 11.868078761523945, 10.858201258558037, 9.886644783575429, 8.859401678885968, 7.964264079184608, 6.95910556768, 5.930677682908829, 5.057383687950047, 6.013984741309562, 6.7954854615403475, 7.74939006769293, 8.776503244090783, 9.762797129970778, 10.697676994168162, 11.6272635942688, 12.566218918620823, 13.617273133778005, 14.44257765239235, 14.74959280121563, 13.686408003905893, 12.692707320746456, 11.76466972956843, 10.81740541207446, 9.878151418187013, 8.941870320956374, 7.914612131571658, 6.950041495552153, 6.095598188000127, 7.026027933021334, 7.817848294158342, 8.713276328928673, 9.652674933986406, 10.681986102893381, 11.669663329352504, 12.597380912048068, 13.637584229619856, 14.605687967422995, 15.410016255877432, 15.678309645432483, 14.673170570170292, 13.720151822854842, 12.739026746355648, 11.781137863761773, 10.806570463468194, 9.833426532244088, 8.891291738639671, 7.972013600732663, 7.041358665313181, 7.994618929833965, 8.807358047533974, 9.69898357228464, 10.586395430800723, 11.57338202303365, 12.569208460737514, 13.508591896039425, 14.582850524388945, 15.607543691231678, 16.39070478106046, 16.68090986805799, 15.646237334234385, 14.70211766815146, 13.715548549969057, 12.714880511054185, 11.870334444377061, 10.858399650581275, 9.866856849893711, 8.900977398009761, 8.002067027064554, 8.97000873089325, 9.865731748539481, 10.723004156814802, 11.658052754867766, 12.530615252323788, 13.481423799018893, 14.465737199741415, 15.477359275868467, 16.442304123722455, 17.40740951373282, 17.520612005821334, 16.592658893875694, 15.682461538995728, 14.693182524407609, 13.75445017430227, 12.734673472140155, 11.802010337609083, 10.856564549837177, 9.851741403639764, 9.024062707532508, 9.921358289190778, 10.920700787288766, 11.792688192964464, 12.712358220480672, 13.491276684130526, 14.440468949515175, 15.404535959479812, 16.331349787993155, 17.305603100418182, 18.33302046560168, 18.514268986389684, 17.562222476798045, 16.741187222566328, 15.726489417885785, 14.742332809339231, 13.732581253962527, 12.749272304431502, 11.845955260994714, 10.876938544951429, 10.026410595334966, 10.167397367078584, 11.092923697218213, 11.789946701612777, 12.832688824878074, 13.72448690194465, 14.767889848257377, 15.720489122840682, 16.70918950613536, 17.75890862908477, 18.728477984332336, 18.428375223719705, 17.4563104549947, 16.435728111704524, 15.46760861194567, 14.606235853629126, 13.692115201059037, 12.76175196440291, 11.82407756830458, 11.128078115062157, 10.13539957152938, 9.107945445362509, 10.151386810953126, 10.853760975657154, 11.868545896363386, 12.788544021051084, 13.788810500278181, 14.77251800721685, 15.761205384301428, 16.801750003044162, 17.74831944357812, 17.455493272818465, 16.513967891972904, 15.467506610953635, 14.471311781714705, 13.63540983955398, 12.639363581630214, 11.85699631717582, 10.843677046150137, 10.063949215610533, 9.095271392817109, 8.136626393745951, 9.126695730578952, 9.829667572382593, 10.897578476553692, 11.824377924205947, 12.862902547165792, 13.816413279368824, 14.821514314885194, 15.765420094174319, 16.79676474087564, 16.55066600501262, 15.636976645244145, 14.584499998307296, 13.54044146650188, 12.639661013617097, 11.707337211910627, 10.882932397108913, 9.88351450154172, 9.02397533232813, 8.102518567546475, 7.133210537195264, 8.143122321885036, 8.892369719852065, 9.890267820418021, 10.888412934538808, 11.835566341826851, 12.815190654864018, 13.774147287097538, 14.802398451264505, 15.788847449425685, 15.550331334959525, 14.604510505862079, 13.62660363043016, 12.567775563594754, 11.635913571681728, 10.632533574346866, 9.884126100372669, 8.920167885565043, 8.029584597417665, 7.1034448315833245, 6.179645901908587, 7.099468650058951, 7.933828782978242, 8.946249689711651, 9.946283630315857, 10.862629979379006, 11.81610854529156, 12.846002420976651, 13.831317960846413, 14.806541375103302, 14.731790181396974, 13.673291171511297, 12.645407205978923, 11.698386681353455, 10.654554387832567, 9.659319234737584, 8.810269548836889, 7.857734904934267, 6.967538398300332, 6.0371169660784005, 5.163797002711819, 6.087507712912808, 7.002347019848689, 7.963004254392724, 8.93412862790979, 9.909764276715887, 10.860926637756336, 11.916629748819329, 12.905143463505174, 13.7817928728423, 13.756742020565985, 12.737707473801375, 11.714319271172236, 10.731700783684825, 9.706671765270315, 8.732187037560518, 7.836702054328203, 6.8616703191440305, 5.9796087108466285, 5.001166727028325, 4.149052293978256, 5.128370054115051, 5.989516747793614, 6.966377419443888, 7.972206867478709, 8.981225550211317, 10.000452534185346, 10.94130486362874, 11.8858717799631, 12.826559949114447, 12.74551512267277, 11.733830136937595, 10.77317817227168, 9.795557909090457, 8.84726272698644, 7.789871136298343, 6.901782234182087, 5.8910706863650955, 4.9493152808795955, 3.9282480695453925, 3.1295689207307182, 4.141386199381444, 5.061541928847163, 5.990960765318908, 7.043735749619151, 8.012683193357706, 9.001948532443945, 9.99270776534587, 10.948534797267005, 11.899721508392604], [11.83683445346512, 10.970920917960166, 9.991583904522955, 9.000708763050373, 7.972474123419324, 7.017360312372464, 5.990016498754486, 4.975132394026856, 4.035475256827755, 3.0110489790821506, 1.9639135462270834, 2.9543309005783405, 4.020394414689847, 4.968279001200693, 5.828757401223353, 6.817235021344249, 7.77462050031784, 8.798993097546116, 9.799919225154973, 10.826656821505079, 10.926030900370097, 10.064575679617638, 9.045076616958674, 8.096539395754982, 7.036689001977149, 6.1311782923263705, 5.067749587828108, 4.095667807782779, 3.04390518198937, 1.9742413818943239, 1.0208456934644445, 1.9305782987290294, 2.9893882384560504, 4.00581541087332, 4.901629405652698, 5.874462390868484, 6.888291701581914, 7.816613546246092, 8.835125308956522, 9.880250556109772, 9.907005841128766, 9.030801480133299, 8.07404188830471, 7.107876168141056, 6.109035735333725, 5.09622209099031, 4.065019488492588, 3.043130979065644, 2.027467990283265, 1.0202132697522701, 0.0, 0.9307929887891703, 1.9830632183604116, 2.9790380527981064, 3.9533368260598682, 4.8919698615859915, 5.841828594790737, 6.894524188384932, 7.909727157873356, 8.86155648754519, 10.730772132129879, 9.977542747176331, 8.954685401274551, 8.0260763817699, 6.986816870220526, 5.96137491129782, 5.012894133845248, 4.021785599443026, 3.0362352492847458, 2.0595098584502813, 1.0590588127533747, 1.9191578546098178, 2.8830611357059435, 3.845609576061694, 4.8760598821777705, 5.9030461301723705, 6.770862505293396, 7.705980581100105, 8.699559734261644, 9.708142418183725, 11.656347783553493, 10.91655666915398, 10.007637067377086, 8.978581238236963, 7.969078791980866, 7.017333604461822, 6.019869579247857, 5.079166179965982, 4.008158982587562, 3.0639145094735944, 2.114274540085427, 2.8585275550223677, 3.8713969318636168, 4.817762776396886, 5.838098134167687, 6.866102157570879, 7.76995836704721, 8.698821716824412, 9.645422516124563, 10.678361234129756, 12.50619088226337, 11.796831170298764, 10.847593273863739, 9.922206356219899, 8.883376895186043, 7.855797108010755, 6.918621654219691, 5.95009189302287, 4.940112340222748, 4.032386324326334, 3.08623943267086, 3.8194571788759495, 4.80997615041411, 5.738935098749234, 6.716745468674365, 7.69598299137217, 8.623315992257162, 9.679677198954002, 10.593104543582125, 11.555847823002694, 13.450221625058418, 12.795666506384737, 11.921413354776341, 10.9230416984862, 9.854148632836933, 8.826110550089874, 7.98083233043463, 6.957394889109655, 5.947429223386329, 4.974140232248296, 4.107703518638335, 4.843342785822463, 5.825510626994028, 6.752604267224018, 7.669225392103403, 8.62340453936012, 9.58556963689222, 10.626640250002692, 11.612659969278518, 12.485278152765535, 14.450327942947315, 13.77794918030514, 12.860938459664846, 11.851060956698937, 10.87950448171633, 9.85226137702687, 8.95712377732551, 7.938776873042819, 6.880615153084267, 5.915614268858954, 5.069009223612453, 5.775272191788077, 6.72917679794066, 7.756289974338514, 8.74258386021851, 9.677463724415894, 10.607050324516532, 11.546005648868555, 12.597059864025736, 13.42236438264008, 15.41974708358419, 14.679267702046793, 13.685567018887356, 12.757529427709331, 11.810265110215362, 10.821888021867972, 9.885606924637333, 8.858348735252617, 7.893778099233113, 6.953828768909035, 6.081052415324225, 6.7976350244060715, 7.693063059176404, 8.632461664234137, 9.661772833141113, 10.649450059600236, 11.5771676422958, 12.617370959867587, 13.585474697670726, 14.389802986125162, 16.357826786344415, 15.666030268311193, 14.700200913756447, 13.719075837257254, 12.761186954663378, 11.750307067149153, 10.777163135925047, 9.83502834232063, 8.830244181641572, 7.899589246222089, 7.049643412136858, 7.7871447777817036, 8.678770302532369, 9.566182161048454, 10.553168753281382, 11.548995190985245, 12.488378626287156, 13.562637254636677, 14.58733042147941, 15.37049151130819, 17.329581044968325, 16.62628642513599, 15.682166759053066, 14.695597640870663, 13.69492960195579, 12.785090263205902, 11.716630231490184, 10.72508743080262, 9.75920797891867, 8.860297607973461, 8.025033213196142, 8.845518478787211, 9.70279088706253, 10.637839485115498, 11.51040198257152, 12.461210529266625, 13.445523929989147, 14.457146006116199, 15.422090853970186, 16.387196243980547, 18.26841257424233, 17.5727079847773, 16.662510629897334, 15.673231615309215, 14.66265182073029, 13.592904053049065, 12.660240918517992, 11.714795130746086, 10.709971984548673, 9.882293288441415, 8.97638277149367, 9.900487517536495, 10.772474923212192, 11.692144950728403, 12.471063414378257, 13.420255679762906, 14.384322689727544, 15.311136518240886, 16.285389830665913, 17.312807195849413, 18.38232931172016, 17.376364754816276, 16.4561903110433, 15.436605155851483, 14.53884214596721, 13.617943803449586, 12.771528328580864, 11.822676557690293, 11.165577991866948, 10.145767345119193, 10.025850222559765, 10.82802477968122, 11.815102111205729, 12.757858296349626, 13.502208901403506, 14.491336508307633, 15.406452751562272, 16.31673925347099, 17.271722240787593, 18.241291596035158, 17.408161953967436, 16.436097185242428, 15.415514841952254, 14.447395342193401, 13.586022583876858, 12.671901931306769, 11.806604791261886, 10.868930395163556, 10.185333921398577, 9.214642886495147, 10.023044570901435, 11.066485936492052, 11.80999851385472, 12.824783434560953, 13.74478155924865, 14.745048038475748, 15.728755545414415, 16.717442922498996, 17.757987541241732, 18.38563840346415, 16.435280003066197, 15.493754622220635, 14.447293341201366, 13.451098511962437, 12.61519656980171, 11.619150311877945, 10.857444115039073, 9.888529873009114, 9.121205021946952, 8.152527199153528, 9.051725519284878, 10.054723530077698, 10.78590511058016, 11.853816014751258, 12.780615462403514, 13.819140085363358, 14.772650817566388, 15.777751853082759, 16.721657632371883, 17.382299215938897, 15.530452735260349, 14.616763375491876, 13.564286728555027, 12.520228196749612, 11.619447743864828, 10.687123942158358, 9.883380194972165, 8.928367328400697, 8.068828159187106, 7.147371394405451, 8.04830966273419, 9.07115012138378, 9.84860725804963, 10.846505358615588, 11.844650472736374, 12.791803880024416, 13.771428193061583, 14.730384825295102, 15.75863598946207, 16.576296431836205, 14.530118065207256, 13.58429723610981, 12.606390360677892, 11.547562293842486, 10.61570030192946, 9.612320304594597, 8.87866945879108, 7.965020712424019, 7.074437424276642, 6.148297658442301, 7.094745027447512, 8.027496449557695, 8.890066321175809, 9.902487227909218, 10.902521168513424, 11.818867517576571, 12.772346083489124, 13.802239959174216, 14.787555499043977, 15.551816287117125, 13.71373115198629, 12.653077901759028, 11.625193936226655, 10.678173411601186, 9.634341118080298, 8.639105964985315, 7.804812907255299, 6.902587731793243, 6.012391225159308, 5.081969792937377, 6.0788961282507445, 7.015535512411552, 7.9585845580462555, 8.91924179259029, 9.890366166107354, 10.866001814913451, 11.8171641759539, 12.872867287016893, 13.871778283020053, 14.663728460540964, 12.736528750813715, 11.717494204049107, 10.694106001419968, 9.711487513932557, 8.686458495518046, 7.7119737678082485, 6.831245412746613, 5.906523146003007, 5.024461537705605, 4.046019553887302, 5.064151419517182, 6.056397853613795, 6.94575428599118, 7.922614957641454, 8.928444405676276, 9.947860369726195, 10.967087353700224, 11.907939683143619, 12.852506599477978, 13.710987273689963, 11.7253018529205, 10.713616867185324, 9.752964902519409, 8.775344639338188, 7.82704945723417, 6.769657866546073, 5.896325592600498, 4.935923513224072, 3.994168107738572, 2.9731008964043695, 4.044668046269644, 5.069413998880187, 6.017779467044729, 6.947198303516474, 8.015236385737456, 9.005036670416164, 9.994302009502404, 10.985061242404331, 11.940888274325467, 12.78414883296812], [10.906041464675948, 11.865016719948878, 10.922376893312123, 9.931501751839543, 8.903267112208495, 7.948153301161635, 6.920809487543657, 5.905925382816027, 4.966268245616926, 3.941841967871321, 2.8947065350162537, 2.0620650987529214, 3.0956693737772825, 4.037486012411523, 4.897964412434182, 5.8864420325550775, 6.843827511528668, 7.868200108756945, 8.869126236365801, 9.895863832715907, 9.99523791158093, 10.951219445400378, 9.975869605747844, 9.027332384544152, 7.967481990766319, 7.06197128111554, 5.998542576617278, 5.026460796571949, 3.97469817077854, 2.9050343706834942, 1.951638682253615, 0.9997853099398591, 2.05859524966688, 3.07502242208415, 3.9708364168635275, 4.943669402079314, 5.957498712792744, 6.885820557456922, 7.904332320167353, 8.949457567320604, 8.976212852339597, 9.917367992162488, 9.004834877093879, 8.038669156930226, 7.039828724122895, 6.02701507977948, 4.995812477281758, 3.9739239678548137, 2.958260979072435, 1.9510062585414403, 0.9307929887891703, 0.0, 1.0522702295712414, 2.048245064008936, 3.022543837270698, 3.9611768727968215, 4.911035606001567, 5.963731199595762, 6.978934169084186, 7.93076349875602, 9.799979143340709, 10.737393208361006, 9.88547839006372, 8.95686937055907, 7.917609859009696, 6.8921679000869895, 5.943687122634418, 4.952578588232196, 3.967028238073916, 2.9903028472394517, 1.989851801542545, 0.9883648658206475, 1.9522681469167733, 2.914816587272524, 3.9452668933886, 4.9722531413832005, 5.840069516504226, 6.775187592310935, 7.768766745472474, 8.777349429394555, 10.725554794764323, 11.674516414627847, 10.938430056166256, 9.909374227026133, 8.899871780770036, 7.945746426751122, 6.900448929727009, 5.959745530445135, 4.888738333066715, 3.944493859952747, 2.9948538905645794, 1.9277345662331973, 2.940603943074447, 3.886969787607716, 4.907305145378516, 5.935309168781708, 6.83916537825804, 7.768028728035242, 8.714629527335394, 9.747568245340586, 11.5753978934742, 12.571465124705627, 11.622227228270601, 10.696840310626762, 9.658010849592905, 8.630431062417617, 7.693255608626554, 6.724725847429734, 5.714746294629611, 4.787212482999896, 3.8410655913444227, 2.888664190086779, 3.8791831616249404, 4.808142109960064, 5.785952479885195, 6.765190002583, 7.692523003467992, 8.748884210164832, 9.662311554792955, 10.625054834213524, 12.519428636269248, 13.533600685225068, 12.696047309183204, 11.697675652893063, 10.628782587243796, 9.600744504496737, 8.755466284841495, 7.712221047783218, 6.702255382059891, 5.728966390921859, 4.841657420104343, 3.912549797033293, 4.894717638204858, 5.821811278434848, 6.738432403314233, 7.692611550570949, 8.65477664810305, 9.695847261213522, 10.681866980489346, 11.554485163976365, 13.519534954158145, 14.51588335914547, 13.635572414071708, 12.6256949111058, 11.654138436123192, 10.626895331433733, 9.731757731732374, 8.693603031716382, 7.6354413117578295, 6.670440427532517, 5.8029631250784615, 4.844479202998907, 5.79838380915149, 6.825496985549344, 7.81179087142934, 8.746670735626722, 9.67625733572736, 10.615212660079383, 11.666266875236564, 12.49157139385091, 14.48895409479502, 15.450261304867784, 14.456560621708347, 13.528523030530321, 12.581258713036352, 11.576714180541536, 10.640433083310898, 9.613174893926182, 8.648604257906676, 7.7086549275825975, 6.8150063167902335, 5.8668420356169015, 6.762270070387234, 7.701668675444967, 8.730979844351943, 9.718657070811066, 10.64637465350663, 11.686577971078416, 12.654681708881554, 13.459009997335992, 15.427033797555245, 16.42573070579044, 15.455027072430013, 14.473901995930818, 13.516013113336943, 12.505133225822718, 11.531989294598612, 10.589854500994194, 9.585070340315134, 8.654415404895651, 7.781525247729577, 6.856351788992534, 7.7479773137432, 8.635389172259284, 9.622375764492212, 10.618202202196075, 11.557585637497986, 12.631844265847505, 13.656537432690238, 14.43969852251902, 16.398788056179157, 17.38111258380956, 16.436992917726634, 15.450423799544229, 14.449755760629355, 13.539916421879465, 12.471456390163747, 11.479913589476183, 10.514034137592233, 9.615123766647024, 8.756915048788862, 7.914725489998041, 8.771997898273362, 9.707046496326328, 10.57960899378235, 11.530417540477455, 12.514730941199977, 13.526353017327029, 14.491297865181016, 15.456403255191379, 17.33761958545316, 17.415135348949455, 16.577738818058684, 15.539119060540488, 14.625470785018951, 13.74616473423578, 12.826524493577864, 11.972826629546477, 11.377910661027034, 10.637119447114978, 9.70826460708639, 8.969694528747326, 9.841681934423024, 10.761351961939233, 11.540270425589087, 12.489462690973737, 13.453529700938374, 14.380343529451716, 15.354596841876743, 16.382014207060244, 17.451536322930988, 16.445571766027104, 15.525397322254129, 14.505812167062311, 13.608049157178039, 12.687150814660415, 11.879262526755445, 10.930410755864875, 10.352713519715369, 11.076560333908365, 10.757732058152484, 9.89723179089205, 10.884309122416559, 11.827065307560456, 12.571415912614336, 13.560543519518463, 14.475659762773102, 15.385946264681818, 16.34092925199842, 17.310498607245986, 16.47736896517826, 15.505304196453256, 14.484721853163082, 13.51660235340423, 12.655229595087686, 11.741108942517597, 10.914338989436468, 9.976664593338137, 9.3657418097482, 10.145435875284317, 10.953837559690605, 10.87780625026939, 11.820494848372181, 12.835279769078413, 13.507358793507901, 14.531623737567214, 15.515331244505882, 16.43684306693402, 17.319609028407204, 17.454845414674974, 15.504487014277023, 14.562961633431463, 13.516500352412194, 12.520305523173265, 11.684403581012539, 10.688357323088773, 9.926651126249904, 8.996264071183695, 8.301612910296576, 9.083320187942698, 9.982518508074048, 10.985516518866866, 11.716698099369328, 12.784609003540426, 13.711408451192682, 14.74993307415253, 15.70344380635556, 16.70854484187193, 17.488666880923297, 16.451506227149725, 14.599659746471177, 13.685970386702705, 12.633493739765855, 11.58943520796044, 10.688654755075657, 9.756330953369186, 8.952587206182995, 8.036101526575278, 7.241568094888607, 8.078164383194622, 8.97910265152336, 10.001943110172949, 10.7794002468388, 11.777298347404757, 12.775443461525544, 13.722596868813588, 14.702221181850755, 15.661177814084274, 16.567327203002936, 15.645503443047033, 13.599325076418085, 12.653504247320638, 11.67559737188872, 10.616769305053314, 9.684907313140288, 8.681527315805425, 7.947876470001909, 7.072754910598601, 6.247177359978142, 7.079090647231471, 8.025538016236682, 8.958289438346863, 9.820859309964979, 10.833280216698387, 11.833314157302594, 12.749660506365743, 13.703139072278296, 14.733032947963387, 15.596246712584843, 14.621023298327954, 12.782938163197118, 11.722284912969856, 10.694400947437483, 9.747380422812014, 8.703548129291127, 7.708312976196144, 6.8740199184661295, 6.010321929967825, 5.185131160860808, 6.012762781726547, 7.0096891170399145, 7.946328501200722, 8.889377546835426, 9.850034781379462, 10.821159154896526, 11.796794803702623, 12.747957164743072, 13.803660275806065, 14.678888819607426, 13.732935471751793, 11.805735762024543, 10.786701215259935, 9.763313012630796, 8.780694525143385, 7.7556655067288744, 6.781180779019078, 5.900452423957443, 5.014257344177588, 4.132195735880186, 4.976812542676472, 5.994944408306352, 6.987190842402965, 7.876547274780351, 8.853407946430625, 9.859237394465445, 10.878653358515365, 11.897880342489394, 12.838732671932789, 13.74619248927567, 12.78019428490079, 10.794508864131329, 9.782823878396153, 8.822171913730237, 7.844551650549016, 6.8962564684449985, 5.838864877756902, 4.965532603811328, 4.043657711398653, 3.1019023059131534, 3.90389388519354, 4.975461035058814, 6.000206987669357, 6.9485724558339, 7.877991292305645, 8.946029374526628, 9.935829659205336, 10.925094998291575, 11.9158542311935, 12.834984076314178, 11.853355844178948], [9.853771235104709, 10.81274649037764, 11.791744694054504, 10.983771981410783, 9.955537341779735, 9.000423530732876, 7.973079717114898, 6.958195612387268, 6.018538475188167, 4.994112197442562, 3.946976764587495, 3.1143353283241626, 2.052289749785935, 2.9941063884201755, 3.845694182862941, 4.834171802983837, 5.791557281957428, 6.815929879185704, 7.816856006794561, 8.843593603144669, 8.942967682009687, 9.898949215829136, 10.801231815750501, 10.079602614115393, 9.01975222033756, 8.11424151068678, 7.050812806188518, 6.07873102614319, 5.026968400349781, 3.9573046002547354, 3.003908911824856, 2.0520555395111004, 1.0152156256755327, 2.0316427980928027, 2.9185661872922863, 3.891399172508072, 4.905228483221502, 5.83355032788568, 6.852062090596112, 7.8971873377493615, 7.9239426227683545, 8.865097762591246, 9.821857354419837, 9.090939386501466, 8.092098953694135, 7.079285309350721, 6.048082706852998, 5.0261941974260544, 4.010531208643676, 3.0032764881126814, 1.9830632183604116, 1.0522702295712414, 0.0, 0.9959748344376946, 1.9702736076994567, 2.9089066432255803, 3.858765376430326, 4.911460970024521, 5.926663939512945, 6.878493269184779, 8.747708913769468, 9.685122978789765, 10.707980324691546, 9.958619070065161, 8.919359558515787, 7.893917599593079, 6.945436822140508, 5.954328287738286, 4.968777937580006, 3.9920525467455414, 2.9916015010486348, 1.9234261710241343, 0.9595228899280085, 1.9220713302837589, 2.952521636399835, 3.91998291181196, 4.7877992869329855, 5.722917362739695, 6.716496515901234, 7.725079199823314, 9.673284565193082, 10.622246185056607, 11.65055124108625, 10.911123926532223, 9.901621480276127, 8.880807731954608, 7.835510234930496, 6.894806835648621, 5.823799638270201, 4.879555165156233, 3.929915195768066, 2.862795871436684, 1.947858686085682, 2.894224530618951, 3.914559888389751, 4.942563911792943, 5.7868951486868, 6.715758498464002, 7.662359297764153, 8.695298015769346, 10.52312766390296, 11.584867354382116, 12.534105250817142, 11.631901615830248, 10.593072154796392, 9.565492367621104, 8.62831691383004, 7.65978715263322, 6.649807599833098, 5.722273788203383, 4.776126896547909, 3.8237254952902657, 2.974631654808843, 3.903590603143967, 4.840421503407233, 5.819659026105039, 6.74699202699003, 7.714183484871615, 8.610041325221715, 9.572784604642283, 11.467158406698008, 12.481330455653827, 13.442512932245945, 12.63273695809655, 11.563843892447283, 10.535805809700223, 9.690527590044981, 8.647282352986704, 7.637316687263378, 6.664027696125346, 5.77671872530783, 4.84761110223678, 4.040335425763402, 4.917259771618751, 5.792901426836272, 6.747080574092988, 7.709245671625088, 8.69004542227151, 9.629596750918108, 10.502214934405124, 12.467264724586904, 13.46361312957423, 14.424824009397382, 13.560756216309287, 12.589199741326679, 11.56195663663722, 10.66681903693586, 9.628664336919869, 8.570502616961317, 7.605501732736004, 6.738024430281948, 5.779540508202394, 5.073496396476244, 5.9209454787332465, 6.866259894951378, 7.801139759148761, 8.730726359249399, 9.669681683601421, 10.680158450355593, 11.43930116427967, 13.43668386522378, 14.484209924022128, 15.391621926911832, 14.463584335733806, 13.516320018239837, 12.511775485745021, 11.575494388514382, 10.548236199129667, 9.583665563110161, 8.643716232786083, 7.75006762199372, 6.801903340820388, 6.037382657711988, 6.949013631398804, 7.792133700035704, 8.779810926494827, 9.707528509190391, 10.741046994600454, 11.668573284000583, 12.406739767764751, 14.374763567984004, 15.379902643246195, 16.35060627660662, 15.408963301134303, 14.451074418540427, 13.440194531026203, 12.467050599802096, 11.52491580619768, 10.520131645518621, 9.589476710099138, 8.716586552933062, 7.79141309419602, 7.023089901067954, 7.88273412821312, 8.786865604161026, 9.741928630959235, 10.681312066261146, 11.735334905775519, 12.705470027804772, 13.38742829294778, 15.346517826607917, 16.381190360431525, 16.505812459331707, 15.464482805407798, 14.612770218695797, 13.649928180212482, 12.749178156631455, 11.923350425613025, 11.44909544279572, 10.55018507185051, 9.691976353992347, 8.849786795201528, 8.047110485598116, 8.954391452280165, 9.744098833451163, 10.694907380146269, 11.64536165948916, 12.656983735616212, 13.621928583470199, 14.404133025620139, 16.29002565180656, 16.362865119378217, 15.525468588487442, 14.486848830969246, 13.573200555447709, 12.693894504664538, 11.787340589700946, 10.933642725669559, 11.885440709342905, 11.572180752318465, 10.643325912289875, 9.904755833950812, 9.116794521747778, 10.00869691789307, 10.704760265257901, 11.65395253064255, 12.584160419227556, 13.510974247740899, 14.485227560165926, 15.334420273413642, 16.399266093359746, 15.393301536455864, 14.473127092682887, 13.45354193749107, 12.555778927606797, 11.634880585089173, 10.840078622878528, 9.891226851987957, 10.860243568031242, 11.874288027164479, 11.69279336335597, 10.832293096095537, 10.163035793458295, 11.074410263514293, 11.73590575228315, 12.725033359187277, 13.606290481062285, 14.516576982971001, 15.471559970287604, 16.33729959240717, 15.425098735607019, 14.453033966882014, 13.43245162359184, 12.464332123832987, 11.602959365516444, 10.688838712946355, 9.87515508555955, 8.93748068946122, 9.976498957857014, 10.943163568540433, 11.81101193188653, 11.812867555472877, 11.099221519413918, 12.11400644012015, 12.671848633176715, 13.696113577236028, 14.660546430519735, 15.567473785223203, 16.450239746696386, 16.402575185103732, 14.452216784705781, 13.510691403860221, 12.464230122840952, 11.468035293602023, 10.632133351441297, 9.636087093517531, 8.883271502258555, 7.957080167306778, 8.91237005840539, 9.881047881198814, 10.839692880269972, 11.89129947247564, 12.123314922688479, 13.138026923719284, 13.636014730021852, 14.622021530348418, 15.636174240974077, 16.529739050835673, 16.436396651352055, 15.399235997578483, 13.547389516899935, 12.633700157131463, 11.581223510194613, 10.537164978389198, 9.636384525504415, 8.704060723797944, 7.909207582191648, 6.99691762269836, 8.000405592515866, 8.971992799779644, 9.922954330240682, 10.971355237957992, 11.831670476410041, 12.829568576975998, 13.827713691096784, 14.774867098384828, 15.754491411421995, 16.54846778821382, 15.515056973431694, 14.593233213475791, 12.547054846846843, 11.601234017749396, 10.623327142317478, 9.564499075482072, 8.632637083569046, 7.629257086234184, 6.904496846010562, 6.033571006721682, 7.006014857605401, 7.9729190638164935, 8.969389694954003, 9.928234473272319, 10.873129539536219, 11.885550446269628, 12.885584386873834, 13.801930735936983, 14.755409301849536, 15.529292022883363, 14.543976483013601, 13.568753068756711, 11.730667933625876, 10.670014683398614, 9.642130717866241, 8.695110193240772, 7.651277899719886, 6.656042746624903, 5.830640294474782, 4.971138026090906, 5.9761697660896385, 6.9065911983115695, 7.9535407957572355, 8.916273536126177, 9.941647776406667, 10.902305010950702, 11.873429384467766, 12.849065033273863, 13.800227394314312, 14.675202452146118, 13.626618590036184, 12.68066524218055, 10.753465532453303, 9.734430985688695, 8.711042783059556, 7.728424295572145, 6.703395277157633, 5.7289105494478365, 4.857072799966096, 3.9750734403006702, 4.9765226429742695, 5.984087535901937, 7.047214637877594, 8.039461071974207, 8.928817504351592, 9.905678176001867, 10.911507624036688, 11.930923588086607, 12.950150572060636, 13.638489176038789, 12.69392225970443, 11.72792405532955, 9.742238634560088, 8.730553648824912, 7.769901684158997, 6.792281420977775, 5.843986238873758, 4.786594648185661, 3.9221529798199803, 3.0044738075217357, 3.946229213007236, 4.956164114764781, 6.027731264630056, 7.052477217240599, 8.000842685405141, 8.930261521876886, 9.998299604097868, 10.988099888776576, 11.977365227862816, 12.78522203193588, 11.78271384674294, 10.801085614607707], [8.857796400667013, 9.816771655939943, 10.795769859616808, 11.78664500108939, 10.95151217621743, 9.99639836517057, 8.969054551552592, 7.954170446824962, 7.014513309625862, 5.990087031880257, 4.942951599025189, 4.092795459022574, 3.0267319449110675, 2.0183395119752583, 2.8497193484252463, 3.8381969685461423, 4.795582447519734, 5.81995504474801, 6.8208811723568665, 7.847618768706973, 7.946992847571992, 8.90297438139144, 9.805256981312805, 10.753794202516497, 10.015727054775255, 9.110216345124476, 8.046787640626214, 7.0747058605808855, 6.022943234787476, 4.95327943469243, 3.999883746262551, 3.0480303739487953, 2.0111904601132276, 1.0558759216478857, 1.9225913528545917, 2.8954243380703772, 3.9092536487838077, 4.837575493447986, 5.856087256158417, 6.901212503311666, 6.927967788330659, 7.86912292815355, 8.825882519982141, 9.792048240145794, 9.08807378813183, 8.075260143788416, 7.0440575412906945, 6.022169031863751, 5.006506043081371, 3.9992513225503767, 2.9790380527981064, 2.048245064008936, 0.9959748344376946, 0.0, 0.974298773261762, 1.9129318087878855, 2.8627905419926307, 3.915486135586826, 4.93068910507525, 5.882518434747084, 7.751734079331771, 8.689148144352068, 9.712005490253848, 10.640614509758498, 9.910121408160286, 8.884679449237579, 7.936198671785006, 6.945090137382785, 5.959539787224505, 4.98281439639004, 3.9823633506931335, 2.914188020668633, 1.9502847395725071, 0.9877362992167565, 1.9942047292033553, 2.924008077374265, 3.7918244524952898, 4.726942528301999, 5.720521681463538, 6.729104365385618, 8.677309730755384, 9.626271350618909, 10.654576406648552, 11.683632235788675, 10.892383329920627, 9.871569581599108, 8.826272084574995, 7.88556868529312, 6.8145614879147, 5.870317014800732, 4.920677045412565, 3.8535577210811827, 2.9386205357301804, 1.9598894995519487, 2.973033975432938, 3.9851529394800522, 4.790920314249105, 5.7197836640263064, 6.666384463326457, 7.69932318133165, 9.527152829465264, 10.58889251994442, 11.538130416379445, 12.463517334023285, 11.583834004440892, 10.556254217265606, 9.619078763474542, 8.650549002277721, 7.6405694494775975, 6.713035637847883, 5.766888746192409, 4.814487344934765, 3.9069879631352515, 2.9780290148001276, 3.89889559045042, 4.878133113148225, 5.805466114033216, 6.71820865043392, 7.614066490784019, 8.576809770204587, 10.471183572260312, 11.485355621216131, 12.446538097808249, 13.453532575715824, 12.554605742091782, 11.526567659344725, 10.681289439689483, 9.638044202631205, 8.628078536907879, 7.654789545769845, 6.767480574952329, 5.838372951881279, 4.9726917340898105, 3.991698183274911, 4.851375513879458, 5.805554661136174, 6.767719758668274, 7.694070587833815, 8.633621916480411, 9.506240099967428, 11.471289890149208, 12.467638295136533, 13.428849174959685, 14.438726677925594, 13.579961590971179, 12.552718486281721, 11.657580886580362, 10.61942618656437, 9.561264466605817, 8.596263582380503, 7.728786279926448, 6.7703023578468935, 6.005852704802653, 4.995383890389407, 5.924733981994565, 6.859613846191948, 7.789200446292586, 8.728155770644609, 9.684183615917897, 10.443326329841973, 12.440709030786083, 13.488235089584432, 14.4659988552035, 15.394036446381525, 14.507081867884336, 13.50253733538952, 12.566256238158882, 11.538998048774166, 10.57442741275466, 9.634478082430583, 8.74082947163822, 7.792665190464888, 6.962850648112698, 6.023452043054965, 6.85060778707889, 7.838285013538013, 8.766002596233578, 9.799521081643642, 10.672598449562887, 11.410764933327055, 13.378788733546308, 14.3839278088085, 15.354631442168925, 15.496252825691377, 14.550538031550516, 13.717717326683657, 12.869482285131818, 12.515677655842179, 11.51089349516312, 10.580238559743638, 9.707348402577562, 8.78217494384052, 7.9037810801998125, 6.957172539869281, 7.845339691204213, 8.80040271800242, 9.739786153304332, 10.793808992818706, 11.709495193367076, 12.391453458510084, 14.35054299217022, 15.385215525993829, 15.509837624894017, 14.468507970970103, 13.616795384258104, 12.65395334577479, 11.821063085788818, 12.794379006573681, 12.43985729244022, 11.54094692149501, 10.682738203636847, 9.840548644846027, 8.927801664729975, 8.028829863936325, 8.80257292049435, 9.753381467189456, 10.703835746532345, 11.715457822659397, 12.680402670513384, 13.408158191182443, 15.294050817368861, 15.366890284940522, 14.52949375404975, 13.490873996531551, 12.577225721010016, 11.697919670226845, 10.85922551885831, 11.804671306630215, 12.790992884058522, 12.562942601962964, 11.634087761934374, 10.895517683595312, 9.997485700879636, 9.083135329549231, 9.763234352301088, 10.712426617685738, 11.642634506270742, 12.569448334784084, 13.543701647209112, 14.338445438975945, 15.403291258922053, 14.39732670201817, 13.477152258245193, 12.457567103053375, 11.559804093169104, 10.63890575065148, 9.91196355203589, 10.796779026703573, 11.765795742746858, 12.779840201880095, 12.683555213000469, 11.823054945740036, 11.043726972590154, 10.148848675170454, 10.794379839326337, 11.783507446230464, 12.66476456810547, 13.575051070014187, 14.53003405733079, 15.341324757969474, 14.429123901169325, 13.45705913244432, 12.436476789154145, 11.468357289395293, 10.606984531078751, 9.692863878508662, 8.947040014716913, 9.843032864176836, 10.88205113257263, 11.848715743256049, 12.716564106602146, 12.803629405117377, 11.979912698545776, 11.19731462917041, 11.730322720219903, 12.754587664279216, 13.719020517562921, 14.625947872266389, 15.508713833739572, 15.406600350666038, 13.456241950268087, 12.514716569422527, 11.468255288403258, 10.472060459164329, 9.636158517003604, 8.640112259079839, 7.907504625813639, 8.862632342022394, 9.817922233121006, 10.78660005591443, 11.745245054985588, 12.796851647191255, 13.004006101820337, 12.221335112769545, 12.69448881706504, 13.680495617391605, 14.694648328017264, 15.588213137878856, 15.440421816914359, 14.403261163140789, 12.55141468246224, 11.637725322693768, 10.585248675756919, 9.541190143951503, 8.64040969106672, 7.708085889360251, 6.933440705746731, 7.902469797413977, 8.905957767231483, 9.877544974495262, 10.828506504956298, 11.876907412673608, 12.752852058203691, 13.296215359707515, 13.645927711005065, 14.63850085834647, 15.618125171383637, 15.552492953776124, 14.519082138994, 13.597258379038097, 11.551080012409148, 10.605259183311702, 9.627352307879784, 8.568524241044377, 7.636662249131351, 6.63328225179649, 5.928729969565645, 6.9391231814372984, 7.911567032321018, 8.87847123853211, 9.87494186966962, 10.833786647987935, 11.79431112132987, 12.806732028063278, 13.806765968667484, 14.741440494500404, 15.560570444015898, 14.533317188445668, 13.548001648575907, 12.572778234319017, 10.734693099188181, 9.67403984896092, 8.646155883428547, 7.699135358803078, 6.655303065282191, 5.660067912187208, 4.854873418029865, 5.8766902008065225, 6.881721940805255, 7.812143373027186, 8.859092970472851, 9.821825710841793, 10.881157534970088, 11.841814769514123, 12.812939143031187, 13.788574791837284, 14.605388536480675, 13.679227617708424, 12.63064375559849, 11.684690407742856, 9.757490698015609, 8.738456151251, 7.715067948621862, 6.7324494611344505, 5.707420442719939, 4.732935715010142, 3.8813059235211793, 4.936884872294057, 5.938334074967656, 6.945898967895324, 8.017495226539266, 9.01089144971541, 9.924792338789286, 10.901653010439562, 11.907482458474382, 12.926898422524301, 13.58336667104449, 12.642514341601094, 11.697947425266735, 10.731949220891856, 8.746263800122394, 7.734578814387218, 6.7739268497213025, 5.79630658654008, 4.848011404436063, 3.7906198137479663, 2.9463861033750636, 3.9662852395151225, 4.908040645000623, 5.952138949202475, 7.02370609906775, 8.048452051678295, 8.996817519842836, 9.92623635631458, 10.994274438535562, 11.98407472321427, 12.846196971878383, 11.789247197498185, 10.786739012305244, 9.805110780170013], [7.883497627405251, 8.84247288267818, 9.821471086355047, 10.812346227827629, 11.774272595513947, 10.932792647798859, 9.90544883418088, 8.890564729453251, 7.950907592254151, 6.926481314508545, 5.879345881653477, 4.937918380416086, 3.871854866304579, 2.86346243336877, 1.8754205751634845, 2.8638981952843805, 3.821283674257972, 4.845656271486248, 5.846582399095103, 6.87331999544521, 6.972694074310231, 7.928675608129678, 8.830958208051044, 9.779495429254736, 10.744243166334789, 10.069247165789394, 9.005818461291131, 8.013822647497484, 6.962060021704074, 5.8896737173207185, 4.936278028890839, 3.976235955185688, 2.917426015458667, 1.900998843041397, 0.9482925795928298, 1.9211255648086154, 2.9349548755220454, 3.8632767201862235, 4.881788482896655, 5.926913730049905, 5.953669015068898, 6.894824154891789, 7.8515837467203795, 8.817749466884033, 9.816589899691364, 9.049558917050177, 8.018356314552456, 6.996467805125512, 5.980804816343133, 4.973550095812138, 3.9533368260598682, 3.022543837270698, 1.9702736076994567, 0.974298773261762, 0.0, 0.9386330355261236, 1.888491768730869, 2.9411873623250644, 3.9563903318134885, 4.908219661485322, 6.77743530607001, 7.714849371090307, 8.737706716992086, 9.666315736496736, 10.705575248046111, 9.85897822249934, 8.910497445046769, 7.919388910644547, 6.933838560486267, 5.9571131696518025, 4.956662123954896, 3.8884867939303946, 2.924583512834269, 1.9620350724785185, 1.0199059559415935, 1.949709304112503, 2.817525679233528, 3.752643755040237, 4.746222908201776, 5.754805592123857, 7.703010957493624, 8.651972577357148, 9.68027763338679, 10.709333462526914, 11.687837169806452, 10.845868354860867, 9.800570857836755, 8.85986745855488, 7.7888602611764615, 6.844615788062494, 5.894975818674326, 4.827856494342944, 3.9129193089919423, 2.9341882728137105, 1.9987352021711762, 3.010854166218291, 3.8166215409873425, 4.745484890764544, 5.692085690064696, 6.725024408069888, 8.552854056203502, 9.614593746682658, 10.563831643117684, 11.489218560761524, 12.52804802179538, 11.530552990527367, 10.593377536736304, 9.624847775539482, 8.614868222739359, 7.687334411109644, 6.74118751945417, 5.788786118196526, 4.831366135448913, 3.9024071871137886, 2.9245968171886583, 3.9038343398864632, 4.831167340771454, 5.7439098771721575, 6.639767717522258, 7.602510996942826, 9.49688479899855, 10.51105684795437, 11.472239324546488, 12.479233802454063, 13.49881975944627, 12.500866432606486, 11.655588212951244, 10.612342975892965, 9.602377310169638, 8.629088319031606, 7.741779348214091, 6.812671725143041, 5.8970699064034715, 4.906850694322956, 3.8770767406176967, 4.831255887874413, 5.793420985406512, 6.719771814572052, 7.659323143218649, 8.531941326705667, 10.496991116887447, 11.493339521874772, 12.454550401697924, 13.464427904663832, 14.43598437964644, 13.527017259543483, 12.631879659842124, 11.59372495982613, 10.535563239867576, 9.570562355642263, 8.70308505318821, 7.744601131108655, 6.930230877116314, 5.910536401437452, 4.950435208732803, 5.885315072930187, 6.814901673030825, 7.753856997382847, 8.709884842656134, 9.469027556580212, 11.466410257524322, 12.51393631632267, 13.491700081941739, 14.419737673119764, 14.539971709976067, 13.687057017715892, 13.540555011420643, 12.513296822035928, 11.548726186016422, 10.608776855692344, 9.715128244899981, 8.76696396372665, 7.8450187877818385, 6.905620182724105, 5.876309013817129, 6.863986240276252, 7.791703822971816, 8.82522230838188, 9.698299676301124, 10.436466160065294, 12.404489960284547, 13.409629035546738, 14.380332668907164, 14.521954052429615, 13.576239258288755, 12.743418553421893, 13.534272675214774, 13.48997642910394, 12.485192268424882, 11.554537333005399, 10.650082913684862, 9.72490945494782, 8.785949219868952, 7.839340679538421, 6.871040917942452, 7.82610394474066, 8.765487380042572, 9.819510219556944, 10.735196420105314, 11.417154685248322, 13.37624421890846, 14.410916752732067, 14.535538851632255, 13.494209197708342, 12.642496610996343, 11.679654572513027, 12.485853475871775, 13.459169396656636, 13.414156065701981, 12.515245694756771, 11.625472714744147, 10.756185574564665, 9.809969804399113, 8.893985709674396, 7.828274147232589, 8.779082693927695, 9.729536973270585, 10.741159049397638, 11.706103897251625, 12.433859417920681, 14.3197520441071, 14.392591511678761, 13.555194980787988, 12.51657522326979, 11.602926947748255, 10.723620896965082, 11.524015908941264, 12.46946169671317, 13.468300917071964, 13.537241375224726, 12.576822273041675, 11.81115461331395, 10.829489193792366, 9.8238794384191, 8.788935579039327, 9.738127844423976, 10.668335733008982, 11.595149561522325, 12.569402873947352, 13.364146665714184, 14.428992485660292, 13.423027928756408, 12.502853484983431, 11.483268329791613, 10.585505319907343, 9.664606977389717, 10.576753942118845, 11.474087059717014, 12.4431037757603, 13.457148234893538, 13.62628972410777, 12.738691875458674, 11.875730465502883, 10.889592784040323, 9.820081066064576, 10.809208672968703, 11.69046579484371, 12.600752296752427, 13.55573528406903, 14.367025984707713, 13.454825127907563, 12.482760359182558, 11.462178015892384, 10.494058516133531, 9.63268575781699, 8.718565105246899, 9.611830404799868, 10.520340897190277, 11.559359165586072, 12.52602377626949, 13.393872139615587, 13.719266334836014, 12.794742421761523, 11.779957501055291, 10.756023946958141, 11.780288891017454, 12.744721744301161, 13.65164909900463, 14.534415060477812, 14.432301577404276, 12.481943177006325, 11.540417796160765, 10.493956515141496, 9.497761685902567, 8.661859743741843, 7.665813485818076, 8.572295015896593, 9.539940375035835, 10.495230266134447, 11.463908088927871, 12.42255308799903, 13.474159680204696, 13.714900395626632, 12.646989491455534, 11.720190043803278, 12.706196844129844, 13.720349554755503, 14.613914364617097, 14.466123043652598, 13.428962389879027, 11.57711590920048, 10.663426549432007, 9.610949902495157, 8.566891370689742, 7.666110917804957, 6.733787116098489, 7.598231095829685, 8.579777830427417, 9.583265800244924, 10.588351045917854, 11.603690424182249, 12.652091331899559, 13.528035977429642, 13.66977405186409, 12.671628937743304, 13.664202085084709, 14.643826398121876, 14.578194180514362, 13.544783365732238, 12.622959605776336, 10.576781239147387, 9.63096041004994, 8.653053534618023, 7.594225467782615, 6.662363475869589, 5.6589834785347275, 6.593520359648599, 7.616431214450739, 8.58887506533446, 9.589277309954703, 10.65012578889557, 11.608970567213886, 12.56949504055582, 13.581915947289229, 13.686431712550391, 14.637138447532553, 14.586271670754137, 13.559018415183907, 12.573702875314146, 11.598479461057256, 9.76039432592642, 8.699741075699158, 7.671857110166786, 6.724836585541317, 5.681004292020429, 4.685769138925446, 5.630057337255816, 6.651874120032473, 7.656905860031205, 8.587327292253136, 9.634276889698802, 10.597009630067744, 11.656341454196038, 12.616998688740074, 13.588123062257138, 14.563758711063235, 13.631089763218913, 12.704928844446663, 11.656344982336728, 10.710391634481095, 8.783191924753847, 7.764157377989239, 6.740769175360101, 5.758150687872689, 4.7331216694581775, 3.7586369417483803, 4.726428844914691, 5.782007793687569, 6.783456996361167, 7.791021889288834, 8.862618147932777, 9.856014371108921, 10.797149998781414, 11.77401067043169, 12.77984011846651, 13.628294881756757, 12.609067897782728, 11.668215568339333, 10.723648652004973, 9.757650447630095, 7.771965026860633, 6.760280041125456, 5.79962807645954, 4.822007813278319, 3.8737126311743015, 2.8163210404862045, 3.791509024768575, 4.811408160908634, 5.753163566394134, 6.798569054569342, 7.8701362044346155, 8.89488215704516, 9.869175179834963, 10.798594016306708, 11.86663209852769, 12.806835142510788, 11.871898198616622, 10.814948424236423, 9.81244023904348, 8.830812006908252], [6.983983470632505, 7.942958725905435, 8.882838050828923, 9.873713192301505, 10.835639559987824, 11.77404667563573, 10.844081869707004, 9.829197764979375, 8.889540627780274, 7.865114350034669, 6.817978917179601, 5.87655141594221, 4.810487901830703, 3.8020954688948936, 2.814053610689608, 1.9883733338311282, 2.9217695174852256, 3.9461421147135014, 4.9470682423223575, 5.973805838672464, 6.034061038784107, 6.990042572603555, 7.89232517252492, 8.840862393728612, 9.805610130808665, 10.794844757318476, 9.944451496817255, 8.952455683023608, 7.900693057230198, 6.828306752846842, 5.874911064416962, 4.9148689907118115, 3.8560590509847907, 2.8396318785675208, 1.8869256151189533, 0.9824925292824918, 1.996321839995922, 2.9246436846601, 3.9431554473705317, 4.988280694523781, 5.015035979542774, 5.956191119365665, 6.912950711194256, 7.879116431357909, 8.87795686416524, 9.890770508508655, 8.95698935007858, 7.935100840651636, 6.919437851869256, 5.912183131338262, 4.8919698615859915, 3.9611768727968215, 2.9089066432255803, 1.9129318087878855, 0.9386330355261236, 0.0, 0.9498587332047455, 2.0025543267989407, 3.017757296287365, 3.9695866259591988, 5.838802270543886, 6.776216335564183, 7.799073681465963, 8.727682700970613, 9.766942212519988, 10.792384171442695, 9.849130480572894, 8.858021946170672, 7.8724715960123905, 6.895746205177926, 5.8952951594810195, 4.827119829456518, 3.8632165483603926, 2.900668108004642, 1.9585389914677171, 1.0110762685863794, 1.8788926437074045, 2.8140107195141137, 3.807589872675653, 4.816172556597733, 6.7643779219675, 7.713339541831025, 8.741644597860667, 9.77070042700079, 10.749204134280328, 11.78450139038699, 10.739203893362879, 9.798500494081004, 8.727493296702585, 7.783248823588617, 6.83360885420045, 5.766489529869068, 4.851552344518066, 3.872821308339834, 2.9373682376973, 2.072221130692167, 2.877988505461219, 3.806851855238421, 4.753452654538573, 5.786391372543765, 7.614221020677379, 8.675960711156534, 9.62519860759156, 10.5505855252354, 11.589414986269256, 12.46918602605349, 11.532010572262427, 10.563480811065606, 9.553501258265483, 8.625967446635768, 7.679820554980294, 6.72741915372265, 5.769999170975036, 4.841040222639912, 3.863229852714782, 3.0411075994605783, 3.8982288783533634, 4.805276841646034, 5.701134681996135, 6.663877961416703, 8.558251763472427, 9.572423812428246, 10.533606289020364, 11.54060076692794, 12.560186723920147, 13.43949946813261, 12.594221248477368, 11.550976011419088, 10.541010345695762, 9.56772135455773, 8.680412383740213, 7.751304760669164, 6.835702941929595, 5.84548372984908, 4.81570977614382, 4.108321406179345, 4.860482522988422, 5.7811387790459285, 6.720690107692526, 7.593308291179544, 9.558358081361323, 10.554706486348648, 11.5159173661718, 12.525794869137709, 13.497351344120316, 14.465650295069606, 13.570512695368247, 12.532357995352253, 11.4741962753937, 10.509195391168387, 9.641718088714333, 8.68323416663478, 7.868863912642437, 6.849169436963575, 5.889068244258927, 5.162380591235118, 5.9170567877567635, 6.843184316159568, 7.771251807130012, 8.530394521054088, 10.527777221998198, 11.575303280796547, 12.553067046415615, 13.48110463759364, 13.912424642634596, 14.625690053242016, 14.479188046946767, 13.451929857562051, 12.487359221542546, 11.547409891218468, 10.653761280426105, 9.705596999252775, 8.783651823307961, 7.844253218250229, 6.814942049343252, 6.19080201322036, 6.975206462314413, 7.9145496271586, 8.759666640775002, 9.49783312453917, 11.465856924758423, 12.470996000020614, 13.44169963338104, 13.864227436491735, 12.948692190947284, 13.682051588948017, 14.472905710740898, 14.428609464630064, 13.423825303951006, 12.493170368531523, 11.588715949210988, 10.663542490473946, 9.724582255395077, 8.777973715064546, 7.809673953468575, 7.152919717684767, 7.977901807374515, 8.908837538333664, 9.79656338457919, 10.478521649722198, 12.437611183382336, 13.472283717205944, 13.877812235694373, 12.836482581770461, 12.014949543654872, 12.61828760803915, 13.424486511397898, 14.39780243218276, 14.352789101228105, 13.453878730282895, 12.564105750270272, 11.694818610090792, 10.74860283992524, 9.83261874520052, 8.766907182758713, 8.215629362825934, 8.941951400602528, 9.939547160117225, 10.862846384295565, 11.495226382394558, 13.381119008580976, 13.73486489574088, 12.897468364850106, 11.85884860733191, 10.975379880406786, 11.662253932491206, 12.462648944467388, 13.408094732239293, 14.406933952598088, 14.47587441075085, 13.5154553085678, 12.749787648840076, 11.76812222931849, 10.762512473945224, 9.72756861456545, 9.19197764272809, 9.880750160340925, 10.807563988854268, 11.781817301279295, 12.42551363018806, 13.771265869722411, 12.765301312818528, 11.84512686904555, 10.825541713853733, 9.957958252565874, 10.60324001291584, 11.515386977644969, 12.412720095243138, 13.381736811286423, 14.395781270419661, 14.564922759633895, 13.677324910984801, 12.814363501029007, 11.828225819566446, 10.7587141015907, 10.263058471272817, 10.902880222175654, 11.81316672408437, 12.768149711400973, 13.428392949181589, 12.79705852326011, 11.825033743244678, 10.804451399954504, 9.83633190019565, 9.00513869047552, 9.657198140773023, 10.550463440325991, 11.4589739327164, 12.497992201112195, 13.464656811795614, 14.33250517514171, 14.657899370362141, 13.733375457287647, 12.718590536581415, 11.694656982484265, 11.270696943480331, 11.957136171633104, 12.864063526336572, 13.746829487809755, 13.774534972756824, 11.824176572358873, 10.882651191513313, 9.836189910494044, 8.840035069964687, 8.034312676400374, 8.6044465213442, 9.510928051422717, 10.478573410561959, 11.43386330166057, 12.402541124453995, 13.361186123525153, 14.41279271573082, 14.653533431152756, 13.585622526981657, 12.658823079329402, 12.19660489659272, 12.973899408102469, 13.82632879194904, 13.676748034483914, 12.771195785231575, 10.78442119163245, 9.883428697843732, 8.841538744061696, 7.9091647547518615, 7.008384301867077, 7.672420151624612, 8.53686413135581, 9.518410865953541, 10.521898835771047, 11.526984081443977, 12.542323459708372, 13.590724367425683, 14.466669012955766, 14.608407087390214, 13.610261973269427, 13.223941101931661, 13.975122032607274, 13.691059175401918, 12.657648360619794, 11.830264888208307, 9.784086521579358, 8.838265692481912, 7.883642376184561, 6.936498851844735, 6.004636859931709, 6.597616514060851, 7.532153395174722, 8.555064249976864, 9.527508100860583, 10.527910345480826, 11.588758824421694, 12.54760360274001, 13.508128076081944, 14.520548982815352, 14.625064748076515, 14.196877464379506, 13.68675751398139, 12.671883410071462, 11.686567870201701, 10.805784743489227, 8.896535672586442, 7.907046358131129, 6.89849480595167, 5.951474281326201, 5.023277676082548, 5.6244021744515695, 6.56869037278194, 7.590507155558597, 8.595538895557329, 9.52596032777926, 10.572909925224925, 11.535642665593867, 12.594974489722162, 13.555631724266197, 14.526756097783261, 13.682737967486617, 12.731575606446167, 11.807906424550769, 10.759322562440834, 9.813369214585201, 7.8836777679811005, 6.928064106214811, 5.9102513842172195, 4.94745335725608, 3.95968509404167, 4.6972699772745035, 5.665061880440815, 6.720640829213693, 7.722090031887291, 8.729654924814959, 9.801251183458902, 10.794647406635047, 11.735783034307538, 12.712643705957813, 13.718473153992633, 12.728780724984011, 11.709553741009982, 10.768701411566587, 9.824134495232228, 8.858136290857349, 6.872450870087885, 5.860765884352709, 4.9001139196867936, 3.9464829518250664, 2.9981877697210493, 3.754954076012328, 4.730142060294699, 5.750041196434758, 6.691796601920258, 7.737202090095465, 8.80876923996074, 9.833515192571284, 10.807808215361087, 11.737227051832832, 12.792775589940877, 11.868202106984665, 10.933265163090498, 9.8763153887103, 8.912926082270737, 7.931297850135505], [6.060595897156367, 7.019571152429298, 7.932979317624179, 8.92385445909676, 9.885780826783078, 10.824187942430985, 11.79394060291175, 10.77905649818412, 9.83939936098502, 8.814973083239416, 7.7678376503843465, 6.826410149146955, 5.760346635035448, 4.751954202099639, 3.763912343894354, 2.938232067035874, 1.9983819440090882, 3.022754541237364, 4.02368066884622, 5.050418265196327, 5.084202305579362, 6.04018383939881, 6.942466439320175, 7.891003660523866, 8.85575139760392, 9.84498602411373, 10.894310230022, 9.902314416228354, 8.850551790434944, 7.778165486051588, 6.824769797621708, 5.864727723916557, 4.805917784189536, 3.7894906117722664, 2.836784348323699, 1.9323512624872372, 1.0729342665197843, 2.001256111183962, 2.9932967141657865, 4.038421961319036, 4.065177246338029, 5.006332386160921, 5.963091977989511, 6.929257698153164, 7.928098130960494, 8.94091177530391, 9.906848083283325, 8.884959573856381, 7.869296585074002, 6.8620418645430075, 5.841828594790737, 4.911035606001567, 3.858765376430326, 2.862790541992631, 1.888491768730869, 0.9498587332047455, 0.0, 1.0526955935941953, 2.0678985630826197, 3.0197278927544535, 4.8889435373391406, 5.826357602359438, 6.849214948261217, 7.777823967765867, 8.817083479315242, 9.84252543823795, 10.79100621569052, 9.807880679375417, 8.822330329217136, 7.845604938382672, 6.845153892685765, 5.776978562661265, 4.813075281565139, 3.850526841209388, 2.9015828659116685, 1.8575525369427908, 0.929033910502659, 1.864151986309368, 2.8577311394709075, 3.8663138233929875, 5.8145191887627545, 6.763480808626279, 7.791785864655921, 8.820841693796044, 9.799345401075582, 10.865153570990785, 11.689062626567628, 10.748359227285754, 9.677352029907333, 8.733107556793364, 7.783467587405197, 6.716348263073815, 5.801411077722812, 4.822680041544579, 3.880412112141251, 2.88983919446421, 1.9281297722564736, 2.8569931220336757, 3.8035939213338272, 4.836532639339019, 6.664362287472633, 7.72610197795179, 8.675339874386815, 9.600726792030654, 10.63955625306451, 11.667136040239797, 12.481869305467175, 11.513339544270353, 10.50335999147023, 9.575826179840515, 8.629679288185041, 7.677277886927397, 6.7130430454189876, 5.784084097083864, 4.806273727158733, 3.8587256632326206, 2.948370145148618, 3.855418108441289, 4.751275948791389, 5.714019228211957, 7.608393030267681, 8.6225650792235, 9.583747555815618, 10.590742033723194, 11.610327990715401, 12.637449482318916, 13.544079981682115, 12.500834744623836, 11.49086907890051, 10.517580087762477, 9.63027111694496, 8.701163493873912, 7.7787468163735465, 6.788527604293031, 5.758753650587772, 4.925939469951388, 3.910623789783676, 4.831280045841185, 5.770831374487781, 6.643449557974798, 8.608499348156577, 9.604847753143902, 10.566058632967055, 11.575936135932963, 12.54749261091557, 13.597487640531439, 14.520371428572995, 13.482216728557, 12.424055008598447, 11.459054124373134, 10.59157682191908, 9.633092899839527, 8.811907787086389, 7.792213311407527, 6.832112118702878, 5.896784654652656, 4.967198054552018, 5.893325582954824, 6.821393073925266, 7.580535787849343, 9.577918488793452, 10.625444547591801, 11.60320831321087, 12.531245904388895, 13.478253239414602, 14.482797771909418, 15.419078869140057, 14.401788590766797, 13.437217954747291, 12.497268624423214, 11.603620013630852, 10.655455732457522, 9.726695697751913, 8.78729709269418, 7.757985923787204, 6.925206076637897, 6.025347729109668, 6.964690893953856, 7.809807907570256, 8.547974391334424, 10.515998191553678, 11.521137266815868, 12.491840900176294, 13.034352456671954, 13.849901100676849, 14.631910322152764, 15.422764443945644, 15.37846819783481, 14.373684037155751, 13.443029101736268, 12.531759823654939, 11.606586364917897, 10.667626129839029, 9.721017589508497, 8.752717827912527, 7.887323781102305, 7.028043074169769, 7.95897880512892, 8.846704651374445, 9.528662916517453, 11.48775245017759, 12.522424984001198, 13.000096430715008, 12.00660760195068, 12.916158453384437, 13.568146341243898, 14.374345244602644, 15.347661165387505, 15.30264783443285, 14.40373746348764, 13.507149624714224, 12.637862484534743, 11.691646714369192, 10.775662619644471, 9.709951057202664, 8.950033426243472, 7.992092667397783, 8.989688426912481, 9.91298765109082, 10.545367649189812, 12.43126027537623, 12.85076490299547, 12.01975255987074, 11.028973627512128, 11.87658879013635, 12.612112665695953, 13.412507677672133, 14.357953465444039, 15.356792685802834, 15.425733143955595, 14.458499183011751, 13.692831523284028, 12.71116610376244, 11.705556348389175, 10.670612489009402, 9.926381706145628, 8.93089142713618, 9.857705255649522, 10.83195856807455, 11.475654896983315, 12.877608159620046, 11.881201320073117, 10.96102687630014, 9.995666734033952, 10.859167162295437, 11.553098746120588, 12.465245710849715, 13.362578828447884, 14.331595544491169, 15.345640003624407, 15.507966634077846, 14.620368785428752, 13.757407375472958, 12.771269694010398, 11.701757976034651, 10.905620763554213, 9.953021488970908, 10.863307990879624, 11.818290978196227, 12.478534215976843, 11.878265696505089, 10.940933750499267, 9.920351407209093, 9.00645692037587, 9.906347600205084, 10.60705687397777, 11.500322173530737, 12.408832665921146, 13.447850934316941, 14.41451554500036, 15.282363908346456, 15.600943244806093, 14.676419331731598, 13.661634411025366, 12.637700856928216, 11.913259235761727, 11.007277438428359, 11.914204793131827, 12.79697075460501, 12.855742146001802, 10.905383745603851, 9.963858364758291, 8.917397083739022, 8.010160090144906, 8.935521586129937, 9.554305254548947, 10.460786784627462, 11.428432143766704, 12.383722034865317, 13.35239985765874, 14.311044856729898, 15.362651448935566, 15.596577305596707, 14.528666401425609, 13.601866953773353, 12.839167188874116, 12.024040674897723, 12.876470058744294, 12.753360461007777, 11.852402958476553, 9.861033618156313, 8.960041124367594, 7.922745917306675, 7.079289774932081, 7.958243035071822, 8.62227888482936, 9.486722864560555, 10.468269599158287, 11.471757568975793, 12.476842814648723, 13.492182192913118, 14.540583100630428, 15.416527746160511, 15.551450961834165, 14.553305847713379, 13.866503394213058, 13.025263299402528, 12.76767160192578, 11.734260787143656, 10.906877314732169, 8.86069894810322, 7.914878119005775, 6.964849549429541, 6.106623872024954, 6.954495593136454, 7.547475247265598, 8.482012128379468, 9.50492298318161, 10.477366834065329, 11.477769078685572, 12.53861755762644, 13.497462335944755, 14.45798680928669, 15.470407716020098, 14.674534427811015, 13.7122160966736, 12.763369940505255, 11.748495836595325, 10.763180296725563, 9.882397170013089, 7.973148099110306, 6.983658784654993, 5.97970197919665, 5.032681454571181, 5.973136409287294, 6.574260907656316, 7.518549105986686, 8.540365888763343, 9.545397628762075, 10.475819060984005, 11.522768658429671, 12.485501398798613, 13.544833222926908, 14.505490457470943, 13.734986042816578, 12.75935039401048, 11.808188032970032, 10.884518851074631, 9.835934988964697, 8.889981641109063, 6.960290194504965, 6.004676532738674, 4.986863810741083, 4.02866053050106, 4.909543827246416, 5.64712871047925, 6.614920613645559, 7.670499562418437, 8.671948765092036, 9.679513658019705, 10.751109916663648, 11.744506139839793, 12.685641767512283, 13.662502439162559, 12.785212050589266, 11.805393151507875, 10.786166167533846, 9.845313838090451, 8.900746921756092, 7.934748717381212, 5.949063296611749, 4.937378310876572, 3.976726346210657, 3.027690125070046, 3.948046502925795, 4.704812809217074, 5.680000793499444, 6.6998999296395025, 7.641655335125003, 8.687060823300211, 9.758627973165485, 10.78337392577603, 11.757666948565832, 12.687085785037578, 11.842916856736132, 10.91834337377992, 9.983406429885752, 8.926456655505556, 7.989538508794599, 7.007910276659369], [5.025606344714268, 5.984581599987198, 6.880283724029983, 7.871158865502564, 8.833085233188882, 9.771492348836787, 10.798836162454766, 11.813720267182397, 10.892094954579214, 9.86766867683361, 8.820533243978542, 7.87910574274115, 6.8130422286296435, 5.804649795693834, 4.813034466273237, 3.8245568461523414, 2.86717136717875, 2.0437266814895483, 2.9886911164041203, 4.015428712754227, 4.031506711985166, 4.987488245804614, 5.889770845725979, 6.83830806692967, 7.803055804009722, 8.792290430519532, 9.855719135017795, 10.847714948811442, 9.903247384029138, 8.830861079645782, 7.877465391215903, 6.917423317510752, 5.8586133777837315, 4.8421862053664615, 3.889479941917894, 2.955553000402876, 1.941723689689446, 1.0134018450252682, 1.940601120571591, 2.9857263677248405, 3.0124816527438334, 3.9536367925667246, 4.910396384395315, 5.876562104558968, 6.875402537366298, 7.888216181709713, 8.919418784207435, 9.937655167450577, 8.921992178668198, 7.9147374581372025, 6.894524188384932, 5.963731199595762, 4.911460970024521, 3.9154861355868262, 2.9411873623250644, 2.0025543267989407, 1.0526955935941953, 0.0, 1.0152029694884244, 1.967032299160258, 4.030829697741119, 4.964726731687928, 5.894240305705394, 6.822849325210044, 7.862108836759419, 8.871545328401089, 9.82002610585366, 10.811134640255883, 9.875025922811329, 8.898300531976865, 7.897849486279959, 6.829674156255459, 5.865770875159333, 4.903222434803583, 3.9353750650089463, 2.8913447360400686, 1.9628261095999369, 1.0277080337932278, 2.001037157832869, 3.009619841754949, 4.956405349164733, 5.903740653665578, 6.9320457096952195, 7.887367760907619, 8.844370758519759, 9.910178928434963, 10.873996176913414, 11.801054820879948, 10.730047623501529, 9.78580315038756, 8.836163180999392, 7.769043856668009, 6.854106671317006, 5.875375635138775, 4.914204311238529, 3.9236313935614877, 2.9619219713537515, 2.07735965991555, 2.946899939695789, 3.979838657700981, 5.807668305834595, 6.869407996313751, 7.818645892748776, 8.744032810392616, 9.782862271426472, 10.810442058601758, 11.747617512392821, 12.566035137864548, 11.556055585064424, 10.62852177343471, 9.682374881779236, 8.729973480521592, 7.746835244516266, 6.817876296181142, 5.8400659262560115, 4.892517862329899, 3.982162344245896, 3.0757846463231635, 3.894581967153351, 4.857325246573919, 6.751699048629643, 7.765871097585462, 8.72705357417758, 9.734048052085155, 10.753634009077363, 11.780755500680877, 12.722377061876234, 13.55353033821803, 12.543564672494703, 11.570275681356671, 10.682966710539155, 9.753859087468106, 8.812539015470824, 7.822319803390309, 6.79254584968505, 5.959731669048666, 4.944415988880954, 4.051646583723059, 4.914137392849742, 5.78675557633676, 7.751805366518539, 8.748153771505864, 9.709364651329016, 10.719242154294925, 11.690798629277532, 12.7407936588934, 13.698668508767113, 14.534912322151195, 13.476750602192642, 12.511749717967328, 11.644272415513274, 10.685788493433721, 9.845699986183666, 8.826005510504805, 7.865904317800156, 6.930576853749935, 6.000990253649296, 5.113692120836698, 5.964699092287228, 6.723841806211305, 8.721224507155414, 9.768750565953763, 10.74651433157283, 11.674551922750856, 12.621559257776564, 13.62610379027138, 14.562384887502018, 15.454484184360991, 14.489913548341486, 13.549964218017408, 12.656315607225046, 11.699134732381921, 10.76048789684919, 9.821089291791457, 8.791778122884482, 7.958998275735176, 7.059139928206946, 6.18505743183573, 6.953113925932217, 7.691280409696387, 9.65930420991564, 10.66444328517783, 11.635146918538256, 12.616271995037451, 13.574160877631327, 14.569742254565378, 15.542886185789484, 16.431163791429004, 15.426379630749945, 14.495724695330463, 13.565552022752216, 12.640378564015174, 11.701418328936306, 10.754809788605774, 9.786510027009804, 8.921115980199584, 8.061835273267048, 7.1793453430107945, 7.990010669736407, 8.671968934879416, 10.631058468539553, 11.665731002363161, 12.048694393247517, 12.875397025120343, 13.7849478765541, 14.617268463622779, 15.423467366981527, 16.39678328776639, 16.355343428027044, 15.456433057081835, 14.540941823811501, 13.67165468363202, 12.72543891346647, 11.809454818741749, 10.743743256299942, 9.983825625340751, 9.025884866495062, 8.210054964794356, 9.056293669452781, 9.688673667551775, 11.574566293738192, 11.89936286552798, 11.06835052240325, 11.89776305068179, 12.745378213306012, 13.661234788074834, 14.461629800051016, 15.407075587822922, 16.405914808181716, 16.47216075997755, 15.492291382109029, 14.726623722381305, 13.744958302859718, 12.739348547486452, 11.70440468810668, 10.960173905242907, 9.964683626233459, 9.242706361711166, 9.991646592560912, 10.618960915345276, 11.88135190941935, 10.929799282605627, 10.00962483883265, 10.864456157203614, 11.7279565854651, 12.602220868499469, 13.514367833228597, 14.411700950826766, 15.380717666870051, 16.39476212600329, 16.541758833175123, 15.65416098452603, 14.791199574570236, 13.805061893107675, 12.735550175131928, 11.939412962651492, 10.986813688068187, 10.248309096941268, 10.97797900268259, 11.621840234338805, 10.882009446304393, 9.989531713031777, 8.968949369741603, 9.875246343545532, 10.775137023374747, 11.656178996356651, 12.54944429590962, 13.457954788300029, 14.496973056695824, 15.463637667379242, 16.331486030725337, 16.63473544390337, 15.710211530828875, 14.695426610122643, 13.671493056025493, 12.947051434859006, 12.041069637525638, 11.29920589919347, 11.956658779091372, 11.859485895801106, 9.909127495403155, 8.983112890513926, 7.965995046271533, 8.878949513314568, 9.8043110092996, 10.603427376927828, 11.509908907006345, 12.477554266145587, 13.4328441572442, 14.401521980037623, 15.360166979108781, 16.41177357131445, 16.630369504693984, 15.562458600522886, 14.63565915287063, 13.872959387971395, 13.057832873995004, 12.261471164805938, 11.733235341280645, 10.856146708275856, 8.849882863059971, 7.948890369271252, 6.971343879839185, 7.948079198101743, 8.84456781418829, 9.67140100720824, 10.535844986939438, 11.51739172153717, 12.520879691354676, 13.525964937027606, 14.541304315292, 15.589705223009311, 16.465649868539394, 15.598461379394458, 14.657600486735717, 13.665027339394312, 12.706503114432168, 11.747546482198649, 10.714135667416524, 9.895726559635827, 7.8495481930068784, 6.903727363909432, 6.013447511962051, 6.975413295194616, 7.840820372252922, 8.59659736964448, 9.53113425075835, 10.554045105560492, 11.526488956444211, 12.526891201064455, 13.587739680005322, 14.546584458323638, 15.507108931665572, 14.654443248688088, 13.654409308083881, 12.692090976946467, 11.743244820778122, 10.728370716868193, 9.743055176998432, 8.871246414916747, 6.961997344013962, 5.97250802955865, 5.02829994172916, 5.9014708777408424, 6.8594611884037615, 7.623383030035199, 8.567671228365569, 9.589488011142226, 10.594519751140957, 11.524941183362888, 12.571890780808554, 13.534623521177496, 14.59395534530579, 13.683265035719648, 12.712140662202584, 11.739225274283347, 10.788062913242898, 9.8643937313475, 8.815809869237565, 7.869856521381932, 5.949139439408621, 4.993525777642332, 4.007835950993266, 4.897449953670722, 5.795868606362883, 6.696250832858133, 7.667616207239755, 8.723195156012633, 9.72464435868623, 10.732209251613899, 11.803805510257842, 12.797201733433987, 13.680778856530882, 12.738345905029888, 11.732516456995068, 10.785268031780742, 9.766041047806713, 8.825188718363318, 7.8806218020289585, 6.91462359765408, 4.937912541515406, 3.9262275557802297, 2.9976984864628404, 3.896479548239708, 4.834371282042262, 5.753934931595957, 6.732696387093639, 7.752595523233698, 8.694350928719198, 9.739756416894405, 10.811323566759679, 11.836069519370223, 12.752804037584431, 11.823385201112686, 10.790221263141934, 9.865647780185723, 8.930710836291558, 7.8737610619113605, 6.954548956352499, 5.987785156932237], [4.0104033752258434, 4.969378630498774, 5.865080754541559, 6.85595589601414, 7.817882263700457, 8.756289379348363, 9.783633192966342, 10.798517297693973, 11.738174434893073, 10.882871646322034, 9.835736213466966, 8.861533553947922, 7.795470039836414, 6.7870776069006045, 5.780281696577651, 4.7918040764567555, 3.8344185974831646, 2.974414274524552, 1.9734881469156957, 3.0002257432658026, 3.016303742496742, 3.9722852763161898, 4.874567876237555, 5.823105097441246, 6.787852834521298, 7.777087461031108, 8.84051616552937, 9.832511979323018, 10.884274605116428, 9.846064049134206, 8.892668360704327, 7.932626286999176, 6.873816347272156, 5.857389174854886, 4.904682911406319, 3.922800230707291, 2.9089709199938607, 1.9806490753296826, 0.9253981510831667, 1.9705233982364163, 1.9972786832554092, 2.9384338230783005, 3.895193414906891, 4.861359135070544, 5.860199567877874, 6.873013212221289, 7.904215814719011, 8.926104324145955, 9.93719514815662, 8.929940427625626, 7.909727157873356, 6.978934169084186, 5.926663939512945, 4.930689105075251, 3.9563903318134885, 3.017757296287365, 2.0678985630826197, 1.0152029694884244, 0.0, 0.9518293296718338, 3.0156267282526947, 3.9495237621995036, 4.87903733621697, 5.80764635572162, 6.846905867270995, 7.856342358912665, 8.804823136365236, 9.795931670767459, 10.78148202092574, 9.912608776011062, 8.912157730314155, 7.843982400289654, 6.880079119193528, 5.917530678837778, 4.8870803727217025, 3.8430500437528248, 2.914531417312693, 1.9794133415059842, 0.9858341883444449, 1.994416872266525, 3.9412023796763087, 4.8885376841771535, 5.916842740206795, 6.872164791419195, 7.829167789031335, 8.894975958946539, 9.85879320742499, 10.799496606706864, 11.744355867535722, 10.800111394421753, 9.850471425033586, 8.783352100702205, 7.8684149153512015, 6.886244976722086, 5.865909618951285, 4.840679376419191, 3.878969954211454, 2.950106604434252, 1.9316969702073645, 2.964635688212557, 4.7924653363461704, 5.854205026825327, 6.803442923260352, 7.728829840904192, 8.767659301938048, 9.795239089113334, 10.732414542904397, 11.700944304101219, 12.512173762226656, 11.58463995059694, 10.638493058941467, 9.686091657683823, 8.695572686145661, 7.7666137378105375, 6.788803367885407, 5.809565845187602, 4.8992103271035985, 3.93237556840467, 2.8793789976649267, 3.842122277085495, 5.736496079141219, 6.750668128097038, 7.711850604689156, 8.718845082596731, 9.738431039588939, 10.765552531192453, 11.70717409238781, 12.739585066902002, 13.499682849656935, 12.526393858518903, 11.639084887701387, 10.709977264630338, 9.76127645710022, 8.771057245019705, 7.741283291314446, 6.876779651906369, 5.861463971738656, 4.9073267169177095, 3.898934423361318, 4.771552606848336, 6.736602397030115, 7.73295080201744, 8.694161681840592, 9.7040391848065, 10.675595659789108, 11.725590689404976, 12.68346553927869, 13.720967050835167, 14.432868779354873, 13.46786789512956, 12.600390592675506, 11.641906670595953, 10.794437427813062, 9.7747429521342, 8.80891134339215, 7.837914178484009, 6.908327578383371, 5.969372254031349, 4.949496122798804, 5.708638836722881, 7.706021537666989, 8.753547596465339, 9.731311362084407, 10.659348953262432, 11.60635628828814, 12.610900820782955, 13.547181918013594, 14.57444010739831, 15.446031725503717, 14.50608239517964, 13.612433784387278, 12.642141757973913, 11.703494922441184, 10.764096317383451, 9.734785148476476, 8.86633560046925, 7.966477252941021, 7.004728573261006, 5.937910956443793, 6.676077440207963, 8.644101240427215, 9.649240315689406, 10.619943949049832, 11.601069025549027, 12.558957908142903, 13.554539285076954, 14.52768321630106, 15.469818009905477, 16.382497807912177, 15.451842872492694, 14.50855904834421, 13.583385589607168, 12.6444253545283, 11.697816814197768, 10.729517052601798, 9.828453304933658, 8.969172598001123, 7.99901648443607, 6.9748077002479825, 7.656765965390991, 9.61585549905113, 10.650528032874737, 11.594647698957662, 12.6288138802703, 13.492700555435315, 14.466328425071438, 15.534788456787156, 16.521627062347328, 17.311461605189276, 16.412551234244066, 15.483948849403495, 14.614661709224013, 13.668445939058461, 12.752461844333741, 11.686750281891936, 10.891162950074825, 9.933222191229136, 9.006035547818344, 8.041090699964357, 8.673470698063351, 10.559363324249768, 10.888492433204435, 11.906385307679379, 12.833563641131594, 13.69320586641468, 14.628482018379248, 15.428877030355428, 16.374322818127332, 17.37316203848613, 17.415167785569544, 16.435298407701023, 15.669630747973297, 14.68796532845171, 13.682355573078446, 12.647411713698673, 11.867511229976982, 10.872020950967533, 9.950696935497515, 8.976443623072488, 9.603757945856852, 10.866148939930923, 9.918928850282082, 10.88360290332753, 11.800256747653417, 12.675784238573767, 13.569468098803883, 14.48161506353301, 15.37894818113118, 16.347964897174464, 17.362009356307702, 17.48476585876712, 16.597168010118022, 15.734206600162228, 14.74806891869967, 13.678557200723922, 12.846750287385566, 11.894151012802261, 10.956299670727617, 9.962776033194165, 10.60663726485038, 9.866806476815967, 8.978661280708232, 9.842927434236483, 10.811046933995335, 11.722964676483414, 12.623426226661065, 13.516691526214032, 14.425202018604443, 15.464220287000238, 16.430884897683654, 17.298733261029753, 17.577742469495362, 16.65321855642087, 15.638433635714637, 14.614500081617487, 13.85438875959308, 12.948406962259712, 11.982000428345682, 10.941455809602948, 10.84428292631268, 8.893924525914729, 7.9679099210255, 8.839973110766412, 9.826777166423234, 10.752138662408267, 11.570674607232242, 12.477156137310757, 13.444801496450001, 14.400091387548613, 15.368769210342037, 16.327414209413195, 17.379020801618864, 16.45603985330916, 15.520635858839574, 14.593836411187318, 13.67716057524483, 12.676478877528002, 11.661938151081346, 10.718032371792221, 9.84094373878743, 7.834679893571545, 6.933687399782826, 7.8453219443340645, 8.895906851210409, 9.811815044492706, 10.638648237512655, 11.50309221724385, 12.484638951841584, 13.48812692165909, 14.493212167332018, 15.508551545596413, 16.54956224643783, 15.518742000778634, 14.583258409906033, 13.642397517247293, 12.649824369905888, 11.691300144943744, 10.732343512710225, 9.6989326979281, 8.880523590147401, 6.8343452235184525, 5.888524394421007, 6.8874255764569305, 7.923240948303283, 8.808067602557337, 9.563844599948894, 10.498381481062765, 11.521292335864906, 12.493736186748626, 13.494138431368869, 14.554986910309735, 15.51383168862805, 14.560201063904811, 13.639240279199663, 12.639206338595457, 11.676888007458043, 10.728041851289698, 9.713167747379769, 8.727852207510008, 7.8560434454283214, 5.946794374525537, 4.957305060070225, 5.90227800622404, 6.849298530849509, 7.826708418708176, 8.590630260339612, 9.534918458669981, 10.556735241446638, 11.56176698144537, 12.4921884136673, 13.539138011112966, 14.501870751481908, 13.62871930077526, 12.668062066231224, 11.69693769271416, 10.724022304794923, 9.772859943754474, 8.849190761859075, 7.800606899749141, 6.854653551893508, 4.933936469920196, 3.978322808153907, 4.881814015488146, 5.864432502975558, 6.763115836667297, 7.663498063162547, 8.645885334522088, 9.701464283294968, 10.702913485968566, 11.710478378896234, 12.782074637540177, 13.610586010095039, 12.665575887042458, 11.723142935541464, 10.717313487506644, 9.770065062292318, 8.750838078318289, 7.809985748874893, 6.865418832540534, 5.899420628165656, 3.922709572026981, 2.9110245862918047, 3.8716765509577202, 4.863726778544122, 5.801618512346677, 6.721182161900371, 7.710965514375973, 8.730864650516033, 9.672620056001533, 10.71802554417674, 11.789592694042014, 12.71189409088581, 11.737601068096007, 10.808182231624262, 9.77501829365351, 8.850444810697297, 7.915507866803133, 6.858558092422936, 5.939345986864075, 4.9725821874438125], [3.1027186321621687, 4.0616938874351, 4.913251424869725, 5.904126566342306, 6.866052934028624, 7.80446004967653, 8.831803863294507, 9.846687968022138, 10.786345105221239, 11.810771382966843, 10.7875655431388, 9.813362883619755, 8.747299369508248, 7.738906936572439, 6.732111026249486, 5.743633406128589, 4.7862479271549985, 3.9262436041963857, 2.9253174765875296, 2.096794118142512, 2.0838128545155925, 3.020455946644357, 3.9227385465657214, 4.871275767769412, 5.836023504849465, 6.825258131359275, 7.888686835857538, 8.880682649651185, 9.932445275444593, 10.797893378806041, 9.844497690376162, 8.88445561667101, 7.8256456769439895, 6.8092185045267195, 5.8565122410781525, 4.874629560379125, 3.8608002496656946, 2.9324784050015165, 1.8772274807550005, 1.0380325102552668, 1.0454493535835756, 1.986604493406467, 2.9433640852350575, 3.9095298053987113, 4.908370238206041, 5.921183882549456, 6.952386485047178, 7.974274994474122, 8.989937983256501, 9.88176975729746, 8.86155648754519, 7.93076349875602, 6.878493269184779, 5.882518434747085, 4.908219661485322, 3.9695866259591988, 3.019727892754453, 1.967032299160258, 0.9518293296718338, 0.0, 2.063797398580861, 2.9976944325276698, 3.927208006545137, 4.855817026049787, 5.895076537599162, 6.904513029240832, 7.852993806693403, 8.844102341095626, 9.829652691253907, 10.806378082088372, 9.86398705998599, 8.795811729961489, 7.831908448865363, 6.869360008509613, 5.838909702393536, 4.794879373424658, 3.866360746984527, 2.931242671177818, 1.9376635180162787, 1.060539607932934, 2.989373050004475, 3.9367083545053196, 4.9650134105349615, 5.920335461747362, 6.877338459359502, 7.943146629274706, 8.906963877753157, 9.84766727703503, 10.82177880137828, 11.751940724093588, 10.80230075470542, 9.73518143037404, 8.820244245023037, 7.838074306393919, 6.817738948623119, 5.792508706091024, 4.830799283883287, 3.9019359341060853, 2.883526299879198, 2.0307584238789658, 3.9974751434004974, 4.977675468749741, 5.911013511514875, 6.836400429158715, 7.8199012959798795, 8.847481083155166, 9.78465653694623, 10.753186298143051, 11.753732159013465, 12.536469280268774, 11.5903223886133, 10.637920987355656, 9.647402015817494, 8.71844306748237, 7.74063269755724, 6.761395174859435, 5.851039656775432, 4.884204898076503, 3.83120832733676, 3.091429923932532, 4.941505886195546, 5.955677935151365, 6.916860411743483, 7.8638180901742105, 8.790673033630771, 9.817794525234286, 10.759416086429642, 11.791827060943834, 12.774237434955126, 13.478223188190736, 12.59091421737322, 11.66180659430217, 10.713105786772052, 9.722886574691538, 8.693112620986279, 7.828608981578202, 6.81329330141049, 5.8591560465895425, 4.850763753033151, 4.020860253695373, 5.952737259480138, 6.937960609071767, 7.899171488894919, 8.894895035755694, 9.816028882510167, 10.843945352171282, 11.735707533320522, 12.773209044877, 13.737157199840446, 14.419697224801393, 13.552219922347339, 12.593736000267786, 11.746266757484895, 10.726572281806034, 9.760740673063983, 8.789743508155842, 7.860156908055204, 6.921201583703182, 5.901325452470637, 4.957946483569918, 6.922156400117012, 7.958557403519665, 8.936321169138735, 9.86435876031676, 10.746789511009199, 11.751334043504015, 12.687615140734653, 13.714873330119369, 14.679443966138875, 15.457911724851474, 14.564263114059111, 13.593971087645748, 12.655324252113017, 11.715925647055284, 10.686614478148309, 9.818164930141084, 8.918306582612853, 7.956557902932839, 6.889740286115626, 5.925385087055, 7.860236102877237, 8.865375178139429, 9.836078811499855, 10.81720388799905, 11.710521962696511, 12.694972507798013, 13.66811643902212, 14.610251232626537, 15.65372912063375, 16.40367220216453, 15.460388378016043, 14.535214919279001, 13.596254684200133, 12.649646143869601, 11.681346382273631, 10.780282634605491, 9.921001927672956, 8.945534527091198, 7.920841360248465, 6.906073612238028, 8.865163145898165, 9.874574395705151, 10.818044656796474, 11.844948742720323, 12.644264609988923, 13.617892479625047, 14.686352511340765, 15.662060285068387, 16.582692917910848, 17.3643805639159, 16.435778179075328, 15.566491038895848, 14.620275268730296, 13.704291174005576, 12.638579611563769, 11.842992279746658, 10.877397422454669, 9.865775346327617, 8.90083049847363, 7.9227783449103875, 9.808670971096804, 10.736624083042447, 11.75451695751739, 12.793136715035587, 13.68383427323701, 14.573926155172991, 15.506589289704063, 16.45203507747597, 17.483135846814495, 18.366997115241375, 17.387127737372854, 16.621460077645132, 15.639794658123545, 14.63418490275028, 13.599241043370506, 12.778605020541555, 11.737250562520131, 10.810436734006789, 9.836183421581762, 8.853065592703889, 10.120563834026541, 10.870758179953917, 11.835432232999365, 12.752086077325252, 13.627613568245598, 14.521297428475718, 15.433444393204844, 16.330777510803014, 17.2997942268463, 18.31383868597954, 18.43659518843895, 17.548997339789857, 16.686035929834063, 15.699898248371502, 14.630386530395755, 13.711979898938164, 12.75938062435486, 11.816039469236891, 10.82251583170344, 9.855944911697417, 9.121221370911584, 9.930490610380067, 10.794756763908318, 11.76287626366717, 12.674794006155246, 13.5752555563329, 14.468520855885867, 15.377031348276278, 16.416049616672073, 17.382714227355493, 18.250562590701588, 17.554906680905063, 16.52830392691189, 15.636971599375034, 14.650317764968781, 13.688913557653386, 12.705206050714718, 11.716518673630139, 10.877515967553833, 10.097586839464318, 8.148339420010347, 8.919739250697335, 9.791802440438246, 10.778606496095067, 11.703967992080099, 12.522503936904076, 13.428985466982592, 14.396630826121836, 15.351920717220448, 16.320598540013872, 17.27924353908503, 16.526938061818367, 15.50421052363733, 14.6129511157759, 13.686151668123644, 12.769475832181154, 11.768794134464327, 10.754253408017671, 9.810347628728547, 9.042478688886368, 7.089094787667163, 7.885516729454661, 8.797151274005898, 9.847736180882242, 10.76364437416454, 11.59047756718449, 12.454921546915685, 13.436468281513418, 14.439956251330925, 15.445041497003853, 16.460380875268246, 15.597732916765997, 14.5669126711068, 13.668401107007385, 12.734712774183619, 11.742139626842214, 10.783615401880068, 9.824658769646549, 8.791247954864426, 8.034561397436411, 6.088760117614069, 6.840353724092841, 7.839254906128764, 8.875070277975116, 9.759896932229172, 10.515673929620728, 11.4502108107346, 12.473121665536741, 13.44556551642046, 14.445967761040704, 15.50681623998157, 14.568896207574912, 13.608371734232978, 12.724382976301015, 11.731521595531783, 10.769203264394369, 9.820357108226023, 8.805483004316093, 7.820167464446333, 6.985749712708372, 5.12265346934479, 5.909134389742059, 6.854107335895874, 7.801127860521343, 8.77853774838001, 9.542459590011447, 10.486747788341816, 11.508564571118473, 12.513596311117205, 13.444017743339135, 14.4909673407848, 13.61789433922096, 12.676889971103426, 11.716232736559391, 10.745108363042327, 9.816337561731249, 8.8651752006908, 7.941506018795402, 6.892922156685467, 5.946968808829833, 4.109795564739449, 4.930152137825741, 5.83364334515998, 6.816261832647392, 7.714945166339131, 8.61532739283438, 9.597714664193923, 10.653293612966802, 11.6547428156404, 12.662307708568068, 13.65215290359935, 12.658756680423204, 11.713746557370623, 10.771313605869631, 9.76548415783481, 8.862380319228643, 7.8431533352546134, 6.902301005811219, 5.95773408947686, 4.991735885101981, 3.0985686668462336, 3.8628539159636386, 4.823505880629554, 5.815556108215956, 6.7534478420185104, 7.673011491572206, 8.662794844047808, 9.682693980187867, 10.624449385673367, 11.669854873848575, 12.741422023713849, 11.760064761213975, 10.785771738424172, 9.856352901952427, 8.823188963981677, 7.898615481025465, 6.963678537131299, 5.9067287627511025, 5.031661243800401, 4.064897444380138], [3.080976475677588, 4.037659803369413, 4.875150935604759, 5.86602607707734, 6.827952444763658, 7.766359560411564, 8.79370337402954, 9.808587478757172, 10.748244615956272, 11.772670893701877, 12.656781187723489, 11.715353686486097, 10.64929017237459, 9.640897739438781, 8.652855881233496, 7.80743080470945, 6.850045325735859, 5.990041002777247, 4.989114875168391, 4.091154107637628, 2.062070698031012, 2.9823554573793896, 3.884638057300755, 4.833175278504446, 5.797923015584499, 6.787157642094309, 7.850586346592571, 8.842582160386218, 9.894344786179627, 10.924491915409757, 11.71371333496085, 10.7536712612557, 9.694861321528679, 8.678434149111409, 7.725727885662841, 6.821294799826379, 5.924597648246555, 4.996275803582377, 3.9410248793358615, 3.1018299088361276, 1.0183480449972853, 1.9485040041415, 2.9052635959700908, 3.8714293161337445, 4.870269748941075, 5.8830833932844895, 6.908651959861792, 7.930540469288736, 8.894640016703175, 9.90189473723417, 10.73077213212988, 9.79997914334071, 8.747708913769468, 7.751734079331773, 6.777435306070011, 5.838802270543887, 4.888943537339141, 4.030829697741119, 3.0156267282526947, 2.063797398580861, 0.0, 0.9374140650202971, 1.9602714109220767, 2.8888804304267266, 3.9281399419761014, 4.953581900898808, 5.902062678351379, 6.893171212753601, 7.878721562911881, 8.855446953746345, 9.85589799944325, 8.889360609813444, 7.925457328717318, 6.962908888361568, 5.932458582245491, 4.888428253276613, 3.959909626836482, 3.024791551029773, 2.0312123978682335, 1.0226297139461533, 0.9255756514236138, 1.8745372712871382, 2.9028423273167805, 3.931898156456904, 4.910401863736442, 5.976210033651645, 6.956032749411133, 7.896736148693007, 8.870847673036254, 9.815092146150223, 10.76473211553839, 9.828730310225994, 8.913793124874992, 7.931623186245874, 6.911287828475074, 5.886057585942979, 4.924348163735242, 3.9954848139580403, 2.977075179731153, 1.9793184710155884, 1.9336777448196365, 2.915504385531559, 3.848842428296694, 4.774229345940534, 5.81305880697439, 6.840638594149677, 7.7778140479407405, 8.746343809137562, 9.756323361937685, 10.6838571735674, 11.630004065222874, 10.731469867207611, 9.74095089566945, 8.811991947334326, 7.834181577409195, 6.85494405471139, 5.944588536627387, 4.899760654240624, 3.8467640835008807, 2.8840208040803126, 2.8777084876146852, 3.8918805365705045, 4.853063013162623, 5.8016470069560295, 6.783830544625282, 7.810952036228795, 8.752573597424153, 9.784984571938345, 10.776828637879346, 11.625611081489362, 12.651468151190349, 11.755355474154126, 10.806654666624008, 9.803411832168093, 8.773637878462834, 7.819458731206118, 6.795468962077091, 5.754398348966619, 4.746006055410228, 3.813451133843154, 3.888939860899277, 4.874163210490906, 5.835374090314059, 6.8327239525375125, 7.804280427520119, 8.837102863165791, 9.728865044315032, 10.76636655587151, 11.739748402764667, 12.56708511810002, 13.523686171459534, 12.686146780432939, 11.732242174280355, 10.677373297409208, 9.627127575645368, 8.656130410737227, 7.7265438106365885, 6.787588486284566, 5.736534271127384, 4.750537363717699, 4.858359001536151, 5.894760004938804, 6.872523770557875, 7.8005613617359, 8.735041056019151, 9.739585588513966, 10.675866685744605, 11.70312487512932, 12.667695511148827, 13.605299618150099, 14.520697131412543, 13.46035799022713, 12.521711154694401, 11.582312549636669, 10.553001380729693, 9.684551832722468, 8.78469348519424, 7.791766721589586, 6.7249491047723735, 5.717975967202781, 5.796438704296376, 6.801577779558567, 7.772281412918992, 8.753406489418186, 9.698773507706463, 10.683224052807965, 11.656367984032071, 12.598502777636488, 13.641980665643702, 14.551060095463153, 15.326775280597428, 14.401601821860385, 13.462641586781517, 12.516033046450985, 11.547733284855015, 10.646669537186876, 9.787388830254342, 8.738125407238979, 7.713432240396246, 6.698664492385809, 6.842660681087282, 7.8107769971242895, 8.754247258215612, 9.78115134413946, 10.632516154998875, 11.606144024634999, 12.674604056350717, 13.650311830078339, 14.570944462920801, 15.511768457214526, 16.302165081656714, 15.43287794147723, 14.486662171311679, 13.570678076586958, 12.504966514145153, 11.654301703324972, 10.66998830260245, 9.658366226475398, 8.69342137862141, 7.7153692250581685, 7.798718517733888, 8.72667162967953, 9.73459112905988, 10.758785318578012, 11.672085818246963, 12.562177700182943, 13.494840834714015, 14.440286622485921, 15.471387391824447, 16.396508722076454, 17.25351463995424, 16.487846980226514, 15.506181560704928, 14.500571805331663, 13.46562794595189, 12.571195900689336, 11.529841442667912, 10.60302761415457, 9.628774301729543, 8.64565647285167, 8.792375498302237, 9.696235212601882, 10.749620207078616, 11.792092212056188, 12.689507446087875, 13.621191619758308, 14.442102801536434, 15.469253244324294, 16.438269960367577, 17.398856609878912, 18.302982091020336, 17.41538424237124, 16.552422832415445, 15.566285150952886, 14.49677343297714, 13.504570779085945, 12.55197150450264, 11.608630349384672, 10.61510671185122, 9.648535791845198, 9.791717961417193, 10.636502782175732, 11.657085125465906, 12.62520462522476, 13.642327008178228, 14.567233491901126, 15.407026338855411, 16.34470073495374, 17.39687516418515, 18.32998106850296, 18.48122807580872, 17.516806191640093, 16.490203437646926, 15.605161502763831, 14.618507668357577, 13.663573688682341, 12.683463894230137, 11.694776517145558, 10.855773811069252, 10.075844682979737, 9.900909911565483, 10.842435292411043, 11.78732508993014, 12.78351991916907, 13.708881415154103, 14.443248791888086, 15.349730321966604, 16.317375681105847, 17.27266557220446, 18.241343394997884, 17.50990902419216, 16.4888375725534, 15.466110034372363, 14.581141019164695, 13.65434157151244, 12.737665735569951, 11.747051977979746, 10.73251125153309, 9.788605472243965, 9.020736532401786, 8.8416652792223, 9.832314443628473, 10.792673923497793, 11.855683805917582, 12.8274417727454, 13.5112224221685, 14.375666401899696, 15.357213136497428, 16.360701106314934, 17.365786351987865, 16.506493167641477, 15.55963242750103, 14.528812181841834, 13.630300617742419, 12.702902677572414, 11.710329530231009, 10.761873245395488, 9.802916613161969, 8.769505798379845, 8.01281924095183, 7.841330609169207, 8.787151438266653, 9.834777555620658, 10.893605622456064, 11.823694330810032, 12.436418784604738, 13.37095566571861, 14.393866520520751, 15.36631037140447, 16.366712616024714, 15.5529285323548, 14.530795718309946, 13.570271244968012, 12.686282487036049, 11.699711498920578, 10.737393167783164, 9.798614951741442, 8.783740847831513, 7.798425307961752, 6.964007556223791, 6.875223960899928, 7.93587721112719, 8.917904734476735, 9.864925259102204, 10.84233514696087, 11.463204444995457, 12.407492643325826, 13.429309426102483, 14.434341166101214, 15.364762598323145, 14.542526590324936, 13.579793849955994, 12.63878948183846, 11.678132247294425, 10.70700787377736, 9.784527465120044, 8.843433044206218, 7.9197638623108215, 6.871180000200886, 5.925226652345253, 5.964793946200602, 6.993949536406602, 7.897440743740842, 8.880059231228254, 9.778742564919991, 10.53607224781839, 11.503864150984702, 12.559443099757582, 13.56089230243118, 14.568457195358846, 13.614052414334383, 12.620656191158238, 11.675646068105657, 10.733213116604665, 9.727383668569844, 8.829057348614109, 7.821411178770033, 6.880558849326638, 5.9359919329922795, 4.969993728617401, 5.09292865634135, 5.9266513145445, 6.887303279210416, 7.879353506796817, 8.817245240599371, 9.593756346556216, 10.568944330838587, 11.588843466978647, 12.530598872464147, 13.576004360639354, 12.746710224559553, 11.721964271949009, 10.747671249159206, 9.81825241268746, 8.78508847471671, 7.860514991760499, 6.925578047866333, 5.868628273486136, 5.007627159734715, 4.043155287895558], [4.0148735096243975, 3.100245738349116, 3.937736870584461, 4.928612012057043, 5.890538379743361, 6.828945495391267, 7.856289309009244, 8.871173413736875, 9.810830550935975, 10.83525682868158, 11.883541391581979, 12.652767751506392, 11.586704237394885, 10.578311804459076, 9.590269946253791, 8.74132783865626, 7.783942359682668, 6.923938036724056, 5.9230119091152, 5.025051141584438, 2.995967731977821, 2.0449413923590924, 2.9472239922804575, 3.895761213484149, 4.860508950564202, 5.849743577074012, 6.913172281572274, 7.90516809536592, 8.95693072115933, 9.987077850389461, 10.94047353881934, 11.691085326275996, 10.632275386548974, 9.615848214131704, 8.663141950683137, 7.758708864846676, 6.858494682193364, 5.930172837529186, 4.87492191328267, 4.0357269427829365, 1.9522450789440944, 1.011089939121203, 1.9678495309497934, 2.934015251113447, 3.9328556839207773, 4.9456693282641915, 5.971237894841495, 6.9931264042684385, 7.957225951682878, 8.964480672213872, 9.97754274717633, 10.737393208361006, 9.685122978789764, 8.68914814435207, 7.714849371090308, 6.776216335564184, 5.826357602359439, 4.964726731687928, 3.9495237621995036, 2.9976944325276698, 0.9374140650202971, 0.0, 1.0228573459017796, 1.9514663654064297, 2.9907258769558043, 4.016167835878511, 4.964648613331082, 5.955757147733304, 6.941307497891584, 7.9180328887260485, 8.918483934422955, 9.826774674833741, 8.862871393737615, 7.900322953381865, 6.8698726472657885, 5.82584231829691, 4.897323691856779, 3.96220561605007, 2.9686264628885306, 1.9600437789664504, 1.8629897164439109, 0.9390139219776499, 1.967318978007292, 2.996374807147416, 3.972987798716144, 5.038795968631348, 6.018618684390836, 6.95932208367271, 7.933433608015957, 8.877678081129925, 9.827318050518093, 10.766144375246292, 9.85120718989529, 8.869037251266171, 7.848701893495371, 6.823471650963275, 5.861762228755539, 4.932898878978337, 3.9144892447514503, 2.9167325360358856, 2.8710918098399336, 1.9799810362220707, 2.9133190789872057, 3.8387059966310453, 4.8775354576649015, 5.9051152448401885, 6.842290698631253, 7.810820459828073, 8.820800012628196, 9.74833382425791, 10.694480715913384, 11.646882117171028, 10.678364960689745, 9.749406012354621, 8.77159564242949, 7.792358119731686, 6.882002601647683, 5.83717471926092, 4.784178148521177, 3.8214348691006097, 3.8151225526349823, 2.9788163723080436, 3.939998848900162, 4.866123657646541, 5.848307195315792, 6.875428686919307, 7.817050248114663, 8.849461222628857, 9.841305288569856, 10.690087732179872, 11.715944801880859, 12.645052424951908, 11.744068731644303, 10.74082589718839, 9.711051943483131, 8.756872796226414, 7.7328830270973885, 6.691812413986916, 5.683420120430525, 4.750865198863451, 4.826353925919574, 3.961099046228445, 4.922309926051598, 5.897200603228024, 6.86875707821063, 7.901579513856302, 8.793341695005543, 9.830843206562022, 10.804225053455177, 11.63156176879053, 12.588162822150045, 13.576981830917523, 12.669656239300652, 11.614787362429505, 10.564541640665665, 9.593544475757524, 8.663957875656886, 7.725002551304863, 6.6739483361476815, 5.687951428737996, 5.795773066556448, 4.981695840676343, 5.959459606295413, 6.887497197473438, 7.799517706709662, 8.804062239204479, 9.740343336435117, 10.767601525819833, 11.732172161839339, 12.66977626884061, 13.600206013861817, 14.39777205524743, 13.459125219714698, 12.519726614656966, 11.49041544574999, 10.621965897742765, 9.722107550214535, 8.729180786609884, 7.662363169792671, 6.655390032223078, 6.733852769316673, 5.9684584069407425, 6.939162040301167, 7.883092299546464, 8.763250158396973, 9.747700703498477, 10.720844634722583, 11.662979428327, 12.706457316334214, 13.615536746153666, 14.568797010674448, 15.339015886880683, 14.400055651801814, 13.453447111471283, 12.485147349875312, 11.584083602207173, 10.724802895274637, 9.675539472259276, 8.650846305416543, 7.6360785574061065, 7.780074746107579, 6.977657624506465, 7.9211278855977865, 8.910837154267737, 9.696992805689385, 10.670620675325509, 11.739080707041227, 12.714788480768851, 13.635421113611313, 14.576245107905038, 15.544186811733733, 16.37029200649753, 15.424076236331977, 14.508092141607257, 13.44238057916545, 12.591715768345269, 11.607402367622747, 10.595780291495695, 9.630835443641708, 8.652783290078466, 8.736132582754184, 7.924079184147774, 8.901471756442053, 9.88847112870629, 10.736562468937471, 11.626654350873453, 12.559317485404526, 13.504763273176431, 14.535864042514957, 15.460985372766963, 16.440854750635484, 17.425261045246813, 16.443595625725226, 15.43798587035196, 14.403042010972188, 13.508609965709631, 12.467255507688208, 11.540441679174865, 10.566188366749838, 9.583070537871968, 9.729789563322534, 8.893642767070126, 9.94702776154686, 10.921778022184466, 11.753984096778384, 12.685668270448819, 13.506579452226944, 14.533729895014805, 15.50274661105809, 16.46333326056942, 17.431359898797705, 17.47605243010676, 16.488975098582248, 15.687467497989099, 14.617036484230844, 13.733798095869556, 12.932797925337956, 12.030402694970705, 11.119182963050978, 10.585949856865497, 10.72913202643749, 9.833910336643976, 10.85449267993415, 11.822612179693003, 12.706803658868736, 13.631710142591636, 14.471502989545922, 15.409177385644252, 16.461351814875663, 17.39445771919347, 17.543814010788424, 16.579392126619794, 15.552789372626625, 14.667747437743532, 13.68109360333728, 12.726159623662042, 11.878541975880506, 10.979505892718503, 10.140503186642196, 11.009741716926547, 10.834806945512293, 10.844661696326709, 11.857447003404221, 12.818909009923967, 13.677629672943883, 14.673675930867649, 15.511038378449197, 16.389577907798696, 17.344867798897308, 17.531139958243024, 16.572494959171866, 15.551423507533102, 14.528695969352064, 13.643726954144398, 12.716927506492143, 11.800251670549653, 10.86177873941114, 10.017240627106036, 9.073334847816911, 9.954633566348596, 9.77556231316911, 10.766211477575283, 11.726570957444602, 12.789580839864392, 13.76133880669221, 14.448636487188795, 15.313080466919992, 16.294627201517724, 17.29811517133523, 16.609654580177192, 15.569079102621181, 14.622218362480734, 13.591398116821537, 12.692886552722122, 11.765488612552117, 10.772915465210712, 9.860556114906334, 9.057391048932132, 8.05423517395279, 8.94671627489864, 8.775227643116017, 9.721048472213463, 10.768674589567468, 11.827502656402874, 12.757591364756841, 13.373832849625034, 14.308369730738905, 15.331280585541046, 16.303724436424766, 15.683642690547474, 14.615514467334503, 13.593381653289649, 12.632857179947715, 11.748868422015752, 10.762297433900281, 9.799979102762867, 8.861257194491703, 8.038215283601676, 7.083154683534697, 7.8979045901706, 7.809120994846737, 8.869774245073998, 9.851801768423543, 10.798822293049012, 11.77623218090768, 12.400618510015752, 13.344906708346121, 14.366723491122778, 15.37175523112151, 14.652062122750307, 13.60511252530464, 12.642379784935699, 11.701375416818163, 10.740718182274128, 9.769593808757064, 8.847113400099747, 7.9060752869564785, 7.013080744274767, 6.155909375773831, 6.859123686292062, 6.898690980147411, 7.927846570353411, 8.83133777768765, 9.813956265175062, 10.7126395988668, 11.473486312838686, 12.441278216004998, 13.496857164777877, 14.498306367451475, 13.748234607958029, 12.676638349314086, 11.68324212613794, 10.73823200308536, 9.795799051584368, 8.789969603549547, 7.891643283593812, 6.884053421520292, 5.943201092076897, 5.136637692231757, 5.90389076256421, 6.02682569028816, 6.860548348491309, 7.821200313157225, 8.813250540743626, 9.75114227454618, 10.531170411576511, 11.506358395858882, 12.526257531998942, 13.468012937484442, 12.88086330940453, 11.809296159539256, 10.784550206928712, 9.810257184138909, 8.880838347667163, 7.847674409696413, 6.923100926740202, 5.988163982846036, 4.931214208465838, 4.0702130947144175, 4.977052321842367], [4.89204352965489, 3.9330682743819594, 2.953731260944747, 3.944606402417328, 4.906532770103646, 5.844939885751552, 6.87228369936953, 7.88716780409716, 8.82682494129626, 9.851251219041865, 10.860684045680198, 11.851101400031455, 12.609561583296664, 11.601169150360855, 10.61312729215557, 9.670841412673727, 8.713455933700136, 7.853451610741523, 6.852525483132667, 5.90222116161493, 3.9254813059952878, 2.97445496637656, 1.9632183826407434, 2.9117556038444343, 3.8765033409244873, 4.865737967434297, 5.92916667193256, 6.921162485726206, 7.950805797487204, 8.964220504487681, 9.91761619291756, 10.87765826662271, 11.655132732450753, 10.638705560033483, 9.685999296584916, 8.781566210748455, 7.788008256210832, 6.859686411546654, 5.804435487300138, 4.965240516800404, 2.8817586529615613, 1.94060351313867, 0.9838439213100795, 1.9500096414737331, 2.9488500742810633, 3.961663718624478, 4.948380548939716, 5.97026905836666, 6.934368605781099, 7.941623326312094, 8.954685401274551, 9.88547839006372, 10.707980324691542, 9.712005490253848, 8.737706716992086, 7.799073681465963, 6.849214948261217, 5.894240305705395, 4.879037336216971, 3.927208006545137, 1.9602714109220767, 1.0228573459017796, 0.0, 0.9286090195046501, 1.967868531054025, 2.9933104899767318, 3.9417912674293034, 4.9328998018315255, 5.918450151989806, 6.89517554282427, 7.895626588521177, 8.963801918545677, 9.885728739639395, 8.923180299283645, 7.892729993167569, 6.848699664198691, 5.920181037758558, 4.985062961951849, 3.99148380879031, 2.98290112486823, 2.8858470623456904, 1.9618712678794294, 1.0559816395449344, 1.9931274552022242, 2.950130452814365, 4.015938622729568, 4.995761338489057, 5.936464737770931, 6.910576262114178, 7.854820735228146, 8.804460704616313, 9.871580028947694, 10.87406453579707, 9.891894597167951, 8.87155923939715, 7.846328996865054, 6.884619574657318, 5.955756224880116, 4.937346590653229, 3.939589881937665, 3.893949155741713, 2.9512196369598733, 2.001981740524848, 2.927368658168688, 3.892693289434742, 4.920273076610028, 5.857448530401092, 6.825978291597912, 7.835957844398035, 8.76349165602775, 9.709638547683223, 10.662039948940867, 11.652558920479029, 10.7722633582564, 9.794452988331269, 8.815215465633464, 7.904859947549463, 6.8600320651627005, 5.807035494422957, 4.844292215002389, 4.837979898536761, 3.9500549730458463, 3.07580182143745, 3.9547863191841834, 4.863465027085633, 5.890586518689147, 6.832208079884504, 7.864619054398696, 8.856463120339695, 9.705245563949711, 10.731102633650698, 11.660210256721747, 12.642378097893312, 11.76368324309017, 10.733909289384911, 9.779730142128194, 8.755740372999167, 7.714669759888695, 6.7062774663323035, 5.77372254476523, 5.849211271821353, 4.932337646966248, 4.058112898588886, 4.985863264765666, 5.888820875965029, 6.916737345626142, 7.808499526775383, 8.84600103833186, 9.819382885225016, 10.646719600560369, 11.603320653919884, 12.592139662687362, 13.546044268839946, 12.637644708331283, 11.587398986567443, 10.616401821659302, 9.686815221558664, 8.747859897206641, 7.69680568204946, 6.710808774639775, 6.818630412458227, 5.952934441414146, 5.095262578832701, 6.023300170010726, 6.819581504464061, 7.824126036958877, 8.760407134189517, 9.787665323574233, 10.752235959593738, 11.684934100610448, 12.615363845631656, 13.614502495305357, 14.481982565616477, 13.542583960558744, 12.513272791651769, 11.644823243644543, 10.744964896116315, 9.752038132511663, 8.68522051569445, 7.678247378124857, 7.7567101152184526, 6.9396970076785465, 6.1282375448179955, 7.018895272083752, 7.783313956151372, 8.767764501252877, 9.740908432476983, 10.6830432260814, 11.726521114088614, 12.630694577923503, 13.583954842444287, 14.50912830118133, 15.422912997703593, 14.476304457373061, 13.50800469577709, 12.606940948108951, 11.747660241176417, 10.698396818161054, 9.673703651318322, 8.658935903307885, 8.802932092009359, 7.948896225244269, 7.110203390114615, 8.046640126805025, 8.717056603443783, 9.690684473079907, 10.759144504795625, 11.73485227852325, 12.655484911365713, 13.591402939674875, 14.559344643503572, 15.53817081492354, 16.446933582233754, 15.530949487509034, 14.465237925067228, 13.614573114247047, 12.630259713524525, 11.618637637397473, 10.653692789543486, 9.675640635980244, 9.758989928655964, 8.895317784885577, 8.090547260958882, 9.024274101243577, 9.756626266691871, 10.646718148627851, 11.579381283158924, 12.52482707093083, 13.555927840269355, 14.481049170521361, 15.460918548389884, 16.465667858635303, 16.551210760653053, 15.69912022099615, 14.664176361616377, 13.820873314774566, 12.970922377532968, 12.139517270174846, 11.589045712651618, 10.605927883773745, 10.752646909224314, 9.86488136780793, 9.149272944529482, 10.057580994721754, 10.774047894532783, 11.705732068203217, 12.526643249981342, 13.553793692769203, 14.522810408812488, 15.483397058323819, 16.451423696552105, 16.492046820467046, 15.504969488942535, 14.703461888349382, 13.633030874591128, 12.74979248622984, 11.94879231569824, 11.133914534944743, 11.886307669590764, 11.608807202767274, 11.75198937233927, 10.80514893738178, 10.18994841362053, 11.046790808379836, 11.726867456623136, 12.651773940346034, 13.49156678730032, 14.42924118339865, 15.481415612630062, 16.414521516947865, 16.55980840114871, 15.595386516980083, 14.568783762986913, 13.683741828103816, 12.697087993697563, 11.742154014022326, 10.89453636624079, 10.083017732692541, 10.907627893181981, 11.854197333715936, 11.711976965542785, 11.815900297064513, 11.1929027370906, 12.0430876386108, 12.697693470698283, 13.693739728622049, 14.531102176203595, 15.409641705553092, 16.364931596651704, 16.54713434860331, 15.588489349532153, 14.567417897893389, 13.544690359712352, 12.659721344504682, 11.732921896852426, 10.816246060909936, 9.877773129771425, 9.120752467080074, 9.840459554356697, 10.815726170103712, 10.652732333199602, 11.643381497605775, 12.187553903522948, 12.973957953823625, 13.72362184523158, 14.625766098341636, 15.505166096270504, 16.36980425016151, 16.65491487936032, 15.62564897053748, 14.585073492981467, 13.638212752841019, 12.607392507181823, 11.708880943082407, 10.7814830029124, 9.788909855570996, 8.87655050526662, 8.073385439292418, 8.821359880492576, 9.807808878653756, 9.652397663146509, 10.598218492243955, 11.645844609597958, 12.704672676433365, 13.63653466834639, 14.396690195526812, 15.331227076640683, 16.354137931442825, 15.660524144449855, 14.69963708090776, 13.631508857694788, 12.609376043649934, 11.648851570308, 10.764862812376037, 9.778291824260565, 8.81597349312315, 7.877251584851988, 7.054209673961962, 7.8502793900744825, 8.775074610201091, 8.686291014877229, 9.74694426510449, 10.774828230636864, 11.721848755262332, 12.70574575492515, 13.42347585591753, 14.3677640542479, 15.389580837024557, 14.59847794533252, 13.66805651311059, 12.621106915664924, 11.658374175295982, 10.717369807178448, 9.756712572634413, 8.785588199117349, 7.863107790460032, 6.922069677316765, 6.029075134635052, 6.923034082313617, 7.736293706322554, 7.775861000177903, 8.833974470954466, 9.760851351705117, 10.743469839192528, 11.64215317288427, 12.496343658740464, 13.464135561906776, 14.519714510679655, 13.77179389124598, 12.764228998318314, 11.692632739674371, 10.699236516498226, 9.754226393445645, 8.811793441944655, 7.805963993909834, 6.907637673954097, 5.900047811880579, 4.959195482437184, 5.903762398771542, 6.781060782594702, 6.903995710318652, 7.790061922508777, 8.750713887174692, 9.742764114761094, 10.68065584856365, 11.55402775747829, 12.52921574176066, 13.54911487790072, 12.890938607191687, 11.869871395857484, 10.825290549899542, 9.800544597288997, 8.826251574499194, 7.896832738027449, 6.863668800056699, 5.939095317100487, 5.004158373206321, 3.947208598826124, 4.903035630747261, 5.854222341872859], [5.82065254915954, 4.8616772938866095, 3.882340280449397, 3.0961428464297636, 4.021077495735638, 4.9594846113835445, 5.972628332390775, 6.987512437118405, 7.927169574317506, 8.951595852063111, 9.93207502617555, 10.922492380526807, 11.988555894638314, 12.529778169865505, 11.54173631166022, 10.599450432178378, 9.642064953204786, 8.782060630246173, 7.781134502637317, 6.83083018111958, 4.8540903254999375, 3.90306398588121, 2.8918274021453936, 2.054341445450217, 2.9910480665564796, 3.9802826930662896, 5.022501628770586, 6.014497442564232, 7.022196777982554, 8.035611484983033, 8.989007173412912, 9.949049247118062, 10.973834695740694, 11.567314579538133, 10.614608316089566, 9.710175230253105, 8.716617275715482, 7.788295431051304, 6.733044506804788, 5.893849536305054, 3.8103676724662114, 2.86921253264332, 1.9124529408147297, 1.0645543671057252, 2.0633947999130555, 3.048030617163458, 4.019771529435066, 5.04166003886201, 6.005759586276449, 7.0130143068074435, 8.0260763817699, 8.95686937055907, 9.958619070065161, 10.640614509758498, 9.666315736496736, 8.727682700970613, 7.777823967765867, 6.822849325210045, 5.807646355721621, 4.855817026049787, 2.8888804304267266, 1.9514663654064297, 0.9286090195046501, 0.0, 1.0392595115493748, 2.0647014704720816, 3.0131822479246533, 4.004290782326875, 4.9898411324851555, 5.96656652331962, 6.967017569016527, 8.035192899041027, 8.999096180137153, 9.851789318788295, 8.821339012672219, 7.777308683703341, 6.8487900572632086, 5.913671981456499, 4.92009282829496, 3.9115101443728797, 3.8144560818503406, 2.8904802873840794, 1.9845906590495845, 1.064518435697574, 2.0215214333097147, 3.087329603224918, 4.067152318984407, 5.007855718266281, 5.981967242609528, 6.926211715723496, 7.875851685111663, 8.942971009443045, 9.977589145459394, 10.820503616672601, 9.8001682589018, 8.774938016369704, 7.813228594161968, 6.8843652443847665, 5.865955610157879, 4.868198901442315, 4.822558175246363, 3.8798286564645235, 2.930590760029498, 2.1195651736886436, 2.9640842699300918, 3.9916640571053787, 4.9288395108964425, 5.897369272093263, 6.907348824893385, 7.8348826365231, 8.781029528178573, 9.733430929436217, 10.723949900974379, 11.652908849309503, 10.72306200783592, 9.743824485138115, 8.833468967054113, 7.788641084667351, 6.735644513927607, 5.772901234507039, 5.766588918041411, 4.878663992550496, 4.0044108409421, 3.146982834704139, 3.934856007580983, 4.961977499184497, 5.903599060379854, 6.936010034894046, 7.927854100835047, 8.776636544445063, 9.802493614146048, 10.731601237217097, 11.713769078388662, 12.666578017784287, 11.66251830888956, 10.708339161632843, 9.684349392503817, 8.643278779393345, 7.634886485836954, 6.70233156426988, 6.7778202913260035, 5.860946666470898, 4.9867219180935365, 4.178059780285622, 4.960211856460379, 5.988128326121493, 6.879890507270733, 7.917392018827211, 8.890773865720368, 9.71811058105572, 10.674711634415235, 11.663530643182712, 12.617435249335294, 13.566253727835933, 12.516008006072093, 11.545010841163952, 10.615424241063314, 9.676468916711292, 8.62541470155411, 7.639417794144425, 7.7472394319628775, 6.881543460918796, 6.023871598337351, 5.231700884409404, 5.890972484959411, 6.895517017454227, 7.831798114684867, 8.859056304069583, 9.823626940089088, 10.7563250811058, 11.686754826127007, 12.685893475800707, 13.581321510571037, 14.471192980063394, 13.441881811156419, 12.573432263149193, 11.673573915620963, 10.680647152016313, 9.6138295351991, 8.606856397629507, 8.685319134723104, 7.868306027183197, 7.056846564322646, 6.22729598648243, 6.854704936646722, 7.839155481748226, 8.812299412972333, 9.75443420657675, 10.797912094583964, 11.702085558418855, 12.655345822939639, 13.58051928167668, 14.519479516755549, 15.404913476877711, 14.43661371528174, 13.535549967613601, 12.676269260681066, 11.627005837665704, 10.602312670822972, 9.587544922812535, 9.73154111151401, 8.877505244748919, 8.038812409619265, 7.255040841203703, 7.788447583939134, 8.762075453575257, 9.830535485290975, 10.8062432590186, 11.726875891861063, 12.662793920170227, 13.630735623998923, 14.609561795418891, 15.543500101285712, 15.805094081496915, 14.739382519055107, 13.911766320308717, 13.239987138942862, 12.547246656902123, 11.582301809048136, 10.604249655484894, 10.687598948160616, 9.823926804390227, 9.019156280463532, 8.232674815642255, 8.828017247187221, 9.718109129123201, 10.650772263654273, 11.59621805142618, 12.627318820764705, 13.552440151016711, 14.532309528885234, 15.537058839130655, 15.665755486285047, 14.813664946628142, 13.77872108724837, 12.93541804040656, 12.301188379204465, 13.068126289679496, 12.517654732156267, 11.534536903278397, 11.681255928728966, 10.79349038731258, 10.077881964034132, 9.265981709120432, 9.845438875028133, 10.777123048698567, 11.598034230476692, 12.625184673264553, 13.594201389307838, 14.554788038819169, 15.522814677047453, 15.606591546099038, 14.61951421457453, 13.818006613981375, 12.74757560022312, 11.864337211861834, 11.279058317369737, 12.062523554449394, 12.814916689095416, 12.537416222271926, 12.680598391843922, 11.73375795688643, 11.11855743312518, 10.255191522778514, 10.798258437118486, 11.723164920841384, 12.56295776779567, 13.500632163894, 14.552806593125412, 15.485912497443216, 15.665599991336864, 14.709931242612077, 13.683328488618907, 12.79828655373581, 11.811632719329555, 10.85669873965432, 10.224802367912286, 11.011626752197191, 11.836236912686633, 12.782806353220588, 12.640585985047435, 12.744509316569163, 12.12151175659525, 11.251488353009478, 11.769084451193633, 12.765130709117399, 13.602493156698944, 14.481032686048442, 15.436322577147054, 15.652925938791464, 14.694280939720306, 13.681962623525383, 12.659235085344346, 11.774266070136674, 10.847466622484419, 9.93079078654193, 9.20803913144292, 10.049361486584724, 10.769068573861347, 11.744335189608362, 11.581341352704252, 12.571990517110425, 13.116162923027598, 12.182358668222303, 12.79501282572693, 13.697157078836986, 14.576557076765852, 15.44119523065686, 15.755259512381567, 14.731440560725632, 13.69086508316962, 12.752757478473013, 11.721937232813817, 10.823425668714401, 9.896027728544393, 8.903454581202988, 8.206816506938114, 9.001994458797068, 9.749968899997226, 10.736417898158406, 10.581006682651159, 11.526827511748605, 12.57445362910261, 13.15502457112943, 13.7987602676623, 14.771960716400747, 15.581267812946937, 15.733312628354822, 14.760868777471103, 13.805428671095912, 12.73730044788294, 11.723920769281929, 10.763396295939994, 9.879407538008032, 8.892836549892557, 7.930518218755143, 7.207517586523483, 7.982818693466612, 8.778888409579134, 9.703683629705742, 9.61490003438188, 10.67555328460914, 11.703437250141514, 12.650457774766982, 13.634354774429799, 14.35208487542218, 15.29637307375255, 14.7038543183525, 13.698822578353768, 12.768401146131838, 11.721451548686172, 10.75871880831723, 9.831914532810442, 8.871257298266407, 7.900132924749342, 6.977652516092024, 6.25233567898826, 6.957684154139702, 7.851643101818267, 8.664902725827204, 8.704470019682553, 9.762583490459116, 10.689460371209769, 11.67207885869718, 12.57076219238892, 13.424952678245115, 14.392744581411426, 13.874684625951474, 12.872138524267228, 11.86457363133956, 10.792977372695617, 9.799581149519472, 8.85457102646689, 7.926338167576647, 6.920508719541826, 6.0221823995860895, 5.2303138135520735, 5.887804501941834, 6.8323714182761925, 7.709669802099352, 7.832604729823302, 8.718670942013427, 9.679322906679342, 10.671373134265744, 11.609264868068298, 12.48263677698294, 13.45782476126531, 12.904084993172539, 11.962329587687039, 10.941262376352835, 9.925635182920786, 8.900889230310241, 7.926596207520439, 6.997177371048694, 5.978213525688691, 5.0536400427324795, 4.155694817218757, 4.875817618330775, 5.831644650251911, 6.782831361377509], [6.859912060708915, 5.900936805435984, 4.921599791998772, 4.047754601856515, 3.0195199622254667, 3.957927077873373, 4.9333688208414, 5.94825292556903, 6.887910062768131, 7.912336340513736, 8.892815514626175, 9.883232868977432, 10.949296383088939, 11.913465946935961, 12.580995823209594, 11.638709943727752, 10.68132446475416, 9.821320141795548, 8.820394014186691, 7.870089692668955, 5.893349837049313, 4.942323497430585, 3.9310869136947684, 3.049340926824141, 1.989490533046308, 2.978725159556118, 3.983242117221211, 4.975237931014857, 5.982937266433179, 6.996351973433657, 7.949747661863537, 8.909789735568687, 9.934575184191319, 10.951002356608589, 11.65386782763894, 10.74943474180248, 9.755876787264857, 8.82755494260068, 7.772304018354163, 6.933109047854429, 4.849627184015587, 3.908472044192695, 2.9517124523641045, 2.0606776992102143, 1.0618372664028837, 2.008771105614083, 2.980512017885691, 4.002400527312635, 4.966500074727074, 5.973754795258069, 6.986816870220526, 7.917609859009696, 8.919359558515787, 9.910121408160284, 10.705575248046111, 9.766942212519988, 8.817083479315242, 7.86210883675942, 6.846905867270996, 5.895076537599162, 3.9281399419761014, 2.9907258769558043, 1.967868531054025, 1.0392595115493748, 0.0, 1.0254419589227068, 1.9739227363752785, 2.9650312707775006, 3.9505816209357807, 4.927307011770245, 5.927758057467152, 6.995933387491652, 7.959836668587778, 8.922385108943528, 9.860598524221594, 8.816568195252716, 7.888049568812583, 6.952931493005874, 5.959352339844335, 4.9507696559222545, 4.853715593399715, 3.929739798933454, 3.0208201971565605, 1.9917643680164367, 0.98226192176034, 2.048070091675543, 3.027892807435032, 3.9685962067169065, 4.942707731060153, 5.886952204174121, 6.8365921735622885, 7.903711497893671, 8.93832963391002, 9.89453830927872, 10.839427770451175, 9.81419752791908, 8.852488105711343, 7.923624755934141, 6.905215121707254, 5.90745841299169, 5.861817686795738, 4.838279033493438, 3.8890411370584133, 2.9636542194145736, 1.924824758380717, 2.952404545556004, 3.8895799993470677, 4.858109760543888, 5.868089313344011, 6.795623124973726, 7.741770016629198, 8.694171417886842, 9.684690389425004, 10.613649337760128, 11.591459707685258, 10.78308399668749, 9.872728478603488, 8.827900596216725, 7.774904025476982, 6.8121607460564135, 6.805848429590786, 5.837114369579411, 4.962861217971016, 3.9644895616808746, 2.895596496031608, 3.9227179876351226, 4.864339548830479, 5.8967505233446715, 6.888594589285672, 7.737377032895688, 8.763234102596673, 9.692341725667722, 10.674509566839287, 11.627318506234912, 12.543939631114297, 11.747598673182218, 10.723608904053192, 9.68253829094272, 8.674145997386328, 7.7415910758192545, 7.817079802875378, 6.819397043499813, 5.9023863228595195, 4.892508819893611, 3.9209523449110044, 4.948868814572118, 5.840630995721358, 6.8781325072778365, 7.851514354170993, 8.678851069506345, 9.63545212286586, 10.624271131633337, 11.57817573778592, 12.631004213349408, 13.555267517621468, 12.584270352713327, 11.654683752612689, 10.715728428260666, 9.664674213103485, 8.6786773056938, 8.783900362551206, 7.720715565241468, 6.727014882082031, 5.798977290904006, 4.851712973410036, 5.8562575059048525, 6.792538603135492, 7.819796792520208, 8.784367428539714, 9.717065569556425, 10.647495314577633, 11.646633964251333, 12.542061999021662, 13.481460604079395, 14.481141322705794, 13.612691774698568, 12.712833427170338, 11.719906663565688, 10.653089046748475, 9.646115909178882, 9.712617206768059, 8.707478131505868, 7.754459384190418, 6.773334307691224, 5.815445425097347, 6.799895970198851, 7.773039901422958, 8.715174695027375, 9.75865258303459, 10.66282604686948, 11.616086311390264, 12.541259770127306, 13.480220005206174, 14.415181100893712, 14.695058214835074, 13.97291843193971, 13.71552877223044, 12.66626534921508, 11.641572182372347, 10.62680443436191, 10.71521742939357, 9.680544895569962, 8.736425229487038, 7.7498561113046325, 6.749188072389759, 7.722815942025883, 8.7912759737416, 9.766983747469226, 10.687616380311688, 11.623534408620852, 12.591476112449548, 13.570302283869516, 14.504240589736337, 14.803536547986742, 13.737824985544936, 12.910208786798544, 13.77630777450809, 13.586506168451498, 12.621561320597511, 11.643509167034269, 11.554919567156913, 10.62696645521127, 9.716769100331305, 8.727490085743185, 7.788757735637846, 8.678849617573828, 9.6115127521049, 10.556958539876806, 11.588059309215332, 12.513180639467338, 13.493050017335861, 14.497799327581282, 14.661982740447193, 13.812107413117971, 12.777163553738198, 11.933860506896387, 12.837509014769694, 13.764322843283036, 13.53794231073333, 12.510524945549829, 12.548576547725263, 11.596530038133624, 10.775494783901905, 9.760796979221361, 8.806179363478758, 9.737863537149194, 10.55877471892732, 11.58592516171518, 12.554941877758464, 13.515528527269796, 14.483555165498082, 14.602818800261185, 13.615741468736676, 12.816449080471203, 11.74601806671295, 10.86277967835166, 11.815378952934966, 12.804079336229645, 13.84676048531891, 13.513404264543357, 13.54791901084022, 12.536797607707474, 11.718126292638296, 10.750006792879443, 9.758998925569111, 10.683905409292011, 11.523698256246297, 12.461372652344627, 13.51354708157604, 14.446652985893842, 14.626340479787489, 13.706158496774224, 12.679555742781053, 11.796729020225637, 10.810075185819384, 9.855141206144147, 10.838848713082815, 11.827536090167394, 12.868080708910128, 13.814650149444082, 13.67984549659681, 13.547548967390206, 12.651381264868219, 11.65518643562929, 10.729824939644258, 11.725871197568024, 12.563233645149571, 13.441773174499069, 14.397063065597681, 14.613666427242089, 13.655021428170931, 12.67818987768753, 11.655462339506492, 10.772708536626503, 9.845909088974247, 8.929233253031757, 9.88274398523479, 10.88784502075116, 11.808328085410722, 12.783594701157737, 12.620600864253626, 13.6112500286598, 13.646032431300567, 12.586056750842115, 11.755753314177555, 12.65789756728761, 13.53729756521648, 14.401935719107486, 14.716000000832192, 13.692181049176257, 12.651605571620244, 11.748984732635162, 10.718164486975965, 9.82186813520423, 8.894470195034222, 7.901897047692816, 8.881521360729984, 9.840477992963503, 10.7892284115466, 11.77567740970778, 11.620266194200534, 12.56608702329798, 13.613713140651985, 13.558722653749241, 12.759500756112924, 13.732701204851372, 14.542008301397566, 14.694053116805447, 13.721609265921728, 12.766169159546537, 11.698040936333566, 10.720148023444077, 9.759623550102143, 8.87785000449786, 7.891279016382384, 6.928960685244971, 7.882439251157525, 8.912333126842617, 9.818147921128508, 10.742943141255116, 10.654159545931254, 11.714812796158515, 12.742696761690889, 13.689717286316357, 13.740859939962085, 14.705915544460654, 14.686411589579782, 13.664594806803125, 12.659563066804393, 11.729141634582463, 10.682192037136797, 9.719459296767855, 8.82814178697259, 7.869699764756236, 6.898575391239171, 5.976094982581852, 6.927257343622301, 7.982960454685294, 8.890902613367642, 9.704162237376579, 9.743729531231928, 10.801843002008491, 11.72871988275914, 12.711338370246551, 13.610021703938294, 14.46421218979449, 13.776432358481882, 12.8354251144021, 11.832879012717854, 10.825314119790185, 9.753717861146242, 8.760321637970097, 7.815311514917515, 6.924780634066476, 5.918951186031655, 5.020624866075917, 6.039851850049947, 6.927064013491209, 7.871630929825567, 8.748929313648727, 8.871864241372677, 9.7579304535628, 10.718582418228715, 11.710632645815119, 12.648524379617673, 13.521896288532314, 12.841512538335767, 11.864825481623164, 10.923070076137664, 9.90200286480346, 8.886375671371411, 7.8616297187608675, 6.887336695971064, 5.957917859499319, 4.97665599217852, 4.052082509222307, 5.041347848308547, 5.915077129880149, 6.870904161801286, 7.822090872926884], [7.861008819673885, 6.902033564400955, 5.922696550963742, 4.982060126488422, 3.9538254868573737, 3.0021307939081785, 3.9079268619186927, 4.922810966646323, 5.862468103845424, 6.886894381591029, 7.867373555703468, 8.857790910054725, 9.923854424166231, 10.888023988013254, 11.734398797662822, 12.648146435369423, 11.690760956395831, 10.830756633437218, 9.829830505828362, 8.871186451633925, 6.902786328690984, 5.951682735318702, 4.932183672659739, 3.983646451456048, 2.923796057678215, 2.0229288755909236, 2.957800158298504, 3.94979597209215, 4.957495307510473, 5.970910014510951, 6.9243057029408295, 7.88434777664598, 8.909133225268612, 9.925560397685881, 10.807270802092168, 11.774876700725187, 10.765313278906527, 9.83699143424235, 8.781740509995833, 7.942545539496099, 5.859063675657257, 4.917908535834366, 3.961148944005775, 2.9949832238421212, 1.9961427910347909, 0.9833291466913762, 1.9550700589629844, 2.9769585683899287, 3.941058115804368, 4.948312836335362, 5.961374911297819, 6.892167900086989, 7.893917599593079, 8.884679449237577, 9.858978222499339, 10.792384171442695, 9.84252543823795, 8.87154532840109, 7.856342358912666, 6.9045130292408325, 4.953581900898809, 4.016167835878512, 2.9933104899767318, 2.0647014704720816, 1.0254419589227068, 0.0, 0.9484807774525718, 1.9395893118547938, 2.925139662013074, 3.9018650528475383, 4.9023160985444445, 5.970491428568945, 6.934394709665071, 7.896943150020821, 8.927393456136897, 9.842010154175423, 8.91349152773529, 7.978373451928581, 6.984794298767042, 5.976211614844962, 5.879157552322423, 4.955181757856161, 4.046262156079267, 3.017206326939143, 2.0077038806830467, 1.0559586931640024, 2.0024508485123254, 2.9431542477942, 3.917265772137447, 4.861510245251415, 5.811150214639582, 6.878269538970964, 7.912887674987314, 8.869096350356013, 9.889431708126814, 10.839639486841786, 9.87793006463405, 8.949066714856848, 7.930657080629961, 6.932900371914397, 6.887259645718445, 5.863720992416145, 4.91448309598112, 3.98909617833728, 2.950266717303424, 2.1067632195083617, 3.0439386732994254, 3.9054611149286638, 4.849219129772632, 5.776752941402347, 6.72289983305782, 7.675301234315464, 8.665820205853626, 9.59477915418875, 10.57258952411388, 11.551827046811685, 10.898170437526195, 9.853342555139433, 8.800345984399689, 7.837602704979121, 7.8312903885134935, 6.862556328502118, 5.988303176893721, 4.989931520603582, 3.921038454954315, 3.0770766615874803, 4.018698222782837, 4.944101877729447, 5.869724405714294, 6.71850684932431, 7.744363919025295, 8.673471542096344, 9.655639383267909, 10.608448322663534, 11.525069447542919, 12.479248594799635, 11.7490508629759, 10.707980249865427, 9.699587956309035, 8.767033034741962, 8.842521761798086, 7.844839002422519, 6.927828281782226, 5.9179507788163175, 4.946394303833711, 4.103227488524476, 4.994989669673716, 5.925483861662611, 6.832644170599615, 7.659980885934968, 8.616581939294482, 9.605400948061959, 10.559305554214543, 11.61213402977803, 12.598427915658025, 13.53330777985541, 12.680125711535396, 11.741170387183374, 10.690116172026192, 9.704119264616507, 9.809342321473911, 8.746157524164174, 7.7524568410047365, 6.824419249826712, 5.8771549323327426, 5.145558597999562, 6.061518561683702, 6.929531883670201, 7.852007983242938, 8.698195385985048, 9.628625131006254, 10.627763780679954, 11.523191815450286, 12.462590420508018, 13.491901589414994, 14.479578815874117, 13.738275386093047, 12.745348622488395, 11.678531005671182, 10.671557868101589, 10.738059165690764, 9.732920090428573, 8.779901343113124, 7.798776266613929, 6.8408873840200535, 6.089197062293561, 7.0447257258248115, 7.906211490738214, 8.92081378271805, 9.643955863298103, 10.597216127818886, 11.522389586555928, 12.461349821634796, 13.396310917322335, 13.797712371123586, 14.79353880882745, 14.74097073115315, 13.691707308137786, 12.667014141295054, 11.652246393284617, 11.740659388316276, 10.705986854492668, 9.761867188409743, 8.77529807022734, 7.774630031312466, 7.152961043202428, 8.093144925167811, 8.958020543180064, 9.849777579995148, 10.604664225049476, 11.57260592887817, 12.551432100298138, 13.485370406164957, 13.906190704275254, 12.840479141833448, 13.791287688528554, 14.710613299139997, 14.611948127374205, 13.647003279520218, 12.668951125956976, 12.580361526079619, 11.652408414133976, 10.74221105925401, 9.752932044665892, 8.814199694560553, 8.108994718750372, 9.041657853281444, 9.94772824312353, 10.800541585625151, 11.62665990551743, 12.523955487175698, 13.528704797421119, 13.636540781524488, 12.914761569406483, 11.87981771002671, 12.82900997541136, 13.7718145394016, 14.698628367914942, 14.563384269656035, 13.535966904472534, 13.574018506647969, 12.62197199705633, 11.80093674282461, 10.786238938144068, 9.831621322401466, 9.168008638325738, 9.988919820103863, 10.990144116805132, 11.825738726936816, 12.629007793319888, 13.573422938241793, 13.577376841338479, 12.59029950981397, 11.919103236759716, 10.848672223001461, 11.797085202983567, 12.749684477566872, 13.73838486086155, 14.781066009950816, 14.538846223466063, 14.573360969762925, 13.56223956663018, 12.743568251561003, 11.77544875180215, 10.784440884491818, 10.114050510468555, 10.95384335742284, 11.891517753521171, 12.812710436903984, 13.560132251943934, 13.60089852086478, 12.680716537851518, 11.654113783858348, 10.89938317651415, 9.912729342107896, 10.789446730776053, 11.77315423771472, 12.7618416147993, 13.802386233542034, 14.748955674075988, 14.680942255561781, 14.572990926312912, 13.676823223790928, 12.680628394551999, 11.755266898566965, 11.166802129897379, 11.993378746326115, 12.871918275675613, 13.827208166774225, 13.58822446831938, 12.629579469248222, 11.652747918764824, 10.630020380583787, 9.875362692915015, 8.94856324526276, 9.863538777663663, 10.817049509866695, 11.822150545383066, 12.76605632467219, 13.77154039179178, 13.621697623218598, 14.612346787624771, 14.671474390223276, 13.611498709764824, 12.781195273100263, 12.098828499616966, 12.967442666393023, 13.83208082028403, 13.690558041909483, 12.666739090253548, 11.626163612697535, 10.723542773712454, 9.692722528053258, 8.866071851239036, 7.997124351322733, 8.836202572324723, 9.81582688536189, 10.77478351759541, 11.777174102180643, 12.763623100341823, 12.621362953165505, 13.567183782262951, 14.614809899616954, 14.58416461267195, 13.784942715035632, 13.173632137180727, 13.972153402574108, 13.668611157882738, 12.696167306999019, 11.740727200623828, 10.672598977410857, 9.69470606452137, 8.734181591179436, 7.922053720532666, 6.9823215765156466, 7.863266209876879, 8.816744775789433, 9.846638651474525, 10.80609361176255, 11.744039900220088, 11.655256304896225, 12.715909555123487, 13.74379352065586, 14.690814045281329, 14.766301898884793, 14.146846476790008, 13.660969630657073, 12.639152847880416, 11.634121107881684, 10.703699675659754, 9.656750078214088, 8.694017337845146, 7.802699828049883, 6.913903480791042, 5.942779107273977, 6.91040050721376, 7.861562868254209, 8.917265979317202, 9.878848304001684, 10.70525899634155, 10.7448262901969, 11.802939760973462, 12.738156374400813, 13.720774861888223, 14.592099891957513, 13.617615164247717, 12.750990399559175, 11.809983155479392, 10.807437053795145, 9.799872160867478, 8.728275902223535, 7.73487967904739, 6.789869555994808, 5.907892554701592, 4.963154902066461, 5.954930390707825, 6.974157374681855, 7.91500970412525, 8.85957662045961, 9.750026072613698, 9.872961000337646, 10.76736694520447, 11.728018909870386, 12.72006913745679, 13.657960871259345, 12.675299262985542, 11.81607057941306, 10.839383522700457, 9.897628117214957, 8.876560905880755, 7.860933712448704, 6.83618775983816, 5.861894737048357, 4.932475900576612, 4.020859708213326, 4.986388033854215, 5.975653372940455, 6.91617388884512, 7.872000920766256, 8.823187631891855], [8.809489597126458, 7.850514341853526, 6.871177328416314, 5.930540903940994, 4.902306264309946, 3.95061157136075, 2.959446084466121, 3.9743301891937515, 4.913987326392852, 5.938413604138457, 6.918892778250896, 7.909310132602154, 8.975373646713662, 9.939543210560684, 10.785918020210252, 11.774395640331148, 12.6392417338484, 11.779237410889788, 10.778311283280932, 9.819667229086498, 7.851267106143554, 6.9001635127712735, 5.88066445011231, 4.9321272289086195, 3.8722768351307866, 2.9714096530434952, 2.009319380845932, 3.001315194639578, 4.009014530057901, 5.022429237058379, 5.975824925488258, 6.935866999193409, 7.960652447816042, 8.977079620233312, 9.858790024639598, 10.831623009855385, 11.713794056359097, 10.78547221169492, 9.730221287448403, 8.89102631694867, 6.807544453109828, 5.866389313286937, 4.909629721458346, 3.943464001294693, 2.9446235684873625, 1.931809924143948, 1.0065892815104125, 2.0284777909373566, 2.992577338351796, 3.9998320588827907, 5.012894133845248, 5.943687122634418, 6.9454368221405085, 7.936198671785007, 8.910497445046769, 9.849130480572892, 10.79100621569052, 9.82002610585366, 8.804823136365236, 7.852993806693403, 5.90206267835138, 4.964648613331083, 3.9417912674293034, 3.0131822479246533, 1.9739227363752785, 0.9484807774525718, 0.0, 0.991108534402222, 1.9766588845605022, 2.9533842753949666, 3.9538353210918733, 5.022010651116374, 5.9859139322125, 6.948462372568251, 7.978912678684328, 9.022943007653206, 9.861972305187862, 8.926854229381153, 7.933275076219614, 6.924692392297533, 6.827638329774994, 5.903662535308733, 4.994742933531839, 3.965687104391715, 2.9561846581356184, 2.0044394706165742, 1.0539700710597535, 1.994673470341628, 2.9687849946848752, 3.913029467798843, 4.8626694371870105, 5.929788761518393, 6.964406897534742, 7.9206155729034435, 8.940950930674244, 9.968954954077436, 10.826410842086624, 9.897547492309421, 8.879137858082533, 7.881381149366969, 7.835740423171017, 6.812201769868716, 5.862963873433691, 4.937576955789852, 3.8987474947559955, 3.035821261712422, 2.098645807921358, 2.9569803374760912, 3.9007383523200607, 4.828272163949776, 5.774419055605248, 6.726820456862892, 7.717339428401053, 8.646298376736178, 9.624108746661308, 10.603346269359113, 11.530679270244104, 10.801823332592004, 9.74882676185226, 8.786083482431692, 8.779771165966066, 7.811037105954689, 6.936783954346293, 5.938412298056154, 4.869519232406887, 4.00613470379154, 3.160856484136298, 3.9956211002768747, 4.921243628261722, 5.770026071871738, 6.795883141572723, 7.724990764643773, 8.707158605815339, 9.659967545210963, 10.576588670090347, 11.530767817347062, 12.492932914879162, 11.656461027317999, 10.648068733761606, 9.715513812194533, 9.791002539250657, 8.793319779875091, 7.876309059234798, 6.86643155626889, 5.894875081286283, 5.032285530728536, 4.137147931027177, 4.97700308421004, 5.884163393147043, 6.711500108482396, 7.668101161841911, 8.656920170609387, 9.61082477676197, 10.663653252325458, 11.649947138205453, 12.584827002402836, 13.514413602503474, 12.689651164635945, 11.638596949478764, 10.652600042069079, 10.757823098926485, 9.694638301616747, 8.70093761845731, 7.7729000272792845, 6.825635709785315, 6.074616640203622, 5.203676823037162, 5.981051106217629, 6.9035272057903665, 7.749714608532477, 8.680144353553683, 9.679283003227383, 10.574711037997712, 11.514109643055445, 12.54342081196242, 13.531098038421543, 14.458815621117107, 13.693829399940967, 12.627011783123754, 11.62003864555416, 11.686539943143337, 10.681400867881147, 9.728382120565698, 8.747257044066503, 7.789368161472626, 7.018255104497621, 6.1868839871782715, 6.957730713285643, 7.972333005265479, 8.695475085845532, 9.648735350366314, 10.573908809103356, 11.512869044182224, 12.447830139869762, 13.43481673210269, 14.430643169806553, 15.370026605108464, 14.640188085590358, 13.615494918747626, 12.600727170737189, 12.68914016576885, 11.654467631945241, 10.710347965862317, 9.723778847679913, 8.723110808765039, 8.082019085406488, 7.235303186521271, 8.009539765727492, 8.901296802542577, 9.656183447596904, 10.624125151425599, 11.602951322845566, 12.536889628712387, 13.230192115776557, 13.78895991928602, 14.739768465981125, 15.65909407659257, 15.560428904826777, 14.59548405697279, 13.617431903409548, 13.528842303532192, 12.60088919158655, 11.690691836706584, 10.701412822118465, 9.762680472013127, 9.038052760954432, 8.19714075345178, 8.999247465670958, 9.85206080817258, 10.678179128064858, 11.575474709723126, 12.580224019968547, 12.688060004071918, 12.175886650163651, 12.828298487479282, 13.777490752863931, 14.720295316854173, 15.647109145367516, 15.511865047108609, 14.484447681925108, 14.522499284100542, 13.570452774508903, 12.749417520277184, 11.734719715596642, 10.780102099854039, 10.097066680529798, 9.144402720274199, 10.04166333935256, 10.877257949484243, 11.680527015867316, 12.624942160789221, 12.62889606388591, 11.6418187323614, 11.110173304542428, 11.797153000454033, 12.74556598043614, 13.698165255019445, 14.686865638314124, 15.72954678740339, 15.487327000918636, 15.521841747215499, 14.510720344082753, 13.692049029013576, 12.723929529254724, 11.732921661944392, 11.043108552672615, 10.109326257593176, 10.995409501879298, 11.86422965945141, 12.611651474491364, 12.652417743412208, 11.732235760398948, 10.705633006405778, 10.061707350542473, 10.861210119560468, 11.737927508228626, 12.721635015167294, 13.710322392251873, 14.750867010994607, 15.697436451528562, 15.629423033014353, 15.521471703765485, 14.625304001243501, 13.629109172004572, 12.703747676019539, 12.095860172101439, 11.148861646496451, 11.97581002403374, 12.928358558903035, 12.639743690866808, 11.68109869179565, 10.704267141312254, 9.681539603131217, 9.03768686694334, 9.897044022715331, 10.812019555116237, 11.765530287319269, 12.770631322835639, 13.714537102124764, 14.720021169244351, 14.57017840067117, 15.560827565077343, 15.61995516767585, 14.559979487217397, 13.729676050552836, 13.027886541821026, 12.12292556656336, 12.935972568642157, 12.74207726445691, 11.718258312800977, 10.677682835244964, 9.775061996259884, 8.744241750600688, 7.962806620005368, 8.945605128775306, 9.784683349777296, 10.764307662814463, 11.723264295047983, 12.725654879633215, 13.712103877794394, 13.569843730618077, 14.515664559715523, 15.563290677069528, 15.532645390124523, 14.733423492488205, 14.062173183858317, 13.127636302744445, 12.720130380430165, 11.747686529546446, 10.792246423171257, 9.724118199958285, 8.7462252870688, 7.785700813726865, 7.0187884892989985, 7.930802353968218, 8.811746987329451, 9.765225553242004, 10.795119428927096, 11.754574389215122, 12.69252067767266, 12.603737082348797, 13.664390332576058, 14.692274298108432, 15.635334030588083, 14.591501737067196, 13.596266583972213, 12.712488853204501, 11.690672070427844, 10.685640330429113, 9.755218898207183, 8.708269300761517, 7.745536560392575, 6.854219050597312, 6.010638249557374, 6.891259884726549, 7.858881284666332, 8.81004364570678, 9.865746756769774, 10.827329081454256, 11.653739773794122, 11.69330706764947, 12.751420538426034, 13.686637151853382, 14.668648132919454, 13.643619114504943, 12.669134386795147, 11.802509622106605, 10.86150237802682, 9.858956276342575, 8.851391383414906, 7.779795124770963, 6.7863989015948185, 5.841388778542236, 4.95941177724902, 5.911635679519033, 6.903411168160397, 7.922638152134427, 8.863490481577822, 9.808057397912181, 10.69850685006627, 10.82144177779022, 11.71584772265704, 12.676499687322956, 13.66854991490936, 12.784210076221068, 11.726818485532972, 10.86758980196049, 9.890902745247885, 8.949147339762385, 7.928080128428182, 6.912452934996132, 5.8877069823855885, 4.913413959595785, 3.98399512312404, 4.969340485665898, 5.934868811306787, 6.9241341503930265, 7.8646546662976915, 8.820481698218828, 9.771668409344427], [9.800598131528679, 8.841622876255748, 7.862285862818537, 6.921649438343216, 5.8934147987121674, 4.941720105762973, 3.9505546188683427, 3.176008999326287, 4.073451802048768, 5.068128299843983, 5.927784243848674, 6.918201598199931, 7.984265112311438, 8.948434676158461, 9.794809485808031, 10.783287105928927, 11.74067258490252, 12.765045182130795, 11.769419817683154, 10.810775763488719, 8.842375640545777, 7.891272047173496, 6.871772984514533, 5.923235763310842, 4.863385369533009, 3.962518187445718, 3.000427915248154, 2.1263610434642963, 3.017905995655679, 4.031320702656156, 4.984716391086035, 5.944758464791186, 6.969543913413819, 7.985971085831089, 8.867681490237377, 9.840514475453162, 10.854343786166591, 11.776580746097142, 10.721329821850626, 9.882134851350893, 7.7986529875120505, 6.857497847689159, 5.900738255860569, 4.9345725356969155, 3.9357321028895846, 2.92291845854617, 1.9976978159126344, 1.067068159989555, 2.001468803949574, 3.0087235244805686, 4.021785599443026, 4.952578588232196, 5.954328287738287, 6.945090137382785, 7.919388910644547, 8.85802194617067, 9.807880679375415, 10.811134640255883, 9.795931670767459, 8.844102341095626, 6.893171212753602, 5.955757147733305, 4.9328998018315255, 4.004290782326875, 2.9650312707775006, 1.9395893118547938, 0.991108534402222, 0.0, 0.9855503501582802, 1.9622757409927445, 2.962726786689651, 4.030902116714152, 4.994805397810278, 5.9573538381660285, 6.987804144282105, 8.031834473250983, 8.960353099691115, 9.895471175497825, 8.924383610621835, 7.915800926699755, 7.818746864177216, 6.894771069710955, 5.9858514679340615, 4.956795638793937, 3.9472931925378405, 2.9955480050187964, 2.004570971984533, 1.0638675727026583, 1.977676460282653, 2.9219209333966214, 3.871560902784789, 4.938680227116171, 5.97329836313252, 6.929507038501221, 7.949842396272022, 8.977846419675213, 9.93955584188295, 10.868419191660152, 9.870246392484754, 8.87248968376919, 8.826848957573239, 7.803310304270938, 6.854072407835913, 5.928685490192073, 4.889856029158217, 3.931879654825006, 2.9947042010339424, 2.0261744398371215, 2.909629817917839, 3.837163629547554, 4.783310521203028, 5.735711922460672, 6.7262308939988324, 7.655189842333956, 8.633000212259088, 9.612237734956892, 10.539570735841883, 11.595931942538723, 10.739935296254483, 9.777192016833915, 9.770879700368287, 8.80214564035691, 7.927892488748515, 6.929520832458374, 5.860627766809108, 4.902193096904124, 4.056914877248882, 3.064815202637905, 3.9301350938595, 4.778917537469517, 5.804774607170502, 6.733882230241552, 7.716050071413117, 8.66885901080874, 9.585480135688126, 10.539659282944843, 11.501824380476942, 12.542894993587414, 11.639177268163829, 10.706622346596756, 10.782111073652878, 9.784428314277312, 8.86741759363702, 7.857540090671111, 6.885983615688504, 5.92834392384112, 5.033206324139761, 4.046197186571069, 4.89305485874482, 5.720391574080175, 6.67699262743969, 7.665811636207167, 8.61971624235975, 9.672544717923236, 10.658838603803233, 11.593718468000617, 12.523305068101255, 13.462260392453278, 12.629705483880986, 11.643708576471301, 11.748931633328706, 10.685746836018968, 9.69204615285953, 8.764008561681505, 7.816744244187536, 6.970675033316207, 6.077503397963374, 5.050245208578659, 5.912418671388144, 6.758606074130255, 7.689035819151462, 8.688174468825162, 9.583602503595493, 10.523001108653226, 11.552312277560201, 12.539989504019324, 13.467707086714888, 14.53362570345231, 13.618120317525976, 12.611147179956383, 12.677648477545558, 11.672509402283367, 10.719490654967917, 9.738365578468724, 8.780476695874848, 7.914313497610205, 6.969059609251089, 6.026924815646672, 6.981224470863256, 7.704366551443309, 8.657626815964093, 9.582800274701135, 10.521760509780004, 11.456721605467543, 12.44370819770047, 13.439534635404334, 14.378918070706245, 15.453176699055764, 14.606603453149848, 13.591835705139411, 13.680248700171068, 12.64557616634746, 11.701456500264536, 10.714887382082132, 9.71421934316726, 8.978077478519072, 8.01747880859409, 7.078733868088522, 7.910188268140355, 8.665074913194681, 9.633016617023378, 10.611842788443345, 11.545781094310165, 12.528378929534586, 13.400941426990608, 14.351749973685713, 15.336063374408235, 16.347685450535288, 15.586592591375013, 14.60854043781177, 14.519950837934411, 13.591997725988769, 12.681800371108803, 11.692521356520684, 10.753789006415346, 9.911979510055673, 8.9793163755246, 8.068441568031988, 8.860952273770359, 9.687070593662636, 10.584366175320906, 11.589115485566326, 11.993302116820292, 12.998911872193556, 13.819407021881505, 14.768599287266154, 15.711403851256396, 16.63821767976974, 16.502973581510826, 15.475556216327327, 15.513607818502761, 14.561561308911122, 13.740526054679403, 12.72582824999886, 11.771210634256258, 10.909887291878045, 9.92657834234702, 9.11085744171359, 9.886149415082023, 10.689418481465093, 11.633833626387, 11.934138176634283, 10.947060845109775, 11.989802968375072, 12.788261534856256, 13.736674514838363, 14.689273789421668, 15.677974172716347, 16.720655321805612, 16.478435535320855, 16.51295028161772, 15.501828878484972, 14.683157563415795, 13.715038063656943, 12.724030196346611, 11.840153603265676, 10.891501879665997, 10.064603604240327, 10.873121125049192, 11.620542940089141, 11.957659856160584, 11.037477873147322, 10.010875119154152, 11.025660039860384, 11.85231865396269, 12.729036042630849, 13.712743549569517, 14.701430926654096, 15.74197554539683, 16.688544985930786, 16.620531567416574, 16.512580238167704, 15.61641253564572, 14.620217706406791, 13.694856210421758, 12.8929052226945, 11.931037268569272, 11.045004126394769, 11.937250024500816, 11.944985803615184, 10.986340804544026, 10.009509254060628, 8.98678171587959, 10.02879540134556, 10.888152557117554, 11.80312808951846, 12.756638821721491, 13.761739857237862, 14.705645636526986, 15.711129703646572, 15.56128693507339, 16.551936099479562, 16.611063702078066, 15.551088021619616, 14.720784584955055, 13.824931592414087, 12.90510118863618, 12.005166671003186, 12.032698856808697, 11.023500425549352, 9.98292494799334, 9.080304109008258, 8.049483863349062, 8.95391515440759, 9.936713663177528, 10.775791884179519, 11.755416197216686, 12.714372829450205, 13.716763414035436, 14.703212412196615, 14.560952265020298, 15.506773094117744, 16.554399211471747, 15.513614378427162, 14.581752386514136, 13.578372389179274, 12.858825133748848, 11.92889141004561, 11.038308121898233, 10.097488535919632, 9.029360312706661, 8.051467399817174, 7.09094292647524, 8.00989702370122, 8.92191088837044, 9.802855521731674, 10.756334087644227, 11.786227963329319, 12.745682923617343, 13.68362921207488, 13.594845616751018, 14.655498866978279, 15.591246020811331, 14.644225496185863, 13.600393202664975, 12.605158049569992, 11.784968582213068, 10.866458429414834, 9.976261922780898, 9.045840490558968, 8.013511413509892, 7.05077867314095, 6.159461163345687, 7.001746783959596, 7.882368419128771, 8.849989819068554, 9.801152180109003, 10.856855291171996, 11.818437615856476, 12.644848308196343, 12.684415602051692, 13.742529072828255, 14.660158086004644, 13.677539598517233, 12.652510580102723, 11.678025852392926, 10.811401087704382, 9.870393843624598, 8.988332235327196, 8.009890251508892, 7.085037237519338, 6.091641014343193, 5.146630891290611, 5.950520311651242, 6.902744213921255, 7.894519702562619, 8.913746686536648, 9.854599015980043, 10.799165932314402, 11.68961538446849, 11.81255031219244, 12.706956257059263, 13.667608221725178, 12.741396723922866, 11.79310154181885, 10.735709951130751, 9.876481267558267, 8.899794210845663, 7.958038805360163, 6.93697159402596, 6.138292445211286, 5.135600282800023, 4.21865607234416, 4.975103657526262, 5.96044902006812, 6.925977345709009, 7.915242684795247, 8.855763200699913, 9.811590232621048, 10.762776943746648], [10.786148481686958, 9.827173226414027, 8.847836212976816, 7.9071997885014955, 6.8789651488704475, 5.927270455921253, 4.936104969026624, 4.027558589089589, 3.087901451890488, 4.082577949685703, 4.9422338936903945, 5.932651248041652, 6.998714762153159, 7.9628843260001805, 8.80925913564975, 9.797736755770647, 10.755122234744238, 11.779494831972514, 12.754970167841435, 11.796326113646998, 9.827925990704056, 8.876822397331775, 7.857323334672812, 6.908786113469121, 5.848935719691289, 4.948068537603998, 3.985978265406435, 3.0841182712908077, 2.0323556454973986, 3.0457703524978763, 3.9991660409277556, 4.959208114632906, 5.983993563255538, 7.000420735672808, 7.882131140079096, 8.854964125294881, 9.86879343600831, 10.797115280672488, 11.706880172008907, 10.867685201509174, 8.78420333767033, 7.8430481978474385, 6.886288606018848, 5.920122885855195, 4.921282453047865, 3.90846880870445, 2.983248166070915, 2.031581442573673, 1.0159184537912938, 2.023173174322288, 3.0362352492847458, 3.967028238073916, 4.968777937580006, 5.959539787224504, 6.933838560486266, 7.87247159601239, 8.822330329217134, 9.87502592281133, 10.78148202092574, 9.829652691253907, 7.878721562911882, 6.941307497891585, 5.918450151989806, 4.9898411324851555, 3.9505816209357807, 2.925139662013074, 1.9766588845605022, 0.9855503501582802, 0.0, 0.9767253908344644, 1.977176436531371, 3.045351766555872, 4.0092550476519975, 4.9718034880077475, 6.002253794123824, 7.046284123092702, 7.974802749532834, 8.909920825339544, 9.903499978501083, 8.901351276858035, 8.804297214335495, 7.880321419869235, 6.971401818092341, 5.942345988952217, 4.932843542696121, 3.9810983551770764, 2.990121322142813, 2.0494179228609384, 0.9921261101243729, 1.9363705832383409, 2.8860105526265083, 3.9531298769578904, 4.98774801297424, 5.94395668834294, 6.964292046113741, 7.992296069516932, 8.954005491724669, 9.882868841501871, 10.849362760364002, 9.85804003392747, 9.812399307731518, 8.780798297835574, 7.831560401400549, 6.906173483756709, 5.867344022722853, 4.839764235547566, 3.9025887817565024, 2.9340590205596815, 1.9240794677595585, 2.851613279389274, 3.797760171044747, 4.750161572302391, 5.7406805438405515, 6.669639492175675, 7.647449862100806, 8.626687384798611, 9.554020385683602, 10.610381592380442, 11.663378163120186, 10.762742366992194, 10.756430050526566, 9.779633633921547, 8.90538048231315, 7.907008826023011, 6.838115760373745, 5.810077677626684, 4.964799457971442, 3.954550409424546, 2.9445847437012196, 3.7933671873112367, 4.8192242570122215, 5.7483318800832715, 6.730499721254836, 7.683308660650459, 8.599929785529843, 9.554108932786558, 10.51627403031866, 11.557344643429133, 12.565736936985525, 11.692172696755035, 11.762375307258484, 10.761916307841949, 9.844905587201657, 8.835028084235748, 7.863471609253141, 6.83622850456368, 5.941090904862321, 4.93593239335771, 3.90750450858654, 4.734841223921895, 5.691442277281409, 6.680261286048886, 7.634165892201469, 8.686994367764955, 9.67328825364495, 10.608168117842332, 11.53775471794297, 12.476710042294993, 13.527764257452175, 12.62925892662958, 12.726419626893342, 11.663234829583605, 10.669534146424168, 9.741496555246142, 8.794232237752173, 7.854978243864724, 6.918697146634084, 5.891438957249369, 4.926868321229863, 5.773055723971975, 6.703485468993181, 7.702624118666881, 8.598052153437212, 9.537450758494945, 10.56676192740192, 11.554439153861043, 12.482156736556608, 13.548075353294026, 14.516179091097165, 13.596697530114662, 13.655136471110195, 12.649997395848004, 11.696978648532554, 10.71585357203336, 9.757964689439484, 8.783397289145906, 7.810253357921799, 6.868118564317382, 5.995674120704975, 6.718816201285029, 7.672076465805812, 8.597249924542854, 9.536210159621723, 10.471171255309262, 11.45815784754219, 12.453984285246053, 13.393367720547964, 14.467626348897483, 15.492319515740215, 14.57738605529769, 14.657736693735705, 13.623064159912097, 12.678944493829173, 11.692375375646769, 10.691707336731897, 9.847161270054773, 8.8586725572648, 7.890517369866025, 6.924637917982074, 7.6795245630364, 8.647466266865097, 9.626292438285065, 10.560230744151884, 11.542828579376305, 12.415391076832327, 13.366199623527432, 14.350513024249954, 15.362135100377007, 16.327079948230995, 15.59409078797005, 15.497438831499048, 14.569485719553406, 13.65928836467344, 12.670009350085321, 11.731276999979983, 10.753173258726381, 9.820510124195309, 8.880225069809491, 7.875401923612077, 8.701520243504355, 9.598815825162625, 10.603565135408045, 11.629914780301545, 12.597134044989211, 13.376052508639065, 14.325244774023714, 15.289311783988351, 16.216125612501695, 17.190378924926723, 16.453044209891964, 16.491095812067396, 15.539049302475759, 14.71801404824404, 13.703316243563497, 12.748698627820895, 11.751081040548753, 10.767772091017727, 9.869615780967026, 8.90059906492374, 9.703868131306812, 10.64828327622872, 11.143902542303286, 11.798610434873076, 12.841352558138373, 13.733150635204948, 14.722224864996644, 15.674824139579949, 16.663524522874628, 17.706205671963893, 17.455923528885492, 17.490438275182353, 16.47931687204961, 15.660645556980432, 14.69252605722158, 13.696009470508358, 12.681347351936385, 11.732695628336705, 10.823361943493763, 9.887570774890909, 10.63499258993086, 11.00305262919274, 10.163328082925945, 10.862424708917453, 11.877209629623685, 12.797207754311383, 13.71458639278913, 14.698293899727798, 15.686981276812377, 16.72752589555511, 17.674095336089067, 17.606081917574855, 17.49006823173234, 16.58839180980747, 15.592196980568538, 14.666835484583505, 13.734098971365208, 12.77223101723998, 11.803762465648205, 10.951699674342533, 10.990378576647341, 10.031733577576183, 9.13535946383925, 9.838331305642892, 10.90624220981399, 11.833041657466246, 12.78867843967674, 13.742189171879772, 14.747290207396142, 15.691195986685267, 16.69668005380485, 16.54683728523167, 17.53748644963784, 16.544788462981423, 15.500729931176007, 14.599949478291224, 13.667625676584754, 12.877985519771652, 11.906687675864008, 11.047148506650416, 10.06889319858151, 9.028317721025497, 8.151786055145335, 8.901033453112364, 9.89893155367832, 10.897076667799107, 11.7613422343378, 12.740966547374967, 13.699923179608486, 14.702313764193716, 15.688762762354896, 15.546502615178577, 16.49232344427602, 15.586892095104288, 14.528064028268881, 13.596202036355855, 12.592822039020993, 11.873274783590567, 10.94334105988733, 10.052757771739952, 9.126618005905613, 8.074753085738818, 7.10813238331925, 7.942492516238541, 8.95491342297195, 9.907461238528718, 10.788405871889955, 11.741884437802508, 12.7717783134876, 13.731233273775624, 14.66917956223316, 14.580395966909297, 15.633579636185424, 14.60569567065305, 13.658675146027582, 12.614842852506694, 11.619607699411711, 10.799418232054787, 9.880908079256555, 8.990711572622619, 8.060290140400689, 7.058904186542049, 6.096171446173107, 7.011010753108988, 7.971667987653023, 8.86791876928705, 9.835540169226835, 10.786702530267284, 11.842405641330277, 12.803987966014757, 13.630398658354622, 13.66996595220997, 14.697995938475502, 13.674607735846363, 12.691989248358952, 11.666960229944442, 10.692475502234645, 9.825850737546101, 8.884843493466319, 8.002781885168917, 7.024339901350613, 6.130430010551495, 5.13703378737535, 5.998180481053913, 6.936070661809523, 7.888294564079534, 8.8800700527209, 9.899297036694929, 10.840149366138323, 11.784716282472683, 12.67516573462677, 12.79810066235072, 13.692506607217544, 12.733466636945806, 11.755846373764586, 10.807551191660568, 9.75015960097247, 8.890930917399986, 7.9142438606873835, 6.9724884552018835, 5.951421243867681, 5.152742095053006, 4.150049932641743, 5.070205662107462, 5.960654007684543, 6.945999370226399, 7.911527695867289, 8.900793034953528, 9.841313550858192, 10.797140582779328, 11.748327293904927], [11.762873872521425, 10.803898617248494, 9.824561603811283, 8.88392517933596, 7.855690539704912, 6.903995846755717, 5.912830359861088, 5.004283979924053, 4.064626842724953, 3.11808049500823, 3.9777364390129213, 4.968153793364179, 6.034217307475686, 6.986158935165717, 7.832533744815287, 8.821011364936183, 9.778396843909775, 10.80276944113805, 11.803695568746907, 12.773051504481465, 10.804651381538523, 9.853547788166242, 8.834048725507278, 7.885511504303587, 6.825661110525753, 5.924793928438462, 4.962703656240899, 4.060843662125272, 3.009081036331863, 2.081272897820403, 3.0346685862502825, 3.990088157179311, 5.007268172421075, 6.023695344838345, 6.905405749244633, 7.8782387344604174, 8.892068045173847, 9.820389889838024, 10.838006927094229, 11.844410592343639, 9.760928728504796, 8.819773588681905, 7.863013996853313, 6.89684827668966, 5.898007843882329, 4.8851941995389145, 3.9599735569053793, 3.0083068334081373, 1.9926438446257582, 1.058675719644815, 2.0595098584502813, 2.9903028472394517, 3.9920525467455414, 4.98281439639004, 5.9571131696518025, 6.895746205177926, 7.845604938382672, 8.898300531976867, 9.912608776011062, 10.806378082088372, 8.855446953746346, 7.918032888726049, 6.89517554282427, 5.96656652331962, 4.927307011770245, 3.9018650528475383, 2.9533842753949666, 1.9622757409927445, 0.9767253908344644, 0.0, 1.0004510456969067, 2.0686263757214074, 3.032529656817533, 3.9950780971732835, 5.02552840328936, 6.069558732258237, 6.998077358698369, 7.933195434505079, 8.926774587666618, 9.8780766676925, 9.78102260516996, 8.8570468107037, 7.948127208926806, 6.919071379786682, 5.909568933530585, 4.957823746011541, 3.9668467129772775, 3.026143313695403, 1.9688515009588374, 1.066538635844695, 2.0161786052328625, 3.0079960761339573, 4.020865452975206, 4.967231297508476, 5.9875666552792755, 7.015570678682467, 7.977280100890203, 8.906143450667406, 9.872637369529537, 10.834765424761935, 10.789124698565983, 9.75752368867004, 8.808285792235013, 7.882898874591173, 6.844069413557317, 5.81648962638203, 4.879314172590966, 3.910784411394146, 2.9008048585940234, 2.1154800237726104, 2.988143497818296, 3.9405448990759395, 4.931063870614101, 5.860022818949225, 6.837833188874355, 7.8170707115721605, 8.744403712457151, 9.800764919153991, 10.820319396987099, 11.73946775782666, 11.733155441361031, 10.756359024756012, 9.882105873147616, 8.883734216857475, 7.814841151208208, 6.786803068461148, 5.941524848805907, 4.9312758002590105, 3.9213101345356844, 3.057233931694573, 4.009607583785771, 4.938715206856821, 5.920883048028386, 6.873691987424008, 7.7903131123033935, 8.74449225956011, 9.70665735709221, 10.747727970202682, 11.756120263759074, 12.6688980875895, 12.73910069809295, 11.738641698676414, 10.82163097803612, 9.811753475070212, 8.840197000087604, 7.8129538953981434, 6.9178162956967855, 5.9126577841921755, 4.884229899421005, 3.9987079683052307, 4.955309021664745, 5.870644612822435, 6.824549218975018, 7.877377694538504, 8.863671580418501, 9.798551444615883, 10.728138044716522, 11.667093369068544, 12.718147584225726, 13.605984317464046, 13.703145017727806, 12.639960220418068, 11.646259537258631, 10.718221946080606, 9.770957628586636, 8.831703634699188, 7.89542253746855, 6.868164348083834, 5.903593712064328, 5.036922468355311, 5.967352213376517, 6.89300744544043, 7.788435480210762, 8.727834085268494, 9.75714525417547, 10.744822480634593, 11.672540063330157, 12.738458680067577, 13.706562417870716, 14.573422920949128, 14.631861861944659, 13.626722786682468, 12.673704039367017, 11.692578962867824, 10.734690080273948, 9.76012267998037, 8.786978748756264, 7.844843955151847, 6.9133378810878465, 5.982682945668365, 6.93594321018915, 7.861116668926193, 8.774142723566728, 9.661554582082811, 10.648541174315739, 11.644367612019602, 12.583751047321513, 13.658009675671032, 14.682702842513764, 15.554111446132156, 15.634462084570169, 14.59978955074656, 13.655669884663636, 12.669100766481233, 11.66843272756636, 10.823886660889237, 9.799723930936459, 8.808181130248895, 7.8423016783649455, 6.943391307419736, 7.911333011248435, 8.890159182668404, 9.798163308096889, 10.733211906149855, 11.605774403605876, 12.556582950300982, 13.540896351023504, 14.552518427150556, 15.517463275004543, 16.495515428567785, 16.474164222333513, 15.546211110387869, 14.636013755507904, 13.646734740919785, 12.708002390814446, 11.67599775249534, 10.743334617964267, 9.797888830192361, 8.793065683994948, 7.96538698788769, 8.862682569545962, 9.867431879791383, 10.86784734424655, 11.78751737176276, 12.566435835412614, 13.515628100797263, 14.4796951107619, 15.406508939275243, 16.38076225170027, 17.408179616883768, 17.467821202901863, 16.51577469331022, 15.694739439078504, 14.680041634397961, 13.683657089694416, 12.673905534317711, 11.690596584786686, 10.787279541349896, 9.818262825306611, 8.967734875690148, 9.912150020612057, 10.794969141936107, 11.782046473460616, 12.824788596725913, 13.597581322437863, 14.58670892934199, 15.501825172596629, 16.412111674505347, 17.367094661821948, 18.336664017069513, 18.46716366601682, 17.45604226288407, 16.637370947814897, 15.669251448056043, 14.618833964277316, 13.604171845705343, 12.655520122105663, 11.741025703876634, 10.80523453527378, 9.898859334314196, 10.166621165007324, 11.140053473760412, 11.839150099751917, 12.853935020458149, 13.773933145145847, 14.691311783623593, 15.675019290562261, 16.663706667646842, 17.704251286389578, 18.650820726923534, 18.43905634665813, 17.49753096581257, 16.4510696847933, 15.454874855554369, 14.618972913393643, 13.622926655469877, 12.875324049004096, 11.902352765794953, 11.122624935255349, 10.153947112461925, 9.195302113390767, 10.112084854673718, 10.815056696477356, 11.882967600648454, 12.80976704830071, 13.765403830511204, 14.718914562714236, 15.724015598230606, 16.66792137751973, 17.673405444639318, 17.523562676066135, 16.62053971908381, 15.568063072146959, 14.524004540341544, 13.62322408745676, 12.69090028575029, 11.901260128937189, 10.942190221186536, 10.082651051972942, 9.16119428719129, 8.19188625684008, 9.1285114459798, 9.877758843946827, 10.875656944512784, 11.87380205863357, 12.738067625172263, 13.71769193820943, 14.67664857044295, 15.67903915502818, 16.66548815318936, 16.523228006013042, 15.588073579701742, 14.610166704269824, 13.551338637434418, 12.619476645521392, 11.616096648186529, 10.896549392756103, 9.978843605209859, 9.088260317062478, 8.162120551228139, 7.238321621553402, 8.084857774153715, 8.919217907073005, 9.931638813806414, 10.884186629363183, 11.765131262724418, 12.718609828636971, 13.748503704322063, 14.707958664610087, 15.645904953067626, 15.557121357743764, 14.65685424535096, 13.628970279818587, 12.681949755193118, 11.63811746167223, 10.642882308577247, 9.822692841220324, 8.916410624579083, 8.026214117945145, 7.0957926857232145, 6.222472722356634, 7.072896837007572, 7.987736143943453, 8.948393378487488, 9.844644160121515, 10.812265560061299, 11.763427921101748, 12.81913103216474, 13.78071335684922, 14.607124049189089, 14.646691343044438, 13.721270547641039, 12.6978823450119, 11.715263857524489, 10.690234839109978, 9.715750111400181, 8.849125346711638, 7.920346038788846, 7.038284430491444, 6.05984244667314, 5.207728013623071, 6.113759178209815, 6.974905871888377, 7.912796052643987, 8.865019954913999, 9.856795443555363, 10.876022427529392, 11.816874756972787, 12.761441673307147, 13.651891125461237, 13.729078196512434, 12.717393210777258, 11.756741246111343, 10.779120982930122, 9.830825800826105, 8.773434210138007, 7.914205526565522, 6.949746406009911, 6.00799100052441, 4.986923789190207, 4.188244640375533, 5.126775323476207, 6.046931052941926, 6.937379398519007, 7.922724761060865, 8.888253086701752, 9.877518425787992, 10.81803894169266, 11.773865973613795, 12.725052684739394], [12.76332491821833, 11.8043496629454, 10.825012649508189, 9.884376225032867, 8.856141585401819, 7.904446892452624, 6.913281405557995, 6.00473502562096, 5.065077888421859, 4.070107791835525, 3.022972358980458, 4.013389713331716, 5.0438912508345695, 5.985707889468809, 6.832082699118381, 7.820560319239277, 8.777945798212869, 9.802318395441144, 10.803244523050001, 11.829982119400107, 11.805102427235429, 10.853998833863148, 9.834499771204184, 8.885962550000492, 7.82611215622266, 6.925244974135369, 5.963154701937806, 5.061294707822179, 4.00953208202877, 3.0333001946476985, 2.079904506217819, 2.9896371114824043, 4.006817126724167, 5.023244299141437, 5.904954703547726, 6.877787688763512, 7.891616999476942, 8.81993884414112, 9.837555881397323, 10.882681128550573, 10.761379774201702, 9.82022463437881, 8.863465042550219, 7.897299322386566, 6.898458889579236, 5.885645245235821, 4.960424602602286, 4.008757879105044, 2.9930948903226646, 2.0591267653417216, 1.0590588127533747, 1.989851801542545, 2.9916015010486348, 3.9823633506931335, 4.956662123954896, 5.8952951594810195, 6.845153892685765, 7.89784948627996, 8.912157730314156, 9.86398705998599, 9.855897999443254, 8.918483934422957, 7.895626588521177, 6.967017569016527, 5.927758057467152, 4.902316098544445, 3.9538353210918733, 2.962726786689651, 1.977176436531371, 1.0004510456969067, 0.0, 1.0681753300245007, 2.0320786111206264, 2.994627051476377, 4.025077357592453, 5.069107686561331, 5.997626313001463, 6.932744388808173, 7.926323541969712, 8.934906225891792, 10.781473650866868, 9.857497856400606, 8.948578254623712, 7.9195224254835885, 6.910019979227492, 5.9582747917084475, 4.960810766494482, 4.020107367212607, 2.949100169834187, 2.0048556967202193, 1.0552157273320522, 2.0075450304370506, 3.0204144072782997, 3.966780251811569, 4.98711560958237, 6.015119632985561, 6.976829055193297, 7.905692404970499, 8.872186323832631, 9.905125041837824, 11.732954689971438, 10.737772357545389, 9.788534461110363, 8.863147543466523, 7.824318082432666, 6.796738295257379, 5.859562841466316, 4.891033080269495, 3.8810535274693727, 2.9733275115729585, 2.0271806199174853, 2.9684746542906324, 3.9589936258287937, 4.887952574163918, 5.865762944089048, 6.845000466786853, 7.772333467671844, 8.828694674368684, 9.819868351290193, 10.782611630710761, 12.676985432766486, 11.736607693631361, 10.862354542022965, 9.863982885732824, 8.795089820083557, 7.767051737336497, 6.921773517681256, 5.89833607635628, 4.8883704106329535, 3.9150814194949213, 3.0486447058849597, 3.9777523289560097, 4.959920170127575, 5.901621742638701, 6.818242867518086, 7.772422014774802, 8.734587112306903, 9.775657725417375, 10.784050018973767, 11.712041960473602, 13.677091750655382, 12.718890367551763, 11.80187964691147, 10.792002143945561, 9.820445668962954, 8.793202564273493, 7.898064964572135, 6.879718060289445, 5.821556340330892, 4.856555456105579, 4.009950410859078, 4.909681734921624, 5.863586341074207, 6.905307449753197, 7.891601335633193, 8.826481199830576, 9.756067799931214, 10.695023124283237, 11.746077339440419, 12.649128190348147, 14.646510891292257, 13.620208889293417, 12.62650820613398, 11.698470614955955, 10.751206297461986, 9.762829209114598, 8.826548111883959, 7.799289922499243, 6.8347192864797375, 5.89476995615566, 5.02199360257085, 5.932044567539618, 6.827472602309951, 7.766871207367684, 8.79618237627466, 9.783859602733783, 10.711577185429347, 11.76638843528227, 12.734492173085409, 13.616566793833229, 15.584590594052482, 14.606971455557817, 13.641142101003073, 12.66001702450388, 11.702128141910004, 10.691248254395779, 9.718104323171673, 8.775969529567256, 7.7711853688881956, 6.840530433468714, 5.990584599383482, 6.915758058120525, 7.813179845665917, 8.700591704182001, 9.687578296414928, 10.683404734118792, 11.622788169420703, 12.697046797770223, 13.721739964612956, 14.597255319016258, 16.476937351654755, 15.567227612382617, 14.623107946299692, 13.636538828117288, 12.635870789202416, 11.726031450452526, 10.657571418736808, 9.666028618049245, 8.700149166165295, 7.801238795220085, 6.965974400442767, 7.944800571862735, 8.837200430196079, 9.772249028249044, 10.644811525705066, 11.595620072400171, 12.579933473122693, 13.591555549249746, 14.556500397103733, 15.534552550666975, 17.402822117375877, 16.513649172023925, 15.60345181714396, 14.61417280255584, 13.603593007976913, 12.533845240295689, 11.601182105764616, 10.65573631799271, 9.650913171795297, 8.82323447568804, 7.917323958740295, 8.922073268985715, 9.90688446634574, 10.82655449386195, 11.605472957511804, 12.554665222896453, 13.51873223286109, 14.445546061374433, 15.41979937379946, 16.44721673898296, 18.396479097944226, 17.483212754946276, 16.66217750071456, 15.606813365652542, 14.541504577494765, 13.53175302211806, 12.548444072587035, 11.645127029150245, 10.67611031310696, 9.825582363490497, 8.96679140980639, 9.84961053113044, 10.836687862654948, 11.879429985920245, 12.636618444537053, 13.62574605144118, 14.540862294695819, 15.451148796604535, 16.40613178392114, 17.375701139168704, 18.411487251862464, 17.439422483137456, 16.41884013984728, 15.450720640088427, 14.589347881771884, 13.675227229201795, 12.865663604015262, 11.927989207916932, 11.24439273415195, 10.27370169924852, 10.026243331522465, 10.83018499050778, 11.77287358861057, 12.787658509316802, 13.572561325430618, 14.596826269489931, 15.580533776428599, 16.502045598856736, 17.384811560329922, 18.33138100086388, 17.438605300961225, 16.497079920115663, 15.450618639096392, 14.454423809857463, 13.618521867696737, 12.622475609772971, 11.87487300330719, 10.94758868576249, 10.180263834700325, 9.2115860119069, 10.110784332038252, 11.112535900370624, 11.815507742174262, 12.88341864634536, 13.810218093997616, 14.765854876208113, 15.719365608411143, 16.724466643927514, 17.66837242321664, 18.385624513833925, 16.533778033155375, 15.620088673386903, 14.567612026450053, 13.523553494644638, 12.622773041759855, 11.690449240053384, 10.900809083240283, 9.987426141154073, 9.12788697194048, 8.206430207158824, 9.107368475487565, 10.128962491676706, 10.878209889643733, 11.87610799020969, 12.874253104330476, 13.738518670869171, 14.718142983906338, 15.677099616139857, 16.679490200725088, 17.579621729731233, 15.533443363102283, 14.587622534004836, 13.609715658572918, 12.550887591737512, 11.619025599824486, 10.615645602489623, 9.896098347059196, 9.024079525177395, 8.133496237030016, 7.207356471195675, 8.153803840200887, 9.08530881985062, 9.91966895276991, 10.93208985950332, 11.88463767506009, 12.765582308421326, 13.719060874333879, 14.74895475001897, 15.708409710306995, 16.55514158501215, 14.717056449881316, 13.656403199654054, 12.628519234121681, 11.681498709496212, 10.637666415975325, 9.642431262880342, 8.822241795523416, 7.961646544546619, 7.071450037912682, 6.141028605690751, 7.137954941004119, 8.073347882704478, 8.988187189640358, 9.948844424184394, 10.84509520581842, 11.812716605758206, 12.763878966798655, 13.819582077861648, 14.781164402546128, 15.607575094885995, 13.739854048708743, 12.720819501944133, 11.697431299314994, 10.714812811827583, 9.689783793413072, 8.715299065703276, 7.84867430101473, 6.965581958756383, 6.083520350458981, 5.105078366640677, 6.123210232270556, 7.1142102239067215, 7.975356917585284, 8.913247098340895, 9.865471000610905, 10.85724648925227, 11.8764734732263, 12.817325802669695, 13.761892719004054, 14.652342171158143, 12.728627150815528, 11.716942165080352, 10.756290200414437, 9.778669937233216, 8.8303747551292, 7.772983164441101, 6.913754480868614, 5.994982325977448, 5.053226920491947, 4.032159709157744, 5.103726859023018, 6.127226369173114, 7.047382098638833, 7.937830444215914, 8.92317580675777, 9.88870413239866, 10.8779694714849, 11.818489987389565, 12.7743170193107, 13.7255037304363], [11.771984421335645, 12.730959676608576, 11.893187979532687, 10.919866617660189, 9.89163197802914, 8.936518166982282, 7.909174353364305, 6.894290248636675, 5.954633111437574, 4.930206833691969, 3.883071400836901, 3.050429964573569, 3.975715920810069, 4.917532559444309, 5.76390736909388, 6.752384989214775, 7.709770468188366, 8.734143065416642, 9.735069193025499, 10.761806789375605, 10.860286142786396, 11.816267676605845, 10.902675101228684, 9.954137880024993, 8.89428748624716, 7.993420304159869, 6.986907442437926, 6.014825662392597, 4.963063036599188, 3.8933992365041417, 2.9400035480742623, 1.9881501757605067, 2.9386417966996667, 3.9550689691169367, 4.836779373523225, 5.80961235873901, 6.82344166945244, 7.751763514116618, 8.769380551372821, 9.81450579852607, 9.841261083545064, 10.782416223367955, 9.93164037257472, 8.965474652411066, 7.966634219603736, 6.9538205752603215, 5.984177343102406, 4.962288833675462, 3.9466258448930827, 2.939371124362088, 1.9191578546098178, 0.9883648658206475, 1.9234261710241343, 2.914188020668633, 3.8884867939303946, 4.827119829456518, 5.776978562661264, 6.829674156255459, 7.843982400289654, 8.795811729961487, 8.889360609813444, 9.826774674833741, 8.963801918545677, 8.035192899041027, 6.995933387491652, 5.970491428568946, 5.022010651116374, 4.030902116714152, 3.045351766555872, 2.0686263757214074, 1.0681753300245007, 0.0, 0.9639032810961258, 1.9264517214518762, 2.9569020275679523, 4.00093235653683, 4.929450982976961, 5.864569058783671, 6.85814821194521, 7.86673089586729, 9.814936261237058, 10.763897881100583, 10.016753584648212, 8.987697755508089, 7.978195309251992, 6.957381560930475, 5.912084063906362, 4.971380664624488, 3.9003734672460677, 2.9561289941320994, 2.006489024743932, 0.9393697004125499, 1.9522390772537992, 2.898604921787068, 3.9189402795578685, 4.94694430296106, 5.908653725168796, 6.837517074945998, 7.804010993808129, 8.836949711813322, 10.664779359946936, 11.583100258884977, 10.633862362449952, 9.708475444806112, 8.669645983772256, 7.64206619659697, 6.704890742805906, 5.736360981609086, 4.726381428808963, 3.7988476171792485, 2.8527007255237753, 1.9002993242661317, 2.890818295804293, 3.819777244139417, 4.797587614064547, 5.776825136762352, 6.704158137647344, 7.760519344344184, 8.751693021265691, 9.714436300686259, 11.608810102741984, 12.58193559497095, 11.707682443362554, 10.709310787072413, 9.640417721423146, 8.612379638676089, 7.767101419020847, 6.72385618196257, 5.7138905162392435, 4.740601525101211, 3.853292554283695, 2.9241849312126456, 3.906352772384211, 4.833446412614201, 5.750067537493585, 6.704246684750301, 7.666411782282402, 8.707482395392873, 9.715874688949265, 10.6438666304491, 12.60891642063088, 13.564218268891352, 12.647207548251059, 11.63733004528515, 10.665773570302543, 9.638530465613085, 8.743392865911726, 7.705238165895734, 6.647076445937182, 5.682075561711869, 4.814598259257814, 3.8561143371782602, 4.810018943330843, 5.837132119728697, 6.823426005608692, 7.758305869806074, 8.687892469906712, 9.626847794258735, 10.677902009415916, 11.580952860323645, 13.578335561267755, 14.461896439047134, 13.468195755887697, 12.540158164709672, 11.592893847215702, 10.588349314720887, 9.652068217490248, 8.624810028105532, 7.660239392086027, 6.72029006176195, 5.826641450969586, 4.8784771697962555, 5.773905204566587, 6.71330380962432, 7.7426149785312965, 8.73029220499042, 9.658009787685984, 10.698213105257768, 11.666316843060907, 12.548391463808727, 14.51641526402798, 15.43736583996979, 14.466662206609364, 13.485537130110169, 12.527648247516293, 11.516768360002068, 10.543624428777962, 9.601489635173545, 8.596705474494485, 7.666050539075004, 6.793160381908931, 5.8679869231718875, 6.759612447922553, 7.647024306438636, 8.634010898671564, 9.629837336375427, 10.569220771677339, 11.643479400026859, 12.668172566869591, 13.529079988991755, 15.423369953911388, 16.392747717988907, 15.448628051905983, 14.46205893372358, 13.461390894808705, 12.551551556058815, 11.483091524343097, 10.491548723655534, 9.525669271771584, 8.626758900826376, 7.768550182968216, 6.926360624177395, 7.783633032452715, 8.71868163050568, 9.591244127961701, 10.542052674656807, 11.526366075379329, 12.537988151506381, 13.502932999360368, 14.48098515292361, 16.349254719632512, 17.277207831578153, 16.42897192275025, 15.439692908162131, 14.429113113583202, 13.359365345901978, 12.426702211370905, 11.481256423599, 10.476433277401586, 9.64875458129433, 8.719899741265744, 7.9813296629266794, 8.853317068602376, 9.772987096118586, 10.55190555976844, 11.501097825153089, 12.465164835117726, 13.391978663631068, 14.366231976056095, 15.393649341239596, 17.34291170020086, 17.311514722686802, 16.391340278913827, 15.371755123722009, 14.473992113837737, 13.553093771320112, 12.76350479390266, 11.81465302301209, 11.341078385536015, 10.651102469096788, 9.769367192331838, 8.908866925071404, 9.895944256595913, 10.838700441739809, 11.583051046793688, 12.572178653697815, 13.487294896952454, 14.39758139886117, 15.352564386177773, 16.32213374142534, 17.343311921837962, 16.371247153112954, 15.35066480982278, 14.382545310063927, 13.521172551747384, 12.607051899177295, 11.798581256583683, 10.860906860485352, 10.354106675568847, 11.133800741104963, 10.828819114047914, 9.889441384448745, 10.832129982551535, 11.846914903257767, 12.518993927687253, 13.543258871746566, 14.526966378685234, 15.448478201113373, 16.331244162586557, 17.277813603120514, 16.370429970936723, 15.428904590091161, 14.382443309071892, 13.386248479832963, 12.550346537672237, 11.554300279748471, 10.806697673282688, 9.88050633833091, 9.289977776117222, 10.071685053763344, 10.970883373894695, 10.917410003535439, 11.856223385826096, 12.870935386856903, 13.48316002453239, 14.469166824858956, 15.483319535484615, 16.41074346672584, 17.354649246014965, 17.317449183809423, 15.465602703130875, 14.551913343362402, 13.499436696425553, 12.455378164620138, 11.554597711735354, 10.622273910028884, 9.83263375321578, 8.920343793722493, 8.229932960709254, 9.066529249015268, 9.967467517344009, 10.990307975993598, 11.767765112659449, 12.765663213225405, 13.763808327346192, 14.710961734634235, 15.690586047671403, 16.649542679904922, 17.433270159662634, 16.51144639970673, 14.465268033077782, 13.519447203980336, 12.541540328548418, 11.482712261713012, 10.550850269799986, 9.547470272465123, 8.827923017034696, 7.956997177745816, 7.23554222579879, 8.067455513052119, 9.01390288205733, 9.946654304167513, 10.809224175785626, 11.821645082519035, 12.821679023123242, 13.73802537218639, 14.691503938098943, 15.721397813784035, 16.46218966924454, 15.486966254987651, 13.648881119856815, 12.588227869629554, 11.56034390409718, 10.613323379471712, 9.569491085950824, 8.574255932855841, 7.754066465498917, 6.89456419711504, 6.173496026681456, 7.001127647547195, 7.998053982860562, 8.93469336702137, 9.877742412656074, 10.83839964720011, 11.809524020717173, 12.78515966952327, 13.73632203056372, 14.792025141626713, 15.544831776267124, 14.59887842841149, 12.671678718684241, 11.652644171919633, 10.629255969290494, 9.646637481803083, 8.621608463388572, 7.647123735678775, 6.78049897099023, 5.898499611324803, 5.120560601700834, 5.96517740849712, 6.9833092741269995, 7.975555708223613, 8.864912140601, 9.841772812251275, 10.847602260286095, 11.867018224336014, 12.886245208310044, 13.827097537753438, 14.612135445935367, 13.646137241560488, 11.660451820791026, 10.64876683505585, 9.688114870389935, 8.710494607208714, 7.762199425104696, 6.7048078344165996, 5.845579150844114, 4.927899978545869, 4.0902671717338, 4.892258751014188, 5.963825900879462, 6.988571853490005, 7.936937321654548, 8.866356158126294, 9.934394240347276, 10.924194525025982, 11.913459864112221, 12.886665317414064, 13.700927032973876, 12.719298800838645], [10.80808114023952, 11.76705639551245, 12.745159873735087, 11.883769898756315, 10.855535259125267, 9.900421448078408, 8.87307763446043, 7.8581935297328, 6.918536392533699, 5.894110114788094, 4.846974681933027, 4.014333245669695, 3.0118126397139435, 3.953629278348184, 4.8000040879977535, 5.788481708118649, 6.74586718709224, 7.770239784320516, 8.771165911929373, 9.797903508279479, 9.89638286169027, 10.852364395509719, 11.754646995431084, 10.918041161121119, 9.858190767343286, 8.957323585255994, 7.95081072353405, 6.978728943488722, 5.926966317695313, 4.857302517600267, 3.903906829170388, 2.9520534568566323, 1.974738515603541, 2.991165688020811, 3.8728760924270986, 4.845709077642884, 5.859538388356315, 6.787860233020493, 7.805477270276695, 8.850602517429945, 8.877357802448937, 9.818512942271829, 10.77527253410042, 9.929377933507192, 8.930537500699861, 7.917723856356447, 6.94808062419853, 5.926192114771586, 4.910529125989208, 3.9032744054582134, 2.8830611357059435, 1.9522681469167733, 0.9595228899280085, 1.9502847395725071, 2.924583512834269, 3.8632165483603926, 4.813075281565138, 5.865770875159333, 6.880079119193528, 7.831908448865362, 7.925457328717317, 8.862871393737613, 9.885728739639394, 8.999096180137153, 7.959836668587778, 6.934394709665071, 5.985913932212499, 4.9948053978102775, 4.0092550476519975, 3.032529656817533, 2.0320786111206264, 0.9639032810961258, 0.0, 0.9625484403557505, 1.9929987464718266, 3.0370290754407043, 3.965547701880836, 4.900665777687545, 5.894244930849084, 6.902827614771164, 8.85103298014093, 9.799994600004455, 10.828299656034098, 9.951601036604215, 8.942098590348118, 7.9212848420266, 6.875987345002487, 5.935283945720613, 4.864276748342193, 3.920032275228225, 2.9703923058400576, 1.9032729815086755, 0.9883357961576734, 1.9347016406909425, 2.955036998461743, 3.983041021864935, 4.944750444072671, 5.873613793849873, 6.840107712712003, 7.873046430717196, 9.70087607885081, 10.762615769329965, 11.597765643546078, 10.672378725902238, 9.633549264868382, 8.605969477693096, 7.6687940239020325, 6.700264262705212, 5.6902847099050895, 4.762750898275375, 3.816604006619901, 2.8642026053622573, 2.0151087648808343, 2.9440677132159583, 3.880898613479225, 4.86013613617703, 5.787469137062022, 6.843830343758862, 7.787789740169565, 8.750533019590133, 10.644906821645858, 11.659078870601677, 12.620261347193795, 11.673214068168539, 10.604321002519272, 9.576282919772215, 8.731004700116973, 7.687759463058696, 6.67779379733537, 5.704504806197337, 4.817195835379821, 3.888088212308771, 3.080812535835393, 3.9577368816907423, 4.833378536908263, 5.787557684164979, 6.74972278169708, 7.790793394807551, 8.799185688363943, 9.679963349352974, 11.645013139534754, 12.641361544522079, 13.602572424345231, 12.601233326381276, 11.629676851398669, 10.602433746709211, 9.707296147007852, 8.66914144699186, 7.610979727033308, 6.645978842807995, 5.77850154035394, 4.8200176182743855, 4.113973506548235, 4.961422588805238, 5.90673700502337, 6.841616869220752, 7.7712034693213905, 8.710158793673413, 9.761213008830595, 10.617049579227519, 12.614432280171629, 13.661958338969978, 14.432099036983825, 13.5040614458058, 12.55679712831183, 11.552252595817015, 10.615971498586376, 9.58871330920166, 8.624142673182154, 7.684193342858076, 6.790544732065712, 5.84238045089238, 5.077859767783979, 5.989490741470796, 6.832610810107695, 7.820288036566819, 8.748005619262383, 9.781524104672446, 10.749627842475585, 11.584488182712601, 13.552511982931854, 14.557651058194045, 15.43056548770549, 14.449440411206297, 13.49155152861242, 12.480671641098196, 11.50752770987409, 10.565392916269673, 9.56060875559061, 8.62995382017113, 7.757063663005055, 6.831890204268012, 6.063567011139945, 6.923211238285112, 7.827342714233018, 8.782405741031226, 9.721789176333138, 10.77581201584751, 11.786524586279775, 12.56517670789563, 14.524266241555766, 15.558938775379374, 16.41253133300211, 15.425962214819705, 14.425294175904833, 13.515454837154941, 12.446994805439223, 11.45545200475166, 10.48957255286771, 9.590662181922502, 8.73245346406434, 7.890263905273519, 7.087587595670107, 7.994868562352156, 8.784575943523155, 9.73538449021826, 10.685838769561151, 11.697460845688203, 12.66240569354219, 13.581881440567988, 15.467774066754407, 16.39572717870005, 16.479778493622256, 15.44115873610406, 14.527510460582523, 13.648204409799352, 12.746863479628956, 11.89316561559757, 11.440336558497712, 10.612657862390456, 9.683803022361868, 8.945232944022804, 8.157271631819768, 9.049174027965062, 9.745237375329893, 10.694429640714542, 11.624637529299548, 12.55145135781289, 13.525704670237918, 14.512168688361491, 16.461431047322755, 16.347611441590676, 15.4274369978177, 14.407851842625883, 13.51008883274161, 12.589190490223986, 11.799601512806538, 10.850749741915967, 11.819766457959252, 11.615005750192914, 10.733270473427963, 9.872770206167528, 9.203512903530285, 10.114887373586285, 10.776382862355142, 11.765510469259269, 12.646767591134276, 13.557054093042993, 14.512037080359596, 15.481606435607162, 16.379408640741833, 15.407343872016828, 14.386761528726653, 13.4186420289678, 12.557269270651258, 11.643148618081169, 10.83467797548756, 9.89700357938923, 10.936021847785025, 11.902686458468443, 11.792722395144038, 10.853344665544869, 10.139698629485908, 11.15448355019214, 11.712325743248707, 12.73659068730802, 13.701023540591727, 14.607950895295195, 15.490716856768378, 16.437286297302332, 15.406526689840595, 14.465001308995035, 13.418540027975766, 12.422345198736837, 11.58644325657611, 10.590396998652345, 9.842794392186565, 8.916603057234788, 9.8718929483334, 10.840570771126824, 11.799215770197982, 11.881313284631563, 11.163792032760469, 12.178504033791274, 12.676491840093844, 13.66249864042041, 14.676651351046068, 15.570216160907663, 16.514121940196787, 16.353545902713297, 14.501699422034749, 13.588010062266276, 12.535533415329427, 11.491474883524011, 10.590694430639228, 9.658370628932758, 8.868730472119656, 7.9564405126263695, 8.959928482443875, 9.931515689707652, 10.88247722016869, 11.930878127886, 12.101089885290996, 13.140918638093165, 13.62793073403387, 14.620503881375274, 15.600128194412441, 16.55908482664596, 16.469366878566507, 15.547543118610605, 13.501364751981656, 12.55554392288421, 11.577637047452292, 10.518808980616885, 9.58694698870386, 8.583566991368997, 7.86401973593857, 6.993093896649691, 7.965537747533411, 8.932441953744501, 9.928912584882012, 10.887757363200327, 11.77312745688175, 12.78554836361516, 13.785582304219366, 14.701928653282515, 15.655407219195068, 16.483601928018174, 15.498286388148415, 14.523062973891525, 12.68497783876069, 11.624324588533428, 10.596440623001055, 9.649420098375586, 8.605587804854698, 7.610352651759715, 6.7901631844027905, 5.930660916018915, 6.935692656017647, 7.866114088239578, 8.913063685685243, 9.875796426054185, 10.841645693752199, 11.802302928296234, 12.773427301813298, 13.749062950619395, 14.700225311659844, 15.629512357280932, 14.580928495170998, 13.634975147315364, 11.707775437588115, 10.688740890823507, 9.665352688194368, 8.682734200706957, 7.657705182292446, 6.683220454582649, 5.816595689894104, 4.934596330228679, 5.936045532902277, 6.9290806895932455, 7.947212555223126, 8.93945898931974, 9.828815421697124, 10.8056760933474, 11.81150554138222, 12.830921505432139, 13.850148489406168, 14.5927990811736, 13.648232164839241, 12.682233960464362, 10.6965485396949, 9.684863553959724, 8.724211589293809, 7.746591326112587, 6.79829614400857, 5.7409045533204734, 4.881675869747989, 3.963996697449744, 4.905752102935244, 5.856162032110313, 6.927729181975588, 7.952475134586131, 8.900840602750673, 9.830259439222418, 10.8982975214434, 11.888097806122108, 12.877363145208347, 13.738637211616464, 12.73702375187775, 11.75539551974252], [9.84553269988377, 10.8045079551567, 11.782611433379337, 12.773486574851919, 11.818083699481017, 10.862969888434158, 9.83562607481618, 8.82074197008855, 7.881084832889449, 6.856658555143844, 5.809523122288777, 4.976881686025445, 3.974361080069694, 3.006075811192015, 3.837455647642003, 4.825933267762899, 5.78331874673649, 6.807691343964766, 7.808617471573623, 8.835355067923729, 8.93383442133452, 9.889815955153969, 10.792098555075334, 11.740635776279026, 10.820739207699038, 9.919872025611745, 8.913359163889801, 7.941277383844473, 6.889514758051064, 5.819850957956017, 4.8664552695261385, 3.914601897212383, 2.9372869559592916, 2.043612220864642, 2.910327652071348, 3.883160637287134, 4.896989948000564, 5.825311792664742, 6.842928829920945, 7.8880540770741945, 7.914809362093187, 8.855964501916079, 9.81272409374467, 10.778889813908323, 9.893085941055613, 8.880272296712198, 7.910629064554282, 6.888740555127338, 5.873077566344959, 4.865822845813964, 3.845609576061694, 2.9148165872725236, 1.9220713302837589, 0.9877362992167565, 1.9620350724785185, 2.900668108004642, 3.850526841209388, 4.903222434803583, 5.917530678837778, 6.869360008509612, 6.962908888361567, 7.900322953381864, 8.923180299283644, 9.851789318788294, 8.922385108943528, 7.896943150020821, 6.948462372568249, 5.957353838166028, 4.9718034880077475, 3.9950780971732835, 2.994627051476377, 1.9264517214518762, 0.9625484403557505, 0.0, 1.0304503061160761, 2.074480635084954, 3.0029992615250856, 3.9381173373317946, 4.931696490493334, 5.940279174415414, 7.888484539785181, 8.837446159648705, 9.865751215678348, 10.89480704481847, 9.904647030703869, 8.88383328238235, 7.838535785358237, 6.897832386076363, 5.826825188697943, 4.882580715583975, 3.932940746195808, 2.865821421864426, 1.9508842365134238, 0.972153200335192, 1.9924885581059923, 3.020492581509184, 3.98220200371692, 4.911065353494122, 5.877559272356253, 6.910497990361446, 8.73832763849506, 9.800067328974215, 10.749305225409241, 11.634927166257988, 10.596097705224132, 9.568517918048846, 8.631342464257783, 7.662812703060962, 6.6528331502608395, 5.725299338631125, 4.779152446975651, 3.826751045718008, 2.919251663918495, 1.9902927155833707, 2.9183501731234744, 3.8975876958212794, 4.82492069670627, 5.88128190340311, 6.825241299813815, 7.787984579234383, 9.682358381290108, 10.696530430245927, 11.657712906838045, 12.635762508524289, 11.566869442875023, 10.538831360127965, 9.693553140472723, 8.650307903414447, 7.64034223769112, 6.667053246553087, 5.779744275735571, 4.850636652664521, 3.9849554348730534, 3.0039618840581546, 3.8708300965525124, 4.8250092438092285, 5.787174341341328, 6.828244954451799, 7.8366372480081905, 8.717414908997224, 10.682464699179004, 11.678813104166329, 12.640023983989481, 13.563781766737026, 12.592225291754419, 11.564982187064961, 10.669844587363603, 9.631689887347612, 8.573528167389059, 7.608527283163745, 6.74104998070969, 5.7825660586301355, 5.018116405585896, 4.007647591172651, 4.944188564667619, 5.879068428865002, 6.8086550289656405, 7.747610353317663, 8.798664568474845, 9.654501138871769, 11.651883839815879, 12.699409898614228, 13.677173664233296, 14.46660988616155, 13.51934556866758, 12.514801036172765, 11.578519938942126, 10.55126174955741, 9.586691113537904, 8.646741783213827, 7.753093172421462, 6.80492889124813, 5.975114348895942, 5.0357157438382085, 5.8700623697519445, 6.857739596211068, 7.785457178906632, 8.818975664316696, 9.787079402119835, 10.621939742356851, 12.589963542576104, 13.595102617838295, 14.56580625119872, 15.411988851562047, 14.45409996896817, 13.443220081453946, 12.47007615022984, 11.527941356625423, 10.523157195946364, 9.592502260526881, 8.719612103360804, 7.794438644623762, 6.916044780983056, 5.9694362406525245, 6.864794273877267, 7.8198573006754755, 8.759240735977388, 9.81326357549176, 10.823976145924025, 11.60262826753988, 13.561717801200016, 14.596390335023624, 15.54051000110655, 15.45624427018686, 14.60453168347486, 13.641689644991546, 12.808799385005578, 12.418000445107413, 11.452120993223463, 10.553210622278254, 9.695001904420089, 8.85281234562927, 7.9400653655132185, 7.041093564719569, 7.822027503167405, 8.77283604986251, 9.723290329205401, 10.734912405332453, 11.69985725318644, 12.619333000212238, 14.505225626398657, 15.4331787383443, 15.517230053266506, 14.478610295748307, 13.564962020226773, 12.685655969443602, 11.846961818075068, 12.792407605846973, 12.402884998853466, 11.575206302746208, 10.646351462717616, 9.907781384378554, 9.00974940166288, 8.095399030332475, 8.782688934974143, 9.731881200358792, 10.662089088943798, 11.58890291745714, 12.563156229882168, 13.549620248005741, 15.498882606967006, 15.385063001234926, 14.464888557461949, 13.445303402270131, 12.54754039238586, 11.626642049868236, 10.899699851252649, 11.78451532592033, 12.753532041963615, 12.577554190548666, 11.695818913783711, 10.835318646523278, 10.055990673373397, 9.161112375953698, 9.813834421999392, 10.802962028903519, 11.684219150778526, 12.594505652687243, 13.549488640003846, 14.519057995251412, 15.41686020038608, 14.444795431661076, 13.424213088370902, 12.456093588612049, 11.594720830295508, 10.680600177725418, 9.934776313933671, 10.830769163393592, 11.869787431789387, 12.836452042472805, 12.755270835499786, 11.815893105900619, 10.99217639932902, 10.209578329953654, 10.749777302892957, 11.77404224695227, 12.738475100235977, 13.645402454939445, 14.528168416412628, 15.474737856946582, 14.443978249484843, 13.502452868639283, 12.455991587620014, 11.459796758381085, 10.62389481622036, 9.627848558296595, 8.895240925030397, 9.85036864123915, 10.805658532337763, 11.774336355131187, 12.732981354202344, 12.843861724987313, 12.016269802603581, 11.233598813552788, 11.713943399738094, 12.69995020006466, 13.714102910690318, 14.607667720551913, 15.551573499841037, 15.390997462357545, 13.539150981678997, 12.625461621910524, 11.572984974973675, 10.52892644316826, 9.628145990283477, 8.695822188577008, 7.9211770049634875, 8.890206096630733, 9.893694066448239, 10.865281273712014, 11.816242804173054, 12.864643711890364, 12.953567655134108, 12.30847906049076, 12.66538229367812, 13.657955441019524, 14.637579754056691, 15.59653638629021, 15.506818438210756, 14.584994678254853, 12.538816311625904, 11.592995482528458, 10.61508860709654, 9.556260540261134, 8.624398548348108, 7.621018551013246, 6.9164662687824014, 7.926859480654055, 8.899303331537775, 9.866207537748865, 10.862678168886376, 11.821522947204691, 12.7356758972375, 13.25249719119713, 13.680185068485207, 14.63089180346737, 15.636878674471323, 15.521053487662424, 14.535737947792663, 13.560514533535773, 11.722429398404937, 10.661776148177676, 9.633892182645303, 8.686871658019834, 7.643039364498947, 6.647804211403964, 5.842609717246622, 6.864426500023279, 7.869458240022011, 8.799879672243941, 9.846829269689607, 10.80956201005855, 11.804194134107949, 12.764851368651984, 13.735975742169048, 14.711611390975145, 15.59312483569743, 14.66696391692518, 13.618380054815246, 12.672426706959612, 10.745226997232365, 9.726192450467757, 8.702804247838618, 7.720185760351207, 6.695156741936695, 5.720672014226898, 4.869042222737935, 5.897144770584429, 6.898593973258027, 7.891629129948996, 8.909760995578877, 9.90200742967549, 10.791363862052874, 11.76822453370315, 12.77405398173797, 13.793469945787889, 14.571102970261245, 13.63025064081785, 12.685683724483491, 11.719685520108612, 9.73400009933915, 8.722315113603974, 7.761663148938059, 6.784042885756837, 5.83574770365282, 4.7783561129647225, 3.93412240259182, 4.926545137805494, 5.868300543290994, 6.818710472466063, 7.890277622331338, 8.915023574941882, 9.863389043106423, 10.792807879578168, 11.86084596179915, 12.850646246477858, 13.833038545640912, 12.776088771260714, 11.774475311522, 10.79284707938677], [8.897483747947547, 9.856459003220477, 10.75216112726326, 11.743036268735842, 12.704962636422161, 11.893420194550234, 10.866076380932256, 9.851192276204626, 8.911535139005526, 7.887108861259921, 6.839973428404853, 5.957824336357679, 4.891760822246172, 3.883368389310363, 2.895326531105078, 3.883804151225974, 4.841189630199565, 5.865562227427841, 6.860568519637399, 7.8873061159875055, 7.9033841152184445, 8.859365649037892, 9.761648248959258, 10.71018547016295, 11.674933207243003, 10.950322331727822, 9.943809470005876, 8.971727689960549, 7.9199650641671395, 6.850301264072094, 5.896905575642214, 4.9450522033284585, 3.93733197140026, 2.92090479898299, 1.9681985355344231, 2.941031520750209, 3.9548608314636393, 4.883182676127817, 5.812478523804869, 6.857603770958119, 6.884359055977112, 7.825514195800003, 8.782273787628593, 9.748439507792247, 10.747279940599578, 9.910722602828274, 8.941079370670357, 7.919190861243413, 6.9035278724610345, 5.89627315193004, 4.87605988217777, 3.9452668933885997, 2.952521636399835, 1.9942047292033553, 1.0199059559415935, 1.9585389914677171, 2.9015828659116685, 3.9353750650089463, 4.8870803727217025, 5.838909702393536, 5.9324585822454905, 6.869872647265788, 7.892729993167567, 8.821339012672217, 9.860598524221592, 8.927393456136897, 7.978912678684326, 6.987804144282104, 6.002253794123824, 5.02552840328936, 4.025077357592453, 2.9569020275679523, 1.9929987464718266, 1.0304503061160761, 0.0, 1.0440303289688777, 1.9725489554090094, 2.9076670312157185, 3.901246184377258, 4.909828868299337, 6.8580342336691045, 7.806995853532629, 8.835300909562271, 9.864356738702394, 10.842860445981932, 9.914283588498426, 8.868986091474314, 7.92828269219244, 6.8572754948140195, 5.913031021700052, 4.963391052311884, 3.896271727980502, 2.9813345426295, 1.999164604000383, 0.9788292462295826, 2.006833269632774, 2.9685426918405105, 3.8974060416177125, 4.847108966240177, 5.880047684245369, 7.707877332378983, 8.769617022858139, 9.718854919293165, 10.644241836937004, 11.571325810551606, 10.54374602337632, 9.606570569585257, 8.638040808388435, 7.628061255588312, 6.700527443958597, 5.7543805523031235, 4.80197915104548, 3.811460179507319, 2.882501231172195, 1.9046908612470648, 2.8839283839448697, 3.811261384829861, 4.8676225915267, 5.794790993697739, 6.757534273118307, 8.651908075174031, 9.66608012412985, 10.627262600721968, 11.634257078629544, 12.542097548202497, 11.51405946545544, 10.668781245800197, 9.62553600874192, 8.615570343018593, 7.64228135188056, 6.754972381063044, 5.825864757991994, 4.877163950461878, 3.886944738381362, 2.8571707846761027, 3.811349931932819, 4.773515029464919, 5.814585642575391, 6.8143464193941305, 7.686964602881148, 9.652014393062927, 10.648362798050252, 11.609573677873405, 12.619451180839313, 13.567453397081893, 12.540210292392436, 11.645072692691077, 10.606917992675085, 9.548756272716531, 8.583755388491218, 7.716278086037162, 6.757794163957608, 5.91032492117472, 4.890630445495858, 3.9305292527912092, 4.865409116988593, 5.794995717089231, 6.733951041441253, 7.785005256598435, 8.624050832755692, 10.621433533699802, 11.668959592498151, 12.64672335811722, 13.574760949295245, 14.49457367399505, 13.490029141500235, 12.553748044269597, 11.52648985488488, 10.561919218865375, 9.621969888541297, 8.728321277748934, 7.763759667372975, 6.8251128318402445, 5.885714226782511, 4.856403057875535, 5.844080284334658, 6.771797867030222, 7.805316352440286, 8.773420090243425, 9.591489436240774, 11.559513236460027, 12.564652311722218, 13.535355945082644, 14.51648102158184, 14.596145214230347, 13.763324509363487, 13.44530425555731, 12.503169461952893, 11.498385301273835, 10.567730365854352, 9.630176957743268, 8.705003499006226, 7.766043263927359, 6.819434723596827, 5.851134962000858, 6.806197988799066, 7.745581424100977, 8.79960426361535, 9.810316834047615, 10.572177961423803, 12.53126749508394, 13.565940028907548, 14.510059694990474, 14.514115153649934, 13.662402566937935, 12.69956052845462, 13.505759431813367, 13.393228550434884, 12.427349098550934, 11.528438727605725, 10.605566758802553, 9.736279618623072, 8.790063848457521, 7.874079753732802, 6.808368191290995, 7.7591767379861, 8.70963101732899, 9.721253093456042, 10.686197941310029, 11.588882694096162, 13.47477532028258, 14.402728432228223, 14.57510093672958, 13.536481179211382, 12.622832903689847, 11.743526852906676, 12.543921864882856, 13.489367652654762, 13.378113104180937, 12.536785694968604, 11.55691631710008, 10.791248657372357, 9.80958323785077, 8.803973482477506, 7.769029623097732, 8.71822188848238, 9.648429777067387, 10.575243605580729, 11.549496918005756, 12.519169941889665, 14.46843230085093, 14.442933884698, 13.522759440925023, 12.503174285733206, 11.605411275848935, 10.68451293333131, 11.596659898060437, 12.493993015658608, 13.463009731701893, 13.539133582771061, 12.606383768166175, 11.718785919517082, 10.855824509561288, 9.869686828098729, 8.800175110122982, 9.789302717027107, 10.670559838902115, 11.580846340810831, 12.535829328127434, 13.505398683375, 14.474731083849155, 13.50266631512415, 12.482083971833976, 11.513964472075124, 10.652591713758582, 9.738471061188493, 10.63173636074146, 11.54024685313187, 12.579265121527666, 13.545929732211084, 13.66583568988225, 12.699360378894422, 11.774836465819929, 10.760051545113697, 9.736117991016547, 10.76038293507586, 11.724815788359566, 12.631743143063034, 13.514509104536216, 14.46107854507017, 13.501849132947918, 12.560323752102358, 11.513862471083089, 10.51766764184416, 9.681765699683435, 8.68571944175967, 9.592200971838185, 10.559846330977429, 11.515136222076041, 12.483814044869465, 13.442459043940623, 13.717721977866075, 12.694994439685038, 11.62708353551394, 10.700284087861684, 11.68629088818825, 12.700443598813909, 13.594008408675501, 14.537914187964626, 14.44886834582062, 12.597021865142073, 11.683332505373599, 10.63085585843675, 9.586797326631334, 8.686016873746551, 7.7536930720400825, 8.618137051771278, 9.599683786369011, 10.603171756186518, 11.608257001859446, 12.623596380123843, 13.671997287841153, 13.632292292215567, 12.649868095922496, 11.65172298180171, 12.644296129143115, 13.623920442180282, 14.582877074413801, 14.564689321673832, 13.64286556171793, 11.59668719508898, 10.650866365991535, 9.672959490559615, 8.614131423724208, 7.682269431811183, 6.678889434476321, 7.613426315590193, 8.636337170392334, 9.608781021276053, 10.609183265896297, 11.670031744837164, 12.62887652315548, 13.589400996497414, 13.593886226628866, 12.666525756608797, 13.61723249159096, 14.623219362594913, 14.5789243711255, 13.59360883125574, 12.61838541699885, 10.780300281868014, 9.719647031640752, 8.69176306610838, 7.7447425414829105, 6.700910247962023, 5.70567509486704, 6.64996329319741, 7.671780075974067, 8.6768118159728, 9.60723324819473, 10.654182845640396, 11.616915586009338, 12.676247410137632, 13.636904644681668, 13.706068225850466, 14.57009819425408, 14.650995719160505, 13.724834800388257, 12.676250938278322, 11.730297590422689, 9.80309788069544, 8.784063333930831, 7.760675131301693, 6.778056643814281, 5.7530276253997705, 4.778542897689974, 5.746334800856284, 6.801913749629161, 7.803362952302761, 8.810927845230427, 9.88252410387437, 10.875920327050515, 11.817055954723008, 12.793916626373283, 13.799746074408104, 14.648200837698349, 13.62897385372432, 12.688121524280925, 11.743554607946566, 10.777556403571687, 8.791870982802225, 7.780185997067049, 6.819534032401133, 5.841913769219913, 4.8936185871158955, 3.836226996427798, 4.811414980710168, 5.831314116850227, 6.773069522335728, 7.8184750105109355, 8.89004216037621, 9.914788112986754, 10.889081135776557, 11.818499972248302, 12.886538054469284, 13.737525183419002, 12.802588239524836, 11.745638465144637, 10.826426359585778, 9.850717962849844], [7.853453418978669, 8.8124286742516, 9.708130798294384, 10.699005939766966, 11.660932307453285, 12.599339423101192, 11.855158138293383, 10.840274033565754, 9.900616896366653, 8.876190618621049, 7.82905518576598, 6.887627684528589, 5.821564170417082, 4.813171737481272, 3.8251298792759876, 2.9994496024175077, 3.8559344809518787, 4.880307078180154, 5.816538190668521, 6.843275787018628, 6.859353786249567, 7.815335320069015, 8.71761791999038, 9.666155141194071, 10.630902878274126, 11.620137504783937, 10.955527765403634, 9.963531951609987, 8.911769325816577, 7.839383021433221, 6.885987333003341, 5.9259452592981905, 4.86713531957117, 3.8507081471538998, 2.8980018837053327, 1.9935687978688712, 2.930486803462575, 3.858808648126753, 4.768448194835992, 5.8135734419892415, 5.8403287270082345, 6.781483866831126, 7.738243458659716, 8.70440917882337, 9.703249611630701, 10.716063255974117, 9.968065618664959, 8.946177109238015, 7.930514120455635, 6.923259399924641, 5.9030461301723705, 4.9722531413832005, 3.9199829118119593, 2.924008077374265, 1.949709304112503, 1.0110762685863794, 1.8575525369427908, 2.8913447360400686, 3.843050043752825, 4.794879373424659, 4.888428253276613, 5.82584231829691, 6.84869966419869, 7.77730868370334, 8.816568195252714, 9.842010154175421, 9.022943007653206, 8.031834473250983, 7.046284123092702, 6.069558732258238, 5.069107686561331, 4.00093235653683, 3.0370290754407043, 2.074480635084954, 1.0440303289688777, 0.0, 0.9285186264401317, 1.8636367022468407, 2.85721585540838, 3.86579853933046, 5.814003904700227, 6.762965524563752, 7.791270580593394, 8.820326409733518, 9.798830117013054, 10.864638286928258, 9.91301642044319, 8.972313021161316, 7.901305823782897, 6.957061350668929, 6.0074213812807615, 4.940302056949379, 4.025364871598378, 3.0431949329692607, 2.0228595751984604, 1.0611448621057875, 1.9276144881939463, 2.8564778379711484, 3.8030786372713, 4.836017355276492, 6.6638470034101065, 7.725586693889263, 8.674824590324288, 9.600211507968128, 10.639040969001984, 11.587776352345198, 10.650600898554135, 9.682071137357314, 8.67209158455719, 7.744557772927475, 6.798410881272002, 5.846009480014358, 4.855490508476197, 3.926531560141073, 2.9487211902159425, 2.0300313308741984, 2.947854861086091, 3.8549028243787617, 4.750760664728862, 5.71350394414943, 7.607877746205155, 8.622049795160974, 9.583232271753092, 10.590226749660667, 11.609812706652875, 12.558089794424317, 11.712811574769075, 10.669566337710796, 9.65960067198747, 8.686311680849437, 7.799002710031922, 6.869895086960872, 5.921194279430756, 4.93097506735024, 3.901201113644981, 3.0972451375929655, 3.9101085057211487, 4.830764761778656, 5.770316090425253, 6.642934273912271, 8.607984064094051, 9.604332469081376, 10.565543348904528, 11.575420851870437, 12.546977326853044, 13.584240621361314, 12.689103021659955, 11.65094832164396, 10.592786601685408, 9.627785717460094, 8.76030841500604, 7.801824492926486, 6.954355250143598, 5.934660774464736, 4.974559581760087, 4.151304322648739, 4.9666827704894905, 5.892810298892296, 6.820877789862739, 7.580020503786816, 9.577403204730926, 10.624929263529275, 11.602693029148343, 12.530730620326368, 13.477737955352076, 14.482282487846891, 13.597778373238473, 12.570520183853757, 11.605949547834252, 10.666000217510174, 9.772351606717812, 8.807789996341853, 7.869143160809123, 6.929744555751389, 5.900433386844413, 5.179725744633981, 6.02483244504714, 6.964175609891328, 7.809292623507728, 8.547459107271898, 10.515482907491151, 11.520621982753342, 12.491325616113768, 13.472450692612963, 13.959768459533663, 14.693127857534398, 14.489334584526187, 13.54719979092177, 12.542415630242711, 11.611760694823229, 10.674207286712146, 9.749033827975104, 8.810073592896236, 7.863465052565705, 6.895165290969736, 6.141843449098388, 7.027527790107242, 7.958463521066392, 8.846189367311919, 9.528147632454926, 11.487237166115063, 12.521909699938671, 13.466029366021598, 13.84755885035684, 13.026025812241251, 13.629363876625531, 14.435562779984277, 14.43725887940376, 13.47137942751981, 12.572469056574601, 11.649597087771431, 10.780309947591949, 9.834094177426397, 8.91811008270168, 7.852398520259873, 7.2045530942395555, 7.9915773833352555, 8.989173142849953, 9.912472367028293, 10.544852365127285, 12.430744991313704, 13.358698103259346, 13.877305096813533, 12.869924875918288, 11.986456148993165, 12.673330201077587, 13.473725213053767, 14.419171000825672, 14.422143433149813, 13.580816023937482, 12.600946646068959, 11.835278986341233, 10.85361356681965, 9.848003811446384, 8.813059952066611, 8.180901374141712, 8.930376143073651, 9.857189971586994, 10.831443284012021, 11.475139612920788, 13.424401971882054, 13.73875385701591, 12.818579413242933, 11.836617982440112, 10.969034521152253, 11.614316281502221, 12.526463246231348, 13.423796363829517, 14.392813079872802, 14.58316391173994, 13.650414097135053, 12.762816248485958, 11.899854838530167, 10.913717157067607, 9.84420543909186, 9.251982202686438, 9.95250620490838, 10.862792706817096, 11.817775694133699, 12.478018931914317, 13.709856520568794, 12.79848628744206, 11.777903944151886, 10.84740816878203, 10.0162149590619, 10.668274409359404, 11.56153970891237, 12.47005020130278, 13.509068469698574, 14.475733080381993, 14.709866018851129, 13.743390707863298, 12.818866794788807, 11.804081874082575, 10.780148319985425, 10.259620674893952, 11.00676215436583, 11.913689509069298, 12.796455470542481, 13.533595105882071, 12.736974569667556, 11.810959964778327, 10.774949620681815, 9.851111338551066, 9.045388944986753, 9.61552278993058, 10.522004320009096, 11.489649679148338, 12.44493957024695, 13.413617393040374, 14.372262392111532, 14.761752306834953, 13.739024768653916, 12.671113864482818, 11.744314416830562, 11.185528628006342, 12.023525390835196, 12.875954774681766, 13.81986055397089, 13.683993782540258, 11.677729937324372, 10.776737443535653, 9.780298454249467, 8.92024102333824, 8.019460570453456, 8.683496420210993, 9.547940399942188, 10.52948713453992, 11.532975104357426, 12.538060350030356, 13.553399728294751, 14.601800636012062, 14.676322621184443, 13.693898424891374, 12.695753310770588, 12.212864833345282, 13.024748015340002, 13.923321802469422, 13.541982741680926, 12.723573633900228, 10.67739526727128, 9.731574438173833, 8.822402086372332, 7.947575120431114, 7.015713128518088, 7.608692782647231, 8.543229663761101, 9.566140518563243, 10.538584369446962, 11.538986614067205, 12.599835093008073, 13.558679871326389, 14.519204344668323, 14.637916555597744, 13.710556085577675, 13.185801195793127, 14.024046935754633, 13.556217791132594, 12.570902251262833, 11.699093489181148, 9.789844418278363, 8.800355103823051, 7.83725451613944, 6.890233991513971, 6.034353944668927, 6.635478443037949, 7.57976664136832, 8.601583424144977, 9.606615164143708, 10.537036596365638, 11.583986193811304, 12.546718934180246, 13.606050758308541, 14.566707992852576, 14.750098554819344, 14.138666898456247, 13.6159099875073, 12.6922408056119, 11.643656943501966, 10.697703595646333, 8.776986513673021, 7.821372851906733, 6.844416347683873, 5.88621306744385, 4.970761362628049, 5.708346245860883, 6.676138149027192, 7.73171709780007, 8.73316630047367, 9.740731193401338, 10.812327452045281, 11.805723675221426, 12.746859302893917, 13.723719974544192, 14.560363531259473, 13.613115106045143, 12.593888122071114, 11.653035792627719, 10.70846887629336, 9.74247067191848, 7.765759615779807, 6.754074630044631, 5.834278883153447, 4.885242662012836, 4.009264038307428, 4.766030344598708, 5.741218328881077, 6.761117465021136, 7.702872870506637, 8.748278358681844, 9.819845508547118, 10.844591461157663, 11.818884483947466, 12.748303320419211, 13.618068337406338, 12.693494854450126, 11.75855791055596, 10.70160813617576, 9.7823960306169, 8.815632231196638], [6.9249347925385365, 7.883910047811467, 8.779612171854254, 9.770487313326836, 10.732413681013153, 11.670820796661058, 12.698164610279036, 11.708090408686777, 10.768433271487677, 9.744006993742072, 8.696871560887006, 7.755444059649614, 6.689380545538107, 5.680988112602297, 4.692946254397012, 3.867265977538533, 2.9274158545117475, 3.9517884517400232, 4.888019564228389, 5.914757160578496, 5.930835159809435, 6.886816693628884, 7.789099293550249, 8.737636514753941, 9.702384251833994, 10.691618878343803, 11.755047582842066, 10.83134832673101, 9.779585700937602, 8.707199396554246, 7.753803708124367, 6.793761634419216, 5.734951694692195, 4.718524522274925, 3.7658182588263576, 2.8613851729898965, 2.0019681770224436, 2.9302900216866217, 3.8399295683958603, 4.885054815549109, 4.911810100568103, 5.852965240390994, 6.809724832219585, 7.775890552383238, 8.774730985190569, 9.787544629533983, 10.818747232031704, 9.81399348435904, 8.79833049557666, 7.791075775045666, 6.770862505293396, 5.840069516504226, 4.787799286932985, 3.7918244524952898, 2.817525679233528, 1.8788926437074045, 0.929033910502659, 1.9628261095999369, 2.9145314173126935, 3.8663607469845274, 3.959909626836482, 4.897323691856779, 5.920181037758558, 6.8487900572632086, 7.888049568812583, 8.91349152773529, 9.861972305187862, 8.960353099691115, 7.974802749532834, 6.99807735869837, 5.997626313001463, 4.929450982976962, 3.965547701880836, 3.0029992615250856, 1.9725489554090094, 0.9285186264401317, 0.0, 0.935118075806709, 1.9286972289682485, 2.9372799128903284, 4.885485278260096, 5.834446898123621, 6.8627519541532624, 7.891807783293386, 8.870311490572924, 9.936119660488128, 10.841535046883324, 9.90083164760145, 8.829824450223029, 7.885579977109061, 6.935940007720894, 5.868820683389512, 4.953883498038509, 3.9717135594093924, 2.951378201638592, 1.9608052839615508, 0.9990958617538146, 1.9279592115310167, 2.874560010831168, 3.9074987288363605, 5.735328376969974, 6.797068067449131, 7.746305963884156, 8.671692881527996, 9.710522342561852, 10.73810212973714, 11.579119524994265, 10.610589763797444, 9.60061021099732, 8.673076399367606, 7.726929507712132, 6.774528106454489, 5.784009134916328, 4.855050186581204, 3.877239816656074, 2.929691752729962, 2.019336234645959, 2.92638419793863, 3.82224203828873, 4.784985317709298, 6.679359119765023, 7.693531168720842, 8.65471364531296, 9.661708123220535, 10.681294080212743, 11.708415571816259, 12.641330201209206, 11.598084964150926, 10.5881192984276, 9.614830307289568, 8.727521336472051, 7.798413713401002, 6.849712905870887, 5.859493693790371, 4.829719740085112, 3.996905559448729, 2.981589879281017, 3.902246135338525, 4.841797463985122, 5.714415647472139, 7.679465437653919, 8.675813842641244, 9.637024722464396, 10.646902225430305, 11.618458700412912, 12.66845373002878, 13.617621648100085, 12.579466948084091, 11.521305228125538, 10.556304343900225, 9.68882704144617, 8.730343119366617, 7.882873876583729, 6.863179400904867, 5.903078208200219, 4.967750744149997, 4.038164144049358, 4.964291672452164, 5.892359163422608, 6.651501877346684, 8.648884578290794, 9.69641063708914, 10.67417440270821, 11.602211993886236, 12.549219328911944, 13.55376386140676, 14.490044958637398, 13.499038810293888, 12.534468174274382, 11.594518843950304, 10.700870233157943, 9.736308622781984, 8.797661787249254, 7.8582631821915205, 6.828952013284544, 5.9961721661352385, 5.096313818607008, 6.035656983451197, 6.880773997067597, 7.618940480831766, 9.586964281051019, 10.59210335631321, 11.562806989673636, 12.543932066172829, 13.501820948766705, 14.497402325700758, 15.417853210966317, 14.4757184173619, 13.470934256682842, 12.540279321263359, 11.602725913152279, 10.677552454415236, 9.738592219336368, 8.791983679005837, 7.823683917409867, 6.958289870599646, 6.09900916366711, 7.0299448946262615, 7.917670740871786, 8.599629006014794, 10.558718539674931, 11.59339107349854, 12.537510739581464, 12.935641512453339, 13.845192363887097, 14.497180251746554, 15.3033791551053, 15.36577750584389, 14.39989805395994, 13.500987683014731, 12.578115714211563, 11.708828574032083, 10.762612803866531, 9.846628709141811, 8.780917146700004, 8.020999515740813, 7.063058756895123, 8.060654516409823, 8.983953740588163, 9.616333738687153, 11.50222636487357, 12.430179476819212, 12.9487864703734, 11.958007538014787, 12.80562270063901, 13.54114657619861, 14.34154158817479, 15.286987375946696, 15.350662059589943, 14.509334650377614, 13.529465272509091, 12.763797612781367, 11.78213219325978, 10.776522437886515, 9.741578578506742, 8.99734779564297, 8.001857516633521, 8.928671345146864, 9.90292465757189, 10.546620986480654, 12.49588334544192, 12.810235230575778, 11.8900607868028, 10.92470064453661, 11.788201072798097, 12.482132656623245, 13.394279621352371, 14.291612738950542, 15.260629454993827, 15.511682538180072, 14.578932723575186, 13.691334874926092, 12.828373464970298, 11.842235783507737, 10.77272406553199, 9.976586853051554, 9.02398757846825, 9.934274080376966, 10.889257067693569, 11.549500305474183, 12.781337894128662, 11.869967661001928, 10.849385317711754, 9.935490830878528, 10.835381510707744, 11.536090784480427, 12.429356084033394, 13.337866576423805, 14.3768848448196, 15.343549455503018, 15.63838464529126, 14.671909334303432, 13.747385421228937, 12.732600500522706, 11.708666946425556, 10.984225325259068, 10.0782435279257, 10.985170882629168, 11.867936844102351, 12.605076479441937, 11.808455943227424, 10.882441338338195, 9.846430994241683, 8.939194000647564, 9.864555496632597, 10.483339165051603, 11.389820695130119, 12.357466054269363, 13.312755945367975, 14.2814337681614, 15.240078767232557, 15.690270933275084, 14.667543395094047, 13.599632490922948, 12.672833043270693, 11.910133278371458, 11.095006764395066, 11.947436148241636, 12.89134192753076, 12.755475156100125, 10.74921131088424, 9.848218817095521, 8.851779827809334, 8.008323685434739, 8.887276945574481, 9.551312795332016, 10.415756775063212, 11.397303509660945, 12.400791479478452, 13.40587672515138, 14.421216103415775, 15.469617011133085, 15.604841247624574, 14.622417051331505, 13.624271937210718, 12.937469483710398, 12.096229388899872, 12.994803176029292, 12.613464115240793, 11.795055007460096, 9.748876640831147, 8.803055811733701, 7.8938834599322, 7.035657782527613, 7.883529503639113, 8.476509157768255, 9.411046038882127, 10.433956893684268, 11.406400744567987, 12.40680298918823, 13.467651468129096, 14.426496246447412, 15.387020719789346, 15.566435182037875, 14.639074712017806, 13.910405846158243, 13.095528309314503, 12.627699164692462, 11.6423836248227, 10.770574862741016, 8.861325791838231, 7.871836477382919, 6.908735889699309, 5.9617153650738395, 6.902170319789953, 7.503294818158974, 8.447583016489343, 9.469399799266, 10.474431539264732, 11.404852971486662, 12.451802568932328, 13.41453530930127, 14.473867133429565, 15.4345243679736, 14.611469110026855, 13.638553722107616, 12.687391361067167, 11.763722179171769, 10.715138317061834, 9.7691849692062, 7.84846788723289, 6.892854225466601, 5.915897721243741, 4.957694441003719, 5.838577737749074, 6.576162620981908, 7.5439545241482175, 8.599533472921095, 9.600982675594695, 10.608547568522361, 11.680143827166305, 12.67354005034245, 13.614675678014942, 14.591536349665217, 13.631844904819339, 12.68459647960501, 11.665369495630982, 10.724517166187587, 9.779950249853227, 8.813952045478349, 6.837240989339675, 5.825556003604499, 4.905760256713315, 3.956724035572705, 4.8770804134284536, 5.633846719719732, 6.609034704002102, 7.628933840142161, 8.570689245627662, 9.61609473380287, 10.687661883668143, 11.712407836278688, 12.686700859068491, 13.616119695540236, 12.689549710966205, 11.764976228009994, 10.830039284115829, 9.77308950973563, 8.853877404176767, 7.887113604756506], [5.989816716731827, 6.9487919720047575, 7.844494096047543, 8.835369237520124, 9.797295605206443, 10.735702720854349, 11.763046534472327, 12.643208484493487, 11.703551347294386, 10.679125069548782, 9.631989636693714, 8.690562135456323, 7.6244986213448165, 6.616106188409007, 5.628064330203722, 4.802384053345242, 3.862533930318456, 3.071434715282776, 3.9529014884216798, 4.979639084771787, 4.9957170840027265, 5.951698617822174, 6.85398121774354, 7.802518438947231, 8.767266176027285, 9.756500802537094, 10.819929507035356, 11.76646640253772, 10.71470377674431, 9.642317472360954, 8.688921783931075, 7.728879710225925, 6.6700697704989045, 5.6536425980816345, 4.7009363346330675, 3.7965032487966055, 2.937086252829152, 2.041109878818496, 2.904811492589151, 3.9499367397424003, 3.9766920247613937, 4.917847164584285, 5.874606756412875, 6.840772476576529, 7.83961290938386, 8.852426553727273, 9.883629156224995, 10.74911156016575, 9.73344857138337, 8.726193850852376, 7.705980581100105, 6.775187592310935, 5.722917362739694, 4.726942528302, 3.7526437550402374, 2.8140107195141137, 1.864151986309368, 1.0277080337932278, 1.9794133415059842, 2.931242671177818, 3.0247915510297725, 3.9622056160500696, 4.985062961951849, 5.913671981456499, 6.952931493005874, 7.978373451928581, 8.926854229381153, 9.895471175497823, 8.909920825339542, 7.933195434505078, 6.932744388808171, 5.864569058783671, 4.900665777687545, 3.9381173373317946, 2.9076670312157185, 1.8636367022468407, 0.935118075806709, 0.0, 0.9935791531615393, 2.0021618370836194, 3.9503672024533865, 4.899328822316911, 5.927633878346553, 6.956689707486676, 7.935193414766214, 9.001001584681418, 9.980824300440906, 10.83594972340816, 9.764942526029738, 8.82069805291577, 7.871058083527603, 6.803938759196221, 5.889001573845218, 4.906831635216101, 3.886496277445301, 2.89592335976826, 1.9342139375605236, 1.0496516261223223, 1.939441935024459, 2.9723806530296515, 4.800210301163265, 5.861949991642422, 6.811187888077447, 7.736574805721286, 8.775404266755142, 9.80298405393043, 10.740159507721494, 11.545707839604153, 10.53572828680403, 9.608194475174315, 8.662047583518842, 7.709646182261198, 6.7191272107230375, 5.790168262387914, 4.812357892462783, 3.8648098285366705, 2.954454310452668, 2.0480766125299357, 2.887123962482021, 3.849867241902589, 5.744241043958313, 6.758413092914132, 7.71959556950625, 8.726590047413826, 9.746176004406033, 10.77329749600955, 11.714919057204906, 12.533203039957636, 11.52323737423431, 10.549948383096277, 9.66263941227876, 8.733531789207712, 7.7848309816775965, 6.794611769597081, 5.764837815891822, 4.932023635255438, 3.916707955087726, 3.023938549929831, 3.9066793881784125, 4.77929757166543, 6.744347361847209, 7.740695766834534, 8.701906646657687, 9.711784149623595, 10.683340624606203, 11.73333565422207, 12.691210504095785, 13.5145850238908, 12.456423303932247, 11.491422419706934, 10.62394511725288, 9.665461195173327, 8.81799195239044, 7.798297476711577, 6.838196284006928, 5.902868819956707, 4.973282219856068, 4.08598408704347, 4.957241087615898, 5.716383801539975, 7.713766502484083, 8.761292561282431, 9.739056326901501, 10.667093918079527, 11.614101253105234, 12.61864578560005, 13.554926882830689, 14.434156886100597, 13.469586250081091, 12.529636919757014, 11.635988308964652, 10.671426698588693, 9.732779863055962, 8.79338125799823, 7.764070089091254, 6.931290241941948, 6.031431894413718, 5.157349398042502, 5.9456559212608875, 6.683822405025057, 8.65184620524431, 9.6569852805065, 10.627688913866926, 11.60881399036612, 12.566702872959995, 13.562284249894049, 14.535428181118155, 15.41083649316861, 14.406052332489551, 13.475397397070068, 12.537843988958988, 11.612670530221946, 10.673710295143078, 9.727101754812546, 8.758801993216576, 7.893407946406356, 7.034127239473819, 6.151637309217566, 6.982552665065077, 7.664510930208086, 9.623600463868222, 10.65827299769183, 11.602392663774754, 12.636558845087393, 13.500445520252407, 14.474073389888531, 15.542533421604249, 16.3008955816506, 15.33501612976665, 14.43610575882144, 13.513233790018273, 12.643946649838792, 11.69773087967324, 10.78174678494852, 9.716035222506713, 8.956117591547523, 7.998176832701833, 7.1823469310011285, 8.048835664781453, 8.681215662880444, 10.56710828906686, 11.495061401012503, 12.096058556196478, 12.893125613821496, 13.740740776445719, 14.47626465200532, 15.2766596639815, 16.222105451753404, 16.285780135396653, 15.444452726184323, 14.4645833483158, 13.698915688588077, 12.71725026906649, 11.711640513693224, 10.676696654313451, 9.93246587144968, 8.93697559244023, 8.21499832791794, 8.984188587889584, 9.611502910673945, 11.56076526963521, 11.898342191788068, 11.037332872625878, 11.85981872034332, 12.723319148604807, 13.417250732429954, 14.32939769715908, 15.226730814757252, 16.195747530800535, 16.44680061398678, 15.514050799381895, 14.626452950732801, 13.763491540777007, 12.777353859314447, 11.7078421413387, 10.911704928858263, 9.959105654274959, 9.220601063148042, 9.970520998011262, 10.614382229667473, 11.846219818321952, 10.958074622214218, 9.996657403534831, 10.870608906685238, 11.770499586514454, 12.471208860287136, 13.364474159840103, 14.272984652230514, 15.312002920626309, 16.27866753130973, 16.57350272109797, 15.607027410110142, 14.682503497035647, 13.667718576329415, 12.643785022232265, 11.919343401065777, 11.01336160373241, 10.271497865400244, 10.949200774420044, 11.669958403635228, 10.873337867420714, 9.947323262531485, 8.99370308006476, 9.874312076454274, 10.799673572439307, 11.418457240858313, 12.324938770936829, 13.292584130076072, 14.247874021174685, 15.216551843968109, 16.175196843039267, 16.625389009081793, 15.602661470900756, 14.534750566729658, 13.607951119077402, 12.845251354178167, 12.030124840201776, 11.233763131012712, 12.016369113245329, 11.820357080293416, 9.81409323507753, 8.913100741288812, 7.999051913632413, 8.943441761241449, 9.822395021381192, 10.486430871138726, 11.350874850869921, 12.332421585467655, 13.335909555285161, 14.34099480095809, 15.356334179222484, 16.404735086939795, 16.539959323431283, 15.557535127138214, 14.559390013017428, 13.872587559517108, 13.031347464706581, 12.281130158800368, 11.678346039434084, 10.859936931653387, 8.813758565024438, 7.867937735926992, 7.041155545755279, 7.970775858334322, 8.818647579445823, 9.411627233574965, 10.346164114688836, 11.369074969490978, 12.341518820374697, 13.34192106499494, 14.402769543935806, 15.361614322254121, 16.322138795596057, 15.618653620705647, 14.61861968010144, 13.656301348964027, 12.707455192795681, 11.692581088885753, 10.707265549015991, 9.835456786934307, 7.926207716031522, 6.93671840157621, 6.056007975522388, 6.896833440880548, 7.837288395596662, 8.438412893965683, 9.382701092296053, 10.40451787507271, 11.409549615071441, 12.339971047293371, 13.386920644739037, 14.34965338510798, 15.408985209236274, 14.64747540773721, 13.676351034220145, 12.703435646300907, 11.752273285260458, 10.828604103365059, 9.780020241255125, 8.834066893399491, 6.913349811426181, 5.957736149659891, 5.035543984786495, 5.8928125168104275, 6.773695813555784, 7.511280696788618, 8.479072599954927, 9.534651548727807, 10.536100751401404, 11.54366564432907, 12.615261902973014, 13.608658126149159, 14.549793753821652, 13.70255627704745, 12.69672682901263, 11.749478403798301, 10.730251419824272, 9.789399090380877, 8.844832174046518, 7.878833969671639, 5.902122913532965, 4.890437927797789, 4.025406520256069, 4.891842111379414, 5.812198489235163, 6.568964795526442, 7.544152779808812, 8.564051915948871, 9.505807321434371, 10.551212809609579, 11.622779959474853, 12.647525912085397, 13.6218189348752, 12.787595573130247, 11.754431635159495, 10.829858152203284, 9.894921208309118, 8.83797143392892, 7.918759328370059, 6.951995528949796], [4.996237563570288, 5.9552128188432185, 6.850914942886004, 7.8417900843585855, 8.803716452044902, 9.74212356769281, 10.769467381310786, 11.784351486038418, 12.697130500455927, 11.672704222710323, 10.625568789855254, 9.684141288617862, 8.618077774506355, 7.609685341570546, 6.621643483365261, 5.7776382648012, 4.820252785827609, 3.960248462868997, 2.9593223352601408, 3.9860599316102476, 4.002137930841187, 4.958119464660635, 5.860402064582001, 6.808939285785692, 7.773687022865745, 8.762921649375555, 9.826350353873817, 10.818346167667464, 11.70828292990585, 10.635896625522495, 9.682500937092616, 8.722458863387464, 7.6636489236604435, 6.6472217512431735, 5.6945154877946065, 4.790082401958145, 3.8948051083383053, 2.9664832636741276, 1.9112323394276116, 2.956357586580861, 2.9831128715998543, 3.9242680114227455, 4.8810276032513364, 5.84719332341499, 6.846033756222321, 7.858847400565735, 8.890050003063457, 9.911938512490401, 10.727027724544909, 9.719773004013915, 8.699559734261644, 7.768766745472474, 6.716496515901233, 5.720521681463539, 4.746222908201776, 3.8075898726756527, 2.8577311394709075, 2.001037157832869, 0.9858341883444449, 1.9376635180162787, 2.0312123978682335, 2.9686264628885306, 3.99148380879031, 4.92009282829496, 5.959352339844335, 6.984794298767042, 7.933275076219614, 8.924383610621836, 9.903499978501081, 8.926774587666618, 7.92632354196971, 6.85814821194521, 5.894244930849084, 4.931696490493334, 3.901246184377258, 2.85721585540838, 1.9286972289682485, 0.9935791531615393, 0.0, 1.00858268392208, 2.9567880492918475, 3.905749669155372, 4.934054725185014, 5.963110554325137, 6.941614261604675, 8.007422431519878, 8.987245147279367, 9.927948546561241, 10.758521679191277, 9.814277206077309, 8.864637236689141, 7.79751791235776, 6.882580727006757, 5.900410788377641, 4.880075430606841, 3.854845188074745, 2.893135765867009, 1.9642724160898068, 0.9458627818629196, 1.978801499868112, 3.806631148001726, 4.868370838480883, 5.817608734915908, 6.742995652559747, 7.781825113593603, 8.80940490076889, 9.746580354559953, 10.715110115756774, 11.52633957388221, 10.598805762252494, 9.65265887059702, 8.700257469339377, 7.709738497801216, 6.780779549466092, 5.802969179540962, 4.823731656843156, 3.9133761387591535, 2.946541380060225, 1.8935448093204816, 2.85628808874105, 4.750661890796774, 5.764833939752593, 6.726016416344711, 7.733010894252287, 8.752596851244494, 9.779718342848009, 10.721339904043365, 11.753750878557558, 12.513848661312489, 11.540559670174456, 10.65325069935694, 9.724143076285891, 8.775442268755775, 7.785223056675259, 6.75544910297, 5.890945463561923, 4.875629783394212, 3.921492528573265, 2.913100235016873, 3.7857184185038912, 5.75076820868567, 6.747116613672995, 7.708327493496148, 8.718204996462056, 9.689761471444664, 10.739756501060532, 11.697631350934245, 12.735132862490723, 13.447034591010427, 12.482033706785113, 11.61455640433106, 10.656072482251506, 9.808603239468617, 8.788908763789756, 7.823077155047705, 6.852079990139565, 5.922493390038927, 4.983538065686904, 3.963661934454359, 4.722804648378436, 6.720187349322544, 7.767713408120893, 8.745477173739962, 9.673514764917988, 10.620522099943695, 11.62506663243851, 12.56134772966915, 13.588605919053865, 14.460197537159273, 13.520248206835195, 12.626599596042832, 11.656307569629469, 10.717660734096738, 9.778262129039005, 8.74895096013203, 7.880501412124806, 6.980643064596577, 6.018894384916561, 4.9520767680993485, 5.690243251863518, 7.65826705208277, 8.663406127344961, 9.634109760705387, 10.615234837204582, 11.573123719798458, 12.56870509673251, 13.541849027956616, 14.483983821561033, 15.396663619567732, 14.46600868414825, 13.522724859999764, 12.597551401262722, 11.658591166183854, 10.711982625853322, 9.743682864257352, 8.842619116589214, 7.983338409656678, 7.0131822960916255, 5.988973511903538, 6.670931777046547, 8.630021310706685, 9.664693844530293, 10.608813510613217, 11.642979691925856, 12.50686636709087, 13.480494236726994, 14.548954268442712, 15.535792874002883, 16.32562741684483, 15.426717045899622, 14.498114661059049, 13.628827520879568, 12.682611750714017, 11.766627655989296, 10.70091609354749, 9.905328761730381, 8.947388002884692, 8.020201359473901, 7.0552565116199135, 7.687636509718906, 9.573529135905323, 10.501482247850966, 11.51937512232591, 12.557994879844106, 13.546436030338956, 14.436527912274938, 15.36919104680601, 16.314636834577914, 17.276391422474834, 16.4293335972251, 15.449464219356576, 14.683796559628853, 13.702131140107266, 12.696521384734, 11.661577525354227, 10.881677041632537, 9.886186762623089, 8.964862747153072, 7.990609434728045, 8.617923757512408, 10.567186116473673, 10.904763038626529, 11.869437091671976, 12.786090935997864, 13.661618426918212, 14.410829885591493, 15.322976850320622, 16.22030996791879, 17.189326683962076, 17.431681485027557, 16.49893167042267, 15.611333821773577, 14.748372411817783, 13.762234730355223, 12.692723012379476, 11.860916099041122, 10.908316824457817, 9.970465482383174, 8.976941844849723, 9.620803076505936, 10.852640665160413, 9.964495469052679, 10.82876162258093, 11.796881122339782, 12.708798864827859, 13.464788013448675, 14.358053313001644, 15.266563805392053, 16.305582073787846, 17.27224668447127, 17.558383592138746, 16.591908281150918, 15.667384368076423, 14.652599447370191, 13.628665893273041, 12.868554571248636, 11.962572773915268, 10.996166240001239, 9.955621621258505, 10.67637925047369, 9.879758714259175, 8.953744109369946, 9.825807299110858, 10.812611354767679, 11.737972850752712, 12.412036394019852, 13.31851792409837, 14.286163283237611, 15.241453174336224, 16.21013099712965, 17.168775996200807, 17.61026988012257, 16.587542341941532, 15.519631437770434, 14.592831990118178, 13.794462524361025, 12.972972232060362, 11.958431505613706, 11.022789960083792, 10.826777927131877, 8.820514081915992, 7.919521588127273, 8.83115613267851, 9.881741039554854, 10.79764923283715, 11.480010024300265, 12.344454004031462, 13.326000738629194, 14.3294887084467, 15.33457395411963, 16.349913332384023, 17.398314240101335, 16.50457618912308, 15.569092598250478, 14.628231705591737, 13.635658558250332, 12.677134333288189, 11.71817770105467, 10.684766886272545, 9.866357778491848, 7.820179411862899, 6.874358582765453, 7.873259764801376, 8.909075136647727, 9.793901790901781, 10.405206386736504, 11.339743267850375, 12.362654122652517, 13.335097973536236, 14.33550021815648, 15.396348697097345, 16.35519347541566, 15.546035252249258, 14.625074467544108, 13.625040526939902, 12.662722195802488, 11.713876039634142, 10.699001935724214, 9.713686395854452, 8.841877633772768, 6.932628562869983, 5.943139248414671, 6.888112194568485, 7.835132719193955, 8.81254260705262, 9.431992047127222, 10.376280245457592, 11.398097028234249, 12.40312876823298, 13.33355020045491, 14.380499797900576, 15.343232538269518, 14.614553489119706, 13.65389625457567, 12.682771881058606, 11.709856493139368, 10.758694132098919, 9.83502495020352, 8.786441088093586, 7.840487740237952, 5.919770658264642, 4.964156996498352, 5.867648203832592, 6.850266691320003, 7.748950025011742, 8.504859849950156, 9.472651753116466, 10.528230701889346, 11.529679904562943, 12.537244797490612, 13.608841056134555, 14.596420198439484, 13.651410075386902, 12.70897712388591, 11.70314767585109, 10.755899250636762, 9.736672266662733, 8.795819937219338, 7.851253020884979, 6.8852548165101, 4.908543760371426, 3.89685877463625, 4.857510739302166, 5.849560966888567, 6.787452700691121, 7.562543948687981, 8.53773193297035, 9.55763106911041, 10.49938647459591, 11.544791962771118, 12.616359112636392, 13.641105065246936, 12.723435256440451, 11.794016419968706, 10.760852481997956, 9.836278999041744, 8.901342055147579, 7.844392280767382, 6.92518017520852, 5.958416375788257], [4.103606189623742, 5.060289517315566, 5.897780649550912, 6.888655791023493, 7.85058215870981, 8.788989274357716, 9.816333087975693, 10.831217192703324, 11.770874329902425, 12.681286906632401, 11.634151473777333, 10.692723972539943, 9.626660458428436, 8.618268025492627, 7.630226167287342, 6.7862209487232805, 5.82883546974969, 4.968831146791077, 3.967905019182221, 3.1573337260754455, 3.084700411977165, 4.004985171325543, 4.907267771246908, 5.855804992450599, 6.820552729530651, 7.809787356040461, 8.873216060538724, 9.86521187433237, 10.916974500125779, 11.644479309444574, 10.691083621014695, 9.731041547309545, 8.672231607582525, 7.655804435165254, 6.703098171716687, 5.798665085880225, 4.903387792260386, 3.9750659475962076, 2.919815023349692, 2.0985721181882004, 2.0409777589434386, 2.9711337180876534, 3.927893309916244, 4.894059030079897, 5.892899462887227, 6.905713107230642, 7.931281673807946, 8.95317018323489, 9.917269730649329, 10.728355687935995, 9.708142418183725, 8.777349429394555, 7.7250791998233135, 6.729104365385619, 5.754805592123857, 4.816172556597733, 3.8663138233929875, 3.009619841754949, 1.994416872266525, 1.060539607932934, 1.0226297139461533, 1.9600437789664504, 2.98290112486823, 3.91151014437288, 4.9507696559222545, 5.976211614844962, 6.924692392297533, 7.915800926699755, 8.901351276858035, 9.8780766676925, 8.93490622589179, 7.86673089586729, 6.902827614771164, 5.940279174415414, 4.909828868299337, 3.86579853933046, 2.9372799128903284, 2.0021618370836194, 1.00858268392208, 0.0, 1.948205365369767, 2.8971669852332917, 3.9254720412629336, 4.954527870403057, 5.933031577682595, 6.998839747597798, 7.978662463357287, 8.919365862639161, 9.893477386982408, 10.82285988999939, 9.873219920611223, 8.80610059627984, 7.891163410928837, 6.90899347229972, 5.88865811452892, 4.863427871996826, 3.901718449789089, 2.972855100011887, 1.9544454657849997, 0.970218815946032, 2.9563074587657896, 3.9381340994777125, 4.8714721422428475, 5.796859059886687, 6.835688520920543, 7.86326830809583, 8.800443761886894, 9.768973523083716, 10.77895307588384, 11.607388446174577, 10.661241554519103, 9.708840153261459, 8.718321181723297, 7.7893622333881725, 6.811551863463042, 5.832314340765237, 4.921958822681233, 3.955124063982305, 2.9021274932425616, 2.0308903159995984, 3.9003382015608383, 4.914510250516658, 5.875692727108776, 6.824276720902183, 7.806460258571434, 8.833581750174949, 9.775203311370305, 10.8076142858845, 11.7994583518255, 12.549142354096539, 11.661833383279022, 10.732725760207973, 9.784024952677855, 8.79380574059734, 7.7640317868920805, 6.899528147484004, 5.884212467316291, 4.901267860885905, 3.892875567329513, 2.9603206457624394, 4.91156957484543, 5.89679292443706, 6.858003804260212, 7.855353666483666, 8.826910141466273, 9.859732577111945, 10.751494758261185, 11.788996269817664, 12.76237811671082, 13.490616390707196, 12.623139088253142, 11.664655166173588, 10.817185923390698, 9.797491447711836, 8.773997087564654, 7.802999922656513, 6.873413322555874, 5.934457998203851, 4.88340378304667, 3.8974068756369844, 5.880988715482304, 6.917389718884958, 7.895153484504027, 8.823191075682052, 9.757670769965305, 10.76221530246012, 11.69849639969076, 12.725754589075475, 13.69032522509498, 14.528830890757277, 13.635182279964914, 12.607227502146419, 11.668580666613687, 10.729182061555955, 9.69987089264898, 8.831421344641754, 7.931562997113524, 6.938636233508872, 5.871818616691659, 4.864845479122066, 6.819068418242529, 7.824207493504721, 8.794911126865147, 9.776036203364342, 10.721403221652617, 11.70585376675412, 12.678997697978225, 13.621132491582642, 14.664610379589856, 15.45085233142552, 14.473644792516714, 13.548471333779672, 12.609511098700803, 11.662902558370272, 10.694602796774301, 9.793539049106162, 8.934258342173626, 7.884994919158265, 6.860301752315531, 5.845534004305095, 7.804623537965233, 8.833406711070444, 9.776876972161766, 10.803781058085615, 11.655145868945029, 12.628773738581152, 13.69723377029687, 14.672941544024493, 15.593574176866955, 16.41156069317689, 15.449034593575998, 14.579747453396518, 13.633531683230967, 12.717547588506246, 11.651836026064439, 10.801171215244256, 9.816857814521734, 8.805235738394682, 7.840290890540695, 6.862238736977454, 8.748131363163871, 9.676084475109514, 10.693977349584458, 11.732597107102656, 12.694715532193115, 13.584807414129097, 14.51747054866017, 15.462916336432075, 16.4940171057706, 17.380253529742046, 16.400384151873524, 15.634716492145802, 14.653051072624216, 13.64744131725095, 12.612497457871177, 11.71806541260862, 10.676710954587197, 9.749897126073854, 8.775643813648827, 7.792525984770956, 9.741788343732221, 10.645648058031867, 11.6990330525086, 12.765904000580832, 13.712137160034027, 14.643821333704462, 15.464732515482588, 16.49188295827045, 17.460899674313733, 18.382601417544503, 17.44985160293962, 16.562253754290527, 15.699292344334733, 14.713154662872173, 13.643642944896426, 12.65144029100523, 11.698841016421925, 10.755499861303957, 9.761976223770505, 8.795405303764486, 10.181760978844517, 10.97307815297476, 11.837344306503011, 12.805463806261864, 13.717381548749938, 14.473370697370756, 15.366635996923723, 16.275146489314135, 17.31416475770993, 18.28082936839335, 18.509303524655696, 17.542828213667867, 16.618304300593373, 15.60351937988714, 14.57958582578999, 13.659078763212744, 12.753096965879376, 11.781200618922021, 10.740656000179287, 9.85098147773224, 9.20887902794328, 9.962326793292027, 10.83438998303294, 11.82119403868976, 12.74655553467479, 13.420619077941932, 14.327100608020448, 15.294745967159692, 16.250035858258304, 17.218713681051728, 18.177358680122886, 17.511467286499553, 16.488739748318515, 15.60377073311085, 14.676971285458594, 13.760295449516104, 12.7696816919259, 11.755140965479244, 10.81123518619012, 10.04336624634794, 8.149634395600096, 8.928104272049353, 9.839738816600592, 10.890323723476934, 11.806231916759232, 12.488592708222345, 13.35303668795354, 14.334583422551274, 15.33807139236878, 16.34315663804171, 17.358496016306102, 16.58226214144718, 15.551441895787987, 14.652930331688571, 13.725532391518568, 12.732959244177163, 11.784502959341642, 10.825546327108123, 9.792135512325999, 9.035448954897983, 7.149299725547003, 7.882941266687533, 8.881842448723457, 9.917657820569808, 10.802484474823864, 11.413789070658584, 12.348325951772456, 13.371236806574597, 14.343680657458316, 15.34408290207856, 16.404931381019423, 15.553425432256098, 14.592900958914164, 13.708912200982201, 12.722341212866732, 11.760022881729318, 10.821244665687596, 9.806370561777667, 8.821055021907906, 7.986637270169944, 6.183193077277724, 6.951721932336751, 7.896694878490566, 8.843715403116034, 9.821125290974702, 10.440574731049303, 11.384862929379672, 12.406679712156329, 13.41171145215506, 14.34213288437699, 15.389082481822657, 14.602423563902146, 13.661419195784612, 12.700761961240577, 11.729637587723513, 10.807157179066198, 9.866062758152372, 8.942393576256974, 7.893809714147039, 6.947856366291406, 5.170335172672383, 5.972739680420433, 6.876230887754672, 7.858849375242084, 8.757532708933823, 9.513442533872237, 10.481234437038548, 11.536813385811428, 12.538262588485026, 13.545827481412694, 14.617423740056637, 13.64328590510439, 12.698275782051809, 11.755842830550817, 10.750013382515997, 9.851687062560263, 8.844040892716187, 7.903188563272791, 6.9586216469384325, 5.992623442563554, 4.159108274779167, 4.905441458558331, 5.866093423224246, 6.858143650810647, 7.796035384613202, 8.571126632610062, 9.546314616892433, 10.566213753032493, 11.507969158517993, 12.5533746466932, 13.624941796558474, 12.744593985895161, 11.770300963105358, 10.840882126633613, 9.807718188662863, 8.883144705706652, 7.948207761812486, 6.891257987432289, 6.030256873680868, 5.065785001841711], [4.006552127101202, 4.963235454793027, 5.800726587028372, 6.791601728500953, 7.753528096187272, 8.691935211835178, 9.719279025453154, 10.734163130180786, 11.673820267379886, 12.69824654512549, 13.5823568391471, 12.640929337909707, 11.5748658237982, 10.566473390862392, 9.578431532657106, 8.733006456133065, 7.775620977159473, 6.915616654200861, 5.914690526592005, 5.016729759061242, 2.9876463494546255, 3.9079311088030035, 4.810213708724368, 5.758750929928059, 6.723498667008113, 7.712733293517923, 8.776161998016185, 9.768157811809832, 10.81992043760324, 11.85006756683337, 12.63928898638446, 11.67924691267931, 10.62043697295229, 9.60400980053502, 8.651303537086452, 7.7468704512499915, 6.850173299670169, 5.921851455005991, 4.8666005307594755, 4.027405560259742, 1.943923696420899, 2.874079655565114, 3.8308392473937043, 4.797004967557358, 5.795845400364689, 6.8086590447081035, 7.834227611285406, 8.85611612071235, 9.820215668126789, 10.827470388657783, 11.65634778355349, 10.72555479476432, 9.673284565193079, 8.677309730755384, 7.703010957493623, 6.764377921967499, 5.814519188762754, 4.956405349164733, 3.9412023796763087, 2.989373050004475, 0.9255756514236138, 1.8629897164439109, 2.8858470623456904, 3.8144560818503406, 4.853715593399715, 5.879157552322422, 6.827638329774993, 7.818746864177215, 8.804297214335495, 9.781022605169959, 10.781473650866864, 9.814936261237058, 8.851032980140932, 7.888484539785182, 6.858034233669105, 5.814003904700227, 4.885485278260095, 3.9503672024533865, 2.956788049291847, 1.948205365369767, 0.0, 0.9489616198635245, 1.9772666758931665, 3.0063225050332902, 4.015824951289387, 5.08163312120459, 6.1269306182287036, 7.067634017510578, 8.138641214888999, 9.082885688002968, 10.032525657391135, 9.148132067406465, 8.113513931390115, 7.077185549687014, 6.056850191916213, 5.028846168513022, 4.067136746305286, 3.138273396528084, 2.119863762301197, 1.0537428195919747, 1.0081020933960227, 1.9899287341079452, 2.92326677687308, 3.84865369451692, 4.887483155550776, 5.915062942726063, 6.8522383965171265, 7.820768157713947, 8.83074771051407, 9.758281522143784, 10.704428413799258, 9.834405022895064, 8.843886051356902, 7.914927103021777, 6.937116733096647, 5.957879210398842, 5.03054620951385, 3.97418500281701, 2.9211884320772668, 1.9584451526566988, 1.9521328361910713, 2.9663048851468905, 3.9274873617390087, 4.8760713555324156, 5.858254893201668, 6.885376384805181, 7.826997946000539, 8.859408920514731, 9.85125298645573, 10.700035430065746, 11.725892499766733, 10.858290629841578, 9.90958982231146, 8.87783618074448, 7.84806222703922, 6.893883079782504, 5.869893310653477, 4.828822697543005, 3.8204304039866135, 2.88787548241954, 2.963364209475663, 3.948587559067292, 4.909798438890445, 5.9071483011138985, 6.878704776096505, 7.911527211742177, 8.803289392891418, 9.840790904447896, 10.81417275134105, 11.641509466676403, 12.598110520035918, 11.760571129009325, 10.806666522856741, 9.751797645985594, 8.701551924221754, 7.730554759313613, 6.8009681592129745, 5.862012834860952, 4.81095861970377, 3.824961712294085, 3.932783350112537, 4.96918435351519, 5.946948119134261, 6.874985710312286, 7.809465404595537, 8.814009937090352, 9.750291034320991, 10.777549223705707, 11.742119859725213, 12.679723966726485, 13.59512147998893, 12.534782338803517, 11.596135503270787, 10.656736898213055, 9.62742572930608, 8.758976181298854, 7.8591178337706245, 6.866191070165972, 5.7993734533487595, 4.792400315779167, 4.870863052872762, 5.876002128134953, 6.846705761495378, 7.827830837994572, 8.773197856282849, 9.757648401384351, 10.730792332608457, 11.672927126212874, 12.716405014220088, 13.62548444403954, 14.401199629173814, 13.476026170436771, 12.537065935357903, 11.590457395027371, 10.622157633431401, 9.721093885763262, 8.861813178830726, 7.812549755815365, 6.787856588972632, 5.773088840962195, 5.917085029663668, 6.8852013457006755, 7.828671606791997, 8.855575692715846, 9.706940503575261, 10.680568373211385, 11.749028404927103, 12.724736178654725, 13.645368811497187, 14.586192805790912, 15.376589430233098, 14.507302290053616, 13.561086519888065, 12.645102425163344, 11.579390862721539, 10.728726051901358, 9.744412651178836, 8.732790575051784, 7.767845727197796, 6.7897935736345545, 6.873142866310274, 7.801095978255916, 8.809015477636263, 9.833209667154398, 10.746510166823349, 11.636602048759329, 12.569265183290401, 13.514710971062307, 14.545811740400833, 15.470933070652839, 16.327938988530626, 15.5622713288029, 14.580605909281314, 13.57499615390805, 12.540052294528277, 11.64562024926572, 10.604265791244297, 9.677451962730954, 8.703198650305927, 7.7200808214280565, 7.8667998468786235, 8.770659561178269, 9.824044555655002, 10.866516560632574, 11.763931794664261, 12.695615968334694, 13.51652715011282, 14.54367759290068, 15.512694308943965, 16.473280958455298, 17.377406439596722, 16.489808590947625, 15.626847180991831, 14.640709499529272, 13.571197781553526, 12.57899512766233, 11.626395853079025, 10.683054697961056, 9.689531060427605, 8.722960140421586, 8.866142309993581, 9.710927130752118, 10.731509474042292, 11.699628973801145, 12.716751356754614, 13.641657840477512, 14.481450687431797, 15.419125083530128, 16.47129951276154, 17.404405417079346, 18.43185954324622, 17.470383050324966, 16.545859137250474, 15.53107421654424, 14.50714066244709, 13.586633599869844, 12.680651802536476, 11.708755455579121, 10.668210836836387, 9.778536314389342, 9.839024260894819, 10.72167849043485, 11.734463797512364, 12.69592580403211, 13.62128730001714, 14.617333557940906, 15.520986076335072, 16.39952560568457, 17.354815496783182, 18.323493319576606, 18.435484675615776, 17.414413223977014, 16.391685685795977, 15.506716670588311, 14.579917222936055, 13.663241386993565, 12.67262762940336, 11.658086902956704, 10.71418112366758, 9.9463121838254, 9.767240930645913, 10.757890095052087, 11.718249574921407, 12.781259457341196, 13.753017424169018, 14.43679807359211, 15.301242053323307, 16.28278878792104, 17.286276757738545, 18.291362003411475, 17.43206881906509, 16.485208078924643, 15.454387833265448, 14.555876269166033, 13.62847832899603, 12.635905181654625, 11.687448896819102, 10.728492264585583, 9.695081449803459, 8.938394892375443, 8.76690626059282, 9.712727089690267, 10.760353207044272, 11.819181273879678, 12.749269982233649, 13.361994436028349, 14.29653131714222, 15.319442171944361, 16.29188602282808, 17.292288267448324, 16.478504183778412, 15.45637136973356, 14.495846896391626, 13.611858138459663, 12.625287150344194, 11.66296881920678, 10.724190603165054, 9.709316499255127, 8.724000959385366, 7.889583207647404, 7.800799612323541, 8.861452862550802, 9.843480385900348, 10.790500910525816, 11.767910798384488, 12.388780096419067, 13.333068294749436, 14.354885077526093, 15.359916817524825, 16.290338249746757, 15.46810224174855, 14.505369501379608, 13.564365133262074, 12.603707898718039, 11.632583525200975, 10.71010311654366, 9.76900869562983, 8.845339513734434, 7.796755651624499, 6.850802303768866, 6.890369597624215, 7.919525187830216, 8.823016395164455, 9.805634882651866, 10.704318216343609, 11.461647899242001, 12.429439802408313, 13.485018751181192, 14.48646795385479, 15.494032846782456, 14.539628065757997, 13.546231842581852, 12.60122171952927, 11.658788768028279, 10.652959319993458, 9.754633000037725, 8.746986830193645, 7.806134500750251, 6.8615675844158925, 5.895569380041014, 6.018504307764964, 6.852226965968114, 7.81287893063403, 8.804929158220432, 9.742820892022987, 10.519331997979826, 11.494519982262197, 12.514419118402257, 13.456174523887757, 14.501580012062965, 13.672285875983167, 12.647539923372623, 11.67324690058282, 10.743828064111074, 9.710664126140324, 8.786090643184114, 7.851153699289946, 6.794203924909749, 5.933202811158329, 4.968730939319171], [4.9538874316020465, 4.039259660326766, 4.876750792562111, 5.867625934034693, 6.8295523017210105, 7.767959417368917, 8.795303230986894, 9.810187335714524, 10.749844472913624, 11.774270750659229, 12.82255531355963, 13.589890957773232, 12.523827443661725, 11.515435010725916, 10.52739315252063, 9.68034176063391, 8.722956281660318, 7.862951958701705, 6.86202583109285, 5.964065063562087, 3.9349816539554707, 2.9839553143367423, 3.886237914258108, 4.834775135461799, 5.799522872541852, 6.788757499051662, 7.852186203549924, 8.84418201734357, 9.895944643136978, 10.926091772367112, 11.879487460796991, 12.628208532542835, 11.569398592815814, 10.552971420398544, 9.600265156949977, 8.695832071113516, 7.797508604171014, 6.869186759506836, 5.81393583526032, 4.974740864760586, 2.8912590009217443, 1.9501038610988528, 2.9068634529274435, 3.8730291730910973, 4.871869605898428, 5.884683250241842, 6.910251816819145, 7.932140326246089, 8.896239873660528, 9.903494594191523, 10.91655666915398, 11.674516414627846, 10.622246185056603, 9.626271350618909, 8.651972577357148, 7.713339541831024, 6.763480808626278, 5.903740653665578, 4.8885376841771535, 3.9367083545053196, 1.8745372712871382, 0.9390139219776499, 1.9618712678794294, 2.8904802873840794, 3.929739798933454, 4.955181757856161, 5.903662535308733, 6.894771069710955, 7.880321419869235, 8.8570468107037, 9.857497856400606, 10.763897881100583, 9.799994600004457, 8.837446159648707, 7.80699585353263, 6.762965524563752, 5.83444689812362, 4.899328822316911, 3.9057496691553717, 2.8971669852332917, 0.9489616198635245, 0.0, 1.028305056029642, 2.057360885169766, 3.0668633314258624, 4.132671501341066, 5.177968998365179, 6.118672397647053, 7.189679595025473, 8.133924068139441, 9.083564037527609, 10.097093687269986, 9.062475551253637, 8.026147169550537, 7.005811811779737, 5.977807788376546, 5.016098366168809, 4.087235016391608, 3.068825382164721, 2.002704439455499, 1.9570637132595472, 1.0409671142444208, 1.9743051570095558, 2.8996920746533954, 3.9385215356872516, 4.966101322862539, 5.903276776653602, 6.871806537850422, 7.881786090650545, 8.80931990228026, 9.755466793935733, 10.707868195193377, 9.792847671220427, 8.863888722885303, 7.886078352960172, 6.906840830262366, 5.979507829377375, 4.923146622680535, 3.8701500519407914, 2.9074067725202233, 2.901094456054596, 2.0398024503303938, 3.000984926922512, 3.927109735668891, 4.909293273338143, 5.936414764941657, 6.878036326137014, 7.910447300651206, 8.902291366592205, 9.751073810202222, 10.776930879903208, 11.706038502974257, 10.858551442174985, 9.826797800608004, 8.797023846902745, 7.842844699646029, 6.818854930517002, 5.77778431740653, 4.769392023850139, 3.8368371022830647, 3.9123258293391876, 3.022085124250795, 3.9832960040739485, 4.958186681250374, 5.9297431562329805, 6.962565591878652, 7.854327773027893, 8.89182928458437, 9.865211131477526, 10.692547846812879, 11.649148900172394, 12.637967908939872, 11.755628142720266, 10.700759265849118, 9.650513544085278, 8.679516379177137, 7.749929779076499, 6.810974454724477, 5.759920239567295, 4.77392333215761, 4.8817449699760616, 4.042681918698693, 5.020445684317764, 5.948483275495789, 6.860503784732012, 7.865048317226829, 8.801329414457468, 9.828587603842184, 10.79315823986169, 11.73076234686296, 12.661192091884166, 13.483743958667041, 12.545097123134312, 11.60569851807658, 10.576387349169604, 9.707937801162378, 8.80807945363415, 7.815152690029497, 6.748335073212284, 5.741361935642692, 5.819824672736287, 5.0294444849630935, 6.000148118323518, 6.944078377568815, 7.824236236419323, 8.808686781520828, 9.781830712744934, 10.723965506349352, 11.767443394356565, 12.676522824176015, 13.629783088696797, 14.424987790300296, 13.486027555221428, 12.539419014890896, 11.571119253294926, 10.670055505626786, 9.810774798694252, 8.76151137567889, 7.736818208836157, 6.72205046082572, 6.866046649527193, 6.038643702528816, 6.9821139636201375, 7.971823232290088, 8.757978883711736, 9.73160675334786, 10.800066785063578, 11.775774558791202, 12.696407191633664, 13.637231185927387, 14.605172889756082, 15.45626390991714, 14.51004813975159, 13.594064045026869, 12.528352482585063, 11.677687671764883, 10.69337427104236, 9.681752194915308, 8.716807347061321, 7.738755193498079, 7.8221044861737985, 6.985065262170125, 7.962457834464404, 8.94945720672864, 9.797548546959824, 10.687640428895804, 11.620303563426877, 12.565749351198782, 13.596850120537308, 14.521971450789314, 15.501840828657837, 16.506590138903256, 15.529567529144838, 14.523957773771574, 13.489013914391801, 12.594581869129247, 11.553227411107823, 10.62641358259448, 9.652160270169453, 8.66904244129158, 8.815761466742147, 7.954628845092478, 9.008013839569212, 9.982764100206817, 10.814970174800736, 11.74665434847117, 12.567565530249295, 13.594715973037156, 14.56373268908044, 15.524319338591772, 16.492345976820058, 17.417872306959687, 16.575808800855356, 15.589671119392797, 14.52015940141705, 13.527956747525856, 12.575357472942551, 11.632016317824583, 10.638492680291131, 9.671921760285109, 9.815103929857104, 8.894896414666327, 9.915478757956501, 10.883598257715354, 11.767789736891089, 12.692696220613987, 13.532489067568273, 14.470163463666603, 15.522337892898015, 16.455443797215818, 17.48289792338269, 17.51840604859745, 16.491803294604274, 15.606761359721183, 14.62010752531493, 13.665173545639693, 12.817555897858153, 11.918519814696154, 11.079517108619847, 10.727497934252863, 10.787985880758342, 9.90564777434906, 10.918433081426572, 11.879895087946318, 12.738615750966236, 13.734662008890002, 14.572024456471548, 15.450563985821045, 16.405853876919657, 17.37453169971308, 17.511508881149517, 16.490437429510752, 15.467709891329715, 14.582740876122049, 13.655941428469793, 12.739265592527303, 11.800792661388789, 10.956254549083686, 10.012348769794562, 10.893647488326243, 10.714576235146758, 10.939870295591733, 11.91308424785892, 12.810765403159143, 13.764544125499533, 14.666688378609589, 15.546088376538457, 16.410726530429464, 17.465898692327627, 17.548668502154847, 16.508093024598832, 15.561232284458384, 14.530412038799188, 13.631900474699773, 12.704502534529768, 11.711929387188363, 10.799570036883983, 9.996404970909783, 8.993249095930441, 9.885730196876287, 9.714241565093666, 10.660062394191112, 11.707688511545115, 12.766516578380521, 13.696605286734492, 14.310956055891873, 15.245492937005745, 16.268403791807884, 17.240847642691605, 16.622656612525127, 15.554528389312154, 14.5323955752673, 13.571871101925366, 12.687882343993403, 11.701311355877932, 10.738993024740518, 9.800271116469352, 8.977229205579327, 8.022168605512348, 8.836918512148248, 8.748134916824386, 9.808788167051647, 10.790815690401194, 11.737836215026663, 12.715246102885331, 13.337741716282592, 14.282029914612961, 15.303846697389618, 16.30887843738835, 15.591076044727957, 14.544126447282292, 13.58139370691335, 12.640389338795814, 11.679732104251778, 10.708607730734714, 9.786127322077398, 8.845089208934128, 7.9520946662524175, 7.094923297751482, 7.798137608269711, 7.8377049021250595, 8.86686049233106, 9.770351699665301, 10.752970187152712, 11.651653520844452, 12.410609519105526, 13.378401422271837, 14.433980371044717, 15.435429573718315, 14.68724852993568, 13.615652271291736, 12.622256048115592, 11.67724592506301, 10.734812973562018, 9.728983525527198, 8.830657205571462, 7.823067343497943, 6.882215014054548, 6.0756516142094075, 6.842904684541859, 6.965839612265809, 7.799562270468959, 8.760214235134875, 9.752264462721277, 10.69015619652383, 11.46829361784335, 12.443481602125722, 13.463380738265782, 14.405136143751282, 13.819877231382181, 12.748310081516907, 11.723564128906363, 10.74927110611656, 9.819852269644814, 8.786688331674064, 7.862114848717852, 6.927177904823686, 5.870228130443489, 5.009227016692067, 5.916066243820016], [5.948025169199824, 4.989049913926894, 4.009712900489681, 5.000588041962263, 5.962514409648581, 6.9009215252964875, 7.928265338914465, 8.943149443642096, 9.882806580841196, 10.9072328585868, 11.913635711782735, 12.904053066133992, 13.552132499691368, 12.543740066755559, 11.555698208550274, 10.708646816663551, 9.751261337689959, 8.891257014731348, 7.8903308871224915, 6.958202801159865, 4.963286709985113, 4.012260370366384, 3.019200022185678, 3.9677372433893687, 4.932484980469423, 5.921719606979233, 6.985148311477495, 7.977144125271141, 9.00375746358974, 10.017172170590218, 10.970567859020097, 11.930609932725247, 12.597703648845457, 11.581276476428187, 10.62857021297962, 9.724137127143159, 8.825813660200655, 7.897491815536478, 6.842240891289962, 6.003045920790228, 3.919564056951386, 2.978408917128495, 2.039825560855014, 3.0059912810186677, 4.004831713825999, 5.017645358169413, 6.001332215042251, 7.023220724469195, 7.987320271883634, 8.994574992414629, 10.007637067377086, 10.938430056166256, 11.650551241086246, 10.654576406648552, 9.68027763338679, 8.741644597860667, 7.791785864655921, 6.9320457096952195, 5.916842740206795, 4.9650134105349615, 2.9028423273167805, 1.967318978007292, 1.0559816395449344, 1.9845906590495845, 3.0208201971565605, 4.046262156079267, 4.994742933531839, 5.985851467934061, 6.971401818092341, 7.948127208926805, 8.948578254623712, 10.016753584648212, 10.8282996560341, 9.86575121567835, 8.835300909562273, 7.791270580593395, 6.8627519541532624, 5.927633878346553, 4.934054725185014, 3.9254720412629336, 1.9772666758931665, 1.028305056029642, 0.0, 1.0290558291401237, 2.0385582753962206, 3.104366445311424, 4.149663942335537, 5.090367341617411, 6.161374538995831, 7.105619012109799, 8.055258981497966, 9.122378305829347, 10.09078060728328, 9.05445222558018, 8.034116867809379, 7.0061128444061875, 6.044403422198451, 5.11554007242125, 4.0971304381943625, 3.031009495485141, 2.9569776878940957, 1.895237997414939, 0.9460001009799136, 1.8713870186237536, 2.9102164796576098, 3.9377962668328967, 4.874971720623961, 5.843501481820781, 6.853481034620904, 7.781014846250619, 8.727161737906092, 9.679563139163736, 10.670082110701898, 9.863802697519848, 8.885992327594717, 7.906754804896913, 6.979421804011922, 5.923060597315082, 4.870064026575339, 3.9073207471547717, 3.9010084306891444, 2.894073333500912, 2.0198201818925154, 2.898804679639249, 3.880988217308501, 4.908109708912015, 5.849731270107371, 6.882142244621565, 7.8739863105625645, 8.72276875417258, 9.748625823873567, 10.677733446944616, 11.659901288116181, 10.826711775242554, 9.796937821537295, 8.842758674280578, 7.8187689051515505, 6.777698292041078, 5.769305998484687, 4.836751076917613, 4.876815006837849, 3.8763560074213133, 3.002131259043952, 3.929881625220732, 4.901438100203339, 5.934260535849011, 6.82602271699825, 7.863524228554729, 8.836906075447885, 9.664242790783238, 10.620843844142753, 11.609662852910231, 12.563567459062813, 11.700673240483667, 10.650427518719827, 9.679430353811686, 8.749843753711048, 7.810888429359025, 6.7598342142018435, 5.773837306792158, 5.846234147474723, 4.896952801869212, 4.039280939287767, 4.967318530465793, 5.83219872870237, 6.836743261197187, 7.7730243584278265, 8.800282547812543, 9.764853183832049, 10.702457290833319, 11.632887035854525, 12.632025685528227, 13.527453720298556, 12.605612492711128, 11.576301323804152, 10.707851775796927, 9.807993428268698, 8.815066664664046, 7.748249047846833, 6.74127591027724, 6.784313850234948, 5.883715368133611, 5.072255905273062, 5.962913632538818, 6.795931180389681, 7.780381725491186, 8.753525656715292, 9.695660450319709, 10.739138338326923, 11.648217768146374, 12.601478032667156, 13.526651491404198, 14.465611726483067, 13.539332989525445, 12.571033227929474, 11.669969480261335, 10.8106887733288, 9.761425350313438, 8.736732183470705, 7.721964435460269, 7.830535827025854, 6.892914585699334, 6.054221750569681, 6.990658487260092, 7.7296738276820935, 8.703301697318217, 9.771761729033935, 10.74746950276156, 11.668102135604022, 12.608926129897746, 13.57686783372644, 14.555694005146409, 15.489632311013228, 14.593978019661417, 13.528266457219612, 12.677601646399431, 11.693288245676909, 10.681666169549857, 9.71672132169587, 8.738669168132628, 8.767289257286286, 7.839336145340643, 7.034565621413948, 7.968292461698645, 8.76924349093018, 9.659335372866162, 10.591998507397234, 11.53744429516914, 12.568545064507665, 13.493666394759671, 14.473535772628194, 15.478285082873615, 16.529481503779387, 15.523871748406123, 14.48892788902635, 13.594495843763795, 12.553141385742371, 11.626327557229029, 10.652074244804002, 9.668956415926129, 9.760946237854636, 8.808899728262995, 8.093291304984549, 9.00159935517682, 9.786665118771092, 10.718349292441527, 11.539260474219653, 12.566410917007513, 13.535427633050798, 14.496014282562129, 15.464040920790413, 16.389567250930043, 16.56095112848747, 15.75944352789432, 14.689012514136065, 13.805774125774779, 13.004773955243175, 12.189896174489679, 11.63840665492568, 10.671835734919657, 10.760288700969593, 9.749167297836845, 9.133966774075596, 9.990809168834902, 10.739484680861445, 11.664391164584345, 12.50418401153863, 13.44185840763696, 14.494032836868373, 15.427138741186177, 16.45459286735305, 16.651368156525017, 15.624765402531848, 14.739723467648755, 13.7530696332425, 12.798135653567265, 11.950518005785725, 11.138999372237476, 11.963609532726917, 11.727411908887412, 11.701444038365137, 10.759918657519577, 10.136921097545667, 10.987105999065866, 11.710310694936592, 12.706356952860357, 13.543719400441905, 14.422258929791402, 15.377548820890015, 16.34622664368344, 16.64447098907709, 15.623399537438324, 14.600671999257287, 13.715702984049619, 12.788903536397363, 11.872227700454875, 10.93375476931636, 10.176734106625009, 10.89644119390163, 11.871707809648646, 11.708713972744535, 11.794141178762251, 11.131572263978015, 11.917976314278691, 12.736239069469889, 13.638383322579944, 14.517783320508812, 15.38242147439982, 16.437593636297983, 16.681630610082415, 15.641055132526402, 14.694194392385954, 13.663374146726758, 12.764862582627343, 11.837464642457338, 10.844891495115933, 9.932532144811555, 9.129367078837353, 9.87734152003751, 10.86379051819869, 10.708379302691442, 11.654200131788889, 12.08946863185515, 12.890642217185817, 13.739986511405258, 14.713186960143705, 15.522494056689897, 16.3457680903765, 16.71650578399479, 15.755618720452695, 14.687490497239724, 13.66535768319487, 12.704833209852936, 11.820844451920973, 10.834273463805502, 9.871955132668088, 8.933233224396924, 8.110191313506897, 8.906261029619417, 9.831056249746025, 9.742272654422163, 10.802925904649424, 11.819120746430835, 12.766141271056304, 13.743551158914972, 14.366046772312234, 15.310334970642604, 16.33215175341926, 15.654459584877456, 14.724038152655526, 13.67708855520986, 12.714355814840918, 11.773351446723384, 10.812694212179348, 9.841569838662284, 8.919089430004968, 7.978051316861699, 7.0850567741799875, 7.97901572185855, 8.792275345867488, 8.831842639722836, 9.8899561104994, 10.798656755694942, 11.781275243182353, 12.679958576874093, 13.438914575135168, 14.40670647830148, 15.46228542707436, 14.827775530790916, 13.82021063786325, 12.748614379219307, 11.755218156043162, 10.81020803299058, 9.867775081489588, 8.861945633454768, 7.9636193134990325, 6.956029451425513, 6.015177121982118, 6.959744038316477, 7.837042422139636, 7.959977349863586, 8.8278673264986, 9.788519291164516, 10.780569518750918, 11.718461252553471, 12.496598673872994, 13.471786658155365, 14.491685794295424, 13.943890273294224, 12.92282306196002, 11.881272189444477, 10.856526236833933, 9.88223321404413, 8.952814377572384, 7.919650439601634, 6.9950769566454225, 6.060140012751256, 5.003190238371059, 5.959017270292195, 6.910203981417793], [6.8851709848571145, 5.926195729584184, 4.946858716146972, 4.160661282127338, 5.011284330241903, 5.949691445889809, 6.925133188857837, 7.940017293585467, 8.879674430784569, 9.904100708530173, 10.884579882642612, 11.874997236993869, 12.941060751105375, 13.572795895895682, 12.584754037690397, 11.663968867875951, 10.70658338890236, 9.846579065943747, 8.84565293833489, 7.895348616817155, 5.918608761197512, 4.967582421578784, 3.956345837842968, 3.1188598811477912, 3.9812549010627443, 4.970489527572554, 5.975006485237648, 6.967002299031294, 7.974701634449616, 8.988116341450095, 9.941512029879974, 10.901554103585124, 11.926339552207756, 12.61033230556831, 11.657626042119743, 10.753192956283282, 9.781135711413055, 8.852813866748878, 7.797562942502362, 6.958367972002628, 4.8748861081637855, 3.9337309683408943, 2.976971376512304, 2.1290728028032992, 3.05360163441932, 4.00053547363052, 4.972276385902128, 5.994164895329072, 6.958264442743511, 7.9655191632745055, 8.978581238236963, 9.909374227026133, 10.911123926532223, 11.683632235788675, 10.709333462526914, 9.77070042700079, 8.820841693796044, 7.887367760907619, 6.872164791419195, 5.920335461747361, 3.9318981564569047, 2.996374807147416, 1.9931274552022242, 1.064518435697574, 1.9917643680164367, 3.0172063269391436, 3.9656871043917152, 4.956795638793937, 5.942345988952217, 6.919071379786682, 7.9195224254835885, 8.987697755508089, 9.951601036604215, 10.894807044818473, 9.864356738702396, 8.820326409733518, 7.891807783293386, 6.956689707486676, 5.963110554325137, 4.954527870403058, 3.0063225050332907, 2.057360885169766, 1.0290558291401237, 0.0, 1.0095024462560966, 2.0753106161712997, 3.120608113195413, 4.061311512477287, 5.132318709855707, 6.076563182969675, 7.0262031523578425, 8.093322476689224, 9.127940612705572, 10.083508054720305, 9.063172696949504, 8.035168673546313, 7.073459251338576, 6.144595901561375, 5.126186267334488, 4.060065324625265, 3.986033517034219, 2.924293826555062, 1.9750559301200372, 1.0550467379910695, 1.9520652828764737, 2.9796450700517605, 3.916820523842824, 4.885350285039645, 5.895329837839768, 6.8228636494694825, 7.769010541124956, 8.7214119423826, 9.711930913920762, 10.640889862255886, 9.915048156734843, 8.935810634037038, 8.008477633152047, 6.952116426455207, 5.899119855715464, 4.9363765762948955, 4.930064259829267, 3.923129162641035, 3.048876011032639, 2.082464399006565, 2.922837020527365, 3.949958512130879, 4.891580073326236, 5.9239910478404285, 6.915835113781428, 7.764617557391445, 8.790474627092431, 9.71958225016348, 10.701750091335045, 11.65455903073067, 10.825993650677418, 9.871814503420701, 8.847824734291674, 7.806754121181202, 6.79836182762481, 5.8658069060577365, 5.905870835977973, 4.905411836561437, 4.031187088184076, 3.1135413445880475, 3.9481928694067614, 4.976109339067875, 5.867871520217115, 6.905373031773593, 7.878754878666749, 8.706091594002103, 9.662692647361618, 10.651511656129095, 11.605416262281679, 12.658244737845166, 11.67948334785995, 10.708486182951809, 9.778899582851171, 8.839944258499148, 7.788890043341967, 6.8028931359322815, 6.875289976614847, 5.926008631009335, 5.068336768427891, 4.167182448711831, 4.878953497905793, 5.8834980304006095, 6.819779127631249, 7.847037317015966, 8.811607953035471, 9.744306094052185, 10.67473583907339, 11.67387448874709, 12.569302523517422, 13.508701128575154, 12.605357152944276, 11.73690760493705, 10.837049257408822, 9.84412249380417, 8.777304876986957, 7.770331739417363, 7.813369679375072, 6.9127711972737345, 6.101311734413185, 5.162777550784856, 5.842685949593104, 6.827136494694608, 7.800280425918715, 8.742415219523131, 9.785893107530345, 10.69006657136524, 11.643326835886022, 12.568500294623064, 13.507460529701932, 14.442421625389471, 13.600089057069598, 12.699025309401458, 11.839744602468924, 10.790481179453561, 9.765788012610829, 8.751020264600392, 8.859591656165978, 7.921970414839457, 7.083277579709804, 6.19052240550613, 6.776428596885516, 7.75005646652164, 8.818516498237358, 9.794224271964982, 10.714856904807444, 11.650774933116612, 12.618716636945306, 13.597542808365274, 14.531481114232093, 15.514078949456515, 14.557322286359735, 13.706657475539554, 12.722344074817032, 11.71072199868998, 10.745777150835993, 9.767724997272751, 9.796345086426408, 8.868391974480765, 8.063621450554072, 7.168156379944683, 7.815998260133603, 8.706090142069584, 9.638753276600657, 10.584199064372562, 11.615299833711088, 12.540421163963094, 13.520290541831617, 14.525039852077038, 15.596034427934365, 15.803871781134408, 14.768927921754635, 13.925624874912824, 13.365706814902037, 12.655383386369152, 11.681130073944125, 10.698012245066252, 10.790002066994758, 9.837955557403118, 9.122347134124672, 8.201463273422858, 8.833419887974514, 9.76510406164495, 10.586015243423075, 11.613165686210936, 12.58218240225422, 13.542769051765552, 14.510795689993838, 15.436322020133467, 15.607505836753113, 14.80821344848764, 13.737782434729386, 12.854544046368098, 12.343576753067309, 13.127041990146969, 12.667462484065803, 11.70089156405978, 11.789344530109714, 10.778223126976968, 10.158792586839793, 9.19067308708094, 9.786239450064867, 10.711145933787767, 11.550938780742053, 12.488613176840383, 13.540787606071795, 14.473893510389598, 15.501347636556469, 15.69792286479066, 14.67132011079749, 13.788493388242074, 12.801839553835821, 11.846905574160584, 11.289320803609858, 12.076145187894767, 12.900755348384205, 12.756467738027535, 12.73049986750526, 11.7889744866597, 11.161746910309864, 10.186969917311904, 10.757065464140014, 11.75311172206378, 12.590474169645328, 13.469013698994825, 14.424303590093437, 15.392981412886861, 15.646785796187368, 14.669954245703966, 13.647226707522929, 12.76447290464294, 11.837673456990684, 10.920997621048194, 10.272557567140494, 11.1138799222823, 11.83358700955892, 12.808853625305936, 12.645859788401827, 12.823197007902374, 12.156398076742212, 11.11784023252473, 11.782993838673312, 12.685138091783367, 13.564538089712237, 14.429176243603242, 15.484348405501406, 15.683945417192694, 14.643369939636681, 13.740749100651598, 12.709928854992402, 11.813632503220665, 10.886234563050659, 9.893661415709254, 9.271334942635688, 10.066512894494643, 10.8144873356948, 11.80093633385598, 11.645525118348734, 12.59134594744618, 13.114294444619347, 12.090506135431855, 12.78674128060868, 13.759941729347128, 14.569248825893322, 15.39252285957992, 15.713373633938165, 14.757933527562974, 13.689805304350003, 12.711912391460514, 11.75138791811858, 10.869614372514295, 9.883043384398823, 8.920725053261409, 8.272036022221057, 9.047337129164188, 9.843406845276707, 10.768202065403317, 10.679418470079455, 11.740071720306716, 12.76795568583909, 13.164448552885629, 13.768100464457842, 14.73315606895641, 15.643105377429102, 15.656359174819562, 14.65132743482083, 13.7209060025989, 12.673956405153234, 11.711223664784292, 10.819906154989027, 9.86146413277267, 8.890339759255607, 7.967859350598289, 7.3168541146858335, 8.022202589837278, 8.91616153751584, 9.72942116152478, 9.768988455380128, 10.827101926156692, 11.753978806907341, 12.736597294394752, 13.635280628086495, 14.467970404275292, 15.435762307441603, 14.827189482418536, 13.82464338073429, 12.817078487806622, 11.745482229162679, 10.752086005986534, 9.807075882933953, 8.916545002082913, 7.910715554048092, 7.012389234092354, 6.294832249249647, 6.9523229376394085, 7.896889853973767, 8.774188237796928, 8.897123165520878, 9.783189377710999, 10.743841342376914, 11.735891569963318, 12.673783303765873, 13.525654503013117, 14.500842487295488, 13.856589849639601, 12.914834444154101, 11.893767232819897, 10.87814003938785, 9.853394086777305, 8.879101063987502, 7.949682227515756, 6.968420360194957, 6.043846877238744, 5.220213252916331, 5.940336054028349, 6.896163085949485, 7.847349797075084], [7.842173982469255, 6.883198727196325, 5.903861713759112, 5.030016523616855, 4.001781883985807, 4.940188999633713, 5.915630742601739, 6.93051484732937, 7.87017198452847, 8.894598262274075, 9.875077436386515, 10.865494790737772, 11.931558304849279, 12.895727868696301, 13.563257744969935, 12.620971865488091, 11.663586386514499, 10.803582063555886, 9.80265593594703, 8.852351614429296, 6.875611758809653, 5.924585419190924, 4.913348835455109, 4.03160284858448, 2.971752454806648, 3.960987081316458, 4.965504038981551, 5.957499852775197, 6.96519918819352, 7.978613895193997, 8.932009583623877, 9.892051657329027, 10.91683710595166, 11.93326427836893, 12.63612974939928, 11.73169666356282, 10.738138709025195, 9.809816864361018, 8.754565940114501, 7.915370969614768, 5.831889105775926, 4.890733965953035, 3.9339743741244444, 3.042939620970554, 2.044099188163224, 2.991033027374423, 3.9627739396460306, 4.9846624490729745, 5.9487619964874145, 6.956016717018409, 7.969078791980866, 8.899871780770036, 9.901621480276127, 10.892383329920625, 11.687837169806452, 10.749204134280328, 9.799345401075582, 8.84437075851976, 7.829167789031335, 6.8773384593595015, 4.910401863736442, 3.9729877987161446, 2.950130452814365, 2.0215214333097147, 0.98226192176034, 2.0077038806830467, 2.9561846581356184, 3.9472931925378405, 4.932843542696121, 5.909568933530585, 6.910019979227492, 7.978195309251992, 8.942098590348118, 9.904647030703869, 10.842860445981934, 9.798830117013056, 8.870311490572924, 7.935193414766214, 6.941614261604675, 5.933031577682595, 4.015824951289387, 3.0668633314258624, 2.0385582753962206, 1.0095024462560966, 0.0, 1.0658081699152033, 2.1111056669393164, 3.0518090662211907, 4.122816263599611, 5.067060736713579, 6.016700706101746, 7.083820030433128, 8.118438166449478, 9.154766548152578, 10.0726751432056, 9.044671119802409, 8.082961697594673, 7.154098347817471, 6.135688713590584, 5.069567770881362, 4.9177568022122555, 3.856017111733099, 2.9067792152980734, 1.9813922976542335, 0.9425628366203771, 1.970142623795664, 2.907318077586728, 3.8758478387835487, 4.885827391583671, 5.813361203213386, 6.75950809486886, 7.711909496126504, 8.702428467664665, 9.63138741599979, 10.60919778592492, 9.867533919215074, 8.940200918330083, 7.883839711633243, 6.830843140893499, 5.868099861472931, 5.861787545007304, 4.854852447819072, 3.9805992962106753, 2.9822276399205347, 1.9133345742712682, 2.9404560658747827, 3.8820776270701396, 4.914488601584332, 5.906332667525332, 6.755115111135349, 7.780972180836335, 8.710079803907384, 9.692247645078949, 10.645056584474574, 11.561677709353958, 10.803537788598735, 9.77954801946971, 8.738477406359237, 7.730085112802846, 6.797530191235772, 6.83759412115601, 5.837135121739474, 4.920124401099179, 3.9102468981332708, 2.938690423150664, 3.966606892811779, 4.858369073961018, 5.895870585517496, 6.8692524324106525, 7.696589147746007, 8.653190201105522, 9.642009209872999, 10.595913816025583, 11.64874229158907, 12.611206633037986, 11.640209468129845, 10.710622868029207, 9.771667543677184, 8.720613328520002, 7.734616421110317, 7.801638440790866, 6.738453643481128, 5.744752960321691, 4.816715369143666, 3.8694510516496963, 4.873995584144512, 5.810276681375152, 6.8375348707598675, 7.802105506779373, 8.734803647796088, 9.665233392817294, 10.664372042490994, 11.559800077261325, 12.499198682319058, 13.528509851226033, 12.668630890115086, 11.768772542586856, 10.775845778982205, 9.709028162164993, 8.7020550245954, 8.730355285007718, 7.725216209745527, 6.772197462430078, 5.7910723859308835, 4.833183503337008, 5.817634048438511, 6.790777979662618, 7.732912773267035, 8.776390661274249, 9.680564125109143, 10.633824389629925, 11.558997848366968, 12.497958083445836, 13.432919179133375, 14.419905771366302, 13.630748594579494, 12.771467887646958, 11.722204464631597, 10.697511297788864, 9.682743549778428, 9.73295550763323, 8.698282973809622, 7.754163307726697, 6.767594189544293, 5.76692615062942, 6.740554020265543, 7.809014051981261, 8.784721825708885, 9.705354458551348, 10.641272486860515, 11.60921419068921, 12.588040362109178, 13.521978667975997, 14.504576503200418, 14.720086907305275, 13.892470708558884, 13.62995938616529, 12.618337310038237, 11.65339246218425, 10.675340308621008, 10.572657645396573, 9.64470453345093, 8.734507178570963, 7.745228163982846, 6.806495813877507, 7.696587695813488, 8.62925083034456, 9.574696618116466, 10.605797387454992, 11.530918717706998, 12.51078809557552, 13.515537405820941, 14.586531981678268, 14.79436933487831, 13.759425475498537, 12.916122428656728, 13.819770936530034, 13.529933701398017, 12.55568038897299, 11.528263023789489, 11.566314625964923, 10.614268116373283, 9.793232862141563, 8.778535057461022, 7.823917441718419, 8.755601615388853, 9.576512797166979, 10.60366323995484, 11.572679955998124, 12.533266605509455, 13.501293243737742, 14.42681957387737, 14.598003390497016, 13.798711002231542, 12.728279988473288, 11.845041600112001, 12.797640874695306, 13.786341257989985, 13.500711698030583, 12.531142342783017, 12.56565708907988, 11.554535685947133, 10.735864370877957, 9.767744871119104, 8.776737003808773, 9.70164348753167, 10.541436334485956, 11.479110730584287, 12.531285159815699, 13.464391064133501, 14.491845190300372, 14.688420418534564, 13.661817664541394, 12.778990941985978, 11.792337107579723, 10.837403127904487, 11.821110634843155, 12.809798011927734, 13.850342630670468, 13.543133538576592, 13.506812426475426, 12.565287045629866, 11.669119343107882, 10.672924513868953, 9.74756301788392, 10.743609275807685, 11.580971723389231, 12.459511252738729, 13.414801143837341, 14.383478966630765, 14.637283349931268, 13.66045179944787, 12.637724261266833, 11.754970458386842, 10.828171010734586, 9.911495174792098, 10.865005906995128, 11.870106942511498, 12.790590007171062, 13.765856622918077, 13.602862786013967, 13.59950956687254, 12.66377050954023, 11.603794829081778, 10.773491392417217, 11.675635645527272, 12.55503564345614, 13.419673797347146, 14.47484595924531, 14.674442970936594, 13.633867493380581, 12.7312466543955, 11.700426408736304, 10.80413005696457, 9.87673211679456, 8.884158969453155, 9.863783282490322, 10.822739914723842, 11.771490333306941, 12.75793933146812, 12.602528115960874, 13.54834894505832, 13.621666877417365, 12.576460731988904, 11.777238834352586, 12.750439283091033, 13.559746379637225, 14.383020413323823, 14.703871187682065, 13.748431081306874, 12.680302858093903, 11.702409945204415, 10.741885471862481, 9.8601119262582, 8.873540938142725, 7.911222607005311, 8.864701172917865, 9.894595048602957, 10.800409842888849, 11.725205063015457, 11.636421467691594, 12.697074717918856, 13.724958683451229, 13.650403149442678, 12.758598018201747, 13.723653622700315, 14.633602931173005, 14.646856728563462, 13.64182498856473, 12.7114035563428, 11.664453958897134, 10.701721218528192, 9.81040370873293, 8.851961686516576, 7.880837312999511, 6.9583569043421925, 7.909519265382642, 8.965222376445634, 9.873164535127982, 10.68642415913692, 10.725991452992268, 11.784104923768831, 12.71098180451948, 13.693600292006892, 13.822190600242626, 14.650785819877381, 14.758694280242223, 13.81768703616244, 12.81514093447819, 11.807576041550524, 10.73597978290658, 9.742583559730436, 8.797573436677855, 7.907042555826816, 6.901213107791995, 6.002886787836258, 7.022113771810288, 7.909325935251549, 8.853892851585908, 9.731191235409067, 9.854126163133017, 10.740192375323138, 11.700844339989054, 12.692894567575458, 13.630786301378013, 14.504158210292655, 13.823774460096107, 12.847087403383505, 11.905331997898005, 10.8842647865638, 9.868637593131751, 8.843891640521207, 7.869598617731404, 6.940179781259658, 5.95891791393886, 5.034344430982648, 6.023609770068887, 6.89733905164049, 7.853166083561626, 8.804352794687224], [8.907982152384458, 7.949006897111527, 6.969669883674315, 6.038018819652423, 5.009784180021375, 4.058089487072181, 4.963885555082696, 5.978769659810326, 6.918426797009427, 7.942853074755032, 8.923332248867471, 9.913749603218728, 10.933097481740544, 11.874914120374784, 12.721288930024352, 13.686780035403293, 12.729394556429702, 11.869390233471089, 10.868464105862232, 9.918159784344498, 7.941419928724855, 6.990393589106127, 5.979157005370311, 5.03960514462005, 3.979754750842217, 3.0788875687549258, 4.013758851462507, 5.005754665256153, 6.013454000674475, 7.026868707674953, 7.9802643961048325, 8.940306469809983, 9.896023357630142, 10.912450530047412, 11.794160934453698, 12.766993919669485, 11.803946878940398, 10.87562503427622, 9.820374110029704, 8.98117913952997, 6.897697275691129, 5.956542135868237, 4.999782544039647, 4.050941917006123, 3.052101484198793, 2.0392878398553784, 3.011028752126987, 4.032917261553931, 4.99701680896837, 6.0042715294993645, 7.017333604461822, 7.945746426751123, 8.88080773195461, 9.871569581599108, 10.845868354860869, 11.784501390386993, 10.865153570990785, 9.910178928434961, 8.894975958946537, 7.943146629274704, 5.976210033651644, 5.038795968631347, 4.015938622729568, 3.087329603224918, 2.048070091675543, 1.0559586931640024, 2.0044394706165742, 2.9955480050187964, 3.9810983551770764, 4.957823746011541, 5.9582747917084475, 6.957381560930475, 7.921284842026601, 8.883833282382351, 9.914283588498428, 10.864638286928258, 9.936119660488126, 9.001001584681417, 8.007422431519878, 6.998839747597797, 5.08163312120459, 4.132671501341066, 3.1043664453114235, 2.0753106161712997, 1.0658081699152033, 0.0, 1.045297497024113, 1.9860008963059874, 3.0570080936844075, 4.001252566798375, 4.950892536186543, 6.018011860517925, 7.052629996534274, 8.088958378237376, 9.109293736008176, 10.110479289717613, 9.148769867509877, 8.219906517732674, 7.201496883505786, 6.135375940796565, 5.983564972127458, 4.921825281648301, 3.9725873852132763, 3.0472004675694366, 2.0083710065355804, 1.050804526344359, 1.9879799801354228, 2.948307763440451, 3.9582873162405736, 4.8858211278702885, 5.831968019525762, 6.784369420783406, 7.774888392321567, 8.703847340656692, 9.681657710581822, 10.660895233279627, 10.006009088245285, 8.949647881548445, 7.896651310808702, 6.933908031388134, 6.927595714922506, 5.920660617734274, 5.046407466125878, 4.0480358098357385, 2.9791427441864715, 2.0211179684234777, 2.9627395296188346, 3.9869485262412345, 4.978792592182234, 5.827575035792251, 6.853432105493237, 7.782539728564287, 8.764707569735853, 9.717516509131476, 10.63413763401086, 11.588316781267576, 10.845356189384912, 9.80428557627444, 8.795893282718048, 7.863338361150975, 7.903402291071212, 6.902943291654676, 5.9859325710143825, 4.976055068048474, 4.004498593065867, 3.0472687953604733, 3.939030976509714, 4.968330510174399, 5.941712357067555, 6.769049072402909, 7.725650125762424, 8.714469134529901, 9.668373740682483, 10.721202216245972, 11.707496102125967, 12.64237596632335, 11.776431037944409, 10.837475713592386, 9.786421498435205, 8.80042459102552, 8.867446610706068, 7.80426181339633, 6.810561130236893, 5.882523539058869, 4.935259221564899, 4.089599904835559, 5.005559868519699, 5.972378532181988, 6.936949168201494, 7.80726357245299, 8.737693317474196, 9.736831967147896, 10.632260001918226, 11.571658606975959, 12.600969775882934, 13.588647002342057, 12.83458071250206, 11.841653948897408, 10.774836332080195, 9.767863194510602, 9.79616345492292, 8.79102437966073, 7.83800563234528, 6.856880555846086, 5.89899167325221, 5.033238369129558, 5.9887670326608085, 6.9309018262652256, 7.974379714272439, 8.753024049766044, 9.706284314286828, 10.63145777302387, 11.570418008102738, 12.505379103790276, 13.492365696023203, 14.488192133727066, 13.837276057562162, 12.7880126345468, 11.763319467704067, 10.74855171969363, 10.798763677548434, 9.764091143724826, 8.8199714776419, 7.8334023594594955, 6.832734320544622, 6.097002350038425, 7.037186232003808, 7.982710878707076, 8.903343511549538, 9.713732411517416, 10.681674115346112, 11.66050028676608, 12.594438592632901, 13.577036427857319, 13.89643783499745, 14.847246381692555, 14.695767556080494, 13.684145479953441, 12.719200632099454, 11.741148478536212, 11.638465815311777, 10.710512703366135, 9.800315348486167, 8.811036333898048, 7.872303983792709, 7.053036025586369, 7.985699160117442, 8.931144947889347, 9.854107517179541, 10.73572809198537, 11.63302367364364, 12.637772983889061, 13.664122628782563, 13.970720262570484, 12.935776403190712, 13.884968668575361, 14.827773232565605, 14.595741871313221, 13.621488558888194, 12.594071193704693, 12.632122795880127, 11.680076286288488, 10.859041032056767, 9.844343227376225, 8.88972561163362, 8.112049945161734, 8.932961126939862, 9.960111569727722, 10.879304658491204, 11.738075979787828, 12.682491124709735, 13.565310246033786, 13.646258202977972, 12.975061929923717, 11.904630916165463, 12.853043896147572, 13.805643170730876, 14.794343554025556, 14.566519867945788, 13.596950512698221, 13.631465258995084, 12.620343855862338, 11.80167254079316, 10.833553041034307, 9.842545173723973, 9.058091817304552, 9.89788466425884, 10.83555906035717, 11.866276368458372, 12.669200438411874, 13.696654564578745, 13.73667523101552, 12.710072477022349, 11.95534186967815, 10.968688035271898, 11.845405423940058, 12.829112930878726, 13.817800307963305, 14.858344926706039, 14.608941708491797, 14.57262059639063, 13.63109521554507, 12.734927513023083, 11.738732683784153, 10.81337118779912, 10.110843436733376, 10.937420053162114, 11.815959582511612, 12.771249473610224, 13.731316125753493, 13.685538162412227, 12.708706611928825, 11.685979073747788, 10.931321386079016, 10.00452193842676, 10.919497470827668, 11.873008203030698, 12.878109238547069, 13.822015017836193, 14.82749908495578, 14.66867095592917, 14.665317736787744, 13.72957867945543, 12.669602998996979, 11.839299562332418, 11.042869806452963, 11.911483973229021, 12.77612212712003, 13.831294289018192, 13.722697783417553, 12.68212230586154, 11.779501466876457, 10.74868122121726, 9.922030544403038, 9.053083044486735, 9.892161265488726, 10.871785578525893, 11.830742210759412, 12.833132795344644, 13.819581793505824, 13.668336285876077, 14.614157114973523, 14.687475047332565, 13.642268901904105, 12.843047004267786, 12.117673444016724, 12.916194709410107, 13.739468743096706, 13.752126000163024, 12.796685893787833, 11.728557670574862, 10.750664757685373, 9.790140284343439, 8.978012413696668, 8.038280269679648, 8.919224903040881, 9.872703468953434, 10.902597344638526, 11.862052304926552, 12.79101323293066, 12.702229637606797, 13.762882887834058, 14.790766853366431, 14.716211319357878, 13.824406188116948, 13.090887783626005, 13.990051260945886, 13.69511154104442, 12.69007980104569, 11.759658368823759, 10.712708771378093, 9.749976031009151, 8.858658521213886, 7.969862173955043, 6.998737800437978, 7.966359200377761, 8.91752156141821, 9.973224672481203, 10.934806997165685, 11.752232329052122, 11.79179962290747, 12.849913093684034, 13.776789974434681, 14.759408461922092, 14.887998770157827, 14.018019980803071, 13.737880531920705, 12.85588117225528, 11.86339574695915, 10.855830854031481, 9.784234595387538, 8.790838372211393, 7.845828249158811, 6.963851247865595, 6.019113595230462, 7.0108890838718265, 8.030116067845857, 8.970968397289251, 9.91553531362361, 10.79699940532427, 10.91993433304822, 11.80600054523834, 12.766652509904256, 13.75870273749066, 14.696594471293214, 13.662189395347072, 12.80296071177459, 11.885281539476345, 10.95358681037896, 9.932519599044756, 8.916892405612707, 7.892146453002163, 6.91785343021236, 5.988434593740615, 5.076818401377327, 6.0423467270182165, 7.031612066104456, 7.963147221555692, 8.918974253476827, 9.870160964602427], [9.86345966818621, 8.904484412913279, 7.925147399476067, 6.984510975000747, 5.956276335369699, 5.004581642420504, 4.013416155525874, 5.028300260253505, 5.967957397452605, 6.9923836751982105, 7.932355215833207, 8.922772570184463, 9.88779998471643, 10.82961662335067, 11.675991433000238, 12.664469053121135, 13.621854532094726, 12.833207481949541, 11.832281354340685, 10.87363730014625, 8.905237177203308, 7.954133583831027, 6.934634521172064, 5.986097299968373, 4.92624690619054, 4.025379724103249, 3.0632894519056855, 4.0552852656993315, 5.022476967640212, 6.035891674640689, 6.989287363070568, 7.900234239666868, 8.850725860606028, 9.867153033023298, 10.748863437429584, 11.72169642264537, 12.7355257333588, 11.839442282754673, 10.784191358508156, 9.944996388008423, 7.861514524169581, 6.92035938434669, 5.9635997925180995, 4.997434072354446, 3.998593639547116, 2.9857799952037016, 2.060559352570166, 3.071639131974088, 4.006039775934107, 5.013294496465101, 6.019869579247857, 6.900448929727009, 7.835510234930496, 8.826272084574994, 9.800570857836755, 10.739203893362879, 11.689062626567624, 10.873996176913414, 9.85879320742499, 8.906963877753157, 6.956032749411134, 6.0186186843908365, 4.995761338489057, 4.067152318984407, 3.027892807435032, 2.0024508485123254, 1.0539700710597535, 2.004570971984533, 2.990121322142813, 3.9668467129772775, 4.960810766494482, 5.912084063906361, 6.875987345002487, 7.838535785358237, 8.868986091474314, 9.913016420443192, 10.841535046883324, 9.980824300440906, 8.987245147279367, 7.978662463357287, 6.126930618228703, 5.177968998365178, 4.149663942335536, 3.120608113195413, 2.1111056669393164, 1.045297497024113, 0.0, 0.9407033992818745, 2.0117105966602944, 2.9559550697742623, 3.9055950391624297, 4.972714363493812, 6.007332499510161, 7.0436608812132615, 8.063996238984062, 9.092000262387254, 10.05370968459499, 9.265204014756787, 8.246794380529899, 7.180673437820677, 6.984624943419833, 5.922885252940676, 4.973647356505651, 4.048260438861812, 3.0094309778279555, 1.9818511906526683, 1.0446757368616046, 1.903010266416338, 2.9129898192164605, 3.8405236308461754, 4.786670522501648, 5.739071923759292, 6.729590895297453, 7.658549843632577, 8.636360213557708, 9.615597736255513, 10.542930737140503, 9.950707852840821, 8.897711282101078, 7.93496800268051, 7.928655686214881, 6.921720589026649, 6.047467437418254, 5.049095781128113, 3.9802027154788466, 2.9521646327317868, 2.106886413076545, 2.9416510292171214, 3.9334950951581216, 4.782277538768138, 5.808134608469123, 6.737242231540173, 7.719410072711738, 8.67221901210736, 9.588840136986747, 10.543019284243464, 11.505184381775562, 10.805345547566816, 9.796953254010424, 8.86439833244335, 8.904462262363587, 7.904003262947051, 6.986992542306758, 5.977115039340849, 5.0055585643582425, 3.9783154596687824, 3.0831778599674236, 3.923033013150286, 4.896414860043442, 5.723751575378796, 6.68035262873831, 7.669171637505787, 8.623076243658371, 9.675904719221856, 10.662198605101853, 11.597078469299237, 12.526665069399876, 11.838535684884762, 10.787481469727581, 9.801484562317896, 9.868506581998444, 8.805321784688706, 7.811621101529269, 6.883583510351244, 5.936319192857274, 5.020646569143869, 4.1497067519774085, 4.927081035157875, 5.89165167117738, 6.761966075428877, 7.692395820450082, 8.691534470123782, 9.586962504894114, 10.526361109951846, 11.555672278858822, 12.543349505317945, 13.471067088013509, 12.842713920189784, 11.775896303372571, 10.768923165802978, 10.797223426215297, 9.792084350953106, 8.839065603637657, 7.857940527138462, 6.900051644544585, 5.964285033437868, 5.132913916118518, 5.903760642225889, 6.947238530233102, 7.7077265527419305, 8.660986817262714, 9.586160275999756, 10.525120511078624, 11.460081606766163, 12.44706819899909, 13.442894636702954, 14.382278072004866, 13.789072605839175, 12.764379438996443, 11.749611690986006, 11.799823648840809, 10.7651511150172, 9.821031448934276, 8.83446233075187, 7.833794291836997, 7.028049014346735, 6.181333115461518, 6.955569694667739, 7.876202327510201, 8.668434914493302, 9.636376618321998, 10.615202789741966, 11.549141095608785, 12.531738930833207, 13.404301428289228, 14.355109974984334, 15.339423375706856, 14.685205451245816, 13.720260603391829, 12.742208449828587, 12.639525786604151, 11.711572674658509, 10.801375319778543, 9.812096305190423, 8.873363955085084, 7.984082689894679, 7.143170682392028, 7.945277394611206, 8.826966333140204, 9.690430594961256, 10.587726176619526, 11.592475486864947, 12.618825131758447, 13.229856721223406, 13.882268558539035, 14.831460823923685, 15.774265387913928, 15.596801842605595, 14.622548530180568, 13.595131164997067, 13.633182767172501, 12.681136257580862, 11.860101003349143, 10.845403198668599, 9.890785582925997, 9.043096609470044, 8.090432649214447, 8.987693268292807, 9.852163474451867, 10.692778482763714, 11.63719362768562, 12.520012749009672, 12.695788803421152, 12.164143375602183, 12.851123071513786, 13.799536051495895, 14.7521353260792, 15.74083570937388, 15.567579839238162, 14.598010483990596, 14.632525230287458, 13.621403827154712, 12.802732512085534, 11.834613012326681, 10.84360514501635, 9.989138481612862, 9.055356186533425, 9.941439430819544, 10.839135184419035, 11.623902941387762, 12.651357067554633, 12.7862058314587, 11.75960307746553, 11.115677421602228, 11.915180190620221, 12.791897579288381, 13.77560508622705, 14.764292463311628, 15.804837082054362, 15.61000167978417, 15.573680567683004, 14.632155186837444, 13.735987484315457, 12.739792655076528, 11.814431159091496, 11.041890101041686, 10.0948915754367, 10.921839952973986, 11.877129844072599, 12.68601862872938, 12.735068762855404, 11.758237212372006, 10.735509674190968, 10.091656938003092, 10.951014093775084, 11.865989626175992, 12.819500358379022, 13.824601393895392, 14.768507173184517, 15.773991240304104, 15.624148471730921, 15.666377708080118, 14.730638650747805, 13.670662970289353, 12.840359533624794, 11.973916470761273, 11.068955495503609, 11.882002497582404, 12.937174659480567, 12.77222838386073, 11.731652906304717, 10.829032067319636, 9.79821182166044, 9.016776691065122, 9.999575199835059, 10.83865342083705, 11.818277733874217, 12.777234366107736, 13.779624950692968, 14.766073948854148, 14.623813801677828, 15.569634630775274, 15.68853501862494, 14.643328873196479, 13.844106975560162, 13.008203112798565, 12.073666231684694, 12.845349113559081, 12.8016566006062, 11.84621649423101, 10.778088271018039, 9.800195358128551, 8.839670884786617, 8.072758560358752, 8.984772425027971, 9.865717058389205, 10.819195624301758, 11.84908949998685, 12.808544460274875, 13.74649074873241, 13.657707153408548, 14.71836040363581, 15.746244369168183, 15.717271290650253, 14.825466159409324, 13.981417452407847, 13.147522783220474, 12.744642141487597, 11.739610401488866, 10.809188969266936, 9.76223937182127, 8.799506631452328, 7.908189121657065, 7.064608320617127, 7.945229955786302, 8.912851355726085, 9.864013716766534, 10.919716827829527, 11.881299152514009, 12.707709844853873, 12.747277138709222, 13.805390609485785, 14.740607222913134, 15.55872154570944, 14.53369252729493, 13.559207799585133, 12.692583034896591, 11.810583675231166, 10.912926347402326, 9.90536145447466, 8.833765195830717, 7.840368972654572, 6.8953588496019895, 6.013381848308773, 6.965605750578786, 7.95738123922015, 8.97660822319418, 9.917460552637575, 10.862027468971934, 11.752476921126021, 11.875411848849971, 12.769817793716793, 13.730469758382709, 14.622578671115074, 13.674283489011057, 12.616891898322958, 11.757663214750476, 10.839984042452231, 9.962609777344696, 8.941542566010494, 7.966423006055885, 6.941677053445342, 5.967384030655539, 5.037965194183793, 6.023310556725651, 6.98883888236654, 7.97810422145278, 8.918624737357444, 9.87445176927858, 10.825638480404178], [10.804163067468084, 9.845187812195153, 8.865850798757942, 7.925214374282621, 6.896979734651573, 5.945285041702379, 4.9541195548077495, 4.239876572028946, 5.137319374751427, 6.131995872546642, 6.991651816551332, 7.98206917090259, 8.947096585434556, 9.888913224068796, 10.735288033718364, 11.72376565383926, 12.681151132812852, 13.705523730041127, 12.772984753622561, 11.814340699428124, 9.845940576485184, 8.894836983112901, 7.875337920453938, 6.926800699250247, 5.866950305472415, 4.966083123385124, 4.003992851187561, 3.190228616166955, 4.081773568358337, 5.095188275358815, 6.048583963788694, 6.959530840384994, 7.910022461324154, 8.926449633741424, 9.80816003814771, 10.780993023363497, 11.794822334076926, 12.723144178741103, 11.724894757790032, 10.8856997872903, 8.802217923451456, 7.861062783628564, 6.904303191799974, 5.93813747163632, 4.9392970388289905, 3.926483394485576, 3.0012627518520407, 2.1309357326922136, 3.0653363766522324, 4.072591097183227, 5.079166179965982, 5.959745530445135, 6.894806835648621, 7.885568685293119, 8.85986745855488, 9.798500494081004, 10.74835922728575, 11.801054820879946, 10.799496606706866, 9.847667277035033, 7.896736148693008, 6.959322083672711, 5.936464737770931, 5.007855718266281, 3.9685962067169065, 2.9431542477941997, 1.994673470341628, 1.0638675727026583, 2.0494179228609384, 3.026143313695403, 4.020107367212607, 4.971380664624487, 5.935283945720613, 6.897832386076363, 7.92828269219244, 8.972313021161318, 9.90083164760145, 10.83594972340816, 9.927948546561241, 8.919365862639161, 7.067634017510577, 6.118672397647052, 5.0903673416174104, 4.061311512477287, 3.0518090662211907, 1.9860008963059874, 0.9407033992818745, 0.0, 1.07100719737842, 2.015251670492388, 2.9648916398805554, 4.0320109642119375, 5.066629100228287, 6.102957481931387, 7.123292839702188, 8.15129686310538, 9.113006285313116, 10.041869635090318, 9.187497779811775, 8.121376837102552, 7.870785834889513, 6.809046144410356, 5.859808247975331, 4.934421330331491, 3.895591869297635, 2.868012082122348, 1.930836628331284, 0.9623068671344635, 1.9722864199345862, 2.899820231564301, 3.8459671232197743, 4.798368524477418, 5.788887496015579, 6.717846444350703, 7.695656814275833, 8.674894336973638, 9.60222733785863, 10.65858854455547, 9.783872173570757, 8.821128894150188, 8.814816577684562, 7.807881480496329, 6.933628328887933, 5.935256672597792, 4.866363606948526, 3.8383255242014664, 2.993047304546224, 2.000947629935247, 2.9927916958762473, 3.841574139486264, 4.867431209187249, 5.796538832258299, 6.7787066734298635, 7.731515612825486, 8.64813673770487, 9.602315884961587, 10.564480982493688, 11.60555159560416, 10.683114145480102, 9.75055922391303, 9.790623153833266, 8.79016415441673, 7.873153433776437, 6.863275930810529, 5.891719455827922, 4.864476351138462, 3.9693387514371032, 2.9823296138684117, 3.9557114607615675, 4.783048176096922, 5.739649229456436, 6.728468238223913, 7.682372844376496, 8.735201319939982, 9.721495205819977, 10.656375070017361, 11.585961670118, 12.524916994470022, 11.67364236119726, 10.687645453787574, 10.754667473468123, 9.691482676158385, 8.697781992998948, 7.769744401820923, 6.822480084326954, 5.906807460613548, 5.013635825260717, 3.986377635876001, 4.950948271895506, 5.821262676147002, 6.751692421168208, 7.750831070841908, 8.64625910561224, 9.585657710669972, 10.614968879576947, 11.60264610603607, 12.530363688731635, 13.596282305469055, 12.66205719484225, 11.655084057272656, 11.683384317684975, 10.678245242422785, 9.725226495107336, 8.74410141860814, 7.786212536014265, 6.850445924907547, 5.905192036548431, 4.963057242944014, 6.006535130951228, 6.767023153460056, 7.7202834179808395, 8.645456876717882, 9.58441711179675, 10.519378207484289, 11.506364799717216, 12.50219123742108, 13.441574672722991, 14.515833301072512, 13.650540330466121, 12.635772582455685, 12.685984540310487, 11.65131200648688, 10.707192340403955, 9.720623222221551, 8.719955183306677, 7.9142099058164135, 6.953611235891431, 6.014866295385865, 6.935498928228327, 7.727731515211428, 8.695673219040124, 9.674499390460092, 10.608437696326913, 11.591035531551332, 12.463598029007354, 13.41440657570246, 14.398719976424982, 15.410342052552034, 14.606421494861507, 13.628369341298265, 13.52568667807383, 12.597733566128188, 11.687536211248222, 10.698257196660103, 9.759524846554765, 8.848111937353014, 7.915448802821941, 7.004573995329332, 7.88626293385833, 8.749727195679382, 9.647022777337652, 10.651772087583073, 11.678121732476574, 12.645340997164238, 13.424259460814092, 14.373451726198741, 15.337518736163378, 16.26433256467672, 15.508709421650247, 14.481292056466746, 14.51934365864218, 13.56729714905054, 12.746261894818822, 11.73156409013828, 10.776946474395677, 9.846019719175386, 8.86271076964436, 8.046989869010932, 8.911460075169995, 9.75207508348184, 10.696490228403746, 11.579309349727797, 12.010928417812433, 13.05367054107773, 13.791826470795659, 14.740239450777771, 15.692838725361076, 16.681539108655755, 16.45374073070784, 15.484171375460274, 15.518686121757137, 14.50756471862439, 13.688893403555214, 12.720773903796362, 11.72976603648603, 10.776286030563018, 9.827634306963338, 9.00073603153767, 9.898431785137163, 10.683199542105886, 11.710653668272757, 12.101345445849981, 11.07474269185681, 12.056380820884101, 12.855883589902094, 13.732600978570257, 14.716308485508925, 15.704995862593504, 16.74554048133624, 16.49616257125385, 16.459841459152685, 15.518316078307123, 14.62214837578514, 13.62595354654621, 12.700592050561177, 11.829037649991841, 10.867169695866613, 9.981136553692112, 10.936426444790724, 11.745315229447504, 12.050208377246685, 11.073376826763287, 10.05064928858225, 11.032360337284967, 11.891717493056957, 12.806693025457868, 13.760203757660898, 14.765304793177268, 15.709210572466393, 16.71469463958598, 16.564851871012795, 16.5525385995498, 15.616799542217487, 14.556823861759035, 13.726520425094474, 12.761064019711428, 11.841233615933522, 10.94129909830053, 11.996471260198692, 12.087367998252011, 11.046792520695998, 10.144171681710917, 9.11335143605172, 9.957480090346996, 10.940278599116931, 11.779356820118926, 12.758981133156093, 13.717937765389612, 14.720328349974842, 15.706777348136022, 15.564517200959703, 16.51033803005715, 16.574695910094622, 15.529489764666161, 14.730267867029843, 13.780481233228478, 12.845944352114607, 11.904645714277207, 12.102175694600891, 11.161356108622291, 10.09322788540932, 9.115334972519832, 8.154810499177898, 9.013461959640626, 9.925475824309844, 10.80642045767108, 11.759899023583634, 12.789792899268726, 13.74924785955675, 14.687194148014285, 14.598410552690423, 15.659063802917684, 16.531724568721664, 15.584704044096195, 14.540871750575308, 13.545636597480325, 12.725447130123403, 11.865944861739528, 11.040129495483557, 10.109708063261627, 9.077378986212551, 8.114646245843609, 7.223328736048345, 8.005311719899002, 8.885933355068175, 9.853554755007961, 10.80471711604841, 11.860420227111403, 12.822002551795883, 13.648413244135748, 13.687980537991097, 14.74609400876766, 15.600636633914977, 14.618018146427566, 13.592989128013055, 12.618504400303259, 11.751879635614717, 10.869880275949292, 10.052199808029854, 9.073757824211551, 8.148904810221996, 7.155508587045852, 6.21049846399327, 6.9540852475906485, 7.90630914986066, 8.898084638502025, 9.917311622476054, 10.85816395191945, 11.802730868253809, 12.693180320407896, 12.816115248131846, 13.71052119299867, 14.65949553501442, 13.681875271833198, 12.73358008972918, 11.676188499041084, 10.816959815468602, 9.899280643170357, 9.021906378062821, 8.000839166728618, 7.202160017913945, 6.199467855502681, 5.282523645046819, 5.9786685934656685, 6.964013956007525, 7.9295422816484145, 8.918807620734654, 9.859328136639318, 10.815155168560453, 11.766341879686053], [11.778274591811332, 10.819299336538402, 9.83996232310119, 8.899325898625868, 7.87109125899482, 6.919396566045625, 5.928231079150996, 5.019684699213961, 4.080027562014861, 5.0747040598100766, 5.934360003814767, 6.924777358166025, 7.876089388056137, 8.817906026690377, 9.664280836339946, 10.652758456460843, 11.610143935434435, 12.63451653266271, 13.635442660271567, 12.788452223771372, 10.82005210082843, 9.86894850745615, 8.849449444797186, 7.900912223593494, 6.841061829815661, 5.9401946477283705, 4.978104375530807, 4.076244381415181, 3.0244817556217716, 4.03789646262225, 4.991292151052129, 5.8885236430065735, 6.8390152639457344, 7.855442436363004, 8.737152840769292, 9.709985825985079, 10.723815136698509, 11.652136981362686, 12.66975401861889, 11.859811311633546, 9.776329447794703, 8.835174307971812, 7.8784147161432205, 6.912248995979567, 5.913408563172237, 4.900594918828823, 3.9753742761952875, 3.0237075526980455, 2.0080445639156665, 3.015299284446661, 4.008158982587561, 4.888738333066715, 5.823799638270201, 6.8145614879147, 7.788860261176462, 8.727493296702587, 9.677352029907333, 10.730047623501529, 11.744355867535724, 10.82177880137828, 8.870847673036256, 7.9334336080159575, 6.910576262114178, 5.981967242609528, 4.942707731060153, 3.917265772137447, 2.9687849946848752, 1.977676460282653, 0.9921261101243729, 1.9688515009588374, 2.949100169834187, 3.9003734672460673, 4.864276748342193, 5.826825188697944, 6.85727549481402, 7.901305823782899, 8.82982445022303, 9.76494252602974, 10.75852167919128, 9.89347738698241, 8.138641214888997, 7.189679595025473, 6.161374538995831, 5.132318709855707, 4.122816263599611, 3.0570080936844075, 2.0117105966602944, 1.07100719737842, 0.0, 0.9442444731139681, 1.8938844425021353, 2.9610037668335174, 3.9956219028498667, 5.031950284552968, 6.052285642323769, 7.08028966572696, 8.041999087934697, 8.970862437711899, 9.989272071938785, 9.192384034480972, 8.850411878190357, 7.7886721877112, 6.839434291276175, 5.914047373632336, 4.87521791259848, 3.847638125423193, 2.9104626716321294, 1.9419329104353085, 0.9319533576351857, 1.8594871692649009, 2.805634060920374, 3.7580354621780176, 4.748554433716179, 5.677513382051303, 6.655323751976433, 7.634561274674239, 8.56189427555923, 9.61825548225607, 10.671252052995813, 9.800754937451034, 9.794442620985405, 8.787507523797172, 7.913254372188778, 6.914882715898637, 5.84598965024937, 4.817951567502312, 3.9726733478470693, 2.9624242993001735, 1.9524586335768468, 2.801241077186863, 3.827098146887849, 4.756205769958899, 5.738373611130464, 6.6911825505260865, 7.607803675405472, 8.561982822662188, 9.524147920194288, 10.56521853330476, 11.573610826861152, 10.730185267213875, 10.77024919713411, 9.769790197717574, 8.852779477077283, 7.842901974111373, 6.871345499128767, 5.844102394439307, 4.9489647947379485, 3.943806283233338, 2.9153783984621673, 3.7427151137975208, 4.699316167157035, 5.688135175924513, 6.642039782077096, 7.694868257640582, 8.681162143520579, 9.616042007717962, 10.5456286078186, 11.484583932170622, 12.535638147327804, 11.66727149708842, 11.734293516768968, 10.67110871945923, 9.677408036299793, 8.749370445121768, 7.802106127627798, 6.862852133740351, 5.926571036509712, 4.899312847124996, 3.934742211105491, 4.780929613847601, 5.711359358868807, 6.710498008542508, 7.60592604331284, 8.545324648370572, 9.574635817277548, 10.56231304373667, 11.490030626432235, 12.555949243169655, 13.524052980972794, 12.634710100573502, 12.66301036098582, 11.65787128572363, 10.70485253840818, 9.723727461908986, 8.76583857931511, 7.791271179021534, 6.818127247797427, 5.8759924541930095, 5.0035480105806025, 5.726690091160655, 6.67995035568144, 7.605123814418483, 8.54408404949735, 9.47904514518489, 10.466031737417817, 11.46185817512168, 12.401241610423591, 13.475500238773112, 14.500193405615844, 13.61539862575653, 13.66561058361133, 12.630938049787723, 11.686818383704798, 10.700249265522395, 9.699581226607522, 8.8550351599304, 7.866546447140427, 6.898391259741652, 5.9325118078577015, 6.687398452912026, 7.655340156740725, 8.634166328160694, 9.568104634027513, 10.550702469251933, 11.423264966707954, 12.37407351340306, 13.358386914125582, 14.370008990252634, 15.334953838106621, 14.607995384599109, 14.505312721374674, 13.577359609429031, 12.667162254549066, 11.677883239960947, 10.739150889855608, 9.76104714860201, 8.828384014070938, 7.888098959685119, 6.883275813487704, 7.7093941333799805, 8.606689715038252, 9.611439025283673, 10.637788670177175, 11.605007934864839, 12.383926398514692, 13.333118663899342, 14.297185673863979, 15.223999502377321, 16.19825281480235, 15.46091809976759, 15.498969701943023, 14.546923192351384, 13.725887938119666, 12.711190133439123, 11.75657251769652, 10.758954930424382, 9.775645980893357, 8.877489670842653, 7.908472954799368, 8.711742021182438, 9.656157166104347, 10.538976287428397, 11.526053618952906, 12.568795742218203, 13.415071885539941, 14.404199492444068, 15.319315735698707, 16.229602237607423, 17.184585224924028, 16.463797418761118, 16.498312165057982, 15.487190761925234, 14.668519446856058, 13.700399947097205, 12.703883360383987, 11.689221241812014, 10.740569518212334, 9.83123583336939, 8.895444664766536, 9.642866479806486, 10.670320605973357, 11.15545419305032, 11.854550819041824, 12.869335739748056, 13.789333864435754, 14.706712502913504, 15.690420009852172, 16.679107386936753, 17.71965200567949, 17.475788614554695, 17.439467502453528, 16.497942121607966, 15.596265699683096, 14.600070870444167, 13.674709374459134, 12.741972861240837, 11.780104907115609, 10.811636355523833, 9.95957356421816, 10.704982167148104, 11.023859687700556, 10.127485573963625, 10.830457415767263, 11.898368319938362, 12.825167767590617, 13.780804549801115, 14.734315282004145, 15.739416317520515, 16.68332209680964, 17.688806163929225, 17.538963395356042, 17.532164642850642, 16.590916866115442, 15.530941185656992, 14.700637748992431, 13.673999230960424, 12.754168827182518, 11.77179890013225, 11.01961837962613, 11.061019308705882, 10.02044383114987, 9.143912165269708, 9.893159563236734, 10.891057663802691, 11.889202777923478, 12.753468344462172, 13.73309265749934, 14.692049289732859, 15.694439874318089, 16.68088887247927, 16.53862872530295, 17.4198206712264, 16.441913795794484, 15.383085728959077, 14.451223737046051, 13.447843739711189, 12.728296484280763, 11.857370644991885, 11.044883881864326, 10.118744116029985, 9.06687919586319, 8.100258493443622, 8.934618626362912, 9.947039533096321, 10.89958734865309, 11.780531982014327, 12.73401054792688, 13.763904423611972, 14.723359383899997, 15.661305672357534, 15.572522077033671, 16.488601336875618, 15.460717371343247, 14.513696846717778, 13.46986455319689, 12.474629400101907, 11.654439932744983, 10.79493766436111, 9.982837682746991, 9.052416250525061, 8.051030296666422, 7.08829755629748, 8.00313686323336, 8.963794097777395, 9.860044879411422, 10.827666279351208, 11.778828640391657, 12.83453175145465, 13.79611407613913, 14.622524768478996, 14.662092062334345, 15.553017639165699, 14.52962943653656, 13.547010949049149, 12.521981930634638, 11.547497202924841, 10.680872438236298, 9.798873078570873, 8.994907995293289, 8.016466011474986, 7.122556120675868, 6.129159897499723, 6.990306591178285, 7.928196771933895, 8.880420674203906, 9.872196162845272, 10.891423146819301, 11.832275476262696, 12.776842392597056, 13.667291844751144, 13.790226772475094, 14.549140302301918, 13.588488337636003, 12.61086807445478, 11.662572892350763, 10.605181301662666, 9.745952618090183, 8.828273445791938, 7.964614565326256, 6.943547353992053, 6.14486820517738, 5.142176042766115, 6.062331772231834, 6.952780117808915, 7.938125480350772, 8.903653805991661, 9.8929191450779, 10.833439660982567, 11.789266692903702, 12.740453404029301], [12.7225190649253, 11.76354380965237, 10.784206796215159, 9.843570371739837, 8.815335732108789, 7.863641039159593, 6.872475552264964, 5.96392917232793, 5.0242720351288295, 4.1846191308529255, 5.027828055700677, 6.006558958705668, 6.931844914942168, 7.873661553576408, 8.720036363225978, 9.708513983346874, 10.665899462320466, 11.690272059548741, 12.691198187157598, 13.717935783507706, 11.7642965739424, 10.813192980570118, 9.793693917911154, 8.845156696707463, 7.785306302929629, 6.884439120842338, 5.922348848644775, 5.020488854529149, 3.96872622873574, 3.1478115336650987, 4.084760202938039, 4.944279169892606, 5.894770790831766, 6.911197963249036, 7.792908367655324, 8.765741352871109, 9.779570663584538, 10.707892508248715, 11.725509545504922, 12.770634792658171, 10.720573920908672, 9.77941878108578, 8.82265918925719, 7.856493469093536, 6.857653036286205, 5.844839391942791, 4.919618749309255, 3.967952025812014, 2.952289037029635, 2.1252143554895104, 3.063914509473594, 3.944493859952747, 4.879555165156233, 5.870317014800731, 6.844615788062494, 7.783248823588617, 8.733107556793362, 9.785803150387558, 10.800111394421755, 11.751940724093588, 9.815092146150224, 8.877678081129927, 7.854820735228147, 6.926211715723497, 5.886952204174122, 4.861510245251415, 3.913029467798843, 2.921920933396621, 1.9363705832383409, 1.066538635844695, 2.0048556967202193, 2.9561289941320994, 3.920032275228225, 4.882580715583975, 5.913031021700052, 6.95706135066893, 7.885579977109062, 8.820698052915771, 9.81427720607731, 10.82285988999939, 9.082885688002966, 8.133924068139441, 7.105619012109798, 6.076563182969675, 5.067060736713579, 4.001252566798375, 2.9559550697742623, 2.015251670492388, 0.9442444731139681, 0.0, 0.9496399693881673, 2.0167592937195495, 3.051377429735899, 4.087705811438999, 5.1080411692098, 6.1360451926129915, 7.097754614820728, 8.02661796459793, 9.045027598824817, 10.111148541534039, 9.794656351304326, 8.73291666082517, 7.783678764390144, 6.8582918467463045, 5.819462385712448, 4.791882598537161, 3.8547071447460977, 2.8861773835492768, 1.8761978307491538, 1.0489413879279155, 1.9216048619736004, 2.874006263231244, 3.8645252347694052, 4.793484183104529, 5.7712945530296595, 6.750532075727465, 7.677865076612456, 8.734226283309296, 9.78722285404904, 10.744999410565002, 10.738687094099374, 9.731751996911143, 8.857498845302747, 7.8591271890126055, 6.790234123363339, 5.7621960406162795, 4.916917820961038, 3.9066687724141413, 2.896703106690815, 1.990695295849878, 2.943068947941075, 3.872176571012125, 4.85434441218369, 5.807153351579313, 6.723774476458698, 7.677953623715414, 8.640118721247514, 9.681189334357986, 10.689581627914379, 11.622136549481452, 11.71449367024808, 10.714034670831545, 9.797023950191251, 8.787146447225343, 7.815589972242735, 6.788346867553275, 5.893209267851916, 4.888050756347306, 3.859622871576135, 2.9321693324605356, 3.88877038582005, 4.8041059769777394, 5.758010583130322, 6.810839058693809, 7.7971329445738045, 8.732012808771188, 9.661599408871826, 10.600554733223849, 11.65160894838103, 12.559222779355997, 12.678537989882937, 11.615353192573199, 10.621652509413762, 9.693614918235737, 8.746350600741767, 7.80709660685432, 6.8708155096236805, 5.843557320238965, 4.878986684219459, 3.970383832510616, 4.900813577531822, 5.826468809595735, 6.721896844366066, 7.6612954494237995, 8.690606618330776, 9.678283844789899, 10.606001427485463, 11.671920044222881, 12.64002378202602, 13.526661382841079, 13.60725483409979, 12.602115758837598, 11.649097011522148, 10.667971935022955, 9.710083052429079, 8.735515652135502, 7.762371720911395, 6.820236927306978, 5.846799245243152, 4.91614430982367, 5.869404574344454, 6.794578033081497, 7.707604087722032, 8.595015946238115, 9.582002538471043, 10.577828976174906, 11.517212411476818, 12.591471039826338, 13.61616420666907, 14.507349908024107, 14.6098550567253, 13.575182522901692, 12.631062856818767, 11.644493738636363, 10.643825699721491, 9.79927963304437, 8.733185295091765, 7.741642494404202, 6.775763042520251, 5.876852671575041, 6.8447943754037395, 7.823620546823707, 8.731624672252195, 9.666673270305159, 10.53923576776118, 11.490044314456286, 12.474357715178808, 13.48597979130586, 14.450924639159847, 15.42897679272309, 15.449557194488643, 14.521604082543, 13.611406727663034, 12.622127713074915, 11.67920688433187, 10.609459116650646, 9.676795982119573, 8.731350194347668, 7.7265270481502535, 6.898848352042996, 7.796143933701267, 8.800893243946687, 9.801308708401857, 10.720978735918065, 11.499897199567918, 12.449089464952568, 13.413156474917205, 14.339970303430547, 15.314223615855575, 16.341640981039074, 16.44321417505699, 15.491167665465353, 14.670132411233634, 13.655434606553092, 12.617118453849722, 11.607366898473018, 10.624057948941992, 9.720740905505203, 8.751724189461918, 7.901196239845454, 8.845611384767363, 9.728430506091412, 10.71550783761592, 11.758249960881217, 12.531042686593167, 13.520170293497294, 14.435286536751933, 15.34557303866065, 16.300556025977254, 17.27012538122482, 17.442556638171947, 16.431435235039203, 15.593668000393402, 14.62554850063455, 13.552295328432622, 12.53763320986065, 11.58898148626097, 10.67448706803194, 9.738695899429086, 8.832320698469502, 9.859774824636373, 10.709004965468752, 11.651693563571543, 12.666478484277775, 13.466985567486732, 14.491250511546045, 15.474958018484713, 16.39646984091285, 17.279235802386037, 18.225805242919993, 18.383711975567497, 17.442186594721935, 16.44467766773173, 15.4484828384928, 14.52312134250777, 13.590384829289473, 12.628516875164244, 11.654887590186382, 10.80282479888071, 9.89443638581112, 10.261840749235462, 11.071730047077594, 11.774701888881232, 12.84261279305233, 13.769412240704586, 14.725049022915083, 15.678559755118114, 16.683660790634484, 17.62756656992361, 18.633050637043194, 18.421731697262974, 17.508042337494498, 16.45556569055765, 15.411507158752235, 14.510726705867452, 13.578402904160981, 12.788762747347882, 11.876472787854592, 11.1327426686607, 10.211285903879045, 9.258424892684776, 10.088156638383676, 10.837404036350703, 11.83530213691666, 12.833447251037446, 13.697712817576141, 14.677337130613308, 15.636293762846828, 16.638684347432058, 17.625133345593238, 17.42139702720988, 16.475576198112435, 15.497669322680515, 14.438841255845109, 13.506979263932083, 12.50359926659722, 11.784052011166795, 10.913126171877915, 10.138351933750236, 9.212212167915895, 8.304860257398097, 9.044502966557591, 9.878863099476881, 10.89128400621029, 11.84383182176706, 12.724776455128296, 13.67825502104085, 14.708148896725941, 15.667603857013965, 16.605550145471504, 16.51676655014764, 15.544356863761651, 14.516472898229278, 13.56945237360381, 12.525620080082922, 11.530384926987939, 10.710195459631015, 9.850693191247139, 9.076305734632902, 8.145884302410972, 7.289011358201329, 8.032542029411449, 8.947381336347329, 9.908038570891364, 10.804289352525391, 11.771910752465176, 12.723073113505626, 13.778776224568619, 14.740358549253099, 15.566769241592965, 15.606336535448314, 14.60877316605173, 13.585384963422591, 12.60276647593518, 11.57773745752067, 10.603252729810873, 9.736627965122329, 8.854628605456902, 8.076689595832933, 7.109934063360896, 6.274266649467767, 7.073404370613692, 7.934551064292254, 8.872441245047863, 9.824665147317875, 10.81644063595924, 11.83566761993327, 12.776519949376665, 13.721086865711024, 14.611536317865113, 14.616580814923125, 13.60489582918795, 12.644243864522034, 11.666623601340811, 10.718328419236794, 9.660936828548698, 8.801708144976214, 7.884028972677968, 7.046396165865899, 6.0370154058779635, 5.254783276220229, 6.086420515880084, 7.006576245345803, 7.897024590922883, 8.88236995346474, 9.84789827910563, 10.83716361819187, 11.777684134096535, 12.73351116601767, 13.68469787714327], [13.672159034313466, 12.713183779040536, 11.733846765603325, 10.793210341128004, 9.764975701496956, 8.813281008547762, 7.8221155216531315, 6.913569141716097, 5.973912004516997, 5.125323519167577, 4.07818808631251, 5.0569189893175, 5.982204945554001, 6.924021584188241, 7.770396393837812, 8.758874013958708, 9.7162594929323, 10.740632090160576, 11.741558217769432, 12.76829581411954, 12.713936543330565, 11.762832949958286, 10.743333887299322, 9.79479666609563, 8.734946272317798, 7.834079090230506, 6.871988818032943, 5.9701288239173165, 4.918366198123907, 4.0885159219797504, 3.1351202335498716, 3.9946392005044387, 4.945130821443598, 5.961557993860868, 6.843268398267157, 7.816101383482943, 8.829930694196372, 9.75825253886055, 10.775869576116754, 11.820994823270004, 11.670213890296838, 10.729058750473946, 9.772299158645357, 8.806133438481703, 7.807293005674373, 6.794479361330958, 5.869258718697423, 4.917591995200182, 3.9019290064178023, 3.074854324877678, 2.114274540085427, 2.9948538905645794, 3.929915195768066, 4.920677045412565, 5.894975818674327, 6.833608854200451, 7.783467587405196, 8.836163180999392, 9.850471425033588, 10.80230075470542, 10.764732115538392, 9.827318050518095, 8.804460704616314, 7.875851685111664, 6.836592173562289, 5.811150214639582, 4.8626694371870105, 3.8715609027847884, 2.8860105526265083, 2.0161786052328625, 1.0552157273320522, 2.006489024743932, 2.9703923058400576, 3.932940746195808, 4.963391052311884, 6.007421381280762, 6.935940007720895, 7.871058083527604, 8.864637236689143, 9.873219920611223, 10.032525657391133, 9.083564037527609, 8.055258981497966, 7.0262031523578425, 6.016700706101746, 4.950892536186543, 3.9055950391624297, 2.9648916398805554, 1.8938844425021353, 0.9496399693881673, 0.0, 1.0671193243313821, 2.1017374603477315, 3.1380658420508323, 4.158401199821633, 5.186405223224824, 6.14811464543256, 7.076977995209762, 8.09538762943665, 9.161508572145872, 10.744296320692493, 9.682556630213337, 8.733318733778312, 7.807931816134471, 6.769102355100615, 5.741522567925328, 4.804347114134264, 3.8358173529374433, 2.8258378001373208, 1.9181117842409063, 0.9719648925854332, 1.9243662938430768, 2.914885265381238, 3.8438442137163618, 4.821654583641492, 5.8008921063392975, 6.728225107224288, 7.784586313921128, 8.837582884660872, 9.80032616408144, 11.671637971360761, 10.68139196629931, 9.807138814690914, 8.808767158400773, 7.739874092751506, 6.711836010004446, 5.866557790349203, 4.843120349024227, 3.833154683300901, 2.859865692162869, 1.9934289785529078, 2.922536601623958, 3.904704442795523, 4.857513382191145, 5.7741345070705306, 6.728313654327247, 7.690478751859346, 8.731549364969817, 9.73994165852621, 10.672496580093283, 12.637546370275063, 11.663674640219712, 10.746663919579419, 9.73678641661351, 8.765229941630903, 7.737986836941442, 6.842849237240082, 5.824502332957392, 4.766340612998839, 3.8013397287735264, 2.9547346835270267, 3.8544660075895725, 4.808370613742156, 5.861199089305641, 6.847492975185637, 7.7823728393830205, 8.711959439483659, 9.650914763835681, 10.701968978992863, 11.609582809967828, 13.606965510911937, 12.564993161961366, 11.57129247880193, 10.643254887623904, 9.695990570129934, 8.707613481782545, 7.771332384551906, 6.74407419516719, 5.779503559147685, 4.839554228823607, 3.9667778752387983, 4.876828840207567, 5.7722568749778995, 6.711655480035633, 7.740966648942609, 8.728643875401733, 9.656361458097297, 10.722280074834714, 11.690383812637853, 12.57702141345291, 14.545045213672163, 13.551755728225766, 12.585926373671022, 11.604801297171827, 10.646912414577951, 9.636032527063726, 8.66288859583962, 7.720753802235204, 6.715969641556143, 5.785314706136661, 4.935368872051431, 5.860542330788474, 6.757964118333866, 7.645375976849949, 8.632362569082876, 9.628189006786739, 10.56757244208865, 11.641831070438169, 12.666524237280901, 13.557709938635938, 15.4217216243227, 14.512011885050565, 13.567892218967641, 12.581323100785237, 11.580655061870363, 10.670815723120473, 9.602355691404755, 8.610812890717192, 7.644933438833242, 6.746023067888032, 5.910758673110716, 6.889584844530684, 7.781984702864028, 8.717033300916993, 9.589595798373013, 10.540404345068119, 11.52471774579064, 12.536339821917693, 13.50128466977168, 14.479336823334922, 16.347606390043826, 15.458433444691874, 14.548236089811908, 13.55895707522379, 12.54837728064486, 11.478629512963636, 10.545966378432563, 9.600520590660658, 8.595697444463244, 7.768018748355987, 6.862108231408244, 7.866857541653664, 8.85166873901369, 9.7713387665299, 10.550257230179751, 11.4994494955644, 12.463516505529038, 13.39033033404238, 14.364583646467407, 15.392001011650908, 17.341263370612175, 16.427997027614225, 15.606961773382508, 14.551597638320487, 13.486288850162712, 12.476537294786008, 11.493228345254982, 10.589911301818194, 9.62089458577491, 8.770366636158444, 7.911575682474339, 8.794394803798388, 9.781472135322897, 10.824214258588194, 11.581402717205, 12.570530324109127, 13.485646567363766, 14.395933069272482, 15.350916056589085, 16.32048541183665, 18.253641723028537, 17.368264597188073, 16.462838396706392, 15.49471889694754, 14.421465724745612, 13.40680360617364, 12.45815188257396, 11.543657464344932, 10.607866295742078, 9.70149109478249, 8.971027604190414, 9.774969263175729, 10.71765786127852, 11.732442781984751, 12.517345598098565, 13.541610542157878, 14.525318049096546, 15.446829871524685, 16.329595832997867, 17.276165273531824, 18.376918995680654, 17.435393614835093, 16.388932333815823, 15.392737504576894, 14.556835562416168, 13.560789304492403, 12.81318669802662, 11.886995363074842, 11.23547956203238, 10.266801739238955, 9.942346655806972, 10.802937882262423, 11.74175126455308, 12.756463265583886, 13.481511694943702, 14.467518495270268, 15.481671205895926, 16.409095137137154, 17.35300091642628, 18.331273424109774, 17.472091727874805, 16.558402368106336, 15.505925721169485, 14.46186718936407, 13.561086736479286, 12.628762934772816, 11.839122777959712, 10.926832818466425, 10.183102699272531, 9.261645934490879, 10.16258420281962, 11.037796607771845, 11.78704400573887, 12.784942106304827, 13.783087220425614, 14.647352786964309, 15.626977100001476, 16.585933732234995, 17.588324316820223, 18.517935424450663, 16.471757057821712, 15.525936228724268, 14.54802935329235, 13.489201286456943, 12.557339294543917, 11.553959297209055, 10.834412041778627, 9.963486202489747, 9.188711964362067, 8.262572198527728, 9.209019567532941, 9.99414293594576, 10.828503068865048, 11.840923975598457, 12.793471791155227, 13.674416424516464, 14.627894990429017, 15.657788866114108, 16.61724382640213, 17.49345527973158, 15.655370144600747, 14.594716894373486, 13.566832928841112, 12.619812404215644, 11.575980110694756, 10.580744957599773, 9.760555490242847, 8.901053221858971, 8.126665765244734, 7.196244333022804, 8.193170668336172, 8.982181998799618, 9.897021305735496, 10.857678540279531, 11.753929321913558, 12.721550721853344, 13.672713082893793, 14.728416193956786, 15.689998518641266, 16.51640921098113, 14.678167743428174, 13.659133196663564, 12.635744994034425, 11.653126506547014, 10.628097488132504, 9.653612760422707, 8.786987995734162, 7.904988636068735, 7.127049626444766, 6.160294093972729, 7.178425959602609, 8.02304434000186, 8.884191033680422, 9.822081214436032, 10.774305116706042, 11.766080605347408, 12.785307589321437, 13.726159918764832, 14.670726835099192, 15.561176287253279, 13.66694084553496, 12.655255859799784, 11.694603895133868, 10.716983631952646, 9.768688449848629, 8.711296859160532, 7.8520681755880455, 6.934389003289801, 6.096756196477732, 5.087375436489796, 6.158942586355071, 7.036060485268251, 7.956216214733971, 8.846664560311051, 9.832009922852908, 10.797538248493797, 11.786803587580037, 12.727324103484701, 13.683151135405836, 14.634337846531436], [12.711354121748197, 13.670329377021128, 12.800966089934708, 11.85923631807274, 10.831001678441693, 9.875887867394834, 8.848544053776855, 7.833659949049224, 6.8940028118501235, 5.869576534104518, 4.822441101249451, 3.9897996649861187, 4.9150856212226195, 5.856902259856859, 6.70327706950643, 7.6917546896273254, 8.649140168600917, 9.673512765829193, 10.67443889343805, 11.701176489788157, 11.799655843198947, 12.755637377018395, 11.810453211630703, 10.861915990427011, 9.802065596649179, 8.901198414561888, 7.926277142850474, 6.954195362805146, 5.902432737011737, 4.8327689369166915, 3.879373248486812, 2.9275198761730565, 3.8780114971122166, 4.894438669529487, 5.776149073935775, 6.74898205915156, 7.76281136986499, 8.691133214529168, 9.708750251785371, 10.753875498938621, 10.780630783957614, 11.721785923780505, 10.839418482976738, 9.873252762813085, 8.874412330005754, 7.86159868566234, 6.923547043514954, 5.9016585340880106, 4.885995545305632, 3.8787408247746376, 2.8585275550223677, 1.9277345662331973, 2.862795871436684, 3.8535577210811827, 4.827856494342945, 5.766489529869069, 6.716348263073814, 7.769043856668009, 8.783352100702205, 9.735181430374038, 9.828730310225994, 10.766144375246292, 9.871580028947696, 8.942971009443045, 7.903711497893671, 6.878269538970964, 5.929788761518393, 4.938680227116171, 3.9531298769578904, 3.0079960761339573, 2.0075450304370506, 0.9393697004125499, 1.9032729815086755, 2.865821421864426, 3.896271727980502, 4.940302056949379, 5.868820683389512, 6.803938759196221, 7.79751791235776, 8.80610059627984, 9.148132067406463, 10.097093687269988, 9.122378305829349, 8.093322476689226, 7.083820030433128, 6.018011860517925, 4.972714363493812, 4.0320109642119375, 2.9610037668335174, 2.0167592937195495, 1.0671193243313821, 0.0, 1.0346181360163493, 2.07094651771945, 3.0912818754902505, 4.119285898893442, 5.080995321101178, 6.00985867087838, 7.028268305105267, 8.094389247814489, 9.787232553352622, 10.64373055847243, 9.694492662037405, 8.769105744393565, 7.730276283359708, 6.702696496184421, 5.765521042393357, 4.7969912811965365, 3.787011728396414, 2.8594779167666986, 1.9133310251112254, 0.9609296238535818, 1.951448595391743, 2.880407543726867, 3.8582179136519974, 4.837455436349803, 5.7647884372347935, 6.8211496439316335, 7.874146214671377, 8.836889494091945, 10.708201301371266, 11.642565894558404, 10.768312742950007, 9.769941086659866, 8.7010480210106, 7.673009938263539, 6.827731718608296, 5.78448648155002, 4.774520815826693, 3.801231824688661, 2.9139228538711457, 1.9848152308000957, 2.966983071971661, 3.8940767122016506, 4.810697837081036, 5.764876984337752, 6.727042081869851, 7.7681126949803225, 8.776504988536715, 9.709059910103788, 11.674109700285568, 12.624848568478805, 11.707837847838512, 10.697960344872603, 9.726403869889996, 8.699160765200535, 7.804023165499175, 6.765868465483184, 5.707706745524631, 4.742705861299319, 3.8752285588452646, 2.9167446367657104, 3.8706492429182933, 4.897762419316146, 5.884056305196142, 6.818936169393526, 7.748522769494164, 8.687478093846186, 9.738532309003368, 10.646146139978333, 12.643528840922443, 13.522526738634584, 12.528826055475147, 11.600788464297121, 10.653524146803152, 9.648979614308336, 8.712698517077698, 7.685440327692982, 6.720869691673477, 5.780920361349399, 4.887271750557036, 3.939107469383705, 4.8345355041540365, 5.77393410921177, 6.803245278118746, 7.790922504577869, 8.718640087273434, 9.75884340484522, 10.726947142648358, 11.613584743463415, 13.581608543682668, 14.497996139557237, 13.527292506196812, 12.546167429697618, 11.588278547103743, 10.577398659589518, 9.604254728365412, 8.662119934760995, 7.657335774081935, 6.726680838662453, 5.85379068149638, 4.928617222759337, 5.820242747510003, 6.707654606026086, 7.694641198259013, 8.690467635962877, 9.629851071264788, 10.704109699614307, 11.72880286645704, 12.594273268646443, 14.484000253498836, 15.453378017576355, 14.50925835149343, 13.522689233311027, 12.522021194396155, 11.612181855646265, 10.543721823930547, 9.552179023242983, 8.586299571359033, 7.687389200413825, 6.829180482555666, 5.986990923764845, 6.844263332040165, 7.7793119300931295, 8.65187442754915, 9.602682974244255, 10.586996374966777, 11.598618451093829, 12.563563298947816, 13.541615452511058, 15.40988501921996, 16.337838131165604, 15.489602222337698, 14.50032320774958, 13.489743413170652, 12.419995645489427, 11.487332510958355, 10.54188672318645, 9.537063576989036, 8.709384880881778, 7.780530040853193, 7.041959962514129, 7.913947368189826, 8.833617395706035, 9.612535859355887, 10.561728124740537, 11.525795134705174, 12.452608963218516, 13.426862275643543, 14.454279640827044, 16.40354199978831, 17.307401714087955, 16.548327905908298, 15.49296377084628, 14.427654982688503, 13.4179034273118, 12.434594477780774, 11.531277434343984, 10.5622607183007, 9.711732768684236, 8.829997491919288, 7.969497224658853, 8.956574556183362, 9.899330741327258, 10.643681346381136, 11.632808953285263, 12.547925196539902, 13.458211698448618, 14.413194685765221, 15.382764041012788, 17.31592035220467, 17.310616853525502, 16.29003451023533, 15.321915010476477, 14.460542252159934, 13.546421599589845, 12.737950956996233, 11.800276560897903, 11.293476375981397, 10.642857227308284, 9.889449413635363, 8.950071684036192, 9.892760282138985, 10.907545202845217, 11.579624227274701, 12.603889171334014, 13.587596678272682, 14.50910850070082, 15.391874462174004, 16.338443902707958, 17.309799671349275, 16.368274290503713, 15.321813009484442, 14.325618180245513, 13.489716238084787, 12.493669980161021, 11.74606737369524, 10.81987603874346, 10.229347476529773, 11.011054754175897, 10.86076846525192, 9.978040303122887, 10.916853685413546, 11.931565686444351, 12.543790324119838, 13.529797124446404, 14.543949835072063, 15.471373766313288, 16.415279545602413, 17.39355205328591, 16.404972403543425, 15.491283043774953, 14.438806396838103, 13.394747865032688, 12.493967412147905, 11.561643610441434, 10.772003453628333, 9.859713494135043, 9.169302661121804, 10.00589894942782, 10.90683721775656, 10.961613711816803, 11.854151537944073, 12.893980290746242, 13.495229218059864, 14.487802365401269, 15.467426678438436, 16.426383310671955, 17.434379219466535, 17.450816100119283, 15.404637733490333, 14.458816904392886, 13.480910028960968, 12.422081962125562, 11.490219970212536, 10.486839972877673, 9.767292717447246, 8.896366878158366, 8.17491192621134, 9.00682521346467, 9.953272582469882, 10.886024004580062, 11.748593876198175, 12.761014782931584, 13.76104872353579, 14.677395072598939, 15.630873638511492, 16.660767514196586, 17.40155936965709, 16.4263359554002, 14.588250820269366, 13.527597570042104, 12.499713604509731, 11.552693079884262, 10.508860786363375, 9.513625633268392, 8.693436165911466, 7.83393389752759, 7.1128657270940066, 7.940497347959745, 8.937423683273114, 9.87406306743392, 10.817112113068623, 11.777769347612658, 12.748893721129722, 13.72452936993582, 14.675691730976268, 15.731394842039261, 16.484201476679672, 15.53824812882404, 13.611048419096791, 12.592013872332183, 11.568625669703044, 10.586007182215633, 9.560978163801122, 8.586493436091326, 7.71986867140278, 6.837869311737354, 6.059930302113385, 6.90454710890967, 7.92267897453955, 8.914925408636163, 9.804281841013548, 10.781142512663823, 11.786971960698644, 12.806387924748563, 13.825614908722592, 14.766467238165987, 15.551505146347917, 14.585506941973039, 12.599821521203577, 11.5881365354684, 10.627484570802485, 9.649864307621263, 8.701569125517246, 7.64417753482915, 6.784948851256664, 5.8672696789584196, 5.029636872146351, 5.831628451426737, 6.903195601292012, 7.9279415539025555, 8.876307022067097, 9.805725858538842, 10.873763940759824, 11.863564225438534, 12.852829564524773, 13.794443427816084, 14.640296733386428, 13.658668501251196], [11.796416936397193, 12.755392191670124, 13.733495669892761, 12.872105694913989, 11.843871055282941, 10.888757244236082, 9.861413430618104, 8.846529325890474, 7.9068721886913735, 6.882445910945768, 5.8353104780907, 5.002669041827368, 4.000148435871617, 4.941965074505857, 5.788339884155427, 6.776817504276323, 7.734202983249914, 8.75857558047819, 9.759501708087047, 10.786239304437153, 10.884718657847944, 11.840700191667393, 12.742982791588759, 11.89653412644336, 10.836683732665527, 9.935816550578236, 8.939146519691723, 7.967064739646396, 6.915302113852987, 5.8456383137579415, 4.892242625328062, 3.940389253014306, 2.963074311761215, 3.979501484178485, 4.861211888584772, 5.834044873800558, 6.847874184513988, 7.776196029178166, 8.79381306643437, 9.838938313587619, 9.865693598606612, 10.806848738429503, 11.763608330258094, 10.907870898829433, 9.909030466022102, 8.896216821678689, 7.936416420356204, 6.914527910929261, 5.898864922146882, 4.8916102016158876, 3.871396931863617, 2.940603943074447, 1.947858686085682, 2.9386205357301804, 3.9129193089919423, 4.8515523445180655, 5.801411077722811, 6.854106671317006, 7.868414915351202, 8.820244245023035, 8.913793124874992, 9.85120718989529, 10.87406453579707, 9.977589145459394, 8.93832963391002, 7.912887674987313, 6.964406897534741, 5.973298363132519, 4.987748012974239, 4.020865452975206, 3.0204144072782997, 1.9522390772537992, 0.9883357961576734, 1.9508842365134238, 2.9813345426295, 4.025364871598377, 4.953883498038509, 5.889001573845219, 6.882580727006758, 7.891163410928838, 8.113513931390115, 9.06247555125364, 10.090780607283282, 9.127940612705574, 8.118438166449478, 7.052629996534274, 6.007332499510161, 5.066629100228287, 3.9956219028498667, 3.051377429735899, 2.1017374603477315, 1.0346181360163493, 0.0, 1.0363283817031008, 2.056663739473901, 3.0846677628770927, 4.046377185084829, 4.9752405348620306, 5.993650169088918, 7.05977111179814, 8.854418535227724, 9.91615822570688, 10.729110798053751, 9.803723880409912, 8.764894419376056, 7.7373146322007695, 6.800139178409706, 5.831609417212886, 4.821629864412763, 3.894096052783048, 2.9479491611275748, 1.9955477598699312, 1.026772968723161, 1.955731917058285, 2.9335422869834153, 3.9127798096812203, 4.840112810566211, 5.896474017263051, 6.94133219654648, 7.904075475967048, 9.783525674702684, 10.797697723658503, 11.758880200250621, 10.804559222676213, 9.735666157026946, 8.707628074279889, 7.862349854624647, 6.819104617566369, 5.8091389518430425, 4.83584996070501, 3.948540989887495, 3.019433366816445, 2.0924767396777195, 2.969401085533069, 3.8860222104124533, 4.840201357669169, 5.802366455201269, 6.84343706831174, 7.851829361868131, 8.784384283435205, 10.749434073616985, 11.74989307303352, 12.741191277402057, 11.73257848088895, 10.761022005906343, 9.733778901216885, 8.838641301515526, 7.800486601499534, 6.742324881540981, 5.777323997315668, 4.9098466948616135, 3.9513627727820597, 3.1256377103905617, 3.973086792647565, 4.95938067852756, 5.894260542724943, 6.823847142825581, 7.762802467177604, 8.813856682334785, 9.72147051330975, 11.71885321425386, 12.77048986748142, 13.563444191491497, 12.635406600313472, 11.688142282819502, 10.683597750324687, 9.747316653094048, 8.720058463709332, 7.7554878276898265, 6.815538497365749, 5.9218898865733856, 4.9737256054000545, 4.089523971626305, 5.001154945313122, 5.885254483611885, 6.872931710071009, 7.800649292766573, 8.834167778176637, 9.802271515979776, 10.688909116794832, 12.656932917014085, 13.662071992276276, 14.561910642213164, 13.580785565713969, 12.622896683120093, 11.612016795605868, 10.638872864381762, 9.696738070777345, 8.691953910098285, 7.761298974678803, 6.88840881751273, 5.963235358775687, 5.075231214982272, 5.934875442127438, 6.879986387737208, 7.835049414535416, 8.774432849837329, 9.828455689351701, 10.839168259783964, 11.66959764197786, 13.628687175637998, 14.663359709461606, 15.543876487509783, 14.55730736932738, 13.556639330412505, 12.646799991662615, 11.578339959946897, 10.586797159259334, 9.620917707375384, 8.722007336430174, 7.863798618572015, 7.021609059781193, 6.099251799512434, 7.006532766194482, 7.837219617027346, 8.788028163722451, 9.738482443065342, 10.750104519192394, 11.715049367046381, 12.68630237465022, 14.561371087318525, 15.489324199264168, 16.50721707373911, 15.534941343765931, 14.524361549187002, 13.454613781505778, 12.521950646974705, 11.5765048592028, 10.571681713005386, 9.744003016898128, 8.815148176869542, 8.076578098530478, 7.168935835662095, 8.060838231807388, 8.797881048834084, 9.747073314218733, 10.677281202803739, 11.604095031317081, 12.578348343742109, 13.60576570892561, 15.555028067886875, 16.45888778218652, 16.415772793975375, 15.396187638783557, 14.498424628899285, 13.57752628638166, 12.787937308964208, 11.839085538073638, 11.596878854317051, 10.746350904700586, 9.864615627935637, 9.004115360675202, 8.215177107372613, 9.12655157742861, 9.829026535859333, 10.81815414276346, 11.699411264638467, 12.609697766547184, 13.564680753863787, 14.534250109111353, 16.467406420303238, 16.395679668174502, 15.375097324884328, 14.406977825125475, 13.545605066808932, 12.631484414238843, 11.82301377164523, 10.8853393755469, 11.924357643942695, 11.677475363324632, 10.924067549651712, 9.984689820052543, 9.151362833328236, 10.166147754034467, 10.764969416752898, 11.78923436081221, 12.753667214095918, 13.660594568799386, 14.543360530272569, 15.489929970806523, 16.39486248599827, 15.453337105152709, 14.40687582413344, 13.410680994894511, 12.574779052733785, 11.57873279481002, 10.831130188344236, 9.904938853392458, 10.86022874449107, 11.828906567284495, 11.89538660126827, 11.012658439139237, 10.175456236602797, 11.190168237633603, 11.729135513598035, 12.7151423139246, 13.72929502455026, 14.622859834411853, 15.566765613700978, 16.545038121384472, 15.490035218192423, 14.57634585842395, 13.523869211487101, 12.479810679681686, 11.579030226796903, 10.646706425090432, 9.857066268277329, 8.944776308784041, 9.948264278601547, 10.919851485865323, 11.870813016326363, 11.996231847833155, 11.112754089133325, 12.152582841935494, 12.68057440753806, 13.673147554879465, 14.652771867916632, 15.611728500150152, 16.5858652875651, 16.53587891476828, 14.48970054813933, 13.543879719041884, 12.565972843609966, 11.50714477677456, 10.575282784861534, 9.571902787526671, 8.852355532096244, 7.981429692807364, 8.953873543691083, 9.920777749902173, 10.917248381039684, 11.876093159358, 12.071295026007148, 13.083715932740557, 13.695377182345148, 14.64608391732731, 15.652070788331264, 16.63090426548061, 16.48662218430609, 15.5113987700492, 13.673313634918363, 12.612660384691102, 11.584776419158729, 10.63775589453326, 9.593923601012373, 8.59868844791739, 7.778498980560465, 6.918996712176588, 7.924028452175319, 8.85444988439725, 9.901399481842915, 10.864132222211857, 11.829981489909873, 12.790638724453908, 13.761763097970972, 14.73739874677707, 15.688561107817518, 16.617848153438608, 15.569264291328672, 14.623310943473038, 12.696111233745789, 11.67707668698118, 10.653688484352042, 9.671069996864631, 8.64604097845012, 7.6715562507403225, 6.804931486051778, 5.9229321263863515, 6.924381329059951, 7.917416485750919, 8.935548351380799, 9.927794785477413, 10.817151217854798, 11.794011889505073, 12.799841337539894, 13.819257301589813, 14.838484285563842, 15.581134877331275, 14.636567960996915, 13.670569756622037, 11.684884335852574, 10.673199350117399, 9.712547385451483, 8.734927122270262, 7.786631940166244, 6.729240349478147, 5.870011665905662, 4.952332493607417, 5.894087899092918, 6.844497828267986, 7.91606497813326, 8.940810930743805, 9.889176398908347, 10.818595235380092, 11.886633317601074, 12.876433602279782, 13.865698941366022, 14.726973007774138, 13.725359548035424, 12.743731315900193], [10.817685900218962, 11.776661155491892, 12.751325731263645, 13.742200872736227, 12.79023689981621, 11.83512308876935, 10.807779275151372, 9.792895170423742, 8.853238033224642, 7.828811755479037, 6.7816763226239685, 5.949034886360637, 4.946514280404886, 3.978229011527207, 4.809608847977195, 5.7980864680980915, 6.755471947071682, 7.779844544299959, 8.780770671908815, 9.807508268258921, 9.902548719218828, 10.858530253038277, 11.760812852959642, 12.709350074163334, 11.79289240803423, 10.892025225946938, 9.885512364224992, 8.913430584179665, 7.861667958386255, 6.79200415829121, 5.83860846986133, 4.886755097547574, 3.9094401562944836, 3.015765421199834, 3.88248085240654, 4.855313837622326, 5.869143148335756, 6.7974649929999345, 7.811643127805252, 8.856768374958502, 8.883523659977495, 9.824678799800386, 10.781438391628978, 11.747604111792631, 10.865239141390806, 9.85242549704739, 8.882782264889473, 7.860893755462529, 6.84523076668015, 5.837976046149156, 4.8177627763968855, 3.8869697876077156, 2.894224530618951, 1.9598894995519487, 2.9341882728137105, 3.872821308339834, 4.822680041544579, 5.8753756351387745, 6.886244976722085, 7.838074306393919, 7.931623186245873, 8.869037251266171, 9.891894597167951, 10.820503616672601, 9.89453830927872, 8.869096350356013, 7.920615572903442, 6.92950703850122, 5.94395668834294, 4.967231297508476, 3.966780251811569, 2.898604921787068, 1.9347016406909425, 0.972153200335192, 1.999164604000383, 3.0431949329692607, 3.9717135594093924, 4.906831635216101, 5.90041078837764, 6.90899347229972, 7.077185549687014, 8.026147169550539, 9.054452225580182, 10.083508054720305, 9.154766548152576, 8.088958378237374, 7.0436608812132615, 6.102957481931387, 5.031950284552967, 4.087705811438999, 3.1380658420508323, 2.07094651771945, 1.0363283817031008, 0.0, 1.0203353577708003, 2.0483393811739923, 3.0100488033817285, 3.9389121531589306, 4.957321787385817, 6.02344273009504, 7.818090153524624, 8.87982984400378, 9.829067740438806, 10.745793555661447, 9.70696409462759, 8.679384307452302, 7.742208853661239, 6.773679092464419, 5.763699539664296, 4.836165728034581, 3.8900188363791077, 2.937617435121464, 1.9470984635833029, 1.0181395152481787, 1.9461969727882824, 2.9254344954860874, 3.8527674963710785, 4.9091287030679185, 5.905003814843379, 6.867747094263947, 8.762120896319672, 9.776292945275491, 10.73747542186761, 11.744469899775185, 10.677735832278481, 9.649697749531422, 8.80441952987618, 7.761174292817903, 6.751208627094576, 5.777919635956544, 4.890610665139028, 3.961503042067978, 3.012802234537862, 2.0318086837229625, 2.898676896217321, 3.852856043474037, 4.815021141006136, 5.856091754116608, 6.864484047673, 7.797038969240074, 9.762088759421854, 10.758575619195893, 11.719786499019046, 12.674648156140485, 11.703091681157877, 10.675848576468418, 9.78071097676706, 8.742556276751067, 7.6843945567925145, 6.719393672567202, 5.8519163701131465, 4.893432448033592, 4.045963205250704, 3.0354943908374583, 3.9720353643324273, 4.90691522852981, 5.836501828630448, 6.7754571529824705, 7.826511368139652, 8.734125199114619, 10.731507900058729, 11.779172413643792, 12.75693617926286, 13.577476275565006, 12.630211958071037, 11.625667425576221, 10.689386328345583, 9.662128138960867, 8.697557502941361, 7.7576081726172825, 6.8639595618249185, 5.9157952806515866, 5.0029611485607495, 4.063562543503016, 4.897909169416753, 5.885586395875876, 6.81330397857144, 7.846822463981503, 8.814926201784642, 9.7015638025997, 11.669587602818954, 12.674726678081145, 13.64543031144157, 14.522855240965503, 13.564966358371628, 12.554086470857403, 11.580942539633297, 10.63880774602888, 9.63402358534982, 8.703368649930336, 7.808025274463774, 6.882851815726731, 5.943891580647864, 4.997283040317332, 5.892641073542076, 6.847704100340284, 7.787087535642195, 8.841110375156568, 9.851822945588832, 10.682252327782729, 12.641341861442866, 13.676014395266474, 14.6201340613494, 15.499377044578914, 14.49870900566404, 13.58886966691415, 12.520409635198432, 11.528866834510868, 10.562987382626918, 9.664077011681709, 8.78341507552306, 7.914127935343577, 6.967912165178026, 6.0689403643843765, 6.849874302832213, 7.800682849527318, 8.751137128870209, 9.762759204997261, 10.727704052851248, 11.698957060455088, 13.574025773123392, 14.501978885069034, 15.519871759543978, 15.4507634960835, 14.537115220561963, 13.657809169778792, 12.81911501841026, 12.518574534454334, 11.513751388256921, 10.686072692149663, 9.734764633820587, 8.969096974092862, 8.037596201327688, 7.123245829997283, 7.81053573463895, 8.7597280000236, 9.689935888608606, 10.616749717121948, 11.591003029546975, 12.618420394730476, 14.567682753691741, 15.471542467991387, 15.437041757797141, 14.417456602605323, 13.519693592721051, 12.598795250203427, 11.871853051587841, 12.756668526255522, 12.538948529568586, 11.68842057995212, 10.784232084886682, 9.896634236237587, 9.083837473038205, 8.188959175618505, 8.8416812216642, 9.830808828568326, 10.712065950443334, 11.62235245235205, 12.577335439668653, 13.54690479491622, 15.480061106108103, 15.416948631996268, 14.396366288706094, 13.428246788947241, 12.566874030630698, 11.65275337806061, 10.906929514268864, 11.802922363728785, 12.84194063212458, 12.619545038576167, 11.843684006602757, 10.877208695614927, 10.020023198993828, 9.237425129618462, 9.777624102557764, 10.801889046617077, 11.766321899900785, 12.673249254604253, 13.556015216077435, 14.50258465661139, 15.416131449820035, 14.474606068974476, 13.428144787955206, 12.431949958716277, 11.596048016555551, 10.600001758631786, 9.867394125365589, 10.822521841574343, 11.777811732672955, 12.746489555466379, 12.815003058219315, 11.905177314701621, 11.044116602268389, 10.261445613217596, 10.741790199402901, 11.727796999729467, 12.741949710355126, 13.63551452021672, 14.579420299505845, 15.55769280718934, 14.51130418201419, 13.597614822245717, 12.545138175308868, 11.501079643503452, 10.600299190618669, 9.667975388912199, 8.89333020529868, 9.862359296965925, 10.865847266783431, 11.837434474047207, 12.788396004508247, 12.888750723395539, 11.981414454798916, 11.336325860155567, 11.693229093342927, 12.685802240684332, 13.665426553721499, 14.624383185955018, 15.598519973369966, 15.557147878590046, 13.510969511961097, 12.56514868286365, 11.587241807431733, 10.528413740596326, 9.5965517486833, 8.593171751348438, 7.888619469117594, 8.899012680989248, 9.871456531872967, 10.838360738084058, 11.834831369221568, 12.793676147539884, 12.939955391672738, 12.280343990861937, 12.708031868150014, 13.658738603132177, 14.66472547413613, 15.643558951285474, 15.507891148127856, 14.532667733870966, 12.69458259874013, 11.633929348512869, 10.606045382980495, 9.659024858355027, 8.615192564834139, 7.619957411739157, 6.814762917581814, 7.836579700358471, 8.841611440357203, 9.772032872579134, 10.8189824700248, 11.781715210393742, 12.776347334443141, 13.288494230603561, 13.747574337391683, 14.611604305795296, 15.562766666835746, 15.639117117260373, 14.590533255150438, 13.644579907294805, 11.717380197567557, 10.698345650802949, 9.67495744817381, 8.6923389606864, 7.667309942271888, 6.692825214562091, 5.841195423073128, 6.86929797091962, 7.8707471735932195, 8.863782330284188, 9.881914195914067, 10.874160630010682, 11.763517062388066, 12.740377734038342, 13.746207182073162, 14.765623146123081, 15.543256170596438, 14.602403841153043, 13.657836924818683, 12.691838720443805, 10.706153299674343, 9.694468313939167, 8.733816349273251, 7.75619608609203, 6.8079009039880125, 5.750509313299915, 4.906275602927012, 5.898698338140686, 6.8404537436261865, 7.790863672801255, 8.862430822666528, 9.887176775277073, 10.835542243441616, 11.76496107991336, 12.832999162134342, 13.82279944681305, 14.80175284352522, 13.744803069145021, 12.746628511857192, 11.765000279721962], [9.876312994177129, 10.835288249450059, 11.730990373492844, 12.721865514965426, 13.683791882651745, 12.855458446540151, 11.828114632922173, 10.813230528194543, 9.873573390995443, 8.849147113249838, 7.802011680394769, 6.936653582587262, 5.870590068475755, 4.862197635539945, 3.8741557773346607, 4.862633397455557, 5.820018876429148, 6.844391473657424, 7.839397765866981, 8.866135362217088, 8.882213361448027, 9.838194895267476, 10.740477495188841, 11.689014716392533, 12.653762453472586, 11.912360583717739, 10.905847721995793, 9.933765941950465, 8.882003316157057, 7.812339516062011, 6.858943827632131, 5.907090455318375, 4.916161217629843, 3.899734045212573, 2.947027781764006, 3.9198607669797916, 4.933690077693222, 5.8620119223574, 6.791307770034452, 7.8364330171877015, 7.863188302206694, 8.804343442029586, 9.761103033858177, 10.72726875402183, 11.726109186829161, 10.87276085481819, 9.903117622660274, 8.88122911323333, 7.865566124450951, 6.858311403919957, 5.838098134167686, 4.907305145378516, 3.914559888389751, 2.973033975432938, 1.9987352021711762, 2.9373682376973, 3.880412112141251, 4.914204311238529, 5.865909618951285, 6.817738948623119, 6.911287828475074, 7.848701893495371, 8.87155923939715, 9.8001682589018, 10.839427770451175, 9.889431708126814, 8.940950930674243, 7.949842396272021, 6.964292046113741, 5.987566655279276, 4.98711560958237, 3.9189402795578685, 2.955036998461743, 1.9924885581059923, 0.9788292462295826, 2.0228595751984604, 2.951378201638592, 3.886496277445301, 4.880075430606841, 5.888658114528921, 6.056850191916213, 7.005811811779738, 8.03411686780938, 9.063172696949504, 10.0726751432056, 9.109293736008174, 8.063996238984062, 7.123292839702188, 6.052285642323768, 5.1080411692098, 4.158401199821633, 3.0912818754902505, 2.056663739473901, 1.0203353577708003, 0.0, 1.0280040234031917, 1.9897134456109282, 2.9185767953881303, 3.9369864296150174, 5.003107372324239, 6.797754795753823, 7.85949448623298, 8.808732382668005, 9.734119300311844, 10.592496564322023, 9.564916777146736, 8.627741323355673, 7.659211562158853, 6.64923200935873, 5.721698197729015, 4.775551306073542, 3.8231499048158977, 2.8326309332777364, 1.9036719849426125, 0.9258616150174821, 1.905099137715287, 2.832432138600278, 3.8887933452971177, 4.884668457072579, 5.8474117364931475, 7.741785538548871, 8.75595758750469, 9.717140064096808, 10.724134542004384, 11.563268301972913, 10.535230219225856, 9.689951999570614, 8.646706762512338, 7.63674109678901, 6.663452105650978, 5.776143134833462, 4.847035511762412, 3.898334704232295, 2.90811549215178, 1.8783415384465203, 2.832520685703236, 3.794685783235336, 4.835756396345808, 5.844148689902199, 6.776703611469273, 8.741753401651053, 9.738240261425092, 10.699451141248245, 11.709328644214153, 12.58862415085231, 11.561381046162852, 10.666243446461493, 9.628088746445503, 8.56992702648695, 7.604926142261636, 6.7374488398075805, 5.778964917728026, 4.931495674945137, 3.9118011992662756, 2.951700006561627, 3.8865798707590096, 4.816166470859648, 5.755121795211671, 6.806176010368852, 7.713789841343818, 9.711172542287928, 10.758837055872991, 11.73660082149206, 12.664638412670085, 13.51574442776547, 12.511199895270655, 11.574918798040017, 10.5476606086553, 9.583089972635795, 8.643140642311717, 7.7494920315193525, 6.784930421143392, 5.846283585610662, 4.906884980552928, 3.877573811645952, 4.865251038105075, 5.7929686208006395, 6.826487106210703, 7.794590844013841, 8.6812284448289, 10.649252245048153, 11.654391320310344, 12.62509495367077, 13.606220030169965, 14.450498828066062, 13.439618940551837, 12.46647500932773, 11.524340215723313, 10.519556055044255, 9.588901119624772, 8.651347711513687, 7.7261742527766435, 6.787214017697776, 5.8406054773672444, 4.872305715771275, 5.827368742569483, 6.766752177871394, 7.820775017385767, 8.831487587818032, 9.661916970011928, 11.621006503672065, 12.655679037495673, 13.5997987035786, 14.633964884891238, 14.641231813167519, 13.678389774684204, 13.405942104892867, 12.414399304205304, 11.448519852321354, 10.549609481376145, 9.626737512572971, 8.75745037239349, 7.811234602227938, 6.895250507503219, 5.829538945061413, 6.780347491756517, 7.730801771099408, 8.74242384722646, 9.707368695080447, 10.678621702684287, 12.553690415352591, 13.481643527298234, 14.499536401773177, 14.515310425440966, 13.60166214991943, 12.72235609913626, 13.52275111111244, 13.40410700414877, 12.399283857951357, 11.557956448739022, 10.578087070870499, 9.812419411142775, 8.830753991621187, 7.825144236247922, 6.79020037686815, 7.739392642252798, 8.669600530837805, 9.596414359351147, 10.570667671776175, 11.598085036959676, 13.54734739592094, 14.451207110220587, 14.501588687154607, 13.482003531962789, 12.584240522078519, 11.663342179560894, 12.575489144290021, 13.47282226188819, 13.424480999263022, 12.56030433654148, 11.627554521936593, 10.7399566732875, 9.876995263331704, 8.890857581869145, 7.821345863893399, 8.810473470797524, 9.691730592672533, 10.60201709458125, 11.557000081897852, 12.526569437145419, 14.459725748337302, 14.481495561353734, 13.46091321806356, 12.492793718304707, 11.631420959988166, 10.717300307418077, 11.610565606971043, 12.519076099361452, 13.558094367757247, 13.491428795165525, 12.687006443652669, 11.72053113266484, 10.796007219590345, 9.781222298884114, 8.757288744786964, 9.781553688846277, 10.745986542129984, 11.652913896833452, 12.535679858306635, 13.482249298840589, 14.480678379177501, 13.539152998331941, 12.492691717312672, 11.496496888073743, 10.660594945913019, 9.664548687989253, 10.571030218067769, 11.53867557720701, 12.493965468305623, 13.462643291099047, 13.658325495269226, 12.738892731636492, 11.716165193455454, 10.648254289284356, 9.7214548416321, 10.707461641958666, 11.721614352584325, 12.61517916244592, 13.559084941735044, 14.53735744941854, 13.575851111371655, 12.662161751603183, 11.609685104666333, 10.565626572860918, 9.664846119976135, 8.732522318269666, 9.596966298000861, 10.578513032598593, 11.5820010024161, 12.58708624808903, 13.602425626353424, 13.68428329164518, 12.653463045985983, 11.671038849692913, 10.672893735572126, 11.665466882913531, 12.645091195950698, 13.604047828184218, 14.578184615599165, 14.621694807947511, 12.575516441318562, 11.629695612221116, 10.651788736789198, 9.592960669953792, 8.661098678040766, 7.657718680705904, 8.592255561819774, 9.615166416621916, 10.587610267505635, 11.588012512125879, 12.648860991066746, 13.607705769385062, 13.612003982859806, 12.615056980399283, 11.687696510379213, 12.638403245361376, 13.64439011636533, 14.623223593514673, 14.572438077485321, 13.597214663228431, 11.759129528097596, 10.698476277870334, 9.670592312337961, 8.723571787712492, 7.6797394941916055, 6.6845043410966225, 7.628792539426993, 8.65060932220365, 9.655641062202381, 10.586062494424311, 11.633012091869977, 12.59574483223892, 13.655076656367214, 13.623207220140907, 12.727238979620882, 13.591268948024496, 14.542431309064945, 14.703664046617838, 13.655080184507904, 12.70912683665227, 10.781927126925023, 9.762892580160415, 8.739504377531276, 7.756885890043865, 6.731856871629353, 5.757372143919556, 6.725164047085865, 7.780742995858743, 8.782192198532343, 9.789757091460011, 10.861353350103954, 11.854749573280099, 12.783852420158867, 13.760713091809142, 13.706863184828398, 14.546739064530431, 14.607803099953903, 13.666950770510509, 12.72238385417615, 11.75638564980127, 9.770700229031808, 8.759015243296632, 7.798363278630717, 6.820743015449495, 5.872447833345478, 4.815056242657381, 5.79024422693975, 6.810143363079809, 7.75189876856531, 8.797304256740517, 9.868871406605791, 10.893617359216336, 11.855877601212416, 12.785296437684162, 13.853334519905143, 14.716354429648586, 13.78141748575442, 12.72446771137422, 11.80525560581536, 10.829547209079427], [8.851082751645034, 9.810058006917965, 10.705760130960748, 11.69663527243333, 12.658561640119649, 13.596968755767556, 12.856118656325364, 11.841234551597735, 10.901577414398634, 9.87715113665303, 8.830015703797962, 7.948772546634377, 6.88270903252287, 5.87431659958706, 4.886274741381775, 4.060594464523295, 4.888221138473298, 5.912593735701574, 6.814167523334886, 7.840905119684993, 7.856983118915932, 8.81296465273538, 9.715247252656745, 10.663784473860437, 11.62853221094049, 12.6177668374503, 11.933851745398986, 10.961769965353657, 9.910007339560249, 8.840343539465202, 7.886947851035323, 6.935094478721568, 5.928280181676958, 4.911853009259688, 3.9591467458111205, 3.054713659974659, 3.9627734609839944, 4.8910953056481725, 5.766077527502357, 6.811202774655606, 6.837958059674599, 7.77911319949749, 8.73587279132608, 9.702038511489734, 10.700878944297065, 11.71369258864048, 10.931121646063467, 9.909233136636523, 8.893570147854144, 7.886315427323149, 6.866102157570879, 5.935309168781709, 4.942563911792943, 3.9851529394800527, 3.010854166218291, 2.072221130692167, 2.88983919446421, 3.9236313935614877, 4.84067937641919, 5.792508706091024, 5.886057585942978, 6.823471650963275, 7.846328996865054, 8.774938016369704, 9.81419752791908, 10.839639486841786, 9.968954954077436, 8.977846419675213, 7.992296069516932, 7.015570678682468, 6.015119632985561, 4.946944302961061, 3.983041021864935, 3.0204925815091843, 2.006833269632774, 1.0611448621057875, 1.9608052839615508, 2.89592335976826, 3.854845188074745, 4.863427871996825, 5.028846168513022, 5.977807788376547, 7.006112844406188, 8.035168673546313, 9.044671119802409, 10.110479289717613, 9.092000262387254, 8.15129686310538, 7.08028966572696, 6.136045192612992, 5.186405223224825, 4.119285898893443, 3.084667762877093, 2.0483393811739923, 1.0280040234031917, 0.0, 0.9617094222077364, 1.8905727719849383, 2.9089824062118255, 3.9751033489210474, 5.769750772350632, 6.831490462829788, 7.780728359264813, 8.706115276908653, 9.74494473794251, 10.587179153595471, 9.650003699804408, 8.681473938607587, 7.671494385807463, 6.743960574177748, 5.797813682522275, 4.845412281264632, 3.8548933097264704, 2.9259343613913464, 1.948123991466216, 0.9688864687684109, 1.896219469653402, 2.8889977583925517, 3.8566644336693874, 4.819407713089955, 6.71378151514568, 7.727953564101499, 8.689136040693617, 9.696130518601192, 10.7157164755934, 11.55749259567459, 10.712214376019348, 9.66896913896107, 8.659003473237744, 7.685714482099711, 6.798405511282195, 5.869297888211145, 4.920597080681029, 3.9303778686005133, 2.900603914895254, 2.036100275487178, 2.85847311428846, 3.864859695792447, 4.873251989348838, 5.748838042852796, 7.713887833034576, 8.710236238021901, 9.671447117845053, 10.681324620810962, 11.65288109579357, 12.583643422611587, 11.688505822910228, 10.650351122894236, 9.592189402935682, 8.62718851871037, 7.7597112162563135, 6.801227294176759, 5.953758051393871, 4.934063575715009, 3.9739623830103605, 3.0901594605429517, 3.9150473790568014, 4.854002703408824, 5.905056918566006, 6.685924272727341, 8.683306973671451, 9.7308330324698, 10.708596798088868, 11.636634389266893, 12.583641724292601, 13.533462271719388, 12.59718117448875, 11.569922985104034, 10.605352349084528, 9.66540301876045, 8.771754407968086, 7.807192797592126, 6.868545962059396, 5.929147357001662, 4.899836188094686, 4.118580882528192, 4.973197053614451, 5.925368014407857, 6.893471752210995, 7.653362876212423, 9.621386676431676, 10.626525751693867, 11.597229385054293, 12.578354461553488, 13.536243344147364, 14.46188131700057, 13.488737385776464, 12.546602592172047, 11.541818431492988, 10.611163496073505, 9.67361008796242, 8.748436629225377, 7.80947639414651, 6.862867853815978, 5.894568092220009, 5.0806985869926, 5.975892398674553, 6.919655925582921, 7.930368496015184, 8.634051401395451, 10.593140935055589, 11.627813468879197, 12.571933134962123, 13.606099316274761, 14.087170674347043, 14.690508738731317, 14.4282044813416, 13.436661680654037, 12.470782228770087, 11.571871857824878, 10.648999889021704, 9.779712748842224, 8.833496978676672, 7.917512883951953, 6.8518013215101465, 6.143408232133767, 6.939941991902566, 7.950365547366483, 8.915310395220471, 9.65075613406781, 11.536648760254229, 12.464601872199871, 13.482494746674815, 13.918812821976337, 13.047601011098955, 13.734475063183373, 14.534870075159555, 14.426369380597503, 13.42154623440009, 12.580218825187755, 11.600349447319232, 10.834681787591508, 9.85301636806992, 8.847406612696656, 7.812462753316884, 7.119756512035924, 7.878740751640963, 8.805554580154306, 9.779807892579333, 10.581043381861313, 12.530305740822579, 13.434165455122224, 13.850866070764353, 12.88550592849816, 12.030179383258043, 12.675461143608008, 13.587608108337136, 14.484941225935305, 14.446743375711755, 13.582566712990213, 12.649816898385327, 11.762219049736233, 10.899257639780437, 9.913119958317878, 8.843608240342133, 8.19083734058065, 8.900870813475692, 9.811157315384408, 10.766140302701011, 11.583922700854842, 13.529648203937535, 13.819340657127425, 12.810190601673305, 11.896296114840078, 11.07735982116769, 11.72941927146519, 12.622684571018159, 13.531195063408568, 14.570213331804363, 14.513691171614258, 13.709268820101402, 12.742793509113573, 11.81826959603908, 10.803484675332848, 9.779551121235698, 9.198475812788164, 9.955126762933142, 10.86205411763661, 11.744820079109793, 12.639498874822596, 13.734603902333921, 12.808589297444692, 11.807236278203234, 10.899999284609114, 10.106533807092543, 10.676667652036366, 11.583149182114884, 12.550794541254126, 13.506084432352738, 14.474762255146162, 14.68058787171796, 13.761155108085227, 12.73842756990419, 11.670516665733091, 10.743717218080835, 10.124383765900554, 10.971889999402507, 11.824319383249078, 12.768225162538203, 13.694607025400547, 12.675359269990738, 11.774366776202019, 10.812585111770886, 9.969128969396289, 9.080605432559246, 9.74464128231678, 10.609085262047977, 11.590631996645708, 12.594119966463214, 13.599205212136145, 14.614544590400538, 14.706545668093913, 13.675725422434716, 12.693301226141648, 11.695156112020861, 11.151719971239494, 11.973112623907312, 12.871686411036734, 13.787324836402323, 13.721202966566594, 11.675024599937645, 10.729203770840199, 9.854688743893751, 8.996463066489163, 8.076857990623877, 8.669837644753018, 9.60437452586689, 10.627285380669031, 11.59972923155275, 12.600131476172994, 13.66097995511386, 14.619824733432175, 14.634266359308539, 13.637319356848018, 12.709958886827948, 12.124656333687339, 12.972411544321943, 13.89086217636719, 13.568531583929198, 12.696722821847514, 10.787473750944727, 9.797984436489417, 8.86954117366086, 7.92252064903539, 7.095498806774716, 7.696623305143737, 8.640911503474106, 9.662728286250763, 10.667760026249494, 11.598181458471425, 12.64513105591709, 13.607863796286033, 14.667195620414327, 14.645469596589642, 13.749501356069617, 13.077522036350459, 13.927593451857167, 13.689870138278266, 12.641286276168332, 11.695332928312698, 9.774615846339387, 8.819002184573097, 7.876703005205292, 6.91849972496527, 6.031906224733837, 6.769491107966671, 7.7372830111329804, 8.792861959905858, 9.794311162579458, 10.801876055507126, 11.87347231415107, 12.866868537327214, 13.808004164999705, 14.78486483664998, 14.729125561277133, 14.032992152856394, 13.59151745473748, 12.650665125294084, 11.706098208959725, 10.740100004584846, 8.763388948446172, 7.751703962710995, 6.866565540674866, 5.917529319534256, 5.0704089004132165, 5.827175206704495, 6.802363190986865, 7.822262327126924, 8.764017732612425, 9.809423220787632, 10.880990370652906, 11.90573632326345, 12.880029346053254, 13.809448182525, 14.615697670072702, 13.69112418711649, 12.756187243222323, 11.699237468842124, 10.780025363283265, 9.813261563863003], [7.889373329437297, 8.848348584710227, 9.744050708753011, 10.734925850225594, 11.696852217911912, 12.63525933355982, 13.662603147177798, 12.707186270440593, 11.767529133241492, 10.743102855495888, 9.69596742264082, 8.75453992140343, 7.688476407291922, 6.680083974356112, 5.6920421161508274, 4.866361839292347, 3.926511716265562, 4.950884313493837, 5.85245810112715, 6.879195697477257, 6.895273696708196, 7.851255230527643, 8.753537830449009, 9.7020750516527, 10.666822788732754, 11.656057415242564, 12.719486119740827, 11.830444188484826, 10.778681562691416, 9.70629525830806, 8.752899569878181, 7.79285749617303, 6.73404755644601, 5.71762038402874, 4.764914120580173, 3.8604810347437106, 3.001064038776258, 3.9293858834404363, 4.80436810529462, 5.84949335244787, 5.876248637466863, 6.817403777289754, 7.7741633691183445, 8.740329089281998, 9.739169522089329, 10.751983166432744, 11.783185768930466, 10.813089346112854, 9.797426357330474, 8.79017163679948, 7.76995836704721, 6.83916537825804, 5.786895148686799, 4.790920314249105, 3.8166215409873425, 2.877988505461219, 1.9281297722564736, 2.9619219713537515, 3.878969954211454, 4.830799283883287, 4.924348163735242, 5.8617622287555395, 6.884619574657319, 7.813228594161969, 8.852488105711345, 9.877930064634052, 10.826410842086624, 9.93955584188295, 8.954005491724669, 7.977280100890204, 6.976829055193297, 5.908653725168797, 4.944750444072671, 3.9822020037169206, 2.968542691840511, 1.9276144881939463, 0.9990958617538146, 1.9342139375605236, 2.893135765867009, 3.901718449789089, 4.067136746305286, 5.01609836616881, 6.044403422198452, 7.073459251338576, 8.082961697594673, 9.148769867509877, 10.05370968459499, 9.113006285313116, 8.041999087934697, 7.097754614820728, 6.14811464543256, 5.080995321101178, 4.046377185084829, 3.0100488033817285, 1.9897134456109282, 0.9617094222077364, 0.0, 0.928863349777202, 1.9472729840040892, 3.013393926713311, 4.808041350142895, 5.869781040622052, 6.819018937057077, 7.744405854700917, 8.783235315734773, 9.810815102910059, 10.611713122012144, 9.643183360815323, 8.6332038080152, 7.705669996385485, 6.759523104730011, 5.807121703472368, 4.816602731934207, 3.8876437835990827, 2.9098334136739523, 1.9305958909761474, 1.0202403728921445, 1.9272883361848154, 2.894955011461651, 3.8576982908822193, 5.752072092937944, 6.766244141893763, 7.727426618485881, 8.734421096393456, 9.754007053385664, 10.781128544989178, 11.673923798227085, 10.630678561168805, 9.620712895445479, 8.647423904307447, 7.760114933489931, 6.831007310418881, 5.882306502888766, 4.8920872908082496, 3.8623133371029903, 2.9978096976949145, 1.9824940175272023, 2.9031502735847106, 3.911542567141102, 4.787128620645061, 6.75217841082684, 7.748526815814165, 8.709737695637317, 9.719615198603226, 10.691171673585833, 11.741166703201701, 12.650215245117964, 11.61206054510197, 10.553898825143417, 9.588897940918104, 8.72142063846405, 7.762936716384496, 6.915467473601608, 5.895772997922745, 4.935671805218097, 3.9686548823961822, 3.0390682822955437, 3.96519581069835, 4.962104266578588, 5.724214850519606, 7.721597551463714, 8.769123610262064, 9.746887375881132, 10.674924967059157, 11.621932302084865, 12.62647683457968, 13.558890596696482, 12.531632407311767, 11.567061771292261, 10.627112440968183, 9.733463830175822, 8.768902219799863, 7.830255384267132, 6.890856779209399, 5.861545610302422, 4.997076304381423, 4.097217956853194, 5.036561121697382, 5.950519100223577, 6.691653454004688, 8.65967725422394, 9.664816329486131, 10.635519962846557, 11.616645039345752, 12.574533921939627, 13.570115298873679, 14.450446807984196, 13.50831201437978, 12.50352785370072, 11.572872918281238, 10.635319510170156, 9.710146051433114, 8.771185816354246, 7.824577276023715, 6.856277514427745, 5.959194008845831, 5.099913301913295, 6.030849032872446, 6.987415844027766, 7.672341979187716, 9.631431512847854, 10.666104046671462, 11.610223712754387, 12.644389894067025, 13.50827656923204, 14.481904438868163, 15.389913903549333, 14.39837110286177, 13.43249165097782, 12.53358128003261, 11.61070931122944, 10.741422171049958, 9.795206400884407, 8.87922230615969, 7.813510743717883, 7.021903653986998, 6.063962895141309, 7.061558654656008, 8.026503502509996, 8.689046711860076, 10.574939338046493, 11.502892449992135, 12.520785324467079, 12.9571033997686, 13.804718562392821, 14.540242437952426, 15.340637449928606, 15.388078802805236, 14.383255656607822, 13.541928247395491, 12.562058869526968, 11.796391209799243, 10.81472579027766, 9.809116034904394, 8.77417217552462, 7.998251933889154, 7.002761654879706, 7.929575483393048, 8.903828795818075, 9.619333959653577, 11.568596318614842, 12.472456032914488, 12.889156648556616, 11.923796506290424, 12.78729693455191, 13.48122851837706, 14.393375483106187, 15.290708600704358, 15.408452797919487, 14.544276135197949, 13.611526320593063, 12.723928471943967, 11.860967061988177, 10.874829380525616, 9.80531766254987, 8.977490991297739, 8.024891716714434, 8.93517821862315, 9.890161205939753, 10.622213278647106, 12.567938781729799, 12.857631234919689, 11.84848117946557, 10.934586692632342, 11.834477372461556, 12.535186646234243, 13.42845194578721, 14.33696243817762, 15.375980706573415, 15.475400593821995, 14.670978242309138, 13.704502931321308, 12.779979018246816, 11.765194097540585, 10.741260543443435, 9.985129463505253, 9.079147666171885, 9.986075020875353, 10.868840982348535, 11.67778945261486, 12.772894480126185, 11.846879875236956, 10.845526855995498, 9.938289862401378, 10.86365135838641, 11.482435026805419, 12.388916556883935, 13.356561916023178, 14.31185180712179, 15.280529629915215, 15.642297293925695, 14.722864530292963, 13.700136992111926, 12.632226087940827, 11.705426640288572, 10.911037416617642, 10.09591090264125, 10.94834028648782, 11.892246065776945, 12.73289760319281, 11.713649847783001, 10.812657353994283, 9.85087568956315, 9.007419547188553, 9.886372807328298, 10.550408657085832, 11.414852636817027, 12.396399371414761, 13.399887341232267, 14.404972586905195, 15.42031196516959, 15.668255090301649, 14.637434844642453, 13.655010648349384, 12.656865534228597, 11.938373621956583, 11.097133527146056, 11.995707314275476, 12.911345739641066, 12.759493544358858, 10.713315177729909, 9.767494348632463, 8.892979321686015, 8.034753644281427, 8.88262536539293, 9.475605019522071, 10.410141900635942, 11.433052755438084, 12.405496606321803, 13.405898850942046, 14.466747329882912, 15.425592108201228, 15.595975781516275, 14.599028779055754, 13.671668309035685, 12.911309984404427, 12.096432447560687, 13.014883079605932, 12.606822161721462, 11.735013399639778, 9.825764328736991, 8.83627501428168, 7.907831751453124, 6.960811226827654, 7.901266181543768, 8.50239067991279, 9.446678878243159, 10.468495661019816, 11.473527401018547, 12.403948833240477, 13.450898430686143, 14.413631171055085, 15.47296299518338, 15.607179018797378, 14.711210778277353, 13.864175687067547, 13.05161435509591, 12.72816071607053, 11.679576853960596, 10.733623506104962, 8.81290642413165, 7.857292762365361, 6.914993582997556, 5.9567903027575335, 6.837673599502889, 7.575258482735723, 8.543050385902033, 9.59862933467491, 10.600078537348509, 11.607643430276177, 12.67923968892012, 13.672635912096265, 14.613771539768756, 15.590632211419031, 14.5962834417181, 13.649035016503772, 12.629808032529743, 11.688955703086348, 10.744388786751989, 9.77839058237711, 7.801679526238436, 6.789994540503259, 5.90485611846713, 4.95581989732652, 5.876176275182268, 6.632942581473547, 7.608130565755917, 8.628029701895976, 9.569785107381476, 10.615190595556683, 11.686757745421957, 12.711503698032502, 13.685796720822305, 14.61521555729405, 13.653988247864966, 12.729414764908753, 11.794477821014587, 10.737528046634388, 9.818315941075527, 8.851552141655267], [6.960509979660095, 7.919485234933026, 8.81518735897581, 9.806062500448391, 10.76798886813471, 11.706395983782617, 12.733739797400595, 13.636049620217795, 12.696392483018695, 11.67196620527309, 10.624830772418022, 9.68340327118063, 8.617339757069123, 7.6089473241333145, 6.62090546592803, 5.79522518906955, 4.855375066042764, 4.121086341405099, 4.923594751349948, 5.950332347700055, 5.966410346930994, 6.922391880750442, 7.824674480671807, 8.773211701875498, 9.737959438955551, 10.727194065465362, 11.790622769963624, 12.759307538262028, 11.707544912468618, 10.635158608085263, 9.681762919655384, 8.721720845950234, 7.662910906223212, 6.646483733805942, 5.693777470357375, 4.789344384520913, 3.92992738855346, 3.0907615049408186, 3.8755047555174187, 4.920630002670668, 4.947385287689661, 5.888540427512552, 6.845300019341143, 7.811465739504796, 8.810306172312126, 9.823119816655542, 10.854322419153263, 11.741952695890058, 10.726289707107679, 9.719034986576684, 8.698821716824414, 7.768028728035243, 6.715758498464002, 5.719783664026307, 4.745484890764545, 3.8068518552384214, 2.8569931220336757, 2.07735965991555, 2.950106604434252, 3.9019359341060857, 3.99548481395804, 4.932898878978337, 5.955756224880116, 6.8843652443847665, 7.923624755934141, 8.949066714856848, 9.89754749230942, 10.868419191660152, 9.882868841501871, 8.906143450667408, 7.9056924049705, 6.837517074946, 5.873613793849874, 4.911065353494123, 3.897406041617713, 2.8564778379711484, 1.9279592115310167, 1.0496516261223223, 1.9642724160898068, 2.972855100011887, 3.138273396528084, 4.087235016391609, 5.1155400724212505, 6.144595901561374, 7.15409834781747, 8.219906517732674, 9.265204014756787, 10.041869635090318, 8.970862437711899, 8.02661796459793, 7.076977995209763, 6.009858670878381, 4.975240534862031, 3.9389121531589306, 2.9185767953881303, 1.8905727719849383, 0.928863349777202, 0.0, 1.0184096342268871, 2.084530576936109, 3.8791780003656933, 4.9409176908448496, 5.8901555872798745, 6.815542504923714, 7.85437196595757, 8.881951753132856, 9.81912720692392, 10.572046710592524, 9.5620671577924, 8.634533346162685, 7.688386454507212, 6.735985053249569, 5.745466081711408, 4.816507133376284, 3.838696763451154, 2.859459240753349, 1.9491037226693466, 0.9984249864076133, 1.966091661684449, 2.928834941105017, 4.823208743160742, 5.837380792116561, 6.798563268708679, 7.8055577466162545, 8.825143703608461, 9.852265195211976, 10.793886756407332, 11.559541910946006, 10.54957624522268, 9.576287254084647, 8.688978283267131, 7.759870660196082, 6.811169852665967, 5.820950640585451, 4.791176686880192, 3.926673047472116, 2.9113573673044044, 1.9742869238075085, 2.9826792173639003, 3.858265270867858, 5.823315061049637, 6.819663466036963, 7.7808743458601155, 8.790751848826025, 9.762308323808632, 10.8123033534245, 11.770178203298212, 12.540923894879171, 11.482762174920618, 10.517761290695304, 9.65028398824125, 8.691800066161697, 7.844330823378809, 6.824636347699947, 5.864535154995298, 4.897518232173384, 3.9679316320727462, 3.0363324609211477, 4.033240916801386, 4.795351500742403, 6.792734201686511, 7.840260260484861, 8.81802402610393, 9.746061617281956, 10.693068952307664, 11.69761348480248, 12.633894582033118, 13.46049575708897, 12.495925121069464, 11.555975790745386, 10.662327179953023, 9.697765569577065, 8.759118734044334, 7.8197201289866, 6.790408960079624, 5.925939654158626, 5.026081306630396, 4.10769777192018, 5.021655750446375, 5.762790104227485, 7.7308139044467366, 8.735952979708928, 9.706656613069354, 10.68778168956855, 11.645670572162425, 12.641251949096478, 13.614395880320584, 14.437175364156982, 13.432391203477923, 12.50173626805844, 11.564182859947358, 10.639009401210316, 9.700049166131448, 8.753440625800916, 7.785140864204947, 6.888057358623033, 6.028776651690498, 5.101985683095244, 6.058552494250565, 6.743478629410514, 8.702568163070652, 9.73724069689426, 10.681360362977184, 11.715526544289823, 12.579413219454837, 13.55304108909096, 14.621501120806679, 15.327234452638972, 14.361355000755022, 13.462444629809813, 12.539572661006643, 11.67028552082716, 10.72406975066161, 9.808085655936889, 8.742374093495084, 7.9507670037642, 6.992826244918511, 6.132695304878807, 7.097640152732795, 7.760183362082873, 9.64607598826929, 10.574029100214933, 11.591921974689877, 12.630541732208073, 13.618982882702923, 14.509074764638905, 15.441737899169977, 16.31694215258244, 15.312119006385025, 14.470791597172694, 13.49092221930417, 12.725254559576445, 11.743589140054858, 10.737979384681594, 9.703035525301821, 8.927115283666357, 7.931625004656908, 7.165346701795617, 8.032993075840926, 8.690470609876375, 10.63973296883764, 11.543592683137286, 12.086984498748203, 12.852659856067627, 13.716160284329112, 14.410091868154263, 15.32223883288339, 16.21957195048156, 16.33731614769669, 15.473139484975151, 14.540389670370265, 13.65279182172117, 12.789830411765376, 11.803692730302817, 10.73418101232707, 9.906354341074941, 8.953755066491636, 8.170949437025719, 9.019325485962604, 9.693349928869903, 11.639075431952596, 11.928767885142486, 11.046309029657156, 11.863450042409545, 12.763340722238759, 13.464049996011445, 14.357315295564412, 15.265825787954823, 16.304844056350618, 16.404263943599197, 15.59984159208634, 14.63336628109851, 13.708842368024017, 12.694057447317785, 11.670123893220635, 10.913992813282455, 10.008011015949087, 9.221846239277921, 9.998005262371386, 10.748926102837657, 11.844031130348982, 10.918016525459754, 10.043354706187085, 10.86715321217858, 11.792514708163612, 12.411298376582621, 13.317779906661137, 14.28542526580038, 15.240715156898993, 16.209392979692417, 16.571160643702896, 15.651727880070164, 14.629000341889126, 13.561089437718028, 12.634289990065772, 11.839900766394845, 11.024774252418453, 10.184111504890389, 11.065173601196673, 11.804034253415608, 10.784786498005799, 9.88379400421708, 9.048703539754737, 9.936282896965755, 10.8152361571055, 11.479272006863035, 12.34371598659423, 13.325262721191963, 14.32875069100947, 15.333835936682398, 16.34917531494679, 16.59711844007885, 15.566298194419655, 14.583873998126585, 13.585728884005798, 12.867236971733785, 12.025996876923259, 11.231478532678045, 12.084273275060793, 11.830630194581655, 9.784451827952706, 8.83863099885526, 8.090807171877602, 8.96361699405863, 9.811488715170132, 10.404468369299273, 11.339005250413145, 12.361916105215286, 13.334359956099005, 14.334762200719249, 15.395610679660114, 16.354455457978432, 16.52483913129348, 15.527892128832955, 14.600531658812885, 13.84017333418163, 13.02529579733789, 12.2506542980085, 11.67795881194426, 10.806150049862575, 8.89690097895979, 7.907411664504478, 7.105659601644711, 7.889674576604856, 8.83012953132097, 9.431254029689992, 10.375542228020361, 11.397359010797018, 12.40239075079575, 13.33281218301768, 14.379761780463346, 15.342494520832288, 16.401826344960583, 15.618168670665478, 14.647044297148414, 13.674128909229175, 12.722966548188726, 11.799297366293327, 10.750713504183393, 9.80476015632776, 7.884043074354449, 6.92842941258816, 6.085195610908817, 6.885653652534735, 7.766536949280091, 8.504121832512926, 9.471913735679236, 10.527492684452115, 11.528941887125713, 12.53650678005338, 13.608103038697323, 14.601499261873467, 15.54263488954596, 14.673249539975718, 13.667420091940897, 12.72017166672657, 11.70094468275254, 10.760092353309146, 9.815525436974786, 8.849527232599907, 6.872816176461233, 5.8611311907260575, 5.0750581463783915, 5.884683247103721, 6.805039624959471, 7.56180593125075, 8.53699391553312, 9.55689305167318, 10.49864845715868, 11.544053945333888, 12.615621095199161, 13.640367047809706, 14.61466007059951, 13.758288836058515, 12.725124898087763, 11.800551415131551, 10.865614471237384, 9.808664696857187, 8.889452591298326, 7.922688791878064], [5.942100345433207, 6.901075600706138, 7.796777724748924, 8.787652866221505, 9.749579233907824, 10.687986349555729, 11.715330163173707, 12.730214267901339, 13.642993282318844, 12.61856700457324, 11.571431571718172, 10.630004070480782, 9.563940556369275, 8.555548123433466, 7.567506265228181, 6.72350104666412, 5.766115567690529, 4.906111244731916, 3.90518511712306, 4.931922713473167, 4.948000712704107, 5.9039822465235545, 6.80626484644492, 7.754802067648611, 8.719549804728665, 9.708784431238474, 10.772213135736736, 11.764208949530383, 12.654145711768768, 11.581759407385412, 10.628363718955534, 9.668321645250384, 8.609511705523364, 7.593084533106093, 6.640378269657526, 5.735945183821064, 4.8406678902012255, 3.9123460455370473, 2.857095121290531, 3.9022203684437806, 3.928975653462774, 4.870130793285665, 5.826890385114256, 6.793056105277909, 7.79189653808524, 8.804710182428654, 9.835912784926375, 10.857801294353319, 11.672890506407828, 10.665635785876834, 9.645422516124563, 8.714629527335394, 7.662359297764152, 6.666384463326458, 5.692085690064696, 4.753452654538572, 3.803593921333827, 2.946899939695789, 1.9316969702073645, 2.883526299879198, 2.9770751797311528, 3.91448924475145, 4.937346590653229, 5.865955610157879, 6.905215121707254, 7.930657080629961, 8.879137858082533, 9.870246392484756, 10.849362760363999, 9.872637369529535, 8.87218632383263, 7.804010993808129, 6.840107712712003, 5.877559272356253, 4.847108966240177, 3.8030786372712995, 2.8745600108311677, 1.939441935024459, 0.9458627818629196, 1.9544454657849997, 2.119863762301197, 3.0688253821647216, 4.097130438194363, 5.126186267334488, 6.135688713590584, 7.201496883505787, 8.2467943805299, 9.187497779811775, 9.989272071938785, 9.045027598824817, 8.09538762943665, 7.028268305105267, 5.993650169088918, 4.957321787385817, 3.9369864296150174, 2.9089824062118255, 1.9472729840040892, 1.0184096342268871, 0.0, 1.066120942709222, 2.860768366138806, 3.9225080566179624, 4.871745953052987, 5.797132870696827, 6.835962331730683, 7.86354211890597, 8.800717572697033, 9.769247333893855, 10.580476792019288, 9.652942980389573, 8.7067960887341, 7.754394687476457, 6.763875715938296, 5.834916767603172, 4.8571063976780415, 3.877868874980236, 2.9675133568962337, 2.000678598197305, 0.9476820274575619, 1.91042530687813, 3.804799108933855, 4.818971157889674, 5.780153634481792, 6.787148112389367, 7.806734069381575, 8.83385556098509, 9.775477122180446, 10.807888096694638, 11.567985879449568, 10.594696888311535, 9.70738791749402, 8.77828029442297, 7.829579486892855, 6.839360274812339, 5.80958632110708, 4.945082681699003, 3.9297670015312915, 2.9756297467103447, 1.9672374531539534, 2.839855636640971, 4.804905426822751, 5.801253831810076, 6.762464711633228, 7.772342214599137, 8.743898689581744, 9.793893719197612, 10.751768569071325, 11.789270080627803, 12.501171809147506, 11.536170924922192, 10.668693622468139, 9.710209700388585, 8.862740457605698, 7.843045981926835, 6.877214373184786, 5.9062172082766455, 4.9766306081760066, 4.037675283823984, 3.017799152591439, 3.776941866515516, 5.774324567459625, 6.821850626257974, 7.799614391877043, 8.727651983055068, 9.674659318080776, 10.679203850575592, 11.61548494780623, 12.642743137190946, 13.514334755296352, 12.574385424972274, 11.68073681417991, 10.710444787766551, 9.77179795223382, 8.832399347176088, 7.803088178269111, 6.934638630261887, 6.0347802827336565, 5.073031603053641, 4.006213986236428, 4.744380470000598, 6.71240427021985, 7.717543345482042, 8.688246978842468, 9.669372055341661, 10.627260937935537, 11.62284231486959, 12.595986246093696, 13.538121039698114, 14.450800837704811, 13.520145902285329, 12.576862078136847, 11.651688619399804, 10.712728384320936, 9.766119843990404, 8.797820082394434, 7.896756334726295, 7.037475627793758, 6.067319514228705, 5.043110730040618, 5.725068995183626, 7.684158528843764, 8.718831062667372, 9.662950728750296, 10.697116910062935, 11.56100358522795, 12.534631454864073, 13.60309148657979, 14.589930092139964, 15.37976463498191, 14.4808542640367, 13.552251879196131, 12.68296473901665, 11.7367489688511, 10.820764874126379, 9.755053311684572, 8.959465979867462, 8.00152522102177, 7.074338577610981, 6.109393729756993, 6.7417737278559855, 8.627666354042404, 9.555619465988046, 10.57351234046299, 11.612132097981188, 12.600573248476035, 13.490665130412017, 14.42332826494309, 15.368774052714995, 16.330528640611913, 15.483470815362182, 14.503601437493659, 13.737933777765935, 12.756268358244348, 11.750658602871082, 10.71571474349131, 9.935814259769618, 8.940323980760168, 8.018999965290151, 7.044746652865125, 7.6720609756494875, 9.621323334610754, 10.5251830489104, 11.578568043387133, 12.645438991459365, 13.617994876316947, 14.549679049987382, 15.370590231765508, 16.39774067455337, 17.355725781923578, 16.48581870316464, 15.553068888559753, 14.66547103991066, 13.802509629954866, 12.816371948492305, 11.746860230516559, 10.9150533171782, 9.962454042594896, 9.024602700520253, 8.031079062986803, 8.674940294643017, 10.62066579772571, 10.910358250915598, 11.77462440444385, 12.742743904202703, 13.654661646690776, 14.410650795311595, 15.303916094864562, 16.212426587254974, 17.251444855650767, 17.416943161788687, 16.61252081027583, 15.646045499288, 14.721521586213505, 13.706736665507274, 12.682803111410124, 11.922691789385715, 11.016709992052347, 10.05030345813832, 9.009758839395586, 9.730516468610773, 10.825621496122094, 9.899606891232866, 10.771670080973779, 11.758474136630598, 12.68383563261563, 13.357899175882771, 14.264380705961287, 15.23202606510053, 16.187315956199143, 17.155993778992567, 17.583839861892386, 16.66440709825965, 15.641679560078614, 14.573768655907516, 13.64696920825526, 12.848599742498104, 12.027109450197443, 11.012568723750787, 10.07692717822087, 10.785624619188724, 9.76637686377891, 8.865384369990192, 9.777018914541431, 10.827603821417773, 11.743512014700071, 12.425872806163184, 13.29031678589438, 14.271863520492113, 15.27535149030962, 16.280436735982548, 17.29577611424694, 17.609797658268338, 16.57897741260914, 15.596553216316073, 14.598408102195286, 13.875935947837046, 13.018892383771963, 12.059935751538443, 11.096026852084991, 10.812220560354767, 8.766042193725818, 7.820221364628372, 8.819122546664296, 9.854937918510647, 10.739764572764702, 11.351069168599423, 12.285606049713294, 13.308516904515436, 14.280960755399155, 15.281363000019399, 16.342211478960262, 17.301056257278578, 16.49189803411218, 15.570937249407027, 14.570903308802821, 13.608584977665407, 12.659738821497061, 11.644864717587133, 10.659549177717372, 9.787740415635687, 7.878491344732902, 6.88900203027759, 7.833974976431405, 8.780995501056873, 9.758405388915541, 10.377854828990142, 11.32214302732051, 12.343959810097168, 13.3489915500959, 14.27941298231783, 15.326362579763495, 16.289095320132436, 15.560416270982625, 14.59975903643859, 13.628634662921526, 12.655719275002287, 11.704556913961838, 10.78088773206644, 9.732303869956505, 8.786350522100872, 6.865633440127561, 5.910019778361272, 6.813510985695511, 7.796129473182923, 8.694812806874662, 9.450722631813075, 10.418514534979387, 11.474093483752267, 12.475542686425865, 13.483107579353533, 14.554703837997476, 15.542282980302405, 14.597272857249823, 13.65483990574883, 12.64901045771401, 11.701762032499682, 10.682535048525652, 9.741682719082258, 8.797115802747898, 7.8311175983730195, 5.854406542234345, 4.8427215564991695, 5.803373521165085, 6.795423748751487, 7.733315482554041, 8.5084067305509, 9.483594714833272, 10.503493850973332, 11.445249256458832, 12.490654744634039, 13.562221894499313, 14.586967847109857, 13.669298038303372, 12.739879201831627, 11.706715263860875, 10.782141780904665, 9.847204837010498, 8.790255062630301, 7.871042957071439, 6.904279157651176], [5.060294946693176, 6.016978274385002, 6.854469406620347, 7.845344548092928, 8.807270915779245, 9.745678031427152, 10.773021845045129, 11.78790594977276, 12.72756308697186, 13.651505722578435, 12.604370289723366, 11.662942788485974, 10.596879274374468, 9.588486841438659, 8.600444983233373, 7.756439764669313, 6.799054285695722, 5.9390499627371085, 4.938123835128253, 4.127552542021478, 4.0413891690466, 4.961673928394978, 5.8639565283163435, 6.812493749520034, 7.777241486600087, 8.766476113109897, 9.82990481760816, 10.821900631401807, 11.873663257195215, 12.614698125390607, 11.661302436960728, 10.701260363255578, 9.642450423528556, 8.626023251111286, 7.6733169876627185, 6.768883901826257, 5.873606608206418, 4.94528476354224, 3.890033839295724, 3.0687909341342325, 2.997666516012874, 3.9278224751570887, 4.884582066985679, 5.8507477871493325, 6.849588219956663, 7.862401864300078, 8.887970430877381, 9.909858940304325, 10.873958487718765, 11.698574503882028, 10.678361234129758, 9.747568245340588, 8.695298015769346, 7.699323181331651, 6.725024408069888, 5.786391372543765, 4.836532639339019, 3.9798386577009817, 2.964635688212557, 2.0307584238789658, 1.9793184710155884, 2.9167325360358856, 3.939589881937665, 4.868198901442315, 5.90745841299169, 6.932900371914396, 7.881381149366968, 8.87248968376919, 9.858040033927471, 10.834765424761937, 9.905125041837824, 8.836949711813324, 7.8730464307171975, 6.910497990361447, 5.880047684245371, 4.836017355276493, 3.9074987288363605, 2.9723806530296515, 1.978801499868112, 0.970218815946032, 1.0537428195919747, 2.002704439455499, 3.031009495485141, 4.060065324625265, 5.069567770881362, 6.135375940796565, 7.180673437820678, 8.121376837102552, 9.192384034480973, 10.11114854153404, 9.161508572145873, 8.09438924781449, 7.05977111179814, 6.02344273009504, 5.003107372324239, 3.9751033489210474, 3.013393926713311, 2.084530576936109, 1.066120942709222, 0.0, 2.0110145593142423, 3.04367155369992, 3.9770095964650545, 4.9023965141088945, 5.941225975142751, 6.968805762318038, 7.905981216109101, 8.874510977305922, 9.884490530106046, 10.719063923098798, 9.772917031443324, 8.82051563018568, 7.829996658647518, 6.901037710312394, 5.923227340387264, 4.9439898176894586, 4.033634299605456, 3.066799540906527, 2.013802970166784, 1.0606715000535665, 2.955045302109291, 3.9692173510651103, 4.9303998276572285, 5.92981417512439, 6.911997712793642, 7.939119204397156, 8.880740765592513, 9.913151740106706, 10.904995806047706, 11.66081783102076, 10.773508860203243, 9.844401237132194, 8.895700429602076, 7.905481217521562, 6.875707263816302, 5.996109427179371, 4.972119658050344, 3.931049044939873, 2.922656751383481, 1.9901018298164077, 3.9551516199981873, 4.951500024985512, 5.912710904808665, 6.922588407774573, 7.89414488275718, 8.944139912373048, 9.857032212483393, 10.89453372403987, 11.867915570933027, 12.602291867631417, 11.734814565177363, 10.77633064309781, 9.90889287025361, 8.854023993382462, 7.803778271618621, 6.832781106710481, 5.903194506609842, 4.96423918225782, 3.913184967100638, 2.9271880596909527, 4.924570760635062, 5.97209681943341, 6.94986058505248, 7.877898176230506, 8.824905511256212, 9.829450043751027, 10.765731140981666, 11.792989330366382, 12.757559966385887, 13.630469712556902, 12.697347827385798, 11.637008686200385, 10.698361850667654, 9.758963245609921, 8.729652076702946, 7.861202528695722, 6.961344181167492, 5.96841741756284, 4.901599800745627, 3.8946266631760347, 5.862650463395287, 6.867789538657478, 7.838493172017903, 8.819618248517097, 9.777507131110973, 10.773088508045026, 11.746232439269132, 12.68836723287355, 13.731845120880763, 14.480633515479486, 13.50342597657068, 12.578252517833638, 11.63929228275477, 10.692683742424238, 9.724383980828268, 8.82332023316013, 7.964039526227594, 6.914776103212233, 5.8900829363695, 4.875315188359063, 6.834404722019201, 7.869077255842808, 8.813196921925734, 9.84736310323837, 10.711249778403385, 11.684877648039508, 12.753337679755226, 13.7401762853154, 14.660808918157862, 15.441341877230858, 14.478815777629965, 13.609528637450484, 12.663312867284933, 11.747328772560213, 10.681617210118405, 9.830952399298226, 8.846638998575704, 7.835016922448651, 6.870072074594663, 5.892019921031422, 7.77791254721784, 8.705865659163482, 9.723758533638426, 10.762378291156622, 11.750819441651473, 12.640911323587453, 13.573574458118525, 14.519020245890431, 15.550121015228957, 16.410034713796016, 15.430165335927493, 14.664497676199769, 13.682832256678182, 12.677222501304916, 11.642278641925143, 10.747846596662587, 9.706492138641163, 8.77967831012782, 7.8054249977027945, 6.822307168824924, 8.77156952778619, 9.675429242085835, 10.728814236562568, 11.795685184634799, 12.768241069492385, 13.699925243162818, 14.520836424940944, 15.547986867728804, 16.517003583772087, 17.412382601598473, 16.479632786993587, 15.592034938344494, 14.7290735283887, 13.74293584692614, 12.673424128950392, 11.681221475059196, 10.728622200475892, 9.785281045357923, 8.791757407824473, 7.825186487818454, 9.770911990901146, 10.615696811659685, 11.63627915494986, 12.604398654708712, 13.677651826910639, 14.645967115305636, 15.485759962259921, 16.42343435835825, 17.47560878758966, 18.34350706022252, 17.539084708709662, 16.572609397721834, 15.64808548464734, 14.633300563941107, 13.609367009843957, 12.68885994726671, 11.782878149933342, 10.81098180297599, 9.770437184233256, 8.880762661786209, 10.179097843889313, 10.932545609238058, 11.804608798978972, 12.79141285463579, 13.716774350620824, 14.390837893887964, 15.297319423966481, 16.264964783105725, 17.220254674204337, 18.18893249699776, 18.51040376032622, 17.590970996693486, 16.56824345851245, 15.50033255434135, 14.573533106689094, 13.6147679003791, 12.787787795035113, 11.773247068588457, 10.837605523058542, 9.93587081236416, 9.119853211546129, 9.898323087995385, 10.809957632546624, 11.860542539422966, 12.776450732705266, 13.458811524168377, 14.323255503899574, 15.304802238497306, 16.308290208314812, 17.313375453987742, 18.328714832252135, 17.53895089851662, 16.508130652857425, 15.609619088758008, 14.682221148588003, 13.689648001246598, 12.741191716411077, 11.782235084177557, 10.748824269395433, 9.992137711967416, 8.119518541493036, 8.853160082633565, 9.852061264669489, 10.88787663651584, 11.772703290769897, 12.384007886604616, 13.318544767718487, 14.341455622520629, 15.313899473404348, 16.31430171802459, 17.375150196965457, 16.510114189325535, 15.5495897159836, 14.665600958051638, 13.679029969936167, 12.716711638798753, 11.77793342275703, 10.763059318847102, 9.77774377897734, 8.943326027239378, 7.1534118932237565, 7.921940748282783, 8.866913694436597, 9.813934219062066, 10.791344106920736, 11.410793546995334, 12.355081745325704, 13.37689852810236, 14.381930268101092, 15.312351700323022, 16.35930129776869, 15.559112320971582, 14.618107952854048, 13.657450718310013, 12.686326344792949, 11.763845936135633, 10.822751515221807, 9.899082333326408, 8.850498471216474, 7.90454512336084, 6.140553988618415, 6.942958496366464, 7.846449703700704, 8.829068191188115, 9.727751524879857, 10.483661349818268, 11.45145325298458, 12.50703220175746, 13.508481404431057, 14.516046297358724, 15.587642556002667, 14.599974662173826, 13.654964539121245, 12.712531587620253, 11.706702139585433, 10.808375819629697, 9.800729649785621, 8.859877320342227, 7.915310404007867, 6.949312199632988, 5.1293270907252, 5.875660274504362, 6.836312239170278, 7.82836246675668, 8.766254200559235, 9.541345448556093, 10.516533432838465, 11.536432568978524, 12.478187974464024, 13.523593462639232, 14.595160612504506, 13.701282742964597, 12.726989720174794, 11.797570883703049, 10.764406945732299, 9.839833462776086, 8.904896518881921, 7.847946744501725, 6.986945630750303, 6.022473758911145], [5.014654220497224, 5.97133754818905, 6.808828680424395, 7.799703821896976, 8.761630189583293, 9.7000373052312, 10.727381118849177, 11.742265223576808, 12.681922360775909, 13.706348638521513, 14.432199937856979, 13.490772436619586, 12.42470892250808, 11.41631648957227, 10.428274631366985, 9.584269412802927, 8.626883933829335, 7.766879610870722, 6.765953483261867, 6.024831852457265, 3.9957484428506485, 4.916033202199026, 5.818315802120392, 6.7668530233240825, 7.7316007604041355, 8.720835386913945, 9.784264091412208, 10.776259905205855, 11.828022530999263, 12.858169660229397, 13.48913208509434, 12.52909001138919, 11.470280071662168, 10.453852899244898, 9.501146635796331, 8.59671354995987, 7.701436256340031, 6.773114411675853, 5.717863487429337, 5.035507653655764, 2.952025789816922, 3.8821817489611368, 4.838941340789727, 5.805107060953381, 6.803947493760711, 7.816761138104126, 8.842329704681429, 9.864218214108373, 10.828317761522813, 11.835572482053808, 12.50619088226337, 11.5753978934742, 10.523127663902958, 9.527152829465264, 8.552854056203502, 7.614221020677379, 6.664362287472633, 5.807668305834595, 4.7924653363461704, 3.9974751434004974, 1.9336777448196365, 2.8710918098399336, 3.893949155741713, 4.822558175246363, 5.861817686795738, 6.887259645718444, 7.835740423171016, 8.826848957573239, 9.81239930773152, 10.789124698565985, 11.732954689971438, 10.664779359946937, 9.700876078850811, 8.738327638495061, 7.707877332378985, 6.6638470034101065, 5.735328376969974, 4.800210301163265, 3.806631148001726, 2.9563074587657896, 1.0081020933960227, 1.9570637132595472, 2.956977687894095, 3.986033517034219, 4.917756802212255, 5.983564972127458, 6.984624943419833, 7.870785834889513, 8.850411878190357, 9.794656351304326, 10.744296320692493, 9.787232553352622, 8.854418535227724, 7.818090153524624, 6.797754795753823, 5.769750772350632, 4.808041350142895, 3.8791780003656933, 2.860768366138806, 2.0110145593142423, 0.0, 1.0617396904791565, 2.0109775869141817, 2.9363645045580213, 3.9751939655918775, 5.0027737527671645, 5.939949206558229, 6.908478967755049, 7.918458520555172, 8.845992332184887, 9.778704330756684, 8.82630292949904, 7.835783957960879, 6.906825009625755, 5.9290146397006245, 4.949777117002819, 4.0224441161178275, 2.9660829094209875, 1.9130863386812442, 0.9503430592606761, 0.9440307427950486, 1.958202791750868, 2.919385268342986, 3.9263797462505616, 4.945965703242768, 5.973087194846283, 6.914708756041639, 7.9471197305558325, 8.938963796496832, 9.787746240106848, 10.779296159516603, 9.850188536445554, 8.901487728915438, 7.869734087348457, 6.839960133643197, 5.885780986386481, 4.861791217257455, 3.820720604146983, 2.812328310590591, 1.8797733890235173, 1.9552621160796404, 2.9404854656712693, 3.9016963454944227, 4.911573848460331, 5.883130323442938, 6.933125353058806, 7.891000202932518, 8.928501714488997, 9.901883561382153, 10.729220276717506, 11.68582133007702, 10.752469035613302, 9.798564429460718, 8.743695552589571, 7.69344983082573, 6.72245266591759, 5.792866065816951, 4.8539107414649285, 3.802856526307747, 2.816859618898062, 2.9246812567165144, 3.9610822601191673, 4.938846025738238, 5.8668836169162635, 6.8138909519419695, 7.818435484436786, 8.754716581667426, 9.781974771052141, 10.746545407071647, 11.686494737395725, 12.587019386592907, 11.526680245407494, 10.588033409874763, 9.64863480481703, 8.619323635910055, 7.750874087902831, 6.851015740374601, 5.858088976769949, 4.791271359952736, 3.784298222383144, 3.8627609594767396, 4.8679000347389305, 5.838603668099355, 6.8197287445985495, 7.777617627192425, 8.762073948730785, 9.735217879954892, 10.677352673559309, 11.720830561566522, 12.63225521470878, 13.39309753577779, 12.467924077040747, 11.528963841961879, 10.582355301631347, 9.614055540035377, 8.712991792367239, 7.8537110854347025, 6.804447662419342, 5.77975449557661, 4.764986747566173, 4.908982936267646, 5.877099252304653, 6.8205695133959745, 7.847473599319823, 8.711360274484838, 9.684988144120961, 10.75344817583668, 11.72916172600116, 12.649794358843621, 13.592963576460152, 14.368487336837074, 13.499200196657593, 12.552984426492042, 11.637000331767322, 10.571288769325514, 9.720623958505335, 8.736310557782813, 7.724688481655761, 6.759743633801773, 5.781691480238532, 5.865040772914251, 6.792993884859894, 7.800913384240241, 8.825107573758375, 9.750929937732923, 10.641021819668905, 11.573684954199978, 12.519130741971884, 13.55023151131041, 14.475352841562415, 15.319836895134602, 14.554169235406878, 13.572503815885291, 12.566894060512025, 11.531950201132252, 10.637518155869698, 9.596163697848274, 8.669349869334932, 7.695096556909904, 6.711978728032034, 6.858697753482601, 7.762557467782247, 8.815942462258981, 9.858414467236551, 10.768351565573836, 11.70003573924427, 12.520946921022396, 13.548097363810257, 14.517114079853542, 15.477700729364873, 16.369304346200696, 15.481706497551603, 14.618745087595808, 13.632607406133248, 12.563095688157501, 11.570893034266307, 10.618293759683002, 9.674952604565034, 8.681428967031582, 7.714858047025563, 7.858040216597558, 8.702825037356096, 9.72340738064627, 10.691526880405123, 11.721171127664189, 12.646077611387089, 13.485870458341374, 14.423544854439704, 15.475719283671117, 16.40882518798892, 17.42875626791677, 16.462280956928943, 15.537757043854448, 14.522972123148216, 13.499038569051066, 12.578531506473821, 11.672549709140453, 10.700653362183099, 9.660108743440365, 8.77043422099332, 8.830922167498796, 9.713576397038828, 10.726361704116341, 11.687823710636087, 12.613185206621118, 13.609231464544884, 14.525405847244649, 15.403945376594146, 16.359235267692757, 17.32791309048618, 18.28655808955734, 17.480642555900594, 16.457915017719557, 15.390004113548459, 14.463204665896203, 13.50443945958621, 12.677459354242222, 11.662918627795566, 10.727277082265651, 9.777941380371498, 9.89016679984198, 10.747798918281502, 11.72101287054869, 12.618694025848912, 13.63177631427798, 14.54125783426447, 15.499469767311556, 16.364107921202564, 17.419280083100723, 18.33306889523426, 18.440170912461113, 17.49331017232067, 16.462489926661473, 15.563978362562056, 14.63658042239205, 13.644007275050646, 12.695550990215125, 11.736594357981605, 10.703183543199481, 9.946496985771464, 9.775008353988843, 10.680989730767179, 11.679890912803103, 12.715706284649453, 13.600532938903509, 14.211837534738228, 15.1463744158521, 16.16928527065424, 17.14172912153796, 18.142131366158203, 17.486606277174435, 16.464473463129583, 15.503948989787649, 14.619960231855686, 13.633389243740215, 12.6710709126028, 11.732292696561078, 10.71741859265115, 9.732103052781389, 8.897685301043426, 8.808901705719563, 9.749770396416396, 10.694743342570211, 11.64176386719568, 12.619173755054348, 13.238623195128946, 14.182911393459316, 15.204728176235973, 16.209759916234706, 17.140181348456636, 16.476204335144573, 15.51347159477563, 14.572467226658096, 13.611809992114061, 12.640685618596997, 11.718205209939681, 10.777110789025855, 9.853441607130456, 8.804857745020522, 7.858904397164888, 7.898471691020237, 8.770788144500077, 9.674279351834318, 10.65689783932173, 11.555581173013469, 12.31149099795188, 13.279282901118192, 14.334861849891071, 15.33631105256467, 16.343875945492336, 15.54773015915402, 14.554333935977875, 13.609323812925293, 12.666890861424301, 11.661061413389481, 10.762735093433745, 9.75508892358967, 8.814236594146275, 7.869669677811915, 6.903671473437036, 7.026606401160986, 7.703489922637976, 8.664141887303892, 9.656192114890294, 10.594083848692847, 11.369175096689705, 12.344363080972077, 13.364262217112136, 14.306017622597636, 15.351423110772844, 14.68038796937919, 13.655642016768645, 12.681348993978842, 11.751930157507097, 10.718766219536347, 9.794192736580134, 8.85925579268597, 7.802306018305773, 6.941304904554351, 5.976833032715193], [5.994854545846467, 5.080226774571186, 5.90495089790462, 6.8958260393772015, 7.857752407063519, 8.796159522711426, 9.771647854334839, 10.786531959062469, 11.72618909626157, 12.750615374007173, 13.723032191525967, 14.552512127098742, 13.486448612987235, 12.478056180051427, 11.490014321846141, 10.646009103282083, 9.688623624308491, 8.828619301349878, 7.8276931737410225, 7.005032177806507, 4.975948768199891, 4.024922428581163, 4.914438019600617, 5.862975240804308, 6.827722977884361, 7.816957604394171, 8.82152115071465, 9.813516964508297, 10.813153943332972, 11.82656865033345, 12.779964338763328, 13.571250434645489, 12.532019762141324, 11.515592589724054, 10.562886326275487, 9.658453240439027, 8.763175946819187, 7.834854102155009, 6.779603177908493, 6.015707979005007, 3.9322261151661646, 2.9910709753432734, 3.935063558269953, 4.901229278433607, 5.900069711240937, 6.847050139107522, 7.81879105137913, 8.840679560806075, 9.796716751626867, 10.803971472157862, 11.796831170298764, 12.571465124705629, 11.584867354382114, 10.58889251994442, 9.614593746682658, 8.675960711156534, 7.726101977951789, 6.86940799631375, 5.854205026825326, 4.97767546874974, 2.915504385531559, 1.9799810362220707, 2.9512196369598733, 3.8798286564645235, 4.838279033493439, 5.863720992416146, 6.812201769868718, 7.80331030427094, 8.780798297835574, 9.757523688670037, 10.73777235754539, 11.583100258884981, 10.762615769329967, 9.800067328974217, 8.76961702285814, 7.725586693889262, 6.79706806744913, 5.861949991642421, 4.868370838480882, 3.938134099477712, 1.9899287341079452, 1.0409671142444208, 1.895237997414939, 2.9242938265550626, 3.856017111733099, 4.921825281648302, 5.922885252940677, 6.809046144410357, 7.788672187711201, 8.73291666082517, 9.682556630213337, 10.64373055847243, 9.91615822570688, 8.87982984400378, 7.859494486232979, 6.8314904628297874, 5.869781040622051, 4.9409176908448496, 3.9225080566179624, 3.04367155369992, 1.0617396904791565, 0.0, 0.9492378964350252, 1.874624814078865, 2.9134542751127217, 3.9410340622880087, 4.878209516079073, 5.846739277275893, 6.856718830076016, 7.784252641705731, 8.730399533361204, 9.682800934618848, 8.897523648440036, 7.968564700104911, 6.99075433017978, 6.011516807481975, 5.084183806596984, 4.027822599900144, 2.9748260291604005, 2.0120827497398324, 2.005770433274205, 0.9988353360859729, 1.960017812678091, 2.9020424750943605, 3.884226012763613, 4.911347504367127, 5.852969065562483, 6.885380040076677, 7.877224106017676, 8.726006549627693, 9.75186361932868, 10.680971242399728, 9.963227419394594, 8.931473777827613, 7.901699824122353, 6.947520676865637, 5.923530907736611, 4.882460294626139, 3.874068001069747, 2.9415130795026734, 2.98157700942291, 1.9811180100063743, 2.9423288898295277, 3.933119420675843, 4.90467589565845, 5.9374983313041225, 6.829260512453362, 7.866762024009841, 8.840143870902997, 9.66748058623835, 10.624081639597865, 11.612900648365343, 10.860304119939874, 9.805435243068727, 8.755189521304887, 7.784192356396746, 6.854605756296108, 5.915650431944085, 4.864596216786904, 3.8785993093772184, 3.950996150059784, 3.0017148044542723, 3.9794785700733426, 4.907516161251367, 5.8354365241574815, 6.839981056652298, 7.7762621538829375, 8.803520343267653, 9.768090979287159, 10.70569508628843, 11.636124831309637, 12.588419935886652, 11.64977310035392, 10.710374495296188, 9.681063326389213, 8.812613778381987, 7.912755430853758, 6.919828667249106, 5.853011050431893, 4.8460379128623, 4.889075852820009, 3.9884773707186723, 4.959181004079097, 5.9031112633243925, 6.799168975844792, 7.783619520946297, 8.756763452170404, 9.69889824577482, 10.742376133782034, 11.651455563601484, 12.604715828122268, 13.529663767519905, 12.590703532441037, 11.644094992110505, 10.675795230514534, 9.774731482846395, 8.91545077591386, 7.866187352898498, 6.841494186055765, 5.826726438045329, 5.935297829610915, 4.997676588284395, 5.941146849375716, 6.930856118045666, 7.732911623137205, 8.706539492773327, 9.774999524489045, 10.750707298216671, 11.671339931059133, 12.612163925352856, 13.580105629181553, 14.55893180060152, 13.6147241169712, 12.69874002224648, 11.633028459804672, 10.782363648984491, 9.79805024826197, 8.786428172134917, 7.821483324280929, 6.843431170717688, 6.872051259871347, 5.944098147925704, 6.921490720219983, 7.908490092484219, 8.772481286385291, 9.662573168321272, 10.595236302852344, 11.54068209062425, 12.571782859962775, 13.496904190214781, 14.476773568083305, 15.481522878328725, 14.634243506364449, 13.628633750991183, 12.59368989161141, 11.699257846348853, 10.65790338832743, 9.731089559814087, 8.75683624738906, 7.77371841851119, 7.865708240439696, 6.913661730848057, 7.96704672532479, 8.941796985962394, 9.789902914226204, 10.721587087896637, 11.542498269674763, 12.569648712462623, 13.538665428505908, 14.49925207801724, 15.467278716245524, 16.392805046385153, 15.680484778074966, 14.694347096612406, 13.624835378636659, 12.632632724745463, 11.680033450162158, 10.73669229504419, 9.743168657510738, 8.77659773750472, 8.865050703554653, 7.853929300421907, 8.874511643712081, 9.842631143470934, 10.742722476316557, 11.667628960039455, 12.50742180699374, 13.44509620309207, 14.497270632323483, 15.430376536641287, 16.45783066280816, 17.373379505762493, 16.599496734333606, 15.584711813627374, 14.560778259530224, 13.640271196952977, 12.734289399619609, 11.762393052662254, 10.72184843391952, 9.832173911472474, 9.8062060409502, 8.86468066010464, 9.877465967182152, 10.838927973701898, 11.713548490391704, 12.70959474831547, 13.546957195897015, 14.425496725246512, 15.380786616345125, 16.34946443913855, 17.30810943820971, 17.51646891118097, 16.49374137299993, 15.610940981464559, 14.684141533812303, 13.767465697869813, 12.828992766731298, 11.997221663328107, 11.053315884038982, 10.753225253822901, 10.865450673293383, 9.898903181347313, 10.8721171336145, 11.769798288914723, 12.739476864925, 13.641621118035056, 14.521021115963922, 15.38565926985493, 16.440831431753093, 17.35462024388663, 17.489884605113684, 16.5872637661286, 15.556443520469404, 14.66010058004228, 13.732702639872278, 12.740129492530873, 11.827770142226493, 11.024605076252291, 10.034216210174861, 10.926697311120707, 10.755208679338086, 10.944066186709133, 11.830013501491635, 12.742464191821849, 13.674326183734875, 14.693126746343406, 15.525731852145007, 16.34900588583161, 17.32144973671533, 17.60444819303998, 16.536319969827005, 15.558427056937516, 14.597902583595582, 13.71608244933591, 12.729511461220442, 11.767193130083028, 10.828471221811862, 10.005429310921835, 9.063135719756769, 9.877885626392668, 9.789102031068806, 10.811510086895554, 11.756483033049365, 12.703503557674834, 13.680913445533506, 14.300362885608102, 15.244651083938471, 16.26646786671513, 17.27149960671386, 16.5674206680759, 15.520471070630236, 14.557738330261294, 13.66642082046603, 12.707932209594286, 11.736807836077222, 10.814327427419908, 9.873289314276638, 8.980294771594926, 8.135890411995902, 8.839104722514131, 8.87867201636948, 9.832527834979235, 10.736019042313472, 11.718637529800883, 12.617320863492626, 13.373230688431036, 14.341022591597348, 15.396601540370227, 16.398050743043825, 15.663593153283625, 14.591996894639681, 13.598600671463537, 12.653590548410955, 11.763013078904526, 10.757183630869706, 9.858857310913972, 8.851267448840453, 7.910415119397057, 7.116618728453828, 7.883871798786279, 8.006806726510229, 8.765229613117132, 9.725881577783047, 10.71793180536945, 11.655823539172005, 12.430914787168861, 13.406102771451232, 14.426001907591292, 15.367757313076792, 14.732219541703252, 13.724654704864852, 12.699908752254307, 11.725615729464504, 10.796196892992759, 9.814888437016572, 8.890314954060361, 7.955378010166195, 6.898428235785998, 6.050194130936488, 6.957033358064436], [6.894025270179738, 5.935050014906808, 4.955713001469595, 5.9465881429421765, 6.908514510628494, 7.8469216262764006, 8.822409957899813, 9.837294062627443, 10.776951199826543, 11.801377477572148, 12.77379429509094, 13.684292327023524, 14.435686509422261, 13.427294076486453, 12.439252218281167, 11.595246999717109, 10.637861520743517, 9.777857197784904, 8.776931070176047, 7.904202902139779, 5.9092868109650265, 4.958260471346298, 3.965200123165592, 4.913737344369283, 5.878485081449336, 6.867719707959146, 7.872283254279624, 8.864279068073271, 9.863916046897947, 10.877330753898423, 11.830726442328302, 12.622012538210463, 13.48125765857635, 12.46483048615908, 11.512124222710513, 10.607691136874053, 9.712413843254213, 8.784091998590036, 7.728841074343519, 6.949046021770142, 4.8655641579313, 3.924409018108409, 2.9858256618349275, 3.9519913819985812, 4.950831814805912, 5.897812242672496, 6.8695531549441045, 7.891441664371048, 8.847478855191842, 9.854733575722836, 10.847593273863737, 11.622227228270603, 12.53410525081714, 11.538130416379445, 10.563831643117684, 9.62519860759156, 8.675339874386815, 7.818645892748776, 6.803442923260352, 5.911013511514875, 3.8488424282966944, 2.9133190789872057, 2.001981740524848, 2.930590760029498, 3.8890411370584133, 4.9144830959811205, 5.862963873433692, 6.854072407835914, 7.831560401400548, 8.808285792235012, 9.788534461110363, 10.633862362449955, 11.597765643546081, 10.749305225409243, 9.718854919293166, 8.674824590324288, 7.746305963884156, 6.811187888077447, 5.817608734915908, 4.8714721422428475, 2.9232667768730805, 1.9743051570095558, 0.9460001009799136, 1.9750559301200372, 2.9067792152980734, 3.9725873852132767, 4.973647356505651, 5.859808247975331, 6.839434291276175, 7.783678764390143, 8.73331873377831, 9.694492662037405, 10.729110798053753, 9.829067740438806, 8.808732382668005, 7.780728359264813, 6.819018937057077, 5.890155587279875, 4.871745953052988, 3.977009596465055, 2.0109775869141817, 0.9492378964350252, 0.0, 0.9253869176438398, 1.9642163786776963, 2.9917961658529832, 3.928971619644047, 4.897501380840867, 5.90748093364099, 6.835014745270705, 7.7811616369261785, 8.733563038183823, 9.724082009721984, 8.917802596539936, 7.939992226614806, 6.960754703917001, 6.033421703032009, 4.977060496335169, 3.924063925595426, 2.961320646174858, 2.9550083297092304, 1.948073232520998, 1.073820080912602, 1.9528045786593353, 2.9349881163285874, 3.962109607932102, 4.903731169127459, 5.936142143641651, 6.9279862095826505, 7.776768653192668, 8.802625722893653, 9.731733345964702, 10.713901187136267, 9.880711674262638, 8.85093772055738, 7.896758573300663, 6.872768804171637, 5.8316981910611645, 4.823305897504773, 3.8907509759376993, 3.930814905857935, 2.9303559064413993, 2.056131158064039, 2.983881524240818, 3.9554379992234248, 4.9882604348690975, 5.880022616018338, 6.917524127574815, 7.890905974467971, 8.718242689803326, 9.67484374316284, 10.663662751930318, 11.617567358082901, 10.754673139503753, 9.704427417739913, 8.733430252831772, 7.803843652731134, 6.864888328379111, 5.81383411322193, 4.827837205812244, 4.900234046494809, 3.9509527008892973, 3.093280838307854, 4.021318429485879, 4.8861986277224565, 5.890743160217273, 6.8270242574479125, 7.854282446832629, 8.818853082852135, 9.756457189853407, 10.686886934874613, 11.686025584548313, 12.581453619318644, 11.659612391731214, 10.630301222824238, 9.761851674817013, 8.861993327288783, 7.8690665636841315, 6.802248946866919, 5.795275809297326, 5.838313749255034, 4.937715267153697, 4.126255804293148, 5.016913531558904, 5.849931079409767, 6.834381624511272, 7.807525555735379, 8.749660349339795, 9.793138237347009, 10.702217667166462, 11.655477931687244, 12.580651390424286, 13.519611625503154, 12.59333288854553, 11.62503312694956, 10.72396937928142, 9.864688672348885, 8.815425249333524, 7.790732082490791, 6.775964334480355, 6.88453572604594, 5.94691448471942, 5.108221649589767, 6.044658386280178, 6.78367372670218, 7.757301596338303, 8.825761628054021, 9.801469401781645, 10.722102034624108, 11.662926028917834, 12.630867732746529, 13.609693904166496, 14.543632210033316, 13.647977918681505, 12.582266356239698, 11.731601545419517, 10.747288144696995, 9.735666068569943, 8.770721220715956, 7.792669067152714, 7.821289156306372, 6.893336044360729, 6.088565520434034, 7.022292360718731, 7.8232433899502665, 8.713335271886248, 9.64599840641732, 10.591444194189226, 11.622544963527751, 12.547666293779757, 13.52753567164828, 14.532284981893701, 15.583481402799475, 14.577871647426209, 13.542927788046436, 12.64849574278388, 11.607141284762456, 10.680327456249113, 9.706074143824086, 8.722956314946217, 8.81494613687472, 7.862899627283082, 7.147291204004635, 8.055599254196906, 8.840665017791178, 9.772349191461613, 10.593260373239739, 11.620410816027599, 12.589427532070884, 13.550014181582215, 14.518040819810501, 15.44356714995013, 16.43064448147464, 15.643584993047432, 14.574073275071685, 13.581870621180489, 12.629271346597184, 11.685930191479216, 10.692406553945764, 9.725835633939745, 9.814288599989677, 8.803167196856931, 8.187966673095682, 9.044809067854988, 9.79348457988153, 10.71839106360443, 11.558183910558716, 12.495858306657047, 13.548032735888459, 14.481138640206261, 15.508592766373132, 16.42414160932747, 16.56859687983947, 15.685723568628667, 14.699069734222414, 13.744135754547177, 12.896518106765637, 12.08499947321739, 11.671086330354546, 10.7814118079075, 10.755443937385223, 9.813918556539663, 9.190920996565753, 10.041105898085952, 10.764310593956678, 11.760356851880443, 12.59771929946199, 13.476258828811488, 14.4315487199101, 15.400226542703525, 16.358871541774683, 16.567231014745943, 15.544503476564905, 14.661703085029533, 13.734903637377277, 12.818227801434787, 11.879754870296273, 11.122734207604923, 11.842441294881544, 11.702463150257925, 11.814688569728407, 10.848141077782337, 10.1855721629981, 10.971976213298777, 11.790238968489975, 12.69238322160003, 13.5717832195289, 14.436421373419906, 15.491593535318069, 16.405382347451603, 16.540646708678658, 15.638025869693575, 14.607205624034378, 13.710862683607257, 12.783464743437252, 11.790891596095847, 10.878532245791467, 10.075367179817267, 10.823341621017423, 11.809790619178603, 11.654379403671358, 11.893304083144157, 11.143468530875236, 11.944642116205904, 12.793986410425344, 13.767186859163791, 14.576493955709985, 15.399767989396583, 16.372211840280304, 16.655210296604952, 15.58708207339198, 14.60918916050249, 13.648664687160556, 12.766844552900887, 11.780273564785416, 10.817955233648002, 9.879233325376836, 9.056191414486811, 9.85226113059933, 10.77705635072594, 10.688272755402078, 11.74892600562934, 12.128616101108127, 13.018584533659677, 13.775345594274505, 14.740401198773073, 15.650350507245765, 16.46220097002736, 16.54860420386281, 15.618182771640877, 14.57123317419521, 13.608500433826269, 12.717182924031004, 11.758694313159262, 10.787569939642198, 9.865089530984882, 8.924051417841612, 8.031056875159901, 8.925015822838464, 9.738275446847403, 9.777842740702752, 10.781765731414257, 11.685256938748498, 12.66787542623591, 13.566558759927652, 14.322468584866062, 15.290260488032374, 16.345839436805253, 15.721920149776267, 14.714355256848599, 13.642758998204656, 12.64936277502851, 11.70435265197593, 10.813775182469502, 9.807945734434682, 8.909619414478946, 7.902029552405427, 6.961177222962032, 7.905744139296391, 8.783042523119551, 8.905977450843501, 9.714467509552156, 10.675119474218072, 11.667169701804475, 12.60506143560703, 13.380152683603887, 14.355340667886258, 15.375239804026318, 14.724129534183756, 13.782981645268226, 12.775416808429826, 11.750670855819282, 10.776377833029478, 9.846958996557733, 8.865650540581548, 7.9410770576253356, 7.00614011373117, 5.949190339350973, 6.905017371272109, 7.856204082397707], [7.819412187823578, 6.860436932550647, 5.881099919113435, 5.215708020118408, 5.98317418164004, 6.921581297287946, 7.897023040255974, 8.911907144983605, 9.851564282182705, 10.87599055992831, 11.848407377447103, 12.758905409379686, 13.684191365616185, 14.35268099413029, 13.364639135925005, 12.520633917360946, 11.563248438387355, 10.703244115428742, 9.702317987819885, 8.829589819783617, 6.834673728608866, 5.883647388990138, 4.890587040809431, 4.173906619138861, 4.953144752460881, 5.942379378970691, 6.946896336635785, 7.938892150429431, 8.938529129254107, 9.951943836254586, 10.905339524684464, 11.696625620566623, 12.647117241505782, 13.390217403802918, 12.437511140354351, 11.53307805451789, 10.63780076089805, 9.709478916233873, 8.654227991987357, 7.874432939413982, 5.79095107557514, 4.849795935752248, 3.9112125794787675, 3.1841195407943688, 4.025491485817457, 4.972425325028657, 5.944166237300265, 6.966054746727209, 7.922091937548002, 8.929346658078996, 9.922206356219897, 10.696840310626763, 11.63190161583025, 12.463517334023283, 11.489218560761522, 10.550585525235398, 9.600726792030652, 8.744032810392616, 7.728829840904191, 6.836400429158715, 4.774229345940534, 3.8387059966310453, 2.927368658168688, 2.1195651736886436, 2.9636542194145736, 3.9890961783372805, 4.937576955789853, 5.928685490192074, 6.906173483756708, 7.882898874591173, 8.863147543466523, 9.708475444806115, 10.672378725902242, 11.634927166257992, 10.644241836937004, 9.600211507968126, 8.671692881527994, 7.736574805721285, 6.742995652559746, 5.796859059886687, 3.84865369451692, 2.8996920746533954, 1.8713870186237536, 1.0550467379910695, 1.9813922976542335, 3.0472004675694366, 4.048260438861812, 4.934421330331491, 5.914047373632336, 6.858291846746304, 7.807931816134471, 8.769105744393565, 9.803723880409915, 10.745793555661447, 9.734119300311844, 8.706115276908653, 7.744405854700916, 6.815542504923714, 5.797132870696827, 4.9023965141088945, 2.9363645045580213, 1.874624814078865, 0.9253869176438398, 0.0, 1.0388294610338564, 2.066409248209143, 3.003584702000207, 3.9721144631970278, 4.98209401599715, 5.909627827626865, 6.855774719282339, 7.808176120539983, 8.798695092078145, 9.727654040413269, 8.865379144258643, 7.886141621560839, 6.958808620675848, 5.902447413979008, 4.849450843239265, 3.8867075638186974, 3.88039524735307, 2.873460150164838, 1.9992069985564418, 1.0274176610154955, 2.0096011986847477, 3.036722690288262, 3.9783442514836187, 5.010755225997811, 6.002599291938811, 6.851381735548828, 7.877238805249814, 8.806346428320863, 9.788514269492428, 10.741323208888053, 9.77632463820122, 8.822145490944504, 7.798155721815476, 6.757085108705004, 5.748692815148613, 4.816137893581539, 4.856201823501776, 3.8557428240852394, 2.9815180757078785, 2.0584946065969785, 3.030051081579585, 4.062873517225258, 4.9546356983744975, 5.992137209930975, 6.965519056824132, 7.792855772159486, 8.749456825519001, 9.738275834286478, 10.69218044043906, 11.680060057147593, 10.629814335383752, 9.658817170475611, 8.729230570374973, 7.790275246022951, 6.739221030865769, 5.753224123456084, 5.82562096413865, 4.876339618533137, 4.018667755951693, 3.1121357107207612, 3.9608117100786173, 4.965356242573433, 5.901637339804073, 6.9288955291887895, 7.893466165208295, 8.831070272209566, 9.761500017230773, 10.760638666904473, 11.656066701674803, 12.584999309375053, 11.555688140468078, 10.687238592460853, 9.787380244932624, 8.794453481327972, 7.727635864510758, 6.720662726941166, 6.763700666898875, 5.863102184797537, 5.051642721936988, 4.107730812793786, 4.924544161765929, 5.908994706867432, 6.882138638091539, 7.824273431695956, 8.86775131970317, 9.77683074952262, 10.730091014043404, 11.655264472780447, 12.594224707859315, 13.51871980618937, 12.5504200445934, 11.64935629692526, 10.790075589992727, 9.740812166977364, 8.716119000134631, 7.701351252124194, 7.809922643689781, 6.872301402363259, 6.033608567233607, 5.13547566751506, 5.858286809058341, 6.8319146786944644, 7.900374710410182, 8.876082484137806, 9.79671511698027, 10.737539111273993, 11.705480815102689, 12.684306986522657, 13.618245292389478, 14.573364836325343, 13.507653273883538, 12.656988463063357, 11.672675062340835, 10.661052986213782, 9.696108138359795, 8.718055984796553, 8.746676073950212, 7.818722962004569, 7.013952438077873, 6.113109641953613, 6.897856472306428, 7.787948354242409, 8.720611488773482, 9.666057276545388, 10.697158045883914, 11.62227937613592, 12.602148754004443, 13.606898064249863, 14.67789264010719, 15.503258565070048, 14.468314705690275, 13.57388266042772, 12.532528202406297, 11.605714373892955, 10.631461061467927, 9.648343232590054, 9.740333054518562, 8.78828654492692, 8.072678121648474, 7.146416535431788, 7.91527810014734, 8.846962273817773, 9.6678734555959, 10.695023898383761, 11.664040614427046, 12.624627263938377, 13.592653902166663, 14.518180232306293, 15.505257563830801, 15.780103299885777, 14.709672286127523, 13.826433897766236, 13.398623491058379, 12.611317109123057, 11.617793471589605, 10.651222551583583, 10.739675517633518, 9.72855411450077, 9.103745848848723, 8.13562634908987, 8.868097662237693, 9.793004145960591, 10.632796992914878, 11.570471389013209, 12.62264581824462, 13.555751722562423, 14.583205848729294, 15.498754691683633, 15.643209962195629, 14.760383239640213, 13.773729405233958, 12.818795425558722, 12.344367541600928, 13.01038639086123, 12.596473247998388, 11.706798725551337, 11.680830855029063, 10.739305474183503, 10.106700172318794, 9.131923179320834, 9.83892367631284, 10.834969934236605, 11.672332381818153, 12.55087191116765, 13.506161802266263, 14.474839625059687, 15.433484624130845, 15.641844097102105, 14.619116558921068, 13.736362756041077, 12.809563308388821, 11.892887472446333, 11.327604305131564, 12.048121125248763, 12.767828212525385, 12.627850067901765, 12.740075487372247, 11.773527995426177, 11.101351338751142, 10.06279349453366, 10.864852050846137, 11.766996303956192, 12.646396301885062, 13.511034455776068, 14.566206617674231, 15.479995429807763, 15.615259791034816, 14.712638952049735, 13.681818706390539, 12.785522354618802, 11.858124414448795, 10.86555126710739, 10.326381680626758, 11.000754097461106, 11.748728538661265, 12.735177536822444, 12.579766321315198, 12.818691000787997, 12.059247706628277, 11.035459397440786, 11.868599492781506, 12.841799941519954, 13.651107038066147, 14.474381071752745, 15.446824922636464, 15.72982337896111, 14.661695155748138, 13.68380224285865, 12.723277769516717, 11.841504223912432, 10.85493323579696, 9.892614904659546, 9.327082760212127, 9.98157833213065, 10.777648048243172, 11.70244326836978, 11.613659673045918, 12.67431292327318, 13.044395276861168, 12.109401814894559, 12.849958676630667, 13.815014281129235, 14.724963589601927, 15.536814052383521, 15.623217286218965, 14.692795853997035, 13.64584625655137, 12.683113516182427, 11.791796006387164, 10.833353984170808, 9.862229610653744, 8.939749201996426, 8.371900852676903, 8.956443792803741, 9.850402740482306, 10.663662364491243, 10.703229658346592, 11.707152649058095, 12.610643856392336, 13.11342273896468, 13.913551258671546, 14.742146478306301, 15.698531084110613, 15.60697505613092, 14.796533232132425, 13.788968339204759, 12.717372080560816, 11.723975857384671, 10.77896573433209, 9.888434853481048, 8.882605405446228, 7.984279085490491, 7.349878987240717, 7.886564140605872, 8.831131056940231, 9.70842944076339, 9.831364368487339, 10.639854427195994, 11.60050639186191, 12.592556619448313, 13.530448353250868, 14.305539601247725, 15.280727585530096, 14.636375423351986, 13.798742616539919, 12.857594727624388, 11.850029890785986, 10.825283938175442, 9.850990915385639, 8.921572078913893, 7.9403102115930935, 7.015736728636881, 6.275259990907401, 6.8745772569948125, 7.830404288915949, 8.781591000041548], [8.784736819089632, 7.825761563816702, 6.846424550379489, 5.972579360237232, 4.944344720606184, 5.88275183625409, 6.8581935792221165, 7.873077683949747, 8.812734821148847, 9.837161098894452, 10.809577916413247, 11.72007594834583, 12.645361904582328, 13.587178543216568, 14.403468596958863, 13.559463378394804, 12.602077899421213, 11.7420735764626, 10.741147448853743, 9.794914451049673, 7.81817459543003, 6.867148255811301, 5.855911672075486, 4.9741656852048575, 3.914315291427025, 4.903549917936835, 5.908066875601928, 6.900062689395574, 7.899699668220251, 8.91311437522073, 9.866510063650608, 10.657796159532767, 11.608287780471926, 12.624714952889196, 13.476340601388209, 12.571907515551748, 11.676630221931909, 10.748308377267731, 9.693057453021215, 8.857933806235145, 6.774451942396303, 5.833296802573412, 4.8765372107448215, 3.9855024575909312, 2.986662024783601, 3.9335958639948, 4.905336776266408, 5.927225285693352, 6.883262476514146, 7.89051719704514, 8.883376895186041, 9.658010849592907, 10.593072154796394, 11.583834004440892, 12.52804802179538, 11.589414986269256, 10.63955625306451, 9.782862271426472, 8.767659301938048, 7.819901295979879, 5.81305880697439, 4.8775354576649015, 3.892693289434742, 2.9640842699300918, 1.924824758380717, 2.950266717303424, 3.8987474947559955, 4.889856029158217, 5.867344022722852, 6.844069413557317, 7.824318082432667, 8.66964598377226, 9.633549264868385, 10.596097705224135, 11.571325810551606, 10.639040969001984, 9.710522342561852, 8.775404266755142, 7.781825113593603, 6.835688520920543, 4.887483155550776, 3.9385215356872516, 2.9102164796576098, 1.9520652828764737, 0.9425628366203771, 2.0083710065355804, 3.0094309778279555, 3.8955918692976352, 4.87521791259848, 5.8194623857124474, 6.769102355100615, 7.730276283359709, 8.76489441937606, 9.70696409462759, 10.592496564322024, 9.74494473794251, 8.783235315734773, 7.854371965957571, 6.835962331730684, 5.941225975142751, 3.9751939655918784, 2.9134542751127217, 1.9642163786776963, 1.0388294610338564, 0.0, 1.027579787175287, 1.9647552409663507, 2.9332850021631716, 3.943264554963294, 4.870798366593009, 5.816945258248483, 6.769346659506127, 7.7598656310442875, 8.688824579379412, 9.666634949304543, 8.924971082594697, 7.997638081709706, 6.941276875012866, 5.888280304273122, 4.925537024852554, 4.919224708386927, 3.9122896111986947, 3.038036459590298, 2.0396648033001576, 0.9707717376508911, 1.9978932292544056, 2.9395147904497625, 3.971925764963955, 4.963769830904955, 5.812552274514972, 6.8384093442159575, 7.7675169672870075, 8.749684808458573, 9.702493747854197, 10.619114872733581, 9.86097495197836, 8.836985182849332, 7.79591456973886, 6.787522276182469, 5.854967354615395, 5.895031284535633, 4.8945722851190965, 3.977561564478803, 2.967684061512894, 1.9961275865302872, 3.0240440561914017, 3.9158062373406413, 4.953307748897119, 5.926689595790275, 6.75402631112563, 7.710627364485145, 8.699446373252622, 9.653350979405204, 10.706179454968693, 11.668643796417609, 10.697646631509468, 9.76806003140883, 8.829104707056807, 7.778050491899625, 6.79205358448994, 6.859075604170489, 5.795890806860751, 4.802190123701314, 3.874152532523289, 2.926888215029319, 3.931432747524135, 4.867713844754775, 5.8949720341394904, 6.859542670158996, 7.79224081117571, 8.722670556196917, 9.721809205870617, 10.617237240640947, 11.556635845698679, 12.585947014605654, 11.726068053494709, 10.82620970596648, 9.833282942361828, 8.766465325544615, 7.759492187975022, 7.787792448387341, 6.78265337312515, 5.8296346258097005, 4.848509549310506, 3.8906206667166305, 4.875071211818134, 5.848215143042241, 6.790349936646658, 7.833827824653872, 8.738001288488764, 9.691261553009548, 10.61643501174659, 11.555395246825459, 12.490356342512996, 13.477342934745923, 12.688185757959117, 11.828905051026583, 10.77964162801122, 9.754948461168487, 8.74018071315805, 8.790392671012853, 7.755720137189245, 6.81160047110632, 5.825031352923916, 4.824363314009043, 5.797991183645166, 6.866451215360884, 7.842158989088508, 8.76279162193097, 9.698709650240136, 10.666651354068833, 11.6454775254888, 12.579415831355622, 13.56201366658004, 14.434576164036061, 13.671709950267434, 12.687396549544912, 11.67577447341786, 10.710829625563873, 9.732777472000631, 9.630094808776196, 8.702141696830553, 7.791944341950586, 6.802665327362469, 5.86393297725713, 6.754024859193111, 7.686687993724184, 8.632133781496089, 9.663234550834614, 10.58835588108662, 11.568225258955144, 12.572974569200564, 13.643969145057891, 14.616319132192945, 14.701988312118916, 13.858685265277106, 13.514184693290982, 12.58737086477764, 11.613117552352612, 10.585700187169111, 10.623751789344546, 9.671705279752906, 8.850670025521186, 7.835972220840645, 6.881354605098042, 7.813038778768475, 8.633949960546603, 9.661100403334464, 10.630117119377749, 11.590703768889078, 12.558730407117363, 13.484256737256992, 14.4713340687815, 14.74127383885192, 13.670842825093667, 12.78760443673238, 13.740203711315685, 13.592973600007742, 12.558148861410208, 11.588579506162642, 11.623094252459502, 10.611972849326756, 9.79330153425758, 8.825182034498727, 7.834174167188395, 8.759080650911292, 9.598873497865581, 10.536547893963911, 11.588722323195324, 12.521828227513126, 13.549282353679997, 14.464831196634332, 14.604380501161769, 13.721553778606356, 12.734899944200102, 11.779965964524866, 12.763673471463534, 13.752360848548113, 13.53682863781899, 12.600570701956215, 12.564249589855049, 11.622724209009489, 10.726556506487503, 9.730361677248574, 8.80500018126354, 9.801046439187306, 10.638408886768856, 11.516948416118353, 12.472238307216966, 13.44091613001039, 14.399561129081548, 14.603014636068245, 13.580287097887208, 12.69753329500722, 11.770733847354965, 10.854058011412477, 11.807568743615507, 12.812669779131877, 13.73315284379144, 13.51126880272775, 13.623494222198232, 12.656946730252162, 11.721207672919851, 10.6612319924614, 9.830928555796838, 10.733072808906893, 11.612472806835765, 12.47711096072677, 13.532283122624934, 14.446071934758466, 14.57643033000096, 13.673809491015877, 12.64298924535668, 11.746692893584946, 10.81929495341494, 9.826721806073534, 10.806346119110701, 11.76530275134422, 12.71405316992732, 13.7005021680885, 13.545090952581251, 13.702109735613982, 12.679104040796986, 11.633897895368525, 10.834675997732207, 11.807876446470654, 12.61718354301685, 13.440457576703448, 14.412901427587167, 14.690993917927253, 13.622865694714282, 12.644972781824793, 11.684448308482859, 10.802674762878576, 9.816103774763103, 8.85378544362569, 9.807264009538242, 10.837157885223334, 11.742972679509228, 12.667767899635834, 12.578984304311971, 13.639637554539233, 13.654860837447767, 12.707840312822299, 11.816035181581368, 12.781090786079936, 13.69104009455263, 14.502890557334224, 14.58438782518511, 13.653966392963179, 12.607016795517513, 11.644284055148571, 10.752966545353306, 9.794524523136952, 8.823400149619888, 7.9009197409625695, 8.852082102003019, 9.907785213066012, 10.81572737174836, 11.628986995757296, 11.668554289612645, 12.726667760389208, 13.649473317426192, 13.71186123689242, 12.879627763622247, 13.708222983257002, 14.664607589061315, 14.568145595097064, 13.75770377109857, 12.750138878170901, 11.678542619526958, 10.685146396350813, 9.740136273298232, 8.849605392447193, 7.843775944412372, 6.945449624456635, 7.964676608430665, 8.851888771871927, 9.796455688206287, 10.673754072029444, 10.796688999753394, 11.678683888229852, 12.639335852895767, 13.631386080482171, 13.841125087942867, 14.650538884519177, 14.515225134616374, 13.59754596231813, 12.759913155506062, 11.818765266590532, 10.811200429752128, 9.786454477141584, 8.81216145435178, 7.8827426178800355, 6.901480750559237, 5.976907267603025, 6.966172606689264, 7.839901888260867, 8.795728920182002, 9.746915631307601], [9.812316606264918, 8.853341350991988, 7.8740043375547755, 7.0001591474125195, 5.971924507781471, 5.10889401341654, 5.995267346178543, 7.010151450906173, 7.927665687438053, 8.92234218523327, 9.781998129237959, 10.692496161170542, 11.61778211740704, 12.55959875604128, 13.405973565690848, 14.394451185811745, 13.629657686596499, 12.769653363637886, 11.76872723602903, 10.822494238224959, 8.845754382605316, 7.894728042986587, 6.883491459250772, 6.001745472380145, 4.941895078602312, 4.129692095099285, 5.045140642558354, 6.037136456352, 6.872119881044964, 7.8855345880454415, 8.83893027647532, 9.630216372357479, 10.580707993296638, 11.597135165713908, 12.478845570120194, 13.451678555335981, 12.704210009107195, 11.775888164443018, 10.7206372401965, 9.885513593410431, 7.802031729571589, 6.860876589748698, 5.904116997920108, 5.013082244766219, 4.014241811958888, 3.090092366199738, 4.042410543222834, 4.998947814814562, 5.855682689338859, 6.862937409869853, 7.855797108010755, 8.63043106241762, 9.565492367621106, 10.556254217265604, 11.530552990527365, 12.469186026053489, 11.667136040239797, 10.810442058601758, 9.795239089113334, 8.847481083155165, 6.840638594149677, 5.9051152448401885, 4.920273076610028, 3.9916640571053787, 2.952404545556004, 2.1067632195083617, 3.035821261712422, 3.9318796548250066, 4.839764235547565, 5.81648962638203, 6.79673829525738, 7.642066196596971, 8.605969477693098, 9.568517918048848, 10.543746023376317, 11.587776352345195, 10.738102129737138, 9.802984053930428, 8.80940490076889, 7.86326830809583, 5.915062942726063, 4.966101322862539, 3.9377962668328963, 2.9796450700517605, 1.970142623795664, 1.050804526344359, 1.9818511906526683, 2.8680120821223483, 3.8476381254231926, 4.7918825985371605, 5.741522567925328, 6.702696496184421, 7.73731463220077, 8.679384307452302, 9.564916777146735, 10.587179153595468, 9.810815102910059, 8.881951753132856, 7.86354211890597, 6.968805762318038, 5.0027737527671645, 3.941034062288008, 2.991796165852983, 2.066409248209143, 1.027579787175287, 0.0, 0.9371754537910637, 1.9057052149878846, 2.915684767788007, 3.843218579417722, 4.789365471073195, 5.741766872330839, 6.732285843869, 7.661244792204124, 8.639055162129253, 9.618292684827058, 9.025217868884992, 7.968856662188152, 6.915860091448408, 5.95311681202784, 5.946804495562213, 4.939869398373981, 4.065616246765584, 3.0672445904754446, 1.998351524826178, 0.9703134420791185, 1.9119350032744755, 2.944345977788668, 3.936190043729668, 4.784972487339685, 5.81082955704067, 6.73993718011172, 7.7221050212832845, 8.674913960678907, 9.591535085558291, 10.545714232815008, 9.864564970024619, 8.823494356914146, 7.815102063357755, 6.882547141790681, 6.922611071710919, 5.922152072294383, 5.005141351654089, 3.9952638486881806, 3.023707373705574, 1.9964642690161143, 2.8882264501653543, 3.9257279617218326, 4.8991098086149885, 5.726446523950343, 6.683047577309857, 7.671866586077334, 8.625771192229916, 9.678599667793403, 10.664893553673398, 11.599773417870782, 10.795639818584116, 9.856684494232093, 8.805630279074911, 7.819633371665226, 7.886655391345776, 6.8234705940360385, 5.8297699108766015, 4.901732319698576, 3.954468002204606, 3.0387953784912005, 3.9547553421753396, 4.929775983729422, 5.8943466197489265, 6.764661024000423, 7.695090769021629, 8.694229418695329, 9.589657453465659, 10.529056058523391, 11.558367227430367, 12.54604445388949, 11.853789493141765, 10.860862729537114, 9.794045112719902, 8.787071975150308, 8.815372235562629, 7.810233160300438, 6.857214412984988, 5.876089336485794, 4.9182004538919175, 3.9824338427851993, 4.937962506316449, 5.880097299920866, 6.92357518792808, 7.710421501313477, 8.66368176583426, 9.588855224571303, 10.52781545965017, 11.462776555337708, 12.449763147570636, 13.445589585274499, 12.856484838201867, 11.807221415186506, 10.782528248343773, 9.767760500333337, 9.817972458188141, 8.783299924364533, 7.8391802582816075, 6.852611140099203, 5.85194310118433, 5.046197823694067, 5.986381705659449, 6.9319063523627165, 7.852538985205179, 8.671129863064849, 9.639071566893545, 10.617897738313513, 11.551836044180334, 12.534433879404752, 13.406996376860773, 14.357804923555879, 13.7149763367202, 12.703354260593148, 11.738409412739161, 10.760357259175919, 10.657674595951484, 9.729721484005841, 8.819524129125874, 7.830245114537756, 6.891512764432417, 6.002231499242011, 6.934894633773085, 7.8803404215449895, 8.803302990835181, 9.693125543532803, 10.590421125191073, 11.595170435436494, 12.621520080329995, 13.588739345017657, 13.98658092953507, 14.886265052452394, 14.54176448046627, 13.614950651952928, 12.6406973395279, 11.6132799743444, 11.651331576519834, 10.699285066928194, 9.878249812696474, 8.863552008015931, 7.908934392273329, 7.061245418817376, 7.882156600595504, 8.909307043383365, 9.828500132146846, 10.69547343133526, 11.639888576257167, 12.522707697581218, 13.509785029105727, 14.025866456268075, 12.95543544250982, 13.815184223907668, 14.767783498490973, 14.62055338718303, 13.585728648585496, 12.61615929333793, 12.65067403963479, 11.639552636502044, 10.820881321432866, 9.852761821674013, 8.861753954363682, 8.007287290960193, 8.847080137914482, 9.784754534012812, 10.815471842114015, 11.626597889959307, 12.654052016126178, 13.503282156958559, 13.741454268118195, 13.006146396022508, 12.019492561616255, 12.807545751700154, 13.791253258638822, 14.7799406357234, 14.564408424994278, 13.628150489131503, 13.591829377030336, 12.650303996184777, 11.754136293662791, 10.757941464423862, 9.832579968438829, 9.060038910389016, 9.886615526817756, 10.765155056167254, 11.720444947265866, 12.688713577300925, 13.625371067742735, 13.740088403024671, 12.717360864843634, 11.982125912423374, 11.055326464771118, 11.881637798587764, 12.835148530790795, 13.840249566307165, 14.760732630966727, 14.538848589903038, 14.65107400937352, 13.68452651742745, 12.748787460095139, 11.688811779636687, 10.858508342972126, 9.992065280108603, 10.860679446884664, 11.725317600775671, 12.780489762673835, 13.693869382049002, 13.713504096957386, 12.810883257972304, 11.780063012313107, 10.972835070747395, 10.103887570831093, 10.854301593248822, 11.83392590628599, 12.792882538519509, 13.741632957102606, 14.728081955263786, 14.572670739756537, 14.72968952278927, 13.706683827972274, 12.661477682543813, 11.862255784907495, 11.066868917672364, 11.865390183065749, 12.688664216752349, 13.661108067636068, 13.82806768488368, 12.759939461670708, 11.782046548781219, 10.821522075439285, 10.028816940041025, 9.089084796024006, 9.881365230800977, 10.83484379671353, 11.864737672398622, 12.770552466684514, 13.69534768681112, 13.606564091487257, 14.667217341714519, 14.682440624623055, 13.735420099997587, 12.843614968756656, 12.040083257281646, 12.939246734601529, 13.751097197383125, 13.721461592141535, 12.791040159919605, 11.74409056247394, 10.781357822104997, 9.890040312309733, 9.020666700299401, 8.049542326782337, 8.928499528137857, 9.879661889178307, 10.9353650002413, 11.843307158923647, 12.656566782932583, 12.696134076787931, 13.754247547564495, 14.67705310460148, 14.739441024067707, 13.907207550797535, 12.967215454458712, 13.912814229110214, 13.540565807921777, 12.762626798297807, 11.864104136898177, 10.815616386483384, 9.82222016330724, 8.877210040254658, 7.995233038961442, 7.069918121574822, 7.973029411631922, 8.992256395605951, 9.879468559047213, 10.824035475381573, 11.70133385920473, 11.82426878692868, 12.706263675405138, 13.666915640071053, 14.658965867657457, 14.868704875118155, 13.909531355720887, 13.487645347441086, 12.569966175142842, 11.732333368330774, 10.791185479415244, 9.948274196708555, 8.92352824409801, 7.949235221308207, 7.019816384836462, 6.127622927721687, 7.004487054778312, 7.9937523938645505, 8.867481675436153, 9.823308707357288, 10.774495418482887], [10.749492060055982, 9.790516804783051, 8.81117979134584, 7.937334601203583, 6.909099961572534, 6.046069467207603, 5.05809189238748, 6.07297599711511, 6.990490233646991, 7.985166731442206, 8.844822675446897, 9.755320707379479, 10.680606663615977, 11.622423302250217, 12.468798111899785, 13.457275732020682, 14.414661210994273, 13.706828817428951, 12.705902689820094, 11.759669692016022, 9.78292983639638, 8.831903496777652, 7.820666913041836, 6.938920926171209, 5.879070532393375, 5.0668675488903485, 4.107965188767291, 5.099961002560937, 5.934944427253901, 6.948359134254379, 7.901754822684259, 8.693040918566416, 9.643532539505575, 10.659959711922845, 11.541670116329131, 12.514503101544918, 13.528332412258347, 12.713063618234083, 11.657812693987566, 10.822689047201496, 8.739207183362653, 7.798052043539762, 6.841292451711172, 5.950257698557282, 4.951417265749951, 4.027267819990801, 3.105235089431771, 4.061772361023498, 4.918507235547796, 5.925761956078791, 6.918621654219692, 7.693255608626556, 8.628316913830043, 9.61907876347454, 10.593377536736302, 11.532010572262426, 12.481869305467171, 11.747617512392823, 10.7324145429044, 9.78465653694623, 7.777814047940741, 6.842290698631253, 5.857448530401093, 4.9288395108964425, 3.8895799993470677, 3.043938673299425, 2.098645807921358, 2.9947042010339424, 3.9025887817565024, 4.879314172590966, 5.859562841466317, 6.704890742805908, 7.668794023902034, 8.631342464257784, 9.606570569585255, 10.650600898554133, 11.579119524994265, 10.740159507721494, 9.746580354559955, 8.800443761886894, 6.852238396517127, 5.903276776653603, 4.874971720623961, 3.9168205238428246, 2.907318077586728, 1.9879799801354228, 1.0446757368616046, 1.930836628331284, 2.9104626716321294, 3.854707144746097, 4.804347114134265, 5.765521042393358, 6.800139178409707, 7.742208853661239, 8.627741323355673, 9.650003699804406, 10.611713122012143, 9.819127206923923, 8.800717572697035, 7.905981216109102, 5.939949206558229, 4.878209516079072, 3.928971619644047, 3.0035847020002073, 1.9647552409663507, 0.9371754537910637, 0.0, 0.9685297611968208, 1.9785093139969434, 2.906043125626659, 3.852190017282132, 4.804591418539776, 5.795110390077936, 6.72406933841306, 7.701879708338191, 8.681117231035996, 9.608450231920987, 8.906032115979217, 7.853035545239473, 6.890292265818905, 6.883979949353277, 5.877044852165045, 5.002791700556649, 4.004420044266508, 2.9355269786172418, 1.9074888958701823, 1.06221067621494, 2.0071705239976043, 2.9990145899386045, 3.8477970335486216, 4.873654103249606, 5.802761726320656, 6.784929567492221, 7.737738506887844, 8.654359631767228, 9.608538779023945, 10.570703876556045, 9.760669810705211, 8.75227751714882, 7.819722595581746, 7.859786525501983, 6.859327526085447, 5.942316805445153, 4.932439302479245, 3.960882827496638, 2.933639722807178, 2.038502123105819, 2.988552507930769, 3.9619343548239248, 4.7892710701592796, 5.745872123518794, 6.734691132286271, 7.6885957384388535, 8.74142421400234, 9.727718099882335, 10.662597964079719, 11.592184564180357, 10.793859948023158, 9.742805732865977, 8.756808825456291, 8.82383084513684, 7.760646047827102, 6.766945364667665, 5.838907773489639, 4.89164345599567, 3.9759708322822642, 3.1050310151158045, 3.9926005299383585, 4.957171165957863, 5.82748557020936, 6.757915315230566, 7.757053964904266, 8.652481999674597, 9.59188060473233, 10.621191773639305, 11.608869000098428, 12.536586582793992, 11.79803818332818, 10.731220566510967, 9.724247428941373, 9.752547689353692, 8.747408614091501, 7.794389866776052, 6.8132647902768575, 5.855375907682981, 4.9196092965762634, 4.088238179256914, 4.969280137006372, 6.012758025013586, 6.773246047522414, 7.726506312043197, 8.65167977078024, 9.590640005859107, 10.525601101546647, 11.512587693779574, 12.508414131483438, 13.447797566785349, 12.74439686897757, 11.719703702134838, 10.704935954124402, 10.755147911979206, 9.720475378155598, 8.776355712072672, 7.789786593890266, 6.789118554975393, 5.98337327748513, 5.136657378599914, 6.021089189448222, 6.941721822290685, 7.733954409273785, 8.701896113102482, 9.68072228452245, 10.61466059038927, 11.59725842561369, 12.469820923069712, 13.420629469764817, 14.40494287048734, 13.640529714384213, 12.675584866530226, 11.697532712966984, 11.594850049742549, 10.666896937796906, 9.756699582916939, 8.767420568328818, 7.82868821822348, 6.939406953033075, 6.098494945530423, 7.010796889391689, 7.892485827920687, 8.75595008974174, 9.65324567140001, 10.65799498164543, 11.684344626538932, 12.651563891226596, 13.43048235487645, 14.379674620261099, 15.343741630225736, 14.552126105743993, 13.577872793318965, 12.550455428135464, 12.588507030310899, 11.63646052071926, 10.815425266487539, 9.800727461806995, 8.846109846064392, 7.998420872608439, 7.045756912352843, 8.05321276307329, 8.917682969232352, 9.758297977544197, 10.702713122466104, 11.585532243790155, 12.572609575314663, 13.208819112463786, 13.892610896300884, 14.752359677698731, 15.704958952282036, 15.557728840974095, 14.52290410237656, 13.553334747128993, 13.587849493425855, 12.57672809029311, 11.75805677522393, 10.789937275465077, 9.798929408154745, 8.944462744751256, 8.01068044967182, 8.948354845770151, 9.90465467919952, 10.689422436168243, 11.716876562335115, 12.566106703167495, 12.804278814327132, 12.160353158463831, 12.956668015407319, 13.744721205491217, 14.728428712429885, 15.717116089514464, 15.501583878785341, 14.565325942922568, 14.529004830821401, 13.587479449975842, 12.691311747453854, 11.695116918214925, 10.769755422229892, 9.99721436418008, 9.050215838575095, 9.928755367924593, 10.884045259023205, 11.751538123509862, 12.688195613951672, 12.802912949233608, 11.780185411052571, 11.136332674864697, 11.992501918562182, 12.818813252378828, 13.772323984581858, 14.777425020098228, 15.69790808475779, 15.476024043694103, 15.588249463164585, 14.621701971218515, 13.685962913886202, 12.62598723342775, 11.79568379676319, 10.929240733899666, 10.024279758642002, 10.88891791253301, 11.944090074431173, 12.756693928257938, 12.776328643166323, 11.87370780418124, 10.842887558522044, 10.061452427926726, 11.041063024622156, 11.791477047039885, 12.771101360077052, 13.730057992310572, 14.67880841089367, 15.665257409054849, 15.5098461935476, 15.666864976580335, 14.643859281763337, 13.598653136334876, 12.799431238698558, 11.963527375936959, 11.028990494823088, 11.852264528509687, 12.824708379393407, 12.890892231092616, 11.822764007879645, 10.844871094990156, 9.884346621648222, 9.117434297220356, 10.026260249815069, 10.81854068459204, 11.772019250504593, 12.801913126189685, 13.707727920475577, 14.632523140602183, 14.54373954527832, 15.604392795505582, 15.619616078414118, 14.67259555378865, 13.78079042254772, 12.93674171554624, 12.102847046358868, 12.914697509140463, 12.784286138350472, 11.853864706128542, 10.806915108682876, 9.844182368313934, 8.95286485851867, 8.109284057478732, 8.9867177805734, 9.86567498192892, 10.81683734296937, 11.872540454032363, 12.78048261271471, 13.593742236723646, 13.633309530578995, 14.691423001355558, 15.614228558392544, 15.67661647785877, 14.838358640433103, 13.863873912723307, 13.076414540867553, 12.603390354130713, 11.825451344506744, 10.926928683107118, 9.878440932692321, 8.885044709516176, 7.940034586463595, 7.058057585170379, 8.007093575365884, 8.910204865422985, 9.929431849397014, 10.816644012838276, 11.761210929172636, 12.638509312995794, 12.761444240719744, 13.643439129196203, 14.604091093862118, 15.415385350014619, 14.467090167910602, 13.409698577222505, 12.550469893650023, 11.632790721351778, 10.795157914539711, 9.854010025624184, 9.011098742917492, 7.986352790306947, 7.012059767517144, 6.082640931045399, 7.06479838151275, 7.941662508569375, 8.930927847655614, 9.804657129227216, 10.760484161148351, 11.71167087227395], [11.718021821252801, 10.75904656597987, 9.77970955254266, 8.887521241417085, 7.859286601786036, 6.907591908836841, 5.916426421942212, 5.2021834391634085, 6.02196047245017, 7.016636970245385, 7.876292914250076, 8.786790946182656, 9.712076902419156, 10.653893541053396, 11.500268350702964, 12.48874597082386, 13.446131449797452, 14.470504047025727, 13.674432451016914, 12.728199453212842, 10.7514595975932, 9.800433257974474, 8.789196674238656, 7.889107566384711, 6.829257172606877, 5.9283899905195865, 4.966299718322023, 4.152535483301418, 4.96641466605708, 5.979829373057558, 6.933225061487438, 7.7245111573695935, 8.675002778308754, 9.691429950726024, 10.57314035513231, 11.545973340348096, 12.559802651061526, 13.488124495725703, 12.626342455184385, 11.791218808398318, 9.707736944559475, 8.766581804736584, 7.809822212907993, 6.900444338770784, 5.901603905963453, 4.888790261620039, 3.9635696189865035, 3.0932425998266764, 3.949977474350975, 4.9572321948819695, 5.95009189302287, 6.724725847429735, 7.659787152633221, 8.65054900227772, 9.62484777553948, 10.563480811065604, 11.51333954427035, 12.566035137864546, 11.700944304101219, 10.753186298143051, 8.746343809137562, 7.810820459828073, 6.825978291597914, 5.897369272093264, 4.858109760543889, 3.905461114928663, 2.9569803374760912, 2.0261744398371215, 2.9340590205596815, 3.910784411394146, 4.891033080269496, 5.736360981609087, 6.700264262705213, 7.662812703060963, 8.638040808388434, 9.682071137357312, 10.610589763797444, 11.545707839604153, 10.715110115756774, 9.768973523083716, 7.820768157713948, 6.871806537850423, 5.843501481820781, 4.885350285039645, 3.8758478387835487, 2.948307763440451, 1.903010266416338, 0.9623068671344635, 1.9419329104353085, 2.8861773835492768, 3.835817352937444, 4.7969912811965365, 5.831609417212886, 6.773679092464419, 7.659211562158852, 8.681473938607587, 9.643183360815323, 10.572046710592526, 9.769247333893855, 8.874510977305922, 6.908478967755049, 5.846739277275892, 4.897501380840867, 3.9721144631970278, 2.9332850021631716, 1.9057052149878846, 0.9685297611968208, 0.0, 1.0099795528001227, 1.937513364429838, 2.883660256085311, 3.8360616573429547, 4.826580628881116, 5.75553957721624, 6.73334994714137, 7.712587469839176, 8.639920470724167, 9.696281677421007, 8.821565306436293, 7.858822027015725, 7.852509710550097, 6.845574613361865, 5.971321461753469, 4.97294980546333, 3.9040567398140626, 2.876018657067003, 2.030740437411761, 1.0386407628007837, 2.030484828741784, 2.8792672723518002, 3.905124342052786, 4.834231965123836, 5.816399806295401, 6.7692087456910235, 7.685829870570409, 8.640009017827126, 9.602174115359226, 10.643244728469698, 9.720807278345639, 8.788252356778566, 8.828316286698803, 7.827857287282267, 6.910846566641974, 5.900969063676065, 4.9294125886934586, 3.9021694840039993, 3.0070318843026396, 2.0200227467339484, 2.9934045936271043, 3.820741308962458, 4.777342362321972, 5.76616137108945, 6.720065977242033, 7.772894452805519, 8.759188338685515, 9.6940682028829, 10.623654802983538, 11.56261012733556, 10.711335494062796, 9.72533858665311, 9.79236060633366, 8.729175809023921, 7.735475125864484, 6.80743753468646, 5.86017321719249, 4.944500593479086, 4.051328958126254, 3.024070768741538, 3.9886414047610432, 4.858955809012539, 5.789385554033744, 6.7885242037074445, 7.683952238477777, 8.62335084353551, 9.652662012442486, 10.640339238901609, 11.568056821597173, 12.633975438334593, 11.699750327707786, 10.692777190138193, 10.721077450550512, 9.71593837528832, 8.76291962797287, 7.781794551473677, 6.823905668879801, 5.888139057773085, 4.942885169413969, 4.0007503758095515, 5.044228263816765, 5.8047162863255926, 6.757976550846376, 7.683150009583419, 8.622110244662286, 9.557071340349827, 10.544057932582755, 11.539884370286618, 12.47926780558853, 13.55352643393805, 12.688233463331658, 11.673465715321221, 11.723677673176022, 10.689005139352414, 9.74488547326949, 8.758316355087086, 7.757648316172213, 6.951903038681952, 5.991304368756969, 5.052559428251401, 5.973192061093864, 6.765424648076964, 7.733366351905661, 8.71219252332563, 9.646130829192447, 10.62872866441687, 11.501291161872892, 12.452099708567998, 13.43641310929052, 14.448035185417572, 13.644114627727042, 12.6660624741638, 12.563379810939365, 11.635426698993722, 10.725229344113757, 9.735950329525638, 8.7972179794203, 7.885805070218552, 6.953141935687479, 6.042267128194868, 6.923956066723867, 7.787420328544918, 8.684715910203188, 9.689465220448609, 10.715814865342109, 11.683034130029776, 12.46195259367963, 13.41114485906428, 14.375211869028917, 15.302025697542259, 14.546402554515781, 13.51898518933228, 13.557036791507715, 12.604990281916075, 11.783955027684357, 10.769257223003814, 9.814639607261212, 8.883712852040924, 7.900403902509899, 7.084683001876469, 7.949153208035531, 8.789768216347376, 9.734183361269283, 10.617002482593334, 11.604079814117842, 12.64682193738314, 13.493098080704879, 14.482225687609006, 15.397341930863645, 16.30762843277236, 15.491433863573375, 14.521864508325809, 14.556379254622671, 13.545257851489925, 12.726586536420749, 11.758467036661896, 10.767459169351564, 9.813979163428556, 8.865327439828876, 8.038429164403206, 8.9361249180027, 9.720892674971424, 10.748346801138295, 11.597576941970674, 12.037049558991272, 13.018687688018566, 13.818190457036557, 14.69490784570472, 15.678615352643387, 16.667302729727968, 16.47011363998216, 15.533855704119384, 15.497534592018217, 14.556009211172658, 13.659841508650674, 12.663646679411745, 11.738285183426711, 10.86673078285738, 9.904862828732151, 9.018829686557648, 9.97411957765626, 10.783008362313042, 11.719665852754853, 12.035683693897749, 11.012956155716711, 11.99466720441943, 12.85402436019142, 13.76899989259233, 14.722510624795362, 15.727611660311732, 16.66643784595461, 16.44455380489092, 16.5567792243614, 15.590231732415331, 14.654492675083022, 13.59451699462457, 12.764213557960009, 11.798757152576966, 10.87892674879906, 9.978992231166066, 11.034164393064229, 11.788164167061119, 11.962376741585178, 11.085845075705016, 10.075658303186183, 10.91978695748146, 11.902585466251395, 12.74166368725339, 13.721288000290556, 14.680244632524076, 15.647338172090489, 16.63378717025167, 16.47837595474442, 16.63539473777715, 15.612389042960157, 14.567182897531696, 13.767960999895378, 12.818174366094016, 11.883637484980145, 10.942338847142743, 11.914782698026462, 12.060677026465294, 11.0088121062985, 10.042191403878931, 9.11711736631236, 9.97576882677509, 10.887782691444308, 11.768727324805544, 12.722205890718097, 13.75209976640319, 14.676257681672396, 15.601052901799003, 15.51226930647514, 16.5729225567024, 16.588145839610938, 15.64112531498547, 14.749320183744539, 13.791388705703298, 12.957494036515925, 12.004771827773519, 11.909857008290544, 10.99434916096037, 9.992963207101731, 9.030230466732789, 8.185635603182808, 8.967618587033465, 9.848240222202639, 10.815861622142425, 11.767023983182874, 12.822727094245867, 13.74901237391153, 14.562271997920465, 14.601839291775814, 15.659952762552377, 16.36561695089958, 15.382998463412166, 14.357969444997655, 13.383484717287859, 12.516859952599317, 11.634860592933892, 10.856921583309921, 9.958398921910295, 9.064489031111176, 8.071092807935031, 7.172805331127733, 7.916392114725111, 8.868616016995123, 9.860391505636489, 10.879618489610518, 11.785173774035096, 12.729740690369455, 13.607039074192613, 13.729974001916563, 14.611968890393022, 15.42447585199902, 14.4468555888178, 13.498560406713782, 12.441168816025684, 11.581940132453202, 10.664260960154957, 9.826628153342888, 8.885480264427361, 8.086801115612687, 7.084108953201424, 6.244830512181282, 6.940975460600131, 7.926320823141989, 8.891849148782878, 9.881114487869118, 10.773186890424036, 11.729013922345171, 12.68020063347077], [12.710227949446516, 11.751252694173585, 10.771915680736374, 9.831279256261054, 8.803044616630006, 7.851349923680811, 6.860184436786182, 5.951638056849148, 5.011980919650047, 6.006657417445262, 6.8663133614499525, 7.776811393382532, 8.702097349619033, 9.643913988253273, 10.49028879790284, 11.478766418023737, 12.436151896997329, 13.460524494225604, 14.46145062183446, 13.720405581406556, 11.752005458463614, 10.800901865091335, 9.781402802432371, 8.83286558122868, 7.773015187450847, 6.872148005363556, 5.910057733165993, 5.008197739050367, 3.9564351132569575, 4.969849820257435, 5.923245508687314, 6.71453160456947, 7.66502322550863, 8.6814503979259, 9.563160802332186, 10.535993787547973, 11.549823098261403, 12.47814494292558, 13.43757191330982, 12.79176466926873, 10.708282805429887, 9.767127665606996, 8.810368073778406, 7.844202353614753, 6.845361920807423, 5.832548276464008, 4.907327633830473, 3.9556609103332314, 2.9399979215508525, 3.947252642081847, 4.940112340222749, 5.714746294629611, 6.649807599833098, 7.640569449477596, 8.614868222739357, 9.55350125826548, 10.503359991470226, 11.556055585064422, 12.512173762226654, 11.753732159013463, 9.756323361937683, 8.820800012628196, 7.835957844398036, 6.907348824893386, 5.8680893133440115, 4.849219129772632, 3.9007383523200607, 2.9096298179178386, 1.9240794677595585, 2.900804858594023, 3.8810535274693736, 4.726381428808963, 5.6902847099050895, 6.6528331502608395, 7.628061255588313, 8.67209158455719, 9.600610210997322, 10.535728286804032, 11.52633957388221, 10.778953075883837, 8.83074771051407, 7.881786090650546, 6.853481034620904, 5.895329837839768, 4.885827391583671, 3.9582873162405736, 2.9129898192164605, 1.9722864199345862, 0.9319533576351857, 1.8761978307491538, 2.825837800137321, 3.7870117283964135, 4.821629864412763, 5.763699539664296, 6.64923200935873, 7.671494385807464, 8.633203808015201, 9.562067157792404, 10.58047679201929, 9.884490530106044, 7.918458520555172, 6.856718830076015, 5.90748093364099, 4.98209401599715, 3.943264554963294, 2.915684767788007, 1.9785093139969434, 1.0099795528001227, 0.0, 0.9275338116297152, 1.8736807032851883, 2.8260821045428317, 3.816601076080993, 4.745560024416117, 5.723370394341248, 6.702607917039053, 7.629940917924044, 8.686302124620884, 9.739298695360628, 8.868801579815848, 8.86248926335022, 7.855554166161988, 6.981301014553592, 5.982929358263451, 4.914036292614185, 3.8859982098671257, 3.0407199902118833, 2.0304709416649875, 1.020505275941661, 1.8692877195516777, 2.895144789252663, 3.8242524123237125, 4.806420253495277, 5.759229192890901, 6.675850317770286, 7.630029465027002, 8.592194562559103, 9.633265175669575, 10.641657469225967, 9.79823190957869, 9.838295839498924, 8.837836840082389, 7.920826119442096, 6.910948616476188, 5.939392141493581, 4.912149036804122, 4.017011437102762, 3.011852925598152, 1.9834250408269813, 2.8107617561623353, 3.76736280952185, 4.756181818289327, 5.71008642444191, 6.762914900005397, 7.749208785885393, 8.684088650082776, 9.613675250183414, 10.552630574535437, 11.603684789692618, 10.735318139453234, 10.802340159133783, 9.739155361824045, 8.745454678664608, 7.817417087486582, 6.870152769992613, 5.930898776105166, 4.994617678874526, 3.96735948948981, 3.002788853470305, 3.8489762562124157, 4.779406001233622, 5.778544650907321, 6.673972685677653, 7.613371290735387, 8.642682459642362, 9.630359686101485, 10.55807726879705, 11.62399588553447, 12.592099623337608, 11.702756742938316, 11.731057003350635, 10.725917928088444, 9.772899180772995, 8.7917741042738, 7.833885221679924, 6.859317821386347, 5.88617389016224, 4.944039096557823, 4.071594652945417, 4.79473673352547, 5.747996998046254, 6.673170456783297, 7.6121306918621645, 8.547091787549704, 9.534078379782631, 10.529904817486495, 11.469288252788406, 12.543546881137924, 13.568240047980657, 12.683445268121345, 12.733657225976147, 11.698984692152539, 10.754865026069615, 9.768295907887211, 8.767627868972337, 7.923081802295215, 6.93459308950524, 5.966437902106467, 5.000558450222516, 5.7554450952768414, 6.72338679910554, 7.702212970525507, 8.636151276392326, 9.618749111616747, 10.491311609072769, 11.442120155767874, 12.426433556490396, 13.438055632617449, 14.403000480471436, 13.676042026963925, 13.57335936373949, 12.645406251793847, 11.735208896913882, 10.745929882325763, 9.807197532220425, 8.829093790966823, 7.89643065643575, 6.956145602049934, 5.951322455852519, 6.777440775744796, 7.674736357403067, 8.679485667648487, 9.705835312541987, 10.673054577229653, 11.451973040879507, 12.401165306264156, 13.365232316228793, 14.292046144742136, 15.266299457167163, 14.528964742132406, 14.56701634430784, 13.6149698347162, 12.793934580484482, 11.77923677580394, 10.824619160061337, 9.827001572789195, 8.84369262325817, 7.945536313207468, 6.976519597164183, 7.779788663547254, 8.724203808469163, 9.607022929793212, 10.59410026131772, 11.636842384583018, 12.483118527904756, 13.472246134808882, 14.387362378063521, 15.297648879972238, 16.25263186728884, 15.531844061125934, 15.566358807422796, 14.55523740429005, 13.736566089220874, 12.768446589462021, 11.7719300027488, 10.757267884176827, 9.808616160577147, 8.899282475734205, 7.963491307131351, 8.710913122171302, 9.738367248338173, 10.587597389170552, 11.530285987273343, 12.545070907979575, 13.41906140879832, 14.443326352857634, 15.427033859796301, 16.34854568222444, 17.231311643697623, 16.54383525691951, 16.507514144818344, 15.565988763972783, 14.664312342047909, 13.66811751280898, 12.742756016823947, 11.81001950360565, 10.848151549480422, 9.879682997888647, 9.027620206582975, 9.77302880951292, 10.70968629995473, 11.059438931598812, 11.76241077340245, 12.830321677573549, 13.757121125225805, 14.712757907436298, 15.66626863963933, 16.671369675155702, 17.615275454444827, 17.454533357691044, 17.566758777161528, 16.600211285215458, 15.658963508480257, 14.598987828021805, 13.768684391357244, 12.742045873325237, 11.82221546954733, 10.839845542497065, 10.087665021990944, 10.778184614260997, 10.952397188785056, 10.075865522904895, 10.825112920871922, 11.823011021437878, 12.821156135558665, 13.685421702097358, 14.665046015134525, 15.624002647368044, 16.626393231953276, 17.612842230114456, 17.470582082938133, 17.645374290577276, 16.616859876357392, 15.571653730928931, 14.772431833292613, 13.760639894389755, 12.826103013275883, 11.803192158473742, 11.082055756901408, 11.05069747366517, 9.998832553498378, 9.03221185107881, 9.8665719839981, 10.878992890731508, 11.831540706288276, 12.712485339649513, 13.665963905562066, 14.695857781247158, 15.655312741535182, 16.59325902999272, 16.504475434668855, 17.314609298438512, 16.28672533290614, 15.339704808280672, 14.295872514759784, 13.300637361664801, 12.48044789430788, 11.620945625924005, 10.899877455490419, 9.984369608160247, 8.98298365430161, 8.020250913932667, 8.935090220868547, 9.895747455412582, 10.791998237046608, 11.759619636986393, 12.710781998026842, 13.766485109089835, 14.728067433774315, 15.55447812611418, 15.594045419969529, 16.379025600728593, 15.355637398099454, 14.373018910612043, 13.347989892197532, 12.373505164487735, 11.506880399799194, 10.624881040133769, 9.846942030509798, 8.948419369110171, 8.054509478311054, 7.061113255134909, 7.922259948813472, 8.860150129569082, 9.812374031839092, 10.804149520480458, 11.823376504454487, 12.764228833897882, 13.708795750232241, 14.599245202386328, 14.722180130110278, 15.375148263864812, 14.414496299198897, 13.436876036017674, 12.488580853913657, 11.43118926322556, 10.571960579653078, 9.654281407354834, 8.816648600542765, 7.875500711627239, 7.076821562812565, 6.074129400401302, 6.994285129867021, 7.884733475444101, 8.870078837985957, 9.835607163626847, 10.824872502713086, 11.76539301861775, 12.721220050538886, 13.672406761664485], [13.63776176107623, 12.6787865058033, 11.699449492366089, 10.758813067890769, 9.73057842825972, 8.778883735310526, 7.787718248415897, 6.8791718684788625, 5.939514731279762, 5.23356051878084, 5.9962998705534165, 6.849277581752817, 7.774563537989318, 8.716380176623558, 9.562754986273127, 10.551232606394024, 11.508618085367615, 12.53299068259589, 13.533916810204747, 14.560654406554853, 12.67953927009333, 11.72843567672105, 10.708936614062086, 9.760399392858394, 8.700548999080562, 7.799681816993271, 6.837591544795708, 5.935731550680082, 4.8839689248866724, 4.1967529215930135, 5.053232017790778, 5.786997792939755, 6.737489413878915, 7.753916586296185, 8.635626990702473, 9.608459975918258, 10.622289286631688, 11.550611131295865, 12.510038101680106, 13.555163348833355, 11.635816617059602, 10.69466147723671, 9.737901885408121, 8.771736165244468, 7.772895732437138, 6.760082088093723, 5.834861445460188, 4.883194721962946, 3.8675317331805674, 3.1741557434174252, 4.032386324326334, 4.787212482999896, 5.722273788203383, 6.713035637847881, 7.687334411109643, 8.625967446635766, 9.575826179840512, 10.628521773434707, 11.584639950596939, 12.536469280268772, 10.6838571735674, 9.748333824257912, 8.763491656027751, 7.834882636523101, 6.7956231249737264, 5.776752941402347, 4.828272163949776, 3.837163629547554, 2.851613279389274, 2.1154800237726104, 2.9733275115729585, 3.7988476171792485, 4.762750898275375, 5.725299338631125, 6.700527443958596, 7.7445577729274735, 8.673076399367606, 9.608194475174315, 10.598805762252494, 11.607388446174575, 9.758281522143786, 8.809319902280262, 7.781014846250619, 6.8228636494694825, 5.813361203213386, 4.8858211278702885, 3.8405236308461754, 2.899820231564301, 1.8594871692649009, 1.0489413879279155, 1.9181117842409063, 2.8594779167666986, 3.894096052783048, 4.8361657280345804, 5.721698197729014, 6.743960574177748, 7.705669996385485, 8.634533346162687, 9.652942980389575, 10.719063923098798, 8.845992332184887, 7.78425264170573, 6.835014745270705, 5.909627827626865, 4.870798366593009, 3.8432185794177225, 2.906043125626659, 1.937513364429838, 0.9275338116297152, 0.0, 0.9461468916554732, 1.8985482929131168, 2.889067264451278, 3.818026212786402, 4.795836582711532, 5.775074105409337, 6.702407106294329, 7.758768312991169, 8.811764883730913, 9.77450816315148, 9.790023074979935, 8.783087977791702, 7.908834826183307, 6.910463169893166, 5.8415701042439, 4.813532021496841, 3.9682538018415987, 2.9250085647833215, 1.915042899059995, 0.9417539079219626, 1.9676109776229478, 2.8967186006939976, 3.878886441865563, 4.831695381261186, 5.74831650614057, 6.702495653397286, 7.664660750929387, 8.705731364039858, 9.71412365759625, 10.646678579163323, 10.765829651128639, 9.765370651712104, 8.848359931071812, 7.838482428105903, 6.866925953123296, 5.839682848433837, 4.944545248732478, 3.906390548716486, 2.848228828757933, 1.8832279445326203, 2.839828997892135, 3.8286480066596122, 4.782552612812195, 5.835381088375682, 6.821674974255677, 7.756554838453059, 8.686141438553697, 9.62509676290572, 10.676150978062902, 11.583764809037868, 11.726233619177625, 10.663048821867887, 9.66934813870845, 8.741310547530425, 7.7940462300364555, 6.789501697541639, 5.8532206003109994, 4.825962410926284, 3.8613917749067785, 2.9214424445827007, 3.851872189603907, 4.851010839277607, 5.746438874047938, 6.685837479105672, 7.715148648012648, 8.702825874471772, 9.630543457167336, 10.696462073904753, 11.664565811707892, 12.55120341252295, 12.643657298052732, 11.638518222790541, 10.667814589430115, 9.686689512930922, 8.728800630337046, 7.717920742822821, 6.744776811598714, 5.802642017994297, 4.797857857315237, 3.867202921895755, 4.820463186416539, 5.745636645153582, 6.68459688023245, 7.619557975919988, 8.606544568152914, 9.602371005856778, 10.54175444115869, 11.61601306950821, 12.640706236350942, 13.531891937705979, 13.628572634633267, 12.593900100809659, 11.649780434726734, 10.66321131654433, 9.662543277629458, 8.752703938879566, 7.684243907163849, 6.692701106476287, 5.726821654592336, 4.8279112836471265, 5.795852987475825, 6.774679158895792, 7.708617464762612, 8.691215299987032, 9.563777797443052, 10.514586344138158, 11.49889974486068, 12.510521820987732, 13.475466668841719, 14.45351882240496, 14.46827477239661, 13.540321660450967, 12.630124305571002, 11.640845290982883, 10.630265496403956, 9.560517728722731, 8.627854594191659, 7.682408806419754, 6.677585660222339, 5.849906964115081, 6.747202545773352, 7.751951856018772, 8.778301500912272, 9.745520765599938, 10.52443922924979, 11.47363149463444, 12.437698504599076, 13.364512333112419, 14.338765645537446, 15.366183010720947, 15.46193175296496, 14.50988524337332, 13.688849989141602, 12.633485854079584, 11.568177065921807, 10.558425510545103, 9.575116561014077, 8.671799517577288, 7.702782801534003, 6.8522548519175395, 7.796669996839448, 8.679489118163497, 9.666566449688005, 10.709308572953303, 11.555584716275039, 12.544712323179166, 13.459828566433805, 14.370115068342521, 15.325098055659124, 16.29466741090669, 16.461274216079918, 15.45015281294717, 14.544726612465487, 13.576607112706634, 12.503353940504708, 11.488691821932735, 10.540040098333055, 9.625545680104025, 8.689754511501171, 7.783379310541586, 8.810833436708458, 9.660063577540837, 10.602752175643628, 11.61753709634986, 12.491527597168604, 13.515792541227917, 14.499500048166585, 15.421011870594723, 16.303777832067908, 17.250347272601864, 17.383722941668648, 16.442197560823086, 15.395736279803815, 14.399541450564886, 13.474179954579855, 12.541443441361558, 11.57957548723633, 10.605946202258467, 9.753883410952795, 8.845494997883204, 9.782152488325016, 10.688032196627532, 11.62684557891819, 12.641557579948994, 13.45569369401374, 14.441700494340306, 15.455853204965965, 16.38327713620719, 17.327182915496316, 18.305455423179815, 18.44296757401183, 17.44286409317301, 16.39038744623616, 15.330411765777711, 14.500108329113152, 13.473469811081145, 12.553639407303237, 11.566108746866885, 10.813928226360764, 9.85065080263128, 10.307366280612692, 11.00339933453461, 11.752646732501637, 12.750544833067593, 13.74868994718838, 14.612955513727073, 15.59257982676424, 16.55153645899776, 17.553927043582988, 18.540376041744167, 18.26411565025703, 17.318294821159583, 16.340387945727667, 15.281559878892258, 14.349697886979232, 13.34631788964437, 12.626770634213944, 11.755844794925066, 11.034389842978037, 10.180683982768635, 9.353801645326014, 9.959745662708524, 10.794105795627814, 11.806526702361223, 12.759074517917991, 13.640019151279228, 14.59349771719178, 15.623391592876873, 16.582846553164895, 17.520792841622434, 17.43200924629857, 16.3870754868088, 15.359191521276427, 14.412170996650959, 13.368338703130071, 12.373103550035088, 11.552914082678164, 10.69341181429429, 9.972343643860704, 9.11435611726371, 8.337952746129245, 8.947784725562382, 9.862624032498262, 10.823281267042297, 11.719532048676323, 12.687153448616108, 13.638315809656557, 14.69401892071955, 15.65560124540403, 16.482011937743895, 16.47052633586349, 15.45149178909888, 14.42810358646974, 13.44548509898233, 12.420456080567819, 11.445971352858022, 10.579346588169479, 9.697347228504054, 8.919408218880083, 8.078405878213635, 7.323208037395681, 7.988647066764624, 8.849793760443188, 9.787683941198797, 10.739907843468806, 11.731683332110173, 12.750910316084202, 13.691762645527596, 14.636329561861956, 15.526779014016043, 15.459299437970275, 14.447614452235099, 13.486962487569183, 12.509342224387963, 11.561047042283946, 10.503655451595847, 9.644426768023363, 8.726747595725119, 7.889114788913049, 7.005487220730703, 6.3037246641481435, 7.0016632120310165, 7.921818941496736, 8.812267287073816, 9.797612649615672, 10.763140975256562, 11.752406314342801, 12.692926830247465, 13.6487538621686, 14.5999405732942], [14.583908652731708, 13.624933397458777, 12.645596384021566, 11.704959959546244, 10.676725319915196, 9.725030626966, 8.733865140071371, 7.825318760134336, 6.885661622935236, 6.09728841175301, 5.050152978897943, 5.903130690097344, 6.828416646333844, 7.770233284968084, 8.616608094617654, 9.60508571473855, 10.562471193712142, 11.586843790940417, 12.587769918549274, 13.61450751489938, 13.625686161748806, 12.674582568376525, 11.655083505717561, 10.70654628451387, 9.646695890736037, 8.745828708648745, 7.7837384364511815, 6.881878442335555, 5.830115816542146, 5.060480814565183, 4.1070851261353045, 4.8408509012842815, 5.791342522223442, 6.807769694640712, 7.689480099047, 8.662313084262784, 9.676142394976214, 10.604464239640391, 11.563891210024632, 12.609016457177882, 12.581963508715079, 11.640808368892188, 10.684048777063596, 9.717883056899943, 8.719042624092612, 7.706228979749197, 6.7810083371156615, 5.8293416136184195, 4.813678624836041, 4.046819217463111, 3.08623943267086, 3.8410655913444227, 4.776126896547909, 5.766888746192407, 6.7411875194541695, 7.679820554980293, 8.629679288185038, 9.682374881779234, 10.638493058941465, 11.590322388613298, 11.630004065222874, 10.694480715913386, 9.709638547683225, 8.781029528178575, 7.7417700166292, 6.722899833057821, 5.774419055605249, 4.783310521203028, 3.797760171044747, 2.9881434978182955, 2.0271806199174853, 2.8527007255237753, 3.816604006619901, 4.779152446975651, 5.754380552303124, 6.798410881272002, 7.726929507712134, 8.662047583518843, 9.65265887059702, 10.661241554519101, 10.70442841379926, 9.755466793935735, 8.727161737906092, 7.769010541124956, 6.75950809486886, 5.831968019525762, 4.786670522501649, 3.8459671232197747, 2.805634060920374, 1.9216048619736004, 0.9719648925854332, 1.9133310251112254, 2.9479491611275748, 3.8900188363791077, 4.775551306073542, 5.797813682522276, 6.759523104730012, 7.688386454507214, 8.706796088734102, 9.772917031443324, 9.778704330756684, 8.730399533361204, 7.7811616369261785, 6.855774719282339, 5.816945258248483, 4.789365471073196, 3.852190017282132, 2.883660256085311, 1.8736807032851883, 0.9461468916554732, 0.0, 0.9524014012576436, 1.9429203727958049, 2.871879321130929, 3.849689691056059, 4.828927213753865, 5.756260214638855, 6.812621421335695, 7.865617992075439, 8.828361271496007, 10.699673078775328, 9.729234869447177, 8.85498171783878, 7.85661006154864, 6.787716995899373, 5.759678913152314, 4.914400693497072, 3.8711554564387947, 2.861189790715468, 1.8879007995774357, 1.0214640859674746, 1.9505717090385244, 2.9327395502100897, 3.8855484896057124, 4.802169614485098, 5.756348761741814, 6.718513859273913, 7.759584472384384, 8.767976765940777, 9.70053168750785, 11.66558147768963, 10.711517543367579, 9.794506822727286, 8.784629319761377, 7.81307284477877, 6.7858297400893095, 5.890692140387951, 4.852537440371959, 3.7943757204134063, 2.8293748361880935, 1.9827697909415933, 2.882501115004139, 3.836405721156722, 4.889234196720208, 5.875528082600204, 6.8104079467975875, 7.739994546898226, 8.678949871250248, 9.73000408640743, 10.637617917382395, 12.635000618326504, 11.609195713523361, 10.615495030363924, 9.687457439185899, 8.740193121691929, 7.735648589197113, 6.799367491966473, 5.772109302581757, 4.807538666562252, 3.867589336238174, 2.9948129826533654, 3.904863947622134, 4.800291982392466, 5.739690587450199, 6.769001756357175, 7.7566789828162985, 8.684396565511863, 9.750315182249281, 10.71841892005242, 11.605056520867477, 13.57308032108673, 12.584665114446015, 11.613961481085589, 10.632836404586396, 9.67494752199252, 8.664067634478295, 7.690923703254188, 6.748788909649771, 5.74400474897071, 4.813349813551228, 3.963403979465997, 4.88857743820304, 5.785999225748432, 6.673411084264515, 7.660397676497442, 8.656224114201306, 9.595607549503217, 10.669866177852736, 11.694559344695469, 12.585745046050505, 14.449756731737265, 13.540046992465133, 12.595927326382208, 11.609358208199804, 10.608690169284932, 9.69885083053504, 8.630390798819322, 7.63884799813176, 6.672968546247809, 5.774058175302599, 4.938793780525282, 5.91761995194525, 6.810019810278594, 7.745068408331559, 8.617630905787578, 9.568439452482684, 10.552752853205206, 11.564374929332258, 12.529319777186245, 13.507371930749487, 15.375641497458389, 14.486468552106441, 13.576271197226475, 12.586992182638356, 11.57641238805943, 10.506664620378205, 9.574001485847132, 8.628555698075226, 7.623732551877811, 6.796053855770554, 5.89014333882281, 6.89489264906823, 7.879703846428255, 8.799373873944464, 9.578292337594316, 10.527484602978966, 11.491551612943603, 12.418365441456945, 13.392618753881973, 14.420036119065474, 16.36929847802674, 15.456032135028794, 14.634996880797075, 13.579632745735058, 12.51432395757728, 11.504572402200576, 10.521263452669551, 9.617946409232761, 8.648929693189476, 7.798401743573012, 6.9396107898889055, 7.822429911212954, 8.809507242737462, 9.85224936600276, 10.609437824619565, 11.598565431523692, 12.513681674778331, 13.423968176687048, 14.37895116400365, 15.348520519251217, 17.2816768304431, 16.396299704602644, 15.49087350412096, 14.522754004362108, 13.449500832160181, 12.434838713588208, 11.486186989988528, 10.571692571759499, 9.635901403156645, 8.729526202197059, 7.999062711604981, 8.803004370590294, 9.745692968693085, 10.760477889399317, 11.54538070551313, 12.569645649572443, 13.553353156511111, 14.47486497893925, 15.357630940412433, 16.304200380946387, 18.25455878134434, 17.38834445247856, 16.34188317145929, 15.34568834222036, 14.420326846235328, 13.487590333017032, 12.525722378891803, 11.55209309391394, 10.700030302608269, 9.791641889538678, 8.970381763221537, 9.830972989676988, 10.769786371967646, 11.784498372998453, 12.509546802358267, 13.495553602684833, 14.509706313310492, 15.437130244551717, 16.381036023840842, 17.359308531524338, 18.318303428654648, 17.404614068886175, 16.352137421949326, 15.30807889014391, 14.407298437259128, 13.474974635552657, 12.685334478739556, 11.773044519246268, 11.082633686233027, 10.233610827076312, 9.973797619772224, 10.814546398370904, 11.707084224498175, 12.746912977300344, 13.460985696298293, 14.453558843639698, 15.433183156676865, 16.392139788910384, 17.400135697704965, 18.367225822974294, 17.317968758601555, 16.37214792950411, 15.394241054072191, 14.335412987236785, 13.403550995323759, 12.400170997988896, 11.68062374255847, 10.80969790326959, 10.088242951322563, 9.234537091113161, 10.180984460118374, 10.905892554363998, 11.740252687283286, 12.752673594016695, 13.705221409573465, 14.586166042934703, 15.539644608847256, 16.569538484532348, 17.528993444820372, 18.339666980511424, 16.50158184538059, 15.440928595153327, 14.413044629620954, 13.466024104995485, 12.422191811474598, 11.426956658379614, 10.60676719102269, 9.747264922638815, 9.02619675220523, 8.168209225608237, 9.165135560921605, 9.893931617217856, 10.808770924153734, 11.76942815869777, 12.665678940331796, 13.633300340271584, 14.584462701312033, 15.640165812375026, 16.601748137059506, 17.428158829399372, 15.524379444208016, 14.505344897443406, 13.481956694814267, 12.499338207326856, 11.474309188912345, 10.499824461202548, 9.633199696514005, 8.751200336848578, 7.973261327224609, 7.132258986558162, 8.150390852188043, 8.934793958420098, 9.79594065209866, 10.733830832854272, 11.68605473512428, 12.677830223765648, 13.697057207739677, 14.637909537183072, 15.582476453517431, 16.47292590567152, 14.513152546314801, 13.501467560579625, 12.54081559591371, 11.563195332732489, 10.614900150628472, 9.557508559940374, 8.69827987636789, 7.780600704069644, 6.942967897257575, 6.059340329075229, 7.130907478940504, 7.94781010368649, 8.867965833152208, 9.758414178729291, 10.743759541271146, 11.709287866912037, 12.698553205998277, 13.639073721902943, 14.594900753824078, 15.546087464949677], [13.672283745601778, 14.57733479871642, 13.597997785279208, 12.657361360803886, 11.629126721172838, 10.677432028223642, 9.686266541329012, 8.77772016139198, 7.838063024192878, 6.830506157958101, 5.783370725103032, 4.9507292888397005, 5.876015245076201, 6.817831883710441, 7.664206693360011, 8.652684313480908, 9.6100697924545, 10.634442389682775, 11.635368517291631, 12.662106113641737, 12.702395400180563, 13.626983969634168, 12.607484906975204, 11.658947685771512, 10.59909729199368, 9.698230109906387, 8.736139837708823, 7.8342798435931975, 6.782517217799788, 5.793698560770274, 4.840302872340394, 3.8884495000266384, 4.838941120965798, 5.855368293383068, 6.737078697789356, 7.709911683005142, 8.723740993718572, 9.652062838382749, 10.611489808766988, 11.656615055920238, 11.68337034093923, 12.59320977014983, 11.636450178321239, 10.670284458157585, 9.671444025350254, 8.658630381006839, 7.733409738373304, 6.781743014876062, 5.766080026093683, 4.83967044862822, 3.8194571788759495, 2.888664190086779, 3.8237254952902657, 4.814487344934764, 5.788786118196526, 6.72741915372265, 7.677277886927396, 8.729973480521592, 9.686091657683821, 10.637920987355654, 10.731469867207611, 11.646882117171028, 10.662039948940867, 9.733430929436217, 8.694171417886842, 7.675301234315463, 6.7268204568628915, 5.73571192246067, 4.75016157230239, 3.940544899075939, 2.9684746542906324, 1.9002993242661317, 2.8642026053622573, 3.826751045718008, 4.80197915104548, 5.846009480014358, 6.77452810645449, 7.709646182261199, 8.700257469339377, 9.708840153261457, 9.834405022895062, 10.70786819519338, 9.679563139163736, 8.7214119423826, 7.711909496126503, 6.784369420783405, 5.739071923759292, 4.798368524477418, 3.758035462178017, 2.874006263231244, 1.9243662938430768, 0.9609296238535818, 1.9955477598699312, 2.9376174351214637, 3.8231499048158977, 4.845412281264632, 5.807121703472368, 6.7359850532495695, 7.754394687476457, 8.820515630185678, 8.82630292949904, 9.682800934618848, 8.733563038183823, 7.808176120539982, 6.769346659506126, 5.741766872330839, 4.804591418539775, 3.8360616573429542, 2.8260821045428317, 1.8985482929131168, 0.9524014012576436, 0.0, 0.9905189715381612, 1.9194779198732852, 2.8972882897984156, 3.8765258124962205, 4.803858813381211, 5.860220020078051, 6.913216590817795, 7.875959870238363, 9.747271677517684, 10.681636270704821, 9.807383119096425, 8.809011462806284, 7.740118397157017, 6.712080314409957, 5.866802094754714, 4.823556857696438, 3.813591191973112, 2.8403022008350796, 1.9529932300175636, 1.0238856069465139, 2.006053448118079, 2.9331470883480693, 3.8497682132274536, 4.80394736048417, 5.766112458016269, 6.80718307112674, 7.815575364683132, 8.748130286250206, 10.713180076431986, 11.663918944625223, 10.74690822398493, 9.737030721019021, 8.765474246036414, 7.738231141346953, 6.843093541645593, 5.804938841629603, 4.74677712167105, 3.781776237445737, 2.9142989349916824, 1.9558150129121286, 2.9097196190647114, 3.936832795462565, 4.92312668134256, 5.8580065455399435, 6.787593145640582, 7.726548469992604, 8.777602685149786, 9.68521651612475, 11.68259921706886, 12.561597114781003, 11.567896431621566, 10.63985884044354, 9.692594522949571, 8.688049990454756, 7.751768893224117, 6.724510703839401, 5.759940067819896, 4.819990737495818, 3.926342126703454, 2.9781778455301233, 3.873605880300455, 4.813004485358189, 5.842315654265165, 6.829992880724288, 7.757710463419852, 8.797913780991637, 9.766017518794776, 10.652655119609832, 12.620678919829086, 13.537066515703657, 12.566362882343231, 11.585237805844038, 10.627348923250162, 9.616469035735937, 8.643325104511831, 7.701190310907415, 6.696406150228354, 5.765751214808872, 4.892861057642798, 3.9676875989057554, 4.859313123656421, 5.746724982172505, 6.733711574405431, 7.729538012109296, 8.668921447411208, 9.743180075760726, 10.767873242603459, 11.63334364479286, 13.523070629645256, 14.492448393722775, 13.54832872763985, 12.561759609457447, 11.561091570542574, 10.651252231792684, 9.582792200076966, 8.591249399389403, 7.625369947505453, 6.726459576560243, 5.868250858702083, 5.026061299911262, 5.8833337081865835, 6.818382306239549, 7.690944803695569, 8.641753350390674, 9.626066751113196, 10.637688827240249, 11.602633675094236, 12.580685828657478, 14.44895539536638, 15.376908507312022, 14.528672598484118, 13.539393583895999, 12.528813789317072, 11.459066021635847, 10.526402887104775, 9.580957099332869, 8.576133953135455, 7.748455257028198, 6.819600416999611, 6.081030338660547, 6.953017744336245, 7.872687771852456, 8.651606235502307, 9.600798500886956, 10.564865510851593, 11.491679339364936, 12.465932651789963, 13.493350016973464, 15.44261237593473, 16.346472090234375, 15.587398282054718, 14.5320341469927, 13.466725358834923, 12.456973803458219, 11.473664853927193, 10.570347810490404, 9.601331094447119, 8.750803144830655, 7.869067868065707, 7.008567600805271, 7.995644932329779, 8.938401117473678, 9.682751722527556, 10.671879329431682, 11.586995572686321, 12.497282074595038, 13.45226506191164, 14.421834417159207, 16.35499072835109, 17.286739659808223, 16.443274905378605, 15.47515540561975, 14.401902233417823, 13.38724011484585, 12.43858839124617, 11.524093973017141, 10.588302804414287, 9.681927603454703, 8.928519789781783, 7.98914206018261, 8.931830658285403, 9.946615578991635, 10.61869460342112, 11.642959547480434, 12.626667054419102, 13.54817887684724, 14.430944838320423, 15.377514278854377, 17.32787267925233, 17.329203914357294, 16.282742633338025, 15.286547804099094, 14.450645861938368, 13.454599604014602, 12.70699699754882, 11.780805662597043, 11.190277100383353, 10.744043290796322, 9.89983884139834, 9.017110679269305, 9.955924061559964, 10.97063606259077, 11.582860700266258, 12.568867500592823, 13.583020211218482, 14.510444142459708, 15.454349921748832, 16.432622429432328, 17.365902027397006, 16.452212667628533, 15.399736020691684, 14.355677488886268, 13.454897036001485, 12.522573234295015, 11.732933077481913, 10.820643117988626, 10.130232284975385, 10.9668285732814, 10.903254697949027, 10.000684087963222, 10.893221914090493, 11.933050666892662, 12.534299594206283, 13.526872741547688, 14.506497054584855, 15.465453686818375, 16.473449595612955, 17.440539720882285, 16.365567357343913, 15.419746528246467, 14.441839652814549, 13.383011585979142, 12.451149594066116, 11.447769596731254, 10.728222341300826, 9.857296502011948, 9.13584155006492, 9.96775483731825, 10.914202206323463, 11.044337759789308, 11.851762850964315, 12.864183757697724, 13.54910236901337, 14.499809103995533, 15.505795974999486, 16.48462945214883, 17.444530086031047, 17.387265579253782, 15.549180444122946, 14.488527193895685, 13.460643228363312, 12.513622703737843, 11.469790410216955, 10.474555257121972, 9.654365789765047, 8.794863521381172, 8.073795350947588, 8.901426971813326, 9.898353307126694, 10.834992691287503, 11.761172325411378, 12.721829559955413, 13.618080341589438, 14.585701741529226, 15.536864102569675, 16.59256721363267, 17.445131100533253, 16.49917775267762, 14.571978042950374, 13.552943496185764, 12.529555293556625, 11.546936806069214, 10.521907787654703, 9.547423059944906, 8.680798295256361, 7.798798935590936, 7.020859925966965, 7.865476732763251, 8.883608598393131, 9.875855032489746, 10.748342053356303, 11.686232234111912, 12.638456136381922, 13.63023162502329, 14.64945860899732, 15.590310938440714, 16.5124347702015, 15.546436565826621, 13.560751145057159, 12.549066159321983, 11.588414194656067, 10.610793931474847, 9.66249874937083, 8.605107158682731, 7.745878475110246, 6.828199302812001, 5.990566495999932, 6.7925580752803185, 7.864125225145592, 8.888871177756137, 9.820367234409852, 10.710815579986932, 11.696160942528788, 12.66168926816968, 13.650954607255919, 14.591475123160585, 15.54730215508172, 14.619598125104778], [12.705976061371501, 13.664951316644432, 14.560653440687219, 13.647880332342048, 12.619645692711, 11.667950999761805, 10.676785512867173, 9.76823913293014, 8.828581995731039, 7.8210251294962605, 6.773889696641193, 5.941248260377861, 5.026921404594778, 5.925327475110509, 6.7067867106123975, 7.695264330733293, 8.652649809706885, 9.67702240693516, 10.669060833061355, 11.695798429411461, 11.711876428642402, 12.66785796246185, 13.570140562383216, 12.649466657309674, 11.589616263531841, 10.68874908144455, 9.726658809246985, 8.82479881513136, 7.77303618933795, 6.784217532308434, 5.830821843878555, 4.878968471564799, 3.9898472804843754, 4.962863884783137, 5.779658715041743, 6.7524917002575275, 7.766321010970958, 8.694642855635136, 9.620970837228827, 10.666096084382076, 10.692851369401069, 11.63400650922396, 12.590766101052552, 11.660803429695747, 10.661962996888416, 9.649149352545003, 8.723928709911466, 7.7722619864142235, 6.756598997631845, 5.830189420166381, 4.80997615041411, 3.8791831616249404, 2.9746316548088427, 3.9069879631352515, 4.831366135448913, 5.769999170975036, 6.713043045418987, 7.746835244516266, 8.69557268614566, 9.647402015817493, 9.740950895669448, 10.678364960689745, 11.652558920479029, 10.723949900974379, 9.684690389425004, 8.665820205853626, 7.717339428401053, 6.726230893998832, 5.7406805438405515, 4.9310638706141, 3.9589936258287937, 2.890818295804293, 2.0151087648808343, 2.919251663918495, 3.811460179507319, 4.855490508476197, 5.784009134916328, 6.7191272107230375, 7.709738497801214, 8.718321181723294, 8.8438860513569, 9.792847671220425, 10.670082110701898, 9.71193091392076, 8.702428467664664, 7.774888392321567, 6.729590895297454, 5.78888749601558, 4.748554433716179, 3.8645252347694052, 2.914885265381238, 1.951448595391743, 1.026772968723161, 1.9470984635833029, 2.8326309332777364, 3.85489330972647, 4.816602731934206, 5.745466081711408, 6.763875715938295, 7.8299966586475165, 7.835783957960878, 8.897523648440034, 9.724082009721984, 8.798695092078145, 7.7598656310442875, 6.7322858438690005, 5.795110390077936, 4.826580628881116, 3.8166010760809934, 2.889067264451278, 1.9429203727958049, 0.9905189715381612, 0.0, 0.928958948335124, 1.9067693182602543, 2.8860068409580593, 3.8133398418430504, 4.86970104853989, 5.922697619279633, 6.885440898700201, 8.756752705979524, 9.770924754935344, 10.732107231527461, 9.799530434344446, 8.730637368695179, 7.702599285948119, 6.857321066292876, 5.814075829234599, 4.804110163511273, 3.8308211723732404, 2.943512201555725, 2.014404578484675, 1.0657037709545587, 1.942628116809908, 2.8592492416892927, 3.8134283889460088, 4.775593486478108, 5.81666409958858, 6.825056393144972, 7.757611314712046, 9.722661104893826, 10.723120104310361, 11.714418308678898, 10.727549692557183, 9.755993217574575, 8.728750112885114, 7.833612513183755, 6.795457813167763, 5.737296093209211, 4.772295208983898, 3.904817906529844, 2.94633398445029, 2.098864741667401, 2.9463138239244038, 3.932607709804399, 4.867487574001782, 5.79707417410242, 6.736029498454442, 7.787083713611624, 8.69469754458659, 10.6920802455307, 11.743716898758258, 12.558415403159726, 11.6303778119817, 10.683113494487731, 9.678568961992916, 8.742287864762277, 7.715029675377561, 6.750459039358057, 5.810509709033979, 4.916861098241616, 3.9686968170682846, 3.062751002903145, 3.974381976589961, 4.858481514888725, 5.846158741347848, 6.773876324043412, 7.807394809453475, 8.775498547256614, 9.662136148071673, 11.630159948290926, 12.635299023553117, 13.556881853881393, 12.575756777382198, 11.617867894788322, 10.606988007274097, 9.633844076049991, 8.691709282445574, 7.686925121766515, 6.756270186347033, 5.88338002918096, 4.958206570443917, 4.048458246259111, 4.908102473404277, 5.853213419014048, 6.808276445812256, 7.747659881114167, 8.80168272062854, 9.812395291060803, 10.642824673254701, 12.601914206914838, 13.636586740738446, 14.538847699178012, 13.552278580995608, 12.551610542080734, 11.641771203330844, 10.573311171615126, 9.581768370927563, 8.615888919043613, 7.716978548098404, 6.858769830240245, 6.016580271449424, 5.072478830789273, 5.979759797471321, 6.810446648304185, 7.76125519499929, 8.71170947434218, 9.723331550469233, 10.68827639832322, 11.65952940592706, 13.534598118595364, 14.462551230541006, 15.48044410501595, 14.52991255543416, 13.519332760855232, 12.449584993174007, 11.516921858642934, 10.571476070871029, 9.566652924673615, 8.73897422856636, 7.810119388537773, 7.071549310198709, 6.142162866938934, 7.034065263084227, 7.771108080110922, 8.720300345495572, 9.650508234080577, 10.57732206259392, 11.551575375018947, 12.578992740202448, 14.528255099163713, 15.43211481346336, 16.485499807940094, 15.522553118530858, 14.457244330373083, 13.447492774996379, 12.464183825465353, 11.560866782028565, 10.59185006598528, 9.741322116368817, 8.859586839603868, 7.999086572343432, 7.188404138649451, 8.09977860870545, 8.802253567136171, 9.791381174040298, 10.672638295915306, 11.582924797824022, 12.537907785140625, 13.507477140388191, 15.440633451580075, 16.37238238303721, 16.293544151341298, 15.325424651582445, 14.464051893265902, 13.549931240695813, 12.849786740368392, 11.912112344270062, 11.578821775952449, 10.672446574992865, 9.919038761319943, 8.979661031720772, 8.124589864605074, 9.139374785311306, 9.738196448029736, 10.76246139208905, 11.726894245372756, 12.633821600076224, 13.516587561549407, 14.463157002083362, 16.413515402481313, 16.37178393160968, 15.32532265059041, 14.32912782135148, 13.493225879190755, 12.497179621266989, 11.814492588948887, 10.93171182211562, 11.887001713214232, 11.734562262334483, 10.8903578129365, 10.007629650807466, 9.148683267879635, 10.163395268910442, 10.702362544874873, 11.688369345201439, 12.702522055827098, 13.596086865688692, 14.539992644977817, 15.518265152661312, 16.408482044649393, 15.49479268488092, 14.442316037944071, 13.398257506138656, 12.497477053253872, 11.565153251547402, 10.84042866888198, 9.971549277507203, 10.975037247324709, 11.946624454588484, 11.893773669487187, 10.991203059501384, 10.085981120410164, 11.125809873212333, 11.653801438814899, 12.646374586156304, 13.62599889919347, 14.58495553142699, 15.559092318841937, 16.526182444111267, 15.4081473745963, 14.462326545498854, 13.484419670066936, 12.42559160323153, 11.493729611318503, 10.490349613983641, 9.835717932700895, 9.008202661530525, 9.980646512414244, 10.947550718625335, 11.904721177861624, 12.00504653062592, 11.044522057283986, 12.056942964017395, 12.668604213621986, 13.619310948604149, 14.625297819608102, 15.604131296757446, 16.53017280926003, 16.42984559650617, 14.591760461375333, 13.531107211148072, 12.503223245615699, 11.55620272099023, 10.512370427469342, 9.51713527437436, 8.761861381165115, 7.945769680899749, 8.95080142089848, 9.881222853120411, 10.888872278664856, 11.825511662825665, 11.976003820413538, 12.936661054957574, 13.708146682863655, 14.572176651267268, 15.523339012307718, 16.579042123370712, 16.48771111778564, 15.541757769930008, 13.614558060202759, 12.59552351343815, 11.572135310809012, 10.5895168233216, 9.56448780490709, 8.590003077197293, 7.7882938866564295, 6.949705095109513, 7.951154297783111, 8.855995704301412, 9.874127569931293, 10.866374004027907, 11.738861024894463, 12.676751205650074, 13.628975107920086, 14.620750596561452, 15.639977580535481, 16.499581703788245, 15.555014787453885, 14.589016583079006, 12.603331162309544, 11.591646176574368, 10.630994211908453, 9.65337394872723, 8.705078766623213, 7.6476871759351175, 6.853374066510314, 5.979105462330578, 6.920860867816078, 7.783077046818479, 8.854644196683754, 9.879390149294299, 10.810886205948012, 11.701334551525093, 12.686679914066952, 13.652208239707841, 14.64147357879408, 15.554130778568595, 14.634918673009732, 13.662178142357163], [11.777017113036376, 12.735992368309306, 13.631694492352093, 14.576839280677174, 13.548604641046126, 12.596909948096929, 11.605744461202299, 10.697198081265263, 9.757540944066163, 8.749984077831385, 7.702848644976317, 6.870207208712985, 5.955880352929902, 4.9963685267753855, 5.777827762277274, 6.766305382398169, 7.72369086137176, 8.748063458600036, 9.74010188472623, 10.766839481076335, 10.782917480307276, 11.738899014126726, 12.64118161404809, 13.5784256056448, 12.518575211866967, 11.617708029779674, 10.65561775758211, 9.753757763466481, 8.701995137673073, 7.713176480643558, 6.759780792213679, 5.807927419899923, 4.918806228819499, 4.033904936448013, 4.850699766706619, 5.823532751922404, 6.837362062635834, 7.765683907300012, 8.6920118888937, 9.73713713604695, 9.763892421065945, 10.705047560888836, 11.661807152717426, 12.589762378030873, 11.590921945223542, 10.578108300880126, 9.652887658246591, 8.701220934749347, 7.685557945966969, 6.759148368501505, 5.738935098749234, 4.808142109960064, 3.9035906031439667, 2.978029014800127, 3.9024071871137886, 4.841040222639912, 5.784084097083863, 6.817876296181142, 7.766613737810535, 8.718443067482369, 8.811991947334324, 9.749406012354621, 10.772263358256401, 11.652908849309503, 10.613649337760128, 9.59477915418875, 8.646298376736178, 7.6551898423339555, 6.669639492175675, 5.860022818949224, 4.887952574163918, 3.819777244139417, 2.9440677132159583, 1.9902927155833707, 2.882501231172195, 3.926531560141073, 4.855050186581204, 5.790168262387914, 6.78077954946609, 7.78936223338817, 7.9149271030217765, 8.863888722885301, 9.86380269751985, 10.640889862255884, 9.631387415999788, 8.70384734065669, 7.658549843632578, 6.7178464443507035, 5.677513382051303, 4.793484183104529, 3.8438442137163618, 2.880407543726867, 1.955731917058285, 1.0181395152481787, 1.9036719849426125, 2.925934361391346, 3.8876437835990822, 4.816507133376284, 5.834916767603171, 6.9010377103123925, 6.906825009625754, 7.968564700104911, 8.917802596539936, 9.727654040413267, 8.68882457937941, 7.6612447922041245, 6.72406933841306, 5.75553957721624, 4.745560024416117, 3.818026212786402, 2.871879321130929, 1.9194779198732852, 0.928958948335124, 0.0, 0.9778103699251304, 1.9570478926229353, 2.8843808935079265, 3.9407421002047665, 4.993738670944509, 5.956481950365077, 7.8277937576444, 8.84196580660022, 9.803148283192337, 10.728489382679568, 9.659596317030301, 8.631558234283244, 7.786280014628, 6.743034777569723, 5.733069111846397, 4.759780120708364, 3.872471149890849, 2.943363526819799, 1.9946627192896829, 1.0136691684747838, 1.9302902933541686, 2.884469440610885, 3.8466345381429843, 4.887705151253456, 5.896097444809848, 6.828652366376922, 8.793702156558702, 9.794161155975237, 10.785459360343774, 11.656508640892305, 10.684952165909698, 9.65770906122024, 8.76257146151888, 7.724416761502887, 6.666255041544335, 5.701254157319022, 4.8337768548649676, 3.8752929327854138, 3.027823690002525, 2.0173548755892794, 3.0036487614692753, 3.9385286256666583, 4.868115225767297, 5.807070550119319, 6.858124765276501, 7.765738596251467, 9.763121297195577, 10.814757950423136, 11.808458633582573, 12.559336760316825, 11.612072442822855, 10.60752791032804, 9.671246813097401, 8.643988623712685, 7.6794179876931805, 6.739468657369103, 5.84582004657674, 4.8976557654034085, 3.9848216333125697, 3.0454230282548367, 3.929522566553601, 4.917199793012724, 5.844917375708288, 6.878435861118351, 7.84653959892149, 8.733177199736549, 10.701200999955802, 11.706340075217993, 12.677043708578418, 13.504715725717322, 12.546826843123446, 11.535946955609221, 10.562803024385115, 9.620668230780698, 8.61588407010164, 7.685229134682157, 6.789885759215594, 5.864712300478551, 4.925752065399684, 3.9791435250691527, 4.924254470678924, 5.879317497477132, 6.818700932779043, 7.872723772293416, 8.88343634272568, 9.713865724919577, 11.672955258579714, 12.707627792403322, 13.651747458486248, 14.48123752933073, 13.480569490415858, 12.57073015166597, 11.502270119950252, 10.510727319262688, 9.544847867378738, 8.645937496433529, 7.76527556027488, 6.895988420095398, 5.949772649929846, 5.050800849136197, 5.881487699969061, 6.832296246664166, 7.782750526007057, 8.794372602134109, 9.759317449988096, 10.730570457591936, 12.60563917026024, 13.533592282205882, 14.551485156680826, 15.458871503769283, 14.448291709190357, 13.378543941509133, 12.44588080697806, 11.500435019206154, 10.495611873008741, 9.667933176901483, 8.716625118572408, 7.950957458844682, 7.019456686079508, 6.105106314749103, 6.842149131775798, 7.791341397160447, 8.721549285745454, 9.648363114258796, 10.622616426683823, 11.650033791867324, 13.59929615082859, 14.503155865128235, 15.556540859604969, 15.385675516905403, 14.48791250702113, 13.567014164503506, 12.889992566836018, 12.489825730363691, 11.520809014320406, 10.670281064703941, 9.766092569638502, 8.878494720989407, 8.065697957790025, 7.170819660370325, 7.873294618801047, 8.862422225705172, 9.743679347580182, 10.653965849488898, 11.608948836805501, 12.578518192053068, 14.51167450324495, 15.443423434702085, 15.364585203006174, 14.396465703247321, 13.535092944930778, 12.620972292360689, 11.92506902951704, 12.821061878976963, 12.507780724287574, 11.601405523327987, 10.825544491354577, 9.859069180366747, 9.001883683745648, 8.219285614370282, 8.809237499694612, 9.833502443753925, 10.797935297037633, 11.7048626517411, 12.587628613214283, 13.534198053748238, 15.484556454146189, 15.442824983274555, 14.396363702255286, 13.400168873016357, 12.56426693085563, 11.568220672931865, 10.885533640613765, 11.84066135682252, 12.795951247921133, 12.663521210669606, 11.796863542971135, 10.887037799453442, 10.025977087020209, 9.243306097969416, 9.77340359653975, 10.759410396866315, 11.773563107491974, 12.667127917353568, 13.611033696642693, 14.589306204326189, 15.479523096314269, 14.565833736545796, 13.513357089608947, 12.469298557803532, 11.568518104918748, 10.636194303212278, 9.911469720546858, 10.880498812214103, 11.88398678203161, 12.855573989295387, 12.800279399521822, 11.87061120814736, 10.963274939550736, 10.318186344907387, 10.724842490479775, 11.71741563782118, 12.697039950858347, 13.655996583091866, 14.630133370506814, 15.597223495776145, 14.479188426261176, 13.53336759716373, 12.555460721731812, 11.496632654896406, 10.56477066298338, 9.561390665648517, 8.906758984365773, 9.917152196237426, 10.889596047121145, 11.856500253332236, 12.833680126196747, 12.882340349766492, 11.921815876424558, 11.262204475613757, 11.739645265286862, 12.690352000269025, 13.696338871272978, 14.675172348422322, 15.601213860924906, 15.500886648171045, 13.66280151304021, 12.602148262812948, 11.574264297280575, 10.627243772655106, 9.583411479134218, 8.588176326039235, 7.832902432829992, 8.85471921560665, 9.859750955605382, 10.790172387827312, 11.817831226999978, 12.754470611160787, 12.85329763955411, 12.270354715355381, 12.77918773452853, 13.643217702932144, 14.594380063972594, 15.650083175035586, 15.558752169450518, 14.612798821594884, 12.685599111867635, 11.666564565103027, 10.643176362473888, 9.660557874986477, 8.635528856571966, 7.661044128862169, 6.859334938321306, 7.878664043444637, 8.880113246118235, 9.784954652636536, 10.803086518266415, 11.79533295236303, 12.667819973229587, 13.321581187663735, 13.758811939736047, 14.59868781943808, 15.616401929408779, 15.57062275545312, 14.626055839118761, 13.660057634743882, 11.67437221397442, 10.662687228239244, 9.702035263573329, 8.724415000392108, 7.77611981828809, 6.7187282275999936, 5.92441511817519, 6.908064410665702, 7.849819816151202, 8.712035995153602, 9.783603145018876, 10.80834909762942, 11.739845154283136, 12.630293499860219, 13.615638862402076, 14.581167188042967, 15.570432527129206, 14.62517183023347, 13.705959724674607, 12.73321919402204], [10.799206743111249, 11.75818199838418, 12.653884122426962, 13.644759263899545, 14.526415010971256, 13.57472031802206, 12.58355483112743, 11.675008451190394, 10.735351313991293, 9.727794447756516, 8.680659014901448, 7.848017578638116, 6.796451683493237, 5.788059250557428, 4.800017392352142, 5.788495012473039, 6.74588049144663, 7.770253088674906, 8.7622915148011, 9.789029111151208, 9.805107110382147, 10.761088644201596, 11.66337124412296, 12.611908465326652, 13.496385581792097, 12.595518399704805, 11.63342812750724, 10.731568133391612, 9.679805507598203, 8.690986850568688, 7.737591162138809, 6.7857377898250535, 5.842022832647325, 4.825595660230055, 3.872889396781488, 4.845722381997273, 5.859551692710704, 6.787873537374882, 7.714201518968572, 8.759326766121822, 8.786082051140815, 9.727237190963706, 10.683996782792295, 11.650162502955949, 12.568732315148672, 11.555918670805257, 10.630698028171722, 9.679031304674478, 8.663368315892098, 7.736958738426635, 6.716745468674365, 5.785952479885195, 4.840421503407233, 3.89889559045042, 2.9245968171886583, 3.863229852714782, 4.806273727158733, 5.8400659262560115, 6.788803367885405, 7.740632697557239, 7.834181577409194, 8.771595642429492, 9.794452988331273, 10.723062007835923, 11.591459707685258, 10.57258952411388, 9.624108746661308, 8.633000212259086, 7.647449862100805, 6.837833188874354, 5.865762944089047, 4.797587614064547, 3.880898613479225, 2.9183501731234744, 1.9046908612470648, 2.9487211902159425, 3.877239816656074, 4.812357892462783, 5.802969179540961, 6.811551863463041, 6.937116733096646, 7.886078352960171, 8.88599232759472, 9.915048156734843, 10.609197785924918, 9.68165771058182, 8.636360213557708, 7.695656814275833, 6.655323751976432, 5.7712945530296595, 4.821654583641492, 3.8582179136519974, 2.9335422869834153, 1.9461969727882824, 0.9258616150174821, 1.948123991466216, 2.9098334136739523, 3.8386967634511544, 4.8571063976780415, 5.923227340387264, 5.929014639700624, 6.99075433017978, 7.939992226614805, 8.865379144258645, 9.666634949304541, 8.639055162129253, 7.70187970833819, 6.733349947141369, 5.723370394341247, 4.795836582711532, 3.849689691056059, 2.8972882897984156, 1.9067693182602543, 0.9778103699251304, 0.0, 0.9792375226978051, 1.906570523582796, 2.962931730279636, 4.015928301019379, 4.978671580439947, 6.84998338771927, 7.864155436675089, 8.825337913267207, 9.832332391174782, 10.637406686955432, 9.609368604208372, 8.76409038455313, 7.720845147494853, 6.710879481771527, 5.737590490633495, 4.850281519815979, 3.9211738967449294, 2.9724730892148132, 1.9822538771342977, 0.9524799234290382, 1.9066590706857542, 2.868824168217854, 3.9098947813283256, 4.918287074884717, 5.850841996451791, 7.815891786633571, 8.816350786050107, 9.807648990418643, 10.817526493384552, 11.662762535834828, 10.635519431145369, 9.74038183144401, 8.702227131428018, 7.644065411469465, 6.679064527244153, 5.811587224790098, 4.853103302710544, 4.005634059927655, 2.9859395842487935, 2.025838391544145, 2.9607182557415275, 3.890304855842166, 4.829260180194189, 5.880314395351371, 6.787928226326336, 8.785310927270446, 9.836947580498006, 10.830648263657443, 11.758685854835468, 12.589882812747987, 11.585338280253172, 10.649057183022533, 9.621798993637817, 8.657228357618312, 7.717279027294233, 6.82363041650187, 5.859068806125911, 4.92042197059318, 3.981023365535447, 2.9517121966284705, 3.9393894230875937, 4.867107005783158, 5.900625491193221, 6.86872922899636, 7.755366829811418, 9.723390630030671, 10.728529705292862, 11.699233338653288, 12.680358415152483, 13.524637213048578, 12.513757325534353, 11.540613394310247, 10.59847860070583, 9.59369444002677, 8.663039504607287, 7.725486096496205, 6.800312637759162, 5.861352402680295, 4.914743862349763, 3.9464441007537934, 4.9015071275520015, 5.840890562853913, 6.894913402368285, 7.905625972800549, 8.736055354994447, 10.695144888654584, 11.729817422478192, 12.673937088561118, 13.708103269873757, 14.45837986034099, 13.5485405215911, 12.480080489875382, 11.488537689187819, 10.522658237303869, 9.62374786635866, 8.70087589755549, 7.831588757376008, 6.885372987210457, 5.969388892485737, 4.903677330043931, 5.8544858767390355, 6.804940156081926, 7.8165622322089785, 8.781507080062966, 9.752760087666806, 11.62782880033511, 12.555781912280752, 13.573674786755696, 14.612294544273894, 14.52752376493691, 13.64821771415374, 13.42369117690319, 12.478245389131285, 11.473422242933871, 10.63209483372154, 9.652225455853017, 8.886557796125294, 7.904892376603706, 6.899282621230441, 5.864338761850668, 6.8135310272353165, 7.743738915820323, 8.670552744333666, 9.644806056758693, 10.672223421942194, 12.621485780903459, 13.525345495203105, 14.578730489679838, 14.40786514698027, 13.510102137095998, 12.589203794578374, 13.501350759307503, 13.467636100288821, 12.498619384245536, 11.634442721523998, 10.701692906919112, 9.814095058270018, 8.951133648314224, 7.964995966851664, 6.895484248875917, 7.884611855780042, 8.765868977655051, 9.676155479563768, 10.63113846688037, 11.600707822127937, 13.53386413331982, 14.465613064776955, 14.386774833081041, 13.418655333322189, 12.557282575005646, 11.643161922435556, 12.536427221988525, 13.444937714378934, 13.485591094212705, 12.565567180148044, 11.761144828635187, 10.794669517647359, 9.870145604572864, 8.855360683866632, 7.831427129769482, 8.855692073828795, 9.820124927112502, 10.72705228181597, 11.609818243289153, 12.556387683823107, 14.506746084221058, 14.465014613349423, 13.418553332330154, 12.422358503091225, 11.586456560930499, 10.590410303006733, 11.49689183308525, 12.464537192224492, 13.419827083323105, 13.627682867489662, 12.732463880251744, 11.81303111661901, 10.790303578437973, 9.722392674266874, 8.795593226614619, 9.781600026941184, 10.795752737566843, 11.689317547428438, 12.633223326717562, 13.611495834401058, 14.501712726389137, 13.588023366620664, 12.535546719683815, 11.4914881878784, 10.590707734993616, 9.658383933287146, 10.522827913018343, 11.504374647616075, 12.507862617433581, 13.512947863106511, 13.735879736802431, 12.758421676627698, 11.727601430968502, 10.745177234675431, 9.747032120554644, 10.73960526789605, 11.719229580933217, 12.678186213166736, 13.652323000581683, 14.619413125851015, 13.501378056336044, 12.555557227238598, 11.57765035180668, 10.518822284971273, 9.586960293058247, 8.583580295723385, 9.518117176837256, 10.541028031639398, 11.513471882523117, 12.51387412714336, 13.574722606084228, 13.646666841184258, 12.686142367842324, 11.689195365381801, 10.761834895361732, 11.712541630343894, 12.718528501347848, 13.697361978497192, 14.623403490999776, 14.523076278245913, 12.684991143115077, 11.624337892887816, 10.596453927355443, 9.649433402729974, 8.605601109209086, 7.610365956114104, 8.554654154444474, 9.576470937221131, 10.581502677219863, 11.511924109441793, 12.558873706887459, 13.521606447256401, 13.617624130971876, 12.697345605123425, 11.8013773646034, 12.665407333007014, 13.616569694047463, 14.672272805110456, 14.580941799525386, 13.634988451669752, 11.707788741942505, 10.688754195177896, 9.665365992548757, 8.682747505061347, 7.657718486646835, 6.683233758937038, 7.651025662103349, 8.706604610876227, 9.708053813549824, 10.715618706477493, 11.780896888191545, 12.77314332228816, 13.645630343154718, 13.74857207743178, 12.781001569810917, 13.62087744951295, 14.638591559483649, 14.59281238552799, 13.64824546919363, 12.682247264818752, 10.69656184404929, 9.684876858314114, 8.724224893648199, 7.746604630466977, 6.79830944836296, 5.740917857674862, 6.716105841957233, 7.7360049780972915, 8.677760383582791, 9.689846365078733, 10.761413514944007, 11.786159467554551, 12.717655524208267, 13.60810386978535, 13.72329676366405, 14.58941980636656, 14.704311234688538, 13.647361460308339, 12.72814935474948, 11.755408824096909], [9.819969220413444, 10.778944475686375, 11.674646599729158, 12.66552174120174, 13.627448108888059, 14.553957840719866, 13.562792353825236, 12.6542459738882, 11.7145888366891, 10.70703197045432, 9.659896537599254, 8.827255101335922, 7.775689206191042, 6.767296773255232, 5.779254915049948, 5.0294809332917065, 5.857107607241709, 6.881480204469986, 7.783053992103297, 8.809791588453404, 8.825869587684343, 9.781851121503792, 10.684133721425155, 11.632670942628847, 12.5974186797089, 13.57475592240261, 12.612665650205047, 11.71080565608942, 10.65904303029601, 9.670224373266494, 8.716828684836615, 7.76497531252286, 6.82126035534513, 5.80483318292786, 4.852126919479293, 4.02360012874307, 4.9316599297524055, 5.859981774416584, 6.734963996270768, 7.780089243424017, 7.80684452844301, 8.747999668265901, 9.704759260094491, 10.670924980258144, 11.669765413065475, 12.535156193503063, 11.609935550869528, 10.658268827372284, 9.642605838589905, 8.716196261124441, 7.695982991372171, 6.765190002583001, 5.819659026105038, 4.878133113148225, 3.9038343398864632, 3.041107599460578, 3.858725663232621, 4.892517862329899, 5.809565845187601, 6.761395174859435, 6.85494405471139, 7.792358119731687, 8.815215465633466, 9.743824485138116, 10.783083996687491, 11.551827046811686, 10.603346269359115, 9.612237734956892, 8.626687384798611, 7.8170707115721605, 6.845000466786853, 5.776825136762353, 4.860136136177029, 3.8975876958212794, 2.8839283839448697, 2.0300313308741984, 2.929691752729962, 3.864809828536671, 4.823731656843156, 5.832314340765237, 5.957879210398842, 6.906840830262366, 7.906754804896915, 8.935810634037038, 9.867533919215074, 10.660895233279625, 9.615597736255513, 8.674894336973638, 7.634561274674239, 6.750532075727465, 5.8008921063392975, 4.837455436349803, 3.9127798096812203, 2.9254344954860874, 1.905099137715287, 0.9688864687684109, 1.9305958909761474, 2.8594592407533495, 3.8778688749802366, 4.9439898176894586, 4.949777117002819, 6.011516807481976, 6.960754703917001, 7.88614162156084, 8.924971082594697, 9.61829268482706, 8.681117231035996, 7.712587469839176, 6.702607917039053, 5.775074105409338, 4.828927213753865, 3.8765258124962205, 2.8860068409580593, 1.9570478926229353, 0.9792375226978051, 0.0, 0.9273330008849912, 1.983694207581831, 3.0366907783215744, 3.9994340577421426, 5.870745865021465, 6.884917913977284, 7.846100390569402, 8.853094868476976, 9.895742820245587, 10.588606126906178, 9.743327907250936, 8.70008267019266, 7.690117004469333, 6.716828013331301, 5.829519042513785, 4.900411419442735, 3.9517106119126177, 2.961491399832103, 1.9317174461268434, 1.067213806718767, 1.889586645520049, 2.9306572586305206, 3.939049552186912, 4.871604473753986, 6.836654263935765, 7.837113263352301, 8.828411467720839, 9.838288970686747, 10.809845445669355, 11.614756953843175, 10.719619354141816, 9.681464654125826, 8.623302934167272, 7.658302049941959, 6.790824747487903, 5.832340825408349, 4.98487158262546, 3.965177106946599, 3.0050759142419503, 2.1212729917745405, 2.9461609102883903, 3.885116234640413, 4.9361704497975945, 5.808690703628531, 7.806073404572639, 8.8577100578002, 9.851410740959636, 10.779448332137662, 11.726712649631631, 12.564575802950978, 11.62829470572034, 10.601036516335624, 9.636465880316118, 8.69651654999204, 7.802867939199675, 6.838306328823716, 5.899659493290986, 4.960260888233252, 3.930949719326276, 3.1496944137597813, 4.00431058484604, 4.956481545639445, 5.924585283442584, 6.776129307113613, 8.744153107332865, 9.749292182595056, 10.719995815955482, 11.701120892454675, 12.65900977504855, 13.49299484823216, 12.519850917008053, 11.577716123403636, 10.572931962724578, 9.642277027305095, 8.70472361919401, 7.779550160456967, 6.8405899253781, 5.893981385047568, 4.925681623451599, 4.111812118224189, 5.007005929906142, 5.950769456814509, 6.961482027246773, 7.756817832296641, 9.715907365956777, 10.750579899780385, 11.69469956586331, 12.728865747175949, 13.592752422340963, 14.527778044288908, 13.45931801257319, 12.467775211885627, 11.501895760001677, 10.602985389056467, 9.680113420253294, 8.810826280073814, 7.864610509908262, 6.948626415183543, 5.882914852741736, 5.174521763365356, 5.971055523134155, 6.981479078598071, 7.946423926452059, 8.773522564969, 10.659415191155416, 11.587368303101059, 12.605261177576002, 13.643880935094199, 14.016487479867367, 14.627455236851546, 14.402928699600999, 13.457482911829093, 12.45265976563168, 11.611332356419345, 10.631462978550822, 9.865795318823098, 8.884129899301511, 7.878520143928246, 6.843576284548473, 6.1508700432675125, 6.909854282872552, 7.836668111385895, 8.810921423810921, 9.7038098127625, 11.653072171723766, 12.556931886023412, 13.610316880500145, 13.854392397266572, 12.999065852026455, 13.56844131727618, 14.480588282005307, 14.44687362298663, 13.477856906943344, 12.613680244221802, 11.680930429616916, 10.793332580967823, 9.930371171012029, 8.944233489549468, 7.874721771573723, 7.221950871812238, 7.9319843447072795, 8.842270846615996, 9.797253833932599, 10.706689131756029, 12.652414634838722, 13.497199455597261, 13.779077070441716, 12.86518258360849, 12.046246289936102, 12.622399445133363, 13.51566474468633, 14.42417523707674, 14.464828616910513, 13.544804702845848, 12.740382351332991, 11.773907040345163, 10.84938312727067, 9.834598206564438, 8.810664652467288, 8.229589344019752, 8.98624029416473, 9.893167648868198, 10.775933610341381, 11.722503050875336, 13.62529658573996, 13.777475766213103, 12.776122746971645, 11.868885753377526, 11.075420275860955, 11.56964782570454, 12.476129355783055, 13.443774714922299, 14.39906460602091, 14.606920390187467, 13.711701402949549, 12.792268639316816, 11.76954110113578, 10.70163019696468, 9.774830749312425, 9.155497297132142, 10.003003530634096, 10.855432914480666, 11.79933869376979, 12.777611201453286, 13.644245738759148, 12.743253244970429, 11.781471580539296, 10.938015438164701, 10.049491901327658, 10.637621455984952, 11.502065435716148, 12.483612170313881, 13.487100140131387, 14.492185385804316, 14.715117259500236, 13.737659199325503, 12.706838953666306, 11.724414757373237, 10.72626964325245, 10.182833502471084, 11.004226155138902, 11.902799942268322, 12.818438367633911, 13.785528492903243, 12.643911068706055, 11.698090239608609, 10.823575212662162, 9.965349535257575, 9.045744459392289, 9.562817818421191, 10.497354699535062, 11.520265554337204, 12.492709405220923, 13.493111649841167, 14.553960128782032, 14.625904363882062, 13.665379890540128, 12.668432888079607, 11.741072418059538, 11.155769864918929, 12.003525075553533, 12.921975707598778, 13.789518858052004, 13.665609290615924, 11.756360219713137, 10.766870905257827, 9.83842764242927, 8.891407117803801, 8.064385275543128, 8.58960347881191, 9.533891677142279, 10.555708459918936, 11.560740199917667, 12.491161632139598, 13.538111229585263, 14.500843969954206, 14.59686165366968, 13.676583127821232, 12.780614887301207, 12.108635567582049, 12.958706983088756, 13.947110246925687, 13.610172744936742, 12.664219397081109, 10.743502315107797, 9.787888653341508, 8.845589473973703, 7.887386193733681, 7.000792693502248, 7.6624712816348435, 8.630263184801153, 9.685842133574031, 10.687291336247629, 11.694856229175297, 12.760134410889354, 13.752380844985968, 14.624867865852524, 14.727809600129586, 13.760239092508723, 13.064105684087984, 13.980728848524942, 13.619551594062495, 12.674984677728135, 11.708986473353256, 9.732275417214582, 8.720590431479406, 7.835452009443278, 6.886415788302667, 6.039295369181628, 6.720155380372668, 7.695343364655037, 8.715242500795096, 9.656997906280596, 10.66908388777654, 11.740651037641815, 12.76539699025236, 13.696893046906073, 14.587341392483156, 14.702534286361857, 14.032648040941595, 13.725073711990733, 12.668123937610535, 11.748911832051675, 10.782148032631413], [8.909613702329441, 9.868588957602372, 10.764291081645158, 11.75516622311774, 12.717092590804057, 13.655499706451963, 14.490125354710226, 13.58157897477319, 12.64192183757409, 11.634364971339313, 10.587229538484245, 9.754588102220914, 8.703022207076033, 7.694629774140224, 6.706587915934939, 5.886602212184492, 4.946752089157706, 5.971124686385982, 6.872698474019295, 7.8994360703694015, 7.9155140696003405, 8.871495603419788, 9.773778203341154, 10.722315424544846, 11.687063161624899, 12.676297788134708, 13.539998651090038, 12.638138656974409, 11.586376031181, 10.597557374151485, 9.644161685721606, 8.692308313407851, 7.7485933562301215, 6.7321661838128515, 5.7794599203642845, 4.880721407635855, 4.021304411668402, 4.94962625633258, 5.824608478186765, 6.869733725340015, 6.896489010359008, 7.837644150181899, 8.79440374201049, 9.760569462174143, 10.759409894981474, 11.772223539324887, 12.537268551754519, 11.585601828257275, 10.569938839474895, 9.643529262009432, 8.623315992257162, 7.692523003467992, 6.7469920269900285, 5.805466114033217, 4.831167340771454, 3.898228878353364, 2.948370145148618, 3.982162344245896, 4.8992103271035985, 5.851039656775432, 5.9445885366273865, 6.882002601647684, 7.904859947549463, 8.833468967054113, 9.872728478603488, 10.898170437526195, 11.530679270244105, 10.539570735841883, 9.554020385683602, 8.744403712457151, 7.772333467671844, 6.704158137647344, 5.78746913706202, 4.82492069670627, 3.811261384829861, 2.947854861086091, 2.019336234645959, 2.954454310452668, 3.9133761387591535, 4.921958822681233, 5.030546209513849, 5.979507829377374, 6.979421804011922, 8.008477633152046, 8.940200918330081, 10.006009088245285, 10.542930737140505, 9.602227337858631, 8.56189427555923, 7.677865076612456, 6.728225107224288, 5.7647884372347935, 4.840112810566211, 3.8527674963710785, 2.832432138600278, 1.896219469653402, 1.0202403728921445, 1.9491037226693466, 2.9675133568962337, 4.033634299605456, 4.022444116117827, 5.084183806596983, 6.033421703032008, 6.958808620675848, 7.997638081709704, 9.02521786888499, 9.608450231920989, 8.639920470724167, 7.629940917924044, 6.702407106294329, 5.756260214638855, 4.803858813381211, 3.8133398418430504, 2.8843808935079265, 1.906570523582796, 0.9273330008849912, 0.0, 1.0563612066968397, 2.109357777436583, 3.072101056857151, 4.943412864136473, 5.957584913092292, 6.91876738968441, 7.925761867591985, 8.968409819360595, 9.99553131096411, 10.670660908135929, 9.627415671077651, 8.617450005354325, 7.644161014216292, 6.7568520433987755, 5.8277444203277255, 4.879043612797609, 3.888824400717094, 2.8590504470118345, 1.9862434137640843, 0.9622536446350579, 2.0033242577455295, 3.0117165513019213, 3.9442714728689947, 5.909321263050774, 6.909780262467311, 7.9010784668358465, 8.910955969801755, 9.882512444784362, 10.93250747440023, 11.646952355026809, 10.608797655010816, 9.550635935052263, 8.58563505082695, 7.718157748372894, 6.75967382629334, 5.9122045835104515, 4.89251010783159, 3.9194116744121787, 2.948414509504038, 2.0188279094033996, 2.957783233755422, 4.008837448912604, 4.881357702743539, 6.878740403687648, 7.9303770569152086, 8.924077740074646, 9.852115331252671, 10.79937964874664, 11.803924181241456, 12.555627706605328, 11.528369517220613, 10.563798881201107, 9.62384955087703, 8.730200940084666, 7.7526420889939445, 6.813995253461214, 5.874596648403481, 4.845285479496504, 3.976835931489279, 3.0769775839610496, 4.029148544754454, 4.997252282557593, 5.848796306228621, 7.8168201064478735, 8.821959181710065, 9.792662815070491, 10.773787891569686, 11.731676774163562, 12.742556661677787, 13.447183917893042, 12.505049124288625, 11.500264963609567, 10.569610028190084, 9.619059379364238, 8.693885920627196, 7.754925685548328, 6.808317145217797, 5.840017383621827, 4.938953635953687, 4.079672929021151, 5.023436455929518, 6.034149026361782, 6.82948483141165, 8.788574365071787, 9.823246898895395, 10.767366564978321, 11.80153274629096, 12.665419421455974, 13.639047291092098, 14.386651013458179, 13.395108212770616, 12.429228760886666, 11.530318389941456, 10.594449180423522, 9.725162040244042, 8.77894627007849, 7.862962175353771, 6.797250612911965, 6.001663281094854, 5.043722522249165, 6.054146077713081, 7.019090925567069, 7.846189564084009, 9.732082190270427, 10.66003530221607, 11.677928176691013, 12.71654793420921, 13.70498908470406, 14.595080966640042, 15.330261700485988, 14.384815912714082, 13.379992766516668, 12.525668116589573, 11.54579873872105, 10.780131078993326, 9.798465659471738, 8.792855904098474, 7.757912044718702, 6.97801156099701, 5.9825212819875615, 6.909335110500904, 7.88358842292593, 8.776476811877512, 10.725739170838777, 11.629598885138423, 12.682983879615156, 12.944036879182569, 13.807537307444056, 14.495774318161171, 15.4079212828903, 15.374206623871618, 14.405189907828333, 13.52801600439203, 12.595266189787145, 11.707668341138051, 10.844706931182255, 9.858569249719697, 8.789057531743952, 7.957250618405593, 7.004651343822289, 7.914937845731006, 8.869920833047608, 9.77935613087104, 11.725081633953733, 12.569866454712272, 12.868721552357712, 11.954827065524487, 12.854717745353703, 13.549732446018353, 14.442997745571322, 15.351508237961731, 15.392161617795502, 14.459140463016077, 13.65471811150322, 12.688242800515392, 11.763718887440898, 10.748933966734667, 9.725000412637517, 8.964889090613106, 8.05890729327974, 8.965834647983208, 9.84860060945639, 10.795170049990345, 12.697963584854971, 12.867120248129101, 11.865767228887641, 10.958530235293523, 11.883891731278556, 12.49698082658953, 13.403462356668047, 14.37110771580729, 15.326397606905902, 15.521256150357695, 14.626037163119777, 13.706604399487045, 12.683876861306008, 11.61596595713491, 10.689166509482654, 9.890797043725495, 9.075670529749104, 9.928099913595675, 10.8720056928848, 11.850278200568296, 12.733890220675146, 11.832897726886427, 10.871116062455293, 10.027659920080698, 10.906613180220443, 11.564954456869943, 12.42939843660114, 13.410945171198872, 14.414433141016378, 15.419518386689308, 15.629453019670464, 14.651994959495731, 13.621174713836535, 12.638750517543466, 11.64060540342268, 10.918133249064436, 10.07689315425391, 10.975466941383331, 11.89110536674892, 12.858195492018252, 11.733555550622054, 10.787734721524608, 9.913219694578158, 9.054994017173572, 9.902865738285074, 10.490150819306182, 11.424687700420053, 12.447598555222195, 13.420042406105914, 14.420444650726157, 15.481293129667023, 15.540240124052291, 14.579715650710357, 13.582768648249836, 12.655408178229766, 11.89106961151228, 11.07619207466854, 11.994642706713787, 12.862185857167013, 12.755253772531923, 10.846004701629138, 9.856515387173825, 8.928072124345267, 7.981051599719798, 8.921506554435913, 9.5169364796969, 10.46122467802727, 11.483041460803927, 12.488073200802658, 13.418494633024588, 14.465444230470254, 15.428176970839196, 15.51119741383991, 14.59091888799146, 13.694950647471435, 12.8439353141754, 12.031373982203764, 13.019777246040697, 12.699817226852739, 11.753863878997105, 9.833146797023796, 8.877533135257506, 7.935233955889701, 6.977030675649678, 7.857913972395034, 8.589804282519834, 9.557596185686144, 10.613175134459023, 11.614624337132621, 12.62218923006029, 13.687467411774342, 14.679713845870957, 15.552200866737515, 15.642145360299814, 14.674574852678951, 13.799405430681336, 13.05339584763995, 12.709196075978491, 11.764629159644132, 10.798630955269253, 8.821919899130581, 7.810234913395404, 6.925096491359275, 5.976060270218664, 6.896416648074413, 7.647488381257659, 8.622676365540029, 9.642575501680088, 10.584330907165588, 11.59641688866153, 12.667984038526804, 13.692729991137348, 14.624226047791064, 15.514674393368146, 14.674228620757109, 13.749655137800898, 12.814718193906733, 11.757768419526535, 10.838556313967672, 9.87179251454741], [7.942778943630513, 8.901754198903443, 9.77491158984538, 10.765786731317963, 11.727713099004283, 12.666120214652189, 13.693464028270167, 14.634474606625409, 13.694817469426308, 12.670391191680704, 11.623255758825636, 10.681828257588244, 9.615764743476737, 8.607372310540928, 7.619330452335643, 6.793650175477163, 5.853800052450377, 5.119511327812712, 5.905863715320366, 6.9326013116704726, 6.9486793109014116, 7.882116111620014, 8.784398711541378, 9.73293593274507, 10.697683669825125, 11.686918296334934, 12.750347000833196, 13.69449986367125, 12.64273723787784, 11.633583594492876, 10.680187906062997, 9.720145832357847, 8.661335892630825, 7.6449087202135555, 6.6922024567649885, 5.787769370928526, 4.928352374961073, 4.089186491348432, 4.857773719487836, 5.902898966641086, 5.9181086992379095, 6.848264658382124, 7.805024250210715, 8.771189970374369, 9.7700304031817, 10.782844047525113, 11.808412614102417, 12.641963034954115, 11.626300046171735, 10.699890468706272, 9.679677198954002, 8.748884210164832, 7.714183484871615, 6.718208650433921, 5.743909877172158, 4.805276841646035, 3.855418108441289, 3.0757846463231635, 3.93237556840467, 4.884204898076503, 4.899760654240624, 5.837174719260921, 6.8600320651627005, 7.788641084667351, 8.827900596216725, 9.853342555139433, 10.801823332592004, 11.595931942538723, 10.610381592380442, 9.800764919153991, 8.828694674368684, 7.760519344344184, 6.84383034375886, 5.88128190340311, 4.8676225915267, 3.8549028243787617, 2.92638419793863, 2.0480766125299357, 2.946541380060225, 3.955124063982305, 3.97418500281701, 4.923146622680535, 5.923060597315083, 6.952116426455207, 7.883839711633242, 8.949647881548445, 9.95070785284082, 10.658588544555471, 9.61825548225607, 8.734226283309296, 7.784586313921128, 6.8211496439316335, 5.896474017263051, 4.9091287030679185, 3.888793345297118, 2.8889977583925517, 1.9272883361848154, 0.9984249864076133, 2.000678598197305, 3.066799540906527, 2.9660829094209875, 4.027822599900144, 4.977060496335169, 5.902447413979009, 6.941276875012865, 7.968856662188152, 8.906032115979215, 9.696281677421007, 8.686302124620884, 7.758768312991169, 6.812621421335695, 5.860220020078051, 4.86970104853989, 3.9407421002047665, 2.962931730279636, 1.983694207581831, 1.0563612066968397, 0.0, 1.0529965707397433, 2.0157398501603114, 3.9101136522160362, 4.924285701171856, 5.885468177763974, 6.892462655671549, 7.912048612663757, 8.939170104267271, 9.880791665462628, 10.68377687777449, 9.673811212051163, 8.70052222091313, 7.8132132500956155, 6.8841056270245655, 5.935404819494449, 4.945185607413934, 3.9154116537086745, 3.0409223196393933, 2.016932550510367, 0.9758619373998951, 1.9842542309562867, 2.9168091525233604, 4.88185894270514, 5.882317942121676, 6.86777925491541, 7.877656757881319, 8.849213232863926, 9.899208262479794, 10.857083112353507, 11.665158861707654, 10.606997141749101, 9.641996257523788, 8.774518955069734, 7.81603503299018, 6.9685657902072915, 5.9276922856381775, 4.8774465638743365, 3.906449398966196, 2.9768627988655574, 2.0379074745135344, 3.0348159303937727, 3.853895382397905, 5.851278083342014, 6.902914736569574, 7.896615419729011, 8.824653010907037, 9.771917328401006, 10.776461860895822, 11.71274295812646, 12.58473072391745, 11.620160087897945, 10.680210757573867, 9.771016119641516, 8.710676978456103, 7.772030142923372, 6.832631537865638, 5.803320368958662, 4.934870820951437, 4.035012473423207, 3.109272785512567, 4.023230764038762, 4.821333985882987, 6.789357786102239, 7.794496861364431, 8.765200494724857, 9.746325571224052, 10.704214453817928, 11.715094341332152, 12.688238272556259, 13.528434631161897, 12.484956743154683, 11.554301807735202, 10.577094268826396, 9.651920810089354, 8.712960575010486, 7.766352034679954, 6.798052273083985, 5.8969885254158445, 5.037707818483309, 4.103560696687631, 5.060127507842951, 5.802022511066015, 7.761112044726153, 8.79578457854976, 9.739904244632687, 10.774070425945325, 11.63795710111034, 12.611584970746463, 13.680045002462181, 14.379799992315732, 13.413920540431782, 12.515010169486574, 11.552484069885681, 10.683196929706199, 9.736981159540647, 8.820997064815929, 7.7552855023741225, 6.959698170557012, 6.001757411711322, 5.134270318471193, 6.099215166325181, 6.818727243738374, 8.704619869924793, 9.632572981870435, 10.65046585634538, 11.689085613863575, 12.677526764358426, 13.567618646294408, 14.50028178082548, 15.369507692259198, 14.364684546061785, 13.483703006051732, 12.503833628183209, 11.738165968455483, 10.756500548933897, 9.750890793560632, 8.71594693418086, 7.936046450459168, 6.940556171449719, 6.166921715388003, 7.0345680894333125, 7.749014491531876, 9.698276850493142, 10.602136564792788, 11.655521559269522, 12.722392507341752, 13.694948392199338, 14.626632565869773, 15.447543747647899, 16.358898403416735, 15.38988168737345, 14.48605089385419, 13.553301079249303, 12.665703230600208, 11.802741820644414, 10.816604139181855, 9.747092421206109, 8.915285507867752, 7.9626862332844475, 7.172524450618106, 8.02090049955499, 8.751893810525406, 10.697619313608099, 11.542404134366638, 12.04473401606477, 12.861875028817158, 13.761765708646372, 14.462474982419057, 15.355740281972025, 16.264250774362434, 16.376853397340618, 15.417175352478235, 14.612753000965379, 13.646277689977548, 12.721753776903055, 11.706968856196823, 10.683035302099674, 9.922923980075266, 9.016942182741898, 8.223421252870308, 8.999580275963773, 9.80746998449316, 11.670501264509337, 11.900285489430171, 11.041779692594698, 11.865578198586194, 12.790939694571225, 13.409723362990233, 14.31620489306875, 15.283850252207992, 16.239140143306603, 16.479291039819856, 15.584072052581936, 14.664639288949202, 13.641911750768164, 12.574000846597066, 11.64720139894481, 10.848831933187656, 10.033705419211262, 9.185686518482775, 10.06674861478906, 10.86257813507111, 11.767055461976216, 10.866062968187498, 10.04712852616235, 10.934707883373369, 11.813661143513114, 12.477696993270646, 13.342140973001843, 14.323687707599575, 15.327175677417081, 16.33226092309001, 16.587487909132623, 15.61002984895789, 14.579209603298693, 13.596785407005623, 12.598640292884836, 11.876168138526598, 11.034928043716068, 10.233053546270432, 11.08584828865318, 11.870495426521067, 10.766720791923124, 9.820899962825678, 9.089232158285215, 9.962041980466243, 10.809913701577745, 11.402893355706885, 12.337430236820756, 13.360341091622898, 14.332784942506617, 15.33318718712686, 16.394035666067726, 16.49827501351445, 15.537750540172516, 14.540803537711993, 13.613443067691923, 12.849104500974443, 12.0342269641307, 11.252229311600887, 12.056928779071272, 11.788419013832993, 9.879169942930208, 8.889680628474895, 8.104084588052324, 8.888099563012469, 9.828554517728584, 10.429679016097603, 11.373967214427973, 12.39578399720463, 13.400815737203361, 14.331237169425291, 15.378186766870957, 16.3409195072399, 16.469232303302068, 15.548953777453617, 14.652985536933592, 13.801970203637563, 12.989408871665923, 12.277363850927797, 11.73298246815381, 10.787029120298177, 8.866312038324866, 7.910698376558577, 7.083620597316431, 7.8840786389423485, 8.764961935687705, 9.502546818920537, 10.470338722086849, 11.525917670859728, 12.527366873533326, 13.534931766460993, 14.606528025104936, 15.59992424828108, 16.541059875953575, 15.63297377084529, 14.62714432281047, 13.702440630696987, 12.683213646722958, 11.742361317279563, 10.797794400945204, 9.831796196570325, 7.855085140431651, 6.843400154696475, 6.073483132786005, 6.883108233511335, 7.803464611367084, 8.560230917658362, 9.535418901940734, 10.555318038080793, 11.497073443566293, 12.5424789317415, 13.614046081606775, 14.63879203421732, 15.613085057007122, 14.718013066928087, 13.684849128957335, 12.760275646001125, 11.825338702106956, 10.768388927726757, 9.871721555268744, 8.904957755848482], [6.88978237289077, 7.848757628163701, 8.72191501910564, 9.712790160578223, 10.67471652826454, 11.613123643912445, 12.640467457530423, 13.655351562258055, 14.590675309776408, 13.566249032030804, 12.519113599175736, 11.577686097938344, 10.511622583826837, 9.503230150891028, 8.515188292685743, 7.671183074121682, 6.713797595148091, 5.853793272189479, 4.852867144580623, 5.87960474093073, 5.895682740161669, 6.829119540880271, 7.731402140801636, 8.679939362005328, 9.644687099085381, 10.63392172559519, 11.697350430093453, 12.6893462438871, 13.601827739226332, 12.529441434842976, 11.576045746413097, 10.616003672707947, 9.557193732980926, 8.540766560563656, 7.588060297115089, 6.683627211278626, 5.788349917658787, 4.860028072994609, 3.8047771487480935, 4.849902395901343, 4.865112128498167, 5.795268087642381, 6.752027679470972, 7.718193399634625, 8.717033832441956, 9.72984747678537, 10.755416043362674, 11.777304552789618, 12.620572533865392, 11.613317813334397, 10.593104543582127, 9.662311554792957, 8.610041325221715, 7.614066490784021, 6.6397677175222585, 5.701134681996135, 4.751275948791389, 3.894581967153351, 2.8793789976649267, 3.8312083273367605, 3.846764083500881, 4.784178148521178, 5.807035494422958, 6.735644513927608, 7.774904025476983, 8.800345984399689, 9.74882676185226, 10.739935296254483, 11.663378163120184, 10.820319396987099, 9.819868351290193, 8.751693021265693, 7.787789740169567, 6.8252412998138166, 5.79479099369774, 4.750760664728862, 3.82224203828873, 2.887123962482021, 1.8935448093204816, 2.9021274932425616, 2.921188432077267, 3.870150051940792, 4.870064026575339, 5.899119855715464, 6.830843140893498, 7.896651310808702, 8.897711282101076, 9.783872173570757, 10.671252052995811, 9.787222854049038, 8.83758288466087, 7.874146214671375, 6.94133219654648, 5.905003814843379, 4.884668457072579, 3.8566644336693874, 2.894955011461651, 1.966091661684449, 0.9476820274575619, 2.013802970166784, 1.9130863386812442, 2.9748260291604005, 3.9240639255954255, 4.849450843239265, 5.888280304273121, 6.915860091448408, 7.853035545239472, 8.821565306436293, 9.739298695360626, 8.81176488373091, 7.865617992075437, 6.913216590817794, 5.922697619279633, 4.993738670944509, 4.015928301019379, 3.036690778321574, 2.109357777436583, 1.0529965707397433, 0.0, 0.962743279420568, 2.857117081476293, 3.871289130432112, 4.83247160702423, 5.839466084931805, 6.859052041924013, 7.8861735335275265, 8.827795094722884, 9.860206069237076, 10.726807782790905, 9.753518791652873, 8.866209820835357, 7.9371021977643075, 6.988401390234192, 5.998182178153677, 4.968408224448417, 4.093008101492281, 3.0690183323632545, 2.027947719252783, 1.0195554256963915, 1.8921736091834092, 3.8572233993651888, 4.853571804352514, 5.8147826841756665, 6.824660187141575, 7.7962166621241815, 8.846211691740049, 9.804086541613763, 10.841588053170241, 11.659993712488843, 10.69499282826353, 9.827515525809476, 8.869031603729923, 8.021562360947035, 6.979778067491065, 5.929532345727224, 4.958535180819084, 4.028948580718445, 3.089993256366422, 2.0701171251338772, 2.829259839057954, 4.826642540002063, 5.874168598800412, 6.851932364419481, 7.779969955597506, 8.726977290623214, 9.73152182311803, 10.667802920348668, 11.695061109733384, 12.65963174575289, 11.733207328313611, 10.8231019014944, 9.762762760308988, 8.824115924776258, 7.884717319718526, 6.855406150811549, 5.986956602804325, 5.087098255276095, 4.125349575596079, 3.0585319587788664, 3.796698442543036, 5.764722242762288, 6.76986131802448, 7.740564951384905, 8.7216900278841, 9.679578910477975, 10.675160287412028, 11.648304218636135, 12.590439012240552, 13.537042525007571, 12.60638758958809, 11.629180050679285, 10.704006591942242, 9.765046356863374, 8.818437816532843, 7.850138054936872, 6.949074307268733, 6.089793600336196, 5.119637486771143, 4.095428702583056, 4.7773869677260645, 6.7364765013862025, 7.77114903520981, 8.715268701292736, 9.749434882605373, 10.613321557770387, 11.58694942740651, 12.655409459122229, 13.642248064682402, 14.46600632228467, 13.567095951339462, 12.60456985173857, 11.735282711559087, 10.789066941393536, 9.873082846668815, 8.80737128422701, 8.0117839524099, 7.05384319356421, 6.126656550153419, 5.161711702299431, 5.794091700398424, 7.679984326584841, 8.607937438530485, 9.625830313005428, 10.664450070523625, 11.652891221018475, 12.542983102954455, 13.475646237485527, 14.421092025257433, 15.416770327914673, 14.53578878790462, 13.555919410036097, 12.790251750308371, 11.808586330786785, 10.80297657541352, 9.768032716033748, 8.988132232312056, 7.9926419533026065, 7.071317937832589, 6.097064625407563, 6.724378948191926, 8.67364130715319, 9.577501021452838, 10.63088601592957, 11.697756964001801, 12.670312848859387, 13.60199702252982, 14.422908204307946, 15.450058647095807, 16.41907536313909, 15.538136675707078, 14.605386861102192, 13.717789012453096, 12.854827602497302, 11.868689921034743, 10.799178203058997, 9.967371289720639, 9.014772015137334, 8.076920673062691, 7.083397035529241, 7.727258267185455, 9.672983770268146, 10.517768591026687, 11.538350934316862, 12.506470434075714, 13.579723606277641, 14.548038894672638, 15.387831741626924, 16.325506137725252, 17.377680566956663, 16.469261134331123, 15.664838782818267, 14.698363471830437, 13.773839558755943, 12.759054638049712, 11.735121083952562, 10.975009761928153, 10.069027964594785, 9.102621430680758, 8.062076811938024, 8.78283444115321, 10.645865721169384, 10.84728891869043, 11.719352108431341, 12.70615616408816, 13.631517660073193, 14.305581203340333, 15.21206273341885, 16.179708092558094, 17.134997983656707, 17.531376821672744, 16.636157834434822, 15.71672507080209, 14.693997532621053, 13.626086628449954, 12.699287180797699, 11.900917715040542, 11.079427422739881, 10.064886696293225, 9.12924515076331, 9.83794259173116, 10.714058891236474, 9.813066397447756, 10.724700941998993, 11.775285848875335, 12.691194042157635, 13.373554833620746, 14.237998813351943, 15.219545547949675, 16.22303351776718, 17.22811876344011, 17.639573690985507, 16.662115630810778, 15.631295385151581, 14.64887118885851, 13.650726074737724, 12.928253920379483, 12.0712103563144, 11.112253724080881, 10.148344824627431, 10.845859883181117, 9.713724221183382, 8.767903392085936, 9.766804574121858, 10.802619945968209, 11.687446600222266, 12.298751196056985, 13.233288077170856, 14.256198931972998, 15.228642782856717, 16.22904502747696, 17.289893506417826, 17.55036079536734, 16.589836322025405, 15.59288931956488, 14.665528849544812, 13.901190282827327, 13.070509276729032, 12.104740854915285, 11.119425315045524, 10.73542244309325, 8.826173372190466, 7.836684057735153, 8.781657003888967, 9.728677528514435, 10.706087416373105, 11.325536856447703, 12.269825054778073, 13.29164183755473, 14.296673577553461, 15.227095009775391, 16.274044607221057, 17.23677734759, 16.48555356533934, 15.524896330795306, 14.553771957278242, 13.60340130245985, 12.652238941419402, 11.728569759524003, 10.679985897414069, 9.734032549558435, 7.813315467585125, 6.857701805818834, 7.761193013153074, 8.743811500640485, 9.642494834332226, 10.398404659270637, 11.366196562436949, 12.421775511209828, 13.423224713883426, 14.430789606811093, 15.502385865455036, 16.467420274659123, 15.52241015160654, 14.579977200105546, 13.574147752070726, 12.649444059957245, 11.630217075983216, 10.689364746539821, 9.744797830205462, 8.778799625830583, 6.802088569691909, 5.790403583956732, 6.751055548622648, 7.743105776209049, 8.680997510011604, 9.456088758008462, 10.431276742290834, 11.451175878430893, 12.392931283916393, 13.438336772091601, 14.509903921956875, 15.53464987456742, 14.594435332660089, 13.665016496188343, 12.631852558217592, 11.707279075261381, 10.772342131367216, 9.715392356987017, 8.818724984529002, 7.851961185108739], [5.964997279757901, 6.9216806074497255, 7.759171739685071, 8.750046881157651, 9.71197324884397, 10.650380364491877, 11.677724178109855, 12.692608282837487, 13.632265420036587, 14.528992311451368, 13.4818568785963, 12.54042937735891, 11.474365863247403, 10.465973430311594, 9.477931572106309, 8.63392635354225, 7.676540874568659, 6.816536551610048, 5.815610424001191, 5.188224042075044, 4.946091502111324, 5.866376261459702, 6.768658861381067, 7.717196082584758, 8.681943819664811, 9.671178446174622, 10.734607150672884, 11.726602964466531, 12.778365590259941, 13.49218471426354, 12.538789025833662, 11.578746952128512, 10.519937012401492, 9.503509839984222, 8.550803576535655, 7.646370490699194, 6.7510931970793555, 5.822771352415177, 4.767520428168662, 4.129462434187799, 3.9023688490775976, 4.832524808221812, 5.789284400050403, 6.755450120214056, 7.754290553021386, 8.767104197364802, 9.792672763942106, 10.81456127336905, 11.77866082078349, 12.576061092754964, 11.555847823002694, 10.625054834213524, 9.572784604642282, 8.576809770204587, 7.602510996942826, 6.663877961416702, 5.714019228211956, 4.857325246573919, 3.842122277085495, 3.091429923932532, 2.8840208040803126, 3.8214348691006097, 4.8442922150023895, 5.77290123450704, 6.812160746056414, 7.837602704979121, 8.786083482431692, 9.777192016833915, 10.762742366992196, 11.73946775782666, 10.782611630710761, 9.71443630068626, 8.750533019590135, 7.787984579234385, 6.757534273118308, 5.71350394414943, 4.784985317709298, 3.849867241902589, 2.85628808874105, 2.0308903159995984, 1.9584451526566988, 2.9074067725202233, 3.907320747154771, 4.936376576294895, 5.86809986147293, 6.933908031388134, 7.934968002680508, 8.821128894150187, 9.800754937451032, 10.744999410565, 9.800326164081438, 8.836889494091944, 7.904075475967048, 6.867747094263947, 5.8474117364931475, 4.819407713089956, 3.8576982908822193, 2.928834941105017, 1.91042530687813, 1.0606715000535665, 0.9503430592606761, 2.0120827497398324, 2.9613206461748574, 3.886707563818697, 4.925537024852553, 5.95311681202784, 6.890292265818903, 7.858822027015724, 8.868801579815846, 9.774508163151479, 8.828361271496005, 7.875959870238362, 6.885440898700201, 5.956481950365077, 4.978671580439947, 3.999434057742142, 3.072101056857151, 2.0157398501603114, 0.962743279420568, 0.0, 1.8943738020557248, 2.908545851011544, 3.8697283276036623, 4.876722805511237, 5.896308762503445, 6.923430254106958, 7.865051815302316, 8.897462789816508, 9.889306855757507, 10.71626207107344, 9.828953100255925, 8.899845477184876, 7.95114466965476, 6.919391028087779, 5.88961707438252, 4.935437927125804, 3.911448157996778, 2.8703775448863063, 1.8619852513299149, 0.9294303297628412, 2.8944801199446206, 3.8908285249319454, 4.852039404755099, 5.861916907721008, 6.833473382703614, 7.883468412319482, 8.841343262193195, 9.878844773749673, 10.852226620642828, 11.657736107684098, 10.790258805230044, 9.802125976352624, 8.848221370200042, 7.793352493328895, 6.743106771565054, 5.7721096066569135, 4.842523006556275, 3.903567682204253, 2.8525134670470713, 1.866516559637386, 3.863899260581495, 4.911425319379843, 5.889189084998915, 6.81722667617694, 7.764234011202646, 8.768778543697461, 9.7050596409281, 10.732317830312816, 11.696888466332322, 12.569798212503336, 11.636676327332232, 10.57633718614682, 9.637690350614088, 8.698291745556356, 7.668980576649379, 6.800531028642155, 5.900672681113925, 4.907745917509273, 3.8409283006920605, 2.833955163122468, 4.80197896334172, 5.807118038603912, 6.777821671964337, 7.758946748463531, 8.716835631057407, 9.71241700799146, 10.685560939215566, 11.627695732819983, 12.671173620827197, 13.41996201542592, 12.442754476517115, 11.517581017780072, 10.578620782701204, 9.632012242370672, 8.663712480774702, 7.762648733106563, 6.903368026174027, 5.854104603158666, 4.829411436315933, 3.8146436883054964, 5.773733221965634, 6.8084057557892415, 7.752525421872167, 8.786691603184805, 9.650578278349819, 10.624206147985943, 11.69266617970166, 12.679504785261834, 13.600137418104296, 14.380670377177292, 13.418144277576399, 12.548857137396919, 11.602641367231367, 10.686657272506647, 9.62094571006484, 8.770280899244659, 7.785967498522137, 6.7743454223950845, 5.809400574541097, 4.831348420977855, 6.717241047164273, 7.6451941591099155, 8.663087033584858, 9.701706791103057, 10.690147941597907, 11.580239823533887, 12.51290295806496, 13.458348745836865, 14.48944951517539, 15.34936321374245, 14.369493835873927, 13.603826176146203, 12.622160756624616, 11.61655100125135, 10.581607141871578, 9.687175096609021, 8.645820638587598, 7.719006810074254, 6.744753497649228, 5.7616356687713575, 7.710898027732623, 8.614757742032268, 9.668142736509001, 10.735013684581233, 11.707569569438819, 12.639253743109252, 13.460164924887378, 14.487315367675238, 15.456332083718523, 16.351711101544907, 15.418961286940021, 14.531363438290928, 13.668402028335134, 12.682264346872573, 11.612752628896827, 10.62054997500563, 9.667950700422326, 8.724609545304357, 7.731085907770906, 6.764514987764887, 8.71024049084758, 9.555025311606117, 10.575607654896292, 11.543727154655144, 12.616980326857071, 13.58529561525207, 14.425088462206356, 15.362762858304686, 16.414937287536098, 17.282835560168955, 16.478413208656097, 15.511937897668268, 14.587413984593773, 13.572629063887542, 12.548695509790392, 11.628188447213144, 10.722206649879777, 9.750310302922422, 8.709765684179688, 7.820091161732642, 9.683122441748818, 10.56577667128885, 11.578561978366363, 12.540023984886108, 13.465385480871142, 14.461431738794907, 15.424354871658942, 16.343163380459128, 17.29845327155774, 18.267131094351164, 17.449732260272654, 16.53029949663992, 15.507571958458882, 14.439661054287784, 13.512861606635528, 12.554096400325534, 11.727116294981546, 10.71257556853489, 9.776934023004973, 8.875199312310592, 10.180524711599695, 10.775809676868324, 11.687444221419561, 12.738029128295903, 13.653937321578203, 14.336298113041313, 15.200742092772508, 16.182288827370243, 17.18577679718775, 18.19086204286068, 18.45314811682334, 17.475690056648606, 16.44486981098941, 15.46244561469634, 14.464300500575554, 13.581432605664475, 12.718899228556065, 11.759942596322546, 10.796033696869094, 9.883116603760548, 9.180190041546602, 9.730646671506504, 10.729547853542426, 11.765363225388777, 12.650189879642834, 13.261494475477551, 14.196031356591423, 15.218942211393564, 16.191386062277285, 17.19178830689753, 18.25263678583839, 17.41481652239026, 16.454292049048327, 15.570303291116362, 14.583732303000891, 13.621413971863477, 12.682635755821755, 11.667761651911826, 10.682446112042065, 9.848028360304102, 8.214083393277322, 8.799427337155722, 9.744400283309535, 10.691420807935003, 11.668830695793673, 12.28828013586827, 13.232568334198639, 14.254385116975296, 15.259416856974028, 16.189838289195958, 17.236787886641622, 16.46381465403631, 15.522810285918773, 14.562153051374738, 13.591028677857674, 12.668548269200357, 11.727453848286531, 10.803784666391133, 9.755200804281198, 8.809247456425565, 7.201225488671981, 7.8204450852394025, 8.723936292573642, 9.706554780061053, 10.605238113752794, 11.361147938691204, 12.328939841857515, 13.384518790630395, 14.385967993303993, 15.393532886231661, 16.465129144875604, 15.504676995238553, 14.559666872185971, 13.617233920684978, 12.611404472650158, 11.713078152694422, 10.705431982850346, 9.764579653406951, 8.820012737072592, 7.854014532697713, 6.189998590778766, 6.7531468633773, 7.713798828043216, 8.705849055629617, 9.643740789432172, 10.418832037429029, 11.3940200217114, 12.41391915785146, 13.35567456333696, 14.401080051512167, 15.472647201377441, 14.605985076029324, 13.63169205323952, 12.702273216767775, 11.669109278797023, 10.744535795840811, 9.809598851946644, 8.752649077566447, 7.891647963815027, 6.92717609197587], [5.9586849632922725, 6.915368290984098, 7.752859423219443, 8.743734564692025, 9.705660932378343, 10.644068048026249, 11.671411861644227, 12.686295966371858, 13.625953103570959, 14.650379381316563, 15.376230680652025, 14.434803179414635, 13.368739665303128, 12.36034723236732, 11.372305374162034, 10.528300155597975, 9.570914676624383, 8.71091035366577, 7.709984226056915, 6.968862595252313, 4.939779185645697, 5.860063944994074, 6.76234654491544, 7.710883766119131, 8.675631503199185, 9.664866129708994, 10.728294834207256, 11.720290648000903, 12.772053273794313, 13.802200403024443, 14.433162827889387, 13.473120754184237, 12.414310814457217, 11.397883642039947, 10.44517737859138, 9.540744292754919, 8.64546699913508, 7.717145154470901, 6.6618942302243855, 5.979538396450812, 3.8960565326119703, 4.826212491756185, 5.7829720835847755, 6.749137803748429, 7.74797823655576, 8.760791880899173, 9.786360447476477, 10.808248956903421, 11.772348504317861, 12.779603224848856, 13.450221625058418, 12.519428636269248, 11.467158406698006, 10.471183572260312, 9.49688479899855, 8.558251763472427, 7.608393030267681, 6.751699048629643, 5.736496079141219, 4.941505886195546, 2.877708487614685, 3.815122552634982, 4.837979898536761, 5.766588918041411, 6.805848429590786, 7.831290388513493, 8.779771165966064, 9.770879700368287, 10.756430050526568, 11.733155441361031, 12.676985432766486, 11.608810102741986, 10.64490682164586, 9.68235838129011, 8.651908075174033, 7.607877746205155, 6.679359119765023, 5.744241043958313, 4.750661890796774, 3.900338201560838, 1.9521328361910713, 2.9010944560545955, 3.9010084306891435, 4.930064259829267, 5.861787545007303, 6.927595714922506, 7.928655686214881, 8.81481657768456, 9.794442620985405, 10.738687094099374, 11.671637971360765, 10.70820130137127, 9.783525674702688, 8.762120896319672, 7.741785538548871, 6.71378151514568, 5.752072092937944, 4.823208743160742, 3.804799108933855, 2.9550453021092915, 0.9440307427950486, 2.005770433274205, 2.95500832970923, 3.8803952473530696, 4.919224708386926, 5.946804495562213, 6.883979949353277, 7.852509710550097, 8.86248926335022, 9.790023074979935, 10.699673078775332, 9.747271677517688, 8.756752705979526, 7.827793757644401, 6.849983387719271, 5.8707458650214654, 4.943412864136474, 3.9101136522160362, 2.857117081476293, 1.8943738020557248, 0.0, 1.0141720489558192, 1.9753545255479374, 2.982349003455513, 4.051242069104779, 5.119980073967993, 6.061601635163349, 7.108697533281024, 8.11866319900435, 9.091952190142383, 9.933985714011119, 9.00487809094007, 8.022710249768505, 6.989102089592417, 5.959328135887158, 5.005148988630442, 3.9811592195014156, 2.940088606390944, 1.9316963128345521, 0.9991413912674786, 1.0112313732845917, 1.9964547228762206, 2.9576656026993744, 3.967543105665283, 4.9390995806478895, 5.9890946102637574, 6.968399106926224, 8.035777001241694, 9.081582963889671, 10.03342622675304, 10.895291418985238, 9.871837037857262, 8.91793243170468, 7.863063554833532, 6.812817833069691, 5.841820668161551, 4.912234068060912, 3.9732787437088897, 2.922224528551708, 1.9362276211420233, 1.9806505139214658, 3.0170515173241186, 3.9948152829431893, 4.922852874121214, 5.869860209146921, 6.8744047416417375, 7.810685838872377, 8.837944028257093, 9.802514664276599, 10.742463994600676, 11.67558587977178, 10.646048247651457, 9.707401412118726, 8.768002807060993, 7.738691638154017, 6.870242090146792, 5.970383742618562, 4.97745697901391, 3.9106393621966973, 2.903666224627105, 2.9187302166816913, 3.9238692919438827, 4.894572925304308, 5.875698001803502, 6.833586884397379, 7.818043205935736, 8.791187137159843, 9.73332193076426, 10.776799818771474, 11.688224471913731, 12.512465538021752, 11.58729207928471, 10.648331844205842, 9.70172330387531, 8.73342354227934, 7.8323597946112, 6.973079087678664, 5.923815664663303, 4.899122497820571, 3.8843547498101336, 3.9649521934725973, 4.933068509509606, 5.876538770600927, 6.903442856524776, 7.767329531689791, 8.740957401325915, 9.809417433041633, 10.78513098320611, 11.705763616048573, 12.648932833665103, 13.487855339081037, 12.618568198901556, 11.672352428736005, 10.756368334011285, 9.690656771569477, 8.839991960749296, 7.8556785600267744, 6.844056483899722, 5.879111636045734, 4.901059482482493, 4.921010030119203, 5.848963142064846, 6.8568826414451935, 7.881076830963329, 8.806899194937877, 9.696991076873859, 10.629654211404931, 11.575099999176837, 12.606200768515363, 13.531322098767369, 14.439204897378564, 13.67353723765084, 12.691871818129254, 11.686262062755988, 10.651318203376215, 9.756886158113659, 8.715531700092235, 7.788717871578892, 6.8144645591538655, 5.831346730275995, 5.914667010687553, 6.818526724987199, 7.871911719463933, 8.914383724441505, 9.82432082277879, 10.756004996449224, 11.57691617822735, 12.60406662101521, 13.573083337058495, 14.533669986569826, 15.48867234844466, 14.601074499795565, 13.738113089839771, 12.751975408377211, 11.682463690401464, 10.690261036510268, 9.737661761926963, 8.794320606808995, 7.8007969692755434, 6.834226049269525, 6.914009473802509, 7.758794294561048, 8.779376637851222, 9.747496137610074, 10.777140384869142, 11.702046868592042, 12.541839715546327, 13.479514111644658, 14.53168854087607, 15.464794445193874, 16.492248571360747, 15.581648959172906, 14.657125046098411, 13.64234012539218, 12.61840657129503, 11.697899508717782, 10.791917711384414, 9.82002136442706, 8.779476745684326, 7.88980222323728, 7.886891424703748, 8.76954565424378, 9.782330961321293, 10.743792967841038, 11.669154463826072, 12.665200721749837, 13.581375104449602, 14.4599146337991, 15.415204524897712, 16.383882347691138, 17.342527346762296, 16.600010558144557, 15.57728301996352, 14.509372115792422, 13.582572668140166, 12.623807461830172, 11.796827356486183, 10.782286630039527, 9.84664508450961, 8.83391063757645, 8.946136057046932, 9.803768175486454, 10.77698212775364, 11.674663283053864, 12.687745571482932, 13.597227091469424, 14.55543902451651, 15.420077178407517, 16.47524934030568, 17.389038152439216, 18.34594320331298, 17.545401118153244, 16.514580872494047, 15.532156676200978, 14.534011562080192, 13.651143667169112, 12.788610290060703, 11.829653657827183, 10.828276927187586, 9.841827929026406, 9.946470727100024, 10.848931180848274, 11.734878495630776, 12.64732918596099, 13.579191177874016, 14.597991740482547, 15.532528621596418, 16.383423794384196, 17.355867645267917, 18.35626988988816, 18.430637019969485, 17.408504205924633, 16.4479797325827, 15.563990974650734, 14.577419986535265, 13.61510165539785, 12.676323439356127, 11.661449335446198, 10.676133795576437, 9.841716043838474, 9.752932448514612, 10.693801139211446, 11.638774085365258, 12.585794609990726, 13.563204497849398, 14.182653937923995, 15.126942136254364, 16.14875891903102, 17.153790659029752, 18.084212091251683, 17.420235077939623, 16.45750233757068, 15.516497969453145, 14.55584073490911, 13.584716361392045, 12.662235952734731, 11.721141531820903, 10.797472349925505, 9.74888848781557, 8.802935139959937, 8.842502433815286, 9.714818887295127, 10.618310094629365, 11.600928582116776, 12.499611915808519, 13.255521740746929, 14.22331364391324, 15.27889259268612, 16.280341795359718, 17.287906688287386, 16.491760901949068, 15.498364678772925, 14.553354555720343, 13.61092160421935, 12.60509215618453, 11.706765836228795, 10.699119666384718, 9.758267336941323, 8.813700420606963, 7.847702216232085, 7.970637143956035, 8.647520665433024, 9.60817263009894, 10.600222857685342, 11.538114591487897, 12.313205839484754, 13.288393823767125, 14.308292959907185, 15.250048365392685, 16.295453853567892, 15.62441871217424, 14.599672759563695, 13.625379736773892, 12.695960900302147, 11.662796962331395, 10.738223479375185, 9.803286535481018, 8.746336761100821, 7.885335647349399, 6.920863775510242], [6.9728570122480935, 6.079062110657159, 6.903786233990593, 7.8946613754631745, 8.856587743149493, 9.794994858797399, 10.77048319042081, 11.78536729514844, 12.72502443234754, 13.749450710093145, 14.721867527611938, 15.448975228370454, 14.382911714258947, 13.374519281323138, 12.386477423117853, 11.542472204553794, 10.585086725580203, 9.72508240262159, 8.724156275012733, 7.983034644208134, 5.953951234601517, 5.023757764667136, 5.91327335568659, 6.861810576890281, 7.826558313970334, 8.815792940480144, 9.820356486800621, 10.812352300594268, 11.811989279418944, 12.82540398641942, 13.7787996748493, 14.487292803140058, 13.428482863413036, 12.412055690995766, 11.459349427547199, 10.554916341710738, 9.659639048090899, 8.731317203426721, 7.676066279180205, 6.993710445406633, 4.91022858156779, 3.9899063114292463, 4.933898894355925, 5.900064614519579, 6.89890504732691, 7.845885475193493, 8.817626387465102, 9.839514896892046, 10.795552087712839, 11.802806808243833, 12.795666506384736, 13.533600685225068, 12.481330455653826, 11.485355621216131, 10.51105684795437, 9.572423812428246, 8.6225650792235, 7.765871097585462, 6.750668128097038, 5.955677935151366, 3.891880536570505, 2.9788163723080436, 3.950054973045846, 4.878663992550496, 5.837114369579411, 6.862556328502118, 7.811037105954689, 8.802145640356912, 9.779633633921545, 10.756359024756009, 11.736607693631361, 12.581935594970952, 11.659078870601679, 10.696530430245929, 9.666080124129852, 8.622049795160974, 7.693531168720842, 6.758413092914132, 5.764833939752593, 4.914510250516658, 2.966304885146891, 2.0398024503303938, 2.8940733335009114, 3.923129162641035, 4.854852447819071, 5.920660617734274, 6.921720589026648, 7.807881480496328, 8.787507523797172, 9.731751996911141, 10.681391966299309, 11.642565894558402, 10.797697723658507, 9.776292945275491, 8.75595758750469, 7.727953564101499, 6.766244141893763, 5.837380792116561, 4.818971157889674, 3.9692173510651108, 1.958202791750868, 0.9988353360859729, 1.948073232520998, 2.8734601501648376, 3.912289611198694, 4.939869398373981, 5.877044852165044, 6.8455746133618645, 7.855554166161987, 8.783087977791702, 9.729234869447176, 10.68163627070482, 9.770924754935345, 8.841965806600221, 7.86415543667509, 6.884917913977285, 5.957584913092293, 4.924285701171856, 3.871289130432112, 2.908545851011544, 1.0141720489558192, 0.0, 0.9611824765921181, 1.9681769544996937, 3.03707002014896, 4.105808025012174, 5.047429586207532, 6.094525484325207, 7.104491150048533, 8.077780141186565, 9.14474487480255, 10.01905013989589, 9.036882298724326, 8.003274138548237, 6.973500184842978, 6.019321037586262, 4.995331268457235, 3.954260655346763, 2.9458683617903714, 2.013313440223298, 1.9827416733369376, 0.9822826739204015, 1.9434935537435547, 2.9533710567094635, 3.92492753169207, 4.974922561307938, 5.954227057970405, 7.021604952285875, 8.067410914933854, 9.019254177797222, 9.975855231156737, 10.886009086813083, 9.932104480660499, 8.877235603789352, 7.826989882025511, 6.8559927171173705, 5.926406117016732, 4.98745079266471, 3.9363965775075282, 2.950399670097843, 2.952160813973812, 2.0028794683682993, 2.9806432339873696, 3.9086808251653946, 4.855688160191102, 5.860232692685918, 6.796513789916558, 7.823771979301274, 8.78834261532078, 9.728291945644857, 10.661413830815961, 11.660220296607275, 10.721573461074543, 9.78217485601681, 8.752863687109835, 7.884414139102612, 6.984555791574382, 5.99162902796973, 4.924811411152517, 3.917838273582925, 3.8902405167340373, 2.9896420346326993, 3.9603456679931246, 4.9042759272384195, 5.819420611878413, 6.803871156979917, 7.777015088204024, 8.719149881808441, 9.762627769815655, 10.674052422957912, 11.630004827628593, 12.555178286365635, 11.66250389316166, 10.715895352831128, 9.747595591235157, 8.84653184356702, 7.987251136634484, 6.937987713619123, 5.91329454677639, 4.898526798765953, 4.936462493524943, 3.998841252198422, 4.942311513289744, 5.932020781959693, 6.753163259170825, 7.726791128806949, 8.795251160522666, 9.770958934250292, 10.691591567092754, 11.634760784709284, 12.605394628687877, 13.584220800107845, 12.686524477691822, 11.770540382967102, 10.704828820525295, 9.817779772779526, 8.833466372057003, 7.821844295929951, 6.856899448075963, 5.878847294512722, 5.873215923785374, 4.945262811839731, 5.922655384134011, 6.909654756398246, 7.792732922418912, 8.682824804354894, 9.615487938885966, 10.560933726657872, 11.592034495996398, 12.517155826248404, 13.497025204116927, 14.501774514362348, 13.706043867085071, 12.700434111711806, 11.665490252332033, 10.734673970143888, 9.693319512122464, 8.766505683609122, 7.7922523711840945, 6.809134542306224, 6.866872904353723, 5.914826394762084, 6.968211389238817, 7.9429616498764215, 8.810154550259824, 9.74183872393026, 10.562749905708385, 11.589900348496245, 12.55891706453953, 13.519503714050861, 14.487530352279148, 15.413056682418777, 14.752285138795589, 13.766147457333028, 12.696635739357282, 11.668048848540497, 10.715449573957192, 9.772108418839224, 8.778584781305772, 7.812013861299754, 7.86621536746868, 6.855093964335934, 7.875676307626108, 8.84379580738496, 9.762974112350177, 10.687880596073077, 11.527673443027362, 12.465347839125693, 13.517522268357105, 14.450628172674907, 15.478082298841779, 16.393631141796117, 15.671297095054229, 14.656512174347997, 13.632578620250847, 12.675687320748011, 11.769705523414643, 10.797809176457289, 9.757264557714555, 8.843691816965393, 8.807370704864226, 7.865845324018666, 8.87863063109618, 9.840092637615925, 10.733800126425324, 11.72984638434909, 12.567208831930637, 13.445748361280135, 14.401038252378747, 15.369716075172171, 16.32836107424333, 17.379967666448998, 16.591455068919338, 15.52354416474824, 14.596744717095984, 13.6015952738604, 12.74999707724628, 11.735456350799623, 10.791550571510498, 9.754389917736928, 9.86661533720741, 8.90006784526134, 9.873281797528527, 10.77096295282875, 11.759728500958621, 12.661872754068677, 13.541272751997546, 14.405910905888552, 15.461083067786715, 16.37487187992025, 17.331776930794014, 17.586099102214572, 16.555278856555375, 15.658935916128254, 14.73153797595825, 13.738964828616846, 12.826605478312466, 12.023440412338266, 11.033051546260834, 10.762307209186885, 10.866950007260503, 9.94523085062316, 10.831178165405662, 11.743628855735876, 12.675490847648902, 13.694291410257433, 14.545983488178631, 15.36925752186523, 16.34170137274895, 17.342103617369194, 17.535155305912976, 16.55726239302349, 15.596737919681553, 14.714917785421884, 13.728346797306415, 12.766028466169, 11.827306557897835, 11.00426464700781, 10.061971055842742, 10.855888092794295, 10.767104497470433, 10.876450184973942, 11.816325735638554, 12.763346260264022, 13.656850031498063, 14.652085184593046, 15.596373382923415, 16.431690502496007, 17.403747571866283, 17.566256004161872, 16.519306406716208, 15.556573666347266, 14.665256156552001, 13.70676754568026, 12.735643172163195, 11.813162763505881, 10.872124650362611, 9.9791301076809, 9.134725748081875, 9.817107188915758, 9.856674482771107, 10.728990936250945, 11.632482143585182, 12.615100631072593, 13.513783964764336, 14.269693789702748, 15.23748569286906, 16.293064641641937, 17.29451384431554, 16.662428489369596, 15.590832230725653, 14.597436007549508, 13.652425884496926, 12.7618484149905, 11.75601896695568, 10.857692646999945, 9.850102784926426, 8.909250455483031, 8.1154540645398, 8.861874265187906, 8.984809192911856, 9.661692714388842, 10.622344679054757, 11.614394906641161, 12.552286640443715, 13.327377888440573, 14.302565872722944, 15.322465008863004, 16.264220414348504, 15.731054877789223, 14.723490040950823, 13.698744088340279, 12.724451065550475, 11.79503222907873, 10.813723773102545, 9.889150290146334, 8.954213346252168, 7.897263571871971, 7.049029467022461, 7.935035824466063], [7.934039488840211, 7.008870095819409, 6.029533082382197, 7.020408223854778, 7.982334591541096, 8.920741707189002, 9.896230038812416, 10.911114143540047, 11.850771280739147, 12.875197558484752, 13.847614376003545, 14.758112407936128, 15.344094190851065, 14.335701757915256, 13.34765989970997, 12.503654681145912, 11.54626920217232, 10.686264879213708, 9.685338751604851, 8.944217120800252, 6.915133711193635, 5.984940241259254, 5.039020204078193, 5.987557425281884, 6.952305162361937, 7.941539788871747, 8.946103335192227, 9.938099148985874, 10.937736127810549, 11.951150834811028, 12.904546523240906, 13.695832619123065, 14.389665340005154, 13.373238167587884, 12.420531904139317, 11.516098818302856, 10.620821524683016, 9.69249968001884, 8.637248755772323, 7.95489292199875, 5.871411058159908, 4.951088788021365, 4.059645742747529, 5.025811462911182, 6.024651895718513, 6.971632323585099, 7.943373235856707, 8.965261745283652, 9.921298936104444, 10.928553656635438, 11.921413354776341, 12.696047309183205, 13.442512932245943, 12.446538097808249, 11.472239324546488, 10.533606289020364, 9.583747555815618, 8.72705357417758, 7.711850604689156, 6.9168604117434835, 4.853063013162623, 3.939998848900162, 3.07580182143745, 4.0044108409421, 4.962861217971016, 5.988303176893723, 6.936783954346295, 7.927892488748516, 8.90538048231315, 9.882105873147616, 10.862354542022967, 11.707682443362557, 12.620261347193797, 11.657712906838047, 10.62726260072197, 9.583232271753092, 8.65471364531296, 7.71959556950625, 6.726016416344711, 5.875692727108776, 3.9274873617390087, 3.000984926922512, 2.0198201818925154, 3.048876011032639, 3.9805992962106753, 5.046407466125879, 6.047467437418254, 6.9336283288879335, 7.913254372188778, 8.857498845302747, 9.807138814690914, 10.768312742950007, 11.758880200250623, 10.73747542186761, 9.717140064096808, 8.689136040693617, 7.727426618485881, 6.798563268708679, 5.780153634481792, 4.9303998276572285, 2.919385268342986, 1.960017812678091, 1.073820080912602, 1.9992069985564418, 3.038036459590298, 4.065616246765585, 5.002791700556649, 5.97132146175347, 6.981301014553592, 7.908834826183307, 8.85498171783878, 9.807383119096425, 10.732107231527461, 9.803148283192337, 8.825337913267207, 7.8461003905694024, 6.918767389684411, 5.885468177763974, 4.83247160702423, 3.8697283276036623, 1.9753545255479374, 0.9611824765921181, 0.0, 1.0069944779075755, 2.075887543556842, 3.1446255484200556, 4.086247109615412, 5.133343007733087, 6.1433086734564135, 7.116597664594446, 8.18356239821043, 9.11267002128148, 9.998064775316443, 8.964456615140355, 7.934682661435096, 6.9805035141783796, 5.956513745049353, 4.915443131938881, 3.9070508383824896, 2.974495916815416, 2.943924149929056, 1.9434651505125196, 0.9823110771514367, 1.9921885801173453, 2.9637450550999525, 4.0137400847158204, 4.993044581378287, 6.060422475693757, 7.106228438341734, 8.058071701205103, 9.014672754564618, 10.044599427247094, 10.893286957252617, 9.83841808038147, 8.78817235861763, 7.817175193709488, 6.88758859360885, 5.948633269256828, 4.897579054099646, 3.9115821466899607, 3.9133432905659298, 2.9640619449604175, 2.019460757395252, 2.947498348573277, 3.8945056835989846, 4.8990502160938005, 5.83533131332444, 6.862589502709156, 7.827160138728662, 8.76710946905274, 9.700231354223844, 10.760570495409256, 11.682755937666663, 10.74335733260893, 9.714046163701955, 8.84559661569473, 7.9457382681665, 6.952811504561848, 5.885993887744635, 4.879020750175043, 4.851422993326155, 3.9508245112248175, 3.0524357233805466, 3.943093450646302, 4.858238135286296, 5.842688680387799, 6.815832611611906, 7.757967405216323, 8.801445293223537, 9.712869946365794, 10.668822351036475, 11.593995809773517, 12.532956044852385, 11.677077829423247, 10.708778067827277, 9.807714320159137, 8.948433613226602, 7.89917019021124, 6.874477023368508, 5.859709275358071, 5.897644970117061, 4.96002372879054, 4.034401568677166, 4.970838305367575, 5.791980782578708, 6.765608652214832, 7.83406868393055, 8.809776457658174, 9.730409090500636, 10.673578308117166, 11.64421215209576, 12.623038323515727, 13.556976629382547, 12.73172285955922, 11.666011297117414, 10.778962249371643, 9.794648848649121, 8.783026772522069, 7.818081924668081, 6.84002977110484, 6.834398400377492, 5.90644528843185, 5.014745439521432, 5.948472279806128, 6.831550445826795, 7.721642327762776, 8.654305462293848, 9.599751250065754, 10.63085201940428, 11.555973349656286, 12.535842727524809, 13.54059203777023, 14.611586613627557, 13.661616588303925, 12.626672728924152, 11.695856446736006, 10.654501988714582, 9.72768816020124, 8.753434847776212, 7.770317018898342, 7.828055380945842, 6.876008871354203, 6.073471123092033, 6.981779173284304, 7.848972073667707, 8.780656247338142, 9.601567429116267, 10.628717871904128, 11.597734587947413, 12.558321237458744, 13.52634787568703, 14.451874205826659, 15.438951537351167, 14.727329933925148, 13.657818215949401, 12.629231325132615, 11.67663205054931, 10.733290895431342, 9.73976725789789, 8.773196337891871, 8.8273978440608, 7.8162764409280525, 7.11414659218308, 7.970988986942386, 8.801791635758061, 9.72669811948096, 10.566490966435245, 11.504165362533575, 12.556339791764987, 13.48944569608279, 14.51689982224966, 15.432448665204, 16.37513726330679, 15.617694650940116, 14.593761096842966, 13.636869797340129, 12.730888000006761, 11.758991653049407, 10.718447034306672, 9.804874293557512, 9.768553181456344, 8.827027800610784, 8.11710091565315, 8.96728581717335, 9.772617649833208, 10.768663907756974, 11.60602635533852, 12.484565884688017, 13.43985577578663, 14.408533598580053, 15.367178597651211, 16.41878518985688, 16.61832355747751, 15.735523165942134, 14.808723718289878, 13.892047882347388, 12.953574951208875, 12.196554288517525, 11.752733048102616, 10.715572394329046, 10.827797813799528, 9.861250321853458, 9.111752082085498, 9.898156132386175, 10.798546024366505, 11.70069027747656, 12.580090275405428, 13.444728429296434, 14.499900591194598, 15.41368940332813, 16.370594454201896, 16.711845950606175, 15.68102570494698, 14.784682764519857, 13.857284824349852, 12.864711677008447, 11.95235232670407, 11.14918726072987, 11.897161701930028, 11.723489685779002, 11.82813248385262, 10.906413327215278, 10.069648449962633, 10.870822035293301, 11.802293466301874, 12.775493915040322, 13.584801011586514, 14.408075045273112, 15.38051889615683, 16.380921140777073, 16.66090215430458, 15.683009241415093, 14.722484768073159, 13.840664633813487, 12.854093645698017, 11.891775314560602, 10.953053406289438, 10.130011495399414, 10.926081211511935, 11.817070569386413, 11.72828697406255, 11.83763266156606, 11.054796020195525, 11.944764452747075, 12.783652650151035, 13.748708254649603, 14.658657563122294, 15.470508025903888, 16.442565095274166, 16.692002852553475, 15.645053255107811, 14.68232051473887, 13.791003004943606, 12.832514394071863, 11.861390020554799, 10.938909611897483, 9.997871498754215, 9.104876956072504, 9.998835903751068, 10.778289665507875, 10.817856959363224, 11.690173412843063, 12.075260010931418, 12.948785376817195, 13.847245232191915, 14.67584045182667, 15.63222505763098, 16.466572611694122, 16.795740230688867, 15.788175337761201, 14.716579079117258, 13.723182855941113, 12.778172732888532, 11.887595263382103, 10.881765815347283, 9.983439495391547, 8.97584963331803, 8.034997303874635, 8.979564220208994, 9.823056741780023, 9.945991669503973, 10.62287519098096, 11.583527155646875, 12.575577383233279, 13.513469117035832, 14.28856036503269, 15.263748349315062, 16.28364748545512, 15.79794961509636, 14.85680172618083, 13.849236889342428, 12.824490936731884, 11.85019791394208, 10.920779077470335, 9.939470621494149, 9.014897138537936, 8.079960194643771, 7.023010420263574, 7.9788374521847105, 8.89621830105818], [8.846829848839073, 7.887854593566143, 6.9085175801289305, 6.243125681133904, 6.984009523906341, 7.922416639554247, 8.897858382522275, 9.912742487249904, 10.852399624449005, 11.876825902194609, 12.849242719713402, 13.759740751645985, 14.685026707882486, 15.342696235822832, 14.354654377617546, 13.510649159053488, 12.553263680079896, 11.693259357121283, 10.692333229512426, 9.857007480799114, 7.862091389624362, 6.911065050005633, 5.918004701824927, 5.201324280154357, 5.953980094727182, 6.943214721236992, 7.947731678902086, 8.939727492695733, 9.939364471520408, 10.952779178520885, 11.906174866950764, 12.697460962832924, 13.647952583772083, 14.38023264549546, 13.427526382046892, 12.523093296210432, 11.627816002590592, 10.699494157926415, 9.644243233679898, 8.901850600429476, 6.818368736590635, 5.877213596767744, 4.938630240494263, 4.211537201809865, 5.026326828083758, 5.973260667294958, 6.945001579566566, 7.96689008899351, 8.922927279814303, 9.930182000345297, 10.923041698486198, 11.697675652893064, 12.632736958096551, 13.453532575715824, 12.479233802454063, 11.54060076692794, 10.590742033723194, 9.734048052085155, 8.718845082596731, 7.8638180901742105, 5.8016470069560295, 4.866123657646541, 3.9547863191841834, 3.146982834704139, 3.9644895616808746, 4.989931520603582, 5.938412298056154, 6.929520832458375, 7.907008826023009, 8.883734216857473, 9.863982885732824, 10.709310787072416, 11.673214068168543, 12.635762508524293, 11.634257078629545, 10.590226749660667, 9.661708123220535, 8.726590047413826, 7.733010894252287, 6.824276720902183, 4.8760713555324156, 3.927109735668891, 2.898804679639249, 2.082464399006565, 2.9822276399205347, 4.0480358098357385, 5.049095781128113, 5.935256672597792, 6.914882715898637, 7.859127189012605, 8.808767158400771, 9.769941086659866, 10.804559222676215, 11.744469899775185, 10.724134542004384, 9.696130518601192, 8.734421096393456, 7.8055577466162545, 6.787148112389367, 5.92981417512439, 3.9263797462505616, 2.9020424750943605, 1.9528045786593353, 1.0274176610154955, 2.0396648033001576, 3.0672445904754446, 4.004420044266508, 4.972949805463329, 5.982929358263451, 6.910463169893166, 7.85661006154864, 8.809011462806284, 9.799530434344446, 10.72848938267957, 9.832332391174782, 8.853094868476978, 7.925761867591986, 6.892462655671549, 5.839466084931805, 4.876722805511237, 2.982349003455513, 1.9681769544996937, 1.0069944779075755, 0.0, 1.0688930656492666, 2.13763107051248, 3.079252631707837, 4.1263485298255125, 5.136314195548839, 6.109603186686871, 7.176567920302855, 8.105675543373904, 9.087843384545469, 9.97145109304793, 8.941677139342671, 7.987497992085955, 6.9635082229569285, 5.922437609846456, 4.914045316290065, 3.9814903947229916, 3.9509186278366313, 2.950459628420095, 1.9893055550590122, 1.0310769455814828, 2.0026334205640897, 3.0526284501799577, 4.031932946842424, 5.0993108411578945, 6.09923396043416, 7.051077223297529, 8.007678276657044, 9.037604949339519, 9.991509555492101, 10.845412558289045, 9.795166836525205, 8.824169671617064, 7.894583071516426, 6.955627747164403, 5.9045735320072215, 4.918576624597536, 4.920337768473505, 3.971056422867993, 3.0127556408832903, 2.0847180497052653, 2.933394049063122, 3.9379385815579377, 4.874219678788577, 5.901477868173293, 6.866048504192799, 7.805997834516877, 8.73911971968798, 9.799458860873393, 10.738105696406123, 11.677504301463856, 10.72104064160953, 9.852591093602305, 8.952732746074076, 7.959805982469423, 6.892988365652211, 5.886015228082618, 5.8584174712337305, 4.957818989132393, 4.0457306068685845, 3.0803131517782902, 3.897126500750433, 4.8815770458519365, 5.8547209770760436, 6.796855770680461, 7.840333658687674, 8.751758311829931, 9.707710716500612, 10.632884175237654, 11.571844410316523, 12.518452950647054, 11.715772545734852, 10.814708798066713, 9.955428091134179, 8.906164668118816, 7.881471501276083, 6.8667037532656465, 6.9046394480246365, 5.967018206698116, 5.027696452165204, 4.108058006499564, 4.830869148042845, 5.804497017678969, 6.872957049394687, 7.848664823122311, 8.769297455964773, 9.712466673581304, 10.683100517559897, 11.661926688979865, 12.595864994846686, 13.590110274714098, 12.67300577502499, 11.785956727279219, 10.801643326556697, 9.790021250429644, 8.825076402575657, 7.847024249012415, 7.841392878285068, 6.913439766339425, 6.00804032300947, 5.085691980938117, 5.870438811290932, 6.760530693226913, 7.6931938277579865, 8.638639615529891, 9.669740384868417, 10.594861715120423, 11.574731092988946, 12.579480403234367, 13.650474979091694, 14.644415740327004, 13.633667206831728, 12.702850924643581, 11.661496466622157, 10.734682638108815, 9.760429325683788, 8.777311496805918, 8.835049858853417, 7.883003349261778, 7.066766006580071, 6.1189988744162935, 6.8878604391318445, 7.819544612802278, 8.640455794580406, 9.667606237368267, 10.636622953411552, 11.59720960292288, 12.565236241151165, 13.490762571290794, 14.477839902815303, 15.5205820260806, 14.664812693856977, 13.63622580304019, 12.683626528456886, 11.740285373338917, 10.746761735805466, 9.780190815799447, 9.834392321968373, 8.823270918835627, 8.076328187833228, 7.108208688074376, 7.840680001222197, 8.765586484945095, 9.605379331899384, 10.543053727997714, 11.595228157229126, 12.528334061546929, 13.5557881877138, 14.471337030668135, 15.414025628770926, 15.761218581906515, 14.77456474750026, 13.819630767825025, 13.371785202616422, 12.765986130956982, 11.725441512214248, 10.811868771465086, 10.77554765936392, 9.83402227851836, 9.0792825113033, 8.10450551830534, 8.811506015297343, 9.80755227322111, 10.644914720802658, 11.523454250152156, 12.478744141250768, 13.447421964044192, 14.40606696311535, 15.457673555321017, 15.619951901187367, 14.73719809830738, 13.810398650655124, 12.893722814712635, 12.355021966147058, 13.075538786264259, 12.759727526010192, 11.722566872236621, 11.834792291707103, 10.868244799761033, 10.073933677735647, 9.035375833518165, 9.83743438983064, 10.739578642940696, 11.618978640869567, 12.483616794760573, 13.538788956658736, 14.452577768792269, 15.409482819666037, 15.713474294316036, 14.68265404865684, 13.786357696885103, 12.858959756715098, 11.866386609373693, 11.353799341642253, 12.028171758476603, 12.776146199676761, 12.730484163686578, 12.835126961760196, 11.913407805122853, 11.031830045612782, 10.008041736425291, 10.84118183176601, 11.814382280504457, 12.623689377050653, 13.44696341073725, 14.41940726162097, 15.419809506241213, 15.66253049801444, 14.684637585124952, 13.724113111783018, 12.842339566178733, 11.855768578063262, 10.893450246925848, 10.354500421227621, 11.008995993146147, 11.805065709258669, 12.729860929385275, 12.641077334061412, 12.844627139473635, 12.016977615845674, 11.081984153879064, 11.82254101561517, 12.787596620113739, 13.697545928586432, 14.509396391368027, 15.481453460738305, 15.693631196263338, 14.646681598817672, 13.68394885844873, 12.792631348653465, 11.834189326437109, 10.863064952920045, 9.940584544262729, 9.399318513692398, 9.983861453819237, 10.877820401497802, 11.691080025506738, 11.730647319362086, 12.697167890750638, 13.037441606581567, 12.086005077949185, 12.88613359765605, 13.714728817290805, 14.671113423095118, 15.505460977158263, 15.797368574398728, 14.78980368147106, 13.718207422827117, 12.724811199650972, 11.77980107659839, 10.889270195747349, 9.883440747712529, 8.985114427756793, 8.377296648256213, 8.913981801621368, 9.858548717955728, 10.735847101778885, 10.858782029502835, 11.629869668888535, 12.59052163355445, 13.086975483380199, 13.84763092197667, 14.65704471855298, 15.606033243241233, 15.637210765618287, 14.799577958806218, 13.858430069890687, 12.850865233052287, 11.826119280441743, 10.85182625765194, 9.922407421180194, 8.941145553859394, 8.016572070903182, 7.302677651922897, 7.901994918010308, 8.857821949931443, 9.809008661057042], [9.755508556740523, 8.796533301467592, 7.81719628803038, 6.943351097888122, 5.915116458257074, 6.8535235739049805, 7.828965316873008, 8.843849421600638, 9.783506558799738, 10.807932836545342, 11.780349654064135, 12.690847685996719, 13.616133642233219, 14.557950280867459, 14.620667612191006, 13.8801677861819, 13.572849637072103, 12.71284531411349, 11.711919186504634, 10.765686188700563, 8.78894633308092, 7.837919993462192, 6.826683409726376, 5.944937422855748, 4.885087029077916, 5.874321655587726, 6.878838613252819, 7.870834427046465, 8.870471405871143, 9.883886112871618, 10.837281801301497, 11.628567897183657, 12.579059518122817, 13.595486690540087, 14.4471123390391, 13.542679253202639, 12.6474019595828, 11.719080114918622, 10.663829190672105, 9.828705543886036, 7.745223680047194, 6.804068540224303, 5.847308948395712, 4.9562741952418214, 3.9574337624344915, 4.904367601645691, 5.876108513917299, 6.897997023344243, 7.854034214165037, 8.86128893469603, 9.854148632836933, 10.628782587243798, 11.563843892447284, 12.554605742091782, 13.49881975944627, 12.560186723920147, 11.610327990715401, 10.753634009077363, 9.738431039588939, 8.79067303363077, 6.783830544625282, 5.848307195315793, 4.863465027085633, 3.934856007580983, 2.895596496031608, 3.921038454954315, 4.869519232406887, 5.860627766809109, 6.838115760373744, 7.814841151208208, 8.79508982008356, 9.64041772142315, 10.604321002519276, 11.566869442875026, 12.542097548202497, 11.609812706652875, 10.681294080212743, 9.746176004406033, 8.752596851244494, 7.806460258571435, 5.858254893201668, 4.909293273338143, 3.880988217308501, 2.922837020527365, 1.9133345742712682, 2.9791427441864715, 3.980202715478846, 4.866363606948526, 5.845989650249371, 6.790234123363339, 7.739874092751506, 8.7010480210106, 9.735666157026948, 10.677735832278481, 11.563268301972915, 10.7157164755934, 9.754007053385664, 8.825143703608461, 7.806734069381575, 6.911997712793642, 4.945965703242769, 3.8842260127636123, 2.9349881163285874, 2.0096011986847477, 0.9707717376508911, 1.998351524826178, 2.9355269786172418, 3.9040567398140626, 4.914036292614186, 5.8415701042439006, 6.787716995899373, 7.740118397157017, 8.730637368695179, 9.659596317030303, 10.637406686955433, 9.895742820245587, 8.968409819360597, 7.912048612663757, 6.859052041924013, 5.896308762503445, 4.051242069104779, 3.03707002014896, 2.075887543556842, 1.0688930656492666, 0.0, 1.0687380048632138, 2.010359566058571, 3.0574554641762464, 4.067421129899573, 5.0407101210376055, 6.10767485465359, 7.03678247772464, 8.018950318896206, 9.052558479072294, 10.01057020499194, 9.056391057735222, 8.032401288606195, 6.991330675495723, 5.982938381939332, 5.050383460372258, 5.003500920122473, 4.003041920705937, 3.0067898268279114, 1.996912323862003, 1.0253558488793961, 2.0753508784952643, 2.9866510129494497, 4.038837448109411, 5.030340894784894, 5.9821841576482635, 6.938785211007778, 7.968711883690254, 8.922616489842838, 9.977485366713985, 10.864059902174471, 9.89306273726633, 8.963476137165692, 8.02452081281367, 6.973466597656488, 5.987469690246803, 5.888303866519598, 4.82511906920986, 3.831418386050423, 2.903380794872398, 1.956116477378428, 2.9606610098732444, 3.896942107103884, 4.9242002964886, 5.8887709325081055, 6.828720262832183, 7.761842148003288, 8.822181289188702, 9.760828124721431, 10.700226729779164, 11.72953789868614, 10.921484159251571, 10.021625811723343, 9.02869904811869, 7.961881431301477, 6.937667403481107, 6.81702071073645, 5.8118816354742595, 4.85886288815881, 3.8777378116596157, 2.9198489290657395, 3.904299474167243, 4.87744340539135, 5.819578198995767, 6.863056087002981, 7.774480740145237, 8.73043314481592, 9.655606603552963, 10.594566838631831, 11.541175378962363, 12.52816197119529, 11.88360186371598, 10.99143195857134, 9.91717333022182, 8.892480163379087, 7.87771241536865, 7.8196209333619615, 6.784948399538354, 5.840828733455429, 4.854259615273024, 3.8535915763581516, 4.827219445994275, 5.895679477709992, 6.871387251437618, 7.79201988428008, 8.735189101896609, 9.705822945875205, 10.684649117295173, 11.618587423161994, 12.612832703029406, 13.485395200485428, 12.700938212616544, 11.716624811894022, 10.70500273576697, 9.740057887912982, 8.76200573434974, 8.659323071125307, 7.731369959179664, 6.821172604299695, 5.831893589711577, 4.893161239606238, 5.783253121542219, 6.715916256073292, 7.661362043845198, 8.692462813183724, 9.61758414343573, 10.597453521304253, 11.602202831549674, 12.673197407407, 13.667138168642312, 14.446056632292166, 13.584767413661517, 12.543412955640093, 11.61659912712675, 10.642345814701724, 9.614928449518223, 9.652980051693657, 8.700933542102016, 7.879898287870296, 6.865200483189753, 5.91058286744715, 6.842267041117584, 7.663178222895712, 8.690328665683571, 9.659345381726856, 10.619932031238188, 11.587958669466474, 12.513484999606103, 13.500562331130611, 14.543304454395908, 14.641614562744557, 13.758376174383269, 13.565543017474821, 12.622201862356853, 11.58737712375932, 10.617807768511753, 10.652322514808613, 9.641201111675866, 8.822529796606688, 7.854410296847835, 6.863402429537503, 7.7883089132604, 8.628101760214689, 9.565776156313019, 10.617950585544431, 11.551056489862233, 12.578510616029105, 13.494059458983443, 14.436748057086234, 14.692325516257245, 13.705671681850992, 12.750737702175755, 13.734445209114423, 13.606601518910836, 12.566056900168102, 11.629798964305326, 11.593477852204158, 10.651952471358598, 9.75578476883661, 8.759589939597682, 7.834228443612649, 8.830274701536416, 9.667637149117963, 10.54617667846746, 11.501466569566073, 12.470144392359497, 13.428789391430655, 14.480395983636322, 14.5510588355381, 13.668305032658111, 12.741505585005855, 11.824829749063365, 12.778340481266397, 13.783441516782768, 13.57765771885043, 12.54049706507686, 12.652722484547342, 11.686174992601272, 10.750435935268959, 9.690460254810507, 8.860156818145947, 9.762301071256003, 10.641701069184872, 11.506339223075878, 12.561511384974041, 13.475300197107574, 14.432205247981342, 14.64458122866677, 13.613760983007573, 12.717464631235837, 11.79006669106583, 10.797493543724425, 11.777117856761592, 12.736074488995111, 13.68482490757821, 13.548414356526816, 13.653057154600434, 12.731337997963092, 11.708332303146094, 10.663126157717633, 9.863904260081316, 10.837104708819764, 11.646411805365958, 12.469685839052556, 13.442129689936275, 14.442531934556518, 14.593637432365174, 13.615744519475685, 12.655220046133751, 11.773446500529467, 10.786875512413994, 9.82455718127658, 10.778035747189133, 11.807929622874225, 12.713744417160118, 13.638539637286724, 13.549756041962862, 13.662557332313874, 12.684089099796875, 11.737068575171406, 10.845263443930477, 11.810319048429045, 12.720268356901737, 13.532118819683332, 14.50417588905361, 14.624738130614071, 13.577788533168405, 12.615055792799463, 11.723738283004199, 10.765296260787842, 9.794171887270778, 8.87169147861346, 9.82285383965391, 10.878556950716902, 11.786499109399251, 12.599758733408187, 12.639326027263536, 13.697439498040099, 13.704553090532768, 12.741089499241527, 11.908856025971357, 12.737451245606112, 13.693835851410423, 14.528183405473568, 14.728475508749462, 13.720910615821793, 12.64931435717785, 11.655918134001706, 10.710908010949124, 9.820377130098082, 8.814547682063262, 7.9162213621075255, 8.935448346081555, 9.822660509522818, 10.767227425857177, 11.644525809680335, 11.767460737404285, 12.649455625880742, 13.610107590546658, 13.74205990467254, 12.870353350291978, 13.679767146868286, 14.628755671556538, 14.56831769996902, 13.730684893156951, 12.78953700424142, 11.781972167403021, 10.757226214792476, 9.782933192002673, 8.853514355530928, 7.872252488210128, 6.9476790052539155, 7.936944344340155, 8.810673625911758, 9.766500657832893, 10.717687368958492], [10.782630048344036, 9.823654793071105, 8.844317779633894, 7.970472589491637, 6.942237949860589, 6.079207455495658, 6.965580788257661, 7.9804648929852915, 8.897979129517172, 9.892655627312386, 10.752311571317078, 11.66280960324966, 12.58809555948616, 13.5299121981204, 13.880118378964488, 14.868595999085384, 14.599971128675618, 13.739966805717005, 12.739040678108148, 11.792807680304076, 9.816067824684435, 8.865041485065706, 7.853804901329891, 6.972058914459263, 5.91220852068143, 5.100005537178403, 6.015454084637472, 7.007449898431118, 7.842433323124083, 8.85584803012456, 9.80924371855444, 10.600529814436598, 11.551021435375757, 12.567448607793027, 13.449159012199313, 14.4219919974151, 13.674523451186314, 12.746201606522137, 11.69095068227562, 10.855827035489552, 8.77234517165071, 7.831190031827817, 6.874430439999227, 5.983395686845336, 4.984555254038006, 4.060405808278856, 5.012723985301952, 5.969261256893679, 6.825996131417978, 7.833250851948972, 8.826110550089874, 9.600744504496738, 10.535805809700225, 11.526567659344723, 12.500866432606484, 13.439499468132608, 12.637449482318916, 11.780755500680877, 10.765552531192453, 9.817794525234286, 7.810952036228796, 6.8754286869193075, 5.8905865186891475, 4.961977499184497, 3.9227179876351226, 3.07707666158748, 4.00613470379154, 4.902193096904124, 5.810077677626684, 6.786803068461149, 7.767051737336499, 8.61237963867609, 9.576282919772217, 10.538831360127967, 11.514059465455437, 12.558089794424315, 11.708415571816257, 10.773297496009548, 9.779718342848009, 8.83358175017495, 6.885376384805182, 5.936414764941658, 4.908109708912016, 3.9499585121308796, 2.9404560658747827, 2.0211179684234777, 2.9521646327317868, 3.8383255242014664, 4.817951567502312, 5.7621960406162795, 6.711836010004447, 7.67300993826354, 8.707628074279889, 9.649697749531422, 10.535230219225856, 11.557492595674589, 10.78112854498918, 9.852265195211977, 8.83385556098509, 7.939119204397157, 5.973087194846284, 4.911347504367127, 3.962109607932102, 3.0367226902882622, 1.9978932292544056, 0.9703134420791185, 1.9074888958701823, 2.876018657067003, 3.885998209867126, 4.813532021496841, 5.759678913152314, 6.712080314409958, 7.702599285948119, 8.631558234283244, 9.609368604208374, 10.588606126906178, 9.995531310964111, 8.939170104267271, 7.886173533527527, 6.923430254106959, 5.119980073967993, 4.105808025012173, 3.1446255484200556, 2.13763107051248, 1.0687380048632138, 0.0, 0.9416215611953569, 1.9887174593130323, 2.998683125036359, 3.971972116174391, 5.038936849790375, 5.968044472861425, 6.9502123140329894, 7.983820474209078, 9.013594427914338, 9.967773575171055, 9.101139293469409, 8.060068680358937, 7.051676386802545, 6.119121465235471, 6.0542909277959405, 5.053831928379404, 4.057579834501379, 3.0477023315354703, 2.0761458565528637, 1.0261508269369959, 1.9179130080862359, 2.970099443246197, 3.961602889921679, 4.913446152785049, 5.870047206144564, 6.899973878827039, 7.853878484979622, 8.908747361850768, 9.958993083614608, 10.92999024852275, 10.032214142028906, 9.093258817676883, 8.042204602519702, 7.056207695110016, 6.939093874193066, 5.875909076883328, 4.882208393723891, 3.9541708025458657, 3.006906485051896, 2.0684819364120823, 2.984441900096221, 3.974147465253786, 4.938718101273292, 5.8786674315973695, 6.811789316768475, 7.872128457953888, 8.810775293486618, 9.75017389854435, 10.779485067451326, 11.767162293910449, 11.090363816586557, 10.088682129118329, 9.021864512301116, 7.988457411154576, 7.867810718409919, 6.862671643147728, 5.909652895832278, 4.928527819333084, 3.970638936739207, 3.012120400706081, 3.9676490642373303, 4.909783857841747, 5.953261745848961, 6.824427908910423, 7.780380313581107, 8.705553772318149, 9.644514007397017, 10.591122547727549, 11.578109139960477, 12.57393557766434, 12.042221966244806, 10.967963337895288, 9.943270171052555, 8.928502423042119, 8.87041094103543, 7.835738407211823, 6.891618741128897, 5.905049622946493, 4.904381584031619, 4.075884381614948, 5.016068263580331, 5.961592910283597, 6.88222554312606, 7.785136270661795, 8.755770114640391, 9.73459628606036, 10.66853459192718, 11.662779871794593, 12.535342369250614, 13.48615091594572, 12.76741481956749, 11.755792743440438, 10.79084789558645, 9.812795742023209, 9.710113078798774, 8.782159966853131, 7.871962611973164, 6.8826835973850455, 5.943951247279706, 5.031918057162892, 5.9645811916939655, 6.91002697946587, 7.832989548756062, 8.758110879008068, 9.70711967293792, 10.71186898318334, 11.738218628076842, 12.717085337407498, 13.496003801057352, 14.445196066442001, 13.59420296331356, 12.667389134800217, 11.69313582237519, 10.665718457191689, 10.703770059367123, 9.751723549775484, 8.930688295543764, 7.915990490863221, 6.9613728751206185, 6.090931976738257, 6.911843158516385, 7.9389936013042455, 8.858186690067726, 9.760458766810526, 10.72848540503881, 11.639406245328065, 12.626483576852573, 13.66922570011787, 13.92574888458894, 14.785497665986785, 14.616333025148288, 13.67299187003032, 12.638167131432786, 11.66859777618522, 11.70311252248208, 10.691991119349334, 9.873319804280156, 8.905200304521303, 7.914192437210971, 7.036973848881074, 7.876766695835362, 8.814441091933691, 9.845158400034894, 10.691583225434574, 11.719037351601445, 12.619980704705405, 13.562669302808196, 13.97645983810163, 12.989806003695374, 13.777859193779271, 14.761566700717939, 14.657391526584302, 13.616846907841568, 12.680588971978793, 12.644267859877626, 11.702742479032066, 10.80657477651008, 9.810379947271151, 8.885018451286118, 8.089725468309897, 8.916302084738636, 9.794841614088133, 10.750131505186745, 11.71880932798017, 12.677454327051327, 13.6479493237921, 13.687674306922752, 12.952439354502493, 12.025639906850238, 12.851951240666882, 13.805461972869914, 14.810563008386284, 14.628447726523898, 13.591287072750328, 13.70351249222081, 12.73696500027474, 11.801225942942429, 10.741250262483977, 9.910946825819416, 9.021751838029484, 9.890366004805543, 10.75500415869655, 11.810176320594714, 12.723965132728246, 13.680870183602014, 13.78119670005142, 12.750376454392224, 11.943148512826514, 11.074201012910212, 11.824615035327941, 12.804239348365108, 13.763195980598628, 14.711946399181723, 14.599204364200284, 14.703847162273902, 13.78212800563656, 12.759122310819563, 11.713916165391103, 10.914694267754784, 10.096555475593245, 10.895076740986628, 11.718350774673228, 12.690794625556947, 13.69119687017719, 13.730252903749825, 12.752359990860336, 11.791835517518402, 10.999130382120144, 10.059398238103125, 10.851678672880096, 11.805157238792649, 12.835051114477741, 13.740865908763631, 14.665661128890237, 14.576877533566375, 14.713347339987342, 13.734879107470345, 12.787858582844876, 11.896053451603946, 11.069769815202527, 11.968933292522408, 12.780783755304004, 13.75284082467428, 13.761353601998723, 12.714404004553057, 11.751671264184115, 10.86035375438885, 9.99098014237852, 9.019855768861456, 9.898812970216976, 10.849975331257426, 11.905678442320418, 12.813620601002764, 13.6268802250117, 13.666447518867049, 14.724560989643612, 14.755343098206238, 13.791879506914997, 12.959646033644825, 11.996902012379593, 12.942500787031094, 13.77684834109424, 13.732940240376925, 12.834417578977298, 11.785929828562502, 10.792533605386357, 9.847523482333775, 8.96554648104056, 8.04023156365394, 8.94334285371104, 9.96256983768507, 10.84978200112633, 11.79434891746069, 12.671647301283848, 12.794582229007798, 13.676577117484257, 14.637229082150172, 14.79284991234601, 13.921143357965445, 12.939217913641768, 13.877420607177209, 13.54027961722196, 12.702646810409892, 11.761498921494365, 10.918587638787672, 9.893841686177128, 8.919548663387324, 7.99012982691558, 7.097936369800806, 7.97480049685743, 8.96406583594367, 9.83779511751527, 10.793622149436406, 11.744808860562005], [11.724251609539394, 10.765276354266463, 9.785939340829252, 8.912094150686995, 7.883859511055946, 7.020829016691016, 6.120302568602419, 7.1351866733300495, 8.05270090986193, 9.047377407657144, 9.907033351661834, 10.817531383594417, 11.742817339830918, 12.684633978465158, 13.531008788114725, 14.519486408235622, 15.476871887209214, 14.681588366912361, 13.680662239303505, 12.734429241499434, 10.757689385879793, 9.806663046261065, 8.795426462525247, 7.913680475654621, 6.853830081876787, 6.041627098373761, 5.17017586498223, 6.162171678775876, 6.99715510346884, 8.010569810469317, 8.963965498899196, 9.755251594781356, 10.705743215720515, 11.722170388137785, 12.603880792544071, 13.576713777759858, 14.590543088473288, 13.687823167717493, 12.632572243470976, 11.797448596684909, 9.713966732846066, 8.772811593023174, 7.816052001194584, 6.925017248040694, 5.926176815233363, 5.002027369474213, 4.16744576564671, 5.123983037238437, 5.980717911762735, 6.9879726322937294, 7.98083233043463, 8.755466284841496, 9.690527590044983, 10.68128943968948, 11.655588212951242, 12.594221248477366, 13.544079981682112, 12.722377061876234, 11.70717409238781, 10.759416086429642, 8.752573597424153, 7.817050248114664, 6.832208079884505, 5.903599060379855, 4.86433954883048, 4.018698222782837, 3.160856484136298, 4.056914877248882, 4.964799457971441, 5.941524848805906, 6.921773517681256, 7.7671014190208485, 8.731004700116975, 9.693553140472725, 10.668781245800195, 11.712811574769074, 12.641330201209206, 11.714919057204904, 10.721339904043365, 9.775203311370307, 7.826997946000539, 6.878036326137014, 5.849731270107372, 4.891580073326236, 3.8820776270701396, 2.9627395296188346, 2.106886413076545, 2.9930473045462245, 3.972673347847069, 4.916917820961037, 5.866557790349204, 6.827731718608298, 7.8623498546246475, 8.80441952987618, 9.689951999570614, 10.712214376019347, 11.673923798227083, 10.793886756407332, 9.775477122180446, 8.880740765592513, 6.91470875604164, 5.852969065562483, 4.903731169127458, 3.9783442514836187, 2.9395147904497625, 1.9119350032744755, 1.06221067621494, 2.030740437411761, 3.0407199902118833, 3.9682538018415983, 4.914400693497072, 5.866802094754716, 6.857321066292877, 7.786280014628001, 8.764090384553132, 9.743327907250936, 10.670660908135927, 9.880791665462628, 8.827795094722884, 7.865051815302316, 6.06160163516335, 5.047429586207531, 4.086247109615413, 3.0792526317078375, 2.010359566058571, 0.9416215611953569, 0.0, 1.0470958981176754, 2.057061563841002, 3.030350554979034, 4.097315288595018, 5.026422911666068, 6.008590752837633, 7.0421989130137215, 8.071972866718982, 9.026152013975697, 10.042760854664767, 9.001690241554295, 7.9932979479979025, 7.060743026430829, 6.983736044412291, 5.983277044995755, 4.987024951117729, 3.977147448151821, 3.005590973169214, 1.9555959435533459, 0.976291446890879, 2.02847788205084, 3.019981328726322, 3.9718245915896917, 4.928425644949206, 5.958352317631682, 6.912256923784265, 7.9671258006554115, 9.017371522419252, 9.988368687327393, 10.91795528742803, 10.03488037887224, 8.983826163715058, 7.997829256305374, 7.868538990809416, 6.805354193499678, 5.811653510340241, 4.8836159191622155, 3.936351601668246, 2.9791014361315042, 2.0428203389008646, 3.0325259040584296, 3.997096540077935, 4.937045870402013, 5.870167755573118, 6.930506896758532, 7.869153732291262, 8.808552337348996, 9.837863506255971, 10.825540732715094, 11.753258315410658, 11.018127245734679, 9.951309628917466, 8.917902527770925, 8.797255835026268, 7.7921167597640775, 6.839098012448628, 5.857972935949434, 4.900084053355557, 3.922739900425503, 3.026027503041974, 3.968162296646391, 5.011640184653604, 5.882806347715067, 6.8387587523857505, 7.7639322111227935, 8.70289244620166, 9.649500986532193, 10.63648757876512, 11.632314016468984, 12.571697451770895, 11.897408454511638, 10.872715287668905, 9.857947539658468, 9.79985605765178, 8.765183523828172, 7.821063857745247, 6.834494739562842, 5.833826700647969, 4.98650388133437, 4.074446702384974, 5.019971349088241, 5.940603981930703, 6.843514709466438, 7.814148553445036, 8.792974724865005, 9.726913030731822, 10.721158310599236, 11.593720808055258, 12.544529354750363, 13.528842755472885, 12.685237860056787, 11.7202930122028, 10.742240858639558, 10.639558195415123, 9.71160508346948, 8.801407728589513, 7.812128714001395, 6.873396363896056, 5.942537556882314, 5.036284269315484, 5.98173005708739, 6.891367987560706, 7.816489317812712, 8.765498111742563, 9.770247421987984, 10.796597066881484, 11.775463776212142, 12.554382239861996, 13.503574505246645, 14.467641515211282, 13.596834251416567, 12.62258093899154, 11.595163573808039, 11.633215175983473, 10.681168666391834, 9.860133412160113, 8.84543560747957, 7.890817991736968, 6.966855185668929, 5.9835462361379035, 7.010696678925764, 7.91656512887237, 8.81883720561517, 9.786863843843456, 10.697784684132708, 11.684862015657217, 12.727604138922514, 13.585527726887245, 14.574655333791371, 15.48977157704601, 14.60243698664667, 13.567612248049135, 12.598042892801569, 12.63255763909843, 11.621436235965684, 10.802764920896506, 9.834645421137653, 8.843637553827321, 7.89712149705656, 6.94846977345688, 7.886144169555211, 8.903536838839537, 9.749961664239216, 10.777415790406087, 11.678359143510049, 12.62104774161284, 13.222563834678773, 13.93142756489073, 14.71948075497463, 15.703188261913297, 15.586836643200652, 14.546292024457918, 13.610034088595143, 13.573712976493976, 12.632187595648416, 11.73601989312643, 10.739825063887501, 9.814463567902468, 8.949873116485383, 7.988005162360154, 8.866544691709652, 9.821834582808265, 10.790512405601689, 11.748734842022644, 12.706327762596743, 12.84239608726751, 12.198543351079637, 12.967261468045594, 13.79357280186224, 14.747083534065272, 15.752184569581642, 15.557892843140248, 14.520732189366678, 14.63295760883716, 13.66641011689109, 12.730671059558778, 11.670695379100327, 10.840391942435765, 9.88189948620497, 8.962069082427062, 9.82670723631807, 10.881879398216233, 11.795668210349765, 12.752150698573331, 12.935918480396179, 11.905098234736982, 11.123663104141666, 12.015822574105568, 12.7662365965233, 13.745860909560466, 14.704817541793986, 15.653567960377082, 15.528649480816634, 15.633292278890252, 14.71157312225291, 13.688567427435913, 12.643361282007453, 11.844139384371134, 10.90131669972202, 9.966779818608149, 10.790053852294747, 11.762497703178466, 12.76289994779871, 12.884974684094583, 11.907081771205094, 10.94655729786316, 10.179644973435297, 11.001019799298481, 11.793300234075454, 12.746778799988007, 13.7766726756731, 14.68248746995899, 15.607282690085595, 15.518499094761733, 15.642792456603692, 14.664324224086695, 13.717303699461226, 12.825498568220295, 11.874531039331302, 11.040636370143929, 11.852486832925523, 12.824543902295801, 12.91607538234348, 11.869125784897815, 10.906393044528873, 10.015075534733608, 9.171494733693672, 9.961477330056812, 10.840434531412335, 11.791596892452784, 12.847300003515777, 13.755242162198122, 14.568501786207058, 14.608069080062407, 15.66618255083897, 15.684788214822587, 14.721324623531347, 13.776147964218165, 12.801663236508368, 12.014203864652615, 12.84855141871576, 12.887662020721683, 11.989139359322053, 10.94065160890726, 9.947255385731115, 9.002245262678533, 8.120268261385318, 8.981853124849296, 9.884964414906399, 10.904191398880428, 11.791403562321689, 12.735970478656048, 13.613268862479206, 13.736203790203156, 14.618198678679613, 15.578850643345529, 15.685940470642803, 14.737645288538786, 13.743979137770543, 12.94912368479873, 12.695001397566719, 11.85736859075465, 10.91622070183912, 10.07330941913243, 9.048563466521886, 8.074270443732082, 7.144851607260338, 8.039557930996162, 8.916422058052788, 9.905687397139028, 10.779416678710628, 11.735243710631764, 12.686430421757363], [12.756662584053586, 11.797687328780656, 10.818350315343444, 9.926162004217868, 8.89792736458682, 7.946232671637625, 6.955067184742996, 6.240824201964193, 7.042451861315035, 8.03712835911025, 8.896784303114941, 9.774286146536141, 10.69957210277264, 11.64138874140688, 12.487763551056448, 13.476241171177344, 14.433626650150936, 15.457999247379211, 14.713073213817697, 13.766840216013627, 11.790100360393986, 10.839074020775257, 9.827837437039442, 8.927748329185494, 7.867897935407661, 6.96703075332037, 6.004940481122807, 5.191176246102202, 5.9869060549219455, 7.000320761922423, 7.953716450352303, 8.712006357723078, 9.662497978662238, 10.678925151079508, 11.560635555485794, 12.53346854070158, 13.54729785141501, 14.475619696079187, 13.664983217985169, 12.829859571199101, 10.746377707360258, 9.805222567537367, 8.848462975708777, 7.9390851015715675, 6.940244668764237, 5.927431024420822, 5.002210381787287, 4.131883362627461, 4.9704688632158405, 5.977723583746835, 6.957394889109654, 7.712221047783219, 8.647282352986705, 9.638044202631203, 10.612342975892965, 11.550976011419088, 12.500834744623834, 13.55353033821803, 12.739585066902002, 11.791827060943834, 9.784984571938345, 8.849461222628857, 7.864619054398697, 6.936010034894047, 5.896750523344672, 4.944101877729446, 3.9956211002768747, 3.0648152026379054, 3.9545504094245465, 4.9312758002590105, 5.89833607635628, 6.723856181962571, 7.687759463058697, 8.650307903414447, 9.625536008741918, 10.669566337710796, 11.598084964150928, 12.533203039957638, 11.753750878557558, 10.8076142858845, 8.859408920514731, 7.910447300651207, 6.882142244621565, 5.9239910478404285, 4.914488601584332, 3.9869485262412345, 2.9416510292171214, 2.000947629935247, 2.9624242993001735, 3.9066687724141413, 4.843120349024228, 5.7844864815500205, 6.81910461756637, 7.761174292817902, 8.646706762512336, 9.668969138961069, 10.630678561168805, 11.559541910946008, 10.807888096694638, 9.913151740106706, 7.9471197305558325, 6.885380040076676, 5.936142143641651, 5.010755225997811, 3.971925764963955, 2.944345977788668, 2.0071705239976043, 1.0386407628007837, 2.0304709416649875, 2.9250085647833215, 3.8711554564387947, 4.823556857696438, 5.814075829234599, 6.743034777569723, 7.720845147494853, 8.700082670192659, 9.62741567107765, 10.68377687777449, 9.860206069237076, 8.897462789816508, 7.108697533281025, 6.094525484325206, 5.133343007733088, 4.1263485298255125, 3.057455464176246, 1.9887174593130323, 1.0470958981176754, 0.0, 1.0099656657233265, 1.9832546568613587, 3.0502193904773427, 3.9793270135483922, 4.961494854719957, 5.995103014896046, 7.024876968601305, 7.979056115858021, 9.003045884987047, 10.04411649809752, 9.040393846115576, 8.107838924548503, 8.030831942529966, 7.03037294311343, 6.034120849235404, 5.024243346269496, 4.052686871286889, 3.0026918416710218, 2.0233873450085547, 0.9813819839331646, 1.9728854306086467, 2.9247286934720162, 3.881329746831531, 4.9112564195140065, 5.865161025666589, 6.9200299025377365, 7.9702756243015775, 8.941272789209718, 9.870859389310356, 10.809814713662378, 10.030922061832733, 9.044925154423048, 8.885701214192096, 7.822516416882358, 6.828815733722921, 5.900778142544896, 4.953513825050926, 3.94896929255611, 3.0126881953254703, 1.985430005940754, 2.9500006419602594, 3.889949972284337, 4.823071857455442, 5.883410998640856, 6.822057834173586, 7.76145643923132, 8.790767608138296, 9.778444834597419, 10.706162417292983, 11.779737455626956, 10.968471852300146, 9.935064751153606, 9.803124893067201, 8.79798581780501, 7.827282184444585, 6.846157107945391, 5.888268225351515, 4.877388337837291, 3.9042444066131843, 2.962109613008767, 4.005587501015981, 4.835710449597391, 5.791662854268074, 6.716836313005117, 7.655796548083984, 8.602405088414516, 9.589391680647443, 10.585218118351307, 11.524601553653218, 12.598860182002738, 11.878584345709838, 10.863816597699401, 10.78804022964774, 9.753367695824132, 8.809248029741205, 7.822678911558801, 6.8220108726439275, 5.941152318746159, 4.952663605956184, 4.013918665450618, 4.93455129829308, 5.7964188113487625, 6.767052655327359, 7.745878826747327, 8.679817132614147, 9.67406241248156, 10.54662490993758, 11.497433456632686, 12.481746857355208, 13.49336893348226, 12.70847718419876, 11.730425030635518, 11.627742367411082, 10.69978925546544, 9.789591900585473, 8.800312885997354, 7.861580535892014, 6.847164307417767, 5.914501172886694, 5.0036263653940845, 5.8853153039230826, 6.810436634175089, 7.718402213624887, 8.723151523870307, 9.749501168763809, 10.728367878094465, 11.507286341744319, 12.456478607128968, 13.420545617093605, 14.347359445606948, 13.610765110987499, 12.583347745803998, 12.621399347979432, 11.669352838387793, 10.848317584156073, 9.83361977947553, 8.854823644616843, 7.845072089240139, 6.8617631397091134, 6.046042239075685, 6.910512445234747, 7.812784521977547, 8.767869664690982, 9.650688786015031, 10.63776611753954, 11.680508240804837, 12.538431828769568, 13.527559435673695, 14.442675678928333, 15.35296218083705, 14.555796420045093, 13.586227064797527, 13.620741811094389, 12.609620407961643, 11.790949092892465, 10.822829593133612, 9.790000519199742, 8.775338400627769, 7.82668667702809, 6.999788401602423, 7.897484155201915, 8.743908980601594, 9.771363106768465, 10.631263245392372, 11.573951843495163, 12.588736764201395, 13.474374709663133, 14.498639653722446, 15.482347160661114, 16.40385898308925, 15.534476196453875, 14.598218260591102, 14.561897148489935, 13.620371767644375, 12.68238285849885, 11.68618802925992, 10.760826533274889, 9.828090020056592, 8.866222065931364, 7.980188923756865, 8.935478814855477, 9.806024667943213, 10.742682158385023, 11.659231864479066, 12.051596918517493, 13.033307967220214, 13.892665122992204, 14.807640655393115, 15.761151387596145, 16.766252423112515, 16.54607701513621, 15.508916361362637, 15.621141780833119, 14.654594288887049, 13.677034024931197, 12.617058344472746, 11.786754907808186, 10.76011638977618, 9.840285985998271, 8.940351468365282, 9.995523630263445, 10.811180472691289, 11.74609801493571, 12.106336464569882, 11.114299065986966, 11.958427720282243, 12.941226229052178, 13.780304450054173, 14.75992876309134, 15.71888539532486, 16.685978934891274, 16.516833652812593, 16.621476450886213, 15.682556510162335, 14.634930392808332, 13.589724247379872, 12.790502349743555, 11.779533603293228, 10.844996722179356, 9.90369808434196, 10.876141935225679, 11.810254208654438, 12.029303495163365, 11.062682792743797, 10.155758129113144, 11.014409589575873, 11.926423454245091, 12.807368087606328, 13.76084665351888, 14.790740529203973, 15.714898444473182, 16.63969366459979, 16.550910069275925, 16.613775844513118, 15.610687189459114, 14.663666664833645, 13.747983095997492, 12.75274794290251, 11.918853273715136, 10.966131064972735, 11.938188134343012, 12.014840549825236, 11.013454595966596, 10.050721855597654, 9.224276365983592, 10.006259349834249, 10.886880985003422, 11.854502384943208, 12.805664745983657, 13.86136785704665, 14.787653136712315, 15.60091276072125, 15.6404800545766, 16.698593525353164, 16.63115118019501, 15.667687588903766, 14.654364867789372, 13.679880140079575, 12.892420768223822, 11.962195650762972, 11.844416783663407, 10.97889031077516, 10.084980419976041, 9.091584196799896, 8.211446093928517, 8.955032877525895, 9.907256779795906, 10.899032268437272, 11.918259252411302, 12.823814536835881, 13.76838145317024, 14.645679836993398, 14.768614764717348, 15.650609653193806, 16.411971052352502, 15.434350789171281, 14.486055607067264, 13.428664016379168, 12.569435332806686, 11.651756160508441, 10.814123353696374, 9.905971653292227, 9.107292504477552, 8.10460034206629, 7.283471274982066, 7.979616223400915, 8.964961585942772, 9.930489911583662, 10.919755250669901, 11.811827653224821, 12.767654685145956, 13.718841396271555], [13.730733225388178, 12.771757970115248, 11.792420956678036, 10.851784532202714, 9.823549892571666, 8.871855199622471, 7.880689712727842, 6.972143332790808, 6.032486195591708, 7.027162693386923, 7.886818637391613, 8.764320480812813, 9.689606437049314, 10.631423075683553, 11.477797885333121, 12.466275505454018, 13.42366098442761, 14.448033581655885, 15.448959709264741, 14.740910857348219, 12.772510734405277, 11.821407141032996, 10.801908078374032, 9.85337085717034, 8.793520463392507, 7.892653281305217, 6.9305630091076535, 6.028703014992027, 4.976940389198618, 5.990355096199096, 6.943750784628975, 7.702040691999751, 8.652532312938911, 9.668959485356181, 10.550669889762467, 11.523502874978254, 12.537332185691684, 13.46565403035586, 14.4250810007401, 13.812269945210392, 11.72878808137155, 10.787632941548658, 9.830873349720067, 8.864707629556413, 7.865867196749083, 6.853053552405669, 5.927832909772134, 4.976166186274892, 3.960503197492513, 4.967757918023508, 5.947429223386328, 6.702255382059892, 7.637316687263379, 8.628078536907877, 9.602377310169638, 10.541010345695762, 11.490869078900507, 12.543564672494703, 13.499682849656933, 12.774237434955126, 10.776828637879346, 9.841305288569856, 8.856463120339697, 7.927854100835048, 6.888594589285673, 5.869724405714293, 4.921243628261721, 3.9301350938594997, 2.9445847437012196, 3.921310134535684, 4.8883704106329535, 5.713890516239244, 6.6777937973353705, 7.6403422376911205, 8.615570343018591, 9.65960067198747, 10.588119298427602, 11.523237374234311, 12.513848661312489, 11.7994583518255, 9.851252986455732, 8.902291366592207, 7.873986310562565, 6.915835113781429, 5.906332667525333, 4.978792592182235, 3.933495095158122, 2.9927916958762477, 1.9524586335768468, 2.896703106690815, 3.8331546833009016, 4.774520815826694, 5.809138951843043, 6.7512086270945755, 7.6367410967890095, 8.659003473237743, 9.620712895445479, 10.549576245222681, 11.56798587944957, 10.904995806047706, 8.938963796496832, 7.877224106017676, 6.927986209582651, 6.002599291938812, 4.963769830904956, 3.9361900437296686, 2.999014589938605, 2.030484828741784, 1.020505275941661, 1.915042899059995, 2.861189790715468, 3.813591191973112, 4.804110163511273, 5.733069111846397, 6.710879481771527, 7.690117004469332, 8.617450005354323, 9.673811212051163, 10.726807782790907, 9.889306855757509, 8.118663199004352, 7.104491150048532, 6.143308673456414, 5.136314195548839, 4.067421129899572, 2.998683125036359, 2.057061563841002, 1.0099656657233265, 0.0, 0.9732889911380324, 2.0402537247540162, 2.9693613478250658, 3.951529188996631, 4.985137349172719, 6.014911302877978, 6.969090450134694, 7.993080219263721, 9.034150832374193, 10.042543125930585, 9.117804590271831, 9.04079760825329, 8.040338608836755, 7.044086514958731, 6.0342090119928224, 5.062652537010216, 4.012657507394348, 3.033353010731881, 1.991347649656491, 0.9629197648853204, 1.91476302774869, 2.8713640811082044, 3.9012907537906805, 4.855195359943263, 5.91006423681441, 6.960309958578251, 7.931307123486391, 8.86089372358703, 9.799849047939052, 10.850903263096233, 10.054890820146376, 9.84712542179949, 8.783940624489752, 7.790239941330315, 6.86220235015229, 5.914938032658321, 4.910393500163504, 3.974112402932865, 2.946854213548149, 1.9822835775286438, 2.9222329078527216, 3.8553547930238263, 4.91569393420924, 5.819081621179007, 6.75848022623674, 7.787791395143716, 8.77546862160284, 9.703186204298405, 10.776761242632377, 11.839318096741223, 10.896488958761, 10.764549100674598, 9.759410025412407, 8.788706392051981, 7.8075813155527864, 6.849692432958911, 5.838812545444686, 4.865668614220579, 3.923533820616162, 3.0510893770037555, 3.867993385165776, 4.823945789836458, 5.749119248573501, 6.688079483652368, 7.6346880239829, 8.621674616215827, 9.61750105391969, 10.556884489221602, 11.63114311757112, 12.655836284413853, 11.825240805306798, 11.749464437255133, 10.714791903431525, 9.7706722373486, 8.784103119166197, 7.783435080251323, 6.902576526353553, 5.9140878135635795, 4.945932626164805, 3.9800531742808545, 4.828701746917147, 5.799335590895743, 6.778161762315711, 7.71210006818253, 8.706345348049943, 9.578907845505965, 10.52971639220107, 11.514029792923592, 12.525651869050645, 13.490596716904632, 12.691849238242911, 12.589166575018476, 11.661213463072833, 10.751016108192868, 9.761737093604749, 8.82300474349941, 7.808588515025162, 6.875925380494089, 5.935640326108272, 4.930817179910857, 5.850697427385102, 6.750685149193271, 7.755434459438691, 8.781784104332191, 9.76065081366285, 10.539569277312703, 11.488761542697352, 12.45282855266199, 13.379642381175332, 14.353895693600359, 13.544771953411392, 13.582823555586826, 12.630777045995186, 11.809741791763468, 10.795043987082925, 9.816247852224238, 8.806496296847534, 7.823187347316509, 6.925031037265806, 5.956014321222521, 6.85304531518756, 7.800152600259366, 8.682971721583415, 9.670049053107924, 10.712791176373221, 11.570714764337952, 12.559842371242079, 13.474958614496718, 14.385245116405434, 15.340228103722037, 14.54765127240492, 14.582166018701782, 13.571044615569036, 12.75237330049986, 11.784253800741007, 10.751424726807139, 9.736762608235166, 8.788110884635486, 7.878777199792544, 6.942986031189689, 7.784169773811607, 8.811623899978478, 9.663546180960756, 10.606234779063547, 11.621019699769779, 12.506657645231517, 13.53092258929083, 14.514630096229498, 15.436141918657636, 16.31890788013082, 15.559642468198495, 15.523321356097329, 14.581795975251769, 13.643807066106246, 12.647612236867317, 11.722250740882286, 10.78951422766399, 9.827646273538761, 8.859177721946986, 8.007114930641313, 8.846285461153226, 9.782942951595036, 10.69151480004745, 11.630328182338108, 12.645040183368913, 13.470823742076654, 14.45683054240322, 15.470983253028878, 16.398407184270106, 17.34231296355923, 16.47034056897003, 16.58256598844051, 15.616018496494442, 14.638458232538595, 13.578482552080143, 12.748179115415583, 11.721540597383576, 10.801710193605668, 9.819340266555404, 9.067159746049281, 9.851441265901302, 10.786358808145723, 11.096370798846554, 11.84561819681358, 12.843516297379537, 13.841661411500324, 14.705926978039018, 15.685551291076186, 16.644507923309703, 17.646898507894935, 17.478257860419987, 17.582900658493603, 16.643980717769733, 15.59635460041573, 14.551148454987269, 13.751926557350952, 12.740134618448094, 11.805597737334223, 10.782686882532081, 10.061550480959745, 10.850515001864451, 11.019337829440037, 10.052717127020468, 10.887077259939758, 11.899498166673167, 12.852045982229937, 13.732990615591174, 14.686469181503726, 15.716363057188818, 16.675818017476843, 17.61376430593438, 17.524980710610517, 17.575200052120515, 16.57211139706651, 15.625090872441042, 14.708584111152359, 13.713348958057376, 12.866936645939514, 11.845119863162857, 11.123596680077078, 11.004874884101907, 10.003488930243268, 9.040756189874326, 9.955595496810206, 10.916252731354241, 11.812503512988268, 12.780124912928054, 13.731287273968503, 14.786990385031496, 15.748572709715976, 16.574983402055842, 16.61455069591119, 17.366534688158875, 16.343146485529736, 15.360527998042324, 14.335498979627813, 13.361014251918016, 12.494389487229475, 11.61239012756405, 10.834451117940079, 9.968924645051832, 9.075014754252715, 8.08161853107657, 8.942765224755131, 9.880655405510742, 10.832879307780752, 11.824654796422118, 12.843881780396147, 13.784734109839542, 14.729301026173902, 15.61975047832799, 15.74268540605194, 16.36265735129509, 15.402005386629178, 14.424385123447957, 13.47608994134394, 12.418698350655841, 11.55946966708336, 10.641790494785115, 9.804157687973046, 8.896005987568898, 8.097326838754226, 7.094634676342962, 8.01479040580868, 8.905238751385761, 9.890584113927618, 10.856112439568507, 11.845377778654747, 12.785898294559413, 13.741725326480548, 14.692912037606147], [14.579515668998194, 13.620540413725264, 12.641203400288052, 11.700566975812732, 10.672332336181684, 9.720637643232488, 8.72947215633786, 7.820925776400825, 6.881268639201725, 6.175314426702803, 6.938053778475378, 7.79103148967478, 8.716317445911281, 9.658134084545521, 10.504508894195089, 11.492986514315986, 12.450371993289577, 13.474744590517853, 14.47567071812671, 15.502408314476817, 13.621293178015293, 12.670189584643014, 11.65069052198405, 10.702153300780358, 9.642302907002525, 8.741435724915233, 7.779345452717671, 6.877485458602044, 5.825722832808635, 5.138506829514976, 5.99498592571274, 6.728751700861718, 7.679243321800879, 8.695670494218149, 9.577380898624435, 10.550213883840222, 11.564043194553651, 12.492365039217828, 13.45179200960207, 14.496917256755319, 12.577570524981565, 11.636415385158674, 10.679655793330085, 9.713490073166431, 8.7146496403591, 7.701835996015686, 6.776615353382151, 5.82494862988491, 4.80928564110253, 4.115909651339388, 4.9741402322482955, 5.728966390921859, 6.664027696125346, 7.6547895457698445, 8.629088319031606, 9.56772135455773, 10.517580087762475, 11.570275681356671, 12.526393858518903, 13.478223188190736, 11.625611081489362, 10.690087732179872, 9.705245563949715, 8.776636544445065, 7.737377032895689, 6.71850684932431, 5.770026071871738, 4.778917537469517, 3.7933671873112362, 3.057233931694573, 3.9150814194949213, 4.740601525101211, 5.704504806197337, 6.667053246553088, 7.64228135188056, 8.686311680849437, 9.61483030728957, 10.549948383096279, 11.540559670174458, 12.549142354096539, 10.700035430065748, 9.751073810202223, 8.72276875417258, 7.764617557391445, 6.755115111135349, 5.827575035792251, 4.782277538768138, 3.841574139486264, 2.801241077186863, 1.990695295849878, 2.859865692162869, 3.8012318246886614, 4.83584996070501, 5.777919635956544, 6.663452105650977, 7.685714482099712, 8.647423904307448, 9.57628725408465, 10.594696888311539, 11.660817831020761, 9.787746240106848, 8.726006549627693, 7.776768653192668, 6.851381735548828, 5.812552274514972, 4.784972487339685, 3.847797033548621, 2.8792672723518002, 1.8692877195516777, 0.9417539079219626, 1.8879007995774357, 2.8403022008350796, 3.830821172373241, 4.759780120708365, 5.737590490633496, 6.716828013331301, 7.644161014216293, 8.700522220913133, 9.753518791652876, 10.716262071073444, 9.091952190142385, 8.077780141186565, 7.116597664594447, 6.109603186686871, 5.040710121037605, 3.971972116174391, 3.030350554979034, 1.9832546568613587, 0.9732889911380324, 0.0, 1.066964733615984, 1.9960723566870338, 2.978240197858599, 4.011848358034687, 5.041622311739946, 5.995801458996662, 7.019791228125689, 8.06086184123616, 9.069254134792553, 10.001809056359626, 10.014086599391325, 9.01362759997479, 8.017375506096764, 7.007498003130855, 6.035941528148248, 4.98594649853238, 4.006642001869913, 2.9646366407945233, 1.9064749208359704, 0.9414740366106576, 1.8980750899701722, 2.928001762652648, 3.881906368805231, 4.936775245676378, 5.987020967440219, 6.958018132348359, 7.887604732448997, 8.82656005680102, 9.877614271958201, 10.863611179367886, 10.784479711255663, 9.721294913945925, 8.727594230786488, 7.799556639608463, 6.852292322114494, 5.847747789619677, 4.9114666923890375, 3.884208503004321, 2.9196378669848158, 1.979688536660738, 2.910118281681944, 3.950364595270643, 4.845792630040974, 5.785191235098708, 6.814502404005684, 7.802179630464807, 8.729897213160372, 9.803472251494345, 10.866029105603191, 11.831049782852968, 11.701903390130768, 10.696764314868577, 9.726060681508152, 8.744935605008958, 7.7870467224150826, 6.776166834900859, 5.8030229036767516, 4.8608881100723345, 3.8561039493932743, 2.9254490139737923, 3.878709278494576, 4.803882737231619, 5.742842972310486, 6.689451512641018, 7.676438104873944, 8.672264542577809, 9.61164797787972, 10.685906606229238, 11.710599773071971, 12.725367521082408, 12.686818726711303, 11.652146192887695, 10.70802652680477, 9.721457408622367, 8.720789369707495, 7.8109500309576045, 6.7424899992418865, 5.750947198554324, 4.785067746670373, 3.886157375725164, 4.854099079553861, 5.832925250973829, 6.766863556840648, 7.761108836708061, 8.633671334164081, 9.584479880859186, 10.568793281581708, 11.58041535770876, 12.545360205562748, 13.52341235912599, 13.526520864474646, 12.598567752529004, 11.688370397649038, 10.69909138306092, 9.688511588481994, 8.618763820800769, 7.686100686269697, 6.740654898497791, 5.735831752300376, 4.908153056193118, 5.805448637851389, 6.810197948096809, 7.836547592990309, 8.815414302320967, 9.594332765970819, 10.543525031355468, 11.507592041320105, 12.434405869833448, 13.408659182258475, 14.436076547441976, 14.520177845042996, 13.568131335451357, 12.747096081219638, 11.69173194615762, 10.626423157999845, 9.616671602623141, 8.633362653092115, 7.730045609655325, 6.76102889361204, 5.910500943995577, 6.854916088917484, 7.737735210241532, 8.724812541766042, 9.767554665031339, 10.625478252996068, 11.614605859900195, 12.529722103154834, 13.44000860506355, 14.394991592380153, 15.36456094762772, 15.519520308157952, 14.508398905025206, 13.602972704543525, 12.634853204784672, 11.561600032582746, 10.546937914010773, 9.598286190411093, 8.683791772182062, 7.748000603579208, 6.8416254026196235, 7.869079528786495, 8.718309669618872, 9.660998267721665, 10.675783188427896, 11.561421133889633, 12.585686077948946, 13.569393584887614, 14.490905407315752, 15.373671368788935, 16.32024080932289, 16.441969033746684, 15.500443652901124, 14.453982371881855, 13.457787542642926, 12.532426046657893, 11.599689533439596, 10.637821579314368, 9.664192294336504, 8.812129503030832, 7.903741089961242, 8.840398580403052, 9.746278288705566, 10.685091670996226, 11.69980367202703, 12.52558723073477, 13.511594031061335, 14.525746741686994, 15.45317067292822, 16.397076452217345, 17.37534895990084, 17.501213666089868, 16.501110185251054, 15.448633538314203, 14.388657857855751, 13.55835442119119, 12.531715903159183, 11.611885499381277, 10.624354838944921, 9.8721743184388, 8.908896894709319, 9.843814436953739, 10.729851697399482, 11.622389523526753, 12.662218276328922, 13.477026124674795, 14.4695992720162, 15.449223585053367, 16.408180217286887, 17.416176126081467, 18.383266251350797, 18.399976852642787, 17.45415602354534, 16.406529906191338, 15.361323760762877, 14.562101863126559, 13.545149190837611, 12.61061230972374, 11.587701454921598, 10.866565053349264, 9.90797063067247, 10.295555553247976, 10.901499570630488, 11.735859703549776, 12.748280610283185, 13.700828425839953, 14.581773059201192, 15.535251625113744, 16.565145500798838, 17.52460046108686, 18.462546749544398, 18.373763154220534, 17.32882939473076, 16.30094542919839, 15.35392490457292, 14.310092611052033, 13.31485745795705, 12.494667990600128, 11.635165722216254, 10.914097551782667, 10.056110025185673, 9.279706654051207, 9.889538633484346, 10.804377940420224, 11.76503517496426, 12.661285956598284, 13.628907356538072, 14.580069717578521, 15.635772828641514, 16.597355153325992, 17.42376584566586, 17.412280243785453, 16.39324569702084, 15.369857494391702, 14.387239006904291, 13.36220998848978, 12.387725260779984, 11.521100496091442, 10.639101136426017, 9.861162126802045, 9.020159786135597, 8.264961945317644, 8.930400974686588, 9.79154766836515, 10.72943784912076, 11.681661751390768, 12.673437240032136, 13.692664224006165, 14.63351655344956, 15.57808346978392, 16.468532921938007, 16.401053345892237, 15.38936836015706, 14.428716395491145, 13.451096132309923, 12.502800950205906, 11.445409359517809, 10.586180675945327, 9.668501503647082, 8.830868696835012, 7.9472411286526645, 7.245478572070106, 7.943417119952979, 8.863572849418698, 9.75402119499578, 10.739366557537634, 11.704894883178525, 12.694160222264765, 13.634680738169429, 14.590507770090564, 15.541694481216163], [15.605372738699181, 14.64639748342625, 13.667060469989039, 12.726424045513717, 11.698189405882669, 10.746494712933474, 9.755329226038844, 8.84678284610181, 7.90712570890271, 7.118752497720485, 6.071617064865418, 6.903722518857264, 7.829008475093765, 8.770825113728005, 9.617199923377575, 10.605677543498471, 11.563063022472063, 12.587435619700338, 13.588361747309195, 14.615099343659303, 14.64715024771628, 13.696046654343998, 12.676547591685035, 11.728010370481343, 10.66815997670351, 9.76729279461622, 8.805202522418655, 7.903342528303029, 6.85157990250962, 6.081944900532658, 5.128549212102779, 5.841442730044202, 6.791934350983363, 7.808361523400633, 8.69007192780692, 9.662904913022707, 10.676734223736137, 11.605056068400314, 12.564483038784552, 13.609608285937801, 13.603427594682552, 12.66227245485966, 11.70551286303107, 10.739347142867416, 9.740506710060085, 8.727693065716672, 7.8024724230831355, 6.850805699585894, 5.835142710803515, 5.068283303430586, 4.107703518638335, 4.841657420104343, 5.77671872530783, 6.767480574952328, 7.741779348214091, 8.680412383740215, 9.63027111694496, 10.682966710539157, 11.639084887701385, 12.590914217373218, 12.651468151190349, 11.715944801880859, 10.731102633650698, 9.802493614146048, 8.763234102596673, 7.744363919025295, 6.795883141572723, 5.8047746071705015, 4.8192242570122215, 4.009607583785771, 3.0486447058849597, 3.8532925542836955, 4.817195835379821, 5.779744275735572, 6.754972381063044, 7.799002710031921, 8.727521336472053, 9.662639412278763, 10.65325069935694, 11.66183338327902, 11.725892499766735, 10.77693087990321, 9.748625823873567, 8.790474627092431, 7.780972180836334, 6.853432105493237, 5.808134608469124, 4.86743120918725, 3.827098146887849, 2.943068947941075, 1.9934289785529078, 2.9139228538711457, 3.948540989887495, 4.890610665139027, 5.776143134833461, 6.798405511282196, 7.760114933489932, 8.688978283267135, 9.707387917494021, 10.773508860203243, 10.779296159516605, 9.75186361932868, 8.802625722893653, 7.877238805249813, 6.838409344215957, 5.81082955704067, 4.873654103249606, 3.905124342052786, 2.895144789252663, 1.9676109776229478, 1.0214640859674746, 1.9529932300175636, 2.9435122015557247, 3.8724711498908486, 4.850281519815979, 5.829519042513785, 6.756852043398776, 7.813213250095616, 8.86620982083536, 9.828953100255928, 9.93398571401112, 9.144744874802548, 8.18356239821043, 7.176567920302855, 6.107674854653588, 5.038936849790375, 4.097315288595018, 3.0502193904773427, 2.0402537247540162, 1.066964733615984, 0.0, 0.9291076230710498, 1.9112754642426149, 2.9448836244187033, 3.9746575781239626, 4.928836725380679, 5.952826494509705, 6.993897107620176, 8.002289401176569, 8.934844322743642, 10.824610006059137, 10.024621096684317, 9.028369002806292, 8.018491499840383, 7.046935024857777, 5.996939995241909, 5.017635498579442, 3.9502576042639723, 2.8829076425589464, 1.9179067583336336, 0.9613057049741188, 1.8610370290366642, 2.814941635189247, 3.869810512060394, 4.920056233824234, 5.8910533987323745, 6.820639998833013, 7.759595323185035, 8.810649538342217, 9.796646445751902, 11.71126195645192, 10.648077159142183, 9.654376475982746, 8.72633888480472, 7.779074567310751, 6.7745300348159345, 5.838248937585295, 4.810990748200578, 3.846420112181073, 2.9064707818569953, 1.9733488966858905, 2.883399861654659, 3.778827896424991, 4.718226501482724, 5.7475376703897005, 6.735214896848824, 7.662932479544388, 8.73650751787836, 9.799064371987207, 10.764085049236984, 12.628685635327026, 11.623546560064835, 10.652842926704409, 9.671717850205216, 8.71382896761134, 7.702949080097116, 6.729805148873009, 5.787670355268592, 4.782886194589532, 3.8522312591700496, 2.9419398934985224, 3.867113352235565, 4.764535139780957, 5.65194699829704, 6.638933590529967, 7.634760028233831, 8.574143463535743, 9.648402091885263, 10.673095258727995, 11.687863006738432, 13.42829264576979, 12.578928438083953, 11.634808772001028, 10.648239653818624, 9.647571614903752, 8.737732276153862, 7.669272244438144, 6.677729443750581, 5.711849991866631, 4.812939620921421, 3.9173296945578073, 4.896155865977775, 5.788555724311119, 6.723604322364084, 7.596166819820104, 8.546975366515209, 9.531288767237731, 10.542910843364783, 11.50785569121877, 12.485907844782012, 14.354177411490914, 13.525349997725261, 12.615152642845295, 11.625873628257176, 10.615293833678251, 9.545546065997026, 8.612882931465954, 7.667437143694048, 6.662613997496633, 5.834935301389375, 4.868679252855335, 5.873428563100755, 6.85823976046078, 7.7779097879769905, 8.556828251626841, 9.50602051701149, 10.470087526976128, 11.39690135548947, 12.371154667914498, 13.398572033097999, 15.347834392059264, 14.494913580647614, 13.673878326415895, 12.618514191353878, 11.553205403196102, 10.543453847819398, 9.560144898288373, 8.656827854851581, 7.687811138808297, 6.837283189191834, 5.918146703921431, 6.800965825245479, 7.788043156769987, 8.830785280035284, 9.58797373865209, 10.577101345556217, 11.492217588810856, 12.402504090719573, 13.357487078036176, 14.327056433283742, 16.260212744475627, 15.435181150221464, 14.529754949739782, 13.56163544998093, 12.488382277779003, 11.47372015920703, 10.52506843560735, 9.610574017378319, 8.674782848775465, 7.768407647815881, 6.977598625637506, 7.781540284622818, 8.72422888272561, 9.739013803431842, 10.523916619545655, 11.548181563604969, 12.531889070543636, 13.453400892971775, 14.336166854444958, 15.282736294978912, 17.233094695376867, 16.427225898097383, 15.380764617078112, 14.384569787839183, 13.45920829185415, 12.526471778635853, 11.564603824510625, 10.59097453953276, 9.738911748227089, 8.8305233351575, 7.948917677254063, 8.809508903709514, 9.748322286000171, 10.763034287030976, 11.488082716390792, 12.474089516717358, 13.488242227343017, 14.415666158584242, 15.359571937873367, 16.33784444555686, 18.29233932772005, 17.427892430447308, 16.37541578351046, 15.315440103052008, 14.485136666387447, 13.45849814835544, 12.538667744577534, 11.551137084141178, 10.798956563635057, 9.835679139905576, 8.95233353380475, 9.793082312403431, 10.685620138530698, 11.725448891332867, 12.439521610330818, 13.432094757672223, 14.41171907070939, 15.37067570294291, 16.378671611737488, 17.345761737006818, 18.318560587361475, 17.37273975826403, 16.394832882832112, 15.336004815996706, 14.40414282408368, 13.400762826748817, 12.681215571318392, 11.810289732029513, 11.088834780082482, 10.256001177080636, 9.905898169091428, 10.836735984229517, 11.64416107540452, 12.65658198213793, 13.454324385137905, 14.405031120120068, 15.411017991124021, 16.389851468273367, 17.34975210215558, 18.32497551641247, 17.502173674140508, 16.441520423913246, 15.413636458380875, 14.466615933755406, 13.422783640234519, 12.427548487139536, 11.607359019782612, 10.747856751398738, 10.02678858096515, 9.189673311575712, 10.18659964688908, 10.915395703185329, 11.830235010121209, 12.790892244665244, 13.687143026299271, 14.654764426239057, 15.605926787279506, 16.6616298983425, 17.623212223026975, 18.44962291536685, 16.52497127296794, 15.505936726203327, 14.482548523574188, 13.499930036086777, 12.474901017672266, 11.50041628996247, 10.633791525273926, 9.751792165608501, 8.973853155984528, 8.153723072525636, 9.171854938155517, 9.956258044387571, 10.817404738066134, 11.755294918821745, 12.707518821091755, 13.699294309733121, 14.71852129370715, 15.659373623150545, 16.603940539484903, 17.494389991638997, 15.513744375074722, 14.502059389339546, 13.541407424673631, 12.563787161492408, 11.615491979388391, 10.558100388700295, 9.69887170512781, 8.781192532829566, 7.9435597260174955, 7.080804415042704, 8.152371564907979, 8.969274189653964, 9.889429919119683, 10.779878264696764, 11.76522362723862, 12.73075195287951, 13.72001729196575, 14.660537807870416, 15.61636483979155, 16.567551550917152], [14.696169352548292, 15.575505106497301, 14.59616809306009, 13.655531668584768, 12.62729702895372, 11.675602336004523, 10.684436849109893, 9.77589046917286, 8.836233331973759, 7.854391764904613, 6.807256332049546, 5.974614895786214, 6.899900852022714, 7.841717490656954, 8.688092300306524, 9.67656992042742, 10.633955399401012, 11.658327996629287, 12.659254124238144, 13.685991720588252, 13.726281007127076, 14.62515427741505, 13.605655214756085, 12.657117993552394, 11.597267599774561, 10.696400417687268, 9.734310145489705, 8.83245015137408, 7.780687525580669, 6.817584167716786, 5.8641884792869075, 4.912335106973152, 5.862826727912312, 6.879253900329582, 7.76096430473587, 8.733797289951655, 9.747626600665084, 10.675948445329261, 11.6353754157135, 12.68050066286675, 12.707255947885743, 13.591380077930712, 12.63462048610212, 11.668454765938467, 10.669614333131136, 9.65680068878772, 8.731580046154185, 7.7799133226569435, 6.764250333874564, 5.863556055574733, 4.843342785822463, 3.912549797033293, 4.84761110223678, 5.8383729518812775, 6.81267172514304, 7.751304760669163, 8.701163493873908, 9.753859087468104, 10.709977264630334, 11.661806594302167, 11.755355474154124, 12.64505242495191, 11.660210256721749, 10.731601237217099, 9.692341725667724, 8.673471542096344, 7.724990764643772, 6.733882230241551, 5.748331880083271, 4.93871520685682, 3.9777523289560097, 2.9241849312126456, 3.888088212308771, 4.850636652664521, 5.825864757991995, 6.869895086960872, 7.798413713401004, 8.733531789207714, 9.72414307628589, 10.73272576020797, 10.858290629841576, 11.706038502974259, 10.677733446944616, 9.71958225016348, 8.710079803907384, 7.782539728564286, 6.737242231540173, 5.796538832258299, 4.756205769958898, 3.872176571012125, 2.922536601623958, 1.9848152308000957, 3.019433366816445, 3.961503042067978, 4.847035511762412, 5.869297888211146, 6.831007310418882, 7.759870660196084, 8.77828029442297, 9.844401237132193, 9.850188536445554, 10.680971242399728, 9.731733345964702, 8.806346428320863, 7.767516967287006, 6.739937180111719, 5.8027617263206555, 4.834231965123835, 3.8242524123237125, 2.8967186006939976, 1.9505717090385244, 1.0238856069465139, 2.014404578484675, 2.943363526819799, 3.9211738967449294, 4.900411419442735, 5.8277444203277255, 6.8841056270245655, 7.937102197764309, 8.899845477184877, 9.004878090940071, 10.01905013989589, 9.112670021281481, 8.105675543373906, 7.036782477724639, 5.9680444728614255, 5.026422911666068, 3.9793270135483927, 2.969361347825066, 1.9960723566870338, 0.9291076230710498, 0.0, 0.9821678411715652, 2.0157760013476533, 3.0455499550529126, 3.9997291023096286, 5.023718871438655, 6.064789484549127, 7.073181778105519, 8.005736699672592, 9.895502382988088, 10.895961382404623, 9.957476625877343, 8.947599122911434, 7.976042647928827, 6.926047618312959, 5.946743121650492, 4.879365227335022, 3.812015265629996, 2.847014381404683, 1.8904133280451685, 0.9319294059656146, 1.8858340121181976, 2.9407028889893443, 3.9909486107531853, 4.961945775661325, 5.8915323757619635, 6.830487700113986, 7.881541915271168, 8.867538822680853, 10.864921523624963, 11.577184782213232, 10.583484099053795, 9.65544650787577, 8.7081821903818, 7.703637657886984, 6.767356560656344, 5.740098371271628, 4.7755277352521235, 3.8355784049280452, 2.9024565197569405, 1.9542922385836095, 2.849720273353941, 3.789118878411674, 4.81843004731865, 5.806107273777773, 6.733824856473337, 7.807399894807309, 8.869956748916158, 9.834977426165935, 11.803001226385188, 12.552654183135886, 11.58195054977546, 10.600825473276267, 9.64293659068239, 8.632056703168166, 7.658912771944059, 6.716777978339642, 5.711993817660582, 4.7813388822411, 3.868975450696284, 2.9438019919592415, 3.835427516709907, 4.72283937522599, 5.709825967458917, 6.705652405162781, 7.6450358404646925, 8.719294468814212, 9.743987635656945, 10.758755383667381, 12.49918502269874, 13.508036061155003, 12.563916395072079, 11.577347276889675, 10.576679237974803, 9.666839899224913, 8.598379867509195, 7.606837066821631, 6.6409576149376806, 5.742047243992471, 4.844365251755569, 4.002175692964748, 4.859448101240069, 5.794496699293035, 6.6670591967490545, 7.617867743444159, 8.60218114416668, 9.613803220293732, 10.57874806814772, 11.556800221710962, 13.425069788419863, 14.353022900365506, 13.544260265916346, 12.554981251328227, 11.5444014567493, 10.474653689068075, 9.541990554537003, 8.596544766765097, 7.591721620567683, 6.764042924460425, 5.795714810053097, 5.057144731714033, 5.929132137389731, 6.848802164905941, 7.6277206285557915, 8.57691289394044, 9.540979903905077, 10.46779373241842, 11.442047044843447, 12.469464410026948, 14.418726768988213, 15.322586483287859, 14.602985949486946, 13.547621814424929, 12.482313026267152, 11.472561470890447, 10.489252521359422, 9.585935477922632, 8.616918761879347, 7.766390812262884, 6.845182261119192, 5.984681993858756, 6.971759325383265, 7.914515510527163, 8.658866115581041, 9.647993722485166, 10.563109965739805, 11.473396467648522, 12.428379454965125, 13.397948810212691, 15.331105121404574, 16.26285405286171, 15.458862572810832, 14.490743073051979, 13.417489900850052, 12.402827782278079, 11.4541760586784, 10.53968164044937, 9.603890471846515, 8.697515270886932, 7.9046341828352675, 6.965256453236096, 7.9079450513388885, 8.92272997204512, 9.594808996474606, 10.61907394053392, 11.602781447472587, 12.524293269900724, 13.407059231373907, 14.353628671907861, 16.303987072305812, 17.245512453151374, 16.30987224014916, 15.31367741091023, 14.3883159149252, 13.455579401706903, 12.493711447581674, 11.520082162603812, 10.66801937129814, 9.75963095822855, 8.875953234451824, 7.99322507232279, 8.93203845461345, 9.946750455644256, 10.558975093319743, 11.544981893646309, 12.559134604271968, 13.486558535513192, 14.430464314802316, 15.408736822485812, 17.363231704648996, 17.476098274575044, 16.423621627638195, 15.379563095832781, 14.478782642947998, 13.546458841241527, 12.756818684428428, 11.844528724935138, 11.1541178919219, 10.764786762976627, 9.879369091002511, 8.976798481016708, 9.869336307143978, 10.909165059946147, 11.510413987259769, 12.502987134601174, 13.482611447638341, 14.44156807987186, 15.449563988666437, 16.416654113935767, 17.389452964290427, 16.44363213519298, 15.465725259761061, 14.406897192925655, 13.475035201012629, 12.471655203677766, 11.75210794824734, 10.88118210895846, 10.159727157011435, 10.991640444264764, 10.83293372628919, 10.020452152842793, 10.8278772440178, 11.84029815075121, 12.525216762066856, 13.475923497049019, 14.481910368052972, 15.460743845202316, 16.42064447908453, 17.395867893341418, 16.57306605106946, 15.512412800842197, 14.484528835309824, 13.537508310684355, 12.493676017163468, 11.498440864068485, 10.67825139671156, 9.818749128327685, 9.097680957894102, 9.92531257875984, 10.922238914073208, 11.032413089988935, 11.759359007147353, 12.720016241691388, 13.564759231308525, 14.428789199712138, 15.379951560752588, 16.43565467181558, 17.347889786845396, 17.523063359624135, 15.595863649896886, 14.576829103132276, 13.553440900503137, 12.570822413015726, 11.545793394601215, 10.571308666891419, 9.704683902202875, 8.822684542537448, 8.04474553291348, 8.889362339709765, 9.907494205339646, 10.885365667458622, 11.746512361137183, 12.684402541892794, 13.636626444162804, 14.628401932804172, 15.647628916778201, 16.588481246221598, 17.533048162555957, 16.570322172773132, 14.584636752003671, 13.572951766268496, 12.61229980160258, 11.634679538421357, 10.68638435631734, 9.628992765629244, 8.76976408205676, 7.852084909758514, 7.0144521029464455, 7.816443682226832, 8.888010832092107, 9.898381812725013, 10.818537542190732, 11.708985887767813, 12.69433125030967, 13.659859575950561, 14.6491249150368, 15.589645430941466, 16.5454724628626, 15.64348373205129], [13.771679832326061, 14.730655087598992, 15.578335934231657, 14.637699509756334, 13.609464870125286, 12.65777017717609, 11.66660469028146, 10.758058310344424, 9.818401173145324, 8.836559606076179, 7.789424173221112, 6.95678273695778, 6.092625175549337, 6.991031246065068, 7.772490481566956, 8.760968101687853, 9.718353580661445, 10.74272617788972, 11.734764604015913, 12.76150220036602, 12.77758019959696, 13.733561733416408, 14.587823055927652, 13.63928583472396, 12.579435440946128, 11.678568258858835, 10.716477986661271, 9.814617992545642, 8.762855366752234, 7.799752008888353, 6.846356320458473, 5.8945029481447175, 5.055551051438934, 6.028567655737696, 6.845362485996302, 7.818195471212087, 8.832024781925517, 9.760346626589694, 10.686674608183385, 11.731799855336634, 11.758555140355627, 12.699710280178518, 13.616788327273687, 12.650622607110034, 11.651782174302703, 10.638968529959287, 9.713747887325752, 8.762081163828508, 7.74641817504613, 6.845723896746299, 5.825510626994029, 4.894717638204859, 4.040335425763401, 4.9726917340898105, 5.8970699064034715, 6.835702941929595, 7.7787468163735465, 8.812539015470826, 9.761276457100218, 10.71310578677205, 10.806654666624008, 11.744068731644305, 12.642378097893314, 11.713769078388664, 10.674509566839289, 9.65563938326791, 8.707158605815339, 7.716050071413116, 6.730499721254836, 5.920883048028385, 4.959920170127575, 3.906352772384211, 3.080812535835393, 3.984955434873054, 4.877163950461878, 5.921194279430756, 6.849712905870888, 7.784830981677597, 8.775442268755773, 9.784024952677854, 9.90958982231146, 10.858551442174985, 11.659901288116181, 10.701750091335045, 9.692247645078949, 8.764707569735851, 7.719410072711739, 6.778706673429864, 5.738373611130464, 4.85434441218369, 3.9047044427955226, 2.966983071971661, 2.0924767396777195, 3.012802234537862, 3.8983347042322953, 4.920597080681029, 5.882306502888765, 6.811169852665967, 7.829579486892854, 8.895700429602076, 8.901487728915438, 9.963227419394594, 10.713901187136267, 9.788514269492428, 8.749684808458571, 7.722105021283285, 6.784929567492221, 5.816399806295401, 4.806420253495278, 3.878886441865563, 2.9327395502100897, 2.006053448118079, 1.0657037709545587, 1.9946627192896829, 2.9724730892148132, 3.951710611912618, 4.879043612797609, 5.935404819494449, 6.988401390234193, 7.951144669654761, 8.022710249768506, 9.036882298724326, 9.998064775316443, 9.087843384545469, 8.018950318896202, 6.950212314032989, 6.008590752837632, 4.961494854719957, 3.951529188996631, 2.978240197858599, 1.9112754642426149, 0.9821678411715652, 0.0, 1.0336081601760883, 2.0633821138813477, 3.0175612611380638, 4.04155103026709, 5.082621643377562, 6.091013936933954, 7.023568858501028, 8.988618648682808, 9.989077648099343, 10.939644467048907, 9.929766964082999, 8.958210489100392, 7.9082154594845235, 6.928910962822057, 5.861533068506587, 4.794183106801561, 3.8291822225762484, 2.872581169216734, 1.9140972471371798, 1.0331609707128424, 2.0372938672905843, 3.0875395890544253, 4.058536753962565, 4.9881233540632035, 5.927078678415226, 6.978132893572408, 7.960655088375573, 9.958037789319683, 11.00967444254724, 11.565651940225358, 10.637614349047332, 9.690350031553363, 8.685805499058548, 7.749524401827909, 6.722266212443193, 5.757695576423688, 4.8177462460996106, 3.8846243609285054, 2.9356940674813163, 1.997047231948586, 2.936445837006319, 3.9657570059132947, 4.953434232372418, 5.881151815067982, 6.954726853401954, 7.966547727217397, 8.928093691860655, 10.896117492079908, 11.901256567342099, 12.564118390947023, 11.58299331444783, 10.625104431853954, 9.614224544339729, 8.641080613115623, 7.698945819511207, 6.694161658832146, 5.7635067234126645, 4.846888169120462, 3.92171471038342, 2.982754475304552, 3.870166333820635, 4.857152926053562, 5.852979363757426, 6.792362799059338, 7.866621427408857, 8.89131459425159, 9.906082342262026, 11.646511981293385, 12.681184515116993, 13.546084236243642, 12.559515118061238, 11.558847079146366, 10.649007740396478, 9.58054770868076, 8.589004907993196, 7.623125456109245, 6.724215085164036, 5.822277970179748, 4.952990830000266, 4.006775059834714, 4.941823657887679, 5.8143861553436995, 6.765194702038804, 7.749508102761325, 8.761130178888378, 9.726075026742365, 10.704127180305607, 12.572396747014508, 13.500349858960151, 14.518242733435095, 13.53714909249979, 12.526569297920865, 11.45682153023964, 10.524158395708568, 9.578712607936662, 8.573889461739249, 7.74621076563199, 6.773627528477276, 6.00795986874955, 5.076459095984376, 5.996129123500586, 6.7750475871504365, 7.724239852535085, 8.688306862499722, 9.615120691013065, 10.589374003438092, 11.616791368621593, 13.566053727582858, 14.469913441882504, 15.523298436359237, 14.529789655596492, 13.464480867438716, 12.454729312062012, 11.471420362530987, 10.568103319094199, 9.599086603050914, 8.748558653434449, 7.823094979543371, 6.935497130894274, 6.122700367694893, 7.0618424691218085, 7.806193074175686, 8.795320681079811, 9.71043692433445, 10.620723426243167, 11.57570641355977, 12.545275768807336, 14.47843207999922, 15.410181011456354, 16.430763354746528, 15.472910914223544, 14.399657742021617, 13.384995623449644, 12.436343899849964, 11.521849481620936, 10.586058313018082, 9.679683112058495, 8.882546901259447, 7.9160715902716134, 7.058886093650517, 8.07367101435675, 8.742135955069251, 9.766400899128564, 10.750108406067232, 11.67162022849537, 12.554386189968552, 13.500955630502506, 15.451314030900457, 16.392839411746017, 16.391026421544968, 15.394831592306039, 14.558929650145313, 13.562883392221547, 12.880196359903447, 11.997415593070178, 11.650187212469707, 10.741798799400113, 9.853865952876005, 8.944040209358308, 8.082979496925077, 9.097691497955886, 9.706302051914388, 10.692308852240954, 11.706461562866613, 12.633885494107837, 13.577791273396961, 14.556063781080457, 16.51055866324364, 16.56049645583548, 15.508019808898629, 14.463961277093214, 13.56318082420843, 12.63085702250196, 11.90613243983654, 11.03725304846176, 12.040741018279267, 11.74695460414819, 10.857281809426691, 9.927613618052224, 9.020277349455604, 10.060106102257773, 10.657740945854414, 11.650314093195819, 12.629938406232986, 13.588895038466505, 14.596890947261082, 15.563981072530414, 16.473851145550857, 15.528030316453412, 14.550123441021494, 13.491295374186087, 12.559433382273061, 11.556053384938199, 10.901421703655455, 10.073906432485083, 11.046350283368803, 11.973808285436329, 11.81084644471337, 10.93934275967136, 9.978818286329426, 10.991239193062835, 11.672543720661501, 12.623250455643664, 13.629237326647617, 14.608070803796961, 15.567971437679175, 16.543194851936065, 15.657464232329891, 14.59681098210263, 13.568927016570257, 12.621906491944788, 11.5780741984239, 10.582839045328917, 9.827565152119675, 9.011473451854307, 10.016505191853039, 10.907480419931405, 11.904406755244773, 11.951303696817503, 10.910300049458979, 11.870957284003014, 12.71208618990317, 13.576116158306784, 14.527278519347233, 15.582981630410226, 16.49521674544004, 16.607461540884564, 14.680261831157319, 13.661227284392709, 12.63783908176357, 11.655220594276159, 10.630191575861648, 9.655706848151851, 8.85399765761099, 8.015408866064071, 9.01685806873767, 9.87153018088133, 10.88966204651121, 11.867533508630185, 11.923130321514053, 12.902373104047637, 13.691710395110686, 14.53158627481272, 15.549300384783418, 16.490152714226813, 16.620718558408445, 15.654720354033566, 13.669034933264104, 12.657349947528928, 11.696697982863013, 10.71907771968179, 9.770782537577773, 8.713390946889676, 7.919077837464873, 7.044809233285137, 7.986564638770638, 8.798611523398398, 9.870178673263672, 10.880549653896578, 11.800705383362297, 12.69115372893938, 13.676499091481237, 14.642027417122128, 15.631292756208367, 16.571813272113033, 15.700622443964292, 14.727881913311723], [12.781460620245547, 13.740435875518477, 14.63613799956126, 15.590508449151958, 14.56227380952091, 13.610579116571714, 12.619413629677084, 11.710867249740048, 10.771210112540947, 9.76365324630617, 8.716517813451102, 7.88387637718777, 6.969549521404685, 6.010037695250169, 6.782271269486441, 7.7707488896073365, 8.728134368580928, 9.752506965809204, 10.744545391935398, 11.771282988285506, 11.787360987516445, 12.743342521335894, 13.645625121257257, 14.592094774119584, 13.532244380341751, 12.631377198254459, 11.669286926056895, 10.767426931941266, 9.715664306147858, 8.726845649118342, 7.773449960688463, 6.821596588374708, 5.932475397294283, 5.047574104922797, 5.855143273915786, 6.827976259131571, 7.841805569845001, 8.77012741450918, 9.69645539610287, 10.74158064325612, 10.768335928275112, 11.709491068098004, 12.666250659926593, 13.603431546505657, 12.604591113698326, 11.591777469354911, 10.666556826721376, 9.714890103224132, 8.699227114441753, 7.772817536976289, 6.752604267224019, 5.821811278434849, 4.917259771618751, 3.991698183274911, 4.906850694322956, 5.84548372984908, 6.78852760429303, 7.822319803390309, 8.771057245019703, 9.722886574691536, 9.803411832168093, 10.74082589718839, 11.76368324309017, 12.666578017784287, 11.627318506234912, 10.608448322663534, 9.659967545210963, 8.66885901080874, 7.683308660650459, 6.873691987424008, 5.901621742638701, 4.833446412614201, 3.9577368816907423, 3.0039618840581546, 3.8869447383813625, 4.93097506735024, 5.859493693790371, 6.794611769597081, 7.785223056675258, 8.793805740597337, 8.87783618074448, 9.826797800608004, 10.826711775242552, 11.654559030730669, 10.645056584474572, 9.717516509131475, 8.672219012107362, 7.731515612825487, 6.6911825505260865, 5.807153351579314, 4.857513382191146, 3.894076712201651, 2.969401085533069, 2.0318086837229625, 2.90811549215178, 3.9303778686005133, 4.8920872908082496, 5.820950640585451, 6.839360274812338, 7.90548121752156, 7.869734087348457, 8.931473777827613, 9.880711674262638, 10.741323208888051, 9.702493747854195, 8.674913960678907, 7.737738506887844, 6.7692087456910235, 5.759229192890901, 4.831695381261186, 3.885548489605713, 2.9331470883480693, 1.942628116809908, 1.0136691684747838, 1.9822538771342977, 2.9614913998321026, 3.888824400717094, 4.945185607413934, 5.998182178153677, 6.91939102808778, 6.989102089592418, 8.003274138548237, 8.964456615140355, 9.97145109304793, 9.05255847907229, 7.983820474209077, 7.042198913013721, 5.995103014896046, 4.985137349172719, 4.011848358034687, 2.9448836244187033, 2.0157760013476533, 1.0336081601760883, 0.0, 1.0297739537052595, 1.9839531009619755, 3.007942870091002, 4.049013483201474, 5.057405776757865, 5.989960698324939, 7.955010488506719, 8.955469487923255, 9.946767692291791, 10.9566451952577, 9.99181864927648, 8.941823619660612, 7.962519122998145, 6.895141228682675, 5.827791266977649, 4.862790382752337, 3.9061893293928223, 2.947705407313268, 2.0585545839856425, 1.0036857071144958, 2.053931428878337, 3.0249285937864774, 3.954515193887116, 4.8934705182391385, 5.94452473339632, 6.927046928199484, 8.924429629143594, 9.976066282371153, 10.96976696553059, 11.671222509223421, 10.723958191729452, 9.719413659234636, 8.783132562003997, 7.755874372619282, 6.791303736599777, 5.851354406275699, 4.918232521104594, 3.9097993003705165, 2.971152464837786, 2.031753859780053, 2.9798052339626624, 3.9674824604217855, 4.89520004311735, 5.9648358292381705, 6.932939567041309, 7.894485531684566, 9.86250933190382, 10.86764840716601, 11.838352040526436, 12.611604448012937, 11.653715565419061, 10.642835677904836, 9.66969174668073, 8.727556953076313, 7.684079065069098, 6.753424129649616, 5.776216590740811, 4.851043132003768, 3.9120828969249004, 2.965474356594369, 3.952460948827296, 4.929600164886193, 5.868983600188105, 6.943242228537624, 7.967935395380357, 8.875174056867595, 10.730037071948178, 11.764709605771786, 12.708829271854711, 13.588126251626345, 12.587458212711473, 11.638925146633428, 10.57046511491771, 9.578922314230146, 8.613042862346196, 7.714132491400988, 6.751606391800096, 5.882319251620614, 4.936103481455063, 4.037131680661413, 4.909694178117434, 5.860502724812538, 6.833033193416118, 7.84465526954317, 8.809600117397158, 9.7876522709604, 11.655921837669302, 12.583874949614945, 13.601767824089888, 14.56387443003155, 13.516486704157815, 12.44673893647659, 11.514075801945518, 10.568630014173612, 9.563806867976199, 8.682825327966146, 7.702955950097624, 6.9372882903698985, 6.005787517604723, 5.09143714627432, 5.870355609924171, 6.819547875308819, 7.771831953154515, 8.698645781667858, 9.672899094092886, 10.700316459276387, 12.649578818237652, 13.553438532537298, 14.606823527014031, 15.519707061833444, 14.454398273675666, 13.444646718298962, 12.461337768767937, 11.558020725331147, 10.589004009287862, 9.685173215768604, 8.75242340116372, 7.864825552514622, 7.052028789315241, 6.157150491895543, 6.901501096949421, 7.890628703853545, 8.793962014989242, 9.70424851689796, 10.659231504214564, 11.62880085946213, 13.561957170654013, 14.493706102111148, 15.514288445401322, 15.400909210456488, 14.539536452139945, 13.625415799569856, 12.938738197991825, 12.511766887857885, 11.57597571925503, 10.616297674392651, 9.811875322879795, 8.845400011891963, 7.988214515270864, 7.205616445895498, 7.837443977842986, 8.861708921902299, 9.845416428840966, 10.755145319150163, 11.637911280623346, 12.5844807211573, 14.534839121555251, 15.476364502400811, 15.400807209464453, 14.404612380225524, 13.568710438064798, 12.572664180141032, 11.89920280908855, 12.854330525297303, 12.640104618706655, 11.67841336173427, 10.783194374496352, 9.873368630978657, 9.012307918545424, 8.229636929494633, 8.801610074688123, 9.787616875014688, 10.801769585640347, 11.71741058476263, 12.661316364051755, 13.639588871735251, 15.594083753898435, 15.570277243754964, 14.517800596818114, 13.473742065012699, 12.572961612127916, 11.640637810421445, 10.925138889021643, 11.894167980688886, 12.897655950506392, 12.683569166482346, 11.786610231047039, 10.856942039672575, 9.949605771075952, 9.304517176432604, 9.753048968628148, 10.745622115969553, 11.72524642900672, 12.68420306124024, 13.680416037915876, 14.647506163185207, 15.483631933470344, 14.537811104372897, 13.55990422894098, 12.501076162105573, 11.569214170192547, 10.565834172857684, 9.920428152840556, 10.930821364712209, 11.903265215595928, 12.870169421807018, 12.740174866333717, 11.868671181291708, 10.908146707949774, 10.248535307138974, 10.767851743435235, 11.718558478417398, 12.724545349421351, 13.703378826570695, 14.651496528333968, 15.626719942590858, 14.667245020249377, 13.606591770022115, 12.578707804489742, 11.631687279864273, 10.587854986343386, 9.592619833248403, 8.846571601304776, 9.868388384081433, 10.873420124080164, 11.803841556302094, 12.831500395474762, 12.88063211843785, 11.839628471079326, 11.256685546880599, 11.807394212676904, 12.671424181080518, 13.622586542120967, 14.67828965318396, 15.578741836094835, 15.617242328804052, 13.690042619076802, 12.671008072312194, 11.647619869683055, 10.665001382195644, 9.639972363781133, 8.665487636071337, 7.87300410679609, 8.89233321191942, 9.89378241459302, 10.79862382111132, 11.8167556867412, 12.809002120837814, 12.8524587431344, 12.307912019188953, 12.78701841788442, 13.626894297586453, 14.644608407557152, 15.585460737000547, 15.630499346327928, 14.66450114195305, 12.678815721183588, 11.667130735448412, 10.706478770782496, 9.728858507601275, 8.780563325497258, 7.723171734809161, 6.938084286649974, 7.9217335791404855, 8.863488984625986, 9.725705163628387, 10.79727231349366, 11.822018266104205, 12.75351432275792, 13.283328673313934, 13.729313611737554, 14.595436654440064, 15.584701993526304, 15.629615337442637, 14.710403231883777, 13.737662701231207], [11.751686666540284, 12.710661921813214, 13.606364045856001, 14.597239187328583, 14.669502429934363, 13.789545754540159, 13.536034754556468, 12.627488374619432, 11.687831237420331, 10.680274371185554, 9.633138938330486, 8.800497502067154, 7.748931606922275, 6.740539173986465, 5.752497315781181, 6.740974935902077, 7.698360414875668, 8.722733012103944, 9.714771438230137, 10.741509034580243, 10.757587033811184, 11.713568567630634, 12.615851167551998, 13.56438838875569, 14.448865505221136, 13.547998323133843, 12.585908050936279, 11.68404805682065, 10.632285431027242, 9.643466773997726, 8.690071085567848, 7.738217713254092, 6.794502756076363, 5.778075583659093, 4.825369320210526, 5.798202305426312, 6.812031616139742, 7.74035346080392, 8.666681442397609, 9.711806689550858, 9.738561974569853, 10.679717114392744, 11.636476706221334, 12.602642426384987, 13.52121223857771, 12.508398594234295, 11.58317795160076, 10.631511228103516, 9.615848239321137, 8.689438661855673, 7.669225392103403, 6.738432403314233, 5.792901426836272, 4.851375513879458, 3.8770767406176962, 4.8157097761438195, 5.758753650587771, 6.79254584968505, 7.741283291314443, 8.693112620986277, 8.773637878462834, 9.711051943483131, 10.733909289384911, 11.662518308889561, 12.543939631114297, 11.525069447542919, 10.576588670090347, 9.585480135688124, 8.599929785529843, 7.790313112303393, 6.8182428675180855, 5.750067537493585, 4.833378536908263, 3.870830096552513, 2.8571707846761027, 3.9012011136449805, 4.829719740085112, 5.764837815891822, 6.755449102969998, 7.764031786892078, 7.84806222703922, 8.797023846902745, 9.796937821537293, 10.825993650677416, 11.561677709353956, 10.634137634010857, 9.588840136986745, 8.64813673770487, 7.607803675405471, 6.723774476458698, 5.7741345070705306, 4.810697837081036, 3.8860222104124538, 2.898676896217321, 1.8783415384465203, 2.900603914895254, 3.8623133371029903, 4.791176686880192, 5.809586321107079, 6.875707263816301, 6.839960133643197, 7.901699824122354, 8.85093772055738, 9.776324638201219, 10.61911487273358, 9.591535085558291, 8.654359631767228, 7.685829870570408, 6.675850317770285, 5.74831650614057, 4.802169614485098, 3.849768213227454, 2.8592492416892927, 1.9302902933541686, 0.9524799234290382, 1.9317174461268434, 2.8590504470118345, 3.9154116537086745, 4.968408224448417, 5.889617074382521, 5.959328135887159, 6.973500184842978, 7.934682661435096, 8.941677139342671, 10.010570204991938, 9.013594427914336, 8.07197286671898, 7.024876968601305, 6.014911302877978, 5.041622311739946, 3.9746575781239626, 3.045549955052913, 2.0633821138813477, 1.0297739537052595, 0.0, 0.954179147256716, 1.9781689163857425, 3.019239529496214, 4.027631823052606, 4.96018674461968, 6.92523653480146, 7.925695534217996, 8.916993738586532, 9.92687124155244, 10.898427716535048, 9.971597573365871, 8.992293076703405, 7.9249151823879345, 6.8575652206829085, 5.892564336457596, 4.935963283098081, 3.9774793610185277, 3.0883285376909018, 2.033459660819755, 1.0733584681151067, 2.0082383323124895, 2.937824932413128, 3.8767802567651506, 4.927834471922332, 5.897272974494225, 7.894655675438334, 8.946292328665894, 9.939993011825331, 10.868030603003357, 11.75373214543471, 10.749187612939895, 9.812906515709257, 8.78564832632454, 7.821077690305036, 6.881128359980958, 5.948006474809853, 4.906588882696871, 3.9679420471641413, 3.0285434421064084, 1.999232273199432, 2.9869094996585552, 3.9146270823541194, 4.948145567764183, 5.916249305567321, 6.864711577979307, 8.83273537819856, 9.837874453460751, 10.808578086821177, 11.789703163320372, 12.650505147745415, 11.63962526023119, 10.666481329007084, 9.724346535402667, 8.680868647395453, 7.750213711975972, 6.7730061730671665, 5.847832714330123, 4.908872479251256, 3.9622639389207244, 2.993964177324755, 3.9490272041229626, 4.888410639424874, 5.942433478939247, 6.953146049371511, 7.845400103162335, 9.749464111184947, 10.784136645008555, 11.728256311091481, 12.797621972282712, 13.584247795037827, 12.635714728959783, 11.567254697244065, 10.575711896556502, 9.609832444672552, 8.710922073727344, 7.748395974126452, 6.87910883394697, 5.932893063781418, 5.016908969056699, 3.9511974066148925, 4.902005953309997, 5.852460232652888, 6.86408230877994, 7.829027156633928, 8.80707931019717, 10.675348876906071, 11.603301988851713, 12.621194863326657, 13.659814620844855, 14.513276286484171, 13.443528518802946, 12.510865384271874, 11.565419596499968, 10.560596450302555, 9.679614910292502, 8.699745532423979, 7.934077872696254, 6.952412453174667, 5.946802697801402, 4.9118588384216295, 5.861051103806278, 6.791258992391285, 7.718072820904627, 8.692326133329654, 9.719743498513155, 11.66900585747442, 12.572865571774066, 13.6262505662508, 14.693121514323032, 14.462582060525039, 13.541683718007414, 13.458127351094292, 12.554810307657505, 11.58579359161422, 10.68196279809496, 9.749212983490073, 8.861615134840978, 7.998653724885186, 7.012516043422625, 5.9430043254468785, 6.932131932351004, 7.813389054226013, 8.72367555613473, 9.678658543451332, 10.648227898698899, 12.581384209890782, 13.513133141347916, 14.53371548463809, 14.371135256751229, 13.509762498434686, 12.595641845864597, 13.488907145417564, 13.508556470184242, 12.572765301581388, 11.613087256719005, 10.808664905206149, 9.842189594218318, 8.917665681143825, 7.9028807604375935, 6.8789472063404435, 7.903212150399756, 8.867645003683464, 9.774572358386932, 10.657338319860115, 11.603907760394069, 13.55426616079202, 14.49579154163758, 14.371033255759194, 13.374838426520265, 12.538936484359539, 11.542890226435773, 12.449371756514289, 13.417017115653532, 13.636894201033012, 12.675202944060624, 11.779983956822706, 10.860551193189972, 9.837823655008934, 8.769912750837836, 7.84311330318558, 8.829120103512144, 9.843272814137803, 10.7368376239994, 11.680743403288524, 12.65901591097202, 14.613510793135204, 14.540503290049704, 13.488026643112855, 12.44396811130744, 11.543187658422656, 10.610863856716186, 11.475307836447382, 12.456854571045115, 13.460342540862621, 13.6803587488087, 12.783399813373393, 11.80594175319866, 10.775121507539463, 9.792697311246393, 8.794552197125606, 9.787125344467011, 10.766749657504178, 11.725706289737698, 12.699843077152645, 13.666933202421976, 14.453857979765084, 13.508037150667638, 12.53013027523572, 11.471302208400314, 10.539440216487288, 9.536060219152425, 10.470597100266296, 11.493507955068438, 12.465951805952157, 13.4663540505724, 13.716319731800073, 12.69418691775522, 11.733662444413286, 10.736715441952763, 9.809354971932693, 10.760061706914856, 11.76604857791881, 12.744882055068153, 13.670923567570737, 14.646146981827627, 13.637471066544117, 12.576817816316856, 11.548933850784483, 10.601913326159014, 9.558081032638126, 8.562845879543143, 9.507134077873513, 10.52895086065017, 11.533982600648901, 12.464404032870831, 13.511353630316497, 13.706147854901362, 12.665144207542838, 11.744865681694387, 10.848897441174362, 11.712927409577976, 12.664089770618425, 13.719792881681418, 14.598168875331604, 14.587468375098792, 12.660268665371543, 11.641234118606935, 10.617845915977796, 9.635227428490385, 8.610198410075874, 7.6357136823660765, 8.603505585532385, 9.659084534305265, 10.660533736978863, 11.668098629906531, 12.733376811620584, 13.725623245717198, 13.677974479597912, 12.796092154002741, 11.828521646381878, 12.668397526083911, 13.68611163605461, 14.626963965498005, 14.60072539262267, 13.63472718824779, 11.649041767478328, 10.637356781743152, 9.676704817077237, 8.699084553896016, 7.750789371791998, 6.693397781103901, 7.66858576538627, 8.68848490152633, 9.63024030701183, 10.642326288507771, 11.713893438373045, 12.73863939098359, 13.670135447637305, 13.771508808127722, 12.770816840235012, 13.636939882937522, 14.626205222023762, 14.599841383737377, 13.680629278178515, 12.707888747525947], [10.88718302713221, 11.84615828240514, 12.694609666810873, 13.685484808283455, 13.997996781219667, 14.741243636388967, 14.490213901813185, 13.581667521876149, 12.642010384677048, 11.634453518442271, 10.587318085587203, 9.754676649323873, 8.703110754178992, 7.694718321243182, 6.706676463037898, 6.096694740010474, 6.924321413960476, 7.948694011188751, 8.850267798822063, 9.87700539517217, 9.88152942923713, 10.801814188585507, 11.70409678850687, 12.652634009710562, 13.617381746790615, 14.50217747039056, 13.540087198192996, 12.638227204077367, 11.586464578283959, 10.597645921254443, 9.644250232824565, 8.69239686051081, 7.74868190333308, 6.73225473091581, 5.779548467467243, 5.090813935461837, 5.998873736471172, 6.92719558113535, 7.802177802989535, 8.847303050142784, 8.837806776203402, 9.767962735347616, 10.724722327176206, 11.69088804733986, 12.68972848014719, 13.462577741491012, 12.537357098857477, 11.585690375360233, 10.570027386577854, 9.64361780911239, 8.62340453936012, 7.69261155057095, 6.747080574092987, 5.805554661136175, 4.831255887874413, 4.1083214061793445, 4.925939469951388, 5.959731669048667, 6.876779651906368, 7.828608981578202, 7.819458731206117, 8.756872796226414, 9.779730142128194, 10.708339161632844, 11.74759867318222, 12.479248594799635, 11.530767817347064, 10.539659282944841, 9.55410893278656, 8.74449225956011, 7.772422014774802, 6.704246684750302, 5.7875576841649785, 4.8250092438092285, 3.811349931932819, 3.0972451375929655, 3.996905559448729, 4.9320236352554385, 5.890945463561923, 6.899528147484004, 6.893883079782503, 7.842844699646028, 8.842758674280576, 9.8718145034207, 10.803537788598735, 11.588316781267576, 10.543019284243464, 9.60231588496159, 8.561982822662188, 7.677953623715414, 6.728313654327247, 5.764876984337752, 4.840201357669169, 3.8528560434740364, 2.832520685703236, 2.036100275487178, 2.9978096976949145, 3.9266730474721165, 4.945082681699004, 5.996109427179372, 5.8857809863864805, 6.947520676865637, 7.896758573300662, 8.822145490944502, 9.860974951978358, 10.54571423281501, 9.608538779023947, 8.640009017827126, 7.630029465027002, 6.702495653397287, 5.756348761741814, 4.80394736048417, 3.8134283889460088, 2.884469440610885, 1.9066590706857542, 1.067213806718767, 1.9862434137640843, 3.0409223196393933, 4.0930081014922814, 4.935437927125805, 5.0051489886304426, 6.019321037586262, 6.9805035141783796, 7.987497992085955, 9.056391057735222, 9.967773575171053, 9.026152013975697, 7.979056115858022, 6.969090450134695, 5.995801458996663, 4.928836725380679, 3.999729102309629, 3.0175612611380638, 1.9839531009619755, 0.954179147256716, 0.0, 1.0239897691290265, 2.065060382239498, 3.07345267579589, 4.006007597362964, 5.971057387544743, 6.971516386961279, 7.962814591329816, 8.972692094295725, 9.944248569278333, 10.925776720622586, 9.94647222396012, 8.87909432964465, 7.811744367939624, 6.846743483714311, 5.890142430354797, 4.931658508275244, 4.042507684947617, 2.987638808076471, 2.025056349963914, 1.0540591850557735, 1.983645785156412, 2.9226011095084345, 3.973655324665616, 4.943093827237509, 6.940476528181617, 7.992113181409177, 8.985813864568614, 9.91385145574664, 10.86111577324061, 11.703366760196612, 10.767085662965973, 9.739827473581258, 8.775256837561752, 7.835307507237674, 6.902185622066569, 5.85828676454568, 4.919639929012949, 3.980241323955216, 2.9509301550482396, 2.0824806070410142, 3.0101981897365784, 3.993966420507467, 4.962070158310605, 5.910532430722591, 7.878556230941842, 8.883695306204034, 9.85439893956446, 10.835524016063655, 11.79341289865753, 12.591323142079998, 11.618179210855892, 10.676044417251475, 9.632566529244261, 8.701911593824779, 7.724704054915974, 6.799530596178931, 5.860570361100064, 4.913961820769532, 3.9456620591735625, 3.0445983115054216, 3.983981746807333, 4.988254331682532, 5.998966902114795, 6.891220955905619, 8.845035218567405, 9.879707752391013, 10.82382741847394, 11.863268870784928, 12.727155545949943, 13.587412610808592, 12.518952579092874, 11.52740977840531, 10.56153032652136, 9.662619955576151, 8.70009385597526, 7.830806715795777, 6.884590945630226, 5.968606850905506, 4.9028952884637, 4.107307956646588, 4.948031340035346, 5.959653416162398, 6.924598264016386, 7.902650417579627, 9.770919984288527, 10.69887309623417, 11.716765970709114, 12.75538572822731, 13.766725209198029, 14.395226400651755, 13.462563266120682, 12.517117478348776, 11.512294332151363, 10.63131279214131, 9.651443414272787, 8.885775754545062, 7.904110335023475, 6.89850057965021, 5.863556720270437, 5.0836562365487445, 5.886830099773743, 6.813643928287085, 7.787897240712112, 8.815314605895612, 10.764576964856877, 11.668436679156523, 12.721821673633256, 13.788692621705486, 14.066279658745222, 14.49586286526413, 14.409825232943101, 13.506508189506313, 12.537491473463028, 11.633660679943768, 10.700910865338882, 9.813313016689786, 8.950351606733992, 7.964213925271432, 6.894702207295687, 6.15473706509347, 6.908960161608471, 7.819246663517188, 8.77422965083379, 9.743799006081357, 11.67695531727324, 12.608704248730373, 13.629286592020547, 13.932396390327257, 13.113460096654869, 13.549820993121312, 14.44308629267428, 14.46025435203305, 13.524463183430196, 12.564785138567814, 11.760362787054957, 10.793887476067127, 9.869363562992634, 8.854578642286402, 7.830645088189252, 7.162375537300984, 7.963216111065923, 8.87014346576939, 9.752909427242573, 10.699478867776527, 12.649837268174478, 13.591362649020038, 13.843336553690412, 12.936099560096293, 12.142634082579722, 12.497069373692488, 13.403550903771006, 14.371196262910248, 14.58859208288182, 13.626900825909432, 12.731681838671514, 11.81224907503878, 10.789521536857743, 9.721610632686644, 8.794811185034389, 8.088283490413373, 8.979979347535288, 9.832408731381857, 10.776314510670982, 11.754587018354478, 13.709081900517662, 13.810467051689194, 12.848685387258064, 12.005229244883468, 11.116705708046425, 11.565043003972901, 12.429486983704098, 13.41103371830183, 14.414521688119336, 14.632056630657509, 13.735097695222201, 12.757639635047468, 11.726819389388272, 10.744395193095201, 9.746250078974414, 9.115619695752315, 9.981201972040093, 10.879775759169513, 11.795414184535103, 12.762504309804434, 13.71112487542482, 12.765304046327374, 11.890789019380929, 11.032563341976342, 10.112958266111056, 10.49023936640914, 11.424776247523011, 12.447687102325153, 13.420130953208872, 14.420533197829116, 14.668017613648882, 13.645884799604028, 12.685360326262094, 11.688413323801571, 10.761052853781502, 10.08855605820016, 10.980500892454724, 11.898951524499969, 12.766494674953195, 13.741718089210085, 12.823574026431903, 11.834084711976592, 10.905641449148037, 9.958620924522569, 9.131599082261895, 9.517025026799859, 10.461313225130228, 11.483130007906885, 12.488161747905616, 13.418583180127547, 14.465532777573213, 14.65784573675017, 13.616842089391646, 12.696563563543195, 11.80059532302317, 11.04142176086328, 11.935682799989948, 12.924086063826879, 13.693739982714062, 13.731433203799874, 11.810716121826562, 10.855102460060273, 9.912803280692469, 8.954600000452448, 8.068006500221015, 8.589892829622793, 9.557684732789102, 10.613263681561982, 11.61471288423558, 12.622277777163248, 13.6875559588773, 14.679802392973915, 14.62967236144672, 13.74779003585155, 12.780219528230687, 11.996891877369215, 12.957704665426133, 13.898556994869528, 13.7421984844469, 12.776200280072022, 10.799489223933348, 9.787804238198172, 8.902665816162044, 7.953629595021433, 7.106509175900395, 7.647576928360618, 8.622764912642987, 9.642664048783047, 10.584419454268547, 11.596505435764488, 12.668072585629762, 13.692818538240306, 14.624314594894022, 14.72320668997653, 13.72251472208382, 12.965434234222826, 13.954699573309066, 13.68808700469225, 12.81612563877044, 11.849361839350179], [9.8718673469645, 10.83084260223743, 11.67061989768185, 12.661495039154431, 13.62342140684075, 14.561828522488657, 15.452378999345283, 14.543832619408247, 13.604175482209147, 12.596618615974368, 11.549483183119301, 10.71684174685597, 9.66527585171109, 8.656883418775282, 7.668841560569996, 6.848855856819551, 5.909005733792764, 6.933378331021039, 7.834952118654352, 8.86168971500446, 8.857539660108102, 9.777824419456481, 10.680107019377846, 11.628644240581538, 12.593391977661591, 13.582626604171402, 14.502252295725095, 13.600392301609467, 12.548629675816057, 11.559811018786542, 10.606415330356663, 9.654561958042908, 8.71084700086518, 7.694419828447908, 6.741713564999341, 5.842975052270914, 4.98355805630346, 5.911879900967638, 6.786862122821822, 7.831987369975072, 7.813817007074377, 8.74397296621859, 9.700732558047182, 10.666898278210835, 11.665738711018166, 12.678552355361582, 13.499522196389576, 12.547855472892332, 11.532192484109952, 10.605782906644489, 9.585569636892219, 8.654776648103049, 7.709245671625087, 6.767719758668274, 5.793420985406511, 4.860482522988422, 3.910623789783676, 4.944415988880953, 5.861463971738655, 6.813293301410489, 6.795468962077091, 7.7328830270973885, 8.755740372999169, 9.684349392503819, 10.723608904053194, 11.749050862975901, 12.492932914879162, 11.50182438047694, 10.516274030318659, 9.706657357092208, 8.734587112306901, 7.666411782282401, 6.749722781697079, 5.787174341341329, 4.773515029464918, 3.9101085057211487, 2.981589879281017, 3.916707955087726, 4.875629783394211, 5.88421246731629, 5.869893310653477, 6.818854930517002, 7.8187689051515505, 8.847824734291674, 9.77954801946971, 10.845356189384912, 11.505184381775562, 10.564480982493688, 9.524147920194286, 8.640118721247513, 7.690478751859345, 6.72704208186985, 5.80236645520127, 4.815021141006136, 3.794685783235336, 2.8584731142884596, 1.9824940175272023, 2.9113573673044044, 3.9297670015312915, 4.972119658050345, 4.861791217257455, 5.923530907736612, 6.872768804171637, 7.798155721815476, 8.836985182849332, 9.86456497002462, 10.570703876556045, 9.602174115359224, 8.5921945625591, 7.664660750929386, 6.718513859273912, 5.766112458016269, 4.775593486478108, 3.8466345381429843, 2.868824168217854, 1.889586645520049, 0.9622536446350579, 2.016932550510367, 3.069018332363255, 3.9114481579967784, 3.9811592195014156, 4.995331268457235, 5.956513745049353, 6.9635082229569285, 8.032401288606195, 9.101139293469409, 10.042760854664765, 9.003045884987047, 7.993080219263721, 7.019791228125689, 5.952826494509705, 5.023718871438655, 4.04155103026709, 3.007942870091002, 1.9781689163857425, 1.0239897691290265, 0.0, 1.0410706131104717, 2.0494629066668635, 2.982017828233937, 4.947067618415716, 5.947526617832252, 6.9388248222007896, 7.948702325166698, 8.920258800149306, 9.970253829765173, 10.94955832642764, 9.903084098773679, 8.835734137068652, 7.870733252843339, 6.914132199483824, 5.955648277404269, 5.062272628412108, 4.007403751540961, 2.9571580297771205, 1.9861608648689801, 1.0565742647683416, 1.9955295891203644, 3.046583804277546, 3.9191040581084815, 5.91648675905259, 6.96812341228015, 7.961824095439587, 8.889861686617612, 9.837126004111582, 10.841670536606397, 11.715627626443704, 10.688369437058988, 9.723798801039482, 8.783849470715404, 7.850727585544299, 6.790388444358886, 5.851741608826155, 4.912343003768422, 3.8830318348614457, 3.014582286854221, 2.114723939325992, 3.066894900119397, 4.034998637922535, 4.886542661593563, 6.854566461812815, 7.859705537075007, 8.830409170435432, 9.811534246934627, 10.769423129528503, 11.780303017042728, 12.550280890669097, 11.60814609706468, 10.564668209057466, 9.634013273637985, 8.65680573472918, 7.731632275992137, 6.79267204091327, 5.846063500582738, 4.8777637389867685, 3.9766999913186285, 3.1174192843860933, 4.0611828112944615, 5.0718953817267245, 5.867231186776592, 7.82632072043673, 8.860993254260338, 9.805112920343262, 10.839279101655901, 11.703165776820915, 12.676793646457039, 13.451054258906078, 12.459511458218515, 11.493632006334565, 10.594721635389357, 9.632195535788464, 8.762908395608983, 7.816692625443432, 6.900708530718712, 5.834996968276906, 5.039409636459795, 4.081468877614107, 5.091892433078024, 6.056837280932012, 6.883935919448951, 8.769828545635368, 9.697781657581011, 10.715674532055955, 11.754294289574151, 12.742735440069001, 13.632827322004983, 14.394664945933886, 13.44921915816198, 12.444396011964567, 11.563414471954514, 10.583545094085991, 9.817877434358268, 8.836212014836681, 7.830602259463416, 6.795658400083643, 6.0157579163619515, 5.020267637352504, 5.947081465865846, 6.9213347782908725, 7.814223167242453, 9.763485526203718, 10.667345240503364, 11.720730234980097, 12.787601183052328, 13.760157067909914, 14.691841241580349, 15.341926912756305, 14.438609869319517, 13.469593153276232, 12.565762359756972, 11.633012545152086, 10.745414696502992, 9.882453286547198, 8.896315605084638, 7.826803887108893, 6.994996973770536, 6.042397699187232, 6.952684201095948, 7.9076671884125505, 8.817102486235981, 10.762827989318675, 11.607612810077214, 12.628195153367388, 12.917080710159546, 13.816971389988762, 14.51198609065341, 15.405251390206377, 15.392356031846255, 14.4565648632434, 13.496886818381018, 12.692464466868161, 11.725989155880333, 10.80146524280584, 9.786680322099608, 8.762746768002458, 8.00263544597805, 7.096653648644684, 8.00358100334815, 8.886346964821334, 9.832916405355288, 11.735709940219913, 12.618364169759946, 12.8280208735227, 11.920783879928582, 12.846145375913615, 13.459234471224587, 14.365716001303102, 15.333361360442346, 15.520693762695025, 14.559002505722637, 13.663783518484719, 12.744350754851986, 11.721623216670949, 10.65371231249985, 9.726912864847595, 8.92854339909044, 8.113416885114049, 8.965846268960618, 9.909752048249743, 10.888024555933239, 12.794954572563096, 12.795151371521484, 11.833369707090352, 10.989913564715756, 11.868866824855502, 12.527208101505, 13.391652081236195, 14.373198815833929, 15.376686785651435, 15.564158310470713, 14.667199375035405, 13.689741314860672, 12.658921069201476, 11.676496872908407, 10.67835175878762, 9.95587960442938, 9.114639509618854, 10.013213296748274, 10.928851722113864, 11.895941847383195, 12.69580919525711, 11.749988366159664, 10.875473339213217, 10.01724766180863, 10.865119382920133, 11.452404463941239, 12.38694134505511, 13.409852199857252, 14.38229605074097, 15.382698295361214, 15.600119293462086, 14.577986479417232, 13.617462006075298, 12.620515003614777, 11.693154533594708, 10.928815966877226, 10.113938430033485, 11.03238906207873, 11.899932212531956, 12.875155626788846, 11.808258346264193, 10.818769031808882, 9.890325768980325, 8.943305244354857, 9.883760199070972, 10.479190124331957, 11.423478322662326, 12.445295105438984, 13.450326845437715, 14.380748277659645, 15.427697875105311, 15.589947416563374, 14.54894376920485, 13.628665243356402, 12.732697002836376, 11.881681669540345, 11.069120337568709, 12.05752360140564, 12.827177520292823, 12.716117523632164, 10.79540044165885, 9.839786779892563, 8.897487600524759, 7.939284320284735, 8.820167617030092, 9.552057927154891, 10.519849830321203, 11.575428779094082, 12.57687798176768, 13.584442874695348, 14.649721056409401, 15.641967490506016, 15.561774041259925, 14.679891715664755, 13.712321208043893, 12.837151786046281, 12.091142203004894, 13.031994532448289, 12.72688280427919, 11.760884599904312, 9.784173543765636, 8.77248855803046, 7.887350135994332, 6.938313914853722, 7.858670292709472, 8.609742025892716, 9.584930010175087, 10.604829146315147, 11.546584551800647, 12.558670533296588, 13.630237683161862, 14.654983635772407, 15.58647969242612, 15.655308369789736, 14.654616401897027, 13.805694142899892, 13.16576119933821, 12.664097235563226, 11.80080995860273, 10.834046159182469], [8.835374824644207, 9.792058152336033, 10.629549284571379, 11.62042442604396, 12.582350793730278, 13.520757909378183, 14.548101722996162, 15.562985827723793, 14.645246095319619, 13.637689229084842, 12.590553796229774, 11.65769019498814, 10.591626680876633, 9.583234247940824, 8.595192389735539, 7.7695121128770595, 6.829661989850273, 6.095373265212608, 6.880814863833406, 7.9075524601835125, 7.816469046997631, 8.736753806346009, 9.639036406267374, 10.587573627471066, 11.55232136455112, 12.541555991060928, 13.60498469555919, 14.596980509352838, 13.58970028892653, 12.600881631897014, 11.647485943467135, 10.69563257115338, 9.637197830030722, 8.620770657613452, 7.668064394164884, 6.7636313083284225, 5.904214312360969, 5.0650484287483275, 5.832724868000876, 6.877850115154126, 6.772746393963905, 7.7029023531081195, 8.65966194493671, 9.625827665100363, 10.624668097907694, 11.637481742251108, 12.663050308828412, 13.588926086002804, 12.573263097220424, 11.646853519754961, 10.62664025000269, 9.69584726121352, 8.690045422271512, 7.694070587833816, 6.719771814572054, 5.78113877904593, 4.831280045841185, 4.051646583723059, 4.9073267169177095, 5.859156046589543, 5.754398348966619, 6.691812413986916, 7.714669759888696, 8.643278779393345, 9.68253829094272, 10.707980249865427, 11.656461027317999, 12.542894993587412, 11.557344643429131, 10.74772797020268, 9.775657725417373, 8.707482395392873, 7.790793394807551, 6.828244954451801, 5.81458564257539, 4.830764761778656, 3.902246135338525, 3.023938549929831, 3.9214925285732645, 4.901267860885905, 4.828822697543005, 5.77778431740653, 6.7776982920410775, 7.806754121181202, 8.738477406359237, 9.804285576274442, 10.805345547566814, 11.60555159560416, 10.565218533304758, 9.681189334357985, 8.731549364969817, 7.7681126949803225, 6.843437068311742, 5.856091754116608, 4.835756396345808, 3.864859695792447, 2.9031502735847106, 1.9742869238075085, 2.9756297467103447, 3.931049044939873, 3.8207206041469823, 4.882460294626139, 5.831698191061164, 6.757085108705003, 7.795914569738859, 8.823494356914146, 9.76066981070521, 10.643244728469696, 9.633265175669573, 8.705731364039858, 7.759584472384384, 6.807183071126741, 5.81666409958858, 4.887705151253456, 3.9098947813283256, 2.9306572586305206, 2.0033242577455295, 0.9758619373998951, 2.027947719252783, 2.8703775448863063, 2.940088606390944, 3.954260655346763, 4.915443131938881, 5.922437609846456, 6.991330675495723, 8.060068680358937, 9.001690241554293, 10.04411649809752, 9.034150832374193, 8.06086184123616, 6.993897107620177, 6.064789484549127, 5.082621643377562, 4.049013483201474, 3.019239529496214, 2.065060382239498, 1.0410706131104717, 0.0, 1.0083922935563916, 1.9409472151234652, 3.905997005305245, 4.906456004721781, 5.8977542090903174, 6.907631712056226, 7.8791881870388325, 8.9291832166547, 9.908487713317166, 10.94415471188415, 9.876804750179124, 8.91180386595381, 7.955202812594296, 6.960603831262012, 6.006699225109429, 4.951830348238282, 3.901584626474441, 2.9305874615663003, 2.001000861465662, 1.0620455371136392, 2.058953992993877, 2.8780334449980103, 4.875416145942119, 5.927052799169679, 6.920753482329116, 7.84879107350714, 8.79605539100111, 9.800599923495925, 10.736881020726564, 11.632796033756307, 10.668225397736801, 9.728276067412724, 8.79515418224162, 7.734815041056207, 6.796168205523476, 5.856769600465743, 4.8274584315587665, 3.959008883551541, 3.0591505360233118, 2.1334108481126717, 3.0473688266388663, 3.845472048483092, 5.8134958487023445, 6.818634923964536, 7.789338557324961, 8.770463633824155, 9.728352516418031, 10.739232403932256, 11.712376335156362, 12.552572693762002, 11.509094805754788, 10.578439870335306, 9.6012323314265, 8.676058872689458, 7.737098637610591, 6.790490097280059, 5.822190335684089, 4.921126588015949, 4.061845881083413, 3.127698759287736, 4.084265570443056, 4.826160573666121, 6.7852501073262586, 7.819922641149866, 8.764042307232792, 9.798208488545429, 10.662095163710443, 11.635723033346567, 12.704183065062285, 13.403938054915837, 12.438058603031887, 11.539148232086678, 10.576622132485785, 9.707334992306304, 8.761119222140753, 7.845135127416033, 6.779423564974227, 5.983836233157116, 5.025895474311427, 4.158408381071298, 5.123353228925286, 5.84286530633848, 7.728757932524897, 8.65671104447054, 9.674603918945484, 10.71322367646368, 11.701664826958531, 12.591756708894511, 13.524419843425584, 14.393645754859303, 13.38882260866189, 12.507841068651835, 11.527971690783312, 10.762304031055589, 9.780638611534002, 8.775028856160738, 7.740084996780964, 6.960184513059272, 5.964694234049824, 5.191059777988108, 6.058706152033417, 6.773152554131982, 8.722414913093246, 9.626274627392894, 10.679659621869627, 11.746530569941857, 12.719086454799443, 13.650770628469877, 14.471681810248002, 15.38303646601684, 14.414019749973555, 13.510188956454293, 12.577439141849407, 11.689841293200313, 10.82687988324452, 9.84074220178196, 8.771230483806214, 7.939423570467855, 6.986824295884551, 6.19666251321821, 7.045038562155095, 7.776031873125511, 9.721757376208203, 10.566542196966743, 11.587124540256918, 12.55524404001577, 13.628497212217697, 14.596812500612694, 15.43660534756698, 16.336782628543578, 15.400991459940723, 14.44131341507834, 13.636891063565482, 12.670415752577654, 11.74589183950316, 10.731106918796929, 9.707173364699779, 8.94706204267537, 8.041080245342002, 7.247559315470411, 8.023718338563878, 8.831608047093265, 10.69463932710944, 11.577293556649476, 12.017641629994595, 12.841440135986089, 13.76680163197112, 14.38558530039013, 15.292066830468645, 16.25971218960789, 16.465120359392348, 15.50342910241996, 14.60821011518204, 13.688777351549307, 12.66604981336827, 11.598138909197171, 10.671339461544916, 9.87296999578776, 9.057843481811368, 8.209824581082879, 9.090886677389165, 9.886716197671216, 11.753883959452624, 11.841014116700538, 11.022990463562246, 11.910569820773263, 12.789523080913012, 13.453558930670543, 14.318002910401738, 15.299549644999471, 16.30303761481698, 16.508584907168036, 15.611625971732726, 14.634167911557995, 13.603347665898799, 12.620923469605728, 11.622778355484941, 10.9003062011267, 10.059066106316173, 9.257191608870535, 10.109986351253285, 10.894633489121173, 11.741671940436165, 10.795851111338719, 10.065094095685112, 10.937903917866137, 11.785775638977643, 12.378755293106781, 13.313292174220653, 14.336203029022794, 15.308646879906513, 16.309049124526755, 16.54454589015941, 15.522413076114555, 14.56188860277262, 13.564941600312098, 12.637581130292029, 11.873242563574545, 11.058365026730804, 10.27636737420099, 11.081066841671378, 11.943445173849211, 10.854121091443247, 9.864631776987936, 9.07994652545222, 9.863961500412364, 10.804416455128482, 11.4055409534975, 12.349829151827869, 13.371645934604526, 14.376677674603258, 15.307099106825188, 16.354048704270852, 16.534374013260695, 15.493370365902173, 14.573091840053722, 13.677123599533697, 12.826108266237664, 12.013546934266028, 11.3015019135279, 12.008312149432244, 11.679625001311871, 9.841263186837907, 8.885649525071617, 8.059482534716327, 8.859940576342243, 9.740823873087603, 10.478408756320434, 11.446200659486745, 12.501779608259625, 13.503228810933223, 14.510793703860891, 15.582389962504834, 16.57578618568098, 16.50620063795725, 15.624318312362076, 14.656747804741213, 13.7815783827436, 13.035568799702213, 12.37138156572577, 11.690390281958898, 10.72439207758402, 8.830036288944692, 7.818351303209515, 7.0493450701859, 7.85897017091123, 8.779326548766981, 9.536092855058259, 10.51128083934063, 11.53117997548069, 12.47293538096619, 13.518340869141397, 14.589908019006671, 15.614653971617216, 16.50206959812583, 15.572650761654081, 14.53948682368333, 13.614913340727119, 12.679976396832954, 11.623026622452755, 10.762025508701333, 9.797553636862176], [7.8269825310878165, 8.78366585877964, 9.621156991014985, 10.612032132487567, 11.573958500173887, 12.512365615821793, 13.539709429439771, 14.554593534167402, 15.494250671366503, 14.585804457727193, 13.538669024872124, 12.597241523634734, 11.531178009523227, 10.522785576587419, 9.534743718382133, 8.690738499818075, 7.733353020844483, 6.87334869788587, 5.872422570277014, 6.899160166627121, 6.80807675344124, 7.7283615127896175, 8.630644112710982, 9.579181333914674, 10.543929070994729, 11.533163697504538, 12.5965924020028, 13.588588215796447, 14.598092582482922, 13.548996860539365, 12.595601172109486, 11.635559098404336, 10.576749158677316, 9.560321986260046, 8.60761572281148, 7.7031826369750185, 6.807905343355179, 5.879583498691001, 4.824332574444485, 5.869457821597734, 5.764354100407513, 6.694510059551728, 7.651269651380319, 8.617435371543973, 9.616275804351304, 10.629089448694717, 11.654658015272021, 12.676546524698965, 13.581655390776817, 12.632873239030788, 11.612659969278518, 10.681866980489348, 9.629596750918106, 8.633621916480411, 7.65932314321865, 6.720690107692526, 5.770831374487781, 4.914137392849742, 3.898934423361318, 4.850763753033152, 4.746006055410228, 5.683420120430525, 6.706277466332304, 7.6348864858369545, 8.67414599738633, 9.699587956309037, 10.648068733761608, 11.63917726816383, 12.565736936985523, 11.756120263759072, 10.784050018973765, 9.715874688949265, 8.799185688363943, 7.836637248008193, 6.814346419394132, 5.770316090425254, 4.841797463985122, 3.9066793881784125, 2.913100235016873, 3.8928755673295137, 3.820430403986614, 4.769392023850139, 5.769305998484686, 6.7983618276248095, 7.730085112802845, 8.795893282718048, 9.796953254010424, 10.683114145480104, 11.57361082686115, 10.689581627914377, 9.73994165852621, 8.776504988536715, 7.851829361868132, 6.864484047673001, 5.8441486899022, 4.873251989348839, 3.9115425671411024, 2.9826792173639003, 1.9672374531539534, 2.9226567513834816, 2.812328310590591, 3.8740680010697472, 4.823305897504772, 5.748692815148612, 6.787522276182468, 7.815102063357755, 8.75227751714882, 9.72080727834564, 10.641657469225965, 9.71412365759625, 8.767976765940777, 7.8155753646831325, 6.825056393144972, 5.896097444809848, 4.918287074884717, 3.9390495521869124, 3.0117165513019213, 1.9842542309562867, 1.0195554256963915, 1.8619852513299149, 1.9316963128345521, 2.9458683617903714, 3.9070508383824896, 4.914045316290065, 5.982938381939332, 7.051676386802545, 7.9932979479979025, 9.040393846115578, 10.042543125930585, 9.069254134792553, 8.002289401176569, 7.073181778105519, 6.091013936933954, 5.057405776757865, 4.027631823052606, 3.07345267579589, 2.0494629066668635, 1.0083922935563916, 0.0, 0.9325549215670735, 2.897604711748853, 3.8980637111653893, 4.889361915533926, 5.8992394184998345, 6.870795893482441, 7.920790923098309, 8.900095419760776, 9.967473314076246, 10.885197043735516, 9.920196159510203, 8.963595106150688, 7.9689961248184025, 7.01509151866582, 5.960222641794673, 4.909976920030832, 3.9389797551226917, 3.009393155022053, 2.0704378306700306, 1.0505616994374858, 1.8696411514416185, 3.867023852385727, 4.918660505613287, 5.912361188772724, 6.84039877995075, 7.787663097444719, 8.792207629939535, 9.728488727170173, 10.75574691655489, 11.676617691293194, 10.736668360969116, 9.803546475798012, 8.743207334612599, 7.804560499079868, 6.865161894022134, 5.835850725115158, 4.9674011771079325, 4.067542829579703, 3.1057941498996877, 2.038976533082475, 2.8370797549267004, 4.805103555145952, 5.810242630408144, 6.780946263768569, 7.762071340267763, 8.719960222861639, 9.730840110375864, 10.70398404159997, 11.646118835204387, 12.517487099311179, 11.586832163891698, 10.609624624982892, 9.68445116624585, 8.745490931166982, 7.79888239083645, 6.830582629240481, 5.92951888157234, 5.070238174639805, 4.100082061074752, 3.0758732768866643, 3.817768280109729, 5.776857813769866, 6.811530347593473, 7.755650013676399, 8.789816194989037, 9.653702870154051, 10.627330739790175, 11.695790771505893, 12.687333572193456, 13.446450896588278, 12.54754052564307, 11.585014426042177, 10.715727285862695, 9.769511515697143, 8.853527420972425, 7.787815858530618, 6.992228526713507, 6.034287767867818, 5.107101124457028, 4.14215627660304, 4.834473012782087, 6.720365638968505, 7.6483187509141475, 8.66621162538909, 9.704831382907287, 10.693272533402137, 11.583364415338119, 12.516027549869191, 13.461473337641097, 14.39721490221828, 13.516233362208228, 12.536363984339705, 11.77069632461198, 10.789030905090392, 9.783421149717128, 8.748477290337355, 7.968576806615664, 6.973086527606215, 6.0517625121361975, 5.077509199711171, 5.764760260575589, 7.714022619536855, 8.6178823338365, 9.671267328313233, 10.738138276385463, 11.71069416124305, 12.642378334913484, 13.46328951669161, 14.49043995947947, 15.422412043529945, 14.518581250010685, 13.5858314354058, 12.698233586756704, 11.83527217680091, 10.849134495338351, 9.779622777362604, 8.947815864024248, 7.995216589440943, 7.0573652473663, 6.063841609832849, 6.767639579569119, 8.713365082651812, 9.55814990341035, 10.578732246700524, 11.546851746459376, 12.620104918661303, 13.588420207056302, 14.428213054010588, 15.365887450108918, 16.409383753497114, 15.449705708634731, 14.645283357121874, 13.678808046134044, 12.754284133059551, 11.73949921235332, 10.71556565825617, 9.955454336231762, 9.049472538898394, 8.083066004984367, 7.042521386241632, 7.823215753536874, 9.68624703355305, 10.568901263093082, 11.581686570170595, 12.54314857669034, 13.468510072675372, 14.464556330599137, 15.427479463463172, 16.34628797226336, 17.301577863361974, 16.511821395976348, 15.616602408738432, 14.697169645105697, 13.67444210692466, 12.606531202753562, 11.679731755101306, 10.881362289344152, 10.05987199704349, 9.045331270596835, 8.109689725066918, 8.878323904114826, 10.745491665896234, 10.832621823144146, 11.744256367695384, 12.794841274571725, 13.710749467854027, 14.393110259317137, 15.257554239048332, 16.239100973646067, 17.242588943463574, 17.516977200724426, 16.62001826528912, 15.642560205114385, 14.611739959455189, 13.629315763162118, 12.631170649041332, 11.908698494683094, 11.05165493061801, 10.09269829838449, 9.128789398931039, 9.886241195564782, 10.733279646879772, 9.787458817782326, 10.786359999818249, 11.8221753716646, 12.707002025918658, 13.318306621753376, 14.252843502867247, 15.275754357669388, 16.24819820855311, 17.248600453173353, 17.5529381837158, 16.530805369670947, 15.570280896329011, 14.573333893868488, 13.64597342384842, 12.881634857130939, 12.050953851032641, 11.085185429218892, 10.099869889349131, 10.93505288029282, 9.845728797886856, 8.856239483431544, 9.801212429585357, 10.748232954210826, 11.725642842069497, 12.345092282144094, 13.289380480474463, 14.31119726325112, 15.316229003249852, 16.246650435471782, 17.293600032917446, 17.54276630681709, 16.501762659458564, 15.581484133610113, 14.685515893090088, 13.834500559794058, 13.006135758567865, 12.075699059219932, 11.027115197109998, 10.67123270775548, 8.832870893281514, 7.877257231515226, 8.780748438849464, 9.763366926336875, 10.662050260028618, 11.417960084967028, 12.38575198813334, 13.441330936906219, 14.442780139579817, 15.450345032507485, 16.52194129115143, 17.36666224656847, 16.421652123515887, 15.479219172014894, 14.473389723980073, 13.57506340402434, 12.567417234180262, 11.626564904736867, 10.681997988402507, 9.715999784027629, 7.8216439953883, 6.809959009653124, 7.770610974319039, 8.762661201905441, 9.700552935707996, 10.475644183704853, 11.450832167987224, 12.470731304127284, 13.412486709612784, 14.457892197787992, 15.529459347653265, 16.46797032735924, 15.493677304569436, 14.564258468097691, 13.53109453012694, 12.606521047170729, 11.67158410327656, 10.614634328896361, 9.75363321514494, 8.789161343305786], [6.894427609520742, 7.851110937212567, 8.688602069447914, 9.679477210920496, 10.641403578606813, 11.579810694254718, 12.607154507872696, 13.622038612600328, 14.561695749799428, 15.45842264121421, 14.411287208359141, 13.469859707121751, 12.403796193010244, 11.395403760074435, 10.40736190186915, 9.563356683305091, 8.6059712043315, 7.745966881372889, 6.745040753764032, 6.117654371837886, 5.875521831874166, 6.795806591222544, 7.698089191143909, 8.6466264123476, 9.611374149427654, 10.600608775937463, 11.664037480435725, 12.656033294229372, 13.707795920022782, 14.421615044026382, 13.468219355596503, 12.508177281891353, 11.449367342164333, 10.432940169747063, 9.480233906298496, 8.575800820462035, 7.6805235268421965, 6.752201682178018, 5.696950757931503, 5.058892763950641, 4.8317991788404395, 5.761955137984654, 6.718714729813245, 7.684880449976898, 8.683720882784229, 9.696534527127643, 10.722103093704947, 11.74399160313189, 12.70809115054633, 13.505491422517805, 12.485278152765535, 11.554485163976365, 10.502214934405123, 9.506240099967428, 8.531941326705667, 7.593308291179543, 6.643449557974797, 5.78675557633676, 4.771552606848336, 4.020860253695374, 3.813451133843154, 4.750865198863451, 5.7737225447652305, 6.702331564269881, 7.741591075819255, 8.767033034741962, 9.715513812194533, 10.706622346596756, 11.692172696755037, 12.6688980875895, 11.712041960473602, 10.643866630449102, 9.679963349352976, 8.717414908997226, 7.686964602881149, 6.642934273912271, 5.714415647472139, 4.77929757166543, 3.785718418503891, 2.96032064576244, 2.88787548241954, 3.8368371022830647, 4.836751076917613, 5.8658069060577365, 6.797530191235772, 7.8633383611509755, 8.86439833244335, 9.750559223913031, 10.730185267213876, 11.622136549481452, 10.672496580093284, 9.70905991010379, 8.784384283435207, 7.797038969240074, 6.776703611469273, 5.748838042852796, 4.78712862064506, 3.858265270867858, 2.839855636640971, 1.9901018298164077, 1.8797733890235173, 2.941513079502674, 3.8907509759376993, 4.816137893581539, 5.854967354615395, 6.882547141790682, 7.819722595581746, 8.788252356778568, 9.798231909578691, 10.646678579163325, 9.700531687507851, 8.748130286250207, 7.757611314712046, 6.828652366376922, 5.850841996451791, 4.871604473753986, 3.9442714728689947, 2.9168091525233604, 1.8921736091834092, 0.9294303297628412, 0.9991413912674786, 2.013313440223298, 2.974495916815416, 3.9814903947229916, 5.050383460372258, 6.119121465235471, 7.060743026430828, 8.107838924548503, 9.11780459027183, 10.001809056359626, 8.934844322743642, 8.005736699672592, 7.023568858501027, 5.989960698324938, 4.960186744619679, 4.006007597362963, 2.982017828233937, 1.9409472151234652, 0.9325549215670735, 0.0, 1.9650497901817794, 2.9655087895983154, 3.956806993966853, 4.9666844969327615, 5.938240971915368, 6.988236001531236, 7.967540498193703, 9.034918392509173, 10.08072435515715, 10.852751081077276, 9.896150027717761, 8.872695646589783, 7.918791040437201, 6.863922163566054, 5.813676441802213, 4.8426792768940725, 3.9130926767934344, 2.974137352441412, 1.9230831372842299, 0.9370862298745448, 2.9344689308186536, 3.9861055840462134, 4.9798062672056504, 5.907843858383675, 6.855108175877644, 7.859652708372461, 8.7959338056031, 9.823191994987816, 10.787762631007322, 11.640367882740495, 10.707245997569391, 9.646906856383978, 8.708260020851247, 7.7688614157935145, 6.739550246886538, 5.871100698879314, 4.971242351351084, 3.9783155877464322, 2.9114979709292195, 1.9045248333596267, 3.8725486335788792, 4.877687708841071, 5.848391342201496, 6.82951641870069, 7.787405301294566, 8.79828518880879, 9.771429120032897, 10.713563913637314, 11.757041801644528, 12.490531685663079, 11.513324146754274, 10.588150688017231, 9.649190452938363, 8.702581912607831, 7.734282151011861, 6.8332184033437215, 5.973937696411186, 4.924674273395825, 3.899981106553092, 2.8852133585426554, 4.844302892202793, 5.8789754260264, 6.823095092109326, 7.857261273421964, 8.721147948586978, 9.694775818223102, 10.76323584993882, 11.754778650626383, 12.686005598921627, 13.451240047414451, 12.488713947813558, 11.619426807634078, 10.673211037468526, 9.757226942743806, 8.691515380301999, 7.840850569481817, 6.856537168759296, 5.8449150926322435, 4.879970244778256, 3.9019180912150144, 5.787810717401432, 6.7157638293470745, 7.733656703822017, 8.772276461340216, 9.760717611835066, 10.650809493771046, 11.583472628302118, 12.528918416074024, 13.56001918541255, 14.419932883979609, 13.440063506111086, 12.674395846383362, 11.692730426861775, 10.68712067148851, 9.652176812108737, 8.757744766846178, 7.716390308824756, 6.789576480311413, 5.815323167886387, 4.8322053390085165, 6.781467697969782, 7.6853274122694275, 8.738712406746162, 9.805583354818392, 10.778139239675978, 11.709823413346411, 12.530734595124537, 13.557885037912397, 14.526901753955682, 15.422280771782066, 14.48953095717718, 13.601933108528087, 12.738971698572293, 11.752834017109732, 10.683322299133986, 9.691119645242788, 8.738520370659483, 7.795179215541515, 6.801655578008065, 5.835084658002046, 7.780810161084738, 8.625594981843276, 9.64617732513345, 10.614296824892303, 11.68754999709423, 12.655865285489229, 13.495658132443515, 14.433332528541845, 15.485506957773257, 16.353405230406114, 15.548982878893256, 14.582507567905427, 13.657983654830932, 12.6431987341247, 11.61926518002755, 10.698758117450302, 9.792776320116934, 8.820879973159583, 7.780335354416848, 6.890660831969801, 8.753692111985977, 9.636346341526009, 10.649131648603522, 11.610593655123267, 12.5359551511083, 13.532001409032066, 14.4949245418961, 15.413733050696287, 16.3690229417949, 17.337700764588323, 16.520301930509813, 15.600869166877079, 14.578141628696041, 13.510230724524943, 12.583431276872687, 11.624666070562691, 10.797685965218706, 9.78314523877205, 8.847503693242134, 7.945768982547752, 9.81293674432916, 10.670568862768683, 11.64378281503587, 12.541463970336093, 13.55454625876516, 14.464027778751653, 15.468988461963008, 16.373895595304706, 17.429067757202866, 18.3428565693364, 17.523717787060498, 16.546259726885765, 15.515439481226569, 14.5330152849335, 13.534870170812713, 12.652002275901634, 11.789468898793226, 10.830512266559706, 9.866603367106254, 8.953686273997707, 10.109620371309445, 10.660077001269345, 11.658978183305269, 12.69479355515162, 13.579620209405675, 14.190924805240392, 15.125461686354264, 16.148372541156405, 17.120816392040126, 18.12121863666037, 18.45663770548718, 17.434504891442327, 16.473980418100393, 15.47703341563987, 14.5496729456198, 13.624938638349478, 12.788767819207857, 11.822999397394108, 10.837683857524347, 10.002497958725746, 9.143513723040165, 9.728857666918563, 10.673830613072377, 11.620851137697846, 12.598261025556514, 13.21771046563111, 14.16199866396148, 15.183815446738137, 16.18884718673687, 17.1192686189588, 18.166218216404463, 17.393244983799153, 16.452240615681614, 15.491583381137579, 14.520459007620515, 13.5979785989632, 12.656884178049372, 11.733214996153974, 10.68463113404404, 9.738677786188406, 8.130655818434823, 8.749875415002244, 9.653366622336485, 10.635985109823896, 11.534668443515635, 12.290578268454045, 13.258370171620356, 14.313949120393236, 15.315398323066834, 16.322963215994502, 17.394559474638445, 16.434107325001396, 15.489097201948812, 14.546664250447819, 13.540834802412999, 12.642508482457265, 11.634862312613187, 10.694009983169792, 9.749443066835433, 8.783444862460554, 7.1194289205416075, 7.682577193140141, 8.643229157806058, 9.635279385392458, 10.573171119195013, 11.34826236719187, 12.323450351474241, 13.3433494876143, 14.2851048930998, 15.330510381275008, 16.402077531140282, 15.535415405792165, 14.561122383002362, 13.631703546530616, 12.598539608559864, 11.673966125603654, 10.739029181709489, 9.68207940732929, 8.821078293577868, 7.856606421738711], [6.9699163365768655, 7.92659966426869, 8.764090796504036, 9.754965937976618, 10.716892305662935, 11.65529942131084, 12.682643234928818, 13.69752733965645, 14.63718447685555, 15.661610754601154, 16.37633699854092, 15.434909497303531, 14.368845983192024, 13.360453550256215, 12.37241169205093, 11.528406473486871, 10.57102099451328, 9.711016671554667, 8.71009054394581, 7.980093968536906, 5.951010558930289, 6.8712953182786665, 7.773577918200032, 8.722115139403723, 9.686862876483776, 10.676097502993585, 11.739526207491847, 12.731522021285494, 13.783284647078904, 14.808145659756363, 15.433269145778283, 14.473227072073133, 13.414417132346113, 12.397989959928843, 11.445283696480276, 10.540850610643815, 9.645573317023976, 8.717251472359798, 7.662000548113282, 6.9907697697354045, 4.907287905896562, 5.837443865040777, 6.794203456869368, 7.760369177033021, 8.759209609840351, 9.772023254183765, 10.79759182076107, 11.819480330188014, 12.77829376104978, 13.785548481580774, 14.450327942947315, 13.519534954158145, 12.467264724586903, 11.471289890149208, 10.496991116887447, 9.558358081361323, 8.608499348156577, 7.751805366518539, 6.736602397030115, 5.952737259480138, 3.888939860899277, 4.826353925919574, 5.849211271821353, 6.7778202913260035, 7.817079802875378, 8.842521761798086, 9.791002539250657, 10.78211107365288, 11.762375307258486, 12.739100698092951, 13.677091750655382, 12.608916420630882, 11.645013139534756, 10.682464699179006, 9.65201439306293, 8.607984064094051, 7.679465437653919, 6.744347361847209, 5.75076820868567, 4.91156957484543, 2.963364209475663, 3.9123258293391876, 4.87681500683785, 5.905870835977973, 6.837594121156009, 7.903402291071212, 8.904462262363587, 9.790623153833268, 10.770249197134113, 11.714493670248082, 12.637546370275064, 11.67410970028557, 10.749434073616987, 9.762088759421854, 8.741753401651053, 7.713887833034576, 6.75217841082684, 5.823315061049638, 4.804905426822751, 3.955151619998187, 1.9552621160796404, 2.9815770094229106, 3.930814905857936, 4.856201823501776, 5.895031284535632, 6.922611071710919, 7.859786525501983, 8.828316286698804, 9.838295839498928, 10.765829651128643, 11.665581477689631, 10.713180076431987, 9.722661104893826, 8.793702156558702, 7.81589178663357, 6.836654263935765, 5.909321263050773, 4.88185894270514, 3.8572233993651888, 2.8944801199446206, 1.0112313732845917, 1.9827416733369376, 2.943924149929056, 3.9509186278366313, 5.003500920122473, 6.0542909277959405, 6.98373604441229, 8.030831942529966, 9.040797608253293, 10.014086599391325, 10.824610006059137, 9.895502382988088, 8.988618648682806, 7.955010488506717, 6.925236534801458, 5.971057387544742, 4.947067618415716, 3.9059970053052444, 2.897604711748853, 1.9650497901817794, 0.0, 1.000458999416536, 1.9967110932945615, 3.00658859626047, 3.978145071243077, 5.028140100858945, 6.0074445975214115, 7.074822491836882, 8.142172453541907, 9.10717333776722, 10.004841835974386, 8.963572977022473, 8.00966837086989, 6.954799493998744, 5.904553772234903, 4.9335566073267625, 4.0039700072261235, 3.065014682874101, 2.0139604677169194, 1.0279635603072346, 0.9694191406368742, 2.0210557938644342, 3.0147564770238713, 3.9427940682018963, 4.890058385695866, 5.8946029181906825, 6.830884015421322, 7.858142204806038, 8.822712840825544, 9.762662171149621, 10.695784056320726, 9.737784186816668, 8.799137351283937, 7.8597387462262045, 6.830427577319228, 5.961978029312004, 5.0621196817837735, 4.069192918179121, 3.0023753013619086, 1.9954021637923165, 1.9074988433970996, 2.912637918659291, 3.8833415520197163, 4.86446662851891, 5.822355511112786, 6.833235398627011, 7.806379329851118, 8.748514123455534, 9.791992011462748, 10.708422648462676, 11.604201477186963, 10.679028018449921, 9.740067783371053, 8.793459243040521, 7.825159481444551, 6.9240957337764115, 6.064815026843875, 5.007651462882469, 3.982958296039736, 2.968190548029299, 2.953720820188006, 3.9218371362250135, 4.865307397316336, 5.8922114832401835, 6.756098158405198, 7.729726028041322, 8.79818605975704, 9.789728860444603, 10.720955808739847, 11.669131010214048, 12.579591278246248, 11.710304138066768, 10.764088367901216, 9.848104273176496, 8.782392710734689, 7.8350380994425874, 6.850724698720066, 5.839102622593014, 4.874157774739026, 3.896105621175785, 3.909778656834612, 4.837731768780254, 5.845651268160602, 6.8698454576787364, 7.795667821653285, 8.685759703589266, 9.618422838120338, 10.563868625892244, 11.59496939523077, 12.520090725482776, 13.499960103351299, 12.765273176816052, 11.741678176944635, 10.736068421571371, 9.701124562191598, 8.751932296806949, 7.710577838785526, 6.783764010272184, 5.809510697847157, 4.826392868969287, 4.9034356374029615, 5.807295351702607, 6.8606803461793415, 7.903152351156912, 8.813089449494196, 9.744773623164631, 10.565684804942757, 11.592835247730617, 12.561851963773902, 13.522438613285233, 14.49046525151352, 13.692810438960777, 12.787919448655153, 11.79914113527454, 10.728710121516286, 9.685307175203558, 8.732707900620253, 7.789366745502286, 6.795843107968835, 5.829272187962816, 5.902778100517918, 6.747562921276457, 7.768145264566631, 8.736264764325485, 9.765909011584549, 10.690815495307449, 11.530608342261734, 12.468282738360065, 13.520457167591477, 14.45356307190928, 15.48101719807615, 14.673384898338117, 13.703371477213233, 12.688586556507001, 11.664653002409851, 10.692945647411072, 9.786963850077704, 8.815067503120353, 7.774522884377618, 6.880254550014632, 6.875660051419157, 7.758314280959189, 8.771099588036702, 9.732561594556449, 10.65792309054148, 11.653969348465246, 12.57014373116501, 13.448683260514507, 14.403973151613119, 15.372650974406543, 16.3312959734777, 15.64625698925938, 14.623529451078342, 13.555618546907244, 12.628819099254988, 11.618853600523462, 10.791873495179477, 9.77733276873282, 8.841691223202904, 7.822679264291858, 7.93490468376234, 8.792536802201862, 9.76575075446905, 10.663431909769274, 11.676514198198342, 12.585995718184833, 13.544207651231918, 14.408845805122924, 15.464017967021087, 16.37780677915462, 17.334711830028386, 16.591647549268068, 15.560827303608871, 14.5784031073158, 13.580257993195014, 12.646189805862402, 11.783656428753996, 10.824699796520477, 9.817045553902993, 8.830596555741813, 8.935239353815433, 9.837699807563682, 10.723647122346184, 11.6360978126764, 12.567959804589426, 13.586760367197957, 14.521297248311829, 15.372192421099601, 16.344636271983322, 17.345038516603566, 18.288276465315064, 17.47989271382463, 16.519368240482695, 15.52242123802217, 14.581444499447661, 13.619126168310247, 12.782955349168628, 11.773441584190847, 10.788126044321086, 9.879408240469852, 9.901346002084713, 10.768919141914465, 11.708794692579076, 12.655815217204545, 13.549318988438587, 14.54455414153357, 15.48884233986394, 16.43462540173038, 17.406682471100655, 18.337103903322586, 18.431466451224217, 17.468733710855275, 16.527729342737736, 15.5670721081937, 14.595947734676637, 13.673467326019322, 12.732372905105496, 11.808703723210098, 10.760119861100163, 9.81416651324453, 9.853733807099879, 10.71492520518402, 11.618416412518261, 12.601034900005672, 13.499718233697415, 14.255628058635825, 15.223419961802136, 16.278998910575016, 17.280448113248617, 18.288013006176286, 17.502992275233662, 16.509596052057518, 15.564585929004934, 14.62215297750394, 13.61632352946912, 12.717997209513387, 11.71035103966931, 10.769498710225916, 9.824931793891556, 8.858933589516678, 8.981868517240628, 9.647626983321919, 10.608278947987834, 11.600329175574238, 12.538220909376793, 13.31331215737365, 14.288500141656021, 15.308399277796081, 16.250154683281583, 17.295560171456792, 16.63565008545883, 15.610904132848287, 14.636611110058483, 13.707192273586738, 12.674028335615986, 11.749454852659776, 10.81451790876561, 9.757568134385412, 8.896567020633992, 7.932095148794835], [7.9551396861684935, 7.061344784577561, 7.886068907910995, 8.876944049383576, 9.838870417069895, 10.7772775327178, 11.752765864341212, 12.767649969068842, 13.707307106267942, 14.731733384013546, 15.70415020153234, 16.431257902290856, 15.365194388179347, 14.356801955243538, 13.368760097038253, 12.524754878474194, 11.567369399500603, 10.70736507654199, 9.706438948933133, 8.965317318128534, 6.936233908521918, 6.0060404385875374, 6.8955560296069915, 7.844093250810682, 8.808840987890736, 9.798075614400545, 10.802639160721023, 11.79463497451467, 12.794271953339345, 13.807686660339822, 14.761082348769701, 15.469575477060456, 14.410765537333436, 13.394338364916166, 12.441632101467599, 11.537199015631138, 10.641921722011299, 9.713599877347121, 8.658348953100605, 7.9759931193270335, 5.892511255488191, 4.972188985349648, 5.916181568276327, 6.882347288439981, 7.881187721247311, 8.828168149113896, 9.799909061385504, 10.821797570812448, 11.77783476163324, 12.785089482164235, 13.777949180305137, 14.515883359145468, 13.463613129574226, 12.467638295136531, 11.49333952187477, 10.554706486348646, 9.6048477531439, 8.748153771505864, 7.732950802017439, 6.937960609071767, 4.874163210490906, 3.961099046228445, 4.932337646966248, 5.860946666470898, 6.819397043499813, 7.844839002422519, 8.793319779875091, 9.784428314277314, 10.761916307841947, 11.73864169867641, 12.718890367551763, 13.564218268891354, 12.641361544522079, 11.678813104166329, 10.648362798050252, 9.604332469081374, 8.675813842641242, 7.740695766834533, 6.747116613672994, 5.896792924437059, 3.948587559067292, 3.022085124250795, 3.8763560074213133, 4.905411836561437, 5.837135121739473, 6.902943291654676, 7.90400326294705, 8.790164154416729, 9.769790197717574, 10.714034670831543, 11.66367464021971, 12.624848568478804, 11.749893073033522, 10.758575619195893, 9.738240261425092, 8.710236238021901, 7.748526815814164, 6.819663466036962, 5.801253831810075, 4.951500024985512, 2.9404854656712693, 1.9811180100063743, 2.9303559064413998, 3.8557428240852394, 4.894572285119096, 5.922152072294383, 6.859327526085446, 7.827857287282266, 8.837836840082389, 9.765370651712104, 10.711517543367577, 11.663918944625221, 10.723120104310361, 9.794161155975237, 8.816350786050107, 7.837113263352302, 6.909780262467311, 5.882317942121675, 4.853571804352513, 3.8908285249319454, 1.9964547228762206, 0.9822826739204015, 1.9434651505125196, 2.950459628420095, 4.003041920705937, 5.053831928379404, 5.983277044995754, 7.030372943113429, 8.040338608836755, 9.013627599974788, 10.024621096684317, 10.895961382404625, 9.989077648099343, 8.955469487923255, 7.925695534217995, 6.971516386961279, 5.947526617832253, 4.906456004721781, 3.898063711165389, 2.9655087895983154, 1.000458999416536, 0.0, 0.9962520938780255, 2.006129596843934, 2.9776860718265405, 4.0276811014424085, 5.006985598104875, 6.0743634924203445, 7.14171345412537, 8.106714338350683, 9.063315391710198, 9.96403197643901, 9.010127370286426, 7.955258493415279, 6.905012771651438, 5.934015606743298, 5.00442900664266, 4.065473682290637, 3.0144194671334557, 2.0284225597237704, 1.9698781400534102, 1.020596794447898, 2.014297477607335, 2.94233506878536, 3.88959938627933, 4.894143918774146, 5.830425016004786, 6.8576832053895025, 7.822253841409008, 8.762203171733086, 9.69532505690419, 10.738243186233202, 9.799596350700472, 8.86019774564274, 7.830886576735764, 6.962437028728539, 6.06257868120031, 5.069651917595658, 4.002834300778445, 2.9958611632088523, 2.9079578428136355, 2.007359360712298, 2.9780629940727232, 3.937930170858385, 4.853331837966641, 5.837782383068145, 6.810926314292252, 7.753061107896669, 8.796538995903884, 9.70796364904614, 10.663916053716822, 11.589089512453864, 10.740526782787589, 9.793918242457057, 8.825618480861086, 7.924554733192947, 7.065274026260411, 6.008110462299005, 4.983417295456272, 3.968649547445835, 3.9541798196045415, 3.016558578278021, 3.9600288393693424, 4.9656750255796585, 5.787074485259053, 6.760702354895177, 7.829162386610895, 8.804870160338519, 9.725502793180983, 10.668672010797513, 11.639305854776106, 12.618132026196074, 11.76454736731775, 10.84856327259303, 9.782851710151224, 8.835497098859124, 7.851183698136602, 6.839561622009549, 5.8746167741555615, 4.89656462059232, 4.890933249864973, 3.96298013791933, 4.940372710213609, 5.943309000018211, 6.82664414850714, 7.716736030443121, 8.649399164974193, 9.594844952746099, 10.625945722084625, 11.55106705233663, 12.530936430205154, 13.535685740450575, 12.742137176361172, 11.736527420987908, 10.701583561608135, 9.752391296223486, 8.711036838202062, 7.784223009688719, 6.809969697263693, 5.826851868385822, 5.884590230433322, 4.932543720841683, 5.985928715318417, 6.976615893496387, 7.844065776348052, 8.775749950018486, 9.596661131796612, 10.623811574584472, 11.592828290627757, 12.553414940139088, 13.521441578367373, 14.446967908507002, 13.78837844807169, 12.799600134691078, 11.729169120932823, 10.685766174620095, 9.73316690003679, 8.789825744918822, 7.796302107385371, 6.829731187379352, 6.883932693548279, 5.872811290415533, 6.893393633705707, 7.86151313346456, 8.796885338438406, 9.721791822161304, 10.56158466911559, 11.49925906521392, 12.551433494445332, 13.484539398763136, 14.511993524930007, 15.427542367884342, 14.70383047662977, 13.689045555923538, 12.665112001826389, 11.69340464682761, 10.787422849494241, 9.815526502536887, 8.774981883794153, 7.861409143044993, 7.825088030943824, 6.8835626500982645, 7.896347957175778, 8.857809963695525, 9.767711352513553, 10.763757610437318, 11.601120058018864, 12.479659587368362, 13.434949478466974, 14.403627301260398, 15.362272300331556, 16.413878892537223, 15.62398845049488, 14.556077546323781, 13.629278098671525, 12.619312599939999, 11.767714403325877, 10.753173676879221, 9.809267897590097, 8.772107243816526, 8.884332663287008, 7.917785171340938, 8.890999123608125, 9.78868027890835, 10.79363972704685, 11.695783980156905, 12.575183978085771, 13.43982213197678, 14.494994293874942, 15.408783106008475, 16.365688156882243, 17.39745230123114, 16.56128630302541, 15.578862106732338, 14.580716992611551, 13.64664880527894, 12.759497336900397, 11.800540704666878, 10.766473533427662, 9.780024535266483, 9.8846673333401, 8.962948176702758, 9.84889549148526, 10.761346181815476, 11.693208173728502, 12.712008736337033, 13.579894714266857, 14.403168747953456, 15.375612598837176, 16.37601484345742, 17.31925279216892, 17.53954506694389, 16.579020593601957, 15.697200459342286, 14.710629471226817, 13.748311140089402, 12.809589231818236, 11.986547320928212, 11.044253729763144, 10.828836219994521, 10.85077398160938, 9.89416751105354, 10.834043061718152, 11.78106358634362, 12.674567357577663, 13.669802510672646, 14.614090709003015, 15.465601728584232, 16.43765879795451, 17.36808023017644, 17.50158908063661, 16.538856340267667, 15.647538830472403, 14.689050219600661, 13.717925846083597, 12.795445437426283, 11.854407324283013, 10.961412781601302, 10.117008422002277, 10.799389862836158, 10.838957156691507, 10.87314976296986, 11.854507052454045, 12.785084510413741, 13.738159939618543, 14.596934707849712, 15.587658203511701, 16.46166631437447, 17.49059422293513, 17.644711163289998, 16.573114904646054, 15.57971868146991, 14.634708558417328, 13.744131088910901, 12.738301640876081, 11.839975320920347, 10.832385458846828, 9.891533129403433, 9.097736738460203, 9.844156939108306, 9.967091866832256, 10.643975388309242, 11.604627352975157, 12.596677580561561, 13.534569314364116, 14.309660562360973, 15.284848546643344, 16.304747682783404, 17.246503088268906, 16.713337551709625, 15.705772714871225, 14.68102676226068, 13.706733739470877, 12.777314902999132, 11.796006447022947, 10.871432964066736, 9.93649602017257, 8.879546245792373, 8.031312140942862, 8.917318498386463], [8.916350565991648, 7.991181172970846, 7.011844159533633, 8.002719301006215, 8.921906285084987, 9.860313400732892, 10.83575514370092, 11.85063924842855, 12.79029638562765, 13.814722663373255, 14.787139480892048, 15.697637512824631, 16.326405268002503, 15.318012835066693, 14.329970976861407, 13.485965758297349, 12.528580279323757, 11.668575956365144, 10.667649828756288, 9.926528197951688, 7.897444788345071, 6.967251318410691, 6.02133128122963, 6.969868502433321, 7.891876855905828, 8.881111482415637, 9.885628440080731, 10.877624253874378, 11.877261232699052, 12.89067593969953, 13.84407162812941, 14.635357724011568, 15.37197641715659, 14.35554924473932, 13.402842981290753, 12.498409895454293, 11.603132601834453, 10.674810757170276, 9.619559832923759, 8.937203999150187, 6.853722135311345, 5.9333998651728015, 5.0419568198989655, 6.008122540062619, 6.964223589262404, 7.9111574284736035, 8.882898340745212, 9.904786850172156, 10.860824040992947, 11.868078761523941, 12.860938459664844, 13.635572414071708, 14.42482400939738, 13.428849174959685, 12.454550401697924, 11.5159173661718, 10.566058632967055, 9.709364651329016, 8.694161681840592, 7.89917148889492, 5.835374090314059, 4.922309926051598, 4.058112898588886, 4.9867219180935365, 5.90238632285952, 6.927828281782228, 7.876309059234799, 8.867417593637022, 9.844905587201653, 10.821630978036119, 11.80187964691147, 12.64720754825106, 13.602572424345233, 12.640023983989483, 11.609573677873406, 10.565543348904528, 9.637024722464396, 8.701906646657687, 7.708327493496148, 6.858003804260212, 4.909798438890445, 3.9832960040739485, 3.0021312590439524, 4.031187088184076, 4.92012440109918, 5.985932571014383, 6.986992542306757, 7.873153433776436, 8.85277947707728, 9.79702395019125, 10.746663919579417, 11.70783784783851, 12.74119127740206, 11.719786499019046, 10.699451141248245, 9.671447117845053, 8.709737695637317, 7.7808743458601155, 6.762464711633228, 5.912710904808665, 3.9016963454944227, 2.9423288898295277, 2.056131158064039, 2.9815180757078785, 3.9775615644788025, 5.005141351654089, 5.942316805445152, 6.910846566641973, 7.920826119442095, 8.84835993107181, 9.794506822727284, 10.746908223984928, 11.714418308678898, 10.785459360343774, 9.807648990418643, 8.828411467720839, 7.901078466835847, 6.86777925491541, 5.8147826841756665, 4.852039404755098, 2.957665602699374, 1.9434935537435547, 0.9823110771514367, 1.9893055550590122, 3.0067898268279114, 4.05757983450138, 4.987024951117729, 6.034120849235405, 7.044086514958732, 8.017375506096764, 9.028369002806294, 9.957476625877343, 10.939644467048907, 9.946767692291791, 8.916993738586532, 7.962814591329816, 6.9388248222007896, 5.8977542090903174, 4.889361915533926, 3.9568069939668526, 1.9967110932945615, 0.9962520938780255, 0.0, 1.0098775029659086, 1.9814339779485155, 3.0314290075643835, 4.010733504226851, 5.078111398542321, 6.145461360247347, 7.110462244472659, 8.067063297832174, 9.108332156784087, 10.006379464164452, 8.951510587293305, 7.9012648655294635, 6.930267700621323, 6.000681100520685, 5.061725776168663, 4.010671561011481, 3.024674653601796, 2.9661302339314357, 2.0168488883259235, 1.037149680243815, 1.96518727142184, 2.9121946064475477, 3.916739138942364, 4.853020236173004, 5.880278425557719, 6.844849061577225, 7.784798391901303, 8.717920277072407, 9.77825941825782, 10.716906253790551, 9.856449839520764, 8.827138670613788, 7.958689122606565, 7.058830775078335, 6.065904011473683, 4.99908639465647, 3.992113257086878, 3.904209936691661, 3.0036114545903234, 2.0701246462291096, 2.960782373494865, 3.875927058134859, 4.860377603236363, 5.83352153446047, 6.775656328064887, 7.819134216072101, 8.730558869214358, 9.686511273885039, 10.61168473262208, 11.550644967700949, 10.79017033633508, 9.82187057473911, 8.920806827070972, 8.061526120138437, 7.00436255617703, 5.979669389334298, 4.964901641323861, 4.950431913482567, 3.9962101576086546, 3.052090491525729, 3.988527228216139, 4.809669705427272, 5.783297575063395, 6.851757606779113, 7.827465380506737, 8.7480980133492, 9.69126723096573, 10.661901074944323, 11.64072724636429, 12.57466555223111, 11.844815366471053, 10.779103804029248, 9.83174919273715, 8.847435792014627, 7.835813715887575, 6.870868868033587, 5.892816714470346, 5.870584829195606, 4.942631717249964, 4.032434362369996, 4.966161202654692, 5.8492393686753585, 6.73933125061134, 7.671994385142413, 8.617440172914318, 9.648540942252843, 10.57366227250485, 11.553531650373372, 12.558280960618793, 13.62927553647612, 12.732779514865934, 11.697835655486161, 10.748643390101511, 9.707288932080088, 8.780475103566745, 7.806221791141718, 6.823103962263848, 6.864241809763956, 5.912195300172317, 5.091160045940597, 5.999468096132867, 6.866660996516271, 7.798345170186704, 8.619256351964832, 9.646406794752693, 10.615423510795978, 11.576010160307307, 12.544036798535593, 13.469563128675222, 14.456640460199731, 13.795852228569103, 12.725421214810849, 11.68201826849812, 10.729418993914816, 9.786077838796848, 8.792554201263396, 7.825983281257377, 7.863584272878913, 6.852462869746167, 6.131835515031644, 6.988677909790949, 7.819480558606624, 8.744387042329521, 9.58417988928381, 10.52185428538214, 11.574028714613553, 12.507134618931353, 13.534588745098224, 14.450137588052563, 15.392826186155354, 14.685297649801564, 13.661364095704414, 12.689656740705635, 11.783674943372267, 10.811778596414912, 9.771233977672178, 8.841060722375627, 8.804739610274458, 7.863214229428898, 7.134789838501715, 7.984974740021913, 8.79030657268177, 9.786352830605535, 10.623715278187085, 11.502254807536582, 12.457544698635195, 13.426222521428619, 14.384867520499776, 15.436474112705444, 16.416919589429916, 15.552329640201807, 14.625530192549551, 13.615564693818024, 12.747365982656511, 11.732825256209855, 10.78891947692073, 9.75175882314716, 9.863984242617642, 8.897436750671572, 8.129441004934062, 8.915845055234739, 9.816234947215067, 10.718379200325122, 11.597779198253992, 12.462417352145, 13.517589514043163, 14.431378326176695, 15.388283377050463, 16.42004752139936, 16.620550809835485, 15.724254458063747, 14.796856517893744, 13.804283370552339, 12.934663403855506, 12.131498337881306, 11.746125112758296, 10.759676114597116, 10.864318912670734, 9.942599756033392, 9.087337372811197, 9.888510958141865, 10.819982389150436, 11.793182837888883, 12.602489934435077, 13.425763968121677, 14.398207819005396, 15.39861006362564, 16.34184801233714, 16.6225343463036, 15.662009872961663, 14.780236327357377, 13.793665339241908, 12.831347008104494, 11.935364483440875, 11.11232257255085, 11.908392288663372, 11.808487799325155, 11.830425560940014, 10.873819090384174, 10.072484943044088, 10.962453375595638, 11.801341572999597, 12.766397177498165, 13.676346485970857, 14.488196948752453, 15.460254018122729, 16.39067545034466, 16.584578359996318, 15.621845619627376, 14.730528109832111, 13.772086087615753, 12.800961714098689, 11.878481305441374, 10.980182575905651, 10.08718803322394, 10.981146980902505, 11.760600742659312, 11.80016803651466, 11.852801342300493, 11.092948933779981, 11.966474299665759, 12.864934155040476, 13.693529374675231, 14.649913980479543, 15.48426153454269, 16.51318944310335, 16.727700442649706, 15.656104184005763, 14.662707960829618, 13.717697837777036, 12.827166956925993, 11.821337508891173, 10.923011188935439, 9.958160710469466, 9.017308381026071, 9.96187529736043, 10.80536781893146, 10.92830274665541, 11.605186268132396, 12.103086398310406, 12.967444705096772, 13.826431479361098, 14.635845275937406, 15.584833800625658, 16.454861167321624, 16.737474719984863, 15.796326831069333, 14.788761994230933, 13.764016041620389, 12.789723018830585, 11.86030418235884, 10.879042315038038, 9.954468832081828, 9.062271271795208, 8.00532149741501, 8.961148529336146, 9.878529378209617], [9.877906794420555, 8.918931539147625, 7.939594525710413, 7.274202626715386, 7.912028782119077, 8.850435897766983, 9.82587764073501, 10.84076174546264, 11.78041888266174, 12.804845160407345, 13.777261977926141, 14.68776000985872, 15.613045966095221, 15.503002889059553, 14.566868238294218, 13.82636841228511, 13.085206718859673, 12.678453459331052, 11.677527331722196, 10.888084426380596, 8.893168335205845, 7.942141995587116, 6.949081647406409, 6.232401225735839, 6.881999352939919, 7.871233979449729, 8.875750937114821, 9.867746750908468, 10.867383729733145, 11.880798436733624, 12.834194125163503, 13.62548022104566, 14.575971841984819, 15.365426747705229, 14.412720484256662, 13.508287398420201, 12.613010104800361, 11.684688260136184, 10.629437335889667, 9.93292754601096, 7.849445682172118, 6.908290542349227, 5.969707186075745, 5.242614147391347, 5.9543460862964945, 6.901279925507693, 7.873020837779301, 8.894909347206246, 9.85094653802704, 10.858201258558035, 11.851060956698936, 12.6256949111058, 13.560756216309287, 14.438726677925594, 13.464427904663832, 12.525794869137709, 11.575936135932963, 10.719242154294925, 9.7040391848065, 8.894895035755694, 6.8327239525375125, 5.897200603228024, 4.9858632647656655, 4.178059780285622, 4.892508819893611, 5.9179507788163175, 6.866431556268889, 7.857540090671111, 8.835028084235747, 9.811753475070212, 10.792002143945561, 11.637330045285152, 12.601233326381278, 13.563781766737028, 12.619451180839315, 11.575420851870437, 10.646902225430305, 9.711784149623595, 8.718204996462056, 7.855353666483666, 5.9071483011138985, 4.958186681250374, 3.9298816252207316, 3.113541344588048, 3.910246898133271, 4.976055068048474, 5.977115039340849, 6.863275930810529, 7.842901974111373, 8.787146447225341, 9.736786416613509, 10.697960344872602, 11.73257848088895, 12.674648156140483, 11.709328644214153, 10.681324620810962, 9.719615198603226, 8.790751848826023, 7.772342214599137, 6.922588407774573, 4.911573848460331, 3.933119420675843, 2.983881524240818, 2.0584946065969785, 2.967684061512894, 3.995263848688181, 4.932439302479245, 5.900969063676065, 6.910948616476188, 7.838482428105903, 8.784629319761375, 9.73703072101902, 10.727549692557181, 11.656508640892305, 10.817526493384552, 9.838288970686747, 8.910955969801757, 7.877656757881319, 6.824660187141575, 5.861916907721007, 3.967543105665283, 2.9533710567094635, 1.9921885801173453, 1.0310769455814828, 1.996912323862003, 3.0477023315354703, 3.977147448151821, 5.024243346269497, 6.034209011992823, 7.007498003130856, 8.018491499840383, 8.947599122911432, 9.929766964082997, 10.9566451952577, 9.92687124155244, 8.972692094295724, 7.948702325166698, 6.907631712056227, 5.899239418499835, 4.9666844969327615, 3.00658859626047, 2.006129596843934, 1.0098775029659086, 0.0, 0.9715564749826069, 2.0215515045984747, 3.0008560012609418, 4.0682338955764115, 5.135583857281437, 6.10058474150675, 7.057185794866264, 8.098454653818177, 9.05235925997076, 9.961388090259213, 8.911142368495373, 7.940145203587232, 7.010558603486594, 6.071603279134571, 5.0205490639773895, 4.034552156567704, 3.976007736897344, 2.975379378461245, 1.9816786953018077, 1.0536411041237828, 1.9023171034816388, 2.9068616359764547, 3.8431427332070944, 4.870400922591811, 5.834971558611317, 6.7749208889353945, 7.7080427741065, 8.768381915291913, 9.707028750824644, 10.646427355882377, 9.837016173579698, 8.968566625572473, 8.068708278044245, 7.0757815144395915, 6.008963897622379, 5.001990760052786, 4.914087439657569, 3.9621419447256447, 3.0146536612871024, 2.0492362061968077, 2.86604955516895, 3.8505001002704535, 4.823644031494561, 5.765778825098978, 6.809256713106191, 7.720681366248448, 8.676633770919132, 9.601807229656174, 10.540767464735042, 11.487376005065574, 10.83174807770502, 9.93068433003688, 9.071403623104347, 8.014240059142939, 6.989546892300206, 5.974779144289769, 5.960309416448475, 4.940739172666647, 3.9966195065837216, 3.076981060918081, 3.7997922024613624, 4.773420072097486, 5.841880103813203, 6.817587877540827, 7.73822051038329, 8.68138972799982, 9.652023571978416, 10.630849743398384, 11.564788049265204, 12.559033329132617, 11.788981306995158, 10.841626695703058, 9.857313294980536, 8.845691218853483, 7.880746370999495, 6.902694217436254, 6.815113844253599, 5.887160732307956, 4.976963377427988, 4.054615035356634, 4.839361865709449, 5.72945374764543, 6.6621168821765036, 7.607562669948409, 8.638663439286935, 9.563784769538941, 10.543654147407464, 11.548403457652885, 12.619398033510212, 13.613338794745523, 12.689750452174458, 11.740558186789809, 10.699203728768385, 9.772389900255043, 8.798136587830015, 7.770719222646514, 7.8087708248219485, 6.856724315230309, 6.035689060998589, 5.08792192883481, 5.8567834935503615, 6.788467667220795, 7.609378848998923, 8.636529291786783, 9.605546007830068, 10.566132657341399, 11.534159295569683, 12.459685625709312, 13.44676295723382, 14.489505080499118, 13.717336011499146, 12.673933065186418, 11.721333790603113, 10.777992635485145, 9.743167896887611, 8.773598541640045, 8.808113287936905, 7.796991884804159, 7.045251242251744, 6.077131742492892, 6.809603055640714, 7.734509539363612, 8.5743023863179, 9.51197678241623, 10.564151211647642, 11.497257115965446, 12.524711242132318, 13.440260085086653, 14.382948683189444, 15.397733603895675, 14.653278892392711, 13.681571537393932, 12.751079669123706, 11.762392292039127, 10.721847673296393, 9.785589737433618, 9.749268625332451, 8.807743244486891, 8.048205565721815, 7.073428572723856, 7.7804290697158605, 8.776475327639627, 9.613837775221175, 10.492377304570672, 11.447667195669284, 12.416345018462708, 13.374990017533866, 14.426596609739534, 15.407042086464005, 15.665217356520117, 14.738417908867861, 13.821742072925371, 13.38609891172854, 12.677354271267848, 11.733448491978724, 10.696287838205153, 10.808513257675635, 9.841965765729565, 9.042856732154164, 8.004298887936681, 8.806357444249159, 9.708501697359214, 10.587901695288082, 11.45253984917909, 12.507712011077253, 13.421500823210785, 14.378405874084553, 15.410170018433451, 15.610673306869575, 14.714376955097839, 13.786979014927836, 12.79440586758643, 12.384876287223735, 13.059248704058085, 12.69065412781629, 11.70420512965511, 11.808847927728728, 10.887128771091385, 10.000753100031298, 8.976964790843807, 9.810104886184527, 10.783305334922975, 11.592612431469167, 12.415886465155767, 13.388330316039486, 14.38873256065973, 15.331970509371232, 15.612656843337687, 14.652132369995753, 13.770358824391469, 12.783787836276, 11.821469505138586, 11.385577366809104, 12.04007293872763, 12.83614265484015, 12.753016814383148, 12.774954575998008, 11.818348105442167, 10.98590067026419, 10.05090720829758, 10.791464070033689, 11.756519674532257, 12.666468983004947, 13.478319445786543, 14.450376515156819, 15.380797947378749, 15.574700857030408, 14.611968116661465, 13.7206506068662, 12.762208584649844, 11.79108421113278, 10.868603802475466, 10.43039545927388, 11.01493839940072, 11.908897347079284, 12.72215697108822, 12.761724264943568, 12.797330357358486, 12.006364661000083, 11.054928132367701, 11.855056652074568, 12.683651871709323, 13.640036477513632, 14.474384031576779, 15.50331194013744, 15.717822939683796, 14.646226681039852, 13.652830457863708, 12.707820334811126, 11.817289453960084, 10.811460005925264, 9.91313368596953, 9.408373593837695, 9.94505874720285, 10.88962566353721, 11.766924047360368, 11.889858975084318, 12.615063771098304, 13.016502125530508, 12.055898537798715, 12.816553976395188, 13.625967772971498, 14.574956297659748, 15.444983664355714, 15.727597217018953, 14.786449328103426, 13.778884491265023, 12.754138538654479, 11.779845515864675, 10.85042667939293, 9.86916481207213, 8.94459132911592, 8.33375459750438, 8.93307186359179, 9.888898895512925, 10.840085606638524], [10.78086440561992, 9.821889150346989, 8.842552136909777, 7.968706946767519, 6.940472307136471, 7.878879422784377, 8.854321165752404, 9.869205270480034, 10.808862407679134, 11.833288685424739, 12.805705502943532, 13.716203534876115, 14.641489491112615, 14.531446414076948, 13.595311763311612, 12.854811937302504, 13.746012236854103, 13.65000993431366, 12.649083806704803, 11.79104203757996, 9.814302181960318, 8.863275842341588, 7.852039258605773, 6.9702932717351445, 5.910442877957312, 6.899677504467122, 7.904194462132215, 8.89619027592586, 9.895827254750538, 10.909241961751015, 11.862637650180893, 12.653923746063054, 13.604415367002213, 14.620842539419483, 14.522439758882266, 13.86069274185114, 13.584566579782969, 12.656244735118792, 11.600993810872275, 10.854061392765434, 8.770579528926591, 7.829424389103699, 6.8726647972751085, 5.981630044121218, 4.982789611313888, 5.929723450525087, 6.901464362796695, 7.923352872223639, 8.879390063044433, 9.886644783575427, 10.879504481716328, 11.654138436123194, 12.58919974132668, 13.579961590971179, 14.43598437964644, 13.497351344120316, 12.54749261091557, 11.690798629277532, 10.675595659789108, 9.816028882510167, 7.804280427520119, 6.86875707821063, 5.888820875965029, 4.960211856460379, 3.920952344911004, 4.946394303833711, 5.8948750812862825, 6.885983615688504, 7.863471609253139, 8.840197000087603, 9.820445668962954, 10.665773570302546, 11.629676851398672, 12.592225291754422, 13.567453397081893, 12.546977326853044, 11.618458700412912, 10.683340624606203, 9.689761471444664, 8.826910141466273, 6.878704776096505, 5.9297431562329805, 4.901438100203339, 3.9481928694067605, 2.938690423150664, 4.004498593065867, 5.0055585643582425, 5.891719455827922, 6.871345499128767, 7.815589972242734, 8.765229941630901, 9.726403869889996, 10.761022005906344, 11.703091681157877, 12.588624150852311, 11.652881095793571, 10.691171673585835, 9.762308323808632, 8.743898689581744, 7.894144882757181, 5.883130323442938, 4.90467589565845, 3.9554379992234248, 3.030051081579585, 1.9961275865302872, 3.023707373705574, 3.9608828274966377, 4.9294125886934586, 5.939392141493581, 6.866925953123296, 7.81307284477877, 8.765474246036414, 9.755993217574575, 10.6849521659097, 11.66276253583483, 10.809845445669355, 9.882512444784364, 8.849213232863926, 7.796216662124182, 6.833473382703614, 4.9390995806478895, 3.9249275316920706, 2.9637450550999525, 2.0026334205640897, 1.0253558488793961, 2.0761458565528637, 3.0055909731692143, 4.052686871286889, 5.062652537010216, 6.035941528148248, 7.046935024857777, 7.976042647928827, 8.958210489100392, 9.99181864927648, 10.89842771653505, 9.944248569278333, 8.920258800149306, 7.879188187038833, 6.870795893482442, 5.938240971915368, 3.978145071243077, 2.977686071826541, 1.9814339779485155, 0.9715564749826069, 0.0, 1.049995029615868, 2.029299526278335, 3.096677420593805, 4.164027382298831, 5.129028266524143, 6.085629319883658, 7.126898178835571, 8.080802784988155, 9.135671661859302, 9.88269884347798, 8.91170167856984, 7.982115078469201, 7.043159754117179, 5.992105538959997, 5.006108631550312, 4.862948017640202, 3.7997632203304637, 2.8060625371710266, 1.8780249459930018, 0.9307606284990321, 1.935305160993848, 2.8715862582244878, 3.898844447609204, 4.863415083628709, 5.803364413952787, 6.736486299123892, 7.796825440309306, 8.735472275842035, 9.674870880899768, 10.704182049806743, 9.94012310055508, 9.04026475302685, 8.012536272565466, 6.945718655748252, 5.912311554601711, 5.791664861857054, 4.786525786594863, 3.8335070392794135, 2.8523819627802194, 1.8944930801863433, 2.878943625287847, 3.852087556511954, 4.794222350116371, 5.837700238123585, 6.749124891265841, 7.705077295936524, 8.630250754673567, 9.569210989752435, 10.515819530082966, 11.502806122315894, 10.902240805019488, 9.966076109691944, 8.891817481342423, 7.867124314499691, 6.852356566489254, 6.794265084482565, 5.759592550658958, 4.815472884576033, 3.828903766393629, 2.8282357274787557, 3.8018635971148793, 4.870323628830597, 5.846031402558221, 6.766664035400684, 7.709833253017212, 8.680467096995809, 9.659293268415777, 10.593231574282598, 11.58747685415001, 12.460039351606031, 11.675582363737147, 10.691268963014625, 9.679646886887573, 8.714702039033586, 7.736649885470344, 7.63396722224591, 6.706014110300267, 5.795816755420299, 4.806537740832182, 3.8678053907268426, 4.757897272662824, 5.690560407193897, 6.636006194965802, 7.6671069643043275, 8.592228294556334, 9.572097672424857, 10.576846982670277, 11.647841558527604, 12.641782319762916, 13.42070078341277, 12.55941156478212, 11.518057106760697, 10.591243278247354, 9.616989965822327, 8.589572600638826, 8.627624202814259, 7.67557769322262, 6.8545424389909, 5.839844634310358, 4.885227018567755, 5.816911192238188, 6.6378223740163165, 7.664972816804177, 8.633989532847462, 9.594576182358791, 10.562602820587077, 11.488129150726706, 12.475206482251215, 13.517948605516512, 14.451846270438018, 13.49278644317873, 12.540187168595425, 11.596846013477457, 10.562021274879923, 9.592451919632357, 9.626966665929215, 8.61584526279647, 7.797173947727293, 6.82905444796844, 5.838046580658108, 6.762953064381005, 7.602745911335293, 8.540420307433623, 9.592594736665035, 10.525700640982837, 11.553154767149708, 12.468703610104047, 13.411392208206838, 14.42617712891307, 14.73102753073039, 13.776093551055155, 13.569933047116018, 12.58124567003144, 11.540701051288705, 10.604443115425928, 10.568122003324762, 9.626596622479202, 8.730428919957216, 7.734234090718286, 6.808872594733254, 7.80491885265702, 8.642281300238567, 9.520820829588065, 10.476110720686677, 11.4447885434801, 12.403433542551259, 13.455040134756926, 14.435485611481399, 14.69366088153751, 13.766861433885254, 12.850185597942765, 13.803696330145796, 13.496207649260159, 12.552301869971034, 11.515141216197463, 11.627366635667945, 10.660819143721875, 9.725080086389564, 8.66510440593111, 7.834800969266551, 8.736945222376608, 9.616345220305476, 10.480983374196482, 11.536155536094645, 12.449944348228177, 13.406849399101946, 14.438613543450842, 14.63911683188697, 13.742820480115233, 12.815422539945228, 11.822849392603823, 12.80247370564099, 13.76143033787451, 13.5095075058086, 12.52305850764742, 12.627701305721038, 11.705982149083695, 10.682976454266699, 9.637770308838236, 8.83854841120192, 9.81174885994037, 10.621055956486561, 11.44432999017316, 12.416773841056878, 13.417176085677122, 14.360414034388624, 14.641100368355081, 13.680575895013147, 12.798802349408863, 11.812231361293392, 10.849913030155978, 11.803391596068531, 12.833285471753623, 13.739100266039515, 13.571870192375458, 13.593807953990318, 12.637201483434477, 11.658733250917479, 10.71171272629201, 9.819907595051081, 10.78496319954965, 11.694912508022341, 12.506762970803935, 13.478820040174213, 14.409241472396143, 14.603144382047802, 13.64041164167886, 12.749094131883595, 11.790652109667239, 10.819527736150174, 9.897047327492858, 10.848209688533307, 11.9039127995963, 12.811854958278648, 13.625114582287583, 13.664681876142932, 13.616183735350797, 12.679197241653371, 11.71573365036213, 10.88350017709196, 11.712095396726717, 12.668480002531027, 13.502827556594172, 14.531755465154834, 14.74626646470119, 13.674670206057247, 12.681273982881102, 11.73626385982852, 10.845732978977479, 9.839903530942658, 8.941577210986923, 9.960804194960952, 10.848016358402214, 11.792583274736574, 12.669881658559731, 12.792816586283681, 13.586620246080912, 13.689334706183796, 12.716704055793144, 11.844997501412582, 12.654411297988892, 13.603399822677142, 14.473427189373107, 14.756040742036348, 13.814892853120817, 12.807328016282417, 11.782582063671873, 10.80828904088207, 9.878870204410324, 8.897608337089524, 7.973034854133312, 8.962300193219551, 9.836029474791154, 10.79185650671229, 11.743043217837888], [11.80878087528103, 10.8498056200081, 9.870468606570888, 8.996623416428633, 7.9683887767975845, 7.105358282432654, 7.991731615194657, 9.006615719922287, 9.924129956454168, 10.918806454249385, 11.778462398254074, 12.688960430186658, 13.614246386423156, 13.77931637164002, 12.853967552027493, 13.84244517214839, 14.79600726646997, 14.700004963929526, 13.69907883632067, 12.81895850724107, 10.84221865162143, 9.891192312002703, 8.879955728266886, 7.998209741396259, 6.938359347618426, 6.126156364115399, 7.041604911574468, 8.033600725368114, 8.868584150061078, 9.881998857061557, 10.835394545491436, 11.626680641373595, 12.577172262312754, 13.593599434730024, 13.781095547598147, 14.848325976697026, 14.634561609398835, 13.706239764734658, 12.650988840488141, 11.881977862426547, 9.798495998587704, 8.857340858764813, 7.900581266936222, 7.0095465137823325, 6.010706080975002, 5.086556635215851, 6.038874812238948, 6.995412083830676, 7.8521469583549734, 8.859401678885968, 9.852261377026869, 10.626895331433735, 11.561956636637222, 12.55271848628172, 13.52701725954348, 14.465650295069604, 13.597487640531437, 12.740793658893399, 11.725590689404974, 10.84394535217128, 8.837102863165791, 7.901579513856303, 6.916737345626143, 5.988128326121493, 4.948868814572118, 4.1032274885244755, 5.032285530728536, 5.928343923841121, 6.83622850456368, 7.812953895398144, 8.793202564273495, 9.638530465613087, 10.602433746709213, 11.564982187064963, 12.540210292392434, 13.584240621361312, 12.668453730028778, 11.733335654222069, 10.73975650106053, 9.859732577111945, 7.911527211742178, 6.962565591878653, 5.9342605358490115, 4.976109339067875, 3.9666068928117784, 3.0472687953604733, 3.9783154596687824, 4.864476351138462, 5.844102394439307, 6.788346867553275, 7.737986836941443, 8.699160765200537, 9.733778901216887, 10.675848576468418, 11.561381046162852, 12.583643422611585, 11.7411667032017, 10.812303353424497, 9.79389371919761, 8.944139912373046, 6.933125353058805, 5.9374983313041225, 4.9882604348690975, 4.062873517225258, 3.0240440561914013, 1.9964642690161143, 2.933639722807178, 3.902169484003999, 4.912149036804122, 5.839682848433837, 6.78582974008931, 7.7382311413469544, 8.728750112885116, 9.65770906122024, 10.63551943114537, 11.614756953843175, 10.932507474400232, 9.899208262479792, 8.846211691740049, 7.8834684123194805, 5.989094610263757, 4.974922561307937, 4.01374008471582, 3.0526284501799577, 2.0753508784952643, 1.0261508269369959, 1.9555959435533459, 3.0026918416710213, 4.012657507394348, 4.98594649853238, 5.996939995241909, 6.926047618312959, 7.9082154594845235, 8.941823619660612, 9.971597573365871, 10.925776720622586, 9.970253829765173, 8.929183216654701, 7.920790923098309, 6.988236001531235, 5.028140100858945, 4.0276811014424085, 3.031429007564383, 2.0215515045984747, 1.049995029615868, 0.0, 0.979304496662467, 2.046682390977937, 3.1140323526829627, 4.079033236908275, 5.03563429026779, 6.076903149219703, 7.030807755372286, 8.085676632243432, 9.135922354007272, 9.961696708185707, 9.03211010808507, 8.093154783733047, 7.042100568575865, 6.05610366116618, 5.91294304725607, 4.849758249946332, 3.856057566786895, 2.92801997560887, 1.9807556581149002, 1.0423311094750862, 1.9786122067057257, 3.005870396090442, 3.9704410321099473, 4.9103903624340255, 5.843512247605131, 6.903851388790544, 7.842498224323275, 8.781896829381008, 9.811207998287983, 10.798885224747107, 10.090259782642718, 9.062531302181334, 7.99571368536412, 6.962306584217579, 6.841659891472922, 5.836520816210731, 4.883502068895282, 3.902376992396088, 2.9444881098022115, 1.9859695737690852, 2.959113504993192, 3.901248298597609, 4.944726186604823, 5.856150839747079, 6.812103244417763, 7.737276703154806, 8.676236938233673, 9.622845478564205, 10.609832070797133, 11.605658508500996, 11.016071139307812, 9.941812510958291, 8.917119344115559, 7.902351596105122, 7.844260114098434, 6.809587580274827, 5.8654679141919015, 4.878898796009497, 3.8782307570946237, 3.0497335546779523, 4.007532704336192, 4.953057351039459, 5.873689983881922, 6.816859201498451, 7.787493045477048, 8.766319216897017, 9.700257522763835, 10.694502802631249, 11.56706530008727, 12.517873846782376, 11.741263992630493, 10.729641916503441, 9.764697068649454, 8.786644915086212, 8.683962251861779, 7.756009139916136, 6.845811785036168, 5.85653277044805, 4.917800420342711, 4.005767230225897, 4.93843036475697, 5.883876152528876, 6.824453989511925, 7.749575319763931, 8.729444697632454, 9.734194007877875, 10.769941558913496, 11.748808268244154, 12.527726731894008, 13.476918997278657, 12.568052136376565, 11.641238307863222, 10.666984995438195, 9.639567630254694, 9.677619232430128, 8.72557272283849, 7.904537468606769, 6.889839663926226, 5.935222048183623, 5.064781149801261, 5.885692331579389, 6.91284277436725, 7.849651130823589, 8.751923207566389, 9.719949845794673, 10.645476175934302, 11.63255350745881, 12.675295630724108, 13.558872218919257, 14.542781472794598, 13.590182198211293, 12.646841043093325, 11.612016304495791, 10.642446949248225, 10.676961695545085, 9.665840292412339, 8.847168977343161, 7.879049477584308, 6.888041610273976, 6.010823021944078, 6.850615868898366, 7.7882902649966965, 8.836622840790756, 9.683047666190436, 10.710501792357308, 11.626050635311643, 12.568739233414433, 13.583524154120665, 14.01595683063237, 14.804010020716266, 14.619928076731886, 13.631240699647307, 12.590696080904573, 11.654438145041798, 11.618117032940631, 10.676591652095071, 9.780423949573082, 8.784229120334153, 7.858867624349122, 7.0635746413729015, 7.89015125780164, 8.768690787151138, 9.72398067824975, 10.692658501043175, 11.651303500114333, 12.654019254398337, 13.592832636688994, 13.978590181439488, 13.051790733787232, 13.878102067603876, 14.831612799806908, 14.546202678876028, 13.602296899586904, 12.565136245813333, 12.677361665283815, 11.710814173337745, 10.77507511600543, 9.715099435546978, 8.884795998882419, 7.995601011092489, 8.864215177868548, 9.728853331759556, 10.784025493657719, 11.697814305791251, 12.65471935666502, 13.637592663092253, 13.776527281329221, 12.96929933976351, 12.100351839847207, 12.850765862264936, 13.830390175302103, 14.789346807535622, 14.55950253542447, 13.57305353726329, 13.677696335336908, 12.755977178699565, 11.732971483882565, 10.687765338454104, 9.888543440817788, 9.07040464865625, 9.868925914049633, 10.692199947736233, 11.664643798619952, 12.665046043240196, 13.608283991951698, 13.778510817797333, 12.817986344455399, 12.02528120905714, 11.08554906504012, 11.877829499817091, 12.831308065729644, 13.861201941414736, 14.767016735700626, 14.621865221991328, 14.643802983606188, 13.687196513050347, 12.708728280533347, 11.761707755907878, 10.869902624666949, 10.043618988265532, 10.942782465585413, 11.754632928367009, 12.726689997737285, 13.657111429959215, 13.740554831490051, 12.77782209112111, 11.886504581325847, 11.017130969315515, 10.04600659579845, 10.924963797153971, 11.87612615819442, 12.931829269257413, 13.839771427939759, 14.653031051948695, 14.692598345804043, 14.666178764966666, 13.72919227126924, 12.765728679977999, 11.933495206707828, 10.970751185442598, 11.916349960094099, 12.750697514157245, 13.779625422717906, 13.860568405914293, 12.812080655499498, 11.818684432323353, 10.873674309270772, 9.991697307977557, 9.066382390590935, 9.969493680648036, 10.988720664622065, 11.875932828063325, 12.820499744397685, 13.697798128220843, 13.820733055944793, 14.636615275696778, 14.739329735799664, 13.766699085409012, 12.89499253102845, 11.913067086704773, 12.851269780240214, 13.72129714693618, 13.72879763734689, 12.78764974843136, 11.944738465724669, 10.919992513114124, 9.945699490324321, 9.016280653852576, 8.1240871967378, 9.000951323794425, 9.990216662880664, 10.863945944452265, 11.8197729763734, 12.770959687499], [12.700543056430273, 11.741567801157343, 10.762230787720132, 9.888385597577873, 8.860150957946825, 7.997120463581894, 7.096594015493298, 8.111478120220928, 9.02899235675281, 10.023668854548024, 10.883324798552714, 11.793822830485297, 12.719108786721797, 12.900878829307656, 13.708588156202383, 14.69706577632328, 15.654451255296872, 15.657879813803241, 14.656953686194385, 13.710720688390314, 11.733980832770673, 10.782954493151944, 9.771717909416127, 8.889971922545499, 7.830121528767666, 7.0179185452646395, 6.146467311873109, 7.138463125666755, 7.97344655035972, 8.986861257360196, 9.940256945790075, 10.731543041672236, 11.682034662611395, 12.698461835028665, 13.580172239434951, 14.553005224650738, 15.566834535364167, 14.664114614608373, 13.608863690361856, 12.773740043575788, 10.690258179736945, 9.749103039914054, 8.792343448085463, 7.901308694931572, 6.902468262124242, 5.978318816365092, 5.143737212537589, 6.100274484129317, 6.957009358653615, 7.964264079184609, 8.95712377732551, 9.731757731732376, 10.666819036935863, 11.65758088658036, 12.631879659842122, 13.570512695368246, 14.520371428572991, 13.698668508767113, 12.68346553927869, 11.735707533320522, 9.72886504431503, 8.793341695005543, 7.808499526775384, 6.8798905072707335, 5.840630995721359, 4.994989669673716, 4.137147931027177, 5.033206324139762, 5.941090904862321, 6.9178162956967855, 7.898064964572136, 8.743392865911728, 9.707296147007854, 10.669844587363604, 11.645072692691075, 12.689103021659953, 13.617621648100085, 12.691210504095784, 11.697631350934245, 10.751494758261185, 8.803289392891417, 7.854327773027893, 6.826022716998251, 5.867871520217115, 4.858369073961018, 3.9390309765097133, 3.0831778599674236, 3.9693387514371032, 4.9489647947379485, 5.893209267851916, 6.842849237240084, 7.804023165499178, 8.838641301515526, 9.78071097676706, 10.666243446461493, 11.688505822910226, 12.650215245117963, 11.770178203298212, 10.751768569071325, 9.857032212483391, 7.891000202932519, 6.829260512453362, 5.880022616018337, 4.9546356983744975, 3.9158062373406413, 2.8882264501653543, 2.038502123105819, 3.00703188430264, 4.017011437102763, 4.944545248732478, 5.8906921403879515, 6.843093541645596, 7.833612513183756, 8.762571461518881, 9.740381831444012, 10.719619354141816, 11.646952355026807, 10.857083112353507, 9.804086541613763, 8.841343262193195, 6.968399106926224, 5.954227057970405, 4.993044581378287, 4.031932946842425, 2.9866510129494497, 1.9179130080862359, 0.976291446890879, 2.0233873450085547, 3.033353010731881, 4.006642001869913, 5.017635498579442, 5.946743121650492, 6.928910962822057, 7.962519122998145, 8.992293076703405, 9.946472223960122, 10.94955832642764, 9.908487713317168, 8.900095419760776, 7.967540498193703, 6.007444597521412, 5.006985598104876, 4.010733504226851, 3.000856001260942, 2.029299526278335, 0.979304496662467, 0.0, 1.0673778943154697, 2.1347278560204956, 3.0997287402458085, 4.0563297936053235, 5.097598652557236, 6.051503258709819, 7.1063721355809655, 8.156617857344806, 9.127615022252947, 10.011414604747536, 9.072459280395513, 8.021405065238332, 7.0354081578286465, 6.892247543918538, 5.829062746608799, 4.835362063449362, 3.907324472271337, 2.9600601547773673, 2.0028099892406246, 1.0665288920099854, 2.071425916323059, 3.035996552342564, 3.975945882666642, 4.909067767837747, 5.96940690902316, 6.9080537445558905, 7.847452349613624, 8.8767635185206, 9.864440744979722, 10.792158327675287, 10.0418357988438, 8.975018182026588, 7.9416110808800475, 7.8209643881353905, 6.8158253128732, 5.862806565557749, 4.881681489058555, 3.9237926064646786, 2.9464484535346234, 2.0497360561510947, 2.9918708497555118, 4.0353487377627255, 4.921706359979696, 5.877658764650379, 6.802832223387422, 7.741792458466289, 8.688400998796821, 9.675387591029748, 10.671214028733612, 11.610597464035523, 10.92111700762076, 9.896423840778027, 8.88165609276759, 8.8235646107609, 7.788892076937294, 6.844772410854368, 5.858203292671964, 4.85753525375709, 4.01021243444349, 3.098155255494095, 4.043679902197361, 4.9643125350398245, 5.882414721731068, 6.853048565709664, 7.831874737129632, 8.765813042996452, 9.760058322863864, 10.632620820319886, 11.583429367014991, 12.567742767737514, 11.708946413165908, 10.74400156531192, 9.765949411748679, 9.663266748524245, 8.735313636578603, 7.825116281698635, 6.8358372671105165, 5.897104917005177, 4.966246109991435, 4.059992822424604, 5.00543861019651, 5.915076540669827, 6.840197870921833, 7.804398124007192, 8.809147434252612, 9.835497079146114, 10.81436378847677, 11.593282252126624, 12.542474517511273, 13.50654152747591, 12.620542804525689, 11.646289492100662, 10.61887212691716, 10.656923729092595, 9.704877219500956, 8.883841965269236, 7.869144160588693, 6.9145265448460895, 5.990563738778049, 5.007254789247024, 6.034405232034884, 6.940273681981491, 7.842545758724292, 8.810572396952576, 9.736098727092205, 10.723176058616714, 11.76591818188201, 12.624427739151873, 13.613555346056, 14.528671589310639, 13.626145539755791, 12.591320801158256, 11.62175144591069, 11.656266192207552, 10.645144789074806, 9.826473474005628, 8.858353974246775, 7.867346106936442, 6.92083005016568, 5.9721783265660005, 6.909852722664331, 7.927245391948659, 8.77367021734834, 9.80112434351521, 10.716673186469546, 11.659361784572337, 12.674146705278568, 13.560370620045438, 14.584635564104751, 15.568343071043419, 14.610545196309772, 13.570000577567038, 12.633742641704265, 12.597421529603098, 11.655896148757538, 10.75972844623555, 9.763533616996622, 8.838172121011588, 7.973581669594504, 7.011713715469274, 7.890253244818773, 8.845543135917385, 9.81422095871081, 10.772443395131768, 11.74464180555624, 12.683455187846898, 13.174834797970517, 13.943552914936474, 14.76986424875312, 15.72337498095615, 15.525507175538495, 14.58160139624937, 13.5444407424758, 13.656666161946282, 12.690118670000212, 11.754379612667899, 10.694403932209447, 9.864100495544886, 8.90560803931409, 7.9857776355361825, 8.85041578942719, 9.905587951325353, 10.819376763458886, 11.775859251682455, 12.728215214250156, 12.881389681627862, 12.099954551032546, 12.992114020996448, 13.742528043414177, 14.722152356451344, 15.681108988684864, 15.538807032086936, 14.552358033925756, 14.657000831999374, 13.735281675362032, 12.712275980545034, 11.667069835116573, 10.867847937480255, 9.92502525283114, 8.99048837171727, 9.813762405403867, 10.786206256287587, 11.78660850090783, 12.729423886969133, 12.883373218095974, 11.92284874475404, 11.155936420326176, 11.97731124618936, 12.769591680966332, 13.723070246878885, 14.752964122563977, 15.658778916849869, 15.601169718653795, 15.623107480268654, 14.666501009712814, 13.688032777195815, 12.741012252570346, 11.849207121329416, 10.898239592440422, 10.06434492325305, 10.876195386034643, 11.848252455404921, 12.778673887626852, 12.845417231788694, 11.882684491419752, 10.991366981624488, 10.147786180584552, 10.937768776947692, 11.816725978303213, 12.767888339343662, 13.823591450406655, 14.731533609089002, 15.544793233097938, 15.584360526953287, 15.645483261629133, 14.708496767931708, 13.745033176640467, 12.799856517327285, 11.825371789617488, 11.037912417761735, 11.87225997182488, 12.901187880385542, 12.965430806212932, 11.91694305579814, 10.923546832621994, 9.978536709569413, 9.096559708276198, 9.958144571740176, 10.861255861797277, 11.880482845771306, 12.767695009212568, 13.712261925546928, 14.589560309370086, 14.712495237094036, 15.594490125570493, 15.718634232462133, 14.709649023751924, 13.761353841647907, 12.767687690879663, 11.97283223790785, 12.842859604603815, 12.83366003764553, 11.892512148729999, 11.04960086602331, 10.024854913412765, 9.050561890622962, 8.121143054151217, 9.015849377887042, 9.892713504943666, 10.881978844029906, 11.755708125601508, 12.711535157522643, 13.662721868648243], [13.738044567986751, 12.77906931271382, 11.79973229927661, 10.907543988151033, 9.879309348519985, 8.92761465557079, 7.936449168676161, 7.222206185897358, 8.023833845248198, 9.018510343043413, 9.878166287048105, 10.755668130469306, 11.680954086705805, 12.622770725340045, 13.469145534989613, 14.45762315511051, 15.415008634084101, 16.439381231312378, 15.694455197750862, 14.748222199946792, 12.77148234432715, 11.820456004708422, 10.809219420972607, 9.90913031311866, 8.849279919340827, 7.948412737253535, 6.986322465055972, 6.172558230035367, 6.968288038855109, 7.9817027458555865, 8.935098434285466, 9.693388341656243, 10.643879962595403, 11.660307135012673, 12.542017539418959, 13.514850524634745, 14.528679835348175, 15.457001680012352, 14.646365201918334, 13.811241555132266, 11.727759691293423, 10.786604551470532, 9.829844959641942, 8.920467085504733, 7.921626652697402, 6.908813008353987, 5.983592365720452, 5.113265346560626, 5.951850847149004, 6.959105567679998, 7.938776873042819, 8.693603031716384, 9.62866433691987, 10.619426186564368, 11.59372495982613, 12.532357995352253, 13.482216728556999, 14.534912322151195, 13.720967050835167, 12.773209044877, 10.76636655587151, 9.830843206562022, 8.846001038331863, 7.917392018827212, 6.878132507277837, 5.925483861662611, 4.97700308421004, 4.046197186571071, 4.93593239335771, 5.912657784192175, 6.879718060289444, 7.705238165895736, 8.669141446991862, 9.631689887347612, 10.606917992675081, 11.650948321643959, 12.579466948084091, 13.5145850238908, 12.735132862490723, 11.788996269817664, 9.840790904447896, 8.891829284584372, 7.86352422855473, 6.9053730317735935, 5.895870585517497, 4.9683305101743995, 3.9230330131502864, 2.982329613868412, 3.9438062832333376, 4.8880507563473055, 5.824502332957392, 6.7658684654831855, 7.800486601499535, 8.742556276751067, 9.6280887464455, 10.650351122894232, 11.612060545101969, 12.540923894879171, 11.789270080627803, 10.89453372403987, 8.928501714488997, 7.866762024009841, 6.917524127574816, 5.992137209930976, 4.95330774889712, 3.925727961721833, 2.9885525079307693, 2.0200227467339484, 3.011852925598152, 3.9063905487164856, 4.852537440371959, 5.804938841629603, 6.795457813167764, 7.724416761502888, 8.702227131428018, 9.681464654125822, 10.608797655010813, 11.665158861707653, 10.841588053170241, 9.878844773749673, 8.035777001241694, 7.021604952285874, 6.060422475693756, 5.0993108411578945, 4.038837448109411, 2.970099443246197, 2.02847788205084, 0.9813819839331646, 1.991347649656491, 2.9646366407945233, 3.9502576042639723, 4.879365227335022, 5.861533068506587, 6.895141228682675, 7.9249151823879345, 8.879094329644651, 9.903084098773679, 10.944154711884151, 9.967473314076246, 9.034918392509173, 7.074822491836882, 6.074363492420345, 5.07811139854232, 4.0682338955764115, 3.096677420593805, 2.046682390977937, 1.0673778943154697, 0.0, 1.067349961705026, 2.0323508459303388, 2.9889518992898534, 4.030220758241766, 4.984125364394349, 6.038994241265495, 7.089239963029336, 8.060237127937476, 8.989823728038115, 9.928779052390137, 9.088782959553802, 8.102786052144117, 7.904319230258931, 6.841134432949193, 5.847433749789756, 4.919396158611731, 3.9721318411177613, 2.967587308622945, 2.0313062113923053, 1.0040480220075894, 1.9686186580270946, 2.9085679883511726, 3.8416898735222773, 4.902029014707691, 5.840675850240421, 6.780074455298155, 7.809385624205131, 8.797062850664254, 9.724780433359818, 10.79835547169379, 9.987089868366981, 8.95368276722044, 8.821742909134036, 7.816603833871845, 6.84590020051142, 5.864775124012226, 4.90688624141835, 3.8960063539041263, 2.9228624226800197, 1.9807276290756026, 3.0242055170828164, 3.854328465664227, 4.810280870334909, 5.735454329071952, 6.674414564150819, 7.621023104481351, 8.608009696714278, 9.603836134418142, 10.543219569720053, 11.617478198069573, 10.897202361776673, 9.882434613766236, 9.806658245714573, 8.771985711890965, 7.827866045808039, 6.841296927625636, 5.8406288887107625, 4.959770334812994, 3.97128162202302, 3.0325366815174526, 3.9531693143599154, 4.815036827415598, 5.785670671394194, 6.764496842814162, 7.698435148680981, 8.692680428548394, 9.565242926004416, 10.516051472699521, 11.500364873422043, 12.511986949549096, 11.727095200265593, 10.74904304670235, 10.646360383477916, 9.718407271532273, 8.808209916652306, 7.818930902064189, 6.880198551958849, 5.865782323484603, 4.93311918895353, 4.0222443814609194, 4.903933319989918, 5.8290546502419245, 6.737020229691722, 7.741769539937142, 8.768119184830642, 9.7469858941613, 10.525904357811154, 11.475096623195803, 12.43916363316044, 13.365977461673783, 12.629383127054332, 11.601965761870831, 11.640017364046265, 10.687970854454626, 9.866935600222906, 8.852237795542365, 7.873441660683678, 6.863690105306975, 5.880381155775949, 5.06466025514252, 5.9291304613015825, 6.831402538044383, 7.786487680757817, 8.669306802081866, 9.656384133606375, 10.699126256871672, 11.557049844836403, 12.54617745174053, 13.461293694995168, 14.371580196903885, 13.574414436111928, 12.604845080864362, 12.639359827161222, 11.628238424028476, 10.8095671089593, 9.841447609200447, 8.808618535266579, 7.793956416694606, 6.845304693094926, 6.018406417669258, 6.916102171268751, 7.76252699666843, 8.789981122835302, 9.649881261459207, 10.592569859561998, 11.60735478026823, 12.492992725729968, 13.51725766978928, 14.500965176727949, 15.422476999156087, 14.55309421252071, 13.616836276657935, 13.580515164556768, 12.638989783711208, 11.701000874565688, 10.704806045326759, 9.779444549341726, 8.84670803612343, 7.8848400819982, 6.9988069398237, 7.954096830922311, 8.824642684010048, 9.76130017445186, 10.677849880545901, 11.616663262836559, 12.631375263867366, 13.457158822575105, 14.44316562290167, 15.45731833352733, 16.384742264768555, 15.56469503120304, 14.52753437742947, 14.639759796899952, 13.673212304953882, 12.695652040998036, 11.635676360539584, 10.805372923875023, 9.778734405843016, 8.858904002065108, 7.958969484432117, 9.01414164633028, 9.829798488758124, 10.764716031002546, 11.661423289239817, 12.095681049920131, 12.93980970421541, 13.922608212985343, 14.761686433987338, 15.741310747024505, 16.700267379258023, 16.521900667040608, 15.535451668879427, 15.640094466953045, 14.701174526229174, 13.65354840887517, 12.60834226344671, 11.809120365810392, 10.798151619360066, 9.863614738246195, 8.922316100408795, 9.894759951292514, 10.828872224721273, 11.718280666289225, 12.044064776676962, 11.137140113046309, 11.99579157350904, 12.907805438178256, 13.788750071539493, 14.742228637452046, 15.772122513137138, 16.696280428406347, 16.584263353607465, 16.606201115222323, 15.632393860579956, 14.629305205525952, 13.682284680900484, 12.76660111206433, 11.771365958969348, 10.937471289781975, 9.98474908103957, 10.956806150409847, 11.887227582631777, 11.994836579899761, 11.03210383953082, 10.205658349916757, 10.987641333767415, 11.868262968936587, 12.835884368876373, 13.787046729916822, 14.842749840979815, 15.76903512064548, 16.582294744654416, 16.621862038509764, 16.611376112496274, 15.649769196261845, 14.686305604970604, 13.67298288385621, 12.698498156146414, 11.91103878429066, 10.980813666829807, 12.009741575390468, 11.960272294708325, 11.066362403909206, 10.072966180733061, 9.192828077861682, 9.936414861459061, 10.888638763729071, 11.880414252370437, 12.899641236344467, 13.805196520769046, 14.749763437103406, 15.627061820926563, 15.749996748650513, 16.631991637126973, 16.629783361800897, 15.58277539028085, 14.634480208176832, 13.640814057408589, 12.845958604436776, 11.951413299608742, 11.795505337629539, 10.887353637225392, 10.088674488410716, 9.085982325999453, 8.264853258915231, 8.96099820733408, 9.946343569875937, 10.911871895516827, 11.901137234603066, 12.793209637157986, 13.749036669079121, 14.70022338020472], [14.693652990273499, 13.734677735000568, 12.755340721563357, 11.814704297088035, 10.786469657456987, 9.834774964507792, 8.843609477613164, 7.935063097676129, 6.9954059604770285, 7.990082458272243, 8.844528699311349, 9.697506410510751, 10.622792366747252, 11.564609005381492, 12.41098381503106, 13.399461435151956, 14.356846914125548, 15.381219511353823, 16.38214563896268, 15.70383062223354, 13.735430499290597, 12.784326905918316, 11.764827843259352, 10.81629062205566, 9.756440228277828, 8.855573046190537, 7.893482773992974, 6.991622779877348, 5.939860154083939, 6.953274861084417, 7.90146084654871, 8.63522662169769, 9.58571824263685, 10.60214541505412, 11.483855819460405, 12.456688804676192, 13.470518115389622, 14.398839960053799, 15.358266930438038, 14.775189710095713, 12.69170784625687, 11.750552706433979, 10.793793114605387, 9.827627394441734, 8.828786961634403, 7.8159733172909895, 6.890752674657454, 5.939085951160212, 4.923422962377834, 5.930677682908828, 6.880615153084266, 7.63544131175783, 8.570502616961317, 9.561264466605815, 10.535563239867576, 11.4741962753937, 12.424055008598446, 13.476750602192642, 14.432868779354871, 13.737157199840446, 11.739748402764667, 10.804225053455177, 9.819382885225018, 8.890773865720368, 7.851514354170993, 6.832644170599614, 5.884163393147042, 4.89305485874482, 3.90750450858654, 4.884229899421005, 5.821556340330892, 6.6470764459371825, 7.610979727033309, 8.573528167389059, 9.54875627271653, 10.592786601685408, 11.52130522812554, 12.45642330393225, 13.447034591010427, 12.76237811671082, 10.814172751341053, 9.865211131477528, 8.836906075447885, 7.878754878666749, 6.8692524324106525, 5.941712357067555, 4.896414860043442, 3.9557114607615675, 2.915378398462167, 3.8596228715761347, 4.76634061299884, 5.707706745524632, 6.7423248815409815, 7.684394556792514, 8.569927026486948, 9.59218940293568, 10.553898825143417, 11.48276217492062, 12.501171809147507, 11.867915570933027, 9.901883561382153, 8.840143870902997, 7.890905974467971, 6.965519056824132, 5.926689595790275, 4.8991098086149885, 3.9619343548239248, 2.993404593627104, 1.9834250408269813, 2.848228828757933, 3.7943757204134063, 4.74677712167105, 5.737296093209211, 6.666255041544335, 7.644065411469465, 8.62330293416727, 9.550635935052261, 10.606997141749101, 11.659993712488845, 10.85222662064283, 9.081582963889673, 8.067410914933854, 7.106228438341735, 6.09923396043416, 5.030340894784893, 3.961602889921679, 3.019981328726322, 1.9728854306086467, 0.9629197648853204, 1.9064749208359704, 2.8829076425589464, 3.812015265629996, 4.794183106801561, 5.827791266977649, 6.8575652206829085, 7.811744367939625, 8.835734137068652, 9.876804750179124, 10.885197043735516, 10.080724355157152, 8.142172453541907, 7.141713454125371, 6.145461360247346, 5.135583857281437, 4.164027382298831, 3.1140323526829627, 2.1347278560204956, 1.067349961705026, 0.0, 0.9650008842253127, 1.9216019375848274, 2.9628707965367402, 3.916775402689323, 4.97164427956047, 6.021890001324311, 6.992887166232451, 7.9224737663330895, 8.861429090685112, 9.912483305842294, 9.170136013849142, 8.88420565691417, 7.821020859604433, 6.827320176444996, 5.89928258526697, 4.952018267773001, 3.9474737352781846, 3.011192638047545, 1.9839344486628288, 1.0193638126433235, 1.9593131429674013, 2.892435028138506, 3.952774169323919, 4.880661663925067, 5.8200602689828, 6.8493714378897765, 7.8370486643489, 8.764766247044465, 9.838341285378437, 10.900898139487284, 9.93356919387568, 9.801629335789276, 8.796490260527085, 7.82578662716666, 6.844661550667466, 5.88677266807359, 4.875892780559366, 3.902748849335259, 2.960614055730842, 2.0881696121184357, 2.9050736202804552, 3.861026024951138, 4.786199483688181, 5.725159718767048, 6.67176825909758, 7.658754851330507, 8.65458128903437, 9.593964724336281, 10.6682233526858, 11.692916519528533, 10.862321040421476, 10.786544672369812, 9.751872138546204, 8.80775247246328, 7.821183354280875, 6.820515315366002, 5.939656761468234, 4.951168048678259, 3.9830128612794855, 3.0171334093955346, 3.865781982031827, 4.836415826010423, 5.815241997430391, 6.74918030329721, 7.743425583164624, 8.615988080620644, 9.56679662731575, 10.551110028038272, 11.562732104165324, 12.527676952019311, 11.72892947335759, 11.626246810133155, 10.698293698187513, 9.788096343307547, 8.798817328719428, 7.860084978614089, 6.845668750139842, 5.9130056156087685, 4.972720561222952, 3.9678974150255373, 4.887777662499781, 5.787765384307951, 6.792514694553371, 7.818864339446872, 8.79773104877753, 9.576649512427382, 10.525841777812031, 11.489908787776669, 12.416722616290011, 13.390975928715038, 12.58185218852607, 12.619903790701505, 11.667857281109866, 10.846822026878147, 9.832124222197605, 8.853328087338918, 7.8435765319622135, 6.860267582431188, 5.962111272380486, 4.993094556337201, 5.89012555030224, 6.837232835374047, 7.720051956698095, 8.707129288222603, 9.7498714114879, 10.607794999452631, 11.596922606356758, 12.512038849611397, 13.422325351520113, 14.377308338836716, 13.5847315075196, 13.619246253816462, 12.608124850683716, 11.78945353561454, 10.821334035855687, 9.788504961921817, 8.773842843349843, 7.825191119750165, 6.915857434907224, 5.9800662663043695, 6.821250008926286, 7.848704135093158, 8.700626416075435, 9.643315014178226, 10.658099934884458, 11.543737880346196, 12.568002824405509, 13.551710331344177, 14.473222153772316, 15.355988115245498, 14.596722703313175, 14.560401591212008, 13.618876210366448, 12.680887301220926, 11.684692471981997, 10.759330975996964, 9.826594462778667, 8.864726508653439, 7.896257957061666, 7.044195165755993, 7.883365696267905, 8.820023186709715, 9.72859503516213, 10.667408417452787, 11.682120418483592, 12.507903977191333, 13.493910777517899, 14.508063488143558, 15.435487419384783, 16.379393198673906, 15.50742080408471, 15.619646223555192, 14.653098731609122, 13.675538467653274, 12.615562787194822, 11.78525935053026, 10.758620832498254, 9.838790428720348, 8.856420501670083, 8.10423998116396, 8.888521501015981, 9.823439043260402, 10.712168443856047, 11.604706269983314, 12.644535022785483, 13.459342871131359, 14.451916018472764, 15.43154033150993, 16.39049696374345, 17.39849287253803, 16.515338095534666, 16.619980893608286, 15.681060952884412, 14.633434835530409, 13.588228690101948, 12.78900679246563, 11.777214853562773, 10.842677972448902, 9.81976711764676, 9.098630716074425, 9.88759523697913, 10.77700367854708, 11.015636891905793, 11.849997024825079, 12.862417931558488, 13.814965747115258, 14.695910380476494, 15.649388946389047, 16.67928282207414, 17.638737782362163, 17.564149780262706, 17.586087541877564, 16.612280287235194, 15.60919163218119, 14.662171107555722, 13.745664346267038, 12.750429193172055, 11.904016881054194, 10.882200098277536, 10.160676915191758, 10.953923102484055, 10.966408695128592, 10.00367595475965, 10.918515261695527, 11.879172496239562, 12.775423277873589, 13.743044677813375, 14.694207038853824, 15.749910149916817, 16.711492474601297, 17.537903166941163, 17.577470460796512, 17.59126253915151, 16.629655622917085, 15.666192031625842, 14.652046118058918, 13.67756139034912, 12.87758437556288, 11.878264684067773, 11.213612340172379, 10.92663470697157, 10.037934519138037, 9.044538295961893, 9.905684989640452, 10.843575170396065, 11.795799072666073, 12.787574561307439, 13.806801545281468, 14.747653874724863, 15.692220791059222, 16.58267024321331, 16.70560517093726, 17.295843280993033, 16.335191316327116, 15.357571053145895, 14.409275871041878, 13.35188428035378, 12.492655596781297, 11.574976424483053, 10.737343617670984, 9.853716049488636, 9.060246603639547, 8.057554441228284, 8.977710170694001, 9.868158516271084, 10.853503878812939, 11.819032204453828, 12.808297543540068, 13.748818059444734, 14.704645091365869, 15.655831802491468], [15.520989705608855, 14.562014450335925, 13.582677436898713, 12.642041012423391, 11.613806372792343, 10.662111679843147, 9.670946192948517, 8.762399813011482, 7.822742675812382, 7.116788463313461, 7.8795278150860355, 8.732505526285438, 9.657791482521938, 10.599608121156178, 11.445982930805746, 12.434460550926643, 13.391846029900234, 14.41621862712851, 15.417144754737366, 16.443882351087474, 14.562767214625953, 13.611663621253673, 12.592164558594709, 11.643627337391017, 10.583776943613184, 9.682909761525892, 8.720819489328328, 7.8189594952127015, 6.767196869419292, 6.079980866125634, 6.936459962323397, 7.670225737472376, 8.620717358411536, 9.637144530828806, 10.518854935235092, 11.491687920450879, 12.505517231164308, 13.433839075828486, 14.393266046212727, 15.438391293365976, 13.519044561592226, 12.577889421769335, 11.621129829940744, 10.65496410977709, 9.65612367696976, 8.643310032626344, 7.718089389992808, 6.766422666495567, 5.750759677713187, 5.057383687950046, 5.915614268858953, 6.670440427532517, 7.605501732736004, 8.596263582380502, 9.570562355642263, 10.509195391168387, 11.459054124373132, 12.511749717967328, 13.46786789512956, 14.419697224801393, 12.567085118100021, 11.631561768790533, 10.64671960056037, 9.71811058105572, 8.678851069506345, 7.659980885934967, 6.7115001084823955, 5.720391574080174, 4.734841223921894, 3.9987079683052307, 4.856555456105578, 5.682075561711869, 6.645978842807995, 7.608527283163745, 8.583755388491216, 9.627785717460094, 10.556304343900226, 11.491422419706936, 12.482033706785115, 13.490616390707196, 11.641509466676407, 10.692547846812882, 9.66424279078324, 8.706091594002103, 7.696589147746006, 6.769049072402909, 5.723751575378796, 4.783048176096922, 3.742715113797521, 2.9321693324605356, 3.8013397287735264, 4.742705861299319, 5.777323997315668, 6.719393672567201, 7.604926142261634, 8.62718851871037, 9.588897940918105, 10.517761290695308, 11.536170924922196, 12.602291867631418, 10.729220276717507, 9.667480586238351, 8.718242689803326, 7.792855772159485, 6.754026311125629, 5.726446523950342, 4.789271070159279, 3.8207413089624582, 2.8107617561623357, 1.8832279445326203, 2.8293748361880935, 3.781776237445737, 4.772295208983898, 5.701254157319022, 6.679064527244153, 7.658302049941958, 8.58563505082695, 9.64199625752379, 10.694992828263533, 11.657736107684102, 10.033426226753042, 9.019254177797222, 8.058071701205105, 7.051077223297529, 5.982184157648263, 4.913446152785049, 3.971824591589692, 2.9247286934720167, 1.91476302774869, 0.9414740366106576, 1.9179067583336336, 2.8470143814046835, 3.829182222576249, 4.862790382752337, 5.892564336457596, 6.846743483714312, 7.870733252843339, 8.91180386595381, 9.920196159510203, 10.852751081077276, 9.10717333776722, 8.106714338350685, 7.110462244472658, 6.10058474150675, 5.129028266524143, 4.079033236908275, 3.0997287402458085, 2.0323508459303388, 0.9650008842253127, 0.0, 0.9566010533595146, 1.9978699123114272, 2.95177451846401, 4.006643395335157, 5.056889117098998, 6.027886282007138, 6.957472882107776, 7.896428206459799, 8.94748242161698, 9.933479329026666, 9.843005674645005, 8.779820877335267, 7.78612019417583, 6.858082602997805, 5.910818285503836, 4.906273753009019, 3.9699926557783796, 2.9427344663936634, 1.9781638303741582, 1.0382145000500804, 1.9686442450712864, 3.020232744929422, 3.9156607796997536, 4.855059384757487, 5.884370553664463, 6.872047780123586, 7.799765362819151, 8.873340401153122, 9.93589725526197, 10.892369211606514, 10.760429353520111, 9.75529027825792, 8.784586644897495, 7.803461568398301, 6.8455726858044255, 5.834692798290201, 4.861548867066094, 3.9194140734616765, 2.9146299127826163, 1.9839749773631346, 2.9372352418839185, 3.862408700620961, 4.801368935699829, 5.747977476030361, 6.734964068263287, 7.730790505967152, 8.670173941269063, 9.744432569618581, 10.769125736461314, 11.78389348447175, 11.745344690100646, 10.710672156277038, 9.766552490194114, 8.77998337201171, 7.779315333096838, 6.869475994346946, 5.8010159626312285, 4.809473161943666, 3.8435937100597153, 2.944683339114506, 3.912625042943204, 4.891451214363172, 5.825389520229991, 6.819634800097404, 7.692197297553425, 8.64300584424853, 9.627319244971051, 10.638941321098104, 11.60388616895209, 12.581938322515333, 12.585046827863989, 11.657093715918347, 10.746896361038381, 9.757617346450262, 8.747037551871337, 7.677289784190111, 6.744626649659038, 5.799180861887133, 4.794357715689718, 3.9666790195824606, 4.863974601240732, 5.868723911486152, 6.895073556379652, 7.873940265710311, 8.652858729360162, 9.602050994744811, 10.566118004709448, 11.49293183322279, 12.467185145647818, 13.494602510831319, 13.578703808432339, 12.6266572988407, 11.805622044608981, 10.750257909546963, 9.684949121389186, 8.675197566012482, 7.6918886164814575, 6.788571573044667, 5.819554857001382, 4.969026907384919, 5.913442052306827, 6.796261173630875, 7.783338505155384, 8.82608062842068, 9.68400421638541, 10.673131823289538, 11.588248066544176, 12.498534568452893, 13.453517555769496, 14.423086911017062, 14.578046271547295, 13.56692486841455, 12.661498667932866, 11.693379168174014, 10.620125995972087, 9.605463877400114, 8.656812153800434, 7.742317735571405, 6.80652656696855, 5.9001513660089655, 6.927605492175838, 7.776835633008215, 8.719524231111007, 9.73430915181724, 10.619947097278976, 11.644212041338289, 12.627919548276957, 13.549431370705095, 14.432197332178278, 15.378766772712233, 15.500494997136023, 14.558969616290463, 13.512508335271194, 12.516313506032265, 11.590952010047234, 10.658215496828937, 9.696347542703709, 8.722718257725846, 7.870655466420174, 6.962267053350584, 7.898924543792395, 8.80480425209491, 9.743617634385568, 10.758329635416374, 11.584113194124113, 12.570119994450678, 13.584272705076337, 14.511696636317563, 15.455602415606688, 16.433874923290183, 16.559739629479207, 15.559636148640392, 14.507159501703542, 13.44718382124509, 12.616880384580531, 11.590241866548524, 10.670411462770616, 9.682880802334264, 8.930700281828141, 7.9674228580986615, 8.902340400343082, 9.788377660788825, 10.680915486916096, 11.720744239718265, 12.535552088064138, 13.528125235405543, 14.50774954844271, 15.46670618067623, 16.47470208947081, 17.44179221474014, 17.458502816032127, 16.51268198693468, 15.465055869580677, 14.419849724152217, 13.6206278265159, 12.603675154226954, 11.669138273113083, 10.646227418310941, 9.925091016738605, 8.966496594061812, 9.85590503562976, 10.83203133261491, 11.639456423789918, 12.651877330523327, 13.550354862871226, 14.501061597853388, 15.507048468857342, 16.485881946006685, 17.445782579888903, 18.42100599414579, 18.424609464301405, 17.443901321285463, 16.44081266623146, 15.49379214160599, 14.572124646931218, 13.576889493836235, 12.730477181718374, 11.708660398941717, 10.963245891788667, 10.032824459566736, 10.221180690661866, 10.831012670095003, 11.745851977030881, 12.706509211574916, 13.602759993208943, 14.57038139314873, 15.52154375418918, 16.577246865252175, 17.53882918993665, 18.365239882276523, 18.35375428039611, 17.3347197336315, 16.31133153100236, 15.328713043514949, 14.303684025100438, 13.329199297390641, 12.4625745327021, 11.580575173036674, 10.802636163412703, 9.961633822746254, 9.206435981928303, 9.871875011297245, 10.733021704975807, 11.670911885731417, 12.623135788001427, 13.614911276642795, 14.634138260616824, 15.574990590060219, 16.519557506394577, 17.41000695854867, 17.342527382502894, 16.330842396767718, 15.370190432101802, 14.39257016892058, 13.444274986816563, 12.386883396128466, 11.527654712555984, 10.60997554025774, 9.77234273344567, 8.88871516526332, 8.186952608680764, 8.884891156563636, 9.805046886029356, 10.695495231606436, 11.680840594148293, 12.646368919789184, 13.635634258875424, 14.57615477478009, 15.531981806701225, 16.483168517826826], [16.47759075896837, 15.518615503695438, 14.539278490258226, 13.598642065782904, 12.570407426151856, 11.618712733202662, 10.62754724630803, 9.719000866370996, 8.779343729171895, 8.073389516672975, 7.032922769839535, 7.8650282238313824, 8.790314180067883, 9.732130818702123, 10.57850562835169, 11.566983248472587, 12.524368727446179, 13.548741324674454, 14.54966745228331, 15.576405048633418, 15.519368267985467, 14.568264674613186, 13.548765611954222, 12.60022839075053, 11.540377996972698, 10.639510814885407, 9.677420542687841, 8.775560548572216, 7.7237979227788065, 7.036581919485149, 6.089854917076897, 6.80274843501832, 7.75324005595748, 8.76966722837475, 9.651377632781037, 10.624210617996823, 11.638039928710253, 12.56636177337443, 13.525788743758671, 14.57091399091192, 14.47564561495174, 13.534490475128848, 12.577730883300257, 11.611565163136603, 10.612724730329273, 9.599911085985859, 8.674690443352322, 7.72302371985508, 6.7073607310727015, 6.013984741309561, 5.069009223612452, 5.8029631250784615, 6.738024430281948, 7.728786279926446, 8.703085053188207, 9.641718088714331, 10.591576821919077, 11.644272415513273, 12.600390592675504, 13.552219922347337, 13.523686171459536, 12.588162822150046, 11.603320653919885, 10.674711634415235, 9.63545212286586, 8.616581939294482, 7.66810116184191, 6.676992627439688, 5.691442277281408, 4.955309021664746, 4.009950410859078, 4.814598259257814, 5.77850154035394, 6.74104998070969, 7.716278086037163, 8.76030841500604, 9.688827041446173, 10.623945117252882, 11.61455640433106, 12.62313908825314, 12.598110520035922, 11.649148900172397, 10.620843844142755, 9.662692647361617, 8.65319020110552, 7.7256501257624235, 6.68035262873831, 5.739649229456436, 4.699316167157035, 3.8887703858200506, 2.9547346835270263, 3.875228558845264, 4.9098466948616135, 5.8519163701131465, 6.7374488398075805, 7.759711216256314, 8.721420638464052, 9.650283988241254, 10.66869362246814, 11.734814565177363, 11.685821330077022, 10.624081639597867, 9.67484374316284, 8.749456825519001, 7.710627364485144, 6.683047577309857, 5.745872123518793, 4.777342362321972, 3.76736280952185, 2.839828997892135, 1.9827697909415933, 2.9142989349916824, 3.9048179065298436, 4.8337768548649676, 5.811587224790098, 6.790824747487903, 7.718157748372894, 8.774518955069734, 9.827515525809478, 10.790258805230046, 10.89529141898524, 9.975855231156736, 9.014672754564618, 8.007678276657042, 6.938785211007776, 5.870047206144562, 4.928425644949206, 3.881329746831531, 2.8713640811082044, 1.8980750899701722, 0.9613057049741188, 1.8904133280451685, 2.872581169216734, 3.906189329392822, 4.935963283098081, 5.890142430354797, 6.914132199483824, 7.955202812594296, 8.963595106150688, 9.896150027717761, 10.004841835974386, 9.0633153917102, 8.067063297832174, 7.057185794866265, 6.085629319883658, 5.03563429026779, 4.0563297936053235, 2.9889518992898534, 1.9216019375848274, 0.9566010533595146, 0.0, 1.0412688589519126, 1.9951734651044954, 3.050042341975642, 4.100288063739483, 5.071285228647623, 6.000871828748261, 6.939827153100284, 7.990881368257465, 8.97687827566715, 10.749956251477801, 9.686771454168063, 8.693070771008626, 7.765033179830601, 6.8177688623366315, 5.813224329841815, 4.8769432326111755, 3.8496850432264598, 2.8851144072069546, 1.9451650768828768, 1.0120431917117718, 2.063631691569907, 2.959059726340239, 3.898458331397972, 4.927769500304948, 5.915446726764071, 6.8431643094596355, 7.916739347793608, 8.979296201902455, 9.944316879152233, 11.66737993035291, 10.662240855090719, 9.691537221730293, 8.710412145231098, 7.752523262637222, 6.741643375122997, 5.76849944389889, 4.826364650294473, 3.821580489615413, 2.890925554195931, 1.9806341885244036, 2.9058076472614465, 3.844767882340314, 4.7913764226708455, 5.778363014903772, 6.7741894526076365, 7.713572887909548, 8.787831516259068, 9.8125246831018, 10.827292431112237, 12.567722070143596, 11.617622733109837, 10.673503067026912, 9.686933948844509, 8.686265909929634, 7.7764265711797425, 6.707966539464025, 5.716423738776463, 4.750544286892512, 3.851633915947303, 2.956023989583689, 3.9348501610036566, 4.868788466870477, 5.863033746737889, 6.73559624419391, 7.686404790889014, 8.670718191611536, 9.682340267738589, 10.647285115592576, 11.625337269155818, 13.491997404696788, 12.564044292751145, 11.65384693787118, 10.66456792328306, 9.653988128704132, 8.584240361022907, 7.651577226491835, 6.70613143871993, 5.701308292522515, 4.873629596415258, 3.9073735478812166, 4.9121228581266365, 5.938472503020138, 6.917339212350796, 7.696257676000647, 8.645449941385296, 9.609516951349933, 10.536330779863276, 11.510584092288303, 12.538001457471804, 14.485654385265137, 13.533607875673498, 12.71257262144178, 11.657208486379758, 10.591899698221983, 9.582148142845279, 8.598839193314253, 7.695522149877464, 6.726505433834179, 5.875977484217716, 4.956840998947312, 5.83966012027136, 6.826737451795869, 7.869479575061165, 8.727403163025896, 9.716530769930023, 10.631647013184661, 11.541933515093378, 12.49691650240998, 13.466485857657547, 15.39964216884943, 14.473875445247348, 13.568449244765663, 12.60032974500681, 11.527076572804884, 10.51241445423291, 9.563762730633231, 8.649268312404201, 7.713477143801347, 6.807101942841763, 6.016292920663387, 6.8202345796487, 7.762923177751492, 8.777708098457724, 9.66334604391946, 10.687610987978774, 11.671318494917442, 12.59283031734558, 13.475596278818763, 14.422165719352718, 16.37252411975067, 15.465920193123262, 14.419458912103993, 13.423264082865064, 12.49790258688003, 11.565166073661734, 10.603298119536506, 9.629668834558643, 8.777606043252971, 7.869217630183382, 6.987611972279945, 7.848203198735394, 8.787016581026053, 9.80172858205686, 10.627512140764598, 11.613518941091163, 12.627671651716822, 13.555095582958048, 14.499001362247173, 15.477273869930668, 17.431768752093852, 16.466586725473192, 15.414110078536341, 14.354134398077889, 13.523830961413328, 12.497192443381321, 11.577362039603415, 10.58983137916706, 9.83765085866094, 8.874373434931458, 7.991027828830632, 8.831776607429312, 9.724314433556582, 10.764143186358751, 11.578951034704623, 12.571524182046028, 13.551148495083195, 14.510105127316715, 15.518101036111293, 16.485191161380623, 18.365453392864925, 17.41963256376748, 16.372006446413476, 15.326800300985015, 14.527578403348697, 13.51062573105975, 12.57608884994588, 11.553177995143738, 10.832041593571404, 9.873447170894607, 8.94459246411731, 9.875430279255397, 10.682855370430405, 11.695276277163813, 12.59375380951171, 13.544460544493873, 14.550447415497826, 15.52928089264717, 16.489181526529386, 17.464404940786274, 18.463479379114624, 17.402826128887362, 16.37494216335499, 15.427921638729522, 14.384089345208634, 13.388854192113651, 12.56866472475673, 11.709162456372855, 10.988094285939269, 10.150979016549831, 9.960441363314079, 10.88739121640154, 11.614337133559957, 12.574994368103992, 13.546118741621056, 14.497326247156993, 15.448488608197442, 16.504191719260437, 17.416426834290252, 18.362380182145884, 17.486276977942055, 16.467242431177443, 15.443854228548304, 14.461235741060893, 13.436206722646382, 12.461721994936585, 11.595097230248044, 10.713097870582619, 9.935158860958648, 9.115028777499756, 10.133160643129635, 10.828476064656758, 11.68962275833532, 12.62751293909093, 13.579736841360942, 14.571512330002308, 15.590739313976337, 16.53159164341973, 17.47615855975409, 18.366608011908184, 16.475050080048838, 15.463365094313662, 14.502713129647747, 13.525092866466524, 12.576797684362507, 11.51940609367441, 10.660177410101928, 9.742498237803684, 8.904865430991615, 8.042110120016822, 9.113677269882096, 9.84149220992315, 10.761647939388869, 11.65209628496595, 12.637441647507808, 13.602969973148697, 14.592235312234937, 15.532755828139603, 16.48858286006074, 17.43976957118634], [15.628098758513907, 16.50743451246292, 15.528097499025705, 14.587461074550383, 13.559226434919335, 12.607531741970138, 11.616366255075508, 10.707819875138474, 9.768162737939374, 8.786321170870227, 7.739185738015161, 6.906544301751829, 7.831830257988329, 8.77364689662257, 9.620021706272139, 10.608499326393035, 11.565884805366627, 12.590257402594903, 13.59118353020376, 14.617921126553867, 14.658210413092691, 15.557083683380664, 14.5375846207217, 13.589047399518009, 12.529197005740176, 11.628329823652884, 10.66623955145532, 9.764379557339694, 8.712616931546284, 7.7495135736824015, 6.796117885252523, 5.844264512938767, 6.794756133877927, 7.811183306295197, 8.692893710701485, 9.665726695917272, 10.679556006630701, 11.607877851294878, 12.567304821679116, 13.612430068832365, 13.639185353851358, 14.523309483896327, 13.566549892067735, 12.600384171904082, 11.601543739096751, 10.588730094753336, 9.6635094521198, 8.711842728622559, 7.696179739840179, 6.795485461540348, 5.775272191788078, 4.844479202998908, 5.779540508202395, 6.770302357846893, 7.744601131108655, 8.68323416663478, 9.633092899839525, 10.685788493433721, 11.641906670595949, 12.593736000267782, 12.686146780432937, 13.576981830917521, 12.592139662687362, 11.663530643182712, 10.624271131633337, 9.605400948061959, 8.656920170609387, 7.665811636207166, 6.680261286048886, 5.870644612822435, 4.909681734921624, 3.8561143371782602, 4.820017618274386, 5.782566058630136, 6.757794163957608, 7.801824492926485, 8.730343119366617, 9.665461195173327, 10.656072482251504, 11.664655166173585, 11.760571129009323, 12.637967908939872, 11.60966285291023, 10.651511656129093, 9.642009209872997, 8.714469134529901, 7.669171637505788, 6.728468238223914, 5.688135175924513, 4.8041059769777394, 3.854466007589572, 2.9167446367657104, 3.9513627727820597, 4.893432448033592, 5.778964917728025, 6.80122729417676, 7.7629367163844964, 8.691800066161699, 9.710209700388585, 10.776330643097808, 10.7524690356133, 11.612900648365342, 10.663662751930316, 9.738275834286476, 8.69944637325262, 7.671866586077334, 6.734691132286271, 5.76616137108945, 4.756181818289328, 3.8286480066596122, 2.882501115004139, 1.9558150129121286, 2.94633398445029, 3.8752929327854138, 4.853103302710544, 5.832340825408349, 6.759673826293341, 7.816035032990181, 8.869031603729924, 9.802125976352624, 9.871837037857262, 10.88600908681308, 10.044599427247094, 9.037604949339519, 7.968711883690252, 6.899973878827039, 5.958352317631682, 4.911256419514007, 3.9012907537906805, 2.928001762652648, 1.8610370290366642, 0.9319294059656146, 1.9140972471371798, 2.947705407313268, 3.9774793610185277, 4.931658508275244, 5.95564827740427, 6.96060383126201, 7.968996124818402, 8.872695646589783, 8.963572977022473, 9.964031976439008, 9.108332156784087, 8.098454653818179, 7.126898178835571, 6.076903149219703, 5.097598652557236, 4.030220758241766, 2.96287079653674, 1.9978699123114272, 1.0412688589519126, 0.0, 0.9539046061525829, 2.0087734830237296, 3.05901920478757, 4.03001636969571, 4.959602969796348, 5.898558294148371, 6.9496125093055525, 7.935609416715238, 9.932992117659348, 10.728040313119976, 9.73433962996054, 8.806302038782514, 7.859037721288544, 6.854493188793728, 5.918212091563088, 4.890953902178373, 3.926383266158867, 2.986433935834789, 2.0533120506636844, 1.0223628326179948, 1.9177908673883264, 2.8571894724460596, 3.8865006413530354, 4.874177867812159, 5.801895450507723, 6.875470488841695, 7.938027342950542, 8.90304802020032, 10.871071820419573, 11.703509714042632, 10.732806080682206, 9.75168100418301, 8.793792121589135, 7.78291223407491, 6.809768302850803, 5.867633509246386, 4.844908519058957, 3.914253583639475, 2.9370460447306694, 2.011872585993627, 2.9034981107442923, 3.7909099692603756, 4.777896561493303, 5.773722999197167, 6.713106434499078, 7.787365062848598, 8.812058229691331, 9.826825977701768, 11.567255616733126, 12.601928150556734, 11.714771925978825, 10.728202807796421, 9.727534768881547, 8.799754600623286, 7.731294568907569, 6.739751768220007, 5.773872316336056, 4.874961945390846, 3.912435845789955, 3.070246286999134, 3.9275186952744545, 4.8625672933274195, 5.73512979078344, 6.685938337478545, 7.670251738201066, 8.681873814328119, 9.646818662182106, 10.624870815745348, 12.49314038245425, 13.421093494399893, 12.695115796823092, 11.705836782234973, 10.677316158147676, 9.60756839046645, 8.674905255935379, 7.729459468163474, 6.7246363219660585, 5.843654781956005, 4.863785404087483, 4.125215325748418, 4.997202731424116, 5.916872758940326, 6.695791222590177, 7.644983487974826, 8.609050497939464, 9.535864326452806, 10.510117638877833, 11.537535004061334, 13.4867973630226, 14.390657077322246, 13.752448517474093, 12.680536515823302, 11.615227727665527, 10.605476172288823, 9.622167222757797, 8.718850179321008, 7.749833463277723, 6.846002669758463, 5.913252855153578, 5.052752587893142, 6.039829919417651, 6.982586104561548, 7.726936709615426, 8.716064316519551, 9.631180559774192, 10.541467061682908, 11.496450048999511, 12.466019404247078, 14.399175715438961, 15.330924646896095, 14.591777274209207, 13.623657774450354, 12.550404602248427, 11.535742483676454, 10.587090760076775, 9.672596341847745, 8.73680517324489, 7.77712712838251, 6.972704776869653, 6.033327047270482, 6.976015645373274, 7.990800566079506, 8.662879590508991, 9.687144534568304, 10.670852041506972, 11.59236386393511, 12.475129825408294, 13.421699265942248, 15.372057666340199, 16.31358304718576, 15.442786941547537, 14.446592112308608, 13.521230616323574, 12.588494103105278, 11.62662614898005, 10.652996864002187, 9.800934072696515, 8.839242815724129, 7.944023828486211, 7.061295666357176, 8.000109048647836, 9.014821049678641, 9.627045687354128, 10.613052487680694, 11.627205198306353, 12.554629129547578, 13.498534908836703, 14.476807416520199, 16.43130229868338, 17.347805568428434, 16.437438107979883, 15.377462427521433, 14.547158990856872, 13.520520472824865, 12.600690069046959, 11.613159408610604, 10.860978888104484, 9.844398620472205, 8.947439685036898, 8.044869075051093, 8.937406901178363, 9.977235653980532, 10.578484581294154, 11.571057728635559, 12.550682041672726, 13.509638673906245, 14.517634582700824, 15.484724707970155, 17.431636968736473, 17.375561541158593, 16.397654665726677, 15.33882659889127, 14.406964606978244, 13.403584609643381, 12.684037354212956, 11.813111514924078, 11.09165656297705, 10.843472356435356, 9.901004320323576, 9.088522746877178, 9.895947838052185, 10.908368744785594, 11.593287356101241, 12.543994091083404, 13.549980962087357, 14.528814439236701, 15.488715073118916, 16.463938487375806, 17.504995457035072, 16.44434220680781, 15.41645824127544, 14.46943771664997, 13.425605423129083, 12.4303702700341, 11.610180802677176, 10.750678534293302, 10.029610363859717, 10.857241984725457, 10.916853219520345, 10.10048368402332, 10.827429601181738, 11.788086835725773, 12.63282982534291, 13.496859793746523, 14.448022154786972, 15.503725265849965, 16.41596038087978, 17.361913728735413, 16.527793055862503, 15.508758509097891, 14.485370306468752, 13.502751818981341, 12.47772280056683, 11.503238072857034, 10.63661330816849, 9.754613948503065, 8.976674938879095, 9.821291745675381, 10.83942361130526, 11.059621342821078, 11.840259873236812, 12.819502655770396, 13.612454030550426, 14.452329910252459, 15.470044020223158, 16.41089634966655, 17.35546326600091, 17.50225157873875, 15.516566157969287, 14.50488117223411, 13.544229207568195, 12.566608944386973, 11.618313762282956, 10.560922171594859, 9.701693488022375, 8.78401431572413, 7.946381508912061, 8.748373088192448, 9.819940238057722, 10.830311218690628, 11.750466948156348, 12.640915293733428, 13.626260656275285, 14.591788981916176, 15.581054321002416, 16.52157483690708, 17.47740186882822, 16.575413138016906], [14.804840803038903, 15.763816058311834, 16.48200210517829, 15.541365680702967, 14.513131041071919, 13.561436348122722, 12.570270861228092, 11.661724481291056, 10.722067344091956, 9.740225777022811, 8.693090344167745, 7.860448907904412, 7.125786146262179, 8.02419221677791, 8.805651452279799, 9.794129072400695, 10.751514551374287, 11.775887148602562, 12.767925574728755, 13.794663171078863, 13.794312872311366, 14.714597631659744, 15.491489226874284, 14.542952005670593, 13.48310161189276, 12.582234429805467, 11.620144157607903, 10.718284163492275, 9.666521537698866, 8.703418179834985, 7.7500224914051055, 6.79816911909135, 6.0887120221517765, 7.061728626450538, 7.878523456709144, 8.85135644192493, 9.865185752638359, 10.793507597302536, 11.719835578896227, 12.764960826049476, 12.75059021927764, 13.680746178421854, 14.52045449822032, 13.554288778056666, 12.555448345249335, 11.54263470090592, 10.617414058272384, 9.66574733477514, 8.650084345992761, 7.749390067692931, 6.729176797940661, 5.798383809151491, 5.073496396476244, 6.005852704802653, 6.930230877116314, 7.868863912642437, 8.811907787086389, 9.845699986183668, 10.79443742781306, 11.746266757484893, 11.732242174280355, 12.669656239300652, 13.546044268839946, 12.617435249335296, 11.578175737785921, 10.559305554214543, 9.610824776761971, 8.619716242359749, 7.634165892201468, 6.824549218975017, 5.863586341074207, 4.810018943330843, 4.113973506548236, 5.0181164055858964, 5.910324921174721, 6.954355250143598, 7.88287387658373, 8.81799195239044, 9.808603239468615, 10.817185923390696, 10.806666522856741, 11.755628142720266, 12.563567459062813, 11.605416262281677, 10.59591381602558, 9.668373740682483, 8.623076243658371, 7.682372844376496, 6.642039782077095, 5.758010583130322, 4.808370613742155, 3.8706492429182933, 3.125637710390562, 4.045963205250704, 4.931495674945138, 5.953758051393872, 6.915467473601608, 7.84433082337881, 8.862740457605696, 9.908892870253608, 9.798564429460718, 10.860304119939874, 11.6175673580829, 10.69218044043906, 9.653350979405204, 8.625771192229916, 7.688595738438853, 6.720065977242032, 5.71008642444191, 4.782552612812195, 3.836405721156722, 2.9097196190647114, 2.098864741667401, 3.027823690002525, 4.005634059927655, 4.984871582625461, 5.9122045835104515, 6.9685657902072915, 8.021562360947035, 8.848221370200042, 8.91793243170468, 9.932104480660499, 10.893286957252617, 9.991509555492103, 8.922616489842836, 7.853878484979623, 6.912256923784266, 5.86516102566659, 4.855195359943264, 3.881906368805231, 2.814941635189247, 1.8858340121181976, 1.0331609707128424, 2.0585545839856425, 3.088328537690902, 4.042507684947618, 5.062272628412108, 6.006699225109428, 7.01509151866582, 7.918791040437201, 8.00966837086989, 9.010127370286426, 10.006379464164452, 9.05235925997076, 8.080802784988153, 7.030807755372285, 6.051503258709818, 4.984125364394348, 3.9167754026893227, 2.95177451846401, 1.9951734651044954, 0.9539046061525829, 0.0, 1.0548688768711467, 2.1051145986349873, 3.076111763543128, 4.005698363643766, 4.944653687995789, 5.9957079031529705, 6.981704810562656, 8.979087511506766, 10.030724164734323, 10.643899817250741, 9.715862226072716, 8.768597908578746, 7.76405337608393, 6.82777227885329, 5.8005140894685745, 4.83594345344907, 3.895994123124992, 2.962872237953887, 1.902533096768474, 0.9638862612357435, 1.9032848662934767, 2.9325960352004525, 3.9202732616595757, 4.84799084435514, 5.921565882689112, 6.98412273679796, 7.949143414047738, 9.91716721426699, 10.922306289529182, 11.63024013217894, 10.649115055679745, 9.69122617308587, 8.680346285571645, 7.707202354347538, 6.7650675607431205, 5.721589672735907, 4.790934737316425, 3.8137271984076198, 2.888553739670577, 1.9495935045917094, 2.8370053631077927, 3.82399195534072, 4.819818393044584, 5.759201828346495, 6.833460456696015, 7.8581536235387475, 8.872921371549184, 10.613351010580542, 11.64802354440415, 12.592143210487077, 11.625636859293156, 10.624968820378282, 9.676435754300238, 8.60797572258452, 7.616432921896957, 6.650553470013006, 5.751643099067796, 4.789116999466905, 3.9198298592874234, 2.9736140891218716, 3.9086626871748367, 4.781225184630857, 5.732033731325962, 6.716347132048483, 7.727969208175535, 8.692914056029522, 9.670966209592764, 11.539235776301666, 12.467188888247309, 13.485081762722253, 12.60138503769836, 11.553997311824626, 10.4842495441434, 9.551586409612328, 8.606140621840423, 7.601317475643008, 6.720335935632955, 5.7404665577644325, 4.974798898036708, 4.043298125271533, 4.962968152787743, 5.741886616437594, 6.691078881822243, 7.65514589178688, 8.581959720300222, 9.55621303272525, 10.58363039790875, 12.532892756870016, 13.436752471169662, 14.490137465646395, 13.557217669500254, 12.491908881342477, 11.482157325965773, 10.498848376434747, 9.595531332997957, 8.626514616954672, 7.722683823435413, 6.789934008830528, 5.902336160181432, 5.089539396982051, 6.028681498408966, 6.773032103462844, 7.762159710366968, 8.677275953621608, 9.587562455530325, 10.542545442846928, 11.512114798094494, 13.445271109286377, 14.377020040743512, 15.397602384033686, 14.500338928127304, 13.427085755925377, 12.412423637353404, 11.463771913753725, 10.549277495524695, 9.61348632692184, 8.65380828205946, 7.849385930546603, 6.882910619558771, 6.025725122937675, 7.0405100436439065, 7.708974984356409, 8.733239928415722, 9.71694743535439, 10.638459257782527, 11.52122521925571, 12.467794659789664, 14.418153060187615, 15.359678441033175, 16.319468095224487, 15.323273265985556, 14.397911770000524, 13.465175256782228, 12.503307302657, 11.529678017679137, 10.677615226373465, 9.715923969401079, 8.82070498216316, 7.910879238645466, 7.049818526212236, 8.064530527243042, 8.673141081201546, 9.659147881528112, 10.67330059215377, 11.600724523394994, 12.54463030268412, 13.522902810367615, 15.477397692530799, 16.39390096227585, 16.54118077961147, 15.497122247806056, 14.596341794921273, 13.664017993214802, 12.939293410549382, 12.070414019174605, 11.737660041781433, 10.721079774149155, 9.824120838713847, 8.894452647339381, 7.987116378742764, 9.026945131544933, 9.624579975141572, 10.617153122482977, 11.596777435520144, 12.555734067753663, 13.56372997654824, 14.530820101817572, 16.477732362583893, 16.561191287166256, 15.583284411734336, 14.52445634489893, 13.592594352985904, 12.589214355651041, 11.934582674368297, 11.107067403197927, 12.04556116912963, 11.720153510112304, 10.777685474000526, 9.90618178895852, 8.945657315616586, 9.958078222349995, 10.639382749948659, 11.590089484930822, 12.596076355934775, 13.574909833084119, 14.534810466966332, 15.510033881223222, 16.690625203042735, 15.629971952815472, 14.602087987283099, 13.65506746265763, 12.611235169136743, 11.61600001604176, 10.860726122832517, 10.044634422567151, 10.983514970012298, 11.81114659087804, 11.793534373197295, 10.918142726104662, 9.877139078746138, 10.837796313290173, 11.678925219190328, 12.542955187593941, 13.49411754863439, 14.549820659697383, 15.4620557747272, 16.408009122582833, 15.713422801870161, 14.694388255105551, 13.671000052476412, 12.688381564989001, 11.66335254657449, 10.688867818864694, 9.887158628323832, 9.048569836776915, 9.930579545031677, 10.775196351827965, 11.793328217457844, 11.834979473853794, 10.889969350801213, 11.869212133334797, 12.658549424397844, 13.498425304099877, 14.516139414070576, 15.45699174351397, 16.40155865984833, 16.687881324746407, 14.702195903976946, 13.69051091824177, 12.729858953575855, 11.752238690394632, 10.803943508290615, 9.746551917602519, 8.952238808177716, 8.07797020399798, 8.900286115064644, 9.702277694345032, 10.773844844210306, 11.78421582484321, 11.817944169747664, 12.747363006219409, 13.600844618250978, 14.466967660953488, 15.456233000039727, 16.46897862712503, 16.733783414677134, 15.761042884024565], [13.758349773086795, 14.715033100778621, 15.552524233013965, 15.640568257200801, 14.62431349432241, 13.744356818928205, 13.304192004857358, 12.714552956854543, 11.774895819655443, 10.767338953420666, 9.720203520565597, 8.887562084302266, 7.973235228519181, 7.013723402364665, 7.785956976600936, 8.774434596721832, 9.731820075695424, 10.7561926729237, 11.748231099049894, 12.774968695400002, 12.739443995440219, 13.659728754788597, 14.562011354709963, 15.510548575913655, 14.535930087456247, 13.635062905368954, 12.67297263317139, 11.771112639055762, 10.719350013262353, 9.730531356232838, 8.777135667802959, 7.825282295489203, 6.936161104408779, 6.0512598120372925, 6.858828981030281, 7.831661966246067, 8.845491276959496, 9.773813121623673, 10.700141103217366, 11.745266350370615, 11.695721342406493, 12.625877301550707, 13.582636893379298, 14.548802613542952, 13.608276820812822, 12.595463176469407, 11.670242533835872, 10.718575810338628, 9.702912821556248, 8.776503244090785, 7.7562899743385145, 6.825496985549345, 5.9209454787332465, 4.995383890389407, 5.910536401437451, 6.8491694369635745, 7.792213311407526, 8.826005510504805, 9.774742952134199, 10.726572281806032, 10.677373297409208, 11.614787362429505, 12.637644708331285, 13.566253727835935, 12.631004213349408, 11.61213402977803, 10.663653252325458, 9.672544717923236, 8.686994367764955, 7.877377694538504, 6.905307449753197, 5.837132119728697, 4.961422588805238, 4.007647591172651, 4.890630445495858, 5.934660774464735, 6.863179400904867, 7.798297476711577, 8.788908763789754, 9.797491447711835, 9.751797645985594, 10.700759265849118, 11.700673240483667, 12.658244737845164, 11.648742291589068, 10.721202216245969, 9.675904719221856, 8.735201319939982, 7.694868257640582, 6.810839058693809, 5.861199089305641, 4.897762419316146, 3.9730867926475644, 3.0354943908374583, 3.9118011992662756, 4.934063575715009, 5.895772997922745, 6.824636347699947, 7.843045981926834, 8.854023993382462, 8.743695552589571, 9.805435243068727, 10.754673139503753, 11.680060057147593, 10.70617945496869, 9.678599667793403, 8.74142421400234, 7.772894452805519, 6.762914900005397, 5.835381088375682, 4.889234196720208, 3.9368327954625646, 2.9463138239244033, 2.0173548755892794, 2.9859395842487935, 3.9651771069465984, 4.89251010783159, 5.927692285638177, 6.979778067491065, 7.793352493328896, 7.863063554833533, 8.877235603789352, 9.83841808038147, 10.845412558289045, 9.977485366713982, 8.908747361850768, 7.9671258006554115, 6.9200299025377365, 5.91006423681441, 4.936775245676378, 3.8698105120603943, 2.9407028889893443, 2.0372938672905843, 1.0036857071144958, 2.033459660819755, 2.987638808076471, 4.007403751540961, 4.951830348238282, 5.960222641794673, 6.863922163566055, 6.954799493998744, 7.95525849341528, 8.951510587293306, 9.961388090259215, 9.1356716618593, 8.085676632243432, 7.1063721355809655, 6.038994241265495, 4.971644279560469, 4.006643395335157, 3.050042341975642, 2.0087734830237296, 1.0548688768711467, 0.0, 1.0502457217638408, 2.021242886671981, 2.9508294867726197, 3.8897848111246427, 4.940839026281824, 5.9268359336915095, 7.924218634635618, 8.975855287863178, 9.969555971022615, 10.719442722560261, 9.772178405066292, 8.767633872571476, 7.831352775340838, 6.804094585956122, 5.839523949936617, 4.899574619612539, 3.966452734441434, 2.9061135932560207, 1.9674667577232903, 1.0280681526655573, 1.9761195268481662, 2.9637967533072893, 3.891514336002854, 4.961150122123675, 5.929253859926813, 6.8942745371765914, 8.862298337395844, 9.867437412658035, 10.83814104601846, 11.60791874089844, 10.650029858304563, 9.639149970790339, 8.666006039566232, 7.723871245961816, 6.680393357954602, 5.7497384225351205, 4.772530883626315, 3.8473574248892723, 2.9083971898104046, 1.9617886494798733, 2.9487752417128004, 3.9259144577716967, 4.865297893073608, 5.939556521423127, 6.964249688265861, 7.87496306235962, 9.72635136483368, 10.761023898657289, 11.705143564740215, 12.58444054451185, 11.583772505596976, 10.635239439518934, 9.566779407803216, 8.575236607115652, 7.609357155231701, 6.710446784286492, 5.7479206846856, 4.878633544506118, 3.932417774340567, 3.0334459735469173, 3.906008471002938, 4.8568170176980425, 5.8293474863016215, 6.840969562428674, 7.805914410282662, 8.783966563845903, 10.652236130554805, 11.580189242500447, 12.598082116975391, 13.560188722917056, 12.512800997043321, 11.443053229362096, 10.510390094831024, 9.564944307059118, 8.560121160861705, 7.67913962085165, 6.699270242983128, 5.933602583255403, 5.0021018104902275, 4.087751439159824, 4.866669902809675, 5.8158621681943234, 6.768146246040018, 7.694960074553361, 8.669213386978388, 9.696630752161889, 11.645893111123154, 12.5497528254228, 13.603137819899533, 14.516021354718948, 13.450712566561172, 12.440961011184468, 11.457652061653443, 10.554335018216655, 9.58531830217337, 8.681487508654108, 7.748737694049224, 6.8611398454001264, 6.048343082200745, 5.153464784781047, 5.897815389834925, 6.886942996739049, 7.790276307874747, 8.700562809783463, 9.655545797100066, 10.625115152347632, 12.558271463539516, 13.49002039499665, 14.510602738286824, 15.459142613346, 14.385889441144073, 13.3712273225721, 12.42257559897242, 11.508081180743392, 10.572290012140538, 9.612611967278156, 8.808189615765299, 7.841714304777466, 6.984528808156369, 6.2019307387810025, 6.83375827072849, 7.858023214787802, 8.84173072172647, 9.751459612035665, 10.634225573508848, 11.580795014042803, 13.531153414440753, 14.472678795286313, 15.513557061756895, 15.408298087340018, 14.572396145179292, 13.576349887255526, 12.902888516203046, 12.488481702897834, 11.636418911592163, 10.674727654619774, 9.779508667381856, 8.869682923864161, 8.008622211430929, 7.225951222380138, 7.797924367573627, 8.78393116790019, 9.79808387852585, 10.713724877648133, 11.657630656937258, 12.635903164620753, 14.590398046783937, 15.506901316528987, 15.521486303932608, 14.477427772127193, 13.57664731924241, 12.64432351753594, 11.928824596136138, 12.897853687803382, 12.69646372700013, 11.67988345936785, 10.782924523932543, 9.853256332558079, 8.945920063961456, 8.300831469318108, 8.749363261513652, 9.741936408855057, 10.721560721892224, 11.680517354125744, 12.676730330801378, 13.64382045607071, 15.59073271683703, 15.541496811487391, 14.563589936055473, 13.504761869220067, 12.57289987730704, 11.569519879972178, 10.924113859955051, 11.934507071826705, 12.906950922710424, 12.678957195331002, 11.736489159219222, 10.864985474177212, 9.904461000835278, 9.244849600024478, 9.76416603632074, 10.714872771302902, 11.720859642306856, 12.6996931194562, 13.64781082121947, 14.62303423547636, 15.67093072736387, 14.61027747713661, 13.582393511604236, 12.635372986978767, 11.59154069345788, 10.596305540362897, 9.850257308419271, 10.872074091195929, 11.87710583119466, 12.80752726341659, 12.75233805841599, 11.876946411323354, 10.83594276396483, 10.252999839766103, 10.803708505562408, 11.667738473966022, 12.618900835006471, 13.674603946069464, 14.575056128980338, 15.521009476835971, 14.693728326191298, 13.674693779426688, 12.651305576797549, 11.668687089310138, 10.643658070895627, 9.66917334318583, 8.876689813910586, 9.896018919033917, 10.897468121707515, 11.802309528225816, 12.820441393855695, 12.793783159072486, 11.848773036019905, 11.304226312074457, 11.783332710769924, 12.623208590471958, 13.640922700442657, 14.581775029886051, 15.52634194622041, 15.647367026026608, 13.682501428298083, 12.670816442562908, 11.710164477896992, 10.732544214715771, 9.784249032611754, 8.726857441923656, 7.94176999376447, 8.925419286254982, 9.867174691740482, 10.729390870742883, 11.800958020608157, 12.825703973218701, 12.776747854966356, 12.279642966199438, 12.725627904623058, 13.591750947325568, 14.581016286411808, 15.593761913497111, 15.685000457143921, 14.720528585304764], [12.708104051322955, 13.664787379014781, 14.502278511250125, 14.612398724697648, 13.596143961819257, 12.716187286425052, 13.722699378670535, 13.700846842734538, 12.761189705535438, 11.75363283930066, 10.706497406445592, 9.873855970182262, 8.822290075037381, 7.813897642101573, 6.825855783896288, 7.814333404017184, 8.771718882990776, 9.79609148021905, 10.782399490307846, 11.809137086657952, 11.689198273676379, 12.609483033024757, 13.511765632946123, 14.460302854149814, 14.626173390998416, 13.695389204742307, 13.659266519051386, 12.757406524935757, 11.705643899142348, 10.716825242112833, 9.763429553682954, 8.8115761813692, 7.86786122419147, 6.8514340517742, 5.898727788325633, 6.871560773541418, 7.8853900842548486, 8.813711928919027, 9.734309494475317, 10.779434741628567, 10.645475620642653, 11.575631579786867, 12.532391171615458, 13.498556891779112, 14.497397324586442, 13.581757062349402, 12.656536419715867, 11.704869696218623, 10.689206707436243, 9.76279712997078, 8.74258386021851, 7.81179087142934, 6.866259894951378, 5.9247339819945655, 4.950435208732803, 5.889068244258927, 6.832112118702877, 7.865904317800156, 8.80891134339215, 9.760740673063983, 9.627127575645368, 10.564541640665665, 11.587398986567445, 12.516008006072095, 13.55526751762147, 12.598427915658025, 11.649947138205453, 10.65883860380323, 9.67328825364495, 8.8636715804185, 7.891601335633192, 6.823426005608692, 5.90673700502337, 4.94418856466762, 3.9305292527912097, 4.974559581760087, 5.903078208200219, 6.838196284006928, 7.823077155047705, 8.773997087564654, 8.701551924221754, 9.650513544085278, 10.650427518719827, 11.67948334785995, 12.611206633037986, 11.707496102125965, 10.662198605101853, 9.721495205819979, 8.681162143520577, 7.797132944573804, 6.847492975185636, 5.884056305196141, 4.959380678527561, 3.9720353643324273, 2.951700006561627, 3.9739623830103605, 4.935671805218097, 5.864535154995298, 6.877214373184786, 7.803778271618621, 7.693449830825731, 8.755189521304887, 9.704427417739913, 10.629814335383752, 11.668643796417609, 10.6648935536734, 9.727718099882336, 8.759188338685515, 7.749208785885392, 6.821674974255677, 5.875528082600203, 4.92312668134256, 3.932607709804399, 3.0036487614692753, 2.025838391544145, 3.00507591424195, 3.9194116744121787, 4.8774465638743365, 5.929532345727224, 6.743106771565055, 6.812817833069692, 7.8269898820255115, 8.78817235861763, 9.795166836525205, 10.864059902174471, 9.958993083614608, 9.017371522419252, 7.970275624301577, 6.96030995857825, 5.987020967440218, 4.920056233824234, 3.990948610753185, 3.0875395890544253, 2.053931428878337, 1.0733584681151067, 2.025056349963914, 2.957158029777121, 3.901584626474441, 4.909976920030832, 5.8136764418022135, 5.9045537722349035, 6.90501277165144, 7.901264865529465, 8.911142368495375, 9.882698843477982, 9.135922354007272, 8.156617857344806, 7.0892399630293355, 6.0218900013243095, 5.056889117098997, 4.100288063739483, 3.05901920478757, 2.1051145986349873, 1.0502457217638408, 0.0, 0.9709971649081405, 1.9005837650087791, 2.8395390893608017, 3.8905933045179832, 4.8765902119276685, 6.8739729128717775, 7.925609566099338, 8.919310249258775, 9.8473478404368, 10.699295226392037, 9.694750693897221, 8.758469596666583, 7.731211407281867, 6.766640771262361, 5.8266914409382835, 4.893569555767178, 3.833230414581765, 2.8945835790490344, 1.9551849739913014, 0.9258738050843254, 1.9135510315434487, 2.841268614239013, 3.910904400359834, 4.879008138162972, 5.84402881541275, 7.812052615632003, 8.817191690894195, 9.78789532425462, 10.769020400753814, 11.577146679630308, 10.566266792116084, 9.593122860891977, 8.65098806728756, 7.607510179280347, 6.676855243860865, 5.699647704952059, 4.774474246215016, 3.8355140111361488, 2.8889054708056174, 1.920605709209648, 2.875668736007856, 3.8150521713097674, 4.889310799659286, 5.914003966502019, 6.824717340595779, 8.67610564306984, 9.710778176893449, 10.654897842976375, 11.724263504167606, 12.51088932692272, 11.562356260844677, 10.493896229128959, 9.502353428441396, 8.536473976557446, 7.637563605612236, 6.6750375060113445, 5.805750365831862, 4.859534595666311, 3.9435505009415914, 2.877838938499785, 3.8286474851948897, 4.7791017645377805, 5.790723840664833, 6.755668688518821, 7.733720842082062, 9.601990408790963, 10.529943520736605, 11.547836395211549, 12.586456152729745, 13.439917818369064, 12.37017005068784, 11.437506916156767, 10.492061128384861, 9.487237982187448, 8.606256442177395, 7.626387064308872, 6.860719404581147, 5.879053985059561, 4.873444229686296, 3.8385003703065226, 4.7876926356911715, 5.717900524276177, 6.64471435278952, 7.618967665214546, 8.646385030398047, 10.595647389359312, 11.499507103658958, 12.552892098135692, 13.619763046207922, 14.377829387886916, 13.368077832510211, 12.384768882979186, 11.481451839542398, 10.512435123499113, 9.608604329979853, 8.675854515374967, 7.788256666725871, 6.925295256770079, 5.939157575307519, 4.869645857331772, 5.858773464235897, 6.740030586110905, 7.650317088019622, 8.605300075336224, 9.57486943058379, 11.508025741775674, 12.439774673232808, 13.460357016522982, 14.428476516281835, 14.583120966549792, 13.669000313979703, 13.349692420298163, 12.435198002069136, 11.499406833466281, 10.539728788603899, 9.735306437091042, 8.76883112610321, 7.844307213028719, 6.829522292322487, 5.805588738225337, 6.829853682284649, 7.794286535568356, 8.701213890271823, 9.583979851745006, 10.53054929227896, 12.480907692676912, 13.422433073522472, 14.463311339993053, 14.448196894635371, 13.612294952474645, 12.61624869455088, 13.522730224629395, 13.415598524223578, 12.563535732917906, 11.601844475945517, 10.7066254887076, 9.787192725074865, 8.764465186893828, 7.69655428272273, 6.769754835070474, 7.755761635397038, 8.769914346022697, 9.663479155884291, 10.607384935173416, 11.585657442856911, 13.540152325020095, 14.456655594765145, 14.561385111227962, 13.517326579422546, 12.616546126537763, 11.684222324831293, 12.548666304562488, 13.530213039160222, 13.623580548325874, 12.607000280693594, 11.710041345258286, 10.732583285083553, 9.701763039424357, 8.719338843131286, 7.7211937290104995, 8.713766876351905, 9.693391189389072, 10.652347821622591, 11.626484609037536, 12.593574734306868, 14.540486995073188, 14.581395618782745, 13.603488743350827, 12.54466067651542, 11.612798684602394, 10.609418687267532, 11.543955568381403, 12.566866423183544, 13.539310274067264, 13.606074016656745, 12.642961263684967, 11.620828449640113, 10.660303976298179, 9.663356973837656, 8.735996503817587, 9.68670323879975, 10.692690109803703, 11.671523586953047, 12.597565099455629, 13.572788513712519, 14.710829534659224, 13.650176284431963, 12.62229231889959, 11.67527179427412, 10.631439500753233, 9.63620434765825, 10.58049254598862, 11.602309328765276, 12.607341068764008, 13.537762500985938, 13.595522127155197, 12.632789386786255, 11.591785739427731, 10.67150721357928, 9.775538973059255, 10.63956894146287, 11.590731302503318, 12.646434413566311, 13.524810407216496, 14.470763755072129, 13.73362713348665, 12.714592586722041, 11.691204384092902, 10.708585896605491, 9.68355687819098, 8.709072150481184, 9.676864053647494, 10.732443002420373, 11.733892205093971, 12.741457098021638, 13.80673527973569, 13.549626134535387, 12.604616011482806, 11.722733685887635, 10.755163178266772, 11.595039057968805, 12.612753167939504, 13.553605497382899, 14.498172413717258, 14.597121304262767, 12.722400235593435, 11.710715249858259, 10.750063285192343, 9.772443022011123, 8.824147839907106, 7.766756249219008, 8.741944233501378, 9.761843369641438, 10.703598775126938, 11.715684756622878, 12.787251906488152, 13.811997859098696, 13.532590830429257, 12.698150340012615, 11.697458372119906, 12.563581414822416, 13.552846753908655, 14.565592380993959, 14.634754735380081, 13.670282863540924], [11.737106886414814, 12.69379021410664, 13.531281346341984, 13.960192359042285, 12.943937596163893, 13.687184451333193, 14.693696543578676, 14.635726706931921, 13.69606956973282, 12.688512703498041, 11.641377270642975, 10.808735834379643, 9.757169939234764, 8.748777506298955, 7.76073564809367, 7.1507539250662475, 7.895166598661744, 8.91953919589002, 9.811402325399705, 10.83813992174981, 10.718201108768238, 11.638485868116616, 12.540768468037982, 13.489305689241673, 13.973967025343052, 14.666386369650448, 14.594146383248768, 13.692286389133141, 12.640523763339731, 11.651705106310215, 10.698309417880337, 9.746456045566582, 8.802741088388853, 7.786313915971582, 6.833607652523015, 6.144873120517611, 6.96971892117244, 7.898040765836618, 8.763312329567176, 9.808437576720426, 9.674478455734512, 10.604634414878726, 11.561394006707317, 12.52755972687097, 13.526400159678301, 14.516636926546784, 13.591416283913249, 12.639749560416005, 11.624086571633626, 10.697676994168162, 9.677463724415892, 8.746670735626722, 7.801139759148761, 6.859613846191947, 5.885315072930185, 5.162380591235118, 5.896784654652656, 6.930576853749935, 7.837914178484009, 8.789743508155842, 8.656130410737227, 9.593544475757524, 10.616401821659304, 11.545010841163954, 12.584270352713329, 13.533307779855408, 12.584827002402836, 11.593718468000613, 10.608168117842332, 9.798551444615882, 8.826481199830575, 7.758305869806074, 6.841616869220752, 5.879068428865002, 4.865409116988592, 4.1513043226487385, 4.967750744149997, 5.902868819956707, 6.852079990139565, 7.802999922656513, 7.730554759313613, 8.679516379177137, 9.679430353811686, 10.708486182951809, 11.640209468129845, 12.642375966323348, 11.597078469299236, 10.656375070017361, 9.61604200771796, 8.732012808771186, 7.782372839383019, 6.818936169393524, 5.894260542724943, 4.90691522852981, 3.8865798707590096, 3.090159460542951, 3.9686548823961827, 4.897518232173384, 5.9062172082766455, 6.832781106710481, 6.72245266591759, 7.784192356396747, 8.733430252831772, 9.658817170475611, 10.697646631509468, 11.599773417870782, 10.662597964079719, 9.694068202882898, 8.684088650082774, 7.756554838453059, 6.810407946797586, 5.858006545539943, 4.867487574001782, 3.938528625666658, 2.9607182557415275, 2.1212729917745405, 2.948414509504038, 3.906449398966196, 4.958535180819084, 5.772109606656914, 5.841820668161552, 6.855992717117371, 7.817175193709489, 8.824169671617064, 9.89306273726633, 10.92999024852275, 9.988368687327393, 8.941272789209718, 7.931307123486391, 6.958018132348359, 5.8910533987323745, 4.9619457756613246, 4.058536753962565, 3.024928593786477, 2.0082383323124895, 1.0540591850557735, 1.9861608648689801, 2.930587461566301, 3.938979755122692, 4.842679276894073, 4.9335566073267625, 5.934015606743299, 6.930267700621324, 7.940145203587233, 8.91170167856984, 9.961696708185707, 9.127615022252947, 8.060237127937476, 6.9928871662324505, 6.027886282007138, 5.071285228647623, 4.03001636969571, 3.076111763543128, 2.021242886671981, 0.9709971649081405, 0.0, 0.9295866001006385, 1.8685419244526613, 2.919596139609843, 3.9055930470195284, 5.902975747963636, 6.954612401191197, 7.948313084350634, 8.87635067552866, 9.823614993022629, 10.665747858805362, 9.729466761574724, 8.702208572190008, 7.737637936170502, 6.7976886058464245, 5.864566720675319, 4.804227579489906, 3.865580743957175, 2.926182138899442, 1.8968709699924657, 1.0284214219852408, 1.9561390046808051, 2.9399072354516935, 3.9080109732548323, 4.87303165050461, 6.841055450723862, 7.8461945259860535, 8.81689815934648, 9.798023235845672, 10.755912118439548, 11.537263957024225, 10.564120025800118, 9.621985232195701, 8.578507344188488, 7.647852408769006, 6.6706448698602, 5.745471411123157, 4.80651117604429, 3.859902635713758, 2.8916028741177886, 1.9905391264496481, 2.9299225617515594, 3.9341951466267577, 4.944907717059022, 5.853720175687639, 7.790976033511633, 8.825648567335241, 9.769768233418166, 10.825768090566946, 11.68965476573196, 12.533353425752818, 11.4648933940371, 10.473350593349537, 9.507471141465587, 8.608560770520377, 7.6460346709194855, 6.776747530740003, 5.830531760574452, 4.9145476658497325, 3.848836103407926, 3.053248771590815, 3.8939721549795725, 4.905594231106625, 5.870539078960613, 6.848591232523854, 8.716860799232755, 9.644813911178398, 10.662706785653342, 11.70132654317154, 12.729224428980046, 13.34116721559598, 12.408504081064908, 11.463058293293003, 10.45823514709559, 9.577253607085536, 8.597384229217013, 7.831716569489288, 6.850051149967701, 5.844441394594436, 4.809497535214663, 4.0295970514929715, 4.832770914717969, 5.759584743231311, 6.733838055656338, 7.761255420839839, 9.710517779801105, 10.61437749410075, 11.667762488577484, 12.734633436649716, 13.746646056820959, 14.339074997418352, 13.355766047887327, 12.45244900445054, 11.483432288407254, 10.579601494887994, 9.646851680283108, 8.759253831634012, 7.896292421678218, 6.910154740215658, 5.840643022239913, 5.100677880037697, 5.854900976552697, 6.765187478461414, 7.720170465778016, 8.689739821025581, 10.622896132217466, 11.5546450636746, 12.575227406964775, 13.543346906723627, 14.167519281710645, 14.603880178177084, 14.320689585206305, 13.406195166977277, 12.470403998374422, 11.51072595351204, 10.706303601999183, 9.739828291011353, 8.81530437793686, 7.800519457230628, 6.776585903133478, 6.108316352245211, 6.909156926010149, 7.816084280713615, 8.698850242186799, 9.645419682720753, 11.595778083118704, 12.537303463964264, 13.578181730434846, 13.906944744797562, 13.196693267635498, 13.55112855874826, 14.457610088826776, 14.386595689131719, 13.534532897826047, 12.572841640853659, 11.67762265361574, 10.758189889983006, 9.735462351801969, 8.66755144763087, 7.740751999978615, 7.0342243053576, 7.925920162479514, 8.778349546326083, 9.722255325615208, 10.700527833298704, 12.655022715461888, 13.571525985206938, 13.819530571959332, 12.976074429584736, 12.1707648931022, 12.619102189028673, 13.483546168759869, 14.465092903357602, 14.594577713234015, 13.577997445601735, 12.681038510166427, 11.703580449991694, 10.672760204332498, 9.690336008039427, 8.69219089391864, 8.061560510696541, 8.92714278698432, 9.82571657411374, 10.741354999479329, 11.70844512474866, 13.65535738551498, 13.726438572905016, 12.861634204082197, 12.00340852667761, 11.167017451166831, 11.544298551464912, 12.478835432578784, 13.501746287380925, 14.474190138264644, 14.577071181564886, 13.613958428593108, 12.591825614548254, 11.63130114120632, 10.634354138745797, 9.706993668725728, 9.034496873144386, 9.92644170739895, 10.844892339444195, 11.712435489897421, 12.687658904154311, 13.784708553009544, 12.795219238554234, 11.876486633849305, 10.929466109223837, 10.18565826731767, 10.57108421185563, 11.515372410186, 12.537189192962657, 13.542220932961389, 14.472642365183319, 14.566519292063338, 13.603786551694396, 12.562782904335872, 11.642504378487422, 10.746536137967396, 9.987362575807506, 10.881623614934174, 11.870026878771105, 12.639680797658288, 13.585634145513922, 12.771850648404204, 11.816236986637914, 10.883648465393737, 9.925445185153716, 9.122065685276791, 9.643952014678565, 10.611743917844876, 11.667322866617756, 12.668772069291354, 13.676336962219022, 14.741615143933075, 14.520623299443528, 13.575613176390947, 12.693730850795776, 11.726160343174913, 10.942832692313441, 11.90364548037036, 12.844497809813754, 13.658952481200362, 13.626124139354626, 11.76062375051099, 10.748938764775813, 9.873511000863312, 8.924474779722702, 8.16056836095617, 8.70163611341639, 9.676824097698761, 10.69672323383882, 11.63847863932432, 12.650564620820262, 13.722131770685536, 14.74687772329608, 14.503587995337398, 13.669147504920756, 12.668455537028047, 11.911375049167052, 12.900640388253292, 13.856484693424814, 13.66375757047194, 12.699285698632783], [10.807520286314176, 11.764203614006002, 12.601694746241346, 13.16873890535886, 13.78168242512839, 14.616771051433831, 15.623283143679314, 15.56531330703256, 14.62565616983346, 13.618099303598683, 12.570963870743615, 11.738322434480285, 10.686756539335404, 9.678364106399595, 8.69032224819431, 7.905430121587893, 6.965579998561106, 7.989952595789381, 8.881815725299067, 9.908553321649173, 9.7886145086676, 10.708899268015978, 11.611181867937344, 12.559719089141035, 13.524466826221088, 14.5137014527309, 15.523732983349408, 14.621872989233779, 13.57011036344037, 12.581291706410855, 11.627896017980976, 10.676042645667222, 9.732327688489493, 8.715900516072223, 7.763194252623655, 6.899549317039256, 6.040132321071802, 6.96845416573598, 7.833725729466537, 8.878850976619788, 8.744891855633874, 9.675047814778088, 10.63180740660668, 11.597973126770333, 12.596813559577663, 13.609627203921079, 14.521002884013889, 13.569336160516645, 12.553673171734266, 11.627263594268802, 10.607050324516532, 9.676257335727362, 8.7307263592494, 7.789200446292587, 6.814901673030825, 5.9170567877567635, 4.967198054552018, 6.000990253649297, 6.90832757838337, 7.860156908055204, 7.7265438106365885, 8.663957875656886, 9.686815221558666, 10.615424241063316, 11.65468375261269, 12.680125711535398, 13.514413602503476, 12.523305068101253, 11.537754717942972, 10.728138044716522, 9.756067799931214, 8.687892469906714, 7.771203469321392, 6.808655028965642, 5.794995717089232, 4.966682770489491, 4.038164144049359, 4.973282219856069, 5.922493390038926, 6.873413322555874, 6.8009681592129745, 7.749929779076499, 8.749843753711048, 9.778899582851171, 10.710622868029207, 11.776431037944409, 12.526665069399876, 11.585961670118001, 10.5456286078186, 9.661599408871826, 8.711959439483659, 7.748522769494164, 6.823847142825581, 5.83650182863045, 4.816166470859649, 3.9150473790568014, 3.039068282295544, 3.9679316320727462, 4.9766306081760066, 5.903194506609842, 5.792866065816952, 6.854605756296109, 7.803843652731134, 8.729230570374973, 9.76806003140883, 10.795639818584117, 11.592184564180359, 10.623654802983538, 9.613675250183414, 8.6861414385537, 7.739994546898226, 6.787593145640582, 5.797074174102421, 4.868115225767297, 3.8903048558421665, 2.9461609102883908, 2.0188279094033996, 2.976862798865557, 4.028948580718445, 4.842523006556275, 4.912234068060913, 5.926406117016732, 6.88758859360885, 7.894583071516426, 8.963476137165692, 10.032214142028906, 10.91795528742803, 9.870859389310356, 8.86089372358703, 7.887604732448997, 6.8206399988330135, 5.8915323757619635, 4.988123354063204, 3.954515193887116, 2.937824932413128, 1.983645785156412, 1.0565742647683416, 2.001000861465662, 3.009393155022053, 3.9130926767934344, 4.003970007226124, 5.004429006642661, 6.000681100520686, 7.0105586034865945, 7.982115078469201, 9.03211010808507, 10.011414604747536, 8.989823728038115, 7.922473766333089, 6.957472882107776, 6.000871828748262, 4.959602969796349, 4.005698363643766, 2.95082948677262, 1.9005837650087791, 0.9295866001006385, 0.0, 0.9389553243520228, 1.9900095395092046, 2.9760064469188894, 4.973389147862998, 6.025025801090559, 7.018726484249996, 7.946764075428021, 8.89402839292199, 9.898572925416806, 10.659053361675364, 9.631795172290648, 8.667224536271142, 7.7272752059470635, 6.794153320775958, 5.733814179590545, 4.795167344057814, 3.855768739000081, 2.8264575700931047, 1.9580080220858793, 1.05814967455765, 2.0103206353510554, 2.978424373154194, 3.9434450504039713, 5.911468850623224, 6.916607925885415, 7.88731155924584, 8.868436635745034, 9.82632551833891, 10.837205405853135, 11.493706625900757, 10.55157183229634, 9.508093944289126, 8.577439008869645, 7.600231469960839, 6.675058011223796, 5.736097776144929, 4.789489235814397, 3.8211894742184276, 2.9201257265502867, 2.0608450196177515, 3.0046085465261196, 4.015321116958384, 4.924133575587, 6.883223109247138, 7.917895643070745, 8.86201530915367, 9.896181490466308, 10.760068165631322, 11.733696035267446, 12.394479994137738, 11.402937193450175, 10.437057741566225, 9.538147370621017, 8.575621271020124, 7.706334130840642, 6.760118360675091, 5.844134265950371, 4.778422703508565, 3.9828353716914533, 3.0248946128457646, 4.035318168309682, 5.00026301616367, 5.940838308259359, 7.826730934445776, 8.754684046391418, 9.772576920866362, 10.811196678384558, 11.799637828879408, 12.68972971081539, 13.338090681165546, 12.39264489339364, 11.387821747196227, 10.506840207186174, 9.526970829317651, 8.761303169589928, 7.77963775006834, 6.774027994695075, 5.739084135315302, 4.95918365159361, 3.9636933725841614, 4.890507201097504, 5.864760513522531, 6.871125556052861, 8.820387915014125, 9.724247629313771, 10.777632623790504, 11.844503571862735, 12.81705945672032, 13.748743630390756, 14.285352647987965, 13.382035604551177, 12.413018888507892, 11.509188094988632, 10.576438280383746, 9.688840431734652, 8.825879021778858, 7.839741340316298, 6.770229622340551, 5.938422709002193, 4.985823434418889, 5.896109936327607, 6.851092923644209, 7.820662278891775, 9.75381859008366, 10.66451519888762, 11.685097542177795, 12.653217041936648, 13.726470214138574, 14.694785502533573, 15.250276185306943, 14.335781767077915, 13.39999059847506, 12.440312553612678, 11.635890202099821, 10.669414891111993, 9.744890978037498, 8.730106057331266, 7.706172503234116, 6.946061181209707, 6.040079383876341, 6.947006738579808, 7.829772700052992, 8.776342140586946, 10.726700540984897, 11.668225921830457, 12.688051865647866, 12.977358144696924, 13.902719640681955, 14.4807151588489, 15.387196688927418, 15.316182289232357, 14.464119497926685, 13.502428240954297, 12.607209253716379, 11.687776490083644, 10.665048951902607, 9.597138047731509, 8.670338600079253, 7.871969134322096, 7.056842620345706, 7.909272004192276, 8.853177783481401, 9.831450291164897, 11.78594517332808, 12.70244844307313, 12.889943971858694, 12.046487829484098, 12.925441089623844, 13.548688789129313, 14.41313276886051, 15.394679503458242, 15.524164313334653, 14.507584045702373, 13.610625110267065, 12.633167050092332, 11.602346804433136, 10.619922608140065, 9.621777494019279, 8.899305339661037, 8.05806524485051, 8.956639031979932, 9.872277457345522, 10.839367582614853, 12.786279843381173, 12.796851972804378, 11.932047603981559, 11.073821926576972, 11.921693647688475, 12.473885151565552, 13.408422032679423, 14.431332887481565, 15.403776738365284, 15.506657781665524, 14.543545028693746, 13.521412214648892, 12.560887741306958, 11.563940738846435, 10.636580268826366, 9.872241702108882, 9.057364165265142, 9.975814797310388, 10.843357947763614, 11.818581362020504, 12.855121952908906, 11.865632638453596, 10.946900033748667, 9.999879509123199, 10.940334463839314, 11.50067081195627, 12.44495901028664, 13.466775793063297, 14.471807533062028, 15.402228965283959, 15.496105892163976, 14.533373151795034, 13.49236950443651, 12.57209097858806, 11.676122738068035, 10.825107404772002, 10.012546072800365, 11.000949336637298, 11.770603255524481, 12.716556603380115, 11.842264048303566, 10.886650386537276, 9.954061865293099, 8.995858585053078, 9.876741881798434, 10.573538614779205, 11.541330517945516, 12.596909466718396, 13.598358669391994, 14.60592356231966, 15.671201744033713, 15.450209899544166, 14.505199776491585, 13.623317450896414, 12.65574694327555, 11.780577521277937, 11.03456793823655, 11.975420267679945, 12.789874939066555, 12.696537539253988, 10.831037150410351, 9.819352164675175, 8.943924400762674, 7.994888179622063, 8.915244557477813, 9.63122271351703, 10.6064106977994, 11.62630983393946, 12.56806523942496, 13.5801512209209, 14.651718370786174, 15.676464323396718, 15.433174595438036, 14.598734105021395, 13.598042137128685, 12.749119878131548, 12.109186934569866, 12.987407151291006, 12.734170970371302, 11.769699098532145], [9.868564961962154, 10.82524828965398, 11.662739421889324, 12.653614563361906, 13.615540931048224, 14.553948046696132, 15.58129186031411, 16.504268631384583, 15.564611494185483, 14.557054627950706, 13.509919195095637, 12.677277758832307, 11.625711863687425, 10.617319430751616, 9.62927757254633, 8.831557649990698, 7.891707526963911, 7.157418802326246, 7.942860400947044, 8.96959799729715, 8.849659184315577, 9.769943943663955, 10.672226543585321, 11.620763764789013, 12.585511501869066, 13.574746128378877, 14.638174832877139, 15.560828313585802, 14.509065687792393, 13.520247030762878, 12.566851342332999, 11.614997970019244, 10.671283012841513, 9.654855840424243, 8.702149576975676, 7.825676845442061, 6.966259849474607, 6.127093965861966, 6.894770405114515, 7.939895652267764, 7.805936531281851, 8.736092490426065, 9.692852082254657, 10.65901780241831, 11.65785823522564, 12.670671879569056, 13.69624044614636, 14.508291484868668, 13.492628496086288, 12.566218918620825, 11.546005648868555, 10.615212660079385, 9.669681683601423, 8.728155770644609, 7.753856997382847, 6.843184316159569, 5.893325582954823, 5.113692120836697, 5.969372254031348, 6.921201583703182, 6.787588486284566, 7.725002551304863, 8.747859897206643, 9.676468916711293, 10.715728428260668, 11.741170387183375, 12.689651164635947, 13.462260392453276, 12.476710042294995, 11.667093369068544, 10.695023124283237, 9.626847794258737, 8.710158793673415, 7.747610353317665, 6.733951041441254, 5.892810298892297, 4.964291672452164, 4.08598408704347, 4.983538065686903, 5.934457998203851, 5.862012834860952, 6.810974454724477, 7.810888429359025, 8.839944258499148, 9.771667543677184, 10.837475713592386, 11.838535684884762, 12.524916994470024, 11.484583932170622, 10.600554733223849, 9.650914763835681, 8.687478093846186, 7.762802467177604, 6.775457152982472, 5.7551217952116716, 4.854002703408824, 3.96519581069835, 3.0363324609211477, 4.037675283823984, 4.96423918225782, 4.853910741464929, 5.915650431944086, 6.864888328379111, 7.790275246022951, 8.829104707056807, 9.856684494232095, 10.793859948023158, 11.56261012733556, 10.552630574535437, 9.625096762905722, 8.678949871250248, 7.726548469992604, 6.736029498454443, 5.807070550119319, 4.829260180194189, 3.8851162346404133, 2.957783233755422, 2.0379074745135344, 3.089993256366422, 3.903567682204253, 3.9732787437088906, 4.98745079266471, 5.948633269256828, 6.955627747164403, 8.02452081281367, 9.093258817676883, 10.03488037887224, 10.809814713662378, 9.799849047939052, 8.82656005680102, 7.759595323185036, 6.830487700113986, 5.927078678415227, 4.8934705182391385, 3.8767802567651506, 2.9226011095084345, 1.9955295891203644, 1.0620455371136392, 2.0704378306700306, 2.974137352441412, 3.0650146828741014, 4.065473682290637, 5.061725776168663, 6.071603279134571, 7.043159754117178, 8.093154783733045, 9.072459280395512, 9.928779052390137, 8.861429090685112, 7.896428206459799, 6.939827153100285, 5.898558294148372, 4.944653687995789, 3.8897848111246427, 2.8395390893608017, 1.8685419244526613, 0.9389553243520228, 0.0, 1.0510542151571818, 2.037051122566867, 4.034433823510976, 5.086070476738535, 6.079771159897972, 7.007808751075997, 7.955073068569966, 8.959617601064782, 9.89589869829542, 10.570750496642669, 9.606179860623163, 8.666230530299085, 7.733108645127981, 6.672769503942567, 5.734122668409837, 4.7947240633521035, 3.7654128944451273, 2.896963346437902, 1.9971049989096727, 1.0713653109990324, 2.039469048802171, 3.0044897260519488, 4.972513526271201, 5.977652601533393, 6.948356234893818, 7.929481311393012, 8.887370193986888, 9.898250081501113, 10.871394012725219, 11.490527156648362, 10.447049268641148, 9.516394333221667, 8.539186794312862, 7.614013335575819, 6.675053100496951, 5.72844456016642, 4.76014479857045, 3.8590810509023092, 2.9998003439697745, 2.0656532221740966, 3.0763657926063606, 3.985178251234977, 5.944267784895115, 6.978940318718722, 7.923059984801648, 8.957226166114285, 9.8211128412793, 10.794740710915423, 11.863200742631141, 12.341892517802197, 11.376013065918247, 10.47710269497304, 9.514576595372146, 8.645289455192666, 7.6990736850271135, 6.783089590302394, 5.717378027860588, 4.921790696043476, 3.9638499371977876, 3.0963628439576585, 4.061307691811646, 5.001882983907336, 6.887775610093754, 7.815728722039396, 8.83362159651434, 9.872241354032536, 10.860682504527386, 11.750774386463368, 12.68343752099444, 13.331600217745663, 12.32677707154825, 11.445795531538197, 10.465926153669674, 9.70025849394195, 8.718593074420362, 7.7129833190470976, 6.678039459667325, 5.898138975945632, 4.902648696936184, 4.1290142408744686, 4.996660614919778, 5.932170231700838, 7.881432590662103, 8.785292304961748, 9.838677299438482, 10.905548247510712, 11.878104132368298, 12.809788306038733, 13.630699487816859, 14.3209909289032, 13.351974212859915, 12.448143419340655, 11.515393604735769, 10.627795756086675, 9.764834346130879, 8.77869666466832, 7.709184946692574, 6.8773780333542165, 5.924778758770913, 5.134616976104571, 5.982993025041456, 6.935049550694368, 8.880775053777061, 9.725559874535598, 10.746142217825772, 11.714261717584625, 12.787514889786552, 13.75583017818155, 14.595623025135836, 15.274737091429937, 14.338945922827083, 13.3792678779647, 12.574845526451844, 11.608370215464015, 10.68384630238952, 9.669061381683289, 8.645127827586139, 7.8850165055617305, 6.979034708228364, 6.185513778356772, 6.961672801450239, 7.908242241984194, 9.853657004678299, 10.73631123421833, 11.749096541295843, 12.71055854781559, 13.63592004380062, 14.631966301724386, 15.59488943458842, 16.25513761358438, 15.403074822278708, 14.44138356530632, 13.546164578068401, 12.626731814435667, 11.60400427625463, 10.536093372083531, 9.609293924431276, 8.810924458674119, 7.995797944697729, 7.147779043969241, 8.028841140275524, 8.963350392562145, 10.912901637021482, 11.770533755461004, 12.085036000675883, 12.972615357886903, 13.851568618026649, 14.487644113481334, 15.35208809321253, 16.333634827810265, 16.463119637686674, 15.446539370054396, 14.549580434619088, 13.572122374444355, 12.541302128785158, 11.558877932492088, 10.560732818371301, 9.83826066401306, 8.997020569202535, 8.195146071756897, 9.047940814139645, 9.971267684012101, 11.913236307074575, 11.857896648452355, 11.127139632798748, 11.999949454979777, 12.84782117609128, 13.412840475917573, 14.347377357031444, 15.370288211833586, 16.342732062717307, 16.445613106017547, 15.482500353045769, 14.460367539000915, 13.49984306565898, 12.502896063198458, 11.575535593178389, 10.811197026460905, 9.996319489617166, 9.214321837087352, 10.019021304557738, 10.994244718814628, 11.916166628556883, 10.926677314101573, 10.141992062565857, 10.926007037526004, 11.866461992242119, 12.439626136308291, 13.38391433463866, 14.405731117415318, 15.41076285741405, 16.34118428963598, 16.435061216515997, 15.472328476147057, 14.431324828788533, 13.511046302940082, 12.615078062420057, 11.764062729124024, 10.95150139715239, 10.239456376414262, 10.946266612318604, 11.892219960174238, 10.903308723951543, 9.947695062185254, 9.121528071829964, 9.921986113455883, 10.80286941020124, 11.512493939131225, 12.480285842297537, 13.535864791070416, 14.537313993744014, 15.544878886671682, 16.610157068385735, 16.38916522389619, 15.444155100843608, 14.562272775248436, 13.594702267627573, 12.71953284562996, 11.973523262588575, 11.309336028612131, 11.965538295860679, 11.757582214901966, 9.892081826058329, 8.880396840323153, 8.111390607299539, 8.92101570802487, 9.841372085880618, 10.57017803786905, 11.545366022151422, 12.565265158291481, 13.507020563776981, 14.519106545272923, 15.590673695138197, 16.61541964774874, 16.37212991979006, 15.537689429373417, 14.536997461480707, 13.68807520248357, 13.04814225892189, 12.321322912223192, 11.79521564601928, 10.830743774180123], [8.817510746804972, 9.774194074496798, 10.611685206732144, 11.602560348204726, 12.564486715891043, 13.502893831538948, 14.530237645156927, 15.545121749884558, 16.484778887083657, 15.608108843107889, 14.56097341025282, 13.64780322307222, 12.581739708960713, 11.573347276024904, 10.585305417819619, 9.74130019925556, 8.783914720281969, 7.923910397323356, 6.9229842697145, 7.949721866064607, 7.798604969158396, 8.718889728506774, 9.62117232842814, 10.569709549631831, 11.534457286711884, 12.523691913221693, 13.587120617719956, 14.579116431513603, 15.560119902949577, 14.571301245920061, 13.617905557490182, 12.666052185176428, 11.627310858114802, 10.610883685697532, 9.658177422248965, 8.753744336412504, 7.858467042792665, 6.9301451981284865, 5.874894273881971, 6.92001952103522, 6.75488231612467, 7.685038275268885, 8.641797867097475, 9.607963587261128, 10.60680402006846, 11.619617664411873, 12.645186230989177, 13.66707474041612, 14.543682711243472, 13.617273133778008, 12.597059864025738, 11.666266875236568, 10.680158450355592, 9.684183615917897, 8.709884842656136, 7.771251807130012, 6.821393073925266, 5.964699092287228, 4.949496122798804, 5.901325452470638, 5.736534271127384, 6.6739483361476815, 7.696805682049461, 8.62541470155411, 9.664674213103485, 10.690116172026192, 11.638596949478764, 12.629705483880986, 13.527764257452178, 12.718147584225727, 11.74607733944042, 10.67790200941592, 9.761213008830596, 8.798664568474846, 7.785005256598436, 6.82087778986274, 5.892359163422608, 4.957241087615898, 3.963661934454359, 4.88340378304667, 4.81095861970377, 5.759920239567295, 6.759834214201843, 7.788890043341967, 8.720613328520002, 9.786421498435207, 10.78748146972758, 11.67364236119726, 12.535638147327806, 11.651608948381032, 10.701968978992864, 9.73853230900337, 8.813856682334787, 7.826511368139654, 6.806176010368853, 5.9050569185660065, 4.962104266578588, 4.033240916801386, 3.017799152591439, 3.913184967100638, 3.8028565263077474, 4.864596216786904, 5.813834113221929, 6.739221030865768, 7.7780504918996245, 8.805630279074911, 9.742805732865975, 10.711335494062796, 11.60368478969262, 10.676150978062905, 9.730004086407432, 8.777602685149787, 7.787083713611626, 6.858124765276502, 5.8803143953513715, 4.936170449797595, 4.008837448912604, 3.0348159303937723, 2.0701171251338772, 2.8525134670470713, 2.9222245285517086, 3.936396577507528, 4.897579054099646, 5.9045735320072215, 6.973466597656488, 8.042204602519702, 8.983826163715058, 10.030922061832733, 10.850903263096233, 9.877614271958201, 8.810649538342217, 7.881541915271168, 6.9781328935724085, 5.94452473339632, 4.927834471922333, 3.9736553246656166, 3.046583804277546, 2.058953992993877, 1.0505616994374858, 1.9230831372842299, 2.0139604677169194, 3.0144194671334557, 4.010671561011481, 5.0205490639773895, 5.992105538959996, 7.042100568575864, 8.021405065238332, 9.088782959553802, 9.912483305842294, 8.94748242161698, 7.990881368257466, 6.949612509305553, 5.9957079031529705, 4.940839026281824, 3.8905933045179837, 2.919596139609843, 1.9900095395092046, 1.0510542151571818, 0.0, 0.985996907409685, 2.9833796083537933, 4.035016261581354, 5.028716944740791, 5.956754535918815, 6.904018853412785, 7.908563385907601, 8.84484448313824, 9.872102672522956, 10.657234075780345, 9.717284745456267, 8.784162860285162, 7.723823719099749, 6.7851768835670185, 5.845778278509285, 4.816467109602309, 3.948017561595084, 3.0481592140668545, 2.0552324504622024, 0.9884148336449894, 1.953435510894767, 3.9214593111140186, 4.9265983863762095, 5.897302019736634, 6.8784270962358285, 7.836315978829704, 8.84719586634393, 9.820339797568035, 10.762474591172452, 11.498103483798332, 10.567448548378849, 9.590241009470043, 8.665067550733001, 7.726107315654133, 6.779498775323601, 5.811199013727632, 4.910135266059491, 4.0508545591269565, 3.0495203616372666, 2.0253115774491786, 2.9341240360777956, 4.8932135697379335, 5.927886103561541, 6.872005769644466, 7.906171950957102, 8.770058626122117, 9.74368649575824, 10.812146527473958, 11.803689328161521, 12.42706728107543, 11.528156910130221, 10.565630810529328, 9.696343670349847, 8.750127900184296, 7.834143805459576, 6.768432243017769, 5.972844911200658, 5.01490415235497, 4.056539425019542, 3.091594577165554, 3.9508287687501547, 5.836721394936572, 6.764674506882215, 7.782567381357158, 8.821187138875356, 9.809628289370202, 10.699720171306184, 11.632383305837257, 12.577829093609163, 13.377831286705433, 12.496849746695379, 11.516980368826855, 10.751312709099132, 9.769647289577545, 8.764037534204279, 7.729093674824506, 6.949193191102815, 5.928014641212054, 5.001200812698712, 4.026947500273685, 4.881116016543657, 6.830378375504922, 7.734238089804568, 8.787623084281302, 9.854494032353532, 10.827049917211115, 11.75873409088155, 12.579645272659675, 13.606795715447536, 14.403028428017098, 13.499197634497836, 12.56644781989295, 11.678849971243856, 10.815888561288062, 9.829750879825502, 8.760239161849755, 7.902743977630085, 6.950144703046782, 6.006803547928814, 5.013279910395363, 5.883995335537186, 7.829720838619878, 8.674505659378417, 9.69508800266859, 10.663207502427444, 11.73646067462937, 12.704775963024368, 13.544568809978653, 14.482243206076983, 15.390000137984266, 14.430322093121884, 13.625899741609025, 12.659424430621197, 11.734900517546702, 10.72011559684047, 9.69618204274332, 8.910382449837599, 8.004400652504232, 7.0325043055468806, 5.9919596868041465, 6.938529127338102, 8.802602789521117, 9.685257019061149, 10.698042326138662, 11.659504332658408, 12.58486582864344, 13.580912086567206, 14.54383521943124, 15.462643728231425, 16.417933619330036, 15.492437780463503, 14.597218793225583, 13.677786029592848, 12.655058491411811, 11.587147587240713, 10.660348139588457, 9.836290402949988, 9.009310297606005, 7.994769571159349, 7.059128025629432, 7.9936372779160525, 9.8618474218643, 10.719479540303823, 11.69269349257101, 12.590374647871233, 13.6034569363003, 14.512938456286793, 15.517899139498148, 16.422806272839843, 17.477978434738006, 16.49759358521158, 15.60063464977627, 14.623176589601535, 13.592356343942338, 12.60993214764927, 11.611787033528483, 10.863626608288929, 10.001093231180525, 9.042136598947005, 8.078227699493553, 9.001554569366009, 10.862182091917393, 10.838020517219812, 11.836921699255736, 12.872737071102087, 13.757563725356142, 14.368868321190861, 15.303405202304733, 16.326316057106872, 17.298759907990593, 17.49666732117473, 16.53355456820295, 15.511421754158095, 14.55089728081616, 13.55395027835564, 12.62658980833557, 11.836562970736773, 11.000392151595156, 10.034623729781407, 9.049308189911645, 10.024531604168535, 10.89629049732434, 9.90680118286903, 10.851774129022845, 11.798794653648313, 12.776204541506981, 13.39565398158158, 14.339942179911949, 15.361758962688606, 16.36679070268734, 17.29721213490927, 17.486115431673177, 16.523382691304235, 15.482379043945713, 14.562100518097264, 13.666132277577239, 12.789428673399893, 11.95557405913038, 11.025137359782446, 9.976553497672512, 10.922506845528146, 9.883432592719, 8.92781893095271, 9.831310138286952, 10.813928625774363, 11.712611959466102, 12.468521784404514, 13.436313687570825, 14.491892636343705, 15.493341839017303, 16.50090673194497, 17.572502990588912, 17.440219439053372, 16.49520931600079, 15.613326990405618, 14.645756482784755, 13.744898789905829, 12.88124442699234, 11.940392097548946, 10.995825181214586, 10.706527999744784, 8.872205694825785, 7.8605207090906095, 8.821172673756525, 9.813222901342927, 10.75111463514548, 11.526205883142339, 12.50139386742471, 13.52129300356477, 14.46304840905027, 15.508453897225477, 16.580021047090753, 17.458498543076395, 16.484205520286594, 15.554786683814847, 14.521622745844095, 13.597049262887884, 12.662112318993719, 11.60516254461352, 10.744161430862098, 9.779689559022941], [7.831513839395287, 8.788197167087112, 9.625688299322459, 10.61656344079504, 11.578489808481358, 12.516896924129263, 13.544240737747241, 14.559124842474873, 15.498781979673973, 16.395508871088754, 15.348373438233686, 14.406945936996296, 13.340882422884789, 12.33248998994898, 11.344448131743695, 10.500442913179636, 9.543057434206045, 8.683053111247432, 7.682126983638576, 7.054740601712431, 6.812608061748711, 7.732892821097089, 8.635175421018454, 9.583712642222146, 10.548460379302199, 11.537695005812008, 12.60112371031027, 13.593119524103917, 14.644882149897327, 15.358701273900927, 14.405305585471048, 13.445263511765898, 12.386453572038878, 11.370026399621608, 10.417320136173041, 9.51288705033658, 8.61760975671674, 7.689287912052563, 6.634036987806047, 5.995978993825186, 5.768885408714985, 6.699041367859199, 7.65580095968779, 8.621966679851443, 9.620807112658774, 10.633620757002188, 11.659189323579492, 12.681077833006436, 13.645177380420876, 14.44257765239235, 13.42236438264008, 12.49157139385091, 11.439301164279668, 10.443326329841973, 9.469027556580212, 8.530394521054088, 7.5805357878493425, 6.723841806211304, 5.70863883672288, 4.957946483569919, 4.750537363717699, 5.687951428737996, 6.7108087746397755, 7.639417794144426, 8.6786773056938, 9.704119264616507, 10.652600042069079, 11.643708576471301, 12.629258926629582, 13.605984317464046, 12.649128190348147, 11.580952860323647, 10.61704957922752, 9.65450113887177, 8.624050832755694, 7.580020503786816, 6.651501877346684, 5.716383801539974, 4.722804648378435, 3.897406875636985, 3.824961712294085, 4.77392333215761, 5.773837306792157, 6.8028931359322815, 7.734616421110316, 8.80042459102552, 9.801484562317894, 10.687645453787574, 11.66727149708842, 12.559222779355999, 11.609582809967831, 10.646146139978336, 9.721470513309754, 8.73412519911462, 7.71378984134382, 6.685924272727341, 5.724214850519605, 4.795351500742403, 3.776941866515516, 2.9271880596909527, 2.816859618898062, 3.8785993093772184, 4.827837205812243, 5.753224123456083, 6.792053584489939, 7.819633371665226, 8.75680882545629, 9.72533858665311, 10.735318139453234, 11.583764809037872, 10.637617917382398, 9.685216516124754, 8.694697544586592, 7.765738596251468, 6.787928226326337, 5.808690703628532, 4.88135770274354, 3.8538953823979054, 2.829259839057954, 1.866516559637386, 1.9362276211420233, 2.9503996700978425, 3.9115821466899607, 4.918576624597536, 5.987469690246803, 7.056207695110016, 7.997829256305373, 9.044925154423048, 10.054890820146374, 10.863611179367886, 9.796646445751902, 8.867538822680853, 7.960655088375572, 6.927046928199483, 5.897272974494224, 4.943093827237508, 3.919104058108482, 2.8780334449980103, 1.8696411514416185, 0.9370862298745448, 1.0279635603072346, 2.0284225597237704, 3.024674653601796, 4.034552156567704, 5.006108631550311, 6.056103661166179, 7.035408157828646, 8.102786052144115, 9.170136013849142, 9.933479329026666, 8.97687827566715, 7.935609416715239, 6.981704810562656, 5.9268359336915095, 4.8765902119276685, 3.905593047019528, 2.9760064469188894, 2.037051122566867, 0.985996907409685, 0.0, 1.9973827009441087, 3.0490193541716684, 4.042720037331105, 4.97075762850913, 5.918021946003099, 6.922566478497916, 7.858847575728555, 8.886105765113271, 9.850676401132777, 10.70328165286595, 9.770159767694846, 8.709820626509433, 7.771173790976704, 6.83177518591897, 5.802464017011994, 4.934014469004769, 4.034156121476539, 3.041229357871887, 1.9744117410546744, 0.9674386034850819, 2.935462403704334, 3.9406014789665256, 4.911305112326951, 5.892430188826145, 6.850319071420021, 7.861198958934246, 8.834342890158352, 9.776477683762769, 10.819955571769983, 11.553445455788534, 10.576237916879728, 9.651064458142686, 8.712104223063818, 7.765495682733286, 6.797195921137317, 5.8961321734691765, 5.036851466536641, 3.98758804352128, 2.962894876678547, 1.9481271286681103, 3.9072166623282483, 4.941889196151855, 5.886008862234781, 6.9201750435474185, 7.784061718712433, 8.757689588348557, 9.826149620064275, 10.817692420751838, 11.748919369047082, 12.514153817539906, 11.551627717939013, 10.682340577759533, 9.736124807593981, 8.82014071286926, 7.7544291504274545, 6.903764339607272, 5.919450938884751, 4.9078288627576985, 3.9428840149037105, 2.9648318613404694, 4.850724487526887, 5.7786775994725295, 6.796570473947472, 7.83519023146567, 8.82363138196052, 9.713723263896501, 10.646386398427573, 11.591832186199479, 12.622932955538005, 13.482846654105064, 12.50297727623654, 11.737309616508817, 10.75564419698723, 9.750034441613964, 8.715090582234192, 7.820658536971633, 6.779304078950211, 5.852490250436868, 4.878236938011842, 3.8951191091339714, 5.844381468095237, 6.7482411823948825, 7.801626176871617, 8.868497124943845, 9.841053009801433, 10.772737183471866, 11.593648365249992, 12.620798808037852, 13.589815524081137, 14.485194541907521, 13.552444727302635, 12.664846878653542, 11.801885468697748, 10.815747787235187, 9.74623606925944, 8.754033415368243, 7.801434140784938, 6.85809298566697, 5.86456934813352, 4.897998428127501, 6.843723931210193, 7.688508751968732, 8.709091095258906, 9.677210595017758, 10.750463767219685, 11.718779055614684, 12.55857190256897, 13.4962462986673, 14.548420727898712, 15.41631900053157, 14.61189664901871, 13.645421338030882, 12.720897424956387, 11.706112504250155, 10.682178950153006, 9.761671887575757, 8.855690090242389, 7.883793743285037, 6.843249124542303, 5.953574602095256, 7.816605882111432, 8.699260111651464, 9.712045418728977, 10.673507425248722, 11.598868921233755, 12.594915179157521, 13.557838312021556, 14.476646820821742, 15.431936711920354, 16.400614534713778, 15.583215700635268, 14.663782937002534, 13.641055398821496, 12.573144494650398, 11.646345046998142, 10.687579840688146, 9.860599735344161, 8.846059008897505, 7.9104174633675886, 7.008682752673207, 8.875850514454616, 9.733482632894138, 10.706696585161325, 11.604377740461548, 12.617460028890616, 13.526941548877108, 14.531902232088463, 15.43680936543016, 16.49198152732832, 17.405770339461856, 16.586631557185953, 15.60917349701122, 14.578353251352024, 13.595929055058955, 12.597783940938168, 11.714916046027088, 10.85238266891868, 9.893426036685161, 8.92951713723171, 8.016600044123162, 9.876185184507708, 10.778645638255957, 11.66459295303846, 12.577043643368674, 13.5089056352817, 14.52770619789023, 15.462243079004102, 16.400155981406837, 17.372599832290557, 18.3730020769108, 17.519551475612634, 16.49741866156778, 15.536894188225846, 14.539947185765325, 13.612586715745255, 12.687852408474933, 11.851681589333312, 10.885913167519563, 9.900597627649802, 9.0654117288512, 10.08059995291471, 10.665943896793108, 11.610916842946919, 12.557937367572388, 13.53534725543106, 14.154796695505656, 15.099084893836025, 16.120901676612682, 17.125933416611414, 18.056354848833344, 18.472112339082866, 17.509379598713924, 16.468375951355398, 15.548097425506949, 14.61635375994415, 13.640718111138053, 12.806863496868536, 11.876426797520603, 10.827842935410668, 10.104192632729738, 9.067742048309368, 9.686961644876789, 10.590452852211026, 11.573071339698437, 12.47175467339018, 13.22766449832859, 14.195456401494901, 15.251035350267781, 16.25248455294138, 17.260049445869047, 18.33164570451299, 17.37119355487594, 16.426183431823357, 15.483750480322364, 14.477921032287544, 13.57959471233181, 12.571948542487732, 11.631096213044337, 10.686529296709978, 9.720531092335099, 8.056515150416153, 8.619663423014686, 9.580315387680601, 10.572365615267003, 11.510257349069558, 12.285348597066415, 13.260536581348786, 14.280435717488846, 15.222191122974346, 16.267596611149553, 17.339163761014827, 16.47250163566671, 15.498208612876907, 14.568789776405161, 13.53562583843441, 12.611052355478199, 11.676115411584034, 10.619165637203835, 9.758164523452413, 8.793692651613256], [7.939335477213739, 8.896018804905564, 9.733509937140909, 10.72438507861349, 11.68631144629981, 12.624718561947716, 13.652062375565695, 14.666946480293326, 15.606603617492427, 16.631029895238033, 17.345756139177794, 16.404328637940406, 15.338265123828897, 14.329872690893088, 13.341830832687803, 12.497825614123744, 11.540440135150153, 10.68043581219154, 9.679509684582683, 8.949513109173779, 6.920429699567163, 7.84071445891554, 8.742997058836906, 9.691534280040598, 10.65628201712065, 11.645516643630462, 12.708945348128724, 13.70094116192237, 14.752703787715781, 15.772189979391221, 16.402688286415156, 15.442646212710006, 14.383836272982986, 13.367409100565716, 12.414702837117149, 11.510269751280688, 10.614992457660849, 9.686670612996672, 8.631419688750155, 7.9601889103722785, 5.876707046533436, 6.806863005677651, 7.763622597506242, 8.729788317669895, 9.728628750477226, 10.741442394820641, 11.7644123804369, 12.786300889863844, 13.742338080684638, 14.749592801215632, 15.419747083584188, 14.488954094795018, 13.436683865223776, 12.440709030786081, 11.46641025752432, 10.527777221998196, 9.57791848879345, 8.721224507155414, 7.706021537666989, 6.922156400117012, 4.858359001536151, 5.795773066556448, 6.818630412458227, 7.7472394319628775, 8.783900362551208, 9.809342321473915, 10.757823098926487, 11.74893163332871, 12.726419626893344, 13.70314501772781, 14.646510891292255, 13.578335561267755, 12.614432280171629, 11.651883839815879, 10.621433533699802, 9.577403204730924, 8.648884578290792, 7.713766502484083, 6.720187349322544, 5.880988715482304, 3.932783350112537, 4.8817449699760616, 5.846234147474724, 6.875289976614848, 7.801638440790867, 8.867446610706072, 9.868506581998446, 10.754667473468126, 11.734293516768972, 12.67853798988294, 13.606965510911937, 12.643528840922443, 11.71885321425386, 10.731507900058727, 9.711172542287926, 8.683306973671451, 7.721597551463714, 6.792734201686512, 5.774324567459625, 4.924570760635062, 2.9246812567165144, 3.9509961500597846, 4.90023404649481, 5.82562096413865, 6.85907560417049, 7.886655391345777, 8.823830845136841, 9.792360606333663, 10.802340159133786, 11.726233619177625, 12.635000618326504, 11.68259921706886, 10.692080245530699, 9.763121297195575, 8.785310927270444, 7.80607340457264, 6.878740403687648, 5.851278083342013, 4.826642540002063, 3.863899260581495, 1.9806505139214658, 2.9521608139738116, 3.9133432905659298, 4.920337768473505, 5.888303866519599, 6.939093874193066, 7.868538990809416, 8.885701214192096, 9.847125421799491, 10.784479711255663, 11.71126195645192, 10.864921523624965, 9.95803778931968, 8.924429629143592, 7.894655675438333, 6.940476528181617, 5.9164867590525905, 4.875416145942118, 3.867023852385727, 2.9344689308186536, 0.9694191406368742, 1.9698781400534102, 2.9661302339314357, 3.976007736897344, 4.8629480176402025, 5.9129430472560705, 6.892247543918537, 7.904319230258931, 8.88420565691417, 9.843005674645006, 10.749956251477801, 9.93299211765935, 8.979087511506766, 7.9242186346356185, 6.8739729128717775, 5.902975747963637, 4.973389147862998, 4.034433823510976, 2.983379608353794, 1.9973827009441087, 0.0, 1.0631847973097384, 2.0568854804691754, 2.9849230716472004, 3.9321873891411703, 4.936731921635986, 5.873013018866626, 6.9002712082513415, 7.864841844270847, 8.804791174594925, 9.73791305976603, 9.045914711911362, 8.107267876378632, 7.1678692713209, 6.138558102413923, 5.1508808759548, 4.223163293259236, 3.1495882549252636, 2.0827706381080504, 1.0493635369615093, 0.9380797027602255, 1.9432187780224168, 2.913922411382842, 3.895047487882036, 4.852936370475913, 5.863816257990138, 6.836960189214245, 7.779094982818662, 8.822572870825876, 9.75055165190798, 10.70650405657866, 9.920256191243217, 8.981295956164349, 8.034687415833817, 7.04770082360089, 6.051874385897025, 5.112490950595114, 4.0382323222455945, 3.013539155402862, 1.998771407392425, 1.9843016795511317, 2.9524179955881396, 3.895888256679461, 4.92279234260331, 5.786679017768325, 6.7603068874044485, 7.8287669191201665, 8.82030971980773, 9.751536668102975, 10.711260013659352, 11.681893857637945, 10.900038356835575, 9.953822586670023, 8.882139067942624, 7.816427505500817, 6.865618958805713, 5.881305558083191, 4.869683481956139, 3.9047386341021513, 2.92668648053891, 2.9403595161977374, 3.86831262814338, 4.8762321275237275, 5.9004263170418625, 6.826248681016412, 7.716340562952393, 8.649003697483465, 9.594449485255371, 10.625550254593897, 11.550671584845903, 12.530540962714426, 11.843253612165089, 10.772259036307762, 9.766649280934496, 8.731705421554723, 7.782513156170074, 6.741158698148651, 5.814344869635309, 4.8400915572102825, 3.856973728332412, 3.934016496766087, 4.8378762110657325, 5.891261205542467, 6.933733210520039, 7.843670308857324, 8.775354482527758, 9.596265664305884, 10.623416107093744, 11.59243282313703, 12.55301947264836, 13.521046110876647, 12.770790874309814, 11.81850030801828, 10.829721994637666, 9.759290980879411, 8.715888034566683, 7.763288759983379, 6.819947604865411, 5.82642396733196, 4.859853047325942, 4.933358959881044, 5.778143780639582, 6.7987261239297565, 7.766845623688609, 8.796489870947678, 9.721396354670576, 10.561189201624861, 11.498863597723192, 12.551038026954604, 13.484143931272406, 14.511598057439278, 13.751365333687154, 12.733952336576358, 11.719167415870126, 10.695233861772977, 9.723526506774197, 8.81754470944083, 7.845648362483478, 6.805103743740744, 5.910835409377758, 5.906240910782283, 6.788895140322314, 7.801680447399828, 8.763142453919574, 9.688503949904607, 10.684550207828373, 11.600724590528136, 12.479264119877634, 13.434554010976246, 14.40323183376967, 15.361876832840828, 14.676837848622505, 13.654110310441467, 12.586199406270369, 11.659399958618113, 10.649434459886587, 9.822454354542602, 8.807913628095946, 7.872272082566029, 6.853260123654984, 6.965485543125466, 7.823117661564988, 8.796331613832175, 9.6940127691324, 10.707095057561467, 11.61657657754796, 12.574788510595045, 13.439426664486051, 14.494598826384214, 15.408387638517747, 16.365292689391513, 15.62222840863119, 14.591408162971994, 13.608983966678926, 12.610838852558139, 11.67677066522553, 10.814237288117122, 9.855280655883602, 8.84762641326612, 7.86117741510494, 7.965820213178558, 8.868280666926807, 9.75422798170931, 10.666678672039525, 11.598540663952551, 12.617341226561082, 13.551878107674954, 14.402773280462728, 15.375217131346448, 16.37561937596669, 17.31885732467819, 16.510473573187753, 15.549949099845817, 14.553002097385296, 13.612025358810788, 12.649707027673374, 11.813536208531753, 10.804022443553974, 9.818706903684213, 8.909989099832979, 8.931926861447838, 9.79950000127759, 10.739375551942201, 11.68639607656767, 12.579899847801713, 13.575135000896696, 14.519423199227065, 15.465206261093504, 16.437263330463782, 17.367684762685712, 18.33470622387496, 17.522434510333895, 16.48143086297537, 15.549332752659655, 14.578208379142591, 13.602572730336494, 12.768718116066976, 11.794536073555014, 10.74595221144508, 9.881924170002513, 9.944784766053179, 10.778482253193909, 11.759839542678094, 12.69041700063779, 13.643492429842592, 14.502267198073762, 15.49299069373575, 16.46127084688374, 17.490198755444403, 18.403635001735786, 18.47241141587054, 17.479015192694394, 16.53400506964181, 15.591572118140817, 14.585742670105997, 13.687416350150261, 12.679770180306184, 11.738917850862789, 10.79435093452843, 9.82835273015355, 9.9512876578775, 10.617046123958792, 11.577698088624707, 12.569748316211111, 13.507640050013666, 14.282731298010523, 15.257919282292894, 16.277818418432954, 17.219573823918456, 18.264979312093665, 17.605069226095708, 16.580323273485163, 15.60603025069536, 14.676611414223615, 13.643447476252863, 12.71887399329665, 11.783937049402484, 10.726987275022285, 9.865986161270865, 8.901514289431708], [8.975736480616392, 8.08194157902546, 8.906665702358893, 9.897540843831475, 10.740235527466936, 11.678642643114841, 12.654084386082868, 13.6689684908105, 14.6086256280096, 15.633051905755204, 16.605468723273997, 17.451854696738756, 16.385791182627248, 15.377398749691437, 14.389356891486152, 13.545351672922093, 12.587966193948501, 11.727961870989889, 10.727035743381032, 9.985914112576433, 7.956830702969816, 7.026637233035435, 7.9161528240548895, 8.86469004525858, 9.710206098287777, 10.699440724797586, 11.70395768246268, 12.695953496256326, 13.695590475081003, 14.70900518208148, 15.662400870511359, 16.450046614807643, 15.431362331781335, 14.414935159364065, 13.462228895915498, 12.557795810079037, 11.662518516459198, 10.73419667179502, 9.678945747548504, 8.996589913774931, 6.913108049936089, 5.992785779797546, 6.936778362724225, 7.9029440828878785, 8.782552831644352, 9.729486670855552, 10.70122758312716, 11.723116092554104, 12.679153283374898, 13.686408003905893, 14.679267702046795, 15.450261304867785, 14.484209924022124, 13.48823508958443, 12.513936316322669, 11.575303280796545, 10.6254445475918, 9.768750565953761, 8.753547596465337, 7.958557403519665, 5.894760004938804, 4.981695840676343, 5.952934441414146, 6.881543460918796, 7.720715565241468, 8.746157524164175, 9.694638301616747, 10.68574683601897, 11.663234829583605, 12.639960220418068, 13.620208889293421, 14.461896439047138, 13.661958338969978, 12.699409898614228, 11.668959592498151, 10.624929263529273, 9.69641063708914, 8.761292561282431, 7.767713408120892, 6.917389718884957, 4.96918435351519, 4.042681918698693, 4.896952801869212, 5.926008631009335, 6.738453643481128, 7.804261813396331, 8.805321784688706, 9.691482676158387, 10.671108719459232, 11.6153531925732, 12.564993161961368, 13.522526738634587, 12.77048986748142, 11.77917241364379, 10.75883705587299, 9.730833032469798, 8.769123610262062, 7.84026026048486, 6.821850626257973, 5.97209681943341, 3.9610822601191673, 3.0017148044542723, 3.9509527008892977, 4.876339618533137, 5.795890806860751, 6.823470594036038, 7.760646047827102, 8.729175809023923, 9.739155361824047, 10.663048821867887, 11.609195713523361, 12.561597114781005, 11.743716898758258, 10.814757950423134, 9.836947580498004, 8.8577100578002, 7.930377056915208, 6.902914736569574, 5.874168598800411, 4.911425319379843, 3.0170515173241186, 2.0028794683682993, 2.9640619449604175, 3.971056422867993, 4.82511906920986, 5.875909076883327, 6.805354193499677, 7.822516416882358, 8.783940624489754, 9.721294913945925, 10.648077159142183, 11.577184782213232, 11.00967444254724, 9.976066282371152, 8.946292328665892, 7.992113181409176, 6.96812341228015, 5.927052799169679, 4.918660505613287, 3.9861055840462134, 2.0210557938644342, 1.020596794447898, 2.0168488883259235, 2.975379378461245, 3.799763220330464, 4.849758249946332, 5.829062746608798, 6.841134432949193, 7.821020859604433, 8.779820877335268, 9.686771454168063, 10.728040313119976, 10.030724164734325, 8.975855287863178, 7.925609566099337, 6.954612401191197, 6.025025801090558, 5.086070476738535, 4.035016261581354, 3.049019354171669, 1.0631847973097384, 0.0, 0.9937006831594369, 1.921738274337462, 2.869002591831432, 3.8735471243262483, 4.809828221556888, 5.837086410941604, 6.801657046961109, 7.741606377285187, 8.674728262456291, 9.735067403641704, 9.17045267368837, 8.231054068630637, 7.201742899723661, 6.214065673264538, 5.286348090568974, 4.2127730522350015, 3.1459554354177888, 2.1125483342712474, 1.9919016415265913, 0.9867625662644, 1.9574661996248253, 2.917333376410487, 3.8327350435187433, 4.817185588620247, 5.790329519844354, 6.732464313448771, 7.775942201455985, 8.687366854598242, 9.643319259268923, 10.568492718005965, 10.035117894930716, 9.088509354600184, 8.101522762367257, 7.105696324663392, 6.166312889361481, 5.0920542610119615, 4.067361094169228, 3.052593346158791, 3.03063431765373, 1.9959617838301227, 2.9394320449214444, 3.9450782311317605, 4.766477690811156, 5.7401055604472795, 6.8085655921629975, 7.784273365890622, 8.704905998733084, 9.648075216349614, 10.618709060328207, 11.597535231748175, 11.000155224772621, 9.928471706045222, 8.862760143603417, 7.911951596908311, 6.92763819618579, 5.916016120058738, 4.95107127220475, 3.973019118641509, 3.8703364554170743, 2.9423833434714317, 3.919775915765711, 4.922712205570313, 5.806047354059243, 6.696139235995224, 7.628802370526297, 8.574248158298202, 9.605348927636728, 10.530470257888734, 11.510339635757257, 12.515088946002678, 11.78552667809097, 10.779916922717705, 9.744973063337932, 8.795780797953283, 7.75442633993186, 6.8276125114185175, 5.853359198993491, 4.82594183380999, 4.8639934359854236, 3.9119469263937843, 4.9653319208705184, 5.95601909904849, 6.823468981900155, 7.755153155570588, 8.576064337348717, 9.603214780136577, 10.572231496179862, 11.532818145691191, 12.500844783919476, 13.426371114059105, 12.831767949801488, 11.842989636420874, 10.77255862266262, 9.729155676349892, 8.776556401766587, 7.83321524664862, 6.798390508051086, 5.82882115280352, 5.86333589910038, 4.852214495967634, 5.872796839257808, 6.840916339016661, 7.776288543990508, 8.701195027713405, 9.540987874667694, 10.478662270766025, 11.530836699997437, 12.463942604315239, 13.49139673048211, 14.406945573436445, 13.747219978359567, 12.732435057653335, 11.708501503556185, 10.736794148557406, 9.806302280287182, 8.817614903202603, 7.777070284459869, 6.840812348597094, 6.804491236495926, 5.862965855650366, 6.875751162727879, 7.837213169247625, 8.747114558065654, 9.74316081598942, 10.580523263570969, 11.459062792920466, 12.414352684019079, 13.383030506812503, 14.34167550588366, 15.393282098089328, 14.667377952224676, 13.599467048053578, 12.672667600401322, 11.662702101669796, 10.747117608877979, 9.732576882431323, 8.788671103142198, 7.751510449368626, 7.863735868839108, 6.897188376893039, 7.870402329160227, 8.76808348446045, 9.773042932598951, 10.675187185709007, 11.554587183637878, 12.419225337528884, 13.474397499427047, 14.38818631156058, 15.345091362434347, 16.376855506783244, 15.604675804755203, 14.622251608462134, 13.624106494341348, 12.690038307008738, 11.738900542452498, 10.779943910218979, 9.745876738979762, 8.759427740818582, 8.864070538892202, 7.942351382254859, 8.828298697037361, 9.740749387367575, 10.672611379280601, 11.691411941889132, 12.559297919818963, 13.382571953505561, 14.35501580438928, 15.355418049009524, 16.298655997721024, 17.320788811765876, 16.563216741629027, 15.566269739168504, 14.625293000593997, 13.662974669456583, 12.732166644952708, 11.702272769267616, 10.716957229397854, 9.80823942554662, 9.830177187161482, 8.873570716605641, 9.813446267270253, 10.760466791895722, 11.653970563129763, 12.649205716224746, 13.593493914555115, 14.445004934136337, 15.417062003506615, 16.347483435728545, 17.314504896917793, 17.440174862009325, 16.54885735221406, 15.590415329997702, 14.619290956480638, 13.696810547823324, 12.87500411873091, 11.9820095760492, 11.137605216450174, 10.780174495716157, 10.843035091766822, 9.85255296852196, 10.833910258006146, 11.764487715965842, 12.717563145170642, 13.576337913401812, 14.5670614090638, 15.441069519926574, 16.469997428487236, 17.38343367477862, 17.474433426387712, 16.481037203211567, 15.536027080158984, 14.645496199307942, 13.639666751273122, 12.741340431317388, 11.852982253294725, 10.91212992385133, 10.1183335329081, 10.864753733556205, 10.987688661280155, 10.919851190384062, 11.844047722536573, 12.765458121396856, 13.679060469491262, 14.518653814663987, 15.501981229209916, 16.411669152705507, 17.35342455819101, 17.614656073451282, 16.60709123661288, 15.582345284002336, 14.608052261212533, 13.678633424740788, 12.697371557419988, 11.772798074463777, 10.957092814620468, 9.90014304024027, 9.05190893539076, 9.937915292834361], [9.953500246235464, 9.02833085321466, 8.048993839777449, 9.03986898125003, 9.746534844307497, 10.684941959955403, 11.660383702923431, 12.67526780765106, 13.614924944850161, 14.639351222595765, 15.611768040114558, 16.51862572046127, 16.37015252728187, 15.47598769424991, 14.539853043484573, 13.799353217475467, 12.959603205913917, 12.019908523039884, 11.704799509000104, 10.963677878195504, 8.934594468588887, 8.004400998654507, 7.058480961473445, 8.007018182677136, 8.716505415128339, 9.705740041638148, 10.710256999303242, 11.702252813096889, 12.701889791921564, 13.715304498922041, 14.66870018735192, 15.456345931648208, 16.40683755258737, 15.392698924983137, 14.43999266153457, 13.535559575698109, 12.64028228207827, 11.711960437414092, 10.656709513167575, 9.974353679394003, 7.89087181555516, 6.970549545416617, 6.079106500142781, 7.045272220306434, 7.7888521484849145, 8.735785987696115, 9.707526899967723, 10.729415409394667, 11.68545260021546, 12.692707320746454, 13.685567018887356, 14.456560621708348, 15.391621926911835, 14.465998855203502, 13.49170008194174, 12.553067046415617, 11.603208313210871, 10.746514331572833, 9.731311362084409, 8.936321169138736, 6.872523770557875, 5.959459606295414, 5.095262578832702, 6.023871598337352, 6.727014882082031, 7.752456841004738, 8.70093761845731, 9.692046152859533, 10.669534146424166, 11.64625953725863, 12.626508206133982, 13.4681957558877, 14.432099036983827, 13.6771736642333, 12.646723358117223, 11.602693029148345, 10.674174402708212, 9.739056326901503, 8.745477173739964, 7.895153484504028, 5.946948119134261, 5.020445684317764, 4.039280939287767, 5.068336768427891, 5.744752960321691, 6.810561130236894, 7.811621101529269, 8.697781992998948, 9.677408036299793, 10.621652509413762, 11.57129247880193, 12.52882605547515, 13.563444191491499, 12.756936179262862, 11.736600821492061, 10.70859679808887, 9.746887375881133, 8.81802402610393, 7.799614391877045, 6.949860585052481, 4.938846025738238, 3.979478570073343, 3.093280838307854, 4.018667755951694, 4.802190123701314, 5.829769910876601, 6.766945364667665, 7.735475125864485, 8.745454678664608, 9.66934813870845, 10.615495030363924, 11.567896431621568, 12.55841540315973, 11.808458633582573, 10.830648263657443, 9.851410740959638, 8.924077740074647, 7.896615419729011, 6.851932364419483, 5.889189084998915, 3.9948152829431893, 2.98064323398737, 2.019460757395252, 3.0127556408832907, 3.831418386050423, 4.882208393723891, 5.811653510340241, 6.828815733722921, 7.7902399413303165, 8.727594230786488, 9.654376475982746, 10.583484099053795, 11.56565194022536, 10.969766965530592, 9.939993011825333, 8.985813864568616, 7.961824095439589, 6.920753482329117, 5.912361188772725, 4.979806267205651, 3.0147564770238713, 2.014297477607335, 1.037149680243815, 1.9816786953018077, 2.806062537171027, 3.856057566786895, 4.835362063449362, 5.847433749789756, 6.827320176444996, 7.7861201941758305, 8.693070771008626, 9.73433962996054, 10.643899817250741, 9.969555971022615, 8.919310249258775, 7.948313084350634, 7.018726484249996, 6.079771159897973, 5.028716944740792, 4.042720037331106, 2.0568854804691754, 0.9937006831594369, 0.0, 0.928037591178025, 1.8753019086719949, 2.879846441166811, 3.816127538397451, 4.843385727782167, 5.807956363801672, 6.74790569412575, 7.681027579296855, 8.741366720482269, 9.680013556014998, 9.224754751790075, 8.1954435828831, 7.207766356423975, 6.280048773728411, 5.206473735394439, 4.139656118577226, 3.1062490174306845, 2.9856023246860284, 1.980463249423837, 1.0329749659852947, 1.92363269325105, 2.8390343603593062, 3.82348490546081, 4.796628836684917, 5.738763630289334, 6.782241518296548, 7.693666171438804, 8.649618576109487, 9.57479203484653, 10.513752269925398, 10.08221003775962, 9.095223445526692, 8.099397007822828, 7.160013572520916, 6.085754944171397, 5.061061777328664, 4.0462940293182275, 3.9937330111884464, 2.9590604773648392, 2.014940811281914, 2.9513775479723234, 3.7727770076517184, 4.7464048772878416, 5.814864909003559, 6.7905726827311845, 7.711205315573647, 8.654374533190175, 9.625008377168772, 10.60383454858874, 11.537772854455561, 10.89157039957994, 9.825858837138133, 8.875050290443028, 7.890736889720507, 6.879114813593454, 5.914169965739466, 4.936117812176225, 4.833435148951791, 3.9054820370061485, 2.9952846821261803, 3.9290115224108764, 4.812346670899805, 5.702438552835786, 6.635101687366859, 7.580547475138765, 8.61164824447729, 9.536769574729297, 10.51663895259782, 11.52138826284324, 12.592382838700567, 11.743015616252423, 10.70807175687265, 9.758879491488, 8.717525033466577, 7.790711204953234, 6.8164578925282076, 5.7890405273447065, 5.827092129520141, 4.8750456199285015, 4.054010365696781, 4.962318415889053, 5.829768298740717, 6.76145247241115, 7.582363654189279, 8.609514096977138, 9.578530813020423, 10.539117462531754, 11.50714410076004, 12.43267043089967, 13.419747762424178, 12.806088329955593, 11.735657316197338, 10.69225436988461, 9.739655095301305, 8.796313940183335, 7.761489201585802, 6.791919846338236, 6.826434592635097, 5.815313189502351, 5.094685834787828, 5.951528229547135, 6.78258786083107, 7.707494344553967, 8.547287191508255, 9.484961587606586, 10.537136016837998, 11.4702419211558, 12.497696047322671, 13.41324489027701, 14.3559334883798, 13.695533751188053, 12.671600197090903, 11.699892842092124, 10.769400973821899, 9.78071359673732, 8.740168977994585, 7.803911042131811, 7.767589930030644, 6.826064549185084, 6.097640158257899, 6.947825059778099, 7.753413874906216, 8.749460132829983, 9.58682258041153, 10.465362109761028, 11.42065200085964, 12.389329823653064, 13.347974822724222, 14.399581414929889, 15.380026891654362, 14.562565741588296, 13.63576629393604, 12.625800795204514, 11.710216302412697, 10.69567557596604, 9.751769796676916, 8.714609142903345, 8.826834562373827, 7.860287070427757, 7.0922913246902475, 7.878695374990924, 8.779342249439514, 9.68148650254957, 10.56088650047844, 11.425524654369445, 12.480696816267608, 13.39448562840114, 14.351390679274909, 15.383154823623805, 16.31732474418489, 15.585350301996852, 14.587205187876066, 13.653137000543456, 12.701999235987216, 11.743042603753697, 10.708975432514482, 9.722526434353302, 9.82716923242692, 8.905450075789577, 8.050187692567382, 8.85136127789805, 9.783089691374883, 10.75629014011333, 11.565597236659524, 12.388871270346122, 13.361315121229842, 14.361717365850085, 15.304955314561587, 16.32708812860644, 16.486638432184176, 15.604864886579888, 14.618293898464419, 13.655975567327005, 12.97251416368469, 12.149472252794665, 11.680055922932574, 10.77133811908134, 10.7932758806962, 9.83666941014036, 9.035335262800274, 9.925303695351824, 10.764448875224044, 11.729504479722612, 12.639453788195304, 13.451304250976898, 14.423361320347176, 15.353782752569106, 16.320804213758354, 16.446474178849886, 15.555156669054622, 14.596714646838263, 13.6255902733212, 12.703109864663885, 12.017332256149466, 11.124337713467755, 12.01829666114632, 11.743273189250875, 11.80613378530154, 10.815651662056679, 10.055799253536167, 10.929324619421944, 11.828041457264924, 12.656636676899678, 13.61302128270399, 14.447368836767135, 15.476296745327797, 16.38973299161918, 16.480732743228273, 15.487336520052128, 14.542326396999547, 13.651795516148503, 12.645966068113683, 11.74763974815795, 10.99531039071328, 10.054458061269886, 10.999024977604245, 11.842517499175276, 11.965452426899226, 11.88294988391878, 11.065936718066592, 11.930295024852958, 12.789538781585545, 13.598952578161853, 14.547941102850105, 15.41796846954607, 16.35972387503157, 16.620955390291844, 15.613390553453444, 14.5886446008429, 13.614351578053096, 12.68493274158135, 11.703670874260549, 10.779097391304338, 10.099420952039024, 9.042471177658825, 9.99829820957996, 10.915679058453433], [10.881537837413486, 9.956368444392686, 8.977031430955474, 8.327843730839168, 8.818497253129472, 9.756904368777379, 10.732346111745406, 11.747230216473035, 12.686887353672136, 13.71131363141774, 14.683730448936533, 15.590588129283244, 15.442114936103845, 14.547950103071885, 13.61181545230655, 12.871315626297442, 12.031565614735891, 12.91683282638002, 12.632837100178127, 11.891715469373526, 9.86263205976691, 8.93243858983253, 7.986518552651471, 7.2860423298596215, 7.788467823950314, 8.777702450460124, 9.782219408125217, 10.774215221918864, 11.773852200743539, 12.787266907744016, 13.740662596173895, 14.528308340470183, 15.478799961409342, 15.49164971132577, 14.538943447877203, 13.877196430846078, 12.957013292225195, 12.639998028592116, 11.584747104345599, 10.902391270572027, 8.818909406733184, 7.8985871365946405, 7.007144091320806, 6.296255251515129, 6.86081455730689, 7.807748396518089, 8.779489308789698, 9.801377818216642, 10.757415009037434, 11.764669729568428, 12.757529427709331, 13.528523030530323, 14.46358433573381, 15.394036446381525, 14.419737673119764, 13.48110463759364, 12.531245904388895, 11.674551922750856, 10.659348953262432, 9.86435876031676, 7.800561361735898, 6.887497197473437, 6.023300170010727, 5.231700884409404, 5.7989772909040065, 6.824419249826713, 7.7729000272792845, 8.764008561681507, 9.74149655524614, 10.718221946080604, 11.698470614955957, 12.540158164709675, 13.504061445805801, 14.466609886161551, 13.574760949295246, 12.530730620326368, 11.602211993886236, 10.667093918079527, 9.673514764917988, 8.823191075682052, 6.874985710312284, 5.9484832754957875, 4.967318530465793, 4.167182448711831, 4.816715369143666, 5.8825235390588695, 6.883583510351244, 7.769744401820923, 8.749370445121768, 9.693614918235737, 10.643254887623904, 11.600788464297125, 12.635406600313473, 13.577476275565006, 12.664638412670087, 11.636634389266895, 10.674924967059159, 9.746061617281956, 8.727651983055068, 7.877898176230505, 5.866883616916262, 4.907516161251367, 4.021318429485879, 3.112135710720761, 3.874152532523289, 4.901732319698576, 5.838907773489639, 6.80743753468646, 7.817417087486582, 8.741310547530425, 9.687457439185899, 10.639858840443543, 11.630377811981704, 12.559336760316828, 11.758685854835466, 10.779448332137662, 9.852115331252671, 8.824653010907035, 7.779969955597506, 6.817226676176938, 4.922852874121213, 3.9086808251653946, 2.9474983485732764, 2.0847180497052653, 2.903380794872398, 3.9541708025458657, 4.883615919162216, 5.900778142544896, 6.862202350152291, 7.799556639608463, 8.72633888480472, 9.65544650787577, 10.637614349047334, 11.671222509223423, 10.868030603003355, 9.913851455746638, 8.889861686617612, 7.84879107350714, 6.840398779950749, 5.907843858383675, 3.942794068201896, 2.94233506878536, 1.96518727142184, 1.0536411041237828, 1.8780249459930018, 2.92801997560887, 3.907324472271337, 4.919396158611731, 5.89928258526697, 6.858082602997805, 7.765033179830602, 8.806302038782514, 9.715862226072716, 10.719442722560263, 9.847347840436798, 8.876350675528657, 7.946764075428019, 7.007808751075997, 5.956754535918815, 4.97075762850913, 2.9849230716472004, 1.921738274337462, 0.928037591178025, 0.0, 0.9472643174939698, 1.9518088499887858, 2.8880899472194255, 3.9153481366041416, 4.879918772623647, 5.819868102947725, 6.75298998811883, 7.813329129304243, 8.751975964836973, 9.691374569894705, 9.123481174061125, 8.135803947602001, 7.208086364906436, 6.134511326572464, 5.067693709755251, 4.03428660860871, 3.9136399158640534, 2.908500840601862, 1.9610125571633197, 0.995595102073025, 1.910996769181281, 2.8954473142827846, 3.8685912455068916, 4.810726039111309, 5.854203927118522, 6.7656285802607785, 7.721580984931462, 8.646754443668504, 9.585714678747372, 10.532323219077904, 10.023261036704717, 9.027434599000854, 8.088051163698943, 7.013792535349422, 5.98909936850669, 4.974331620496253, 4.921770602366472, 3.8870980685428647, 2.9429784024599392, 2.023339956794299, 2.8447394164736934, 3.818367286109817, 4.886827317825535, 5.862535091553159, 6.783167724395621, 7.72633694201215, 8.696970785990747, 9.675796957410714, 10.609735263277535, 11.603980543144948, 10.75389642831616, 9.803087881621055, 8.818774480898533, 7.80715240477148, 6.842207556917492, 5.864155403354251, 5.7614727401298165, 4.833519628184174, 3.9233222733042057, 3.000973931232852, 3.8843090797217803, 4.774400961657761, 5.707064096188835, 6.6525098839607395, 7.683610653299265, 8.608731983551271, 9.588601361419794, 10.593350671665215, 11.664345247522542, 12.658286008757853, 11.636109348050676, 10.686917082666026, 9.645562624644603, 8.71874879613126, 7.744495483706233, 6.717078118522732, 6.755129720698166, 5.803083211106527, 4.982047956874807, 4.034280824711027, 4.901730707562693, 5.833414881233126, 6.654326063011254, 7.681476505799115, 8.6504932218424, 9.611079871353729, 10.579106509582015, 11.504632839721644, 12.491710171246153, 13.53445229451145, 12.663694907375364, 11.620291961062636, 10.66769268647933, 9.724351531361362, 8.689526792763827, 7.719957437516261, 7.754472183813123, 6.743350780680377, 5.991610138127962, 5.023490638369109, 5.854550269653045, 6.779456753375943, 7.619249600330231, 8.55692399642856, 9.609098425659973, 10.542204329977775, 11.569658456144646, 12.485207299098985, 13.427895897201775, 14.442680817908007, 13.599637788268929, 12.62793043327015, 11.697438564999922, 10.708751187915343, 9.66820656917261, 8.731948633309836, 8.695627521208669, 7.754102140363109, 6.994564461598033, 6.019787468600073, 6.8253762837281915, 7.821422541651958, 8.658784989233505, 9.537324518583002, 10.492614409681615, 11.461292232475039, 12.419937231546196, 13.471543823751864, 14.451989300476336, 15.466701301507143, 14.563803885114066, 13.55383838638254, 12.638253893590722, 11.623713167144066, 10.679807387854941, 9.64264673408137, 9.754872153551853, 8.788324661605783, 7.989215628030381, 6.950657783812899, 7.851304658261489, 8.753448911371546, 9.632848909300414, 10.49748706319142, 11.552659225089583, 12.466448037223115, 13.423353088096883, 14.45511723244578, 15.389287153006865, 15.620845426108234, 14.69344748593823, 13.700874338596824, 13.438517391347517, 12.671080194931722, 11.637013023692507, 10.650564025531327, 10.755206823604945, 9.833487666967603, 8.947111995907516, 7.923323686720026, 8.855052100196858, 9.828252548935307, 10.637559645481499, 11.460833679168097, 12.433277530051816, 13.43367977467206, 14.376917723383562, 15.399050537428415, 15.558600841006148, 14.676827295401864, 13.690256307286393, 12.72793797614898, 12.439218470932886, 13.07750984397269, 12.6080935141106, 11.699375710259366, 11.721313471874225, 10.764707001318385, 9.932259566140408, 8.997266104173798, 9.836411284046019, 10.801466888544589, 11.711416197017279, 12.523266659798873, 13.49532372916915, 14.425745161391081, 15.39276662258033, 15.51843658767186, 14.627119077876596, 13.66867705566024, 12.697552682143176, 11.77507227348586, 11.484036563397662, 12.05237530464578, 12.946334252324345, 12.6713107804289, 12.734171376479566, 11.743689253234704, 10.9527235568763, 10.001287028243919, 10.900003866086898, 11.728599085721655, 12.684983691525964, 13.51933124558911, 14.548259154149772, 15.461695400441156, 15.552695152050248, 14.559298928874103, 13.614288805821522, 12.72375792497048, 11.71792847693566, 10.819602156979924, 10.462014697961477, 10.982495652447911, 11.92706256878227, 12.770555090353298, 12.893490018077248, 12.810987475096805, 11.962861021406727, 11.002257433674933, 11.86150119040752, 12.67091498698383, 13.61990351167208, 14.489930878368044, 15.431686283853544, 15.692917799113818, 14.685352962275418, 13.660607009664874, 12.68631398687507, 11.756895150403325, 10.775633283082525, 9.851059800126313, 9.387395701628162, 9.97050876883685, 10.926335800757986, 11.843716649631455], [11.71162503411895, 10.752649778846019, 9.773312765408807, 8.89946757526655, 7.871232935635502, 8.80964005128341, 9.785081794251436, 10.799965898979067, 11.739623036178168, 12.764049313923772, 13.736466131442565, 14.643323811789276, 14.494850618609876, 13.600685785577914, 12.664551134812578, 11.92405130880347, 12.815251608355071, 13.712545882658059, 13.579844435203835, 12.72180266607899, 10.745062810459348, 9.79403647084062, 8.782799887104805, 7.901053900234176, 6.841203506456344, 7.830438132966154, 8.834955090631247, 9.826950904424894, 10.82658788324957, 11.840002590250048, 12.793398278679927, 13.581044022976213, 14.531535643915372, 14.5443853938318, 13.591679130383232, 12.929932113352107, 13.740699285844375, 13.587005363617823, 12.531754439371307, 11.784822021264464, 9.701340157425621, 8.76018501760273, 7.80342542577414, 6.9123906726202495, 5.91355023981292, 6.860484079024119, 7.832224991295727, 8.854113500722672, 9.810150691543464, 10.817405412074459, 11.810265110215362, 12.581258713036354, 13.51632001823984, 14.507081867884338, 14.539971709976061, 13.9124246426346, 13.478253239414602, 12.621559257776564, 11.60635628828814, 10.746789511009197, 8.735041056019151, 7.799517706709662, 6.819581504464061, 5.890972484959411, 4.851712973410036, 5.877154932332743, 6.825635709785315, 7.816744244187537, 8.794232237752171, 9.770957628586636, 10.751206297461987, 11.592893847215706, 12.556797128311832, 13.519345568667582, 14.494573673995053, 13.477737955352076, 12.549219328911944, 11.614101253105234, 10.620522099943695, 9.757670769965305, 7.809465404595537, 6.860503784732012, 5.83219872870237, 4.878953497905793, 3.8694510516496963, 4.9352592215649, 5.936319192857274, 6.822480084326954, 7.802106127627798, 8.746350600741767, 9.695990570129934, 10.653524146803155, 11.688142282819506, 12.630211958071037, 13.51574442776547, 12.583641724292601, 11.621932302084865, 10.693068952307662, 9.674659318080776, 8.824905511256212, 6.8138909519419695, 5.8354365241574815, 4.8861986277224565, 3.960811710078617, 2.926888215029319, 3.954468002204606, 4.89164345599567, 5.86017321719249, 6.870152769992613, 7.794046230036456, 8.740193121691929, 9.692594522949573, 10.683113494487735, 11.612072442822859, 12.58988281274799, 11.726712649631633, 10.799379648746642, 9.771917328401006, 8.726977290623214, 7.764234011202646, 5.869860209146921, 4.855688160191102, 3.894505683598984, 2.9333940490631214, 1.956116477378428, 3.0069064850518963, 3.936351601668246, 4.953513825050926, 5.914938032658322, 6.852292322114494, 7.779074567310751, 8.7081821903818, 9.690350031553365, 10.723958191729453, 11.753732145434713, 10.86111577324061, 9.837126004111584, 8.796055391001111, 7.78766309744472, 6.855108175877646, 4.890058385695866, 3.88959938627933, 2.9121946064475477, 1.9023171034816388, 0.9307606284990321, 1.9807556581149002, 2.9600601547773673, 3.9721318411177613, 4.952018267773001, 5.910818285503836, 6.817768862336632, 7.859037721288545, 8.768597908578748, 9.772178405066295, 10.699295226392039, 9.823614993022629, 8.89402839292199, 7.955073068569968, 6.904018853412786, 5.918021946003101, 3.9321873891411703, 2.869002591831432, 1.8753019086719949, 0.9472643174939698, 0.0, 1.0045445324948161, 1.9408256297254556, 2.9680838191101717, 3.932654455129677, 4.872603785453755, 5.80572567062486, 6.866064811810274, 7.804711647343004, 8.744110252400738, 9.773421421307713, 9.08306826509597, 8.155350682400407, 7.0817756440664335, 6.014958027249221, 4.981550926102679, 4.860904233358023, 3.855765158095832, 2.9027464107803818, 1.9216213342811876, 0.9637324516873113, 1.9481829967888151, 2.921326928012922, 3.8634617216173393, 4.906939609624553, 5.818364262766809, 6.774316667437493, 7.699490126174536, 8.638450361253403, 9.585058901583935, 10.572045493816862, 9.974698916494821, 9.03531548119291, 7.961056852843392, 6.936363686000659, 5.921595937990222, 5.863504455983533, 4.828831922159926, 3.884712256077001, 2.8981431378945968, 1.8974750989797236, 2.871102968615847, 3.9395630003315647, 4.91527077405919, 5.835903406901652, 6.7790726245181805, 7.749706468496778, 8.728532639916747, 9.662470945783564, 10.656716225650978, 11.529278723107, 10.744821735238116, 9.760508334515594, 8.748886258388541, 7.7839414105345535, 6.805889256971312, 6.703206593746878, 5.7752534818012355, 4.865056126921267, 3.8757771123331497, 2.9370447622278104, 3.8271366441637915, 4.759799778694864, 5.70524556646677, 6.736346335805296, 7.661467666057302, 8.641337043925825, 9.646086354171246, 10.717080930028573, 11.711021691263884, 12.489940154913738, 11.628650936283087, 10.587296478261663, 9.660482649748321, 8.686229337323294, 7.658811972139794, 7.696863574315228, 6.7448170647235886, 5.923781810491868, 4.909084005811326, 3.9544663900687222, 4.8861505637391565, 5.707061745517284, 6.734212188305144, 7.703228904348429, 8.66381555385976, 9.631842192088044, 10.557368522227673, 11.544445853752181, 12.587187977017479, 13.521085641938987, 12.562025814679696, 11.609426540096392, 10.666085384978423, 9.63126064638089, 8.661691291133323, 8.696206037430185, 7.685084634297438, 6.86641331922826, 5.898293819469408, 4.907285952159075, 5.832192435881973, 6.6719852828362605, 7.609659678934591, 8.661834108166003, 9.594940012483807, 10.622394138650678, 11.537942981605013, 12.480631579707804, 13.495416500414036, 14.457028522832552, 13.56966428688721, 12.639172418616985, 11.650485041532406, 10.609940422789672, 9.673682486926898, 9.63736137482573, 8.69583599398017, 7.7996682914581825, 6.803473462219253, 5.878111966234221, 6.874158224157988, 7.711520671739534, 8.590060201089033, 9.545350092187645, 10.51402791498107, 11.472672914052227, 12.524279506257894, 13.504724982982365, 14.519436984013172, 14.697622062384285, 13.780946226441795, 13.579987747207783, 12.565447020761127, 11.621541241472002, 10.584380587698432, 10.696606007168914, 9.730058515222844, 8.79431945789053, 7.734343777432079, 6.904040340767519, 7.806184593877576, 8.685584591806442, 9.55022274569745, 10.605394907595613, 11.519183719729146, 12.476088770602914, 13.507852914951812, 14.442022835512894, 14.673581108614265, 13.74618316844426, 12.753610021102855, 13.733234334140022, 13.612814048548783, 12.578746877309568, 11.592297879148388, 11.696940677222006, 10.775221520584664, 9.752215825767665, 8.707009680339205, 7.907787782702887, 8.880988231441336, 9.690295327987528, 10.513569361674127, 11.486013212557847, 12.48641545717809, 13.429653405889592, 14.451786219934446, 14.611336523512179, 13.729562977907895, 12.742991989792424, 11.78067365865501, 12.734152224567563, 13.764046100252655, 13.54982736772766, 12.641109563876427, 12.663047325491286, 11.706440854935446, 10.727972622418447, 9.780952097792978, 8.889146966552048, 9.854202571050617, 10.764151879523308, 11.576002342304903, 12.54805941167518, 13.47848084389711, 14.445502305086361, 14.57117227017789, 13.679854760382627, 12.72141273816627, 11.750288364649206, 10.82780795599189, 11.77897031703234, 12.834673428095332, 13.742615586777678, 13.613044634045961, 13.675905230096628, 12.685423106851765, 11.74843661315434, 10.784973021863099, 9.952739548592927, 10.781334768227683, 11.737719374031993, 12.57206692809514, 13.6009948366558, 14.514431082947185, 14.605430834556278, 13.612034611380134, 12.667024488327552, 11.77649360747651, 10.77066415944169, 9.872337839485954, 10.891564823459984, 11.778776986901244, 12.723343903235603, 13.600642287058761, 13.723577214782711, 13.719226042350682, 12.758574077684766, 11.785943427294113, 10.914236872913548, 11.723650669489858, 12.672639194178108, 13.542666560874075, 14.484421966359575, 14.74565348161985, 13.738088644781449, 12.713342692170905, 11.739049669381101, 10.809630832909356, 9.828368965588556, 8.903795482632344, 9.893060821718583, 10.766790103290184, 11.722617135211319, 12.673803846336918], [12.716169566613768, 11.757194311340838, 10.777857297903626, 9.904012107761368, 8.87577746813032, 8.147689391907742, 9.034062724669743, 10.048946829397373, 10.942879695755213, 11.937556193550428, 12.785801568095057, 13.63877927929446, 13.631150095196896, 12.736985262164934, 11.811636442552407, 12.800114062673304, 13.757499541646895, 14.703331782778971, 14.58438896769865, 13.726347198573809, 11.749607342954167, 10.798581003335439, 9.787344419599622, 8.905598432728993, 7.845748038951161, 7.168487473590486, 8.083936021049555, 9.075931834843201, 9.887333889362123, 10.9007485963626, 11.842733715332418, 12.576499490481398, 13.526991111420557, 13.691470701571628, 12.738764438123061, 13.80599486722194, 14.6829472191362, 14.591549896112639, 13.536298971866122, 12.789366553759283, 10.70588468992044, 9.764729550097549, 8.807969958268957, 7.916935205115067, 6.918094772307737, 6.128887744690938, 7.081205921714035, 8.037743193305761, 8.870896697656018, 9.878151418187013, 10.821888021867974, 11.576714180541538, 12.511775485745025, 13.502537335389523, 13.68705701771589, 14.625690053242014, 14.482797771909418, 13.62610379027138, 12.610900820782955, 11.751334043504016, 9.739585588513966, 8.804062239204479, 7.824126036958878, 6.895517017454228, 5.856257505904853, 5.145558597999562, 6.074616640203622, 6.970675033316207, 7.854978243864725, 8.831703634699188, 9.7628292091146, 10.58834931472089, 11.552252595817016, 12.514801036172766, 13.490029141500237, 14.482282487846891, 13.55376386140676, 12.61864578560005, 11.62506663243851, 10.76221530246012, 8.814009937090352, 7.865048317226829, 6.836743261197187, 5.8834980304006095, 4.873995584144513, 4.08959990483556, 5.020646569143869, 5.906807460613549, 6.862852133740352, 7.80709660685432, 8.707613481782547, 9.64897961430834, 10.68359775032469, 11.625667425576221, 12.511199895270655, 13.533462271719388, 12.62647683457968, 11.697613484802478, 10.679203850575592, 9.829450043751027, 7.818435484436785, 6.839981056652298, 5.890743160217273, 4.965356242573433, 3.9314327475241355, 3.038795378491201, 3.9759708322822647, 4.944500593479085, 5.930898776105167, 6.78950169754164, 7.735648589197114, 8.688049990454758, 9.67856896199292, 10.607527910328043, 11.585338280253174, 12.564575802950978, 11.803924181241458, 10.776461860895822, 9.73152182311803, 8.768778543697461, 6.874404741641737, 5.860232692685917, 4.8990502160938, 3.9379385815579377, 2.9606610098732444, 2.0684819364120823, 2.9791014361315034, 3.9489692925561095, 4.910393500163505, 5.847747789619677, 6.7745300348159345, 7.7036376578869845, 8.68580549905855, 9.719413659234638, 10.749187612939897, 11.703366760196612, 10.841670536606399, 9.800599923495927, 8.792207629939535, 7.859652708372462, 5.8946029181906825, 4.894143918774146, 3.916739138942363, 2.9068616359764547, 1.935305160993848, 1.0423311094750862, 2.0028099892406246, 2.967587308622945, 3.9474737352781846, 4.906273753009019, 5.813224329841816, 6.854493188793729, 7.764053376083932, 8.767633872571478, 9.694750693897223, 10.665747858805364, 9.898572925416806, 8.959617601064783, 7.908563385907602, 6.922566478497917, 4.936731921635986, 3.873547124326248, 2.8798464411668108, 1.9518088499887858, 1.0045445324948161, 0.0, 0.9362810972306395, 1.9635392866153556, 2.928109922634861, 3.868059252958939, 4.801181138130044, 5.8615202793154575, 6.800167114848188, 7.739565719905921, 8.768876888812898, 9.75655411527202, 9.159895214895222, 8.08632017656125, 7.019502559744037, 5.986095458597496, 5.86544876585284, 4.860309690590648, 3.8935323109012936, 2.9124072344020995, 1.9545183518082234, 0.943638464293999, 1.9167823955181058, 2.858917189122523, 3.9023950771297367, 4.813819730271993, 5.769772134942675, 6.694945593679718, 7.633905828758586, 8.580514369089117, 9.567500961322045, 10.563327399025908, 10.03986001368773, 8.965601385338209, 7.940908218495476, 6.92614047048504, 6.854290356104445, 5.819617822280838, 4.875498156197913, 3.888929038015509, 2.888260999100636, 2.0074024452028665, 2.965201594861106, 3.910726241564373, 4.831358874406836, 5.774528092023364, 6.745161936001961, 7.7239881074219285, 8.657926413288749, 9.652171693156161, 10.524734190612183, 11.475542737307288, 10.751294234636505, 9.739672158509453, 8.774727310655466, 7.796675157092224, 7.69399249386779, 6.766039381922147, 5.855842027042179, 4.866563012454062, 3.9278306623487227, 2.963436120750811, 3.8960992552818836, 4.841545043053789, 5.782122880036838, 6.707244210288844, 7.6871135881573665, 8.691862898402787, 9.72761044943841, 10.706477158769067, 11.48539562241892, 12.43458788780357, 11.578082378382577, 10.651268549869235, 9.677015237444207, 8.649597872260706, 8.687649474436139, 7.7356029648445, 6.91456771061278, 5.899869905932238, 4.945252290189635, 4.022450040326175, 4.843361222104303, 5.870511664892163, 6.807320021348502, 7.709592098091303, 8.677618736319587, 9.603145066459216, 10.590222397983725, 11.632964521249022, 12.51654110944417, 13.505668716348296, 12.600212440217305, 11.656871285099337, 10.622046546501801, 9.652477191254235, 9.686991937551095, 8.67587053441835, 7.857199219349173, 6.88907971959032, 5.898071852279988, 4.968491912468992, 5.808284759423279, 6.74595915552161, 7.7942917313156705, 8.64071655671535, 9.668170682882222, 10.583719525836557, 11.526408123939348, 12.54119304464558, 13.452483990337734, 14.476748934397047, 13.629958318737897, 12.641270941653318, 11.600726322910583, 10.664468387047808, 10.628147274946642, 9.686621894101082, 8.790454191579096, 7.794259362340166, 6.868897866355134, 6.021243531897816, 6.847820148326553, 7.726359677676053, 8.681649568774665, 9.650327391568089, 10.608972390639247, 11.611688144923251, 12.550501527213909, 13.565213528244715, 14.09412184326232, 14.785490758936614, 14.570773647328695, 13.556232920882039, 12.612327141592914, 11.575166487819343, 11.687391907289825, 10.720844415343755, 9.785105358011444, 8.72512967755299, 7.894826240888431, 6.9532699016174035, 7.821884068393461, 8.68652222228447, 9.741694384182633, 10.655483196316165, 11.612388247189934, 12.595261553617167, 13.487799379744438, 14.011630449238597, 13.142682949322294, 13.758154553597672, 14.737778866634839, 14.603599948669695, 13.56953277743048, 12.5830837792693, 12.687726577342918, 11.766007420705575, 10.743001725888579, 9.697795580460117, 8.8985736828238, 8.028073539181165, 8.826594804574547, 9.649868838261147, 10.622312689144866, 11.62271493376511, 12.565952882476612, 13.588085696521466, 13.860317453930486, 13.067612318532227, 12.127880174515207, 12.785218191149827, 13.73869675706238, 14.768590632747472, 14.540613267848572, 13.631895463997338, 13.653833225612198, 12.697226755056358, 11.718758522539359, 10.77173799791389, 9.879932866672961, 9.001287878790446, 9.900451356110327, 10.712301818891923, 11.6843588882622, 12.61478032048413, 13.58180178167338, 13.820153200596199, 12.928835690800934, 12.059462078790602, 11.088337705273538, 11.832352488486707, 12.783514849527156, 13.83921796059015, 14.747160119272497, 14.603830534166873, 14.66669113021754, 13.676209006972677, 12.739222513275251, 11.77575892198401, 10.902904803677309, 9.928420075967512, 10.874018850619013, 11.70836640468216, 12.73729431324282, 13.650730559534205, 13.854411764974586, 12.86101554179844, 11.91600541874586, 11.034028417452644, 10.108713500066022, 10.876882371980772, 11.8961093559548, 12.783321519396063, 13.727888435730423, 14.60518681955358, 14.72812174727753, 14.710011942471594, 13.749359977805678, 12.776729327415024, 11.86440212799793, 10.870735977229687, 11.808938670765128, 12.678966037461095, 13.620721442946595, 13.794988918272342, 12.987069575199756, 11.962323622589212, 10.988030599799409, 10.058611763327663, 9.166418306212888, 9.90834001512716, 10.8976053542134, 11.771334635785003, 12.727161667706138, 13.678348378831737], [13.652450663844405, 12.693475408571475, 11.714138395134263, 10.840293204992006, 9.812058565360958, 9.06364935559188, 8.163122907503285, 9.178007012230914, 10.006598598524572, 11.001275096319787, 11.849520470864416, 12.70249818206382, 12.728514770329632, 11.83434993729767, 12.642059264192397, 13.630536884313294, 14.587922363286886, 15.612294960515161, 15.520670064929291, 14.662628295804446, 12.685888440184804, 11.734862100566076, 10.72362551683026, 9.841879529959632, 8.7820291361818, 8.084447437274624, 7.212996203883095, 8.203864441427672, 8.951052792131483, 9.96446749913196, 10.906452618101778, 11.640218393250757, 12.590710014189916, 12.796813527625043, 13.569187259763051, 14.63641768886193, 15.51337004077619, 15.52783099334328, 14.472580069096763, 13.72564765098992, 11.642165787151077, 10.701010647328186, 9.744251055499596, 8.853216302345706, 7.854375869538376, 7.044847708375077, 6.210266104547575, 7.144571557952931, 7.934615600425378, 8.941870320956372, 9.885606924637333, 10.640433083310898, 11.575494388514384, 12.566256238158882, 13.540555011420643, 14.479188046946767, 15.419078869140058, 14.56238488750202, 13.547181918013596, 12.687615140734653, 10.675866685744607, 9.740343336435117, 8.760407134189517, 7.831798114684867, 6.792538603135492, 6.061518561683701, 5.203676823037163, 6.077503397963376, 6.918697146634084, 7.895422537468549, 8.826548111883959, 9.65206821749025, 10.615971498586376, 11.578519938942126, 12.553748044269597, 13.597778373238475, 14.4900449586374, 13.55492688283069, 12.561347729669151, 11.698496399690761, 9.750291034320993, 8.801329414457468, 7.7730243584278265, 6.819779127631248, 5.810276681375152, 5.005559868519699, 4.149706751977409, 5.013635825260717, 5.926571036509712, 6.87081550962368, 7.771332384551906, 8.7126985170777, 9.74731665309405, 10.68938632834558, 11.574918798040015, 12.597181174488748, 13.558890596696484, 12.633894582033118, 11.615484947806232, 10.765731140981668, 8.754716581667426, 7.7762621538829375, 6.8270242574479125, 5.901637339804073, 4.867713844754775, 3.95475534217534, 3.1050310151158045, 4.051328958126254, 4.994617678874526, 5.853220600311, 6.799367491966473, 7.751768893224117, 8.742287864762279, 9.671246813097403, 10.649057183022533, 11.628294705720338, 12.555627706605328, 11.71274295812646, 10.66780292034867, 9.705059640928102, 7.810685838872376, 6.796513789916557, 5.835331313324439, 4.874219678788577, 3.896942107103884, 2.9844419000962215, 2.0428203389008646, 3.01268819532547, 3.974112402932865, 4.9114666923890375, 5.838248937585294, 6.767356560656344, 7.749524401827909, 8.783132562003997, 9.812906515709257, 10.767085662965972, 11.715627626443704, 10.736881020726566, 9.728488727170173, 8.7959338056031, 6.830884015421321, 5.830425016004785, 4.853020236173003, 3.8431427332070944, 2.8715862582244878, 1.9786122067057257, 1.0665288920099854, 2.0313062113923053, 3.011192638047545, 3.9699926557783796, 4.8769432326111755, 5.918212091563088, 6.827772278853291, 7.831352775340838, 8.758469596666583, 9.729466761574724, 10.659053361675362, 9.895898698295422, 8.84484448313824, 7.858847575728555, 5.873013018866626, 4.809828221556887, 3.8161275383974504, 2.8880899472194255, 1.9408256297254556, 0.9362810972306395, 0.0, 1.0272581893847161, 1.9918288254042213, 2.931778155728299, 3.864900040899404, 4.925239182084817, 5.863886017617547, 6.803284622675281, 7.832595791582257, 8.82027301804138, 9.747990600736944, 9.02260127379189, 7.955783656974677, 6.922376555828135, 6.801729863083478, 5.7965907878212874, 4.829813408131933, 3.848688331632739, 2.890799449038863, 1.8799195615246385, 0.9832071641411093, 1.9253419577455264, 2.96881984575274, 3.877538633041353, 4.833491037712036, 5.758664496449079, 6.697624731527946, 7.644233271858478, 8.631219864091404, 9.627046301795268, 10.56642973709718, 9.901882482568848, 8.877189315726115, 7.862421567715678, 7.790571453335085, 6.755898919511478, 5.811779253428552, 4.825210135246149, 3.824542096331275, 2.9436835424335057, 2.0316263634841096, 2.9771510101873764, 3.897783643029839, 4.8382469947927245, 5.808880838771321, 6.787707010191289, 7.721645316058108, 8.715890595925522, 9.588453093381542, 10.539261640076647, 11.52357504079917, 10.675953255740092, 9.711008407886105, 8.732956254322863, 8.63027359109843, 7.702320479152787, 6.792123124272819, 5.802844109684702, 4.864111759579362, 3.89971721798145, 2.9934639304146193, 3.9389097181865247, 4.848547648659842, 5.773668978911848, 6.75353835678037, 7.75828766702579, 8.79132935220777, 9.770196061538428, 10.54911452518828, 11.49830679057293, 12.462373800537566, 11.587549647099873, 10.613296334674846, 9.585878969491345, 9.62393057166678, 8.67188406207514, 7.85084880784342, 6.836151003162877, 5.881533387420275, 4.9240348467680635, 3.9407258972370385, 4.967876340024898, 5.873744789971506, 6.776016866714307, 7.744043504942592, 8.669569835082221, 9.65664716660673, 10.699389289872027, 11.580260012213529, 12.569387619117656, 13.484503862372295, 12.593152382329976, 11.558327643732442, 10.588758288484875, 10.623273034781736, 9.61215163164899, 8.793480316579812, 7.825360816820959, 6.834352949510627, 5.854301158155694, 4.9056494345560155, 5.843323830654346, 6.8607164999386745, 7.707141325338354, 8.734595451505225, 9.650144294459562, 10.592832892562352, 11.607617813268584, 12.516202893107094, 13.540467837166407, 14.524175344105075, 13.577552038883958, 12.537007420141224, 11.600749484278449, 11.564428372177282, 10.622902991331722, 9.726735288809735, 8.730540459570806, 7.805178963585774, 6.907052777584518, 5.9451848234592894, 6.823724352808789, 7.7790142439074, 8.747692066700825, 9.705914503121782, 10.678112913546256, 11.616926295836913, 12.63163829686772, 13.48036898995223, 14.466375790278796, 15.480528500904455, 14.49251401811268, 13.548608238823554, 12.511447585049984, 12.623673004520466, 11.657125512574396, 10.721386455242083, 9.661410774783631, 8.831107338119072, 7.839079147304106, 6.919248743526198, 7.783886897417206, 8.839059059315368, 9.752847871448902, 10.70933035967247, 11.661686322240172, 12.554224148367442, 13.166483443042534, 14.058642913006432, 14.69443565082831, 15.674059963865478, 15.539881045900335, 14.50581387466112, 13.51936487649994, 13.624007674573559, 12.702288517936216, 11.679282823119218, 10.634076677690757, 9.83485478005444, 8.858496360821155, 7.923959479707284, 8.747233513393883, 9.719677364277603, 10.720079608897846, 11.662894994959148, 12.685027809004001, 12.989377636764027, 12.222465312336164, 13.043840138199345, 13.721499288380466, 14.674977854293019, 15.70487172997811, 15.476894365079213, 14.568176561227979, 14.590114322842838, 13.633507852286998, 12.65503961977, 11.70801909514453, 10.816213963903602, 9.831710700430436, 8.997816031243064, 9.80966649402466, 10.781723563394937, 11.712144995616868, 12.678743894155916, 12.94921338342974, 12.057895873634475, 11.21431507259454, 12.004297668957676, 12.768633585717346, 13.719795946757795, 14.775499057820788, 15.683441216503134, 15.540111631397513, 15.60297222744818, 14.612490104203317, 13.675503610505892, 12.712040019214651, 11.7333276253173, 10.758842897607503, 9.97138352575175, 10.805731079814896, 11.834658988375558, 12.748095234666943, 12.983471947808127, 11.990075724631982, 11.0450656015794, 10.163088600286185, 11.02467346375016, 11.81316346921141, 12.83239045318544, 13.7196026166267, 14.66416953296106, 15.541467916784217, 15.664402844508167, 15.646293039702234, 14.685641075036319, 13.643120131741936, 12.694824949637919, 11.701158798869677, 10.906303345897864, 11.77633071259383, 12.71808611807933, 12.858707821041701, 12.07143924168709, 11.068747079275827, 10.11709078263295, 9.187671946161204, 10.082378269897026, 10.8446211123578, 11.83388645144404, 12.70761573301564, 13.663442764936775, 14.614629476062374], [14.679708853229123, 13.720733597956192, 12.74139658451898, 11.867551394376724, 10.839316754745676, 9.931662677578379, 8.94049719068375, 8.226254207904946, 8.979340409139857, 9.974016906935073, 10.8222622814797, 11.675239992679103, 11.899549335336955, 12.76995717382899, 13.577666500723717, 14.566144120844614, 15.523529599818206, 16.547902197046483, 16.54792825431401, 15.689886485189163, 13.713146629569522, 12.762120289950794, 11.750883706214976, 10.86913771934435, 9.809287325566517, 8.952460759261124, 7.990370487063561, 7.176606252042955, 7.923794602746767, 8.937209309747246, 9.879194428717062, 10.612960203866042, 11.5634518248052, 12.57987899722247, 13.461589401628757, 14.434422386844544, 15.448251697557973, 16.37657354222215, 15.499838258481478, 14.752905840374638, 12.669423976535795, 11.728268836712903, 10.771509244884312, 9.880474491730423, 8.881634058923092, 7.912861030361576, 6.987640387728041, 6.1173133685682135, 6.907357411040662, 7.914612131571657, 8.858348735252617, 9.613174893926182, 10.548236199129668, 11.538998048774166, 12.513296822035928, 13.451929857562051, 14.401788590766797, 15.454484184360993, 14.574440107398312, 13.71487333011937, 11.703124875129324, 10.767601525819835, 9.787665323574233, 8.859056304069583, 7.819796792520208, 6.9295318836702, 5.981051106217628, 5.050245208578659, 5.891438957249369, 6.868164348083833, 7.799289922499242, 8.624810028105534, 9.58871330920166, 10.55126174955741, 11.52648985488488, 12.570520183853759, 13.499038810293891, 14.4341568861006, 13.588605919053867, 12.725754589075478, 10.77754922370571, 9.828587603842186, 8.800282547812543, 7.847037317015964, 6.8375348707598675, 5.972378532181988, 4.927081035157875, 3.986377635876001, 4.899312847124996, 5.843557320238964, 6.74407419516719, 7.685440327692984, 8.720058463709332, 9.662128138960865, 10.547660608655299, 11.569922985104032, 12.531632407311768, 13.460495757088971, 12.642743137190948, 11.792989330366384, 9.781974771052141, 8.803520343267655, 7.854282446832629, 6.9288955291887895, 5.8949720341394904, 4.929775983729423, 3.9926005299383585, 3.0240707687415376, 3.96735948948981, 4.825962410926284, 5.772109302581757, 6.724510703839401, 7.715029675377562, 8.643988623712687, 9.621798993637817, 10.601036516335622, 11.528369517220613, 12.584730723917453, 11.695061109733386, 10.732317830312818, 8.837944028257093, 7.823771979301274, 6.862589502709156, 5.901477868173294, 4.9242002964886, 3.9741474652537865, 3.0325259040584296, 1.985430005940754, 2.946854213548149, 3.884208503004321, 4.810990748200578, 5.740098371271628, 6.722266212443193, 7.755874372619282, 8.78564832632454, 9.739827473581258, 10.688369437058988, 11.632796033756307, 10.755746916554891, 9.823191994987818, 7.858142204806038, 6.857683205389502, 5.880278425557719, 4.870400922591811, 3.898844447609204, 3.005870396090442, 2.071425916323059, 1.0040480220075894, 1.9839344486628288, 2.9427344663936634, 3.8496850432264598, 4.890953902178373, 5.800514089468575, 6.804094585956122, 7.731211407281867, 8.702208572190008, 9.631795172290646, 10.570750496642669, 9.872102672522958, 8.886105765113273, 6.9002712082513415, 5.837086410941604, 4.843385727782167, 3.9153481366041416, 2.9680838191101717, 1.9635392866153556, 1.0272581893847161, 0.0, 0.9645706360195052, 1.904519966343583, 2.8376418515146877, 3.8979809927001012, 4.836627828232832, 5.776026433290565, 6.805337602197541, 7.7930148286566645, 8.720732411352229, 9.794307449686201, 8.983041846359392, 7.949634745212851, 7.817694887126448, 6.812555811864256, 5.8418521785038315, 4.860727102004637, 3.902838219410761, 2.8919583318965367, 1.9188144006724301, 0.9766796070680132, 2.020157495075227, 2.8502804436566374, 3.8062328483273196, 4.731406307064362, 5.670366542143229, 6.616975082473761, 7.603961674706688, 8.599788112410552, 9.539171547712463, 10.613430176061982, 9.893154339769085, 8.878386591758648, 8.802610223706983, 7.767937689883376, 6.823818023800451, 5.837248905618046, 4.836580866703173, 3.955722312805404, 2.9672336000154305, 2.028488659509863, 2.949121292352326, 3.810988805408009, 4.7816226493866045, 5.760448820806572, 6.694387126673392, 7.688632406540805, 8.561194903996824, 9.51200345069193, 10.496316851414452, 11.507938927541504, 10.723047178258003, 9.744995024694761, 9.642312361470328, 8.714359249524685, 7.804161894644717, 6.814882880056599, 5.87615052995126, 4.861734301477013, 3.92907116694594, 3.0181963594533294, 3.8998852979823284, 4.825006628234335, 5.732972207684132, 6.737721517929552, 7.764071162823052, 8.74293787215371, 9.521856335803562, 10.471048601188212, 11.435115611152849, 12.361929439666191, 11.625335105046744, 10.597917739863243, 10.635969342038678, 9.683922832447038, 8.862887578215318, 7.848189773534775, 6.8693936386760885, 5.859642083299385, 4.87633313376836, 4.060612233134931, 4.925082439293993, 5.827354516036793, 6.782439658750228, 7.665258780074276, 8.652336111598785, 9.695078234864082, 10.553001822828811, 11.542129429732938, 12.457245672987577, 13.367532174896294, 12.57036641410434, 11.600797058856774, 11.635311805153634, 10.624190402020888, 9.80551908695171, 8.837399587192857, 7.804570513258989, 6.789908394687016, 5.841256671087336, 5.014358395661668, 5.912054149261161, 6.75847897466084, 7.785933100827712, 8.645833239451616, 9.588521837554408, 10.60330675826064, 11.488944703722376, 12.51320964778169, 13.496917154720357, 14.418428977148496, 13.549046190513122, 12.612788254650347, 12.57646714254918, 11.63494176170362, 10.696952852558097, 9.700758023319167, 8.775396527334136, 7.84266001411584, 6.88079205999061, 5.99475891781611, 6.950048808914722, 7.820594662002459, 8.75725215244427, 9.67380185853831, 10.61261524082897, 11.627327241859774, 12.453110800567513, 13.439117600894079, 14.453270311519738, 15.380694242760963, 14.560647009195453, 13.523486355421882, 13.635711774892364, 12.669164282946294, 11.691604018990445, 10.631628338531993, 9.801324901867433, 8.774686383835427, 7.854855980057518, 6.954921462424528, 8.010093624322689, 8.825750466750536, 9.760668008994957, 10.657375267232226, 11.549913093359496, 12.589741846161665, 13.404549694507539, 14.397122841848944, 15.376747154886111, 16.33570378711963, 15.517852645033019, 14.531403646871839, 14.636046444945457, 13.697126504221583, 12.64950038686758, 11.604294241439119, 10.805072343802802, 9.794103597352475, 8.859566716238604, 7.918268078401206, 8.890711929284926, 9.824824202713685, 10.714232644281635, 11.701028939058311, 12.141188135053897, 12.99983959551663, 13.911853460185844, 14.748757477765183, 15.702236043677736, 16.73212991936283, 16.488933135451113, 15.580215331599877, 15.602153093214737, 14.628345838572365, 13.625257183518361, 12.678236658892892, 11.76255309005674, 10.767317936961756, 9.933423267774383, 8.980701059031983, 9.952758128402259, 10.883179560624189, 11.730081543478404, 11.987610403422476, 11.209706371924344, 11.991689355775005, 12.872310990944175, 13.795891775102064, 14.747054136142513, 15.802757247205506, 16.71069940588785, 16.55215040176941, 16.61501099782008, 15.607328090488684, 14.645721174254254, 13.682257582963013, 12.66893486184862, 11.694450134138823, 10.906990762283069, 9.976765644822219, 11.00569355338288, 11.919129799674264, 12.021868967800863, 11.028472744624718, 10.19687609986927, 10.940462883466651, 11.89268678573666, 12.840421658596128, 13.859648642570157, 14.746860806011417, 15.691427722345777, 16.568726106168935, 16.691661033892885, 16.58638730445922, 15.625735339793303, 14.578727368273258, 13.63043218616924, 12.636766035400997, 11.841910582429184, 10.947365277601154, 11.889120683086654, 11.831449631656987, 11.044181052302376, 10.041488889891111, 9.268901280922819, 9.96504622934167, 10.950391591883525, 11.871879301742517, 12.861144640828757, 13.734873922400357, 14.690700954321493, 15.641887665447092], [15.644279489248628, 14.685304233975698, 13.705967220538486, 12.83212203039623, 11.803887390765182, 10.854138777151116, 9.862973290256486, 8.954426910319452, 8.014769773120351, 9.009446270915566, 9.857691645460195, 10.710669356659597, 11.635955312896098, 12.577771951530337, 13.424146761179905, 14.412624381300802, 15.370009860274394, 16.39438245750267, 17.395308585111525, 16.65445712120867, 14.677717265589028, 13.7266909259703, 12.715454342234482, 11.833708355363855, 10.773857961586023, 9.87493685883386, 8.912846586636297, 8.01098659252067, 6.9592239667272615, 7.972638673727739, 8.914623792697556, 9.648389567846536, 10.598881188785695, 11.615308361202965, 12.497018765609251, 13.469851750825038, 14.483681061538467, 15.412002906202645, 16.371429876586884, 15.717476476394143, 13.6339946125553, 12.692839472732409, 11.736079880903818, 10.845045127749929, 9.846204694942598, 8.835337129934313, 7.910116487300777, 6.958449763803536, 5.9427867750211565, 6.950041495552151, 7.893778099233112, 8.648604257906676, 9.583665563110163, 10.57442741275466, 11.548726186016422, 12.487359221542546, 13.437217954747291, 14.489913548341487, 15.446031725503717, 14.679443966138876, 12.66769551114883, 11.73217216183934, 10.752235959593738, 9.823626940089088, 8.784367428539714, 7.852007983242936, 6.903527205790365, 5.912418671388143, 4.926868321229863, 5.903593712064327, 6.834719286479737, 7.660239392086028, 8.624142673182154, 9.586691113537904, 10.561919218865375, 11.605949547834253, 12.534468174274386, 13.469586250081095, 14.460197537159273, 13.690325225094984, 11.742119859725216, 10.793158239861691, 9.764853183832049, 8.81160795303547, 7.802105506779373, 6.936949168201494, 5.891651671177381, 4.9509482718955065, 3.9347422111054904, 4.878986684219458, 5.779503559147685, 6.720869691673478, 7.755487827689827, 8.69755750294136, 9.583089972635793, 10.605352349084527, 11.567061771292263, 12.495925121069465, 13.514334755296353, 12.75755996638589, 10.746545407071647, 9.76809097928716, 8.818853082852135, 7.893466165208294, 6.859542670158996, 5.8943466197489265, 4.957171165957863, 3.988641404761043, 3.002788853470305, 3.861391774906778, 4.807538666562252, 5.759940067819896, 6.750459039358057, 7.6794179876931805, 8.657228357618312, 9.636465880316116, 10.563798881201107, 11.620160087897947, 12.659631745752892, 11.696888466332323, 9.802514664276599, 8.78834261532078, 7.827160138728661, 6.866048504192799, 5.8887709325081055, 4.938718101273292, 3.997096540077935, 2.9500006419602594, 1.9822835775286438, 2.9196378669848158, 3.8464201121810735, 4.7755277352521235, 5.757695576423688, 6.791303736599777, 7.821077690305036, 8.775256837561752, 9.723798801039482, 10.668225397736801, 11.676617691293194, 10.787762631007324, 8.822712840825544, 7.822253841409007, 6.844849061577224, 5.834971558611316, 4.863415083628709, 3.9704410321099473, 3.0359965523425645, 1.9686186580270946, 1.0193638126433235, 1.9781638303741582, 2.8851144072069546, 3.926383266158867, 4.83594345344907, 5.839523949936616, 6.766640771262361, 7.737637936170501, 8.66722453627114, 9.606179860623163, 10.657234075780345, 9.850676401132779, 7.864841844270847, 6.801657046961109, 5.807956363801672, 4.879918772623647, 3.9326544551296774, 2.928109922634861, 1.9918288254042213, 0.9645706360195052, 0.0, 0.9399493303240779, 1.8730712154951827, 2.933410356680596, 3.8720571922133264, 4.811455797271059, 5.840766966178036, 6.828444192637159, 7.756161775332723, 8.829736813666695, 9.896554430483908, 8.914205381232357, 8.782265523145952, 7.777126447883761, 6.806422814523336, 5.825297738024142, 4.867408855430266, 3.8565289679160424, 2.8833850366919354, 1.9412502430875183, 1.068805799475112, 1.8857098076371321, 2.8416622123078144, 3.766835671044857, 4.705795906123725, 5.652404446454256, 6.639391038687183, 7.635217476391047, 8.57460091169296, 9.64885954004248, 10.673552706885213, 9.842957227778152, 9.767180859726489, 8.73250832590288, 7.788388659819955, 6.801819541637552, 5.8011515027226785, 4.92029294882491, 3.9318042360349357, 2.9636490486361615, 1.9977695967522107, 2.846418169388504, 3.8170520133670998, 4.7958781847870675, 5.729816490653887, 6.724061770521301, 7.596624267977321, 8.547432814672426, 9.531746215394948, 10.543368291522, 11.508313139375987, 10.709565660714267, 10.606882997489832, 9.67892988554419, 8.768732530664222, 7.779453516076105, 6.840721165970765, 5.826304937496519, 4.893641802965446, 3.953356748579628, 2.9485336023822133, 3.8684138498564584, 4.7684015716646275, 5.773150881910047, 6.799500526803548, 7.7783672361342076, 8.557285699784059, 9.506477965168708, 10.470544975133345, 11.397358803646688, 12.371612116071715, 11.562488375882747, 11.600539978058181, 10.648493468466542, 9.827458214234822, 8.812760409554281, 7.833964274695594, 6.824212719318891, 5.840903769787865, 4.942747459737162, 3.9737307436938774, 4.870761737658917, 5.817869022730723, 6.700688144054771, 7.68776547557928, 8.730507598844577, 9.588431186809308, 10.577558793713434, 11.492675036968073, 12.40296153887679, 13.357944526193393, 12.565367694876276, 12.599882441173138, 11.588761038040392, 10.770089722971216, 9.801970223212363, 8.769141149278495, 7.754479030706522, 6.805827307106842, 5.8964936222638995, 4.960702453661045, 5.801886196282964, 6.829340322449836, 7.681262603432111, 8.623951201534902, 9.638736122241134, 10.524374067702873, 11.548639011762186, 12.532346518700853, 13.453858341128992, 14.336624302602175, 13.577358890669851, 13.541037778568684, 12.599512397723124, 11.661523488577602, 10.665328659338673, 9.739967163353642, 8.807230650135345, 7.845362696010116, 6.876894144418342, 6.024831353112669, 6.864001883624582, 7.800659374066393, 8.709231222518806, 9.648044604809463, 10.662756605840269, 11.48854016454801, 12.474546964874575, 13.488699675500234, 14.41612360674146, 15.360029386030584, 14.488056991441386, 14.600282410911868, 13.633734918965798, 12.65617465500995, 11.596198974551498, 10.765895537886939, 9.739257019854932, 8.819426616077024, 7.83705668902676, 7.084876168520637, 7.86915768837266, 8.80407523061708, 9.692804631212724, 10.58534245733999, 11.62517121014216, 12.439979058488035, 13.43255220582944, 14.412176518866607, 15.371133151100127, 16.379129059894705, 15.495974282891343, 15.60061708096496, 14.661697140241088, 13.614071022887085, 12.568864877458624, 11.769642979822308, 10.75785104091945, 9.823314159805578, 8.800403305003437, 8.079266903431101, 8.86823142433581, 9.757639865903759, 10.736458303038809, 11.543883394213813, 12.556304300947222, 13.454781833295122, 14.405488568277285, 15.411475439281238, 16.390308916430584, 17.350209550312798, 16.544785967619383, 16.56672372923424, 15.59291647459187, 14.589827819537867, 13.642807294912398, 12.726300533623714, 11.731065380528731, 10.88465306841087, 9.862836285634213, 9.141313102548434, 9.934559289840735, 10.773488765100527, 11.02303976740297, 11.93787907433885, 12.898536308882885, 13.794787090516913, 14.76046241112157, 15.711624772162018, 16.76732788322501, 17.675270041907353, 17.516721037788916, 17.57958163383958, 16.571898726508188, 15.61029181027376, 14.646828218982519, 13.632682305415594, 12.658197577705797, 11.858220562919556, 10.85890087142445, 10.194248527529055, 10.97050952889081, 11.057298331781357, 10.063902108605213, 10.925048802283776, 11.862938983039387, 12.815162885309396, 13.804992294615634, 14.824219278589663, 15.711431442030923, 16.65599835836528, 17.53329674218844, 17.65623166991239, 17.550134748026196, 16.58948278336028, 15.542474811840231, 14.594179629736214, 13.600513478967972, 12.793140383065671, 11.829500504203384, 11.224541957496088, 10.866878995637482, 10.079610416282868, 9.076918253871606, 9.997073983337325, 10.887522328914406, 11.872867691456262, 12.836449937762023, 13.825715276848262, 14.699444558419863, 15.655271590340998, 16.6064583014666], [16.559204205658933, 15.600228950386002, 14.62089193694879, 13.680255512473469, 12.65202087284242, 11.700326179893226, 10.709160692998596, 9.800614313061562, 8.860957175862461, 8.15500296336354, 8.917742315136117, 9.770720026335518, 10.696005982572018, 11.637822621206258, 12.484197430855826, 13.472675050976722, 14.430060529950314, 15.45443312717859, 16.455359254787446, 17.482096851137552, 15.600981714676031, 14.64987812130375, 13.630379058644786, 12.681841837441095, 11.621991443663262, 10.721124261575971, 9.759033989378407, 8.85717399526278, 7.805411369469372, 7.118195366175714, 7.974674462373478, 8.708440237522456, 9.658931858461616, 10.675359030878885, 11.557069435285172, 12.529902420500958, 13.543731731214388, 14.472053575878565, 15.431480546262804, 16.476605793416056, 14.557259061642304, 13.616103921819413, 12.659344329990821, 11.693178609827168, 10.694338177019837, 9.681524532676423, 8.756303890042888, 7.804637166545646, 6.788974177763267, 6.0955981880001255, 6.953828768909034, 7.708654927582597, 8.643716232786083, 9.634478082430581, 10.608776855692343, 11.547409891218466, 12.497268624423212, 13.549964218017408, 14.506082395179638, 15.45791172485147, 13.6052996181501, 12.66977626884061, 11.68493410061045, 10.7563250811058, 9.717065569556425, 8.698195385985047, 7.749714608532475, 6.758606074130253, 5.773055723971973, 5.036922468355311, 5.894769956155659, 6.720290061761949, 7.684193342858075, 8.646741783213825, 9.621969888541296, 10.666000217510174, 11.594518843950306, 12.529636919757015, 13.520248206835193, 14.528830890757273, 12.679723966726486, 11.730762346862962, 10.702457290833319, 9.744306094052181, 8.734803647796085, 7.807263572452989, 6.761966075428876, 5.821262676147001, 4.780929613847601, 3.970383832510616, 4.839554228823607, 5.7809203613493985, 6.815538497365748, 7.757608172617281, 8.643140642311714, 9.665403018760447, 10.627112440968183, 11.555975790745386, 12.574385424972274, 13.630469712556904, 11.686494737395725, 10.705695086288431, 9.756457189853405, 8.831070272209566, 7.792240811175708, 6.7646610240004215, 5.827485570209358, 4.858955809012538, 3.8489762562124152, 2.9214424445827003, 3.8675893362381735, 4.819990737495817, 5.810509709033978, 6.739468657369102, 7.717279027294232, 8.696516549992037, 9.623849550877027, 10.680210757573867, 11.733207328313611, 12.569798212503338, 10.742463994600676, 9.728291945644857, 8.76710946905274, 7.805997834516877, 6.828720262832183, 5.8786674315973695, 4.937045870402012, 3.8899499722843367, 2.9222329078527216, 1.979688536660738, 2.9064707818569957, 3.8355784049280457, 4.8177462460996106, 5.851354406275699, 6.881128359980958, 7.835307507237674, 8.783849470715404, 9.728276067412725, 10.736668360969118, 11.640367882740497, 9.76266217114962, 8.762203171733084, 7.784798391901302, 6.774920888935394, 5.803364413952787, 4.9103903624340255, 3.975945882666642, 2.908567988351172, 1.9593131429674013, 1.0382145000500804, 1.9451650768828768, 2.986433935834789, 3.895994123124992, 4.8995746196125385, 5.8266914409382835, 6.797688605846424, 7.727275205947063, 8.666230530299085, 9.717284745456267, 10.703281652865952, 8.804791174594925, 7.741606377285187, 6.74790569412575, 5.819868102947725, 4.872603785453755, 3.868059252958939, 2.931778155728299, 1.904519966343583, 0.9399493303240779, 0.0, 0.9331218851711048, 1.9934610263565182, 2.9321078618892487, 3.8715064669469816, 4.900817635853958, 5.888494862313081, 6.816212445008645, 7.889787483342618, 8.95660510015983, 9.854154711556435, 9.72221485347003, 8.717075778207839, 7.746372144847414, 6.76524706834822, 5.807358185754344, 4.79647829824012, 3.823334367016013, 2.881199573411596, 1.876415412732536, 0.9457604773130541, 1.9017128819837366, 2.826886340720779, 3.765846575799647, 4.712455116130179, 5.699441708363105, 6.69526814606697, 7.634651581368881, 8.7089102097184, 9.733603376561133, 10.74837112457157, 10.707130190050568, 9.67245765622696, 8.728337990144034, 7.7417688719616296, 6.741100833046756, 5.831261494296866, 4.762801462581148, 3.7712586618935857, 2.805379210009635, 1.9064688390644258, 2.877102683043022, 3.8559288544629897, 4.789867160329809, 5.784112440197223, 6.656674937653243, 7.607483484348347, 8.591796885070869, 9.60341896119792, 10.568363809051908, 11.54641596261515, 11.546832327813911, 10.618879215868269, 9.708681860988301, 8.719402846400182, 7.708823051821257, 6.639075284140032, 5.706412149608958, 4.760966361837053, 3.7561432156396375, 2.92846451953238, 3.8284522413405497, 4.83320155158597, 5.859551196479471, 6.83841790581013, 7.61733636945998, 8.566528634844628, 9.530595644809265, 10.457409473322608, 11.431662785747635, 12.459080150931136, 12.540489308382261, 11.588442798790622, 10.767407544558901, 9.712043409496882, 8.646734621339107, 7.636983065962403, 6.653674116431378, 5.7503570729945865, 4.7813403569513016, 3.9308124073348383, 4.877919692406645, 5.760738813730693, 6.747816145255202, 7.790558268520498, 8.64848185648523, 9.637609463389355, 10.552725706643994, 11.46301220855271, 12.417995195869313, 13.38756455111688, 13.539831771497218, 12.528710368364472, 11.623284167882787, 10.655164668123934, 9.581911495922007, 8.567249377350034, 7.618597653750355, 6.704103235521324, 5.76831206691847, 4.861936865958885, 5.889390992125756, 6.741313273108033, 7.684001871210826, 8.698786791917058, 9.584424737378795, 10.608689681438108, 11.592397188376776, 12.513909010804912, 13.396674972278095, 14.34324441281205, 14.462280497085946, 13.520755116240386, 12.474293835221117, 11.478099005982187, 10.552737509997154, 9.620000996778858, 8.65813304265363, 7.684503757675767, 6.832440966370093, 5.924052553300504, 6.860710043742314, 7.769281892194727, 8.708095274485387, 9.722807275516193, 10.548590834223932, 11.534597634550497, 12.548750345176156, 13.47617427641738, 14.420080055706505, 15.39835256339, 15.52152512942913, 14.521421648590314, 13.468945001653465, 12.408969321195013, 11.578665884530452, 10.552027366498445, 9.632196962720538, 8.644666302284184, 7.892485781778062, 6.929208358048581, 7.864125900293001, 8.752855300888644, 9.645393127015915, 10.685221879818084, 11.500029728163957, 12.492602875505362, 13.47222718854253, 14.431183820776049, 15.439179729570625, 16.406269854839955, 16.42028831598205, 15.474467486884603, 14.4268413695306, 13.381635224102139, 12.58241332646582, 11.565460654176874, 10.630923773063003, 9.608012918260862, 8.886876516688526, 7.928282094011731, 8.817690535579679, 9.79650897271473, 10.603934063889737, 11.616354970623146, 12.514832502971045, 13.465539237953207, 14.47152610895716, 15.450359586106504, 16.410260219988718, 17.385483634245606, 17.386394964251327, 16.405686821235385, 15.402598166181381, 14.455577641555912, 13.533910146881139, 12.538674993786156, 11.692262681668295, 10.670445898891638, 9.925031391738585, 8.994609959516655, 9.833539434776448, 10.79627217514539, 11.535415827019289, 12.496073061563324, 13.467197435080388, 14.418404940616327, 15.369567301656776, 16.42527041271977, 17.337505527749585, 18.283458875605216, 18.399252868856667, 17.384669073151702, 16.423062156917275, 15.459598565626033, 14.440291918673019, 13.465807190963222, 12.66583017617698, 11.666510484681874, 10.977966816719206, 10.03056019856673, 10.24465048197838, 10.910089511347323, 11.771236205025886, 12.709126385781497, 13.661350288051507, 14.653125776692873, 15.672352760666902, 16.6132050901103, 17.557772006444658, 18.448221458598745, 18.38074188255297, 17.369056896817796, 16.408404932151882, 15.430784668970661, 14.482489486866644, 13.425097896178546, 12.565869212606064, 11.648190040307819, 10.81055723349575, 9.926929665313402, 9.225167108730842, 9.923105656613716, 10.843261386079435, 11.733709731656516, 12.719055094198373, 13.684583419839262, 14.673848758925502, 15.614369274830167, 16.570196306751303, 17.521383017876904], [17.489633950680144, 16.53065869540721, 15.551321681969998, 14.610685257494676, 13.582450617863628, 12.630755924914434, 11.639590438019804, 10.73104405808277, 9.791386920883669, 9.085432708384747, 8.044965961551307, 8.877071415543154, 9.802357371779655, 10.744174010413895, 11.590548820063463, 12.579026440184359, 13.53641191915795, 14.560784516386226, 15.561710643995083, 16.58844824034519, 16.53141145969724, 15.580307866324958, 14.560808803665994, 13.612271582462302, 12.55242118868447, 11.651554006597179, 10.689463734399615, 9.787603740283988, 8.73584111449058, 8.048625111196921, 7.101898108788669, 7.814791626730092, 8.765283247669252, 9.781710420086522, 10.663420824492809, 11.636253809708595, 12.650083120422025, 13.578404965086202, 14.537831935470443, 15.582957182623693, 15.487688806663511, 14.54653366684062, 13.589774075012029, 12.623608354848376, 11.624767922041045, 10.611954277697631, 9.686733635064096, 8.735066911566852, 7.7194039227844735, 7.026027933021333, 6.0810524153242245, 6.8150063167902335, 7.75006762199372, 8.740829471638218, 9.71512824489998, 10.653761280426103, 11.603620013630849, 12.656315607225045, 13.612433784387276, 14.56426311405911, 14.520697131412545, 13.600206013861818, 12.61536384563166, 11.686754826127009, 10.647495314577634, 9.628625131006254, 8.680144353553683, 7.68903581915146, 6.70348546899318, 5.967352213376518, 5.02199360257085, 5.826641450969586, 6.790544732065712, 7.753093172421462, 8.728321277748934, 9.772351606717812, 10.700870233157945, 11.635988308964654, 12.626599596042832, 13.635182279964912, 13.595121479988931, 12.66119209188417, 11.632887035854527, 10.67473583907339, 9.665233392817294, 8.737693317474195, 7.692395820450082, 6.751692421168208, 5.711359358868807, 4.900813577531823, 3.9667778752387983, 4.887271750557036, 5.9218898865733856, 6.8639595618249185, 7.7494920315193525, 8.771754407968086, 9.733463830175822, 10.662327179953024, 11.680736814179912, 12.697347827385798, 12.587019386592909, 11.636124831309639, 10.686886934874613, 9.761500017230773, 8.722670556196917, 7.695090769021629, 6.757915315230565, 5.789385554033744, 4.779406001233622, 3.851872189603907, 2.9948129826533654, 3.9263421267034544, 4.916861098241616, 5.84582004657674, 6.82363041650187, 7.802867939199675, 8.730200940084666, 9.771016119641512, 10.8231019014944, 11.636676327332232, 11.67558587977178, 10.661413830815961, 9.700231354223844, 8.73911971968798, 7.7618421480032875, 6.811789316768474, 5.870167755573117, 4.823071857455442, 3.8553547930238268, 2.910118281681944, 1.9733488966858905, 2.9024565197569405, 3.884624360928506, 4.918232521104594, 5.948006474809853, 6.902185622066569, 7.850727585544298, 8.795154182241617, 9.80354647579801, 10.707245997569391, 10.695784056320724, 9.695325056904188, 8.717920277072407, 7.708042774106498, 6.736486299123891, 5.84351224760513, 4.9090677678377475, 3.8416898735222773, 2.8924350281385065, 1.9686442450712864, 1.0120431917117718, 2.0533120506636844, 2.962872237953887, 3.966452734441434, 4.893569555767178, 5.8645667206753185, 6.794153320775957, 7.733108645127979, 8.78416286028516, 9.770159767694846, 9.73791305976603, 8.674728262456291, 7.681027579296854, 6.752989988118829, 5.8057256706248594, 4.801181138130043, 3.864900040899404, 2.8376418515146877, 1.8730712154951827, 0.9331218851711048, 0.0, 1.0603391411854133, 1.9989859767181437, 2.938384581775877, 3.9676957506828527, 4.955372977141976, 5.88309055983754, 6.956665598171512, 8.023483214988726, 9.056890316135267, 10.655336738641134, 9.650197663378943, 8.679494030018517, 7.698368953519324, 6.740480070925448, 5.7296001834112245, 4.756456252187117, 3.8143214585827008, 2.809537297903641, 1.878882362484159, 0.9685909968126318, 1.8937644555496744, 2.832724690628542, 3.7793332309590735, 4.766319823192, 5.7621462608958645, 6.701529696197776, 7.775788324547295, 8.800481491390029, 9.815249239400465, 11.555678878431824, 10.605579541398061, 9.661459875315137, 8.674890757132733, 7.674222718217861, 6.76438337946797, 5.695923347752253, 4.704380547064691, 3.73850109518074, 2.839590724235531, 1.943980797871917, 2.922806969291885, 3.8567452751587044, 4.850990555026117, 5.723553052482138, 6.674361599177242, 7.658674999899763, 8.670297076026817, 9.635241923880804, 10.613294077444046, 12.479954212985012, 11.55200110103937, 10.641803746159404, 9.652524731571285, 8.641944936992362, 7.572197169311136, 6.639534034780063, 5.694088247008158, 4.689265100810743, 3.8615864047034854, 2.8953303561694446, 3.9000796664148645, 4.9264293113083655, 5.905296020639024, 6.684214484288875, 7.633406749673523, 8.59747375963816, 9.524287588151502, 10.498540900576529, 11.52595826576003, 13.473611193553362, 12.521564683961723, 11.700529429730004, 10.645165294667986, 9.579856506510211, 8.570104951133507, 7.586796001602482, 6.683478958165692, 5.714462242122407, 4.8639342925059434, 3.94479780723554, 4.827616928559588, 5.814694260084097, 6.857436383349393, 7.715359971314124, 8.704487578218249, 9.619603821472888, 10.529890323381604, 11.484873310698207, 12.454442665945773, 14.387598977137657, 13.461832253535572, 12.556406053053891, 11.588286553295038, 10.515033381093112, 9.500371262521139, 8.551719538921459, 7.637225120692429, 6.701433952089575, 5.79505875112999, 5.004249728951615, 5.808191387936928, 6.75087998603972, 7.765664906745952, 8.651302852207689, 9.675567796267002, 10.65927530320567, 11.580787125633806, 12.46355308710699, 13.410122527640944, 15.360480928038895, 14.45387700141149, 13.40741572039222, 12.411220891153292, 11.485859395168259, 10.553122881949962, 9.591254927824734, 8.617625642846871, 7.7655628515411985, 6.857174438471609, 5.975568780568173, 6.836160007023622, 7.774973389314281, 8.789685390345088, 9.615468949052826, 10.601475749379391, 11.61562846000505, 12.543052391246274, 13.486958170535399, 14.465230678218894, 16.419725560382076, 15.454543533761418, 14.402066886824569, 13.342091206366117, 12.511787769701556, 11.485149251669549, 10.565318847891643, 9.577788187455289, 8.825607666949168, 7.862330243219686, 6.9789846371188595, 7.819733415717539, 8.71227124184481, 9.75209999464698, 10.566907842992851, 11.559480990334256, 12.539105303371423, 13.498061935604943, 14.50605784439952, 15.473147969668851, 17.353410201153153, 16.407589372055707, 15.359963254701704, 14.314757109273243, 13.515535211636925, 12.498582539347979, 11.564045658234107, 10.541134803431966, 9.819998401859632, 8.861403979182835, 7.932549272405538, 8.863387087543625, 9.670812178718633, 10.683233085452041, 11.581710617799938, 12.532417352782101, 13.538404223786054, 14.517237700935398, 15.477138334817612, 16.4523617490745, 18.300334298988783, 17.33880870640649, 16.335720051352485, 15.388699526727017, 14.467032032052243, 13.47179687895726, 12.625384566839399, 11.603567784062742, 10.85815327690969, 9.92773184468776, 8.948398171602307, 9.875348024689767, 10.602293941848185, 11.56295117639222, 12.534075549909284, 13.48528305544522, 14.43644541648567, 15.492148527548663, 16.404383642578477, 17.35033699043411, 18.498320169653827, 17.479285622889215, 16.455897420260076, 15.473278932772665, 14.448249914358154, 13.473765186648357, 12.607140421959816, 11.72514106229439, 10.94720205267042, 10.127071969211528, 9.96314288033587, 10.834485683487525, 11.61512421390326, 12.594366996436843, 13.5136997551168, 14.440753171951156, 15.458467281921855, 16.39931961136525, 17.34388652769961, 18.30556991416196, 17.48709327176061, 16.475408286025434, 15.514756321359519, 14.537136058178296, 13.58884087607428, 12.531449285386183, 11.6722206018137, 10.754541429515456, 9.916908622703387, 9.054153311728594, 10.125720461593868, 10.853535401634923, 11.773691131100643, 12.664139476677724, 13.64948483921958, 14.61501316486047, 15.60427850394671, 16.544799019851375, 17.500626051772514, 18.451812762898115], [16.541334465904722, 17.498017793596546, 16.550460331643702, 15.60982390716838, 14.581589267537332, 13.629894574588135, 12.638729087693505, 11.73018270775647, 10.790525570557369, 9.808684003488224, 8.761548570633156, 7.928907134369824, 8.854193090606325, 9.796009729240565, 10.642384538890132, 11.630862159011029, 12.58824763798462, 13.612620235212896, 14.613546362821753, 15.64028395917186, 15.522428688258145, 16.442713447606522, 15.559947453339698, 14.611410232136006, 13.551559838358173, 12.65069265627088, 11.688602384073317, 10.786742389957688, 9.73497976416428, 8.771876406300397, 7.818480717870518, 6.866627345556762, 7.817118966495922, 8.833546138913192, 9.715256543319478, 10.688089528535265, 11.701918839248695, 12.630240683912872, 13.56753990905708, 14.61266515621033, 14.478706035224418, 15.408861994368632, 14.588912724685732, 13.622747004522079, 12.623906571714748, 11.611092927371333, 10.685872284737798, 9.734205561240554, 8.718542572458174, 7.817848294158344, 6.797635024406073, 5.866842035616903, 6.80190334082039, 7.792665190464888, 8.76696396372665, 9.705596999252773, 10.655455732457519, 11.699134732381921, 12.642141757973913, 13.593971087645746, 13.460357990227132, 14.39777205524743, 13.61450249530536, 12.68589347580071, 11.646633964251334, 10.627763780679956, 9.679283003227384, 8.688174468825162, 7.702624118666881, 6.89300744544043, 5.932044567539619, 4.8784771697962555, 5.842380450892382, 6.804928891248132, 7.763759667372974, 8.807789996341851, 9.736308622781984, 10.671426698588693, 11.656307569629469, 12.607227502146417, 12.534782338803518, 13.483743958667043, 12.632025685528227, 11.67387448874709, 10.664372042490994, 9.736831967147896, 8.691534470123784, 7.750831070841909, 6.710498008542508, 5.826468809595735, 4.876828840207567, 3.939107469383705, 4.9737256054000545, 5.915795280651587, 6.784930421143391, 7.807192797592126, 8.768902219799863, 9.697765569577065, 10.71044478776655, 11.637008686200385, 11.526680245407496, 12.588419935886652, 11.686025584548313, 10.760638666904473, 9.721809205870617, 8.694229418695329, 7.757053964904266, 6.788524203707445, 5.778544650907323, 4.851010839277608, 3.9048639476221343, 2.9781778455301233, 3.9686968170682846, 4.8976557654034085, 5.85906880612591, 6.838306328823715, 7.752642088993944, 8.710676978456101, 9.762762760308988, 10.57633718614682, 10.646048247651457, 11.660220296607276, 10.760570495409258, 9.799458860873395, 8.822181289188702, 7.872128457953886, 6.93050689675853, 5.883410998640855, 4.91569393420924, 3.9503645952706434, 2.8833998616546594, 1.9542922385836095, 2.9356940674813163, 3.9097993003705165, 4.906588882696871, 5.858286764545678, 6.790388444358886, 7.734815041056206, 8.743207334612597, 9.646906856383978, 9.737784186816668, 10.738243186233204, 9.778259418257822, 8.768381915291913, 7.796825440309306, 6.903851388790544, 5.96940690902316, 4.902029014707691, 3.9527741693239196, 3.0202327449294217, 2.063631691569907, 1.0223628326179948, 1.902533096768474, 2.9061135932560207, 3.833230414581765, 4.804227579489905, 5.733814179590544, 6.6727695039425665, 7.723823719099748, 8.709820626509433, 9.045914711911362, 9.735067403641706, 8.741366720482269, 7.813329129304243, 6.866064811810274, 5.8615202793154575, 4.925239182084818, 3.8979809927001012, 2.933410356680596, 1.9934610263565182, 1.0603391411854133, 0.0, 0.9386468355327304, 1.8780454405904634, 2.9073566094974392, 3.8950338359565624, 4.8227514186521265, 5.896326456986099, 6.963144073803312, 7.996551174949853, 9.90837365047837, 10.701899779244421, 9.731196145883995, 8.7500710693848, 7.7921821867909244, 6.7813022992767005, 5.8081583680525934, 4.866023574448176, 3.822545686440962, 2.89189075102148, 1.914683212112675, 0.9895097533756322, 1.9243540788886964, 2.8117659374047794, 3.7987525296377065, 4.794578967341571, 5.733962402643482, 6.808221030993002, 7.832914197835734, 8.84768194584617, 10.58811158487753, 11.622784118701137, 10.713161991180614, 9.72659287299821, 8.725924834083337, 7.777391768005291, 6.708931736289574, 5.717388935602012, 4.751509483718061, 3.852599112772852, 2.89007301317196, 2.047883454381139, 2.948374663418859, 3.8834232614718234, 4.755985758927844, 5.706794305622949, 6.69110770634547, 7.702729782472522, 8.667674630326509, 9.645726783889751, 11.513996350598653, 12.441949462544295, 11.693505862024882, 10.702341051403415, 9.65495332552968, 8.585205557848456, 7.652542423317383, 6.707096635545478, 5.702273489348063, 4.82129194933801, 3.841422571469488, 3.102852493130424, 4.01805869956852, 4.93772872708473, 5.716647190734581, 6.66583945611923, 7.629906466083867, 8.55672029459721, 9.530973607022236, 10.558390972205737, 12.507653331167003, 13.411513045466648, 12.7300856848561, 11.658173683205309, 10.592864895047532, 9.583113339670827, 8.599804390139802, 7.696487346703012, 6.727470630659727, 5.823639837140469, 4.890890022535583, 4.030389755275148, 5.017467086799656, 6.003442072705953, 6.747792677759831, 7.736920284663955, 8.652036527918595, 9.562323029827311, 10.517306017143914, 11.48687537239148, 13.420031683583364, 14.351780615040498, 13.569414441591212, 12.601294941832359, 11.528041769630432, 10.51337965105846, 9.56472792745878, 8.65023350922975, 7.714442340626896, 6.754764295764516, 5.950341944251658, 5.010964214652487, 5.95365281275528, 6.968437733461512, 7.683735558653396, 8.708000502712709, 9.691708009651377, 10.613219832079514, 11.495985793552697, 12.442555234086651, 14.392913634484602, 15.334439015330162, 14.42042410892954, 13.42422927969061, 12.49886778370558, 11.566131270487283, 10.604263316362054, 9.630634031384192, 8.77857124007852, 7.816879983106134, 6.921660995868216, 6.038932833739182, 6.977746216029841, 7.992458217060647, 8.647901655498533, 9.633908455825098, 10.648061166450757, 11.575485097691981, 12.519390876981106, 13.497663384664602, 15.452158266827785, 16.368661536572837, 15.415075275361888, 14.355099594903436, 13.524796158238876, 12.49815764020687, 11.578327236428962, 10.59079657599261, 9.838616055486488, 8.822035787854212, 7.925076852418902, 7.022506242433098, 7.915044068560369, 8.954872821362539, 9.599340549438558, 10.591913696779963, 11.57153800981713, 12.53049464205065, 13.538490550845227, 14.505580676114558, 16.45249293688088, 17.398313765978326, 16.372971643239023, 15.327765497810562, 14.528543600174245, 13.5115909278853, 12.577054046771428, 11.554143191969287, 10.821511768437606, 9.821109523817363, 8.87864148770558, 8.066159914259185, 8.873585005434192, 9.886005912167601, 10.614143324245646, 11.564850059227808, 12.570836930231762, 13.549670407381106, 14.50957104126332, 15.484794455520209, 17.332767005434494, 17.466705039425804, 16.438821073893433, 15.491800549267964, 14.447968255747076, 13.452733102652093, 12.632543635295171, 11.773041366911297, 11.05197319647771, 10.887437389322287, 9.89449038690235, 9.078120851405327, 9.805066768563744, 10.76572400310778, 11.653685793487314, 12.517715761890928, 13.468878122931377, 14.52458123399437, 15.436816349024186, 16.38276969687982, 17.550155888480496, 16.531121341715885, 15.507733139086746, 14.525114651599335, 13.500085633184824, 12.525600905475027, 11.658976140786486, 10.77697678112106, 9.99903777149709, 10.843654578293375, 10.909235095635912, 10.037258510203085, 10.817897040618819, 11.797139823152403, 12.63330999869483, 13.473185878396864, 14.490899988367563, 15.431752317810957, 16.376319234145317, 17.33800262060767, 16.53892899058728, 15.527244004852104, 14.566592040186189, 13.588971777004966, 12.640676594900949, 11.583285004212852, 10.72405632064037, 9.806377148342126, 8.968744341530057, 9.770735920810441, 10.842303070675715, 11.024242364936693, 11.74587185956527, 12.675290696037015, 13.575605192547965, 14.441728235250475, 15.430993574336714, 16.443739201422016, 17.442743831662657, 17.503513278122693], [15.602687630371989, 16.559370958063813, 16.498569703770663, 15.551898709592976, 14.535643946714584, 13.65568727132038, 12.808025783641586, 11.896704981529794, 11.6859536053277, 10.704112038258554, 9.656976605403488, 8.824335169140156, 8.089672407497924, 8.981190160087955, 9.72043936294532, 10.708916983066217, 11.666302462039809, 12.690675059268084, 13.67698306935688, 14.703720665706985, 14.583781852725412, 15.50406661207379, 16.406349211995156, 15.506838266906335, 14.446987873128503, 13.546120691041212, 12.584030418843648, 11.682170424728021, 10.63040779893461, 9.667304441070728, 8.71390875264085, 7.7620553803270935, 7.052598283387521, 8.018726569760583, 8.793311367374667, 9.766144352590453, 10.779973663303883, 11.70829550796806, 12.62889307352435, 13.6740183206776, 13.540059199691687, 14.4702151588359, 15.426974750664492, 14.518175039292409, 13.519334606485078, 12.506520962141664, 11.581300319508129, 10.629633596010885, 9.613970607228506, 8.713276328928675, 7.693063059176405, 6.762270070387235, 6.037382657711988, 6.962850648112697, 7.845018787781838, 8.783651823307961, 9.726695697751913, 10.760487896849192, 11.703494922441184, 12.655324252113017, 12.521711154694401, 13.459125219714698, 14.481982565616478, 13.581321510571039, 12.542061999021664, 11.523191815450287, 10.574711037997716, 9.583602503595493, 8.598052153437212, 7.788435480210762, 6.827472602309951, 5.773905204566587, 5.07785976778398, 5.975114348895941, 6.8251128318402445, 7.869143160809122, 8.797661787249254, 9.732779863055963, 10.71766073409674, 11.668580666613686, 11.596135503270787, 12.545097123134312, 13.527453720298556, 12.56930252351742, 11.559800077261324, 10.632260001918226, 9.586962504894114, 8.64625910561224, 7.60592604331284, 6.721896844366066, 5.772256874977899, 4.8345355041540365, 4.089523971626306, 5.002961148560749, 5.846283585610662, 6.868545962059396, 7.830255384267132, 8.759118734044334, 9.77179795223382, 10.698361850667654, 10.588033409874765, 11.64977310035392, 12.581453619318642, 11.656066701674803, 10.617237240640947, 9.58965745346566, 8.652481999674597, 7.683952238477777, 6.673972685677654, 5.746438874047939, 4.800291982392466, 3.8736058803004547, 3.062751002903145, 3.9848216333125697, 4.920421970593179, 5.899659493290985, 6.813995253461213, 7.77203014292337, 8.824115924776258, 9.637690350614088, 9.707401412118726, 10.721573461074545, 11.682755937666663, 10.738105696406125, 9.760828124721431, 8.810775293486618, 7.869153732291261, 6.822057834173586, 5.8190816211790075, 4.845792630040975, 3.778827896424991, 2.849720273353941, 1.997047231948586, 2.971152464837786, 3.967942047164141, 4.919639929012948, 5.851741608826155, 6.796168205523475, 7.804560499079867, 8.708260020851247, 8.799137351283937, 9.799596350700472, 10.716906253790551, 9.707028750824643, 8.735472275842035, 7.842498224323274, 6.908053744555891, 5.840675850240421, 4.880661663925066, 3.9156607796997536, 2.959059726340239, 1.9177908673883264, 0.9638862612357435, 1.9674667577232903, 2.8945835790490344, 3.865580743957175, 4.7951673440578135, 5.734122668409836, 6.785176883567018, 7.771173790976703, 8.107267876378632, 9.17045267368837, 9.680013556014998, 8.751975964836973, 7.804711647343003, 6.800167114848187, 5.863886017617547, 4.836627828232832, 3.8720571922133264, 2.9321078618892487, 1.9989859767181437, 0.9386468355327304, 0.0, 0.9393986050577331, 1.9687097739647093, 2.9563870004238324, 3.884104583119397, 4.957679621453369, 6.024497238270582, 7.0579043394171235, 8.969726814945641, 9.974865890207832, 10.666353870943194, 9.685228794444, 8.727339911850125, 7.716460024335901, 6.743316093111794, 5.801181299507377, 4.757703411500163, 3.827048476080681, 2.849840937171876, 1.9246674784348334, 0.9857072433559659, 1.8731191018720492, 2.860105694104976, 3.8559321318088404, 4.795315567110752, 5.869574195460271, 6.894267362303005, 7.909035110313441, 9.6494647493448, 10.684137283168408, 11.628256949251334, 10.66175059805741, 9.661082559142537, 8.712549493064493, 7.644089461348775, 6.652546660661213, 5.686667208777262, 4.7877568378320525, 3.825230738231161, 2.95594359805168, 2.0097278278861284, 2.944776425939093, 3.8173389233951136, 4.768147470090218, 5.752460870812739, 6.764082946939792, 7.7290277947937795, 8.707079948357022, 10.575349515065922, 11.503302627011564, 12.521195501486508, 11.637498776462618, 10.590111050588883, 9.520363282907658, 8.587700148376586, 7.64225436060468, 6.637431214407265, 5.756449674397211, 4.776580296528689, 4.010912636800965, 3.0794118640357895, 3.9990818915519997, 4.778000355201851, 5.727192620586499, 6.691259630551136, 7.618073459064479, 8.592326771489505, 9.619744136673006, 11.569006495634271, 12.472866209933917, 13.52625120441065, 12.593331408264511, 11.528022620106734, 10.51827106473003, 9.534962115199004, 8.631645071762213, 7.662628355718929, 6.758797562199669, 5.826047747594784, 4.938449898945689, 4.125653135746307, 5.064795237173222, 5.8091458422271, 6.798273449131225, 7.713389692385864, 8.623676194294582, 9.578659181611183, 10.54822853685875, 12.481384848050633, 13.413133779507767, 14.433716122797941, 13.536452666891561, 12.463199494689635, 11.448537376117661, 10.499885652517982, 9.58539123428895, 8.649600065686096, 7.689922020823716, 6.885499669310859, 5.919024358323028, 5.061838861701931, 6.076623782408163, 6.745088723120665, 7.769353667179977, 8.753061174118645, 9.674572996546784, 10.557338958019965, 11.50390839855392, 13.45426679895187, 14.39579217979743, 15.355581833988742, 14.359387004749813, 13.434025508764782, 12.501288995546485, 11.539421041421257, 10.565791756443392, 9.71372896513772, 8.752037708165336, 7.856818720927417, 6.946992977409723, 6.085932264976492, 7.100644266007298, 7.7092548199658015, 8.695261620292365, 9.709414330918024, 10.636838262159252, 11.580744041448376, 12.55901654913187, 14.513511431295054, 15.430014701040104, 16.35023300042109, 15.290257319962638, 14.459953883298079, 13.433315365266072, 12.513484961488164, 11.52595430105181, 10.773773780545689, 9.757193512913412, 8.860234577478103, 7.9305663861036395, 7.02323011750702, 8.06305887030919, 8.660693713905827, 9.653266861247232, 10.6328911742844, 11.591847806517919, 12.599843715312497, 13.566933840581827, 15.513846101348147, 16.459666930445593, 16.49807232239986, 15.439244255564452, 14.507382263651426, 13.504002266316563, 12.891580617678342, 12.070953664433672, 11.756669493496805, 10.756267248876561, 9.813799212764781, 8.942295527722777, 7.981771054380843, 8.994191961114252, 9.675496488712914, 10.626203223695077, 11.63219009469903, 12.611023571848374, 13.57092420573059, 14.54614761998748, 16.394120169901765, 16.544759863480994, 15.516875897948621, 14.569855373323152, 13.526023079802265, 12.530787926707282, 11.817724066142562, 11.008520683802896, 11.947401231248044, 11.822595114381485, 10.82964811196155, 9.95425646486892, 8.913252817510395, 9.87391005205443, 10.715038957954583, 11.579068926358197, 12.530231287398646, 13.585934398461639, 14.498169513491456, 15.44412286134709, 16.628210712535683, 15.609176165771073, 14.585787963141934, 13.603169475654523, 12.578140457240012, 11.603655729530216, 10.844156571633876, 10.01245609801266, 10.894465806267421, 11.739082613063708, 11.844392820695113, 10.871093212618051, 9.92608308956547, 10.905325872099054, 11.6946631631621, 12.534539042864132, 13.552253152834831, 14.493105482278226, 15.437672398612586, 16.399355785074942, 15.616983814642468, 14.605298828907292, 13.644646864241377, 12.667026601060156, 11.71873141895614, 10.66133982826804, 9.90923675148776, 9.041856465233725, 9.864172376300388, 10.666163955580775, 11.737731105446048, 11.828350931301724, 10.85405790851192, 11.783476744983666, 12.636958357015233, 13.503081399717743, 14.492346738803983, 15.505092365889286, 16.504096996129924, 16.56486644258996], [14.66328902531426, 15.619972353006084, 15.55917109871293, 14.612500104535243, 13.596245341656852, 12.716288666262647, 12.2761238521918, 12.791326775318675, 12.625352210385433, 11.64351064331629, 10.596375210461222, 9.763733774197892, 9.001303381184739, 8.041791555030223, 8.78104075788759, 9.769518378008486, 10.726903856982078, 11.751276454210354, 12.737584464299147, 13.764322060649253, 13.644383247667683, 14.56466800701606, 15.466950606937424, 15.65430150551479, 14.62627477083601, 13.695490584579902, 13.226250555811989, 12.621569029785753, 11.569806403992343, 10.606703046128462, 9.653307357698584, 8.701453985384829, 7.9642292570743365, 7.07932796470285, 7.853912762316935, 8.826745747532721, 9.84057505824615, 10.768896902910328, 11.689494468466618, 12.734619715619868, 12.600660594633956, 13.53081655377817, 14.48757614560676, 15.453741865770413, 14.45873321154281, 13.445919567199397, 12.520698924565862, 11.569032201068618, 10.553369212286238, 9.65267493398641, 8.632461664234139, 7.701668675444969, 6.949013631398803, 6.023452043054965, 6.905620182724105, 7.844253218250229, 8.78729709269418, 9.82108929179146, 10.764096317383451, 11.715925647055284, 11.58231254963667, 12.519726614656967, 13.542583960558748, 14.471192980063398, 13.4814606040794, 12.46259042050802, 11.514109643055448, 10.523001108653226, 9.537450758494945, 8.727834085268494, 7.766871207367684, 6.713303809624321, 5.989490741470795, 5.0357157438382085, 5.885714226782512, 6.929744555751389, 7.858263182191521, 8.793381257998231, 9.778262129039007, 10.729182061555955, 10.656736898213056, 11.605698518076581, 12.60561249271113, 13.508701128575156, 12.49919868231906, 11.57165860697596, 10.526361109951848, 9.585657710669974, 8.545324648370572, 7.6612954494237995, 6.711655480035632, 5.773934109211771, 5.001154945313122, 4.063562543503016, 4.906884980552929, 5.929147357001663, 6.8908567792093995, 7.819720128986601, 8.832399347176088, 9.758963245609923, 9.648634804817034, 10.71037449529619, 11.659612391731216, 12.584999309375055, 11.556635845698683, 10.529056058523395, 9.591880604732332, 8.62335084353551, 7.613371290735387, 6.685837479105672, 5.739690587450199, 4.813004485358189, 3.974381976589961, 3.045423028254837, 3.981023365535447, 4.960260888233252, 5.87459664840348, 6.8326315378656375, 7.884717319718526, 8.698291745556357, 8.768002807060993, 9.782174856016812, 10.74335733260893, 11.677504301463857, 10.700226729779164, 9.75017389854435, 8.808552337348994, 7.761456439231319, 6.75848022623674, 5.785191235098708, 4.718226501482724, 3.7891188784116743, 2.9364458370063193, 2.031753859780053, 3.0285434421064084, 3.9802413239552155, 4.912343003768422, 5.856769600465743, 6.865161894022134, 7.768861415793515, 7.8597387462262045, 8.86019774564274, 9.856449839520765, 10.646427355882375, 9.674870880899768, 8.781896829381006, 7.847452349613624, 6.780074455298154, 5.820060268982799, 4.855059384757487, 3.898458331397972, 2.8571894724460596, 1.9032848662934767, 1.0280681526655573, 1.9551849739913014, 2.926182138899442, 3.8557687390000805, 4.7947240633521035, 5.845778278509285, 6.83177518591897, 7.1678692713209, 8.231054068630637, 9.224754751790075, 9.691374569894705, 8.744110252400736, 7.73956571990592, 6.80328462267528, 5.776026433290564, 4.811455797271059, 3.871506466946981, 2.9383845817758765, 1.8780454405904634, 0.9393986050577331, 0.0, 1.029311168906976, 2.0169883953660994, 2.9447059780616636, 4.018281016395636, 5.085098633212849, 6.11850573435939, 8.030328209887907, 9.035467285150098, 10.006170918510524, 10.579850588232883, 9.621961705639007, 8.611081818124783, 7.637937886900676, 6.695803093296259, 5.652325205289046, 4.721670269869564, 3.744462730960758, 2.8192892722237155, 1.8803290371448478, 0.9337204968143161, 1.920707089047243, 2.9165335267511074, 3.8559169620530187, 4.930175590402538, 5.95486875724527, 6.969636505255707, 8.710066144287065, 9.744738678110673, 10.688858344193598, 11.556372391846292, 10.55570435293142, 9.607171286853376, 8.538711255137658, 7.547168454450095, 6.581289002566145, 5.682378631620935, 4.7198525320200435, 3.850565391840562, 2.90434962167501, 2.00537782088136, 2.87794031833738, 3.828748865032485, 4.813062265755006, 5.824684341882058, 6.789629189736046, 7.767681343299287, 9.635950910008187, 10.56390402195383, 11.581796896428774, 12.5321205702515, 11.484732844377765, 10.41498507669654, 9.482321942165468, 8.536876154393562, 7.532053008196147, 6.651071468186093, 5.671202090317571, 4.905534430589847, 3.974033657824671, 3.0596832864942662, 3.8386017501441176, 4.787794015528767, 5.751861025493403, 6.678674854006745, 7.652928166431772, 8.680345531615272, 10.629607890576537, 11.533467604876183, 12.586852599352916, 13.487953202053394, 12.422644413895616, 11.412892858518912, 10.429583908987887, 9.526266865551097, 8.557250149507812, 7.653419355988552, 6.720669541383667, 5.8330716927345705, 5.020274929535189, 4.125396632115489, 4.869747237169367, 5.858874844073492, 6.773991087328131, 7.684277589236848, 8.63926057655345, 9.608829931801017, 11.5419862429929, 12.473735174450033, 13.494317517740207, 14.431074460680444, 13.357821288478517, 12.343159169906544, 11.394507446306864, 10.480013028077835, 9.54422185947498, 8.584543814612598, 7.780121463099742, 6.81364615211191, 5.956460655490813, 5.173862586115445, 5.805690118062932, 6.829955062122244, 7.813662569060912, 8.73517439148905, 9.617940352962233, 10.564509793496187, 12.514868193894138, 13.456393574739698, 14.497271841210278, 15.254008798538695, 14.328647302553664, 13.395910789335367, 12.434042835210139, 11.460413550232277, 10.608350758926605, 9.646659501954217, 8.751440514716299, 7.841614771198604, 6.980554058765374, 6.19788306971458, 6.769856214908069, 7.755863015234633, 8.770015725860292, 9.697439657101517, 10.641345436390642, 11.619617944074138, 13.574112826237322, 14.490616095982372, 15.491923007642626, 15.472511553413847, 14.571731100529064, 13.639407298822594, 12.956892748801696, 12.420576094840694, 11.668395574334573, 10.651815306702293, 9.754856371266985, 8.825188179892521, 7.917851911295902, 7.272763316652551, 7.721295108848095, 8.7138682561895, 9.693492569226667, 10.652449201460186, 11.660445110254763, 12.627535235524094, 14.574447496290414, 15.52026832538786, 15.558673717342128, 14.499845650506721, 13.567983658593695, 12.564603661258833, 11.952182012620609, 12.962575224492262, 12.651291287285687, 11.650889042665444, 10.708421006553664, 9.836917321511658, 8.876392848169724, 8.21678144735892, 8.736097883655182, 9.686804618637344, 10.692791489641298, 11.671624966790642, 12.631525600672855, 13.606749014929745, 15.45472156484403, 15.605361258423263, 14.57747729289089, 13.630456768265422, 12.586624474744534, 11.591389321649551, 10.87832546108483, 11.900142243861486, 12.88679983630578, 12.717216908170368, 11.724269905750432, 10.8488782586578, 9.807874611299276, 9.224931687100545, 9.77564035289685, 10.639670321300464, 11.590832682340913, 12.646535793403906, 13.558770908433722, 14.504724256289355, 15.688812107477952, 14.669777560713342, 13.646389358084203, 12.663770870596792, 11.638741852182282, 10.664257124472485, 9.904757966576144, 10.924087071699475, 11.833864411325157, 12.67848121812144, 12.739014614483995, 11.765715006406932, 10.82070488335435, 10.276158159408899, 10.755264558104367, 11.5951404378064, 12.612854547777099, 13.553706877220494, 14.498273793554853, 15.459957180017208, 14.677585209584738, 13.665900223849562, 12.705248259183646, 11.727627996002424, 10.779332813898407, 9.72194122321031, 8.969838146430028, 9.95348743892054, 10.803570981358124, 11.605562560638507, 12.677129710503781, 12.722972725090605, 11.748679702300802, 11.25157481353388, 11.6975597519575, 12.56368279466001, 13.55294813374625, 14.565693760831554, 15.564698391072193, 15.625467837532229], [13.63397785640728, 14.590661184099107, 14.633195913791011, 13.686524919613325, 12.670270156734933, 11.790313481340728, 12.796825573586212, 13.649364098362804, 13.654663379292408, 12.672821812223265, 11.625686379368197, 10.793044943104867, 9.748163880121707, 8.739771447185898, 7.751729588980613, 8.74020720910151, 9.697592688075101, 10.721965285303376, 11.708273295392171, 12.735010891742277, 12.615072078760704, 13.535356838109083, 14.437639438030448, 14.72832632059287, 13.700299585914092, 12.769515399657983, 13.7469522772064, 13.650880198692729, 12.599117572899319, 11.636014215035438, 10.682618526605559, 9.730765154291804, 8.793735029275794, 7.777307856858525, 6.824601593409958, 7.797434578625744, 8.811263889339173, 9.73958573400335, 10.660183299559643, 11.705308546712892, 11.571349425726979, 12.501505384871193, 13.458264976699784, 14.424430696863437, 14.627952852557517, 13.809115128557531, 13.550010093472837, 12.598343369975593, 11.582680381193214, 10.681986102893385, 9.661772833141114, 8.730979844351944, 7.792133700035704, 6.85060778707889, 5.876309013817128, 6.8149420493432515, 7.757985923787203, 8.791778122884482, 9.734785148476476, 10.686614478148309, 10.553001380729693, 11.49041544574999, 12.51327279165177, 13.44188181115642, 14.481141322705795, 13.491901589414995, 12.543420811962424, 11.552312277560201, 10.56676192740192, 9.75714525417547, 8.79618237627466, 7.7426149785312965, 6.832610810107695, 5.870062369751945, 4.856403057875535, 5.900433386844412, 6.828952013284544, 7.764070089091254, 8.748950960132031, 9.699870892648978, 9.62742572930608, 10.576387349169604, 11.576301323804152, 12.605357152944276, 13.528509851226035, 12.600969775882936, 11.555672278858824, 10.61496887957695, 9.574635817277548, 8.690606618330774, 7.740966648942607, 6.803245278118746, 5.885254483611886, 4.897909169416753, 3.8775738116459526, 4.899836188094686, 5.861545610302422, 6.790408960079624, 7.803088178269111, 8.729652076702946, 8.619323635910057, 9.681063326389213, 10.630301222824238, 11.555688140468078, 12.585947014605658, 11.55836722743037, 10.621191773639307, 9.652662012442486, 8.642682459642362, 7.715148648012647, 6.7690017563571745, 5.842315654265164, 4.858481514888725, 3.929522566553601, 2.9517121966284705, 3.9309497193262755, 4.8452854794965035, 5.803320368958662, 6.855406150811549, 7.66898057664938, 7.738691638154018, 8.752863687109837, 9.714046163701955, 10.72104064160953, 11.72953789868614, 10.779485067451327, 9.837863506255971, 8.790767608138296, 7.787791395143715, 6.814502404005683, 5.7475376703897, 4.81843004731865, 3.9657570059132947, 2.979805233962662, 1.999232273199432, 2.950930155048239, 3.8830318348614457, 4.8274584315587665, 5.835850725115158, 6.739550246886539, 6.830427577319229, 7.830886576735765, 8.827138670613792, 9.8370161735797, 10.704182049806743, 9.811207998287982, 8.876763518520601, 7.809385624205131, 6.849371437889775, 5.884370553664462, 4.927769500304948, 3.8865006413530354, 2.9325960352004525, 1.9761195268481662, 0.9258738050843254, 1.8968709699924657, 2.8264575700931043, 3.7654128944451273, 4.816467109602309, 5.802464017011994, 6.138558102413924, 7.201742899723662, 8.1954435828831, 9.123481174061125, 9.773421421307711, 8.768876888812896, 7.832595791582257, 6.805337602197541, 5.840766966178036, 4.900817635853958, 3.9676957506828527, 2.9073566094974397, 1.9687097739647093, 1.029311168906976, 0.0, 0.9876772264591233, 1.9153948091546877, 2.98896984748866, 4.055787464305873, 5.089194565452415, 7.063589614060332, 8.068728689322523, 9.039432322682948, 10.020557399182142, 10.651272874545983, 9.640392987031758, 8.667249055807652, 7.725114262203236, 6.681636374196022, 5.75098143877654, 4.773773899867734, 3.8486004411306918, 2.909640206051824, 1.9630316657212923, 0.9947319041253226, 1.9497949309235307, 2.889178366225442, 3.9634369945749617, 4.988130161417695, 6.002897909428132, 7.750231837985516, 8.784904371809123, 9.72902403789205, 10.79838969908328, 11.585015521838395, 10.636482455760353, 9.568022424044635, 8.576479623357072, 7.610600171473121, 6.711689800527911, 5.74916370092702, 4.879876560747538, 3.9336607905819863, 3.0176766958572663, 1.95196513341546, 2.902773680110565, 3.8532279594534553, 4.864850035580508, 5.829794883434496, 6.807847036997737, 8.676116603706639, 9.604069715652281, 10.621962590127225, 11.660582347645423, 12.51404401328474, 11.444296245603516, 10.511633111072443, 9.566187323300538, 8.561364177103124, 7.68038263709307, 6.7005132592245475, 5.934845599496822, 4.953180179975235, 3.9475704246019703, 2.9126265652221974, 3.861818830606846, 4.792026719191853, 5.718840547705195, 6.6930938601302215, 7.7205112253137225, 9.669773584274989, 10.573633298574634, 11.627018293051368, 12.6938892411236, 13.451955582802592, 12.442204027425888, 11.458895077894862, 10.555578034458073, 9.586561318414788, 8.682730524895527, 7.749980710290643, 6.862382861641546, 5.999421451685754, 5.013283770223193, 3.943772052247447, 4.9328996591515715, 5.814156781026581, 6.724443282935297, 7.679426270251899, 8.648995625499465, 10.58215193669135, 11.513900868148484, 12.534483211438658, 13.502602711197511, 14.387132457385492, 13.37247033881352, 12.42381861521384, 11.50932419698481, 10.573533028381956, 9.613854983519573, 8.809432632006718, 7.842957321018885, 6.918433407944394, 5.903648487238162, 4.879714933141012, 5.9039798772003245, 6.868412730484033, 7.775340085187499, 8.658106046660683, 9.604675487194637, 11.555033887592588, 12.496559268438148, 13.53743753490873, 14.498899541428475, 14.538168757558969, 13.542122499635203, 13.463354004117114, 12.489724719139252, 11.63766192783358, 10.675970670861192, 9.780751683623276, 8.861318919990541, 7.838591381809504, 6.770680477638406, 5.84388102998615, 6.829887830312713, 7.844040540938371, 8.737605350799967, 9.681511130089092, 10.659783637772588, 12.614278519935771, 13.530781789680821, 14.532088701341078, 14.44320038450687, 13.542419931622087, 12.610096129915616, 13.474540109646814, 13.44988726374767, 12.697706743241548, 11.681126475609268, 10.784167540173963, 9.806709479999228, 8.775889234340031, 7.793465038046962, 6.795319923926176, 7.787893071267581, 8.767517384304748, 9.726474016538267, 10.700610803953213, 11.667700929222544, 13.614613189988864, 14.56043401908631, 14.52936254843515, 13.470534481599744, 12.538672489686718, 11.535292492351855, 12.469829373465727, 13.492740228267868, 13.680602456192663, 12.68020021157242, 11.717087458600641, 10.694954644555787, 9.734430171213853, 8.737483168753332, 7.810122698733262, 8.760829433715426, 9.766816304719379, 10.745649781868723, 11.671691294371305, 12.646914708628195, 14.49488725854248, 14.576050089516286, 13.548166123983913, 12.601145599358444, 11.557313305837557, 10.562078152742574, 11.506366351072943, 12.5281831338496, 13.533214873848332, 13.716597919516538, 12.669648322070872, 11.70691558170193, 10.665911934343406, 9.745633408494957, 8.849665167974932, 9.713695136378545, 10.664857497418994, 11.720560608481987, 12.598936602132172, 13.544889949987805, 14.659500938570975, 13.640466391806365, 12.617078189177226, 11.634459701689815, 10.609430683275304, 9.634945955565508, 10.60273785873182, 11.658316807504699, 12.659766010178297, 13.667330903105963, 13.617148552627206, 12.623752329451062, 11.67874220639848, 10.79685988080331, 9.829289373182448, 10.669165252884481, 11.68687936285518, 12.627731692298575, 13.572298608632934, 14.500122873715657, 13.64827404067776, 12.636589054942585, 11.675937090276669, 10.698316827095448, 9.750021644991431, 8.692630054303333, 9.667818038585704, 10.687717174725764, 11.629472580211264, 12.634873729545482, 13.706440879410756, 13.581010048134734, 12.606717025344931, 11.772276534928292, 10.771584567035582, 11.637707609738092, 12.626972948824331, 13.639718575909635, 14.638723206150274, 14.59615666862525], [12.765528308400057, 13.722211636091881, 13.821540609320952, 12.931770937057044, 11.915516174178652, 12.753525719383676, 13.760037811629159, 14.612576336405754, 14.642340605751532, 13.660499038682389, 12.61336360582732, 11.78072216956399, 10.73584110658083, 9.727448673645021, 8.739406815439736, 8.179175347051489, 8.923588020646985, 9.94796061787526, 10.839823747384946, 11.866561343735054, 11.74662253075348, 12.666907290101857, 13.569189890023221, 13.97357233803659, 12.945545603357811, 13.73272763770093, 14.710164515249348, 14.638557425151852, 13.586794799358442, 12.623691441494561, 11.670295753064682, 10.718442380750927, 9.781412255734919, 8.764985083317649, 7.812278819869081, 7.173294542502852, 7.998140343157681, 8.926462187821858, 9.791733751552417, 10.836858998705667, 10.702899877719753, 11.633055836863967, 12.589815428692557, 13.55598114885621, 13.873198870001236, 14.772327366600479, 14.53768731993196, 13.586020596434716, 12.570357607652337, 11.669663329352508, 10.649450059600237, 9.718657070811068, 8.779810926494827, 7.838285013538013, 6.863986240276251, 6.19080201322036, 6.925206076637897, 7.9589982757351745, 8.86633560046925, 9.818164930141084, 9.684551832722468, 10.621965897742765, 11.644823243644545, 12.573432263149195, 13.61269177469857, 14.479578815874119, 13.531098038421547, 12.539989504019324, 11.554439153861043, 10.744822480634594, 9.783859602733784, 8.73029220499042, 7.820288036566819, 6.8577395962110685, 5.844080284334658, 5.17972574463398, 5.996172166135238, 6.931290241941946, 7.880501412124805, 8.831421344641754, 8.758976181298854, 9.707937801162378, 10.707851775796927, 11.73690760493705, 12.668630890115086, 13.588647002342059, 12.543349505317947, 11.602646106036072, 10.56231304373667, 9.678283844789899, 8.728643875401731, 7.790922504577869, 6.8729317100710094, 5.885586395875876, 4.865251038105075, 4.118580882528192, 4.997076304381423, 5.925939654158625, 6.934638630261886, 7.8612025286957214, 7.750874087902831, 8.812613778381987, 9.761851674817013, 10.687238592460853, 11.726068053494709, 12.546044453889493, 11.60886900009843, 10.640339238901609, 9.630359686101485, 8.70282587447177, 7.756678982816298, 6.829992880724287, 5.846158741347848, 4.917199793012724, 3.9393894230875937, 3.1496944137597813, 3.976835931489279, 4.934870820951437, 5.986956602804324, 6.800531028642155, 6.870242090146792, 7.884414139102612, 8.84559661569473, 9.852591093602305, 10.921484159251571, 11.76716229391045, 10.825540732715094, 9.778444834597419, 8.775468621602839, 7.802179630464806, 6.735214896848823, 5.806107273777773, 4.953434232372418, 3.9674824604217855, 2.9869094996585552, 2.0824806070410142, 3.014582286854221, 3.959008883551541, 4.9674011771079325, 5.871100698879314, 5.961978029312004, 6.96243702872854, 7.9586891226065655, 8.968566625572475, 9.940123100555082, 10.798885224747105, 9.864440744979724, 8.797062850664254, 7.837048664348898, 6.8720477801235855, 5.915446726764071, 4.874177867812159, 3.9202732616595757, 2.9637967533072898, 1.9135510315434487, 1.0284214219852408, 1.9580080220858793, 2.896963346437902, 3.9480175615950834, 4.934014469004769, 5.1508808759548, 6.214065673264539, 7.207766356423976, 8.135803947602001, 9.08306826509597, 9.756554115272019, 8.82027301804138, 7.7930148286566645, 6.828444192637159, 5.888494862313081, 4.955372977141976, 3.895033835956563, 2.9563870004238324, 2.0169883953660994, 0.9876772264591233, 0.0, 0.9277175826955644, 2.0012926210295365, 3.0681102378467493, 4.101517338993291, 6.075912387601209, 7.0810514628634, 8.051755096223825, 9.032880172723019, 9.990769055316894, 10.622292055711666, 9.64914812448756, 8.707013330883143, 7.663535442875928, 6.732880507456446, 5.755672968547641, 4.830499509810598, 3.8915392747317306, 2.944930734401199, 1.9579441421682717, 0.9621177044644075, 1.9015011397663188, 2.9757597681158385, 4.000452934958572, 5.015220682969009, 6.762554611526393, 7.79722714535, 8.741346811432926, 9.810712472624157, 10.811380511539031, 11.618381524440258, 10.54992149272454, 9.558378692036976, 8.592499240153026, 7.693588869207818, 6.731062769606926, 5.861775629427444, 4.915559859261893, 3.980888933900215, 2.915177371458409, 2.0248273496055744, 2.865550732994332, 3.877172809121385, 4.842117656975373, 5.820169810538614, 7.688439377247515, 8.616392489193156, 9.6342853636681, 10.672905121186297, 11.720292847060032, 12.42619531428342, 11.493532179752348, 10.548086391980442, 9.543263245783029, 8.662281705772976, 7.682412327904454, 6.916744668176729, 5.916392418018185, 4.91078266264492, 3.8758388032651463, 3.001175629507731, 3.804349492732729, 4.731163321246072, 5.705416633671098, 6.732833998854599, 8.682096357815864, 9.58595607211551, 10.639341066592243, 11.706212014664473, 12.737714474900944, 13.424103096105792, 12.440794146574767, 11.537477103137977, 10.568460387094692, 9.664629593575434, 8.73187977897055, 7.844281930321452, 6.962633689728703, 5.9764960082661425, 4.906984290290396, 4.072256458052457, 4.826479554567457, 5.736766056476174, 6.691749043792776, 7.661318399040343, 9.594474710232227, 10.52622364168936, 11.546805984979533, 12.514925484738386, 13.588178656940313, 14.354369407493424, 13.405717683893744, 12.491223265664715, 11.55543209706186, 10.595754052199482, 9.791331700686625, 8.824856389698793, 7.8816456459873425, 6.866860725281111, 5.842927171183961, 5.079894930259971, 5.8807355040249085, 6.787662858728376, 7.670428820201559, 8.616998260735514, 10.567356661133465, 11.508882041979025, 12.549760308449605, 13.51122231496935, 14.225114689620737, 14.529799726094327, 14.44525307279702, 13.471623787819157, 12.619560996513485, 11.6578697395411, 10.762650752303182, 9.824531158033489, 8.801803619852452, 7.733892715681353, 6.807093268029098, 6.005802883372359, 6.897498740494274, 7.749928124340844, 8.693833903629969, 9.672106411313464, 11.626601293476648, 12.543104563221698, 13.544411474881953, 14.004495851569978, 13.19918631508744, 13.59777335637474, 14.462217336105937, 14.431786332427574, 13.679605811921453, 12.663025544289177, 11.766066608853869, 10.769921718042177, 9.73910147238298, 8.75667727608991, 7.758532161969123, 7.033139088711301, 7.898721364999079, 8.7972951521285, 9.71293357749409, 10.680023702763421, 12.626935963529741, 13.572756792627187, 13.890055626067438, 13.031829948662851, 12.19543887315207, 12.522969718810979, 13.45750659992485, 14.480417454726991, 14.662501524872571, 13.662099280252328, 12.68029969664359, 11.658166882598737, 10.697642409256803, 9.70069540679628, 8.77333493677621, 8.006075451159145, 8.898020285413711, 9.816470917458956, 10.684014067912182, 11.659237482169072, 13.507210032083357, 13.823640660539477, 12.904908055834547, 11.957887531209078, 11.21407968930291, 11.549755379201697, 12.494043577532066, 13.515860360308723, 14.520892100307455, 14.679810157559487, 13.632860560113821, 12.670127819744879, 11.629124172386355, 10.708845646537904, 9.81287740601788, 8.958941153822265, 9.853202192948935, 10.841605456785866, 11.611259375673049, 12.557212723528682, 13.800272070389445, 12.844658408623157, 11.91206988737898, 10.953866607138957, 10.15048710726203, 10.62262318202463, 11.590415085190942, 12.645994033963822, 13.64744323663742, 14.655008129565086, 14.580360790670156, 13.586964567494011, 12.64195444444143, 11.760072118846258, 10.792501611225395, 9.9144112703282, 10.87522405838512, 11.816076387828515, 12.630531059215123, 13.512445647256534, 12.78904517249623, 11.777360186761054, 10.901932422848553, 9.952896201707944, 9.188989782941409, 9.680307280762456, 10.655495265044827, 11.675394401184887, 12.617149806670387, 13.622550956004606, 14.69411810586988, 14.544222286177684, 13.56992926338788, 12.73548877297124, 11.73479680507853, 10.882953627181811, 11.87221896626805, 12.828063271439575, 13.696955656732463, 13.727707120618026], [11.865669960871827, 12.82235328856365, 12.922734814614735, 12.110589230801212, 12.72353275057074, 13.6786465616176, 14.687755394324723, 15.540293919101318, 15.570058188447096, 14.588216621377953, 13.541081188522885, 12.708439752259554, 11.663558689276392, 10.655166256340584, 9.667124398135298, 8.963579796145543, 8.023729673118757, 9.048102270347032, 9.939965399856716, 10.966702996206823, 10.84676418322525, 11.767048942573627, 12.66933154249499, 13.152390631780758, 13.753562179749899, 14.657848479934854, 15.637882097944912, 15.566275007847416, 14.514512382054006, 13.551409024190125, 12.598013335760246, 11.646159963446491, 10.709129838430481, 9.692702666013211, 8.739996402564644, 7.9576989915969065, 7.098281995629453, 8.02660384029363, 8.891875404024187, 9.937000651177437, 9.803041530191523, 10.733197489335737, 11.689957081164327, 12.65612280132798, 13.65496323413531, 14.667776878478726, 15.465404902627524, 14.51373817913028, 13.498075190347901, 12.597380912048072, 11.577167642295802, 10.646374653506632, 9.707528509190391, 8.766002596233577, 7.791703822971815, 6.975206462314414, 6.025347729109669, 7.059139928206946, 7.96647725294102, 8.918306582612853, 8.784693485194238, 9.722107550214535, 10.744964896116315, 11.673573915620965, 12.71283342717034, 13.738275386093047, 14.458815621117111, 13.467707086714888, 12.482156736556608, 11.672540063330157, 10.711577185429347, 9.658009787685984, 8.748005619262383, 7.785457178906633, 6.771797867030222, 6.02483244504714, 5.096313818607009, 6.031431894413718, 6.980643064596576, 7.931562997113524, 7.859117833770624, 8.808079453634148, 9.807993428268697, 10.83704925740882, 11.768772542586856, 12.83458071250206, 13.47106708801351, 12.530363688731637, 11.490030626432235, 10.606001427485461, 9.656361458097294, 8.718640087273434, 7.800649292766574, 6.81330397857144, 5.7929686208006395, 4.973197053614451, 4.097217956853195, 5.026081306630396, 6.0347802827336565, 6.961344181167492, 6.851015740374601, 7.912755430853758, 8.861993327288783, 9.787380244932622, 10.826209705966479, 11.853789493141765, 12.536586582793994, 11.568056821597173, 10.55807726879705, 9.630543457167335, 8.684396565511861, 7.757710463419851, 6.773876324043412, 5.844917375708288, 4.867107005783158, 4.00431058484604, 3.0769775839610496, 4.0350124734232065, 5.087098255276095, 5.900672681113925, 5.970383742618563, 6.984555791574382, 7.9457382681665, 8.952732746074076, 10.021625811723343, 11.090363816586557, 11.753258315410658, 10.706162417292983, 9.703186204298403, 8.72989721316037, 7.662932479544387, 6.733824856473337, 5.881151815067982, 4.89520004311735, 3.9146270823541194, 3.0101981897365784, 2.114723939325992, 3.0591505360233118, 4.067542829579703, 4.971242351351084, 5.0621196817837735, 6.06257868120031, 7.058830775078335, 8.068708278044245, 9.040264753026852, 10.09025978264272, 10.792158327675288, 9.724780433359818, 8.764766247044463, 7.79976536281915, 6.8431643094596355, 5.801895450507723, 4.84799084435514, 3.891514336002854, 2.841268614239013, 1.9561390046808051, 1.05814967455765, 1.9971049989096727, 3.0481592140668545, 4.034156121476539, 4.223163293259236, 5.286348090568975, 6.280048773728412, 7.208086364906437, 8.155350682400407, 9.159895214895222, 9.747990600736944, 8.720732411352229, 7.756161775332723, 6.816212445008645, 5.88309055983754, 4.8227514186521265, 3.8841045831193965, 2.9447059780616636, 1.9153948091546877, 0.9277175826955644, 0.0, 1.0735750383339724, 2.140392655151185, 3.1737997562977265, 5.161242996019461, 6.166382071281653, 7.137085704642078, 8.118210781141272, 9.076099663735148, 10.086979551249373, 10.576865707183124, 9.634730913578707, 8.591253025571493, 7.6605980901520105, 6.683390551243205, 5.758217092506162, 4.819256857427295, 3.8726483170967634, 2.8856617248638363, 1.889835287159972, 1.0026953450601017, 2.0678629495090366, 3.0925561163517696, 4.107323864362207, 5.863748816820175, 6.898421350643782, 7.842541016726708, 8.911906677917939, 9.912574716832811, 10.886202586468935, 11.477639075420106, 10.486096274732542, 9.520216822848592, 8.621306451903383, 7.65878035230249, 6.789493212123008, 5.843277441957457, 4.90860651659578, 3.842894954153974, 2.951058339010636, 1.966744938288115, 2.9783670144151673, 3.943311862269155, 4.921364015832396, 6.789633582541298, 7.717586694486941, 8.735479568961884, 9.77409932648008, 10.821487052353815, 11.842236262016879, 12.421249762447914, 11.475803974676008, 10.470980828478595, 9.58999928846854, 8.610129910600017, 7.844462250872293, 6.844110000713749, 5.838500245340484, 4.803556385960711, 3.927406618912793, 2.905543698026512, 3.832357526539855, 4.806610838964882, 5.834028204148383, 7.783290563109648, 8.687150277409293, 9.740535271886026, 10.807406219958256, 11.838908680194727, 12.848660235571431, 13.368511729270333, 12.465194685833545, 11.49617796979026, 10.592347176270998, 9.659597361666112, 8.771999513017017, 7.890351272424267, 6.904213590961707, 5.83470187298596, 4.880273034444544, 3.9276737598612397, 4.8379602617699575, 5.7929432490865596, 6.762512604334126, 8.69566891552601, 9.627417846983143, 10.648000190273317, 11.61611969003217, 12.689372862234096, 13.70403498080607, 14.33343526658931, 13.418940848360283, 12.483149679757428, 11.523471634895046, 10.719049283382187, 9.752573972394357, 8.809363228682907, 7.794578307976675, 6.770644753879525, 5.887911506652058, 4.981929709318691, 5.888857064022159, 6.771623025495343, 7.718192466029297, 9.668550866427248, 10.610076247272808, 11.650954513743388, 12.612416520263134, 13.537778016248165, 14.53382427417193, 15.372970655492585, 14.399341370514724, 13.547278579209053, 12.585587322236664, 11.690368334998745, 10.752248740729053, 9.729521202548016, 8.661610298376917, 7.734810850724662, 6.813819459764447, 5.998692945788056, 6.851122329634627, 7.795028108923752, 8.773300616607248, 10.727795498770432, 11.644298768515482, 12.645605680175736, 13.104637504041749, 13.983590764181494, 14.525490939070302, 15.389934918801497, 15.359503915123142, 14.607323394617021, 13.59074312698474, 12.693784191549431, 11.697639300737741, 10.666819055078545, 9.684394858785474, 8.686249744664687, 7.841155665103388, 6.9999155702928615, 7.898489357422283, 8.814127782787873, 9.781217908057204, 11.728130168823524, 12.67395099792097, 12.99019727853921, 12.131971601134623, 12.979843322246126, 13.450687301506541, 14.385224182620412, 15.408135037422554, 15.590219107568135, 14.589816862947892, 13.608017279339155, 12.585884465294301, 11.625359991952367, 10.628412989491844, 9.701052519471775, 8.814092027551233, 7.999214490707494, 8.917665122752739, 9.785208273205965, 10.760431687462855, 12.60840423737714, 12.923782313011246, 12.005049708306318, 11.05802918368085, 11.998484138396964, 12.47747296189726, 13.421761160227629, 14.443577943004286, 15.448609683003017, 15.607527740255051, 14.560578142809385, 13.597845402440443, 12.55684175508192, 11.636563229233468, 10.740594988713443, 9.766957730214353, 8.954396398242718, 9.942799662079649, 10.712453580966832, 11.658406928822465, 12.900413722861215, 11.944800061094927, 11.01221153985075, 10.054008259610729, 10.934891556356085, 11.550340764720193, 12.518132667886505, 13.573711616659384, 14.575160819332982, 15.58272571226065, 15.50807837336572, 14.514682150189575, 13.569672027136994, 12.687789701541822, 11.72021919392096, 10.722427846720288, 9.976418263678903, 10.917270593122298, 11.731725264508906, 12.613639852550317, 11.889186824968, 10.877501839232824, 10.002074075320325, 9.053037854179715, 9.973394232035464, 10.608024863458018, 11.58321284774039, 12.60311198388045, 13.54486738936595, 14.55026853870017, 15.621835688565444, 15.471939868873248, 14.497646846083445, 13.663206355666803, 12.662514387774094, 11.6909702035739, 11.051037260012219, 11.929257476733358, 12.798149862026246, 12.827848773089796], [10.872743197267173, 11.829426524958999, 12.243434939105537, 13.176440425265692, 13.78938394503522, 14.74449775608208, 15.761330432658696, 16.613868957435287, 16.635976805184516, 15.628419938949737, 14.58128450609467, 13.748643069831338, 12.697077174686457, 11.688684741750649, 10.700642883545363, 9.90292296098973, 8.963072837962944, 8.228784113325279, 8.9782167201767, 10.004954316526806, 9.853837419620596, 10.774122178968975, 11.67640477889034, 12.624942000094032, 13.589689737174085, 14.578924363683896, 15.642353068182159, 16.632193624584836, 15.580430998791426, 14.59161234176191, 13.638216653332032, 12.686363281018277, 11.742648323840546, 10.726221151423276, 9.77351488797471, 8.897042156441094, 8.03762516047364, 7.198459276860999, 7.930126724344172, 8.975251971497421, 8.81011476658687, 9.740270725731085, 10.697030317559676, 11.66319603772333, 12.66203647053066, 13.674850114874076, 14.70041868145138, 15.5796567958677, 14.563993807085321, 13.637584229619858, 12.617370959867587, 11.686577971078417, 10.741046994600456, 9.799521081643642, 8.82522230838188, 7.9145496271586016, 6.964690893953856, 6.18505743183573, 7.004728573261005, 7.956557902932839, 7.791766721589585, 8.729180786609883, 9.752038132511663, 10.680647152016313, 11.719906663565688, 12.745348622488395, 13.693829399940967, 14.533625703452309, 13.548075353294028, 12.738458680067577, 11.76638843528227, 10.69821310525777, 9.781524104672448, 8.818975664316698, 7.805316352440287, 6.964175609891328, 6.035656983451196, 5.157349398042502, 6.01889438491656, 6.938636233508872, 6.866191070165971, 7.815152690029496, 8.815066664664045, 9.844122493804168, 10.775845778982204, 11.841653948897406, 12.842713920189782, 13.596282305469057, 12.555949243169655, 11.671920044222881, 10.722280074834714, 9.75884340484522, 8.834167778176637, 7.846822463981505, 6.826487106210704, 5.925368014407858, 5.036561121697382, 4.10769777192018, 5.073031603053641, 5.96841741756284, 5.858088976769949, 6.919828667249106, 7.869066563684131, 8.79445348132797, 9.833282942361826, 10.860862729537114, 11.798038183328178, 12.633975438334593, 11.62399588553447, 10.696462073904755, 9.750315182249281, 8.797913780991637, 7.807394809453476, 6.878435861118352, 5.900625491193222, 4.956481545639447, 4.029148544754455, 3.109272785512567, 4.125349575596079, 4.907745917509273, 4.977456979013911, 5.99162902796973, 6.952811504561848, 7.959805982469423, 9.028699048118689, 10.08868212911833, 11.01812724573468, 11.779737455626957, 10.776761242632377, 9.803472251494345, 8.73650751787836, 7.80739989480731, 6.954726853401955, 5.964835829238171, 4.9481455677641835, 3.9939664205074674, 3.0668949001193972, 2.1334108481126717, 3.105794149899688, 3.9783155877464322, 4.069192918179121, 5.069651917595658, 6.065904011473683, 7.0757815144395915, 8.012536272565466, 9.062531302181334, 10.0418357988438, 10.798355471693792, 9.838341285378437, 8.873340401153124, 7.916739347793609, 6.875470488841696, 5.921565882689113, 4.961150122123676, 3.9109044003598346, 2.939907235451694, 2.0103206353510554, 1.0713653109990324, 2.0552324504622024, 3.041229357871887, 3.1495882549252636, 4.212773052235002, 5.2064737353944395, 6.134511326572465, 7.081775644066434, 8.08632017656125, 9.022601273791889, 9.794307449686203, 8.829736813666697, 7.8897874833426185, 6.956665598171513, 5.8963264569861, 4.957679621453369, 4.018281016395636, 2.9889698474886597, 2.0012926210295365, 1.0735750383339724, 0.0, 1.066817616817213, 2.100224717963754, 4.087667957685489, 5.092807032947681, 6.0635106663081055, 7.0446357428073, 8.002524625401175, 9.0134045129154, 9.986548444139506, 10.708305951912678, 9.664828063905464, 8.734173128485983, 7.756965589577177, 6.831792130840134, 5.892831895761267, 4.946223355430735, 3.9592367631978083, 2.963410325493944, 2.0685465395245837, 0.9942879111750643, 2.0189810780177972, 3.0337488260282344, 4.9103793353636345, 5.945051869187242, 6.889171535270167, 7.958537196461398, 8.936267272693588, 9.909895142329711, 10.97835517404543, 11.559671313066513, 10.593791861182563, 9.694881490237355, 8.732355390636462, 7.863068250456981, 6.916852480291429, 5.982181554929752, 4.916469992487945, 4.016909533475118, 3.0325961327525968, 2.0249975329586265, 2.9899423808126144, 3.9679945343758556, 5.853887160562273, 6.781840272507916, 7.799733146982859, 8.838352904501056, 9.88574063037479, 10.865928817877656, 11.798591952408728, 12.549379013009979, 11.544555866812566, 10.663574326802513, 9.68370494893399, 8.918037289206266, 7.91768503904772, 6.912075283674455, 5.877131424294682, 4.993257813377275, 3.9713948924909936, 3.0576489298754366, 3.9252953039207457, 4.898281782169358, 6.847544141130623, 7.751403855430269, 8.804788849907002, 9.871659797979232, 10.903162258215703, 11.912913813592407, 12.745853919231147, 13.538769724167516, 12.56975300812423, 11.66592221460497, 10.733172400000084, 9.84557455135099, 8.963926310758238, 7.977788629295677, 6.908276911319932, 5.946124228909025, 4.993524954325721, 4.063251665105539, 4.911627714042424, 5.88119706928999, 7.814353380481875, 8.691671425004118, 9.712253768294293, 10.680373268053145, 11.753626440255072, 12.768288558827045, 13.710777456550124, 14.492515886694253, 13.556724718091399, 12.597046673229016, 11.79262432171616, 10.826149010728331, 9.882938267016879, 8.868153346310647, 7.844219792213497, 6.953762701116539, 6.047780903783173, 5.11414846735774, 5.890307490451207, 6.836876930985161, 8.787235331383114, 9.702422784686851, 10.715208091764364, 11.67667009828411, 12.602031594269143, 13.598077852192908, 14.561000985056943, 15.472916408848695, 14.620853617543023, 13.659162360570635, 12.763943373332717, 11.825823779063025, 10.803096240881988, 9.73518533671089, 8.808385889058634, 7.879670654228928, 7.064544140252538, 6.076413732970209, 6.957475829276492, 7.891985081563112, 9.846479963726297, 10.736645305929525, 11.709859258196712, 12.607540413496935, 13.620622701926003, 14.530104221912495, 15.53506490512385, 16.433078953457112, 15.680898432950992, 14.664318165318711, 13.767359229883404, 12.771214339071712, 11.740394093412515, 10.757969897119446, 9.75982478299866, 8.907006859567868, 8.065766764757344, 7.123780760757866, 7.976575503140614, 8.899902373013068, 10.84681463377939, 11.781808311291345, 12.198504943797783, 13.07131476597881, 13.919186487090315, 14.484205786916606, 15.418742668030477, 16.441653522832617, 16.663794145902106, 15.663391901281862, 14.681592317673125, 13.659459503628272, 12.698935030286338, 11.701988027825816, 10.774627557805747, 9.879943222015713, 9.065065685171975, 8.142956526088321, 8.947655993558707, 9.922879407815596, 11.770851957729882, 11.96203363333123, 11.213357373564891, 11.997372348525037, 12.937827303241153, 13.510991447307324, 14.455279645637694, 15.47709642841435, 16.482128168413084, 16.681102778589022, 15.634153181143356, 14.671420440774414, 13.63041679341589, 12.71013826756744, 11.80844457348493, 10.832808924678833, 10.020247592707198, 9.168091065415231, 9.874901301319573, 10.820854649175207, 11.9386650431812, 10.98305138141491, 10.192893382828998, 10.993351424454916, 11.874234721200274, 12.583859250130258, 13.55165115329657, 14.60723010206945, 15.608679304743047, 16.616244197670714, 16.58165341169969, 15.588257188523546, 14.643247065470964, 13.761364739875795, 12.788068778692447, 11.788279041184769, 11.042269458143384, 10.2379707176131, 10.894172984861648, 11.776087572903059, 10.927438145287985, 9.915753159552809, 9.182755918298572, 9.992381019023902, 10.912737396879653, 11.641543348868083, 12.616731333150454, 13.636630469290514, 14.578385874776014, 15.590471856271957, 16.66203900613723, 16.545514907207217, 15.571221884417415, 14.736781394000776, 13.73036397254558, 12.75682139803838, 12.1168884544767, 11.24995760122416, 11.960597582378988, 11.834922009485142], [9.805925580449962, 10.762608908141786, 11.600100040377129, 12.59097518184971, 13.55290154953603, 14.491308665183936, 15.518652478801915, 16.533536583529546, 17.473193720728645, 16.596523676752877, 15.54938824389781, 14.636218056717208, 13.570154542605701, 12.561762109669893, 11.573720251464607, 10.729715032900549, 9.772329553926957, 8.912325230968344, 7.911399103359488, 8.938136699709595, 8.787019802803385, 9.707304562151762, 10.609587162073126, 11.558124383276818, 12.52287212035687, 13.512106746866682, 14.575535451364944, 15.56753126515859, 16.54853473659457, 15.559716079565051, 14.606320391135172, 13.654467018821418, 12.61572569175979, 11.59929851934252, 10.646592255893953, 9.742159170057493, 8.846881876437653, 7.918560031773475, 6.863309107526959, 7.9084343546802085, 7.743297149769658, 8.673453108913872, 9.630212700742462, 10.596378420906115, 11.595218853713446, 12.608032498056861, 13.633601064634167, 14.65548957406111, 15.532097544888462, 14.605687967422998, 13.585474697670728, 12.654681708881558, 11.66857328400058, 10.672598449562885, 9.698299676301124, 8.759666640775, 7.809807907570255, 6.953113925932216, 5.937910956443792, 6.889740286115626, 6.724949104772373, 7.66236316979267, 8.68522051569445, 9.6138295351991, 10.653089046748475, 11.678531005671182, 12.627011783123754, 13.618120317525976, 14.516179091097168, 13.706562417870717, 12.73449217308541, 11.66631684306091, 10.749627842475586, 9.787079402119836, 8.773420090243425, 7.809292623507728, 6.880773997067596, 5.945655921260887, 4.952076768099348, 5.871818616691659, 5.799373453348759, 6.748335073212283, 7.748249047846832, 8.777304876986955, 9.70902816216499, 10.774836332080195, 11.775896303372567, 12.662057194842248, 13.524052980972796, 12.640023782026022, 11.690383812637855, 10.72694714264836, 9.802271515979777, 8.814926201784644, 7.794590844013843, 6.8934717522109965, 5.950519100223576, 5.021655750446374, 4.006213986236428, 4.901599800745627, 4.791271359952736, 5.853011050431893, 6.802248946866918, 7.7276358645107575, 8.766465325544614, 9.7940451127199, 10.731220566510963, 11.699750327707784, 12.59209962333761, 11.664565811707895, 10.718418920052422, 9.766017518794778, 8.775498547256616, 7.846539598921491, 6.868729228996361, 5.924585283442585, 4.997252282557594, 4.023230764038761, 3.0585319587788664, 3.8409283006920605, 3.910639362196698, 4.924811411152517, 5.885993887744635, 6.892988365652211, 7.961881431301477, 9.021864512301116, 9.951309628917466, 10.968471852300146, 11.839318096741223, 10.866029105603191, 9.799064371987207, 8.869956748916158, 7.966547727217399, 6.93293956704131, 5.916249305567322, 4.962070158310606, 4.034998637922536, 3.0473688266388663, 2.038976533082475, 2.9114979709292195, 3.002375301361909, 4.002834300778445, 4.99908639465647, 6.008963897622379, 6.9457186557482515, 7.9957136853641195, 8.975018182026586, 9.987089868366981, 10.900898139487284, 9.93589725526197, 8.979296201902455, 7.9380273429505435, 6.984122736797961, 5.929253859926814, 4.879008138162973, 3.9080109732548327, 2.978424373154194, 2.039469048802171, 0.9884148336449894, 1.9744117410546744, 2.0827706381080504, 3.1459554354177888, 4.139656118577226, 5.06769370975525, 6.01495802724922, 7.019502559744036, 7.955783656974676, 8.983041846359392, 9.896554430483908, 8.95660510015983, 8.023483214988726, 6.963144073803313, 6.024497238270582, 5.085098633212849, 4.0557874643058724, 3.0681102378467493, 2.140392655151185, 1.066817616817213, 0.0, 1.033407101146541, 3.020850340868276, 4.025989416130468, 4.996693049490893, 5.977818125990087, 6.935707008583963, 7.946586896098188, 8.919730827322294, 9.86186562092671, 10.731645680722679, 9.800990745303196, 8.82378320639439, 7.898609747657347, 6.95964951257848, 6.013040972247948, 5.0260543800150215, 4.030227942311157, 3.135364156341797, 2.0611055279922774, 1.0368967438041894, 2.0140956263295697, 3.9731851599897077, 5.007857693813315, 5.95197735989624, 7.00556298071136, 7.869449655876375, 8.843077525512498, 9.911537557228216, 10.90308035791578, 11.660609477999778, 10.761699107054568, 9.799173007453675, 8.929885867274194, 7.983670097108642, 7.048999171746965, 5.983287609305159, 5.064060068224126, 4.079746667501605, 3.068124591374553, 2.103179743520565, 3.030800359001929, 4.916692985188346, 5.844646097133989, 6.862538971608932, 7.901158729127129, 8.90901931912446, 9.799111201060443, 10.731774335591515, 11.677220123363421, 12.61137348362978, 11.730391943619725, 10.750522565751202, 9.984854906023479, 8.970700145726175, 7.96509039035291, 6.930146530973137, 5.980954265588489, 4.939599807567065, 4.012785979053723, 3.0385326666286963, 3.961087606795431, 5.910349965756696, 6.814209680056342, 7.867594674533075, 8.934465622605305, 9.926440946965373, 10.858125120635808, 11.679036302413934, 12.706186745201794, 13.636570624941445, 12.732739831422183, 11.799990016817297, 10.912392168168203, 10.016941417436692, 9.02816310405608, 7.957732090297825, 6.914329143985097, 5.961729869401793, 5.018388714283825, 4.024865076750374, 4.96396692578896, 6.909692428871653, 7.754477249630192, 8.775059592920366, 9.743179092679219, 10.816432264881145, 11.804166992778626, 12.643959839732911, 13.581634235831242, 14.623542334908613, 13.66386429004623, 12.859441938533372, 11.892966627545544, 10.932393445994773, 9.917608525288541, 8.893674971191391, 7.921967616192611, 7.015985818859245, 6.044089471901891, 5.003544853159157, 5.950114293693112, 7.882574379772891, 8.765228609312924, 9.778013916390437, 10.739475922910183, 11.664837418895214, 12.66088367681898, 13.623806809683014, 14.562034757985684, 15.517324649084296, 14.72597997738785, 13.83076099014993, 12.87527895804092, 11.852551419859882, 10.784640515688784, 9.857841068036528, 8.847875569305, 8.020895463961017, 7.00635473751436, 6.070713191984443, 7.005222444271062, 8.941819012116074, 9.799451130555598, 10.772665082822785, 11.670346238123008, 12.683428526552076, 13.592910046538567, 14.597870729749921, 15.522197302594101, 16.577369464492264, 15.731135782135926, 14.834176846700617, 13.820669518049606, 12.78984927239041, 11.80742507609734, 10.809279961976554, 9.87521177464394, 9.012678397535536, 8.053721765302017, 7.089812865848565, 8.013139735721019, 9.942153682169167, 10.844614135917418, 11.73056145069992, 12.643012141030134, 13.57487413294316, 14.593674695551691, 15.528211576665562, 16.48554391857078, 17.4579877694545, 16.730209518099077, 15.73104749665102, 14.708914682606165, 13.748390209264231, 12.75144320680371, 11.8104664682292, 10.848148137091785, 10.011977317950167, 9.046208896136418, 8.060893356266657, 9.036116770523547, 10.884089320437832, 10.895216016514018, 11.840188962667833, 12.787209487293302, 13.76461937515197, 14.384068815226568, 15.328357013556937, 16.350173796333593, 17.355205536332324, 17.730557957566912, 16.683608360121248, 15.720875619752308, 14.679871972393784, 13.747773862078066, 12.776649488561002, 11.801013839754905, 10.967159225485391, 10.036722526137458, 8.988138664027524, 9.934092011883157, 10.871847426363988, 9.916233764597699, 10.81972497193194, 11.802343459419351, 12.70102679311109, 13.456936618049502, 14.424728521215814, 15.480307469988693, 16.481756672662293, 17.48932156558996, 17.631108590677584, 16.63771236750144, 15.692702244448858, 14.762103141803339, 13.756273693768518, 12.75648395626084, 11.892829593347352, 10.951977263903958, 10.007410347569598, 10.88932493561101, 9.860620528470774, 8.848935542735598, 9.809587507401513, 10.801637734987915, 11.739529468790469, 12.514620716787327, 13.489808701069698, 14.509707837209758, 15.451463242695258, 16.496868730870467, 17.56843588073574, 17.59497008618511, 16.62067706339531, 15.73751979592832, 14.698568887621652, 13.725026313114451, 12.967448589680668, 11.963964147515018, 11.073834945086938, 10.768104392667931], [8.798952442880369, 9.755635770572194, 10.59312690280754, 11.584002044280123, 12.54592841196644, 13.484335527614345, 14.511679341232323, 15.526563445959955, 16.466220583159057, 17.362947474573836, 16.315812041718768, 15.374384540481378, 14.308321026369871, 13.299928593434062, 12.311886735228777, 11.467881516664718, 10.510496037691127, 9.650491714732514, 8.649565587123657, 8.022179205197512, 7.780046665233793, 8.70033142458217, 9.602614024503536, 10.551151245707228, 11.51589898278728, 12.50513360929709, 13.568562313795352, 14.560558127589, 15.61232075338241, 16.32613987738601, 15.37274418895613, 14.41270211525098, 13.35389217552396, 12.33746500310669, 11.384758739658123, 10.480325653821662, 9.585048360201823, 8.656726515537645, 7.601475591291129, 6.963417597310267, 6.7363240122000665, 7.666479971344281, 8.623239563172872, 9.589405283336525, 10.588245716143856, 11.60105936048727, 12.626627927064574, 13.648516436491517, 14.612615983905958, 15.410016255877432, 14.389802986125162, 13.459009997335992, 12.40673976776475, 11.410764933327055, 10.436466160065294, 9.49783312453917, 8.547974391334424, 7.691280409696386, 6.676077440207962, 5.925385087055, 5.717975967202781, 6.655390032223078, 7.6782473781248575, 8.606856397629507, 9.646115909178882, 10.671557868101589, 11.62003864555416, 12.611147179956383, 13.596697530114664, 14.573422920949128, 13.616566793833229, 12.548391463808729, 11.584488182712603, 10.621939742356853, 9.591489436240776, 8.547459107271898, 7.618940480831766, 6.683822405025056, 5.690243251863517, 4.864845479122066, 4.792400315779167, 5.741361935642692, 6.741275910277239, 7.770331739417363, 8.7020550245954, 9.767863194510603, 10.768923165802976, 11.655084057272656, 12.634710100573502, 13.526661382841079, 12.577021413452911, 11.613584743463417, 10.688909116794834, 9.701563802599702, 8.681228444828902, 7.653362876212423, 6.691653454004687, 5.762790104227485, 4.744380470000598, 3.8946266631760347, 3.784298222383144, 4.8460379128623, 5.795275809297325, 6.720662726941165, 7.759492187975021, 8.787071975150308, 9.724247428941371, 10.692777190138193, 11.702756742938316, 12.551203412522952, 11.605056520867478, 10.652655119609834, 9.662136148071673, 8.733177199736549, 7.755366829811419, 6.776129307113614, 5.848796306228622, 4.821333985882987, 3.796698442543036, 2.833955163122468, 2.903666224627105, 3.9178382735829245, 4.879020750175043, 5.886015228082618, 6.937667403481107, 7.988457411154575, 8.917902527770925, 9.935064751153606, 10.896488958761001, 11.831049782852968, 10.764085049236984, 9.834977426165935, 8.928093691860655, 7.894485531684566, 6.864711577979307, 5.910532430722591, 4.886542661593564, 3.845472048483092, 2.8370797549267004, 1.9045248333596267, 1.9954021637923165, 2.9958611632088523, 3.992113257086878, 5.001990760052786, 5.912311554601711, 6.962306584217579, 7.941611080880046, 8.95368276722044, 9.93356919387568, 10.892369211606514, 9.944316879152233, 8.90304802020032, 7.949143414047738, 6.894274537176591, 5.8440288154127495, 4.873031650504609, 3.9434450504039713, 3.0044897260519488, 1.953435510894767, 0.9674386034850819, 1.0493635369615093, 2.1125483342712474, 3.1062490174306845, 4.03428660860871, 4.981550926102679, 5.986095458597496, 6.922376555828135, 7.949634745212851, 8.914205381232357, 9.854154711556435, 9.056890316135267, 7.996551174949854, 7.0579043394171235, 6.11850573435939, 5.089194565452414, 4.101517338993291, 3.1737997562977265, 2.100224717963754, 1.033407101146541, 0.0, 1.9874432397217348, 2.992582314983926, 3.9632859483443514, 4.9444110248435456, 5.902299907437422, 6.913179794951647, 7.886323726175754, 8.82845851978017, 9.871936407787384, 10.79991518886949, 9.827346767770862, 8.90217330903382, 7.963213073954952, 7.01660453362442, 6.029617941391494, 5.033791503687629, 4.094408068385718, 3.0201494400361986, 1.9954562731934655, 0.9806885251830285, 2.9397780588431663, 3.9744505926667735, 4.918570258749699, 5.972155879564819, 6.8360425547298345, 7.809670424365958, 8.878130456081676, 9.86967325676924, 10.800900205064483, 11.760623550620862, 10.802736568830147, 9.933449428650665, 8.987233658485113, 7.952845845259101, 6.887134282817295, 5.93632573612219, 4.952012335399669, 3.9403902592726165, 2.9754454114186286, 1.9973932578553875, 3.883285884041805, 4.8112389959874475, 5.8291318704623905, 6.867751627980588, 7.875612217977921, 8.765704099913902, 9.698367234444975, 10.64381302221688, 11.674913791555406, 12.600035121807412, 11.754086127127675, 10.913960389481563, 9.842965813624236, 8.837356058250972, 7.8024121988712, 6.853219933486551, 5.811865475465129, 4.885051646951786, 3.91079833452676, 2.9276805056488895, 4.876942864610155, 5.7808025789098005, 6.834187573386535, 7.901058521458763, 8.893033845818833, 9.824718019489268, 10.645629201267393, 11.672779644055254, 12.641796360098539, 13.60238300960987, 12.767023981765917, 11.841497651626288, 10.889207085334753, 9.900428771954143, 8.829997758195889, 7.78659481188316, 6.833995537299856, 5.890654382181888, 4.897130744648438, 3.930559824642419, 5.876285327725111, 6.72107014848365, 7.7416524917738245, 8.709771991532678, 9.783025163734605, 10.770759891632085, 11.610552738586371, 12.548227134684701, 13.600401563916114, 14.533507468233918, 13.826475903481992, 12.822072111003628, 11.804659113892836, 10.789874193186604, 9.765940639089454, 8.794233284090673, 7.888251486757308, 6.916355139799955, 5.875810521057221, 4.986135998610174, 6.84916727862635, 7.731821508166382, 8.744606815243895, 9.706068821763642, 10.631430317748674, 11.62747657567244, 12.590399708536474, 13.528627656839143, 14.483917547937756, 15.45259537073118, 14.79779495509855, 13.747544625938982, 12.724817087757945, 11.656906183586846, 10.73010673593459, 9.720141237203062, 8.89316113185908, 7.878620405412423, 6.942978859882507, 6.041244149188125, 7.908411910969533, 8.766044029409056, 9.739257981676243, 10.636939136976467, 11.650021425405535, 12.559502945392026, 13.56446362860338, 14.48879020144756, 15.543962363345724, 16.457751175479256, 15.741336093664978, 14.692935185947668, 13.662114940288472, 12.679690743995403, 11.681545629874616, 10.747477442542003, 9.884944065433599, 8.92598743320008, 7.962078533746628, 7.049161440638081, 8.908746581022626, 9.811207034770876, 10.697154349553378, 11.609605039883593, 12.54146703179662, 13.56026759440515, 14.494804475519022, 15.452136817424238, 16.424580668307957, 17.4249829129282, 16.603313164549082, 15.581180350504228, 14.620655877162294, 13.623708874701773, 12.682732136127262, 11.720413804989848, 10.88424298584823, 9.918474564034483, 8.933159024164722, 8.09797312536612, 9.874853229291906, 10.742426369121658, 11.68230191978627, 12.629322444411738, 13.52282621564578, 14.518061368740764, 15.462349567071133, 16.48416634984779, 17.48662686742529, 18.41704829964722, 17.55587402801931, 16.59314128765037, 15.552137640291846, 14.620039529976129, 13.648915156459065, 12.673279507652968, 11.839424893383454, 10.908988194035523, 9.860404331925588, 9.136754029244658, 10.035180651794448, 10.654400248361867, 11.557891455696108, 12.540509943183519, 13.439193276875262, 14.195103101813672, 15.162895004979983, 16.218473953752863, 17.219923156426464, 18.227488049354132, 18.50337425857565, 17.509978035399506, 16.564967912346923, 15.634368809701401, 14.628539361666581, 13.628749624158903, 12.765095261245417, 11.824242931802022, 10.879676015467663, 10.09198695297251, 9.023953753901234, 9.587102026499766, 10.547753991165681, 11.539804218752085, 12.47769595255464, 13.252787200551497, 14.227975184833868, 15.247874320973928, 16.18962972645943, 17.23503521463464, 18.306602364499913, 17.439940239151788, 16.465647216361987, 15.536228379890243, 14.503064441919491, 13.57849095896328, 12.643554015069116, 11.586604240688917, 10.725603126937495, 9.761131255098338], [8.877415179973966, 9.834098507665791, 10.671589639901136, 11.662464781373718, 12.624391149060036, 13.562798264707943, 14.590142078325922, 15.605026183053553, 16.544683320252652, 17.569109597998256, 18.28383584193802, 17.342408340700633, 16.276344826589124, 15.267952393653315, 14.27991053544803, 13.435905316883971, 12.47851983791038, 11.618515514951767, 10.61758938734291, 9.887592811934006, 7.858509402327389, 8.778794161675767, 9.681076761597133, 10.629613982800825, 11.594361719880878, 12.583596346390689, 13.647025050888951, 14.639020864682598, 15.687492116607595, 16.700906823608072, 17.340767989175383, 16.380725915470233, 15.321915975743213, 14.305488803325943, 13.352782539877376, 12.448349454040915, 11.553072160421076, 10.624750315756899, 9.569499391510382, 8.898268613132505, 6.8147867492936625, 7.744942708437877, 8.701702300266469, 9.667868020430122, 10.666708453237453, 11.679522097580868, 12.693129224653752, 13.715017734080696, 14.67105492490149, 15.678309645432485, 16.357826786344415, 15.427033797555245, 14.374763567984003, 13.378788733546308, 12.404489960284547, 11.465856924758423, 10.515998191553678, 9.65930420991564, 8.644101240427215, 7.860236102877238, 5.796438704296377, 6.733852769316674, 7.756710115218453, 8.685319134723104, 9.71261720676806, 10.738059165690768, 11.68653994314334, 12.677648477545562, 13.655136471110197, 14.63186186194466, 15.584590594052482, 14.516415264027982, 13.552511982931856, 12.589963542576106, 11.55951323646003, 10.515482907491151, 9.586964281051019, 8.65184620524431, 7.65826705208277, 6.81906841824253, 4.870863052872763, 5.819824672736288, 6.784313850234948, 7.8133696793750715, 8.73035528500772, 9.796163454922922, 10.797223426215298, 11.683384317684979, 12.663010360985824, 13.607254834099793, 14.545045213672163, 13.581608543682668, 12.656932917014085, 11.669587602818952, 10.649252245048151, 9.621386676431676, 8.65967725422394, 7.730813904446737, 6.71240427021985, 5.862650463395287, 3.86276095947674, 4.889075852820009, 5.838313749255034, 6.763700666898874, 7.787792448387343, 8.81537223556263, 9.752547689353694, 10.721077450550515, 11.731057003350639, 12.643657298052732, 13.57308032108673, 12.620678919829086, 11.630159948290924, 10.7012009999558, 9.72339063003067, 8.744153107332865, 7.8168201064478735, 6.78935778610224, 5.764722242762288, 4.80197896334172, 2.9187302166816913, 3.890240516734037, 4.851422993326155, 5.8584174712337305, 6.817020710736451, 7.867810718409919, 8.797255835026268, 9.803124893067203, 10.764549100674598, 11.70190339013077, 12.628685635327027, 11.803001226385188, 10.896117492079906, 9.862509331903818, 8.832735378198558, 7.878556230941842, 6.854566461812816, 5.8134958487023445, 4.805103555145953, 3.8725486335788792, 1.9074988433970996, 2.9079578428136355, 3.904209936691661, 4.914087439657569, 5.791664861857055, 6.841659891472923, 7.82096438813539, 8.821742909134038, 9.801629335789277, 10.760429353520113, 11.667379930352908, 10.871071820419573, 9.91716721426699, 8.862298337395844, 7.812052615632003, 6.841055450723863, 5.911468850623224, 4.972513526271201, 3.9214593111140195, 2.935462403704334, 0.9380797027602255, 1.9919016415265913, 2.9856023246860284, 3.9136399158640534, 4.860904233358023, 5.86544876585284, 6.801729863083479, 7.817694887126449, 8.782265523145954, 9.722214853470032, 10.655336738641136, 9.90837365047837, 8.969726814945641, 8.030328209887909, 7.063589614060332, 6.075912387601209, 5.161242996019461, 4.087667957685489, 3.020850340868276, 1.9874432397217348, 0.0, 1.0051390752621914, 1.9758427086226167, 2.956967785121811, 3.914856667715687, 4.9257365552299115, 5.8988804864540185, 6.841015280058436, 7.884493168065649, 8.815148103485132, 9.792355642393938, 8.982176488482992, 8.043216253404124, 7.096607713073592, 6.109621120840665, 5.113794683136801, 4.17441124783489, 3.1001526194853697, 2.0754594526426366, 1.0606917046321995, 1.0462219767909062, 2.0143382928279143, 2.957808553919236, 3.9847126398430843, 4.8485993150081, 5.822227184644223, 6.890687216359941, 7.882230017047504, 8.813456965342748, 9.775856465236505, 10.767745443453222, 9.96195865407535, 9.015742883909798, 7.944059365182398, 6.878347802740592, 5.927539256045487, 4.943225855322966, 3.931603779195914, 2.966658931341926, 1.9886067777786849, 2.0022798134375117, 2.9302329253831543, 3.9381524247635022, 4.962346614281637, 5.888168978256187, 6.778260860192168, 7.710923994723241, 8.656369782495146, 9.687470551833671, 10.612591882085677, 11.5924612599542, 10.905173909404862, 9.834179333547535, 8.828569578174271, 7.793625718794497, 6.844433453409849, 5.803078995388426, 4.876265166875084, 3.9020118544500573, 2.918894025572187, 2.9959367940058614, 3.899796508305507, 4.953181502782241, 5.995653507759814, 6.905590606097099, 7.837274779767532, 8.65818596154566, 9.68533640433352, 10.654353120376806, 11.614939769888135, 12.58296640811642, 11.832711171549587, 10.880420605258053, 9.89164229187744, 8.821211278119186, 7.777808331806457, 6.825209057223153, 5.881867902105186, 4.888344264571735, 3.9217733445657164, 3.995279257120818, 4.840064077879356, 5.86064642116953, 6.828765920928383, 7.858410168187452, 8.783316651910349, 9.623109498864638, 10.560783894962968, 11.61295832419438, 12.546064228512183, 13.573518354679054, 12.813285630926927, 11.795872633816133, 10.781087713109901, 9.757154159012751, 8.785446804013972, 7.879465006680605, 6.907568659723252, 5.867024040980518, 4.972755706617532, 4.968161208022057, 5.850815437562089, 6.8636007446396015, 7.825062751159347, 8.75042424714438, 9.746470505068146, 10.662644887767913, 11.54118441711741, 12.496474308216023, 13.465152131009447, 14.423797130080604, 13.73875814586228, 12.716030607681242, 11.648119703510144, 10.721320255857888, 9.711354757126362, 8.884374651782377, 7.869833925335721, 6.934192379805804, 5.915180420894758, 6.0274058403652395, 6.885037958804762, 7.8582519110719495, 8.755933066372172, 9.76901535480124, 10.678496874787733, 11.636708807834822, 12.501346961725828, 13.55651912362399, 14.470307935757523, 15.427212986631291, 14.684148705870967, 13.653328460211771, 12.6709042639187, 11.672759149797914, 10.738690962465302, 9.876157585356896, 8.917200953123377, 7.909546710505894, 6.923097712344714, 7.027740510418333, 7.930200964166582, 8.816148278949084, 9.728598969279298, 10.660460961192324, 11.679261523800855, 12.613798404914727, 13.464693577702505, 14.437137428586224, 15.437539673206468, 16.380777621917968, 15.572393870427527, 14.611869397085593, 13.61492239462507, 12.673945656050561, 11.711627324913147, 10.875456505771528, 9.865942740793749, 8.880627200923987, 7.9719093970727535, 7.993847158687612, 8.861420298517364, 9.801295849181976, 10.748316373807445, 11.641820145041486, 12.637055298136469, 13.581343496466838, 14.527126558333281, 15.499183627703559, 16.42960505992549, 17.396626521114737, 16.584354807573668, 15.543351160215146, 14.611253049899428, 13.640128676382364, 12.664493027576267, 11.830638413306751, 10.856456370794788, 9.807872508684854, 8.943844467242286, 9.006705063292953, 9.840402550433684, 10.821759839917869, 11.752337297877565, 12.705412727082365, 13.564187495313535, 14.554910990975523, 15.523191144123517, 16.55211905268418, 17.465555298975563, 18.4113712298483, 17.501191555322805, 16.556181432270222, 15.6255823296247, 14.61975288158988, 13.619963144082202, 12.712563438004683, 11.771711108561288, 10.827144192226928, 9.899077390970138, 10.017931961186168, 10.907700772295787, 11.831897304448294, 12.753307703308579, 13.666910051402986, 14.50650339657571, 15.489830811121639, 16.49379077690245, 17.435546182387952, 18.48095167056316, 18.543148928855935, 17.51840297624539, 16.54410995345559, 15.614691116983842, 14.58152717901309, 13.656953696056878, 12.72201675216271, 11.665066977782512, 10.804065864031092, 9.839593992191935], [9.882554255236156, 9.06870414528986, 9.893428268623293, 10.884303410095875, 11.726998093731337, 12.665405209379244, 13.64084695234727, 14.655731057074899, 15.595388194274, 16.619814472019605, 17.5922312895384, 17.470244314285992, 16.44083575937606, 15.443265254345322, 14.472791713722307, 13.702112339116784, 12.808003736193413, 11.811256961245462, 10.87062506349577, 10.892731887196197, 8.86364847758958, 8.013399799299837, 8.902915390319288, 9.85145261152298, 10.696968664552179, 11.68620329106199, 12.69072024872708, 13.682716062520727, 14.682353041345404, 15.695767748345883, 16.649163436775762, 17.385864990732422, 16.327055051005402, 15.310627878588134, 14.357921615139567, 13.453488529303106, 12.558211235683267, 11.62988939101909, 10.574638466772573, 9.903407688394696, 7.819925824555853, 6.9795483460619465, 7.923540928988625, 8.889706649152279, 9.769315397908754, 10.716249237119953, 11.687990149391561, 12.709878658818505, 13.6659158496393, 14.673170570170294, 15.666030268311196, 16.425730705790436, 15.379902643246194, 14.3839278088085, 13.409629035546738, 12.470996000020614, 11.521137266815868, 10.66444328517783, 9.649240315689406, 8.865375178139429, 6.801577779558568, 5.968458406940743, 6.939697007678546, 7.868306027183196, 8.70747813150587, 9.732920090428577, 10.681400867881148, 11.67250940228337, 12.649997395848006, 13.626722786682471, 14.606971455557822, 15.43736583996979, 14.557651058194047, 13.595102617838297, 12.56465231172222, 11.520621982753342, 10.59210335631321, 9.6569852805065, 8.663406127344961, 7.824207493504721, 5.876002128134954, 5.0294444849630935, 5.883715368133611, 6.9127711972737345, 7.725216209745529, 8.791024379660733, 9.792084350953107, 10.678245242422788, 11.657871285723633, 12.602115758837602, 13.55175572822577, 14.49799613955724, 13.662071992276276, 12.674726678081143, 11.654391320310342, 10.626525751693867, 9.664816329486131, 8.735952979708928, 7.717543345482041, 6.867789538657478, 4.867900034738931, 3.9884773707186723, 4.937715267153697, 5.863102184797537, 6.782653373125152, 7.810233160300439, 8.747408614091503, 9.715938375288324, 10.725917928088448, 11.63851822279054, 12.584665114446013, 13.537066515703657, 12.635299023553115, 11.706340075217991, 10.72852970529286, 9.749292182595056, 8.821959181710065, 7.794496861364431, 6.769861318024479, 5.807118038603911, 3.9238692919438827, 2.9896420346326993, 3.9508245112248175, 4.957818989132393, 5.81188163547426, 6.862671643147728, 7.7921167597640775, 8.797985817805012, 9.759410025412407, 10.696764314868577, 11.623546560064836, 12.552654183135886, 11.901256567342097, 10.867648407166008, 9.83787445346075, 8.883695306204032, 7.859705537075007, 6.818634923964535, 5.810242630408144, 4.87768770884107, 2.912637918659291, 2.007359360712298, 3.0036114545903234, 3.9621419447256447, 4.786525786594864, 5.836520816210732, 6.815825312873199, 7.816603833871847, 8.796490260527086, 9.75529027825792, 10.662240855090717, 11.70350971404263, 10.922306289529182, 9.867437412658035, 8.817191690894195, 7.8461945259860535, 6.9166079258854145, 5.977652601533392, 4.92659838637621, 3.9406014789665256, 1.9432187780224168, 0.9867625662644, 1.980463249423837, 2.908500840601862, 3.855765158095832, 4.860309690590648, 5.7965907878212874, 6.812555811864257, 7.777126447883763, 8.71707577820784, 9.650197663378945, 10.70189977924442, 9.974865890207832, 9.0354672851501, 8.068728689322523, 7.081051462863399, 6.166382071281652, 5.09280703294768, 4.025989416130467, 2.992582314983926, 1.0051390752621914, 0.0, 0.9707036333604252, 1.9518287098596194, 2.9097175924534957, 3.92059747996772, 4.893741411191827, 5.835876204796244, 6.8793540928034576, 7.8100090282229395, 8.787216567131745, 9.712390025868787, 9.048355328666315, 8.101746788335783, 7.114760196102855, 6.118933758398991, 5.17955032309708, 4.10529169474756, 3.0805985279048276, 2.065830779894391, 2.04387175138933, 1.0091992175657227, 1.9526694786570444, 2.9795735645808934, 3.843460239745908, 4.8170881093820315, 5.885548141097749, 6.877090941785311, 7.8083178900805565, 8.770717389974312, 9.76260636819103, 10.741432539610997, 10.013392658508222, 8.941709139780823, 7.875997577339016, 6.925189030643911, 5.94087562992139, 4.929253553794338, 3.9643087059403497, 2.9862565523771085, 2.8835738891526743, 1.9556207772070318, 2.9330133495013113, 3.9572075390194463, 4.883029902993995, 5.773121784929976, 6.705784919461049, 7.651230707232955, 8.68233147657148, 9.607452806823487, 10.58732218469201, 11.59207149493743, 10.798764111826571, 9.793154356453305, 8.758210497073533, 7.809018231688883, 6.76766377366746, 5.840849945154117, 4.866596632729091, 3.83917926754559, 3.877230869721024, 2.9251843601293843, 3.978569354606118, 4.990514432497623, 5.900451530834907, 6.83213570450534, 7.653046886283469, 8.680197329071328, 9.649214045114613, 10.609800694625944, 11.57782733285423, 12.50335366299386, 11.845005383537089, 10.856227070156475, 9.78579605639822, 8.742393110085493, 7.789793835502188, 6.846452680384219, 5.811627941786686, 4.842058586539119, 4.876573332835981, 3.8654519297032337, 4.886034272993408, 5.854153772752261, 6.85327109292526, 7.778177576648157, 8.617970423602445, 9.555644819700776, 10.607819248932188, 11.54092515324999, 12.568379279416861, 13.4839281223712, 12.760457412095167, 11.745672491388936, 10.721738937291786, 9.750031582293007, 8.819539714022783, 7.830852336938203, 6.790307718195469, 5.8540497823326945, 5.817728670231526, 4.876203289385966, 5.888988596463479, 6.850450602983225, 7.775812098968257, 8.771858356892023, 9.65750581250572, 10.536045341855218, 11.49133523295383, 12.460013055747254, 13.418658054818412, 14.470264647024079, 13.680615385960277, 12.612704481789178, 11.685905034136923, 10.675939535405396, 9.760355042613579, 8.745814316166923, 7.801908536877798, 6.764747883104227, 6.876973302574709, 5.91042581062864, 6.883639762895827, 7.78132091819605, 8.794403206625118, 9.70388472661161, 10.631569732572629, 11.496207886463635, 12.551380048361798, 13.46516886049533, 14.422073911369099, 15.453838055717995, 14.617913238490804, 13.635489042197735, 12.637343928076948, 11.703275740744338, 10.752137976188099, 9.79318134395458, 8.759114172715364, 7.7726651745541835, 7.877307972627802, 6.95558881599046, 7.841536130772961, 8.753986821103176, 9.685848813016202, 10.704649375624733, 11.636280468753714, 12.459554502440312, 13.431998353324031, 14.432400597944275, 15.375638546655777, 16.39777136070063, 15.576454175364626, 14.579507172904105, 13.638530434329597, 12.676212103192183, 11.74540407868831, 10.715510203003218, 9.730194663133457, 8.821476859282223, 8.843414620897082, 7.886808150341242, 8.826683701005852, 9.77370422563132, 10.667207996865363, 11.662443149960346, 12.606731348290715, 13.521987483071088, 14.494044552441366, 15.424465984663296, 16.391487445852544, 17.354220186221486, 16.507935938494178, 15.575837828178464, 14.6047134546614, 13.629077805855303, 12.700585986223533, 11.706023833004258, 10.657439970894323, 9.793411929451757, 9.856272525502423, 8.865790402257561, 9.847147691741744, 10.77772514970144, 11.730800578906242, 12.589575347137412, 13.580298842799401, 14.518052068861325, 15.546979977421987, 16.46041622371337, 17.406232154586107, 17.46779976947597, 16.522789646423387, 15.632258765572345, 14.626429317537525, 13.72810299758179, 12.839744819559124, 11.89889249011573, 11.105096099172501, 10.74864485317961, 10.867499423395637, 9.933088624119662, 10.85728515627217, 11.778695555132455, 12.692297903226862, 13.531891248399587, 14.515218662945516, 15.48865170164026, 16.43040710712576, 17.47581259530097, 17.59385380287728, 16.569107850266736, 15.594814827476934, 14.66539599100519, 13.684134123684391, 12.759560640728179, 11.943855380884868, 10.88690560650467, 10.03867150165516, 10.844733067454126], [10.85325788859658, 10.039407778650284, 9.081968805762742, 10.072843947235324, 10.773979346415887, 11.712386462063794, 12.687828205031819, 13.702712309759448, 14.642369446958549, 15.666795724704153, 16.63921254222295, 16.499540680925566, 15.470132126015635, 14.575967292983675, 13.627658553765325, 12.856979179159804, 11.983680332002539, 10.986933557054588, 11.787511357309592, 11.86343552055662, 9.834352110950004, 8.98410343266026, 8.091455927458739, 9.03999314866243, 9.743949917236728, 10.733184543746539, 11.73770150141163, 12.729697315205277, 13.729334294029954, 14.742749001030433, 15.696144689460311, 16.45481238236987, 16.50720625012604, 15.507492812784546, 14.55478654933598, 13.862859983708441, 12.909128009491843, 12.017258393518867, 11.545342100132997, 10.874111321755121, 8.790629457916278, 7.9502519794223705, 7.112081466128076, 8.07824718629173, 8.816296650593303, 9.763230489804503, 10.734971402076111, 11.756859911503055, 12.712897102323849, 13.720151822854843, 14.700200913756447, 15.455027072430012, 16.35060627660662, 15.354631442168923, 14.380332668907162, 13.441699633381038, 12.491840900176292, 11.635146918538254, 10.61994394904983, 9.836078811499855, 7.772281412918993, 6.939162040301167, 6.128237544817996, 7.056846564322647, 7.754459384190419, 8.779901343113126, 9.728382120565698, 10.71949065496792, 11.696978648532555, 12.67370403936702, 13.641142101003073, 14.466662206609364, 15.43056548770549, 14.56580625119872, 13.535355945082644, 12.491325616113766, 11.562806989673634, 10.627688913866924, 9.634109760705385, 8.794911126865147, 6.846705761495379, 6.0001481183235175, 5.072255905273062, 6.101311734413185, 6.7721974624300785, 7.838005632345282, 8.839065603637657, 9.725226495107337, 10.704852538408183, 11.649097011522151, 12.58592637367102, 13.527292506196813, 14.561910642213164, 13.645430311441569, 12.625094953670768, 11.597229385054291, 10.635519962846555, 9.706656613069352, 8.688246978842466, 7.838493172017903, 5.838603668099356, 4.959181004079097, 4.126255804293148, 5.051642721936988, 5.829634625809701, 6.857214412984988, 7.7943898667760525, 8.762919627972874, 9.772899180772997, 10.667814589430114, 11.613961481085587, 12.566362882343231, 13.556881853881393, 12.677043708578417, 11.699233338653286, 10.719995815955482, 9.792662815070491, 8.765200494724855, 7.740564951384904, 6.777821671964336, 4.894572925304308, 3.9603456679931246, 3.0524357233805466, 4.045730606868585, 4.85886288815881, 5.909652895832278, 6.839098012448628, 7.827282184444586, 8.788706392051981, 9.726060681508152, 10.65284292670441, 11.58195054977546, 12.564118390947025, 11.838352040526434, 10.808578086821175, 9.854398939564458, 8.830409170435432, 7.78933855732496, 6.780946263768569, 5.848391342201495, 3.883341552019716, 2.9780629940727232, 2.0701246462291096, 3.0146536612871024, 3.833507039279414, 4.883502068895282, 5.862806565557749, 6.845900200511422, 7.825786627166661, 8.784586644897495, 9.691537221730291, 10.732806080682204, 11.63024013217894, 10.838141046018459, 9.787895324254619, 8.816898159346477, 7.887311559245839, 6.948356234893817, 5.897302019736635, 4.91130511232695, 2.913922411382842, 1.9574661996248253, 1.0329749659852947, 1.9610125571633197, 2.9027464107803818, 3.8935323109012936, 4.829813408131933, 5.841852178503832, 6.806422814523337, 7.746372144847415, 8.67949403001852, 9.731196145883995, 10.666353870943198, 10.006170918510525, 9.039432322682947, 8.051755096223824, 7.137085704642078, 6.0635106663081055, 4.996693049490893, 3.9632859483443514, 1.9758427086226167, 0.9707036333604252, 0.0, 0.9811250764991941, 1.9390139590930704, 2.949893846607295, 3.923037777831402, 4.865172571435819, 5.908650459443033, 6.839305394862515, 7.81651293377132, 8.741686392508363, 9.680646627587231, 9.072450421696209, 8.085463829463281, 7.089637391759417, 6.150253956457505, 5.075995328107986, 4.051302161265253, 3.036534413254816, 2.960758045203152, 1.9260855113795448, 0.9819658452966193, 2.0088699312204676, 2.8727566063854826, 3.846384476021606, 4.914844507737324, 5.906387308424886, 6.837614256720132, 7.800013756613886, 8.791902734830606, 9.770728906250573, 10.704667212117393, 9.858595433594644, 8.792883871152839, 7.842075324457733, 6.857761923735212, 5.84613984760816, 4.881194999754172, 3.9031428461909305, 3.8004601829664963, 2.872507071020854, 1.962309716140886, 2.9865039056590206, 3.9123262696335694, 4.802418151569551, 5.735081286100624, 6.680527073872529, 7.711627843211055, 8.63674917346306, 9.616618551331584, 10.621367861577005, 11.692362437434332, 10.710040650267127, 9.675096790887354, 8.725904525502704, 7.684550067481282, 6.757736238967939, 5.783482926542913, 4.756065561359412, 4.794117163534846, 3.8420706539432063, 3.0210353997114865, 4.019810799137197, 4.929747897474481, 5.8614320711449155, 6.682343252923044, 7.709493695710904, 8.67851041175419, 9.639097061265518, 10.607123699493805, 11.532650029633434, 12.519727361157942, 11.773113363970296, 10.702682350212042, 9.659279403899314, 8.706680129316009, 7.763338974198041, 6.728514235600508, 5.758944880352941, 5.793459626649803, 4.782338223517056, 4.061710868802534, 5.009020612795279, 5.882567459564834, 6.807473943287732, 7.64726679024202, 8.58494118634035, 9.637115615571762, 10.570221519889564, 11.597675646056436, 12.513224489010774, 13.455913087113565, 12.662558785202757, 11.638625231105607, 10.666917876106828, 9.736426007836604, 8.747738630752025, 7.707194012009291, 6.7709360761465165, 6.734614964045347, 5.793089583199787, 5.064665192272605, 6.005317443026243, 6.85339347363998, 7.849439731563747, 8.686802179145294, 9.565341708494792, 10.520631599593404, 11.489309422386828, 12.447954421457986, 13.499561013663653, 14.480006490388126, 13.529590775603, 12.602791327950744, 11.592825829219217, 10.6772413364274, 9.662700609980744, 8.71879483069162, 7.681634176918048, 7.79385959638853, 6.827312104442461, 6.059316358704953, 6.936187758239068, 7.879321848173278, 8.781466101283334, 9.660866099212203, 10.52550425310321, 11.580676415001372, 12.494465227134905, 13.451370278008673, 14.483134422357569, 15.417304342918655, 14.552375336011556, 13.55423022189077, 12.62016203455816, 11.66902427000192, 10.7100676377684, 9.676000466529183, 8.689551468368004, 8.794194266441623, 7.872475109804281, 7.017212726582087, 7.908853661146195, 8.84071565305922, 9.856269738847095, 10.665576835393288, 11.488850869079887, 12.461294719963606, 13.46169696458385, 14.404934913295351, 15.427067727340205, 16.37584527979248, 15.496393466717926, 14.555416728143419, 13.593098397006004, 12.66229037250213, 11.632396496817037, 10.647080956947276, 9.738363153096042, 9.760300914710903, 8.803694444155063, 8.002360296814977, 8.949380821440446, 9.822074836908381, 10.817309990003364, 11.739433386929068, 12.551283849710662, 13.52334091908094, 14.45376235130287, 15.42078381249212, 16.38351655286106, 16.58260117116301, 15.624159148946655, 14.65303477542959, 13.730554366772274, 13.050307222134759, 12.157312679453048, 11.574326264708143, 10.710298223265578, 10.773158819316244, 9.782676696071382, 9.02282428755087, 9.953401745510567, 10.88566741894926, 11.74444218718043, 12.713000881437754, 13.547348435500899, 14.576276344061561, 15.489712590352946, 16.435528521225685, 16.514781022160516, 15.569770899107935, 14.679240018256895, 13.673410570222075, 12.775084250266339, 12.028285356698573, 11.087433027255178, 12.031999943589538, 11.66553114699343, 11.784385717209458, 10.849974917933483, 10.032961752081295, 10.95437215094158, 11.847164743269882, 12.686758088442605, 13.64792070158387, 14.517948068279834, 15.459703473765334, 16.505108961940543, 16.64083505556183, 15.616089102951287, 14.641796080161484, 13.712377243689739, 12.73111537636894, 11.806541893412728, 11.132395918024317, 10.075446143644118, 11.009375135015585, 11.81543670081455], [11.834382965095774, 10.951963546465711, 9.9726265330285, 9.323438832912192, 9.79285426991669, 10.731261385564597, 11.706703128532624, 12.721587233260255, 13.661244370459356, 14.68567064820496, 15.658087465723753, 15.518415604426373, 14.489007049516442, 13.594842216484478, 12.64653347726613, 11.875854102660607, 11.035970512662866, 11.921237724306991, 12.768636433808789, 12.844560597055814, 10.815477187449197, 9.928033691905556, 8.982113654724497, 8.281637431932646, 8.762824840737531, 9.752059467247342, 10.756576424912435, 11.748572238706082, 12.748209217530757, 13.761623924531236, 14.715019612961115, 15.47368730587068, 15.526081173626844, 14.526367736285351, 13.573661472836784, 12.881734907209244, 11.96141819015217, 12.889740034816347, 12.526467176632192, 11.855236398254315, 9.771754534415471, 8.894182238667666, 8.002739193393833, 7.2918503535881545, 7.835171574094107, 8.782105413305308, 9.753846325576916, 10.77573483500386, 11.731772025824652, 12.739026746355647, 13.719075837257256, 14.47390199593082, 15.408963301134307, 15.496252825691375, 14.521954052429614, 13.864227436491737, 13.034352456671954, 12.61627199503745, 11.601069025549025, 10.817203887999048, 8.753406489418186, 7.883092299546463, 7.0188952720837525, 6.22729598648243, 6.773334307691224, 7.798776266613931, 8.747257044066503, 9.738365578468725, 10.715853572033359, 11.692578962867824, 12.660017024503881, 13.485537130110172, 14.449440411206298, 15.411988851562048, 14.51648102158184, 13.472450692612961, 12.543932066172829, 11.60881399036612, 10.61523483720458, 9.77603620336434, 7.827830837994572, 6.944078377568813, 5.962913632538818, 5.162777550784856, 5.7910723859308835, 6.856880555846087, 7.857940527138462, 8.74410141860814, 9.723727461908986, 10.667971935022955, 11.604801297171829, 12.546167429697622, 13.58078556571397, 14.522855240965503, 13.606220030169963, 12.578354461553488, 11.616645039345752, 10.68778168956855, 9.669372055341661, 8.819618248517097, 6.8197287445985495, 5.9031112633243925, 5.016913531558904, 4.107730812793786, 4.848509549310506, 5.876089336485793, 6.8132647902768575, 7.781794551473678, 8.7917741042738, 9.686689512930922, 10.632836404586396, 11.58523780584404, 12.575756777382201, 13.504715725717325, 12.680358415152481, 11.701120892454677, 10.773787891569686, 9.74632557122405, 8.7216900278841, 7.758946748463531, 5.875698001803501, 4.9042759272384195, 3.943093450646302, 3.0803131517782907, 3.8777378116596157, 4.928527819333084, 5.857972935949434, 6.846157107945393, 7.807581315552788, 8.74493560500896, 9.671717850205217, 10.600825473276267, 11.582993314447831, 12.611604448012939, 11.789703163320372, 10.835524016063655, 9.811534246934627, 8.770463633824155, 7.762071340267764, 6.82951641870069, 4.86446662851891, 3.937930170858385, 2.960782373494865, 2.0492362061968077, 2.85238196278022, 3.902376992396088, 4.881681489058555, 5.864775124012228, 6.8446615506674675, 7.803461568398302, 8.710412145231098, 9.75168100418301, 10.649115055679745, 11.607918740898443, 10.769020400753814, 9.798023235845672, 8.868436635745034, 7.929481311393012, 6.87842709623583, 5.892430188826145, 3.895047487882036, 2.917333376410487, 1.92363269325105, 0.995595102073025, 1.9216213342811876, 2.9124072344020995, 3.848688331632739, 4.860727102004638, 5.825297738024144, 6.765247068348222, 7.698368953519327, 8.750071069384802, 9.685228794444003, 10.579850588232885, 10.020557399182142, 9.032880172723019, 8.118210781141272, 7.0446357428073, 5.977818125990087, 4.9444110248435456, 2.956967785121811, 1.9518287098596194, 0.9811250764991941, 0.0, 0.9578888825938763, 1.9687687701081007, 2.9419127013322077, 3.884047494936625, 4.927525382943839, 5.8581803183633205, 6.835387857272126, 7.760561316009169, 8.699521551088036, 9.646130091418568, 9.066588905962474, 8.07076246825861, 7.131379032956699, 6.057120404607179, 5.032427237764447, 4.01765948975401, 3.941883121702346, 2.9072105878787387, 1.9630909217958135, 1.0277448547212737, 1.8916315298862885, 2.865259399522412, 3.9337194312381296, 4.925262231925692, 5.856489180220938, 6.818888680114692, 7.8107776583314115, 8.78960382975138, 9.7235421356182, 10.717787415485612, 9.774008947652034, 8.823200400956928, 7.838887000234406, 6.827264924107354, 5.862320076253366, 4.884267922690125, 4.7815852594656905, 3.853632147520048, 2.94343479264008, 2.0053788291598265, 2.9312011931343753, 3.8212930750703564, 4.753956209601429, 5.699401997373334, 6.73050276671186, 7.655624096963866, 8.635493474832389, 9.64024278507781, 10.711237360935137, 11.691165726766322, 10.656221867386549, 9.7070296020019, 8.665675143980476, 7.738861315467133, 6.764608003042107, 5.737190637858606, 5.77524224003404, 4.823195730442401, 4.002160476210681, 3.0386857226380024, 3.948622820975287, 4.880306994645721, 5.701218176423849, 6.728368619211709, 7.697385335254994, 8.657971984766323, 9.625998622994608, 10.551524953134237, 11.538602284658745, 12.581344407924043, 11.683807426711237, 10.640404480398509, 9.687805205815204, 8.744464050697236, 7.709639312099702, 6.740069956852135, 6.774584703148997, 5.763463300016251, 4.996015036054937, 4.027895536296084, 4.90144238306564, 5.826348866788538, 6.666141713742825, 7.603816109841156, 8.655990539072567, 9.589096443390371, 10.616550569557242, 11.532099412511577, 12.474788010614368, 13.4895729313206, 12.619750307604802, 11.648042952606023, 10.717551084335797, 9.728863707251218, 8.688319088508484, 7.752061152645711, 7.715740040544542, 6.774214659698982, 5.998969359525008, 5.024192366527048, 5.872268397140786, 6.868314655064553, 7.705677102646099, 8.584216631995599, 9.53950652309421, 10.508184345887635, 11.466829344958793, 12.51843593716446, 13.49888141388893, 14.510715852102194, 13.583916404449939, 12.573950905718412, 11.658366412926595, 10.64382568647994, 9.699919907190814, 8.662759253417244, 8.774984672887726, 7.808437180941656, 6.993620525957356, 5.955062681739873, 6.898196771674083, 7.8003410247841405, 8.679741022713007, 9.544379176604016, 10.59955133850218, 11.513340150635711, 12.47024520150948, 13.502009345858376, 14.436179266419458, 15.476008019221627, 14.535355298389964, 13.601287111057353, 12.650149346501115, 11.691192714267595, 10.65712554302838, 9.6706765448672, 9.775319342940819, 8.853600186303476, 7.95151689383449, 6.927728584647, 7.859590576560026, 8.875144662347902, 9.684451758894092, 10.507725792580693, 11.480169643464412, 12.480571888084656, 13.423809836796158, 14.445942650841012, 15.39472020329328, 15.651184312189082, 14.664613324073612, 13.702294992936197, 13.43481357300591, 12.613521573316234, 11.628206033446473, 10.719488229595239, 10.741425991210098, 9.784819520654258, 8.93666446406738, 8.001671002100773, 8.840949760409186, 9.83618491350417, 10.758308310429872, 11.57015877321147, 12.542215842581747, 13.472637274803677, 14.439658735992927, 15.402391476361869, 15.601476094663814, 14.643034072447458, 13.671909698930394, 12.749429290273078, 12.479631665470686, 13.047970406718806, 12.55545134120734, 11.691423299764773, 11.75428389581544, 10.763801772570577, 9.957128454803273, 9.005691926170893, 9.904542342450066, 10.763317110681236, 11.731875804938557, 12.566223359001706, 13.595151267562368, 14.508587513853753, 15.45440344472649, 15.533655945661321, 14.58864582260874, 13.698114941757698, 12.692285493722878, 11.793959173767142, 11.4576098000345, 11.978090754520936, 12.922657670855296, 12.646656223492625, 12.765510793708655, 11.83109999443268, 10.967265919333698, 10.006662331601907, 10.866039666770686, 11.70563301194341, 12.666795625084672, 13.53682299178064, 14.47857839726614, 15.523983885441348, 15.659709979062637, 14.634964026452092, 13.660671003662289, 12.731252167190544, 11.749990299869744, 10.825416816913531, 10.382990803701185, 10.966103870909876, 11.921930902831011, 12.796561777313743], [12.675357485806263, 11.716382230533332, 10.73704521709612, 9.863200026953862, 8.834965387322814, 9.77337250297072, 10.748814245938748, 11.763698350666377, 12.703355487865478, 13.727781765611082, 14.700198583129875, 14.560526721832495, 13.531118166922564, 12.636953333890604, 11.700818683125268, 10.960318857116157, 11.851519156667761, 12.748813430970749, 13.69303003003948, 13.685535117766303, 11.708795262146662, 10.757768922527934, 9.746532338792116, 8.864786351921488, 7.8049359581436555, 8.794170584653465, 9.798687542318559, 10.790683356112206, 11.790320334936881, 12.803735041937358, 13.757130730367237, 14.515798423276802, 14.568192291032966, 13.58065294214449, 12.627946678695922, 11.966199661664794, 12.776966834157065, 13.705288678821242, 13.484356059226068, 12.748554472951778, 10.665072609112935, 9.723917469290043, 8.767157877461452, 7.876123124307561, 6.877282691500231, 7.824216530711431, 8.79595744298304, 9.817845952409984, 10.773883143230776, 11.78113786376177, 12.761186954663378, 13.516013113336943, 14.45107441854043, 14.550538031550513, 13.576239258288751, 12.948692190947286, 13.849901100676849, 13.574160877631325, 12.5589579081429, 11.710521962696511, 9.698773507706463, 8.763250158396975, 7.783313956151373, 6.854704936646723, 5.815445425097348, 6.840887384020055, 7.789368161472627, 8.78047669587485, 9.757964689439483, 10.734690080273946, 11.702128141910004, 12.527648247516295, 13.49155152861242, 14.45409996896817, 14.596145214230345, 13.959768459533665, 13.501820948766705, 12.566702872959995, 11.573123719798456, 10.721403221652617, 8.773197856282849, 7.824236236419324, 6.795931180389682, 5.842685949593104, 4.833183503337008, 5.898991673252211, 6.900051644544586, 7.786212536014266, 8.76583857931511, 9.710083052429079, 10.646912414577951, 11.588278547103744, 12.622896683120093, 13.564966358371626, 14.45049882806606, 13.536243344147362, 12.574533921939626, 11.645670572162423, 10.627260937935537, 9.777507131110973, 7.777617627192427, 6.799168975844793, 5.849931079409768, 4.924544161765929, 3.8906206667166305, 4.9182004538919175, 5.855375907682982, 6.823905668879802, 7.833885221679925, 8.728800630337044, 9.674947521992518, 10.627348923250162, 11.617867894788324, 12.546826843123448, 13.524637213048578, 12.659009775048553, 11.731676774163562, 10.704214453817926, 9.679578910477975, 8.716835631057407, 6.833586884397379, 5.819420611878413, 4.858238135286295, 3.897126500750433, 2.9198489290657395, 3.970638936739207, 4.900084053355558, 5.888268225351515, 6.849692432958911, 7.7870467224150826, 8.71382896761134, 9.642936590682389, 10.625104431853954, 11.653715565419061, 12.650505147745415, 11.793412898657529, 10.769423129528503, 9.728352516418031, 8.719960222861639, 7.787405301294566, 5.822355511112787, 4.853331837966641, 3.8759270581348586, 2.86604955516895, 1.8944930801863433, 2.9444881098022115, 3.9237926064646786, 4.90688624141835, 5.88677266807359, 6.845572685804425, 7.752523262637221, 8.793792121589133, 9.691226173085868, 10.650029858304565, 11.577146679630308, 10.755912118439548, 9.82632551833891, 8.887370193986888, 7.836315978829706, 6.850319071420021, 4.852936370475913, 3.832735043518743, 2.839034360359306, 1.910996769181281, 0.9637324516873113, 1.9545183518082234, 2.890799449038863, 3.902838219410761, 4.867408855430266, 5.807358185754344, 6.740480070925449, 7.7921821867909244, 8.727339911850125, 9.621961705639007, 10.651272874545983, 9.990769055316894, 9.07609966373515, 8.002524625401177, 6.935707008583964, 5.902299907437422, 3.914856667715687, 2.9097175924534957, 1.9390139590930704, 0.9578888825938763, 0.0, 1.0108798875142244, 1.9840238187383312, 2.926158612342748, 3.969636500349962, 4.900291435769444, 5.877498974678249, 6.802672433415292, 7.74163266849416, 8.68824120882469, 9.675227801057618, 9.028651350852487, 8.089267915550575, 7.015009287201057, 5.990316120358323, 4.975548372347887, 4.8997720042962225, 3.8650994704726154, 2.92097980438969, 1.9344106862072854, 0.9337426472924122, 1.9073705169285358, 2.9758305486442533, 3.9673733493318157, 4.898600297627061, 5.860999797520815, 6.852888775737535, 7.8317149471575025, 8.765653253024322, 9.759898532891734, 10.632461030347756, 9.781089283550806, 8.796775882828284, 7.7851538067012305, 6.8202089588472425, 5.842156805284001, 5.739474142059567, 4.811521030113925, 3.9013236752339564, 2.9120446606458383, 1.973312310540499, 2.86340419247648, 3.796067327007553, 4.741513114779458, 5.772613884117984, 6.69773521436999, 7.677604592238512, 8.682353902483932, 9.753348478341259, 10.758958233714523, 11.593122462154493, 10.664918484595777, 9.623564026574353, 8.696750198061011, 7.722496885635984, 6.695079520452483, 6.733131122627917, 5.781084613036278, 4.960049358804557, 3.9453515541240143, 2.9907339383814113, 3.9224181120518447, 4.743329293829972, 5.770479736617832, 6.739496452661117, 7.7000831021724485, 8.668109740400734, 9.593636070540363, 10.580713402064871, 11.623455525330169, 12.624267949179742, 11.598293362992386, 10.645694088409082, 9.702352933291113, 8.667528194693578, 7.697958839446012, 7.7324735857428735, 6.7213521826101275, 5.902680867540949, 4.934561367782096, 3.943553500471764, 4.868459984194661, 5.708252831148949, 6.645927227247279, 7.69810165647869, 8.631207560796495, 9.658661686963367, 10.574210529917703, 11.516899128020494, 12.531684048726726, 13.555617602823876, 12.6059318351999, 11.675439966929673, 10.686752589845094, 9.64620797110236, 8.709950035239586, 8.67362892313842, 7.73210354229286, 6.8359358397708725, 5.8397410105319425, 4.91437951454691, 5.910425772470677, 6.747788220052223, 7.626327749401721, 8.581617640500333, 9.550295463293757, 10.508940462364915, 11.560547054570582, 12.540992531295055, 13.555704532325862, 14.482503979978118, 13.53183978831229, 12.616255295520473, 11.601714569073817, 10.657808789784692, 9.620648136011122, 9.732873555481603, 8.766326063535534, 7.830587006203221, 6.770611325744768, 5.9403078890802075, 6.842452142190265, 7.721852140119131, 8.586490294010138, 9.641662455908302, 10.555451268041834, 11.512356318915602, 12.544120463264498, 13.478290383825584, 14.518119136627753, 14.709915620131572, 13.717342472790166, 13.608038229094992, 12.649081596861473, 11.615014425622258, 10.628565427461078, 10.733208225534696, 9.811489068897354, 8.788483374080355, 7.743277228651895, 6.9440553310155755, 7.917255779754026, 8.726562876300218, 9.549836909986816, 10.522280760870535, 11.522683005490778, 12.46592095420228, 13.488053768247134, 14.436831320699406, 14.693295429595205, 13.706724441479736, 12.744406110342322, 13.697884676254874, 13.571410455910112, 12.58609491604035, 11.677377112189117, 11.699314873803976, 10.742708403248136, 9.764240170731137, 8.817219646105668, 7.925414514864736, 8.890470119363307, 9.800419427835998, 10.612269890617592, 11.58432695998787, 12.5147483922098, 13.481769853399049, 14.444502593767991, 14.643587212069939, 13.68514518985358, 12.714020816336516, 11.791540407679202, 12.742702768719651, 13.798405879782644, 13.513340223801217, 12.649312182358651, 12.712172778409318, 11.721690655164455, 10.78470416146703, 9.821240570175789, 8.989007096905615, 9.817602316540373, 10.773986922344683, 11.608334476407828, 12.63726238496849, 13.550698631259875, 14.496514562132612, 14.575767063067445, 13.630756940014864, 12.74022605916382, 11.734396611129, 10.836070291173266, 11.855297275147295, 12.742509438588558, 13.687076354922917, 13.604545106086503, 13.723399676302533, 12.755493590663372, 11.794841625997456, 10.822210975606803, 9.950504421226235, 10.759918217802548, 11.708906742490798, 12.578934109186763, 13.520689514672263, 14.56609500284747, 14.70182109646876, 13.677075143858216, 12.702782121068413, 11.773363284596668, 10.792101417275866, 9.867527934319655, 10.856793273405895, 11.730522554977497, 12.686349586898633, 13.637536298024232], [13.659808030907765, 12.700832775634835, 11.721495762197623, 10.847650572055366, 9.819415932424318, 9.091327856201739, 9.977701188963742, 10.992585293691373, 11.871298741036393, 12.86597523883161, 13.714220613376238, 13.716920185812828, 12.687511630902897, 11.793346797870935, 10.867997978258408, 11.856475598379305, 12.813861077352897, 13.75969331848497, 14.703909917553702, 14.669985662867806, 12.693245807248164, 11.742219467629436, 10.73098288389362, 9.849236897022992, 8.78938650324516, 8.112125937884484, 9.027574485343553, 10.0195702991372, 10.815752934643303, 11.829167641643782, 12.7711527606136, 13.50491853576258, 13.7245857550133, 12.74783223727763, 11.795125973829062, 12.862356402927942, 13.7393087548422, 14.667630599506378, 14.479937436160123, 13.73300501805328, 11.649523154214437, 10.708368014391546, 9.751608422562956, 8.860573669409066, 7.861733236601736, 7.072526208984937, 8.024844386008034, 8.98138165759976, 9.799315742937198, 10.806570463468193, 11.750307067149155, 12.50513322582272, 13.440194531026206, 13.717717326683653, 12.743418553421892, 13.682051588948015, 14.63191032215276, 14.56974225456538, 13.554539285076956, 12.694972507798013, 10.683224052807967, 9.747700703498477, 8.767764501252877, 7.839155481748227, 6.799895970198852, 6.089197062293561, 7.018255104497621, 7.914313497610205, 8.783397289145904, 9.76012267998037, 10.69124825439578, 11.516768360002072, 12.480671641098198, 13.443220081453948, 13.763324509363486, 14.693127857534394, 14.49740232570076, 13.56228424989405, 12.568705096732511, 11.705853766754121, 9.757648401384353, 8.808686781520828, 7.7803817254911865, 6.827136494694608, 5.817634048438512, 5.033238369129559, 5.964285033437868, 6.850445924907548, 7.791271179021532, 8.7355156521355, 9.636032527063728, 10.577398659589521, 11.612016795605872, 12.554086470857403, 13.439618940551837, 14.46188131700057, 13.57011529887368, 12.641251949096478, 11.622842314869592, 10.773088508045028, 8.762073948730785, 7.7836195209462975, 6.8343816245112725, 5.908994706867433, 4.875071211818135, 3.9824338427851997, 4.9196092965762634, 5.888139057773084, 6.859317821386346, 7.717920742822821, 8.664067634478295, 9.616469035735939, 10.6069880072741, 11.535946955609225, 12.513757325534355, 13.49299484823216, 12.742556661677787, 11.71509434133215, 10.67516028741203, 9.712417007991462, 7.818043205935736, 6.803871156979917, 5.842688680387799, 4.881577045851937, 3.904299474167243, 3.012120400706081, 3.922739900425503, 4.87738833783729, 5.838812545444686, 6.776166834900859, 7.702949080097116, 8.632056703168166, 9.61422454433973, 10.642835677904836, 11.63962526023119, 12.591323142079998, 11.780303017042728, 10.739232403932256, 9.730840110375864, 8.79828518880879, 6.833235398627011, 5.837782383068145, 4.860377603236363, 3.8505001002704544, 2.8789436252878473, 1.9859695737690852, 2.946448453534624, 3.8960063539041263, 4.875892780559365, 5.834692798290201, 6.741643375122997, 7.78291223407491, 8.680346285571645, 9.63914997079034, 10.566266792116084, 11.537263957024225, 10.837205405853135, 9.898250081501113, 8.847195866343931, 7.861198958934246, 5.863816257990137, 4.817185588620247, 3.82348490546081, 2.895447314282785, 1.9481829967888151, 0.943638464293999, 1.8799195615246385, 2.8919583318965367, 3.856528967916042, 4.79647829824012, 5.729600183411225, 6.7813022992767, 7.716460024335901, 8.611081818124783, 9.640392987031758, 10.622292055711664, 10.086979551249373, 9.0134045129154, 7.946586896098188, 6.913179794951646, 4.9257365552299115, 3.92059747996772, 2.949893846607295, 1.9687687701081007, 1.0108798875142244, 0.0, 0.9731439312241068, 1.9152787248285237, 2.9587566128357374, 3.8894115482552194, 4.8666190871640245, 5.7917925459010675, 6.730752780979935, 7.677361321310467, 8.664347913543393, 9.660174351247257, 9.1001478030648, 8.02588917471528, 7.001196007872547, 5.986428259862111, 5.9106518918104465, 4.875979357986839, 3.931859691903914, 2.94529057372151, 1.9446225348066366, 1.0637639809088673, 2.021563130567107, 2.9670877772703736, 3.8877204101128364, 4.850119910006591, 5.84200888822331, 6.820835059643278, 7.754773365510097, 8.749018645377511, 9.62158114283353, 10.572389689528636, 9.807655770342507, 8.796033694215454, 7.8310888463614665, 6.853036692798225, 6.750354029573791, 5.822400917628149, 4.91220356274818, 3.9229245481600628, 2.9841921980547235, 2.0197976564568116, 2.9524607909878844, 3.8979065787597897, 4.8384844157428395, 5.7636057459948455, 6.743475123863368, 7.748224434108788, 8.819219009966114, 9.803324110990417, 10.582242574640269, 11.531434840024918, 10.634443914088576, 9.707630085575234, 8.733376773150207, 7.705959407966707, 7.744011010142141, 6.791964500550502, 5.970929246318781, 4.956231441638239, 4.001613825895635, 3.0788115760321766, 3.8997227578103035, 4.9268732005981635, 5.863681557054504, 6.765953633797304, 7.7339802720255895, 8.65950660216522, 9.646583933689728, 10.689326056955025, 11.613388061665518, 12.602515668569644, 11.656573975923305, 10.713232820805336, 9.678408082207802, 8.708838726960236, 8.743353473257098, 7.732232070124351, 6.913560755055173, 5.945441255296321, 4.954433387985988, 4.024853448174993, 4.864646295129281, 5.802320691227611, 6.850653267021672, 7.697078092421351, 8.724532218588223, 9.64008106154256, 10.58276965964535, 11.597554580351582, 12.549330942559083, 13.573595886618396, 12.686319854443898, 11.697632477359319, 10.657087858616585, 9.720829922753811, 9.684508810652643, 8.742983429807083, 7.846815727285096, 6.8506208980461665, 5.925259402061134, 5.077605067603817, 5.9041816840325545, 6.782721213382054, 7.738011104480665, 8.70668892727409, 9.665333926345248, 10.668049680629254, 11.606863062919912, 12.621575063950718, 13.51349703940422, 14.499503839730785, 13.627135183034696, 12.61259445658804, 11.668688677298915, 10.631528023525345, 10.743753442995827, 9.777205951049757, 8.841466893717444, 7.781491213258992, 6.951187776594432, 6.009631437323405, 6.878245604099463, 7.742883757990471, 8.798055919888633, 9.711844732022167, 10.668749782895935, 11.65162308932317, 12.54416091545044, 13.58398966825261, 14.086321413616291, 14.70179301789167, 14.618918116609215, 13.659961484375696, 12.625894313136481, 11.639445314975301, 11.74408811304892, 10.822368956411577, 9.799363261594578, 8.754157116166118, 7.9549352185298, 7.084435074887166, 7.882956340280549, 8.706230373967148, 9.678674224850868, 10.679076469471111, 11.622314418182613, 12.644447232227467, 13.502701852324263, 14.011250782826224, 13.071518638809204, 13.728856655443826, 14.682335221356379, 14.582290343424335, 13.596974803554573, 12.68825699970334, 12.7101947613182, 11.753588290762359, 10.77512005824536, 9.828099533619891, 8.93629440237896, 8.057649414496447, 8.956812891816329, 9.768663354597924, 10.740720423968202, 11.671141856190133, 12.638163317379382, 13.600896057748324, 13.872474155094933, 13.0031005430846, 12.031976169567535, 12.775990952780706, 13.727153313821155, 14.782856424884148, 14.52422011131544, 13.660192069872874, 13.72305266592354, 12.732570542678678, 11.795584048981253, 10.832120457690012, 9.95926633938331, 8.984781611673514, 9.930380386325014, 10.76472794038816, 11.793655848948823, 12.707092095240208, 13.652908026112945, 13.80465400609244, 12.859643883039858, 11.977666881746643, 11.05235196436002, 11.82052083627477, 12.8397478202488, 13.72695998369006, 14.67152690002442, 14.615424993600726, 14.734279563816754, 13.766373478177593, 12.805721513511678, 11.833090863121026, 10.92076366370393, 9.927097512935688, 10.86530020647113, 11.735327573167096, 12.677082978652596, 13.722488466827803, 13.930708039493755, 12.90596208688321, 11.931669064093407, 11.002250227621662, 10.110056770506885, 10.85197847942116, 11.8412438185074, 12.714973100079, 13.670800132000135, 14.621986843125734], [14.632951962131873, 13.673976706858943, 12.694639693421731, 11.820794503279474, 10.792559863648426, 10.046856519732989, 9.146330071644392, 10.145068608577377, 10.898154809812286, 11.892831307607501, 12.74107668215213, 12.774716161098455, 11.745307606188524, 10.85114277315656, 11.658852100051288, 12.647329720172184, 13.604715199145776, 14.629087796374051, 15.605109343162896, 15.643129594091914, 13.666389738472272, 12.715363398853544, 11.704126815117727, 10.8223808282471, 9.762530434469268, 9.067654601415734, 8.196203368024204, 9.095420652715386, 9.842609003419197, 10.856023710419674, 11.798008829389492, 12.531774604538471, 12.782381730298926, 11.813606363483933, 12.585980095621942, 13.653210524720821, 14.53016287663508, 15.458484721299257, 15.453081367384229, 14.706148949277388, 12.622667085438545, 11.681511945615654, 10.724752353787062, 9.833717600633173, 8.834877167825843, 8.028054872516186, 7.193473268688684, 8.036127769240645, 8.826171811713092, 9.833426532244086, 10.777163135925047, 11.531989294598612, 12.467050599802098, 12.869482285131818, 13.53427267521477, 14.472905710740894, 15.42276444394564, 15.542886185789486, 14.527683216301062, 13.668116439022121, 11.656367984032075, 10.720844634722585, 9.740908432476983, 8.812299412972333, 7.773039901422958, 7.044725725824811, 6.1868839871782715, 6.96905960925109, 7.810253357921798, 8.786978748756262, 9.718104323171673, 10.543624428777964, 11.50752770987409, 12.47007615022984, 13.44530425555731, 14.489334584526189, 15.41785321096632, 14.535428181118156, 13.541849027956617, 12.678997697978229, 10.73079233260846, 9.781830712744936, 8.753525656715293, 7.800280425918714, 6.790777979662618, 5.9887670326608085, 5.132913916118518, 5.905192036548431, 6.818127247797426, 7.762371720911394, 8.66288859583962, 9.604254728365413, 10.638872864381764, 11.580942539633295, 12.466475009327729, 13.488737385776462, 14.450446807984198, 13.614395880320586, 12.595986246093698, 11.746232439269134, 9.735217879954892, 8.756763452170405, 7.8075255557353795, 6.88213863809154, 5.848215143042241, 4.937962506316449, 4.088238179256914, 4.942885169413968, 5.88617389016224, 6.744776811598714, 7.690923703254187, 8.643325104511831, 9.633844076049993, 10.562803024385117, 11.540613394310247, 12.519850917008052, 13.447183917893042, 12.688238272556257, 11.648304218636136, 10.685560939215568, 8.791187137159843, 7.777015088204024, 6.815832611611906, 5.854720977076044, 4.87744340539135, 3.9676490642373303, 3.0260275030419734, 3.904244406613184, 4.86566861422058, 5.8030229036767516, 6.729805148873009, 7.658912771944059, 8.641080613115625, 9.66969174668073, 10.666481329007084, 11.618179210855892, 12.550280890669098, 11.712376335156362, 10.70398404159997, 9.771429120032897, 7.806379329851118, 6.810926314292252, 5.83352153446047, 4.8236440314945614, 3.8520875565119543, 2.959113504993192, 2.0497360561510947, 2.9228624226800193, 3.902748849335259, 4.861548867066094, 5.76849944389889, 6.809768302850803, 7.7072023543475385, 8.666006039566234, 9.593122860891977, 10.564120025800118, 11.493706625900757, 10.871394012725219, 9.820339797568037, 8.834342890158352, 6.836960189214244, 5.790329519844354, 4.796628836684917, 3.868591245506892, 2.921326928012922, 1.9167823955181058, 0.9832071641411093, 1.9188144006724301, 2.8833850366919354, 3.823334367016013, 4.756456252187118, 5.8081583680525934, 6.743316093111795, 7.637937886900676, 8.667249055807652, 9.649148124487558, 10.576865707183122, 9.986548444139506, 8.919730827322294, 7.886323726175753, 5.8988804864540185, 4.893741411191827, 3.923037777831402, 2.9419127013322077, 1.9840238187383312, 0.9731439312241068, 0.0, 0.942134793604417, 1.9856126816116308, 2.916267617031113, 3.8934751559399183, 4.818648614676961, 5.757608849755829, 6.70421739008636, 7.691203982319287, 8.68703042002315, 9.626413855325062, 8.999033105939388, 7.974339939096655, 6.9595721910862185, 6.8837958230345535, 5.849123289210946, 4.905003623128021, 3.9184345049456164, 2.917766466030743, 2.036907912132974, 1.0484191993430003, 1.993943846046267, 2.91457647888873, 3.8769759787824847, 4.868864956999204, 5.8476911284191715, 6.781629434285991, 7.775874714153405, 8.648437211609425, 9.59924575830453, 10.583559159027052, 9.76917762543956, 8.804232777585574, 7.826180624022332, 7.723497960797898, 6.795544848852256, 5.885347493972287, 4.896068479384169, 3.95733612927883, 2.9429199008045828, 2.01025676627351, 2.9557025540454154, 3.8653404845187325, 4.7904618147707385, 5.770331192639261, 6.7750805028846806, 7.846075078742007, 8.83018017976631, 9.609098643416162, 10.558290908800812, 11.522357918765449, 10.680774016799342, 9.706520704374315, 8.679103339190814, 8.717154941366248, 7.765108431774609, 6.944073177542888, 5.929375372862346, 4.950579238003659, 3.9408276826269546, 2.957518733095929, 3.9846691758837895, 4.8905376258303965, 5.792809702573197, 6.760836340801482, 7.6863626709411115, 8.67344000246562, 9.716182125730917, 10.640244130441411, 11.629371737345538, 12.544487980600177, 11.686376752029444, 10.651552013431909, 9.681982658184342, 9.716497404481204, 8.705376001348458, 7.8867046862792805, 6.918585186520428, 5.885756112586558, 4.8710939940145845, 3.922442270414906, 4.860116666513236, 5.877509335797565, 6.723934161197244, 7.751388287364115, 8.666937130318452, 9.609625728421243, 10.624410649127475, 11.576187011334977, 12.60045195539429, 13.584159462332957, 12.670776408583425, 11.63023178984069, 10.693973853977917, 10.65765274187675, 9.716127361031191, 8.778138451885665, 7.781943622646736, 6.856582126661704, 5.923845613443408, 4.96197765931818, 5.840517188667679, 6.79580707976629, 7.764484902559715, 8.722707338980673, 9.694905749405146, 10.633719131695804, 11.64843113272661, 12.540353108180113, 13.526359908506679, 14.540512619132338, 13.585738387812148, 12.641832608523023, 11.604671954749453, 11.716897374219934, 10.750349882273865, 9.772789618318013, 8.712813937859561, 7.882510501195002, 6.855871983162996, 5.936041579385088, 6.800679733276096, 7.855851895174259, 8.769640707307792, 9.72612319553136, 10.678479158099062, 11.571016984226333, 12.610845737028502, 13.491792002120139, 14.484365149461544, 15.463989462498711, 14.633105415599804, 13.599038244360589, 12.61258924619941, 12.717232044273027, 11.778312103549151, 10.730685986195148, 9.685479840766687, 8.88625794313037, 7.875289196680045, 6.940752315566174, 7.764026349252775, 8.736470200136495, 9.736872444756738, 10.679687830818038, 11.701820644862892, 12.529557921100155, 13.205672476477272, 14.027047302340454, 14.702000586667934, 15.655479152580487, 15.555434274648443, 14.570118734778681, 13.661400930927448, 13.683338692542307, 12.709531437899933, 11.70644278284593, 10.75942225822046, 9.84373868938431, 8.848503536289327, 8.014608867101954, 8.826459329883551, 9.798516399253828, 10.728937831475758, 11.695536730014807, 12.658269470383749, 13.041103037775583, 12.197522236735647, 12.987504833098786, 13.749134884004814, 14.700297245045263, 15.756000356108256, 15.497364042539548, 14.633336001096982, 14.696196597147647, 13.688513689816252, 12.726906773581822, 11.763443182290581, 10.75012046117619, 9.775635733466393, 8.98817636161064, 9.822523915673788, 10.851451824234449, 11.764888070525833, 12.71028143874837, 12.94728714529715, 12.028272765720509, 11.146295764427293, 12.00788062789127, 12.793664767498878, 13.812891751472907, 14.700103914914168, 15.644670831248527, 15.588568924824834, 15.679257889521963, 14.667572903786787, 13.706920939120872, 12.659912967600826, 11.71161778549681, 10.717951634728568, 9.923096181756755, 10.793123548452723, 11.734878953938223, 12.78028444211343, 12.962995452974804, 11.960303290563541, 11.100297946774058, 10.170879110302312, 11.065585434038136, 11.825122410645267, 12.814387749731507, 13.688117031303108, 14.643944063224243, 15.595130774349842], [15.57508675573629, 14.61611150046336, 13.636774487026148, 12.762929296883891, 11.734694657252843, 10.908342284646393, 9.917176797751763, 9.20293381497296, 9.95602001620787, 10.950696514003084, 11.798941888547713, 11.952278283178874, 10.922869728268942, 11.793277566760977, 12.600986893655705, 13.589464513776601, 14.546849992750193, 15.571222589978468, 16.547244136767315, 16.58526438769633, 14.60852453207669, 13.657498192457961, 12.646261608722144, 11.764515621851517, 10.704665228073685, 9.929140366329138, 8.967050094131574, 8.15328585911097, 8.90047420981478, 9.913888916815257, 10.855874035785074, 11.589639810934054, 11.959943852379345, 12.75574115708835, 13.528114889226359, 14.595345318325238, 15.472297670239497, 16.400619514903674, 16.395216160988646, 15.648283742881805, 13.564801879042962, 12.62364673922007, 11.66688714739148, 10.77585239423759, 9.77701196143026, 8.88954063742959, 7.964319994796054, 7.093992975636228, 7.884037018108675, 8.89129173863967, 9.83502834232063, 10.589854500994194, 11.524915806197681, 12.515677655842179, 13.48997642910394, 14.428609464630064, 15.37846819783481, 16.431163791429004, 15.46981800990548, 14.610251232626538, 12.598502777636492, 11.662979428327002, 10.6830432260814, 9.75443420657675, 8.715174695027375, 7.9062114907382135, 6.957730713285642, 6.026924815646673, 6.868118564317381, 7.844843955151846, 8.775969529567256, 9.601489635173547, 10.565392916269673, 11.527941356625423, 12.503169461952893, 13.547199790921772, 14.475718417361904, 15.410836493168613, 14.483983821561035, 13.621132491582646, 11.672927126212878, 10.723965506349353, 9.69566045031971, 8.742415219523131, 7.732912773267035, 6.930901826265224, 5.903760642225889, 4.963057242944014, 5.875992454193009, 6.8202369273069765, 7.720753802235203, 8.662119934760996, 9.696738070777347, 10.638807746028878, 11.524340215723312, 12.546602592172045, 13.508312014379781, 14.437175364156984, 13.538121039698115, 12.688367232873551, 10.677352673559309, 9.698898245774823, 8.749660349339797, 7.824273431695956, 6.790349936646658, 5.880097299920865, 4.969280137006371, 4.000750375809551, 4.944039096557823, 5.802642017994297, 6.74878890964977, 7.701190310907414, 8.691709282445576, 9.6206682307807, 10.59847860070583, 11.577716123403635, 12.505049124288625, 13.528434631161897, 12.590439012240553, 11.627695732819985, 9.73332193076426, 8.719149881808441, 7.7579674052163226, 6.796855770680461, 5.819578198995767, 4.909783857841747, 3.9681622966463905, 2.962109613008767, 3.923533820616162, 4.8608881100723345, 5.787670355268591, 6.716777978339641, 7.698945819511206, 8.727556953076313, 9.724346535402667, 10.676044417251475, 11.608146097064681, 12.552572693762002, 11.646118835204389, 10.713563913637316, 8.748514123455536, 7.753061107896669, 6.775656328064886, 5.765778825098978, 4.794222350116371, 3.901248298597609, 2.9918708497555118, 1.9807276290756026, 2.960614055730842, 3.9194140734616765, 4.826364650294472, 5.867633509246385, 6.765067560743121, 7.723871245961817, 8.65098806728756, 9.621985232195701, 10.55157183229634, 11.490527156648362, 10.762474591172456, 9.77647768376277, 7.779094982818661, 6.732464313448771, 5.738763630289334, 4.810726039111309, 3.8634617216173393, 2.858917189122523, 1.9253419577455264, 0.9766796070680132, 1.9412502430875183, 2.881199573411596, 3.8143214585827008, 4.866023574448176, 5.801181299507378, 6.695803093296259, 7.725114262203236, 8.707013330883141, 9.634730913578705, 10.708305951912678, 9.86186562092671, 8.82845851978017, 6.841015280058436, 5.835876204796244, 4.865172571435819, 3.8840474949366244, 2.926158612342748, 1.9152787248285237, 0.942134793604417, 0.0, 1.0434778880072137, 1.9741328234266957, 2.9513403623355012, 3.876513821072544, 4.8154740561514116, 5.762082596481943, 6.74906918871487, 7.744895626418734, 8.684279061720646, 9.758537690070167, 8.916474732701072, 7.901706984690636, 7.825930616638971, 6.7912580828153635, 5.847138416732438, 4.8605692985500335, 3.8599012596351603, 2.979042705737391, 1.9905539929474174, 1.05180905244185, 1.9724416852843127, 2.9348411851780676, 3.9267301633947866, 4.905556334814754, 5.839494640681574, 6.833739920548988, 7.7063024180050075, 8.657110964700113, 9.641424365422635, 10.653046441549687, 9.74636757118999, 8.768315417626749, 8.665632754402315, 7.737679642456673, 6.8274822875767045, 5.838203272988586, 4.899470922883247, 3.885054694409, 2.952391559877927, 2.0415167523853164, 2.9232056909143154, 3.8483270211663214, 4.8281963990348435, 5.8329457092802635, 6.9039402851375895, 7.888045386161894, 8.666963849811745, 9.616156115196395, 10.580223125161032, 11.507036953674374, 10.648655497978732, 9.62123813279523, 9.659289734970665, 8.707243225379026, 7.886207971147305, 6.871510166466763, 5.892714031608076, 4.882962476231372, 3.8996535267003463, 3.0839326260669173, 3.9484028322259794, 4.85067490896878, 5.818701547197065, 6.744227877336694, 7.731305208861203, 8.7740473321265, 9.698109336836994, 10.687236943741121, 11.60235318699576, 12.512639688904477, 11.593686807036326, 10.62411745178876, 10.658632198085622, 9.647510794952876, 8.828839479883698, 7.860719980124845, 6.827890906190975, 5.813228787619002, 4.864577064019323, 4.037678788593655, 4.935374542193148, 5.781799367592827, 6.809253493759698, 7.724802336714034, 8.667490934816826, 9.682275855523057, 10.63405221773056, 11.658317161789872, 12.64202466872854, 13.563536491156679, 12.572366583445108, 11.636108647582335, 11.599787535481168, 10.658262154635608, 9.720273245490082, 8.724078416251153, 7.798716920266121, 6.865980407047825, 5.904112452922597, 5.018079310748098, 5.973369201846709, 6.843915054934445, 7.7805725453762555, 8.752770955800727, 9.691584338091387, 10.706296339122193, 11.598218314575696, 12.584225114902262, 13.59837782552792, 14.525801756769146, 13.58396740212744, 12.54680674835387, 12.659032167824352, 11.692484675878282, 10.71492441192243, 9.654948731463978, 8.824645294799419, 7.798006776767413, 6.878176372989505, 5.978241855356515, 7.033414017254677, 7.849070859682523, 8.783988401926942, 9.736344364494645, 10.628882190621916, 11.668710943424085, 12.549657208515722, 13.542230355857127, 14.521854668894294, 15.480811301127813, 14.541173037965006, 13.554724039803826, 13.659366837877444, 12.720446897153568, 11.672820779799565, 10.627614634371104, 9.828392736734788, 8.817423990284462, 7.882887109170591, 6.941588471333193, 7.914032322216912, 8.848144595645673, 9.73755303721362, 10.759685851258475, 11.587423127495738, 12.599844034229147, 13.56445998332281, 14.515166718304972, 15.521153589308925, 16.497569068252858, 15.512253528383098, 14.603535724531865, 14.625473486146724, 13.65166623150435, 12.648577576450347, 11.701557051824878, 10.785873482988727, 9.790638329893744, 8.95674366070637, 8.00402145196397, 8.976078521334246, 9.906499953556176, 10.75340193641039, 11.716134676779332, 12.186385978992359, 12.968368962843018, 13.84899059801219, 14.691269677609231, 15.64243203864968, 16.698135149712673, 16.439498836143965, 15.575470794701399, 15.638331390752064, 14.63064848342067, 13.66904156718624, 12.705577975894998, 11.692255254780607, 10.71777052707081, 9.930311155215056, 9.000086037754206, 10.029013946314869, 10.942450192606252, 11.768146645143952, 12.005152351692733, 11.173555706937284, 11.917142490534664, 12.869366392804674, 13.735799561103295, 14.755026545077325, 15.642238708518585, 16.586805624852943, 16.53070371842925, 16.62139268312638, 15.609707697391205, 14.649055732725289, 13.602047761205244, 12.653752579101226, 11.660086428332985, 10.865230975361172, 9.970685670533141, 10.912441076018641, 11.957846564193849, 12.020860659370387, 11.018168496959124, 10.245580887990833, 10.941725836409683, 11.92707119895154, 12.767257204249685, 13.756522543335924, 14.630251824907525, 15.58607885682866, 16.53726556795426], [16.618564643743504, 15.659589388470573, 14.680252375033362, 13.806407184891105, 12.778172545260057, 11.922944576626229, 10.931779089731597, 10.023232709794563, 9.083575572595462, 10.031418376096077, 10.794157727868653, 11.195573365181213, 11.712878762464074, 12.652381174990365, 13.47260814481558, 14.461085764936476, 15.418471243910068, 16.442843841138345, 17.41886538792719, 17.628742275703544, 15.652002420083903, 14.700976080465175, 13.689739496729358, 12.807993509858731, 11.748143116080898, 10.943742658308974, 9.981652386111408, 9.079792391995781, 8.028029766202373, 8.99461077890825, 9.851089875106014, 10.584855650254994, 11.535347271194153, 12.551774443611423, 13.43348484801771, 14.406317833233496, 15.420147143946926, 16.348468988611103, 17.307895958995342, 16.69176163088902, 14.608279767050176, 13.667124627227285, 12.710365035398693, 11.819330282244804, 10.820489849437473, 9.904142929409426, 8.978922286775889, 8.027255563278647, 7.011592574496269, 7.972013600732661, 8.83024418164157, 9.585070340315134, 10.520131645518621, 11.510893495163119, 12.48519226842488, 13.423825303951004, 14.37368403715575, 15.426379630749945, 16.382497807912177, 15.653729120633752, 13.641980665643706, 12.706457316334216, 11.726521114088614, 10.797912094583964, 9.75865258303459, 8.92081378271805, 7.972333005265477, 6.981224470863255, 5.995674120704975, 6.9133378810878465, 7.771185368888195, 8.596705474494486, 9.560608755590613, 10.523157195946363, 11.498385301273833, 12.542415630242711, 13.470934256682844, 14.406052332489553, 15.39666361956773, 14.66461037958986, 12.716405014220092, 11.767443394356567, 10.739138338326924, 9.785893107530345, 8.776390661274249, 7.9743797142724375, 6.947238530233102, 6.006535130951228, 5.0035480105806025, 5.846799245243152, 6.715969641556143, 7.657335774081936, 8.691953910098285, 9.634023585349818, 10.519556055044252, 11.541818431492985, 12.50352785370072, 13.432391203477923, 14.450800837704811, 13.731845120880765, 11.720830561566522, 10.742376133782036, 9.79313823734701, 8.86775131970317, 7.833827824653872, 6.923575187928079, 6.012758025013585, 5.044228263816764, 4.071594652945417, 4.797857857315236, 5.74400474897071, 6.696406150228354, 7.686925121766515, 8.61588407010164, 9.59369444002677, 10.572931962724574, 11.500264963609565, 12.484956743154683, 13.537042525007571, 12.671173620827199, 10.776799818771474, 9.762627769815655, 8.801445293223537, 7.840333658687674, 6.863056087002981, 5.953261745848961, 5.011640184653604, 4.005587501015981, 3.051089377003756, 3.856103949393274, 4.782886194589532, 5.711993817660582, 6.694161658832146, 7.684079065069099, 8.680868647395455, 9.632566529244261, 10.564668209057468, 11.509094805754788, 12.51748709931118, 11.75704180164453, 9.79199201146275, 8.796538995903884, 7.8191342160721, 6.809256713106191, 5.837700238123585, 4.944726186604823, 4.0353487377627255, 3.024205517082816, 2.0881696121184357, 2.9146299127826163, 3.821580489615413, 4.844908519058957, 5.721589672735908, 6.680393357954603, 7.6075101792803475, 8.578507344188488, 9.508093944289126, 10.447049268641148, 11.49810348379833, 10.819955571769984, 8.822572870825875, 7.775942201455985, 6.782241518296548, 5.854203927118522, 4.906939609624553, 3.9023950771297367, 2.96881984575274, 2.020157495075227, 1.068805799475112, 1.876415412732536, 2.809537297903641, 3.822545686440962, 4.757703411500164, 5.652325205289046, 6.681636374196022, 7.663535442875928, 8.591253025571493, 9.664828063905466, 10.731645680722679, 9.871936407787384, 7.884493168065649, 6.8793540928034576, 5.908650459443033, 4.927525382943839, 3.9696365003499623, 2.958756612835738, 1.9856126816116308, 1.0434778880072137, 0.0, 0.930654935419482, 1.9078624743282873, 2.83303593306533, 3.771996168144198, 4.71860470847473, 5.705591300707656, 6.7014177384115206, 7.640801173713432, 8.715059802062951, 9.739752968905684, 8.94518487269785, 8.869408504646184, 7.834735970822577, 6.890616304739652, 5.904047186557247, 4.903379147642374, 3.95484608156433, 2.8863860498486122, 1.8948432491610496, 0.9289637972770989, 1.8913632971708538, 2.8832522753875724, 3.8620784468075406, 4.79601675267436, 5.790262032541774, 6.662824529997794, 7.613633076692898, 8.59794647741542, 9.609568553542472, 10.574513401396459, 9.811793305633962, 9.709110642409529, 8.781157530463886, 7.870960175583918, 6.8797953649624555, 5.8324076390887205, 4.762659871407495, 3.8299967368764216, 2.8845509491045163, 1.8797278029071016, 2.8048491331591077, 3.7847185110276302, 4.789467821273051, 5.860462397130377, 6.844567498154681, 7.623485961804531, 8.57267822718918, 9.536745237153816, 10.463559065667159, 11.437812378092186, 10.664716020802445, 10.702767622977879, 9.75072111338624, 8.907539998415137, 7.835627996764347, 6.770319208606571, 5.760567653229867, 4.777258703698841, 3.8739416602620502, 2.9049249442187657, 3.807197020961566, 4.775223659189852, 5.700749989329481, 6.687827320853989, 7.730569444119285, 8.65463144882978, 9.643759055733906, 10.558875298988545, 11.469161800897261, 12.424144788213864, 11.667595339795973, 11.702110086092835, 10.69098868296009, 9.746868755150249, 8.778749255391396, 7.70549608318947, 6.690833964617497, 5.742182241017818, 4.827687822788787, 3.8918966541859334, 4.738321479585613, 5.765775605752484, 6.68132444870682, 7.624013046809613, 8.638797967515845, 9.590574329723346, 10.614839273782659, 11.598546780721326, 12.520058603149463, 13.402824564622646, 12.679586535589548, 12.585865084353408, 11.644339703507848, 10.597878422488579, 9.60168359324965, 8.676322097264617, 7.74358558404632, 6.781717629921092, 5.808088344943229, 4.9560255536375575, 5.800437166927232, 6.737094657369042, 7.7092930677935145, 8.648106450084175, 9.66281845111498, 10.554740426568483, 11.540747226895048, 12.554899937520707, 13.482323868761931, 14.426229648051056, 13.53288429722611, 13.645109716696592, 12.645006235857776, 11.592529588920927, 10.532553908462475, 9.702250471797914, 8.675611953765907, 7.755781549988, 6.768250889551647, 6.016070369045526, 6.805592971675309, 7.7405105139197286, 8.692866476487431, 9.585404302614702, 10.62523305541687, 11.506179320508508, 12.498752467849913, 13.47837678088708, 14.4373334131206, 15.445329321915176, 14.540801588676066, 14.543872903249511, 13.598052074152065, 12.550425956798062, 11.505219811369601, 10.705997913733283, 9.689045241444337, 8.754508360330465, 7.731597505528325, 7.010461103955991, 7.804666707638459, 8.694075149206407, 9.71620796325126, 10.543945239488524, 11.556366146221933, 12.520982095315595, 13.471688830297758, 14.477675701301711, 15.456509178451055, 16.41640981233327, 15.56557112515938, 15.509979551518791, 14.529271408502847, 13.526182753448843, 12.579162228823375, 11.657494734148601, 10.662259581053618, 9.815847268935759, 8.794030486159102, 8.072507303073325, 8.870994573143383, 9.709924048403176, 10.672656788772118, 11.475427002618076, 12.436084237162111, 13.407208610679175, 14.382844259485273, 15.334006620525722, 16.389709731588717, 17.343655120094137, 16.459976860073468, 16.522837456124133, 15.508253660419166, 14.546646744184736, 13.583183152893495, 12.563876505940481, 11.589391778230684, 10.789414763444444, 9.790095071949338, 9.125442728053947, 9.906944812193458, 10.724668757136739, 11.132707908080324, 11.993854601758887, 12.931744782514498, 13.88396868478451, 14.77927744911051, 15.798504433084538, 16.685716596525797, 17.630283512860156, 17.41520978380132, 17.493013934286257, 16.48132894855108, 15.520676983885165, 14.47366901236512, 13.525373830261103, 12.53170767949286, 11.72433458359056, 10.760694704728273, 10.15573615802098, 10.979863469676392, 11.10158252146338, 10.145724053346717, 11.065879782812436, 11.956328128389517, 12.941673490931375, 13.810735092256898, 14.800000431343138, 15.673729712914739, 16.629556744835874, 17.580743455961475], [17.504964682971988, 16.54598942769906, 15.566652414261846, 14.626015989786524, 13.597781350155476, 12.646086657206281, 11.65492117031165, 10.746374790374617, 9.806717653175516, 9.100763440676594, 9.863502792449172, 10.716480503648576, 11.641766459885075, 12.583583098519314, 13.429957908168882, 14.418435528289779, 15.37582100726337, 16.400193604491648, 17.401119732100504, 18.42785732845061, 16.546742191989086, 15.595638598616805, 14.576139535957841, 13.62760231475415, 12.567751920976317, 11.666884738889026, 10.704794466691462, 9.802934472575835, 8.751171846782427, 8.063955843488769, 8.920434939686533, 9.654200714835513, 10.604692335774672, 11.621119508191942, 12.502829912598228, 13.475662897814015, 14.489492208527444, 15.417814053191622, 16.37724102357586, 17.422366270729107, 15.503019538955359, 14.561864399132467, 13.605104807303876, 12.638939087140223, 11.640098654332892, 10.627285009989478, 9.702064367355943, 8.750397643858701, 7.734734655076322, 7.04135866531318, 7.899589246222089, 8.654415404895653, 9.58947671009914, 10.580238559743638, 11.554537333005399, 12.493170368531523, 13.443029101736268, 14.495724695330464, 15.451842872492692, 16.403672202164525, 14.551060095463155, 13.615536746153666, 12.630694577923506, 11.702085558418856, 10.662826046869482, 9.643955863298102, 8.69547508584553, 7.704366551443308, 6.718816201285028, 5.9826829456683654, 6.840530433468714, 7.666050539075005, 8.629953820171131, 9.592502260526881, 10.56773036585435, 11.611760694823229, 12.54027932126336, 13.47539739707007, 14.466008684148248, 15.450852331425518, 13.625484444039541, 12.676522824176017, 11.648217768146374, 10.690066571365238, 9.680564125109141, 8.753024049766044, 7.7077265527419305, 6.767023153460056, 5.7266900911606555, 4.916144309823671, 5.785314706136662, 6.726680838662455, 7.761298974678804, 8.703368649930336, 9.588901119624769, 10.611163496073502, 11.572872918281238, 12.50173626805844, 13.520145902285329, 14.480633515479486, 12.632255214708778, 11.651455563601486, 10.70221766716646, 9.77683074952262, 8.738001288488764, 7.710421501313476, 6.773246047522413, 5.8047162863255926, 4.79473673352547, 3.867202921895755, 4.813349813551229, 5.765751214808873, 6.756270186347034, 7.6852291346821575, 8.663039504607287, 9.642277027305092, 10.569610028190082, 11.5543018077352, 12.606387589588088, 13.41996201542592, 11.68822447191373, 10.67405242295791, 9.712869946365792, 8.75175831182993, 7.774480740145237, 6.8244279089104225, 5.882806347715066, 4.835710449597391, 3.867993385165776, 2.9254490139737923, 3.85223125917005, 4.7813388822411, 5.7635067234126645, 6.753424129649616, 7.750213711975972, 8.701911593824779, 9.634013273637986, 10.578439870335306, 11.586832163891698, 12.490531685663079, 10.708422648462674, 9.707963649046139, 8.730558869214356, 7.7206813662484475, 6.749124891265841, 5.8561508397470785, 4.921706359979696, 3.854328465664227, 2.9050736202804557, 1.9839749773631346, 2.890925554195931, 3.914253583639475, 4.790934737316426, 5.7497384225351205, 6.6768552438608655, 7.647852408769006, 8.577439008869645, 9.516394333221667, 10.567448548378849, 11.553445455788534, 9.750551651907978, 8.68736685459824, 7.693666171438803, 6.7656285802607785, 5.818364262766809, 4.813819730271993, 3.8775386330413535, 2.8502804436566374, 1.8857098076371321, 0.9457604773130541, 1.878882362484159, 2.89189075102148, 3.827048476080682, 4.721670269869564, 5.75098143877654, 6.732880507456446, 7.6605980901520105, 8.734173128485983, 9.800990745303196, 10.799915188869488, 8.81514810348513, 7.8100090282229395, 6.839305394862515, 5.8581803183633205, 4.900291435769445, 3.88941154825522, 2.916267617031113, 1.9741328234266957, 0.930654935419482, 0.0, 0.9772075389088053, 1.9023809976458481, 2.841341232724716, 3.7879497730552476, 4.774936365288174, 5.770762802992039, 6.71014623829395, 7.784404866643469, 8.809098033486203, 9.82386578149664, 9.800063440065667, 8.76539090624206, 7.821271240159134, 6.83470212197673, 5.834034083061857, 4.885501016983811, 3.817040985268094, 2.825498184580532, 1.859618732696581, 0.9607083617513718, 1.9525973399680905, 2.9314235113880587, 3.865361817254878, 4.859607097122291, 5.732169594578312, 6.682978141273416, 7.6672915419959375, 8.67891361812299, 9.643858465976978, 10.62191061954022, 10.63976557782901, 9.711812465883368, 8.8016151110034, 7.810450300381937, 6.7630625745082025, 5.693314806826977, 4.760651672295904, 3.8152058845239982, 2.8103827383265836, 1.9827040422193263, 2.9039468982656182, 3.9086962085110386, 4.935045853404539, 5.913912562735198, 6.692831026385049, 7.642023291769697, 8.606090301734334, 9.532904130247676, 10.507157442672703, 11.534574807856204, 11.63342255839736, 10.68137604880572, 9.838194933834618, 8.766282932183827, 7.700974144026052, 6.691222588649349, 5.707913639118323, 4.804596595681533, 3.8355798796382476, 2.9850519300217844, 3.9530785682500698, 4.836233470655762, 5.823310802180271, 6.866052925445567, 7.723976513410298, 8.713104120314423, 9.628220363569062, 10.538506865477778, 11.493489852794381, 12.463059208041948, 12.632765021512316, 11.62164361837957, 10.677523690569732, 9.70940419081088, 8.636151018608953, 7.621488900036979, 6.6728371764373, 5.75834275820827, 4.822551589605416, 3.916176388645831, 4.943630514812703, 5.816807930033102, 6.7594965281358945, 7.774281448842126, 8.659919394303863, 9.684184338363176, 10.667891845301844, 11.58940366772998, 12.472169629203163, 13.418739069737118, 13.51652001977289, 12.57499463892733, 11.528533357908062, 10.532338528669133, 9.6069770326841, 8.674240519465803, 7.712372565340574, 6.738743280362712, 5.8866804890570394, 4.97829207598745, 5.914949566429261, 6.844776549119796, 7.7835899314104555, 8.798301932441262, 9.624085491149, 10.610092291475565, 11.624245002101224, 12.551668933342448, 13.495574712631573, 14.463539232645592, 14.575764652116074, 13.57566117127726, 12.52318452434041, 11.463208843881958, 10.632905407217397, 9.60626688918539, 8.686436485407482, 7.6989058249711295, 6.946725304465008, 5.983447880735527, 6.918365422979948, 7.828349957813713, 8.720887783940984, 9.760716536743153, 10.575524385089025, 11.56809753243043, 12.547721845467597, 13.506678477701117, 14.514674386495694, 15.471456524095549, 15.474527838668994, 14.528707009571548, 13.481080892217545, 12.435874746789084, 11.636652849152766, 10.61970017686382, 9.685163295749948, 8.662252440947807, 7.941116039375473, 6.982521616698677, 7.871930058266626, 8.8720036296398, 9.679428720814807, 10.691849627548216, 11.590327159896113, 12.541033894878275, 13.547020765882229, 14.525854243031572, 15.485754876913786, 16.460978291170676, 16.440634486938272, 15.45992634392233, 14.456837688868326, 13.509817164242858, 12.588149669568084, 11.592914516473101, 10.74650220435524, 9.724685421578583, 8.97927091442553, 8.0488494822036, 8.887778957463395, 9.850511697832337, 10.610910483944359, 11.571567718488394, 12.542692092005458, 13.493899597541395, 14.445061958581844, 15.500765069644837, 16.41300018467465, 17.358953532530283, 17.453492391543612, 16.438908595838647, 15.477301679604219, 14.513838088312978, 13.494531441359964, 12.520046713650167, 11.720069698863925, 10.72075000736882, 10.032206339406152, 9.084799721253676, 9.902523666196958, 10.809649356630093, 11.623740755999433, 12.602983538533017, 13.522316297212974, 14.44936971404733, 15.46708382401803, 16.407936153461424, 17.352503069795784, 18.314186456258135, 18.42366886970574, 17.411983883970564, 16.45133191930465, 15.404323947784603, 14.456028765680585, 13.462362614912342, 12.65498951901004, 11.691349640147754, 11.062499769373185, 10.157718378736607, 10.170927586043897, 10.86886613392677, 11.78902186339249, 12.67947020896957, 13.664815571511427, 14.630343897152317, 15.619609236238556, 16.560129752143222, 17.51595678406436, 18.46714349518996], [18.407751756275015, 17.499249692219845, 16.51991267878263, 15.57927625430731, 14.551041614676262, 13.599346921727065, 12.608181434832435, 11.699635054895401, 10.7599779176963, 10.05402370519738, 9.013556958363939, 9.8435903464825, 10.768876302718999, 11.710692941353239, 12.525503488848345, 13.513981108969242, 14.471366587942834, 15.495739185171109, 16.482047195259906, 17.50878479161001, 17.38884597862844, 16.54889886313759, 15.529399800478627, 14.580862579274935, 13.521012185497103, 12.62014500340981, 11.658054731212246, 10.75619473709662, 9.70443211130321, 9.017216108009553, 8.0704891056013, 8.781310557669437, 9.731802178608596, 10.748229351025866, 11.598375493277691, 12.571208478493478, 13.585037789206908, 14.513359633871085, 15.433957199427377, 16.479082446580627, 16.345123325594713, 15.515124663653253, 14.558365071824662, 13.592199351661009, 12.593358918853678, 11.580545274510262, 10.655324631876727, 9.703657908379485, 8.687994919597106, 7.9946189298339645, 7.049643412136856, 7.7815252477295775, 8.716586552933064, 9.707348402577562, 10.650082913684862, 11.588715949210986, 12.531759823654937, 13.565552022752216, 14.50855904834421, 15.460388378016043, 15.326775280597428, 14.568797010674448, 13.583954842444289, 12.655345822939639, 11.616086311390264, 10.597216127818886, 9.648735350366314, 8.657626815964091, 7.672076465805811, 6.93594321018915, 5.990584599383482, 6.79316038190893, 7.757063663005056, 8.719612103360806, 9.630176957743268, 10.674207286712146, 11.602725913152279, 12.537843988958988, 13.522724859999766, 14.473644792516712, 14.401199629173814, 13.629783088696799, 12.601478032667156, 11.64332683588602, 10.633824389629924, 9.706284314286826, 8.660986817262714, 7.7202834179808395, 6.679950355681439, 5.869404574344454, 4.93536887205143, 5.853790681496379, 6.888408817512729, 7.808025274463773, 8.651347711513687, 9.67361008796242, 10.635319510170156, 11.564182859947358, 12.576862078136847, 13.50342597657068, 13.393097535777791, 12.604715828122268, 11.655477931687242, 10.730091014043403, 9.691261553009547, 8.66368176583426, 7.726506312043196, 6.757976550846376, 5.747996998046253, 4.820463186416538, 3.9634039794659968, 4.892861057642798, 5.883380029180959, 6.789885759215594, 7.725486096496205, 8.70472361919401, 9.61905937936424, 10.577094268826396, 11.629180050679285, 12.442754476517115, 12.512465538021752, 11.630004827628593, 10.668822351036475, 9.707710716500612, 8.730433144815919, 7.780380313581105, 6.838758752385749, 5.791662854268074, 4.823945789836459, 3.878709278494576, 2.9419398934985224, 3.868975450696284, 4.846888169120462, 5.776216590740811, 6.7730061730671665, 7.724704054915973, 8.656805734729181, 9.601232331426502, 10.609624624982894, 11.513324146754274, 11.604201477186963, 10.663916053716822, 9.686511273885039, 8.67663377091913, 7.7050772959365235, 6.812103244417761, 5.877658764650379, 4.810280870334909, 3.861026024951138, 2.9372352418839185, 1.9806341885244036, 2.9370460447306694, 3.81372719840762, 4.772530883626315, 5.69964770495206, 6.6706448698602, 7.600231469960839, 8.539186794312862, 9.590241009470043, 10.576237916879728, 10.70650405657866, 9.643319259268923, 8.649618576109486, 7.721580984931461, 6.774316667437492, 5.769772134942675, 4.833491037712036, 3.8062328483273196, 2.8416622123078144, 1.9017128819837366, 0.9685909968126318, 1.914683212112675, 2.8498409371718765, 3.744462730960758, 4.773773899867734, 5.755672968547641, 6.683390551243205, 7.756965589577177, 8.82378320639439, 9.827346767770862, 9.792355642393936, 8.787216567131745, 7.81651293377132, 6.835387857272126, 5.87749897467825, 4.866619087164025, 3.8934751559399183, 2.9513403623355012, 1.9078624743282873, 0.9772075389088053, 0.0, 0.9251734587370427, 1.8641336938159103, 2.810742234146442, 3.797728826379369, 4.793555264083233, 5.732938699385144, 6.807197327734664, 7.831890494577397, 8.846658242587834, 10.587087881619192, 9.742598445150865, 8.79847877906794, 7.811909660885536, 6.811241621970662, 5.862708555892617, 4.7942485241769, 3.802705723489337, 2.836826271605386, 1.937915900660177, 0.9753898010592852, 1.9542159724792532, 2.8881542783460725, 3.882399558213486, 4.754962055669506, 5.705770602364611, 6.690084003087132, 7.701706079214184, 8.666650927068172, 9.644703080631414, 11.512972647340316, 10.689020004792173, 9.778822649912208, 8.787657839290743, 7.740270113417008, 6.670522345735782, 5.737859211204709, 4.792413423432803, 3.7875902772353887, 2.9066087372253353, 1.9267393593568127, 2.931488669602233, 3.9578383144957336, 4.936705023826392, 5.715623487476243, 6.664815752860892, 7.628882762825529, 8.555696591338872, 9.5299499037639, 10.5573672689474, 12.506629627908666, 11.658583587714526, 10.815402472743425, 9.743490471092635, 8.678181682934857, 7.668430127558154, 6.685121178027129, 5.781804134590338, 4.812787418547053, 3.908956625027794, 2.976206810422908, 3.859025931746957, 4.846103263271465, 5.888845386536762, 6.746768974501492, 7.735896581405617, 8.651012824660256, 9.561299326568975, 10.516282313885577, 11.485851669133144, 13.419007980325027, 12.598851157288376, 11.654731229478537, 10.686611729719685, 9.613358557517758, 8.598696438945785, 7.650044715346105, 6.735550297117076, 5.799759128514221, 4.840081083651841, 4.035658732138983, 4.839600391124296, 5.782288989227089, 6.797073909933321, 7.682711855395057, 8.70697679945437, 9.690684306393038, 10.612196128821177, 11.49496209029436, 12.441531530828314, 14.391889931226265, 13.552202177836135, 12.505740896816866, 11.509546067577936, 10.584184571592905, 9.651448058374609, 8.68958010424938, 7.715950819271518, 6.863888027965845, 5.902196770993459, 5.0069777837555405, 5.867569010210991, 6.80638239250165, 7.821094393532456, 8.646877952240194, 9.63288475256676, 10.647037463192419, 11.574461394433644, 12.518367173722769, 13.496639681406265, 15.451134563569449, 14.552868710186063, 13.500392063249214, 12.440416382790762, 11.610112946126202, 10.583474428094195, 9.663644024316287, 8.676113363879935, 7.923932843373813, 6.907352575741537, 6.010393640306227, 6.8511424189049075, 7.743680245032178, 8.783508997834348, 9.59831684618022, 10.590889993521625, 11.570514306558792, 12.529470938792311, 13.53746684758689, 14.504556972856221, 16.451469233622543, 15.505914548480352, 14.458288431126348, 13.413082285697888, 12.613860388061571, 11.596907715772625, 10.662370834658754, 9.639459979856612, 8.90682855632493, 7.906426311704687, 6.963958275592905, 7.894796090730993, 8.702221181906001, 9.71464208863941, 10.613119620987307, 11.56382635596947, 12.569813226973423, 13.548646704122767, 14.508547338004982, 15.483770752261872, 17.331743302176157, 16.437133882831134, 15.43404522777713, 14.487024703151661, 13.56535720847689, 12.570122055381907, 11.723709743264045, 10.701892960487388, 9.90317560943154, 8.97275417720961, 7.979807174789673, 8.906757027877134, 9.633702945035553, 10.594360179579589, 11.565484553096653, 12.51669205863259, 13.467854419673039, 14.523557530736031, 15.435792645765849, 16.381745993621482, 18.331779134932535, 17.41611613474745, 16.454509218513024, 15.491045627221782, 14.47173898026877, 13.497254252558973, 12.697277237772731, 11.697957546277625, 10.956111034412164, 10.008704416259686, 8.994551883523236, 9.865894686674892, 10.646533217090628, 11.625775999624212, 12.545108758304169, 13.472162175138525, 14.489876285109224, 15.430728614552619, 16.375295530886977, 17.336978917349334, 18.422047940545493, 17.410362954810317, 16.4497109901444, 15.472090726963179, 14.523795544859162, 13.466403954171065, 12.638739532753045, 11.7210603604548, 10.883427553642733, 10.022744308541224, 10.014035256770775, 10.8528785414085, 11.574508036037079, 12.503926872508824, 13.487403952157303, 14.440704531992136, 15.429969871078375, 16.44271549816368, 17.441720128404317, 18.26381735807118], [17.482578297537973, 17.486514026032577, 16.511019377308013, 15.564348383130326, 14.548093620251935, 13.66813694485773, 12.710329981319303, 11.799009179207511, 11.096881092312316, 10.798193756863856, 9.751058324008788, 8.918416887745456, 9.843702843981957, 10.785519482616197, 11.600330030111303, 12.5888076502322, 13.546193129205792, 14.570565726434067, 15.55687373652286, 16.583611332872966, 16.463672519891396, 17.383957279239773, 16.454573259215667, 15.506036038011977, 14.446185644234145, 13.545318462146854, 12.58322818994929, 11.681368195833663, 10.629605570040253, 9.761386159676029, 8.80799047124615, 7.856137098932394, 8.806628719871554, 9.823055892288824, 10.67320203454065, 11.646035019756436, 12.659864330469865, 13.588186175134043, 14.508783740690331, 15.553908987843581, 15.419949866857669, 16.350105826001883, 15.483538530561704, 14.51737281039805, 13.51853237759072, 12.505718733247306, 11.580498090613771, 10.628831367116527, 9.613168378334148, 8.807358047533976, 7.787144777781705, 6.856351788992535, 7.791413094196022, 8.78217494384052, 9.72490945494782, 10.663542490473944, 11.606586364917895, 12.640378564015174, 13.583385589607165, 14.535214919278998, 14.401601821860384, 15.33901588688068, 14.509128301181331, 13.58051928167668, 12.541259770127306, 11.52238958655593, 10.573908809103358, 9.582800274701135, 8.597249924542854, 7.861116668926192, 6.915758058120525, 5.8679869231718875, 6.831890204268014, 7.794438644623764, 8.705003499006226, 9.749033827975104, 10.677552454415236, 11.612670530221946, 12.59755140126272, 13.548471333779668, 13.47602617043677, 14.424987790300294, 13.526651491404198, 12.568500294623062, 11.558997848366966, 10.631457773023868, 9.586160275999756, 8.645456876717882, 7.605123814418482, 6.794578033081497, 5.860542330788473, 4.928617222759337, 5.963235358775687, 6.882851815726731, 7.726174252776644, 8.748436629225377, 9.710146051433114, 10.639009401210316, 11.6516886193998, 12.578252517833636, 12.467924077040747, 13.529663767519903, 12.580651390424284, 11.655264472780445, 10.616435011746589, 9.588855224571303, 8.65167977078024, 7.683150009583419, 6.673170456783296, 5.745636645153581, 4.88857743820304, 3.9676875989057554, 4.958206570443917, 5.864712300478552, 6.800312637759162, 7.779550160456967, 8.693885920627196, 9.65192081008935, 10.704006591942239, 11.51758101778007, 11.587292079284708, 12.555178286365637, 11.593995809773519, 10.632884175237656, 9.655606603552963, 8.705553772318147, 7.763932211122791, 6.716836313005116, 5.749119248573502, 4.803882737231619, 3.8671133522355654, 2.9438019919592415, 3.9217147103834193, 4.851043132003769, 5.847832714330123, 6.799530596178931, 7.731632275992137, 8.676058872689456, 9.684451166245848, 10.58815068801723, 10.67902801844992, 11.589089512453864, 10.611684732622082, 9.601807229656174, 8.630250754673567, 7.737276703154805, 6.802832223387421, 5.735454329071952, 4.786199483688181, 3.862408700620961, 2.9058076472614465, 2.011872585993627, 2.888553739670577, 3.8473574248892723, 4.774474246215017, 5.745471411123157, 6.675058011223795, 7.614013335575818, 8.665067550733, 9.651064458142685, 9.920256191243217, 10.568492718005967, 9.57479203484653, 8.646754443668504, 7.699490126174535, 6.694945593679718, 5.758664496449079, 4.731406307064362, 3.766835671044857, 2.826886340720779, 1.8937644555496744, 0.9895097533756322, 1.9246674784348334, 2.819289272223715, 3.8486004411306913, 4.830499509810598, 5.758217092506162, 6.831792130840134, 7.898609747657347, 8.90217330903382, 8.982176488482992, 9.712390025868789, 8.741686392508363, 7.760561316009168, 6.802672433415292, 5.7917925459010675, 4.8186486146769605, 3.876513821072544, 2.83303593306533, 1.9023809976458481, 0.9251734587370427, 0.0, 0.9389602350788676, 1.885568775409399, 2.872555367642326, 3.8683818053461905, 4.807765240648102, 5.882023868997622, 6.906717035840355, 7.921484783850792, 9.661914422882148, 10.667771903887907, 9.723652237804982, 8.737083119622579, 7.736415080707705, 6.787882014629659, 5.719421982913942, 4.7278791822263795, 3.761999730342429, 2.86308935939722, 1.900563259796328, 1.058373701005507, 1.96298081960903, 2.957226099476443, 3.829788596932463, 4.780597143627568, 5.764910544350089, 6.776532620477141, 7.741477468331129, 8.71952962189437, 10.587799188603272, 11.515752300548915, 10.70399610864925, 9.712831298027785, 8.66544357215405, 7.595695804472824, 6.663032669941751, 5.717586882169846, 4.712763735972432, 3.8317821959623783, 2.8519128180938558, 2.113342739754792, 3.032664855758691, 4.011531565089349, 4.7904500287392, 5.739642294123849, 6.703709304088486, 7.630523132601828, 8.604776445026856, 9.632193810210357, 11.581456169171622, 12.485315883471268, 11.740575931480468, 10.668663929829677, 9.6033551416719, 8.593603586295195, 7.610294636764171, 6.706977593327381, 5.737960877284096, 4.834130083764837, 3.901380269159951, 3.0408800018995157, 4.027957333424024, 5.07069945668932, 5.82159551576445, 6.810723122668574, 7.725839365923214, 8.63612586783193, 9.591108855148534, 10.5606782103961, 12.493834521587983, 13.425583453045117, 12.57990468821558, 11.611785188456727, 10.5385320162548, 9.523869897682827, 8.575218174083147, 7.660723755854119, 6.724932587251264, 5.765254542388884, 4.960832190876026, 4.021454461276855, 4.964143059379648, 5.97892798008588, 6.757538396658015, 7.781803340717327, 8.765510847655996, 9.687022670084133, 10.569788631557316, 11.51635807209127, 13.466716472489221, 14.408241853334781, 13.430914355553908, 12.434719526314979, 11.509358030329947, 10.57662151711165, 9.614753562986422, 8.641124278008562, 7.789061486702888, 6.827370229730502, 5.9321512424925835, 5.04942308036355, 5.988236462654209, 7.002948463685015, 7.721704493503152, 8.707711293829716, 9.721864004455375, 10.6492879356966, 11.593193714985725, 12.57146622266922, 14.525961104832405, 15.442464374577455, 14.425565521986256, 13.365589841527804, 12.535286404863244, 11.508647886831238, 10.58881748305333, 9.601286822616979, 8.849106302110856, 7.83252603447858, 6.93556709904327, 6.032996489057466, 6.925534315184737, 7.965363067986907, 8.673143387443178, 9.665716534784583, 10.64534084782175, 11.60429748005527, 12.612293388849846, 13.579383514119177, 15.526295774885497, 16.431088007217394, 15.38346188986339, 14.33825574443493, 13.539033846798613, 12.522081174509669, 11.587544293395798, 10.564633438593656, 9.832002015061974, 8.83159977044173, 7.889131734329949, 7.076650160883552, 7.88407525205856, 8.896496158791969, 9.687946162250265, 10.638652897232427, 11.644639768236381, 12.623473245385725, 13.583373879267938, 14.558597293524828, 16.406569843439115, 17.362307341568176, 16.359218686514172, 15.412198161888703, 14.490530667213934, 13.49529551411895, 12.64888320200109, 11.627066419224432, 10.828349068168585, 9.897927635946655, 8.904980633526717, 8.088611098029695, 8.815557015188112, 9.776214249732147, 10.727488631491934, 11.591518599895547, 12.542680960935996, 13.59838407199899, 14.510619187028805, 15.456572534884438, 17.40660567619549, 17.489066832937056, 16.465678630307917, 15.483060142820506, 14.458031124405995, 13.483546396696198, 12.648485894162118, 11.766486534496693, 10.988547524872722, 10.93387787499673, 9.91972534226028, 9.047748756827453, 9.828387287243187, 10.80763006977677, 11.70711283669945, 12.546988716401483, 13.564702826372182, 14.505555155815577, 15.450122072149936, 16.41180545861229, 17.49687448180845, 16.485189496073275, 15.52453753140736, 14.546917268226137, 13.59862208612212, 12.541230495434023, 11.713566074016002, 10.795886901717758, 9.958254094905689, 10.760245674186073, 10.939208715507819, 10.034732611561061, 10.756362106189638, 11.685780942661383, 12.649408030552584, 13.515531073255094, 14.504796412341333, 15.517542039426637, 16.516546669667274, 17.33864389933413], [16.543618062459107, 16.54755379095371, 15.572059142229147, 14.62538814805146, 13.609133385173068, 12.729176709778864, 11.822318540285622, 10.91099773817383, 11.85065487537293, 11.689819281614522, 10.642683848759454, 9.810042412496124, 9.07537965085389, 9.92212059217507, 10.661369795032435, 11.649847415153332, 12.607232894126923, 13.631605491355199, 14.617913501443994, 15.6446510977941, 15.52471228481253, 16.444997044160907, 16.56257202053315, 15.667189549031006, 14.639162814352227, 13.708378628096119, 12.77244524390581, 11.96064569403582, 11.568565805119121, 10.653011684426694, 9.699615995996815, 8.74776262368306, 8.038305526743487, 8.959657001847697, 9.734241799461781, 10.707074784677568, 11.720904095390997, 12.649225940055175, 13.569823505611465, 14.614948752764715, 14.480989631778803, 15.411145590923017, 16.367905182751606, 15.45633304547692, 14.45749261266959, 13.444678968326174, 12.51945832569264, 11.567791602195395, 10.552128613413016, 9.698983572284641, 8.67877030253237, 7.747977313743201, 7.023089901067954, 7.903781080199812, 8.785949219868952, 9.724582255395076, 10.667626129839027, 11.701418328936306, 12.644425354528298, 13.596254684200131, 13.462641586781517, 14.400055651801814, 15.422912997703595, 14.51947951675555, 13.480220005206176, 12.461349821634798, 11.512869044182226, 10.521760509780004, 9.536210159621723, 8.774142723566728, 7.813179845665917, 6.759612447922553, 6.063567011139946, 6.916044780983055, 7.766043263927359, 8.810073592896236, 9.738592219336368, 10.673710295143078, 11.658591166183854, 12.609511098700802, 12.537065935357903, 13.486027555221428, 14.465611726483068, 13.507460529701932, 12.497958083445836, 11.570418008102738, 10.525120511078626, 9.584417111796752, 8.54408404949735, 7.707604087722032, 6.757964118333865, 5.820242747510003, 5.0752312149822725, 5.943891580647864, 6.787214017697776, 7.809476394146511, 8.771185816354247, 9.70004916613145, 10.712728384320934, 11.63929228275477, 11.52896384196188, 12.590703532441037, 13.519611625503154, 12.594224707859315, 11.555395246825459, 10.527815459650173, 9.59064000585911, 8.622110244662288, 7.6121306918621645, 6.68459688023245, 5.785999225748432, 4.85931312365642, 4.048458246259111, 4.925752065399685, 5.861352402680295, 6.8405899253781, 7.754925685548328, 8.712960575010486, 9.765046356863373, 10.578620782701204, 10.648331844205842, 11.662503893161661, 12.532956044852385, 11.571844410316523, 10.59456683863183, 9.644514007397015, 8.702892446201659, 7.655796548083984, 6.688079483652369, 5.742842972310487, 4.764535139780957, 3.835427516709907, 2.982754475304552, 3.912082896924901, 4.908872479251256, 5.860570361100063, 6.792672040913271, 7.737098637610591, 8.745490931166982, 9.649190452938363, 9.740067783371053, 10.740526782787589, 11.550644967700949, 10.54076746473504, 9.569210989752433, 8.676236938233671, 7.741792458466289, 6.674414564150819, 5.725159718767048, 4.801368935699829, 3.8447678823403137, 2.9034981107442923, 1.9495935045917094, 2.908397189810405, 3.8355140111361496, 4.80651117604429, 5.736097776144929, 6.675053100496951, 7.726107315654133, 8.712104223063818, 8.981295956164349, 10.035117894930714, 10.513752269925396, 9.58571467874737, 8.638450361253401, 7.633905828758585, 6.697624731527945, 5.670366542143229, 4.705795906123725, 3.765846575799647, 2.832724690628542, 1.9243540788886964, 0.9857072433559659, 1.8803290371448478, 2.909640206051824, 3.89153927473173, 4.819256857427295, 5.892831895761267, 6.95964951257848, 7.963213073954952, 8.043216253404124, 9.048355328666315, 9.68064662758723, 8.699521551088036, 7.7416326684941605, 6.730752780979936, 5.757608849755829, 4.8154740561514116, 3.771996168144198, 2.841341232724716, 1.8641336938159103, 0.9389602350788676, 0.0, 0.9466085403305315, 1.9335951325634584, 2.9294215702673227, 3.868805005569234, 4.9430636339187535, 5.967756800761487, 6.982524548771924, 8.722954187803282, 9.75762672162689, 10.662612472883849, 9.676043354701445, 8.675375315786573, 7.726842249708527, 6.65838221799281, 5.666839417305248, 4.700959965421297, 3.8020495944760877, 2.8395234948751957, 1.970236354695714, 1.0240205845301622, 2.0182658643975753, 2.890828361853596, 3.8416369085487005, 4.825950309271222, 5.837572385398274, 6.802517233252262, 7.780569386815503, 9.648838953524404, 10.576792065470046, 11.59468493994499, 10.651791533106651, 9.604403807232917, 8.534656039551692, 7.601992905020619, 6.6565471172487145, 5.651723971051299, 4.770742431041246, 3.7908730531727235, 3.025205393444999, 2.0937046206798233, 3.072571330010482, 3.8514897936603334, 4.800682059044982, 5.764749069009619, 6.691562897522961, 7.665816209947987, 8.693233575131488, 10.642495934092754, 11.5463556483924, 12.599740642869133, 11.607624164908543, 10.542315376750768, 9.532563821374064, 8.549254871843038, 7.6459378284062485, 6.6769211123629635, 5.773090318843704, 4.840340504238819, 3.9527426555897227, 3.139945892390341, 4.138284675631704, 4.882635280685583, 5.871762887589708, 6.786879130844346, 7.697165632753063, 8.652148620069665, 9.621717975317232, 11.554874286509115, 12.48662321796625, 13.507205561256423, 12.550745423535595, 11.477492251333668, 10.462830132761695, 9.514178409162016, 8.599683990932986, 7.663892822330132, 6.704214777467751, 5.899792425954894, 4.933317114967062, 4.076131618345965, 5.090916539052197, 5.818578161579149, 6.842843105638461, 7.826550612577129, 8.748062435005265, 9.630828396478448, 10.577397837012402, 12.527756237410353, 13.469281618255913, 14.369874590632778, 13.373679761393849, 12.448318265408815, 11.515581752190519, 10.55371379806529, 9.580084513087428, 8.728021721781756, 7.76633046480937, 6.871111477571452, 5.961285734053757, 5.100225021620526, 6.114937022651332, 6.782744258424286, 7.7687510587508495, 8.782903769376508, 9.710327700617732, 10.654233479906857, 11.632505987590353, 13.587000869753536, 14.503504139498586, 15.364525757065126, 14.304550076606674, 13.474246639942113, 12.447608121910106, 11.5277777181322, 10.540247057695845, 9.788066537189724, 8.771486269557446, 7.8745273341221385, 6.944859142747673, 6.037522874151054, 7.077351626953224, 7.734183152364311, 8.726756299705716, 9.706380612742883, 10.665337244976403, 11.673333153770978, 12.64042327904031, 14.58733553980663, 15.533156368904075, 16.32242212494226, 15.2772159795138, 14.477994081877481, 13.461041409588535, 12.526504528474664, 11.503593673672523, 10.77096225014084, 9.770560005520597, 8.828091969408817, 7.956588284366811, 6.996063811024877, 8.008484717758286, 8.748985927171399, 9.699692662153561, 10.705679533157515, 11.684513010306858, 12.64441364418907, 13.61963705844596, 15.467609608360245, 16.46437570325486, 16.457806330035737, 15.510785805410267, 14.466953511889379, 13.471718358794396, 12.758654498229676, 11.994227927158862, 11.767309303247451, 10.836887871025521, 9.843940868605586, 8.968549221512953, 7.92754557415443, 8.888202808698464, 9.788528396413067, 10.65255836481668, 11.60372072585713, 12.659423836920123, 13.571658951949937, 14.51761229980557, 16.467645441116623, 16.550106597858186, 15.526718395229048, 14.544099907741638, 13.519070889327127, 12.54458616161733, 11.78508700372099, 10.998163341368626, 11.880173049623389, 11.872838110075596, 10.858685577339148, 9.885385969262087, 8.940375846209506, 9.91961862874309, 10.768152601620583, 11.608028481322616, 12.625742591293315, 13.56659492073671, 14.51116183707107, 15.472845223533422, 16.557914246729585, 15.546229260994407, 14.585577296328491, 13.60795703314727, 12.659661851043253, 11.602270260355155, 10.850167183574875, 10.02756370858969, 10.849879619656356, 11.651871198936739, 11.867389640556304, 10.84264368794576, 9.868350665155956, 10.797769501627702, 11.710447795473717, 12.576570838176227, 13.565836177262467, 14.57858180434777, 15.57758643458841, 16.399683664255264], [15.597009522128573, 15.600945250623178, 14.625450601898615, 13.678779607720928, 12.662524844842537, 11.782568169448332, 11.342403355377483, 11.85760627850436, 12.79726341570346, 12.577231140130603, 11.530095707275537, 10.697454271012205, 9.935023877999056, 8.975512051844538, 9.714761254701903, 10.7032388748228, 11.660624353796392, 12.684996951024667, 13.671304961113464, 14.69804255746357, 14.578103744481997, 15.498388503830375, 15.61596348020262, 14.720581008700474, 13.692554274021695, 12.761770087765587, 12.292530058997672, 12.90725423436635, 12.50352690080666, 11.540423542942778, 10.587027854512899, 9.635174482199144, 8.897949753888653, 8.013048461517165, 8.78763325913125, 9.760466244347036, 10.774295555060466, 11.702617399724643, 12.623214965280935, 13.668340212434185, 13.534381091448271, 14.464537050592485, 15.421296642421076, 15.619047973472451, 14.62020754066512, 13.801369816665135, 13.29526015833319, 12.502752697882935, 11.487089709100555, 10.586395430800724, 9.566182161048454, 8.635389172259284, 7.88273412821312, 6.95717253986928, 7.83934067953842, 8.777973715064544, 9.721017589508495, 10.754809788605774, 11.697816814197768, 12.649646143869601, 12.516033046450985, 13.453447111471283, 14.476304457373063, 15.404913476877713, 14.415181100893717, 13.396310917322337, 12.447830139869765, 11.456721605467543, 10.471171255309262, 9.661554582082811, 8.700591704182001, 7.647024306438636, 6.923211238285112, 5.969436240652524, 6.819434723596827, 7.863465052565704, 8.791983679005837, 9.727101754812546, 10.711982625853324, 11.66290255837027, 11.590457395027371, 12.539419014890896, 13.539332989525445, 14.442421625389473, 13.432919179133377, 12.505379103790277, 11.460081606766165, 10.51937820748429, 9.47904514518489, 8.595015946238115, 7.645375976849948, 6.707654606026086, 5.934875442127439, 4.997283040317332, 5.8406054773672444, 6.862867853815979, 7.8245772760237156, 8.753440625800918, 9.766119843990404, 10.692683742424238, 10.582355301631349, 11.644094992110505, 12.59333288854553, 13.51871980618937, 12.490356342513, 11.462776555337712, 10.525601101546648, 9.557071340349827, 8.547091787549704, 7.619557975919989, 6.673411084264515, 5.746724982172504, 4.908102473404277, 3.979143525069153, 4.914743862349763, 5.893981385047568, 6.808317145217797, 7.766352034679954, 8.818437816532843, 9.632012242370672, 9.70172330387531, 10.71589535283113, 11.677077829423247, 12.518452950647053, 11.54117537896236, 10.591122547727547, 9.64950098653219, 8.602405088414516, 7.634688023982901, 6.689451512641019, 5.65194699829704, 4.72283937522599, 3.8701663338206354, 2.965474356594369, 3.9622639389207244, 4.913961820769532, 5.846063500582739, 6.790490097280059, 7.79888239083645, 8.702581912607831, 8.793459243040521, 9.793918242457057, 10.790170336335082, 11.48737600506557, 10.515819530082963, 9.622845478564201, 8.688400998796821, 7.621023104481351, 6.67176825909758, 5.747977476030361, 4.7913764226708455, 3.7909099692603756, 2.8370053631077927, 1.9617886494798733, 2.888905470805618, 3.8599026357137585, 4.789489235814397, 5.72844456016642, 6.779498775323601, 7.765495682733286, 8.034687415833817, 9.088509354600182, 10.08221003775962, 10.5323232190779, 9.585058901583931, 8.580514369089116, 7.644233271858477, 6.616975082473761, 5.652404446454256, 4.712455116130179, 3.7793332309590735, 2.81176593740478, 1.8731191018720492, 0.9337204968143161, 1.9630316657212923, 2.944930734401199, 3.872648317096763, 4.946223355430735, 6.013040972247948, 7.01660453362442, 7.096607713073592, 8.101746788335783, 9.072450421696209, 9.646130091418566, 8.68824120882469, 7.677361321310467, 6.7042173900863595, 5.762082596481942, 4.718604708474729, 3.7879497730552467, 2.8107422341464416, 1.885568775409399, 0.9466085403305315, 0.0, 0.986986592232927, 1.9828130299367912, 2.9221964652387027, 3.996455093588222, 5.021148260430955, 6.035916008441392, 7.77634564747275, 8.811018181296358, 9.755137847379284, 10.622651895031975, 9.621983856117103, 8.673450790039059, 7.604990758323341, 6.6134479576357785, 5.647568505751828, 4.748658134806618, 3.7861320352057266, 2.9168448950262453, 1.9706291248606937, 1.071657324067044, 1.9442198215230642, 2.895028368218169, 3.87934176894069, 4.890963845067742, 5.85590869292173, 6.833960846484971, 8.702230413193872, 9.630183525139515, 10.648076399614459, 11.598400073437183, 10.551012347563448, 9.481264579882223, 8.548601445351151, 7.603155657579245, 6.59833251138183, 5.7173509713717765, 4.737481593503254, 3.97181393377553, 3.0403131610103546, 2.1259627896799502, 2.9048812533298016, 3.85407351871445, 4.818140528679087, 5.744954357192429, 6.719207669617456, 7.746625034800957, 9.695887393762222, 10.599747108061868, 11.653132102538601, 12.554232705239077, 11.4889239170813, 10.479172361704595, 9.49586341217357, 8.592546368736778, 7.623529652693494, 6.719698859174235, 5.78694904456935, 4.899351195920254, 4.086554432720872, 3.1916761353011727, 3.936026740355051, 4.925154347259176, 5.840270590513814, 6.7505570924225315, 7.705540079739134, 8.6751094349867, 10.608265746178583, 11.540014677635718, 12.560597020925892, 13.497353963866127, 12.4241007916642, 11.409438673092227, 10.460786949492547, 9.546292531263516, 8.610501362660662, 7.650823317798282, 6.846400966285425, 5.879925655297593, 5.022740158676496, 4.240142089301129, 4.871969621248617, 5.896234565307929, 6.879942072246597, 7.801453894674733, 8.684219856147916, 9.63078929668187, 11.581147697079821, 12.522673077925381, 13.563551344395963, 14.320288301724378, 13.394926805739347, 12.46219029252105, 11.500322338395822, 10.526693053417958, 9.674630262112286, 8.712939005139901, 7.817720017901983, 6.9078942743842875, 6.046833561951057, 5.264162572900264, 5.836135718093754, 6.822142518420318, 7.836295229045976, 8.7637191602872, 9.707624939576325, 10.685897447259821, 12.640392329423005, 13.556895599168055, 14.55820251082831, 15.251158616937204, 14.420855180272644, 13.394216662240638, 12.47438625846273, 11.486855598026375, 10.734675077520254, 9.718094809887978, 8.821135874452668, 7.891467683078204, 6.984131414481585, 6.339042819838235, 6.787574612033779, 7.780147759375184, 8.759772072412352, 9.718728704645871, 10.726724613440446, 11.693814738709778, 13.640726999476097, 14.586547828573543, 15.516098878705446, 15.433566147321034, 14.501704155408008, 13.498324158073146, 12.885902509434924, 12.450202214003053, 11.71757079047137, 10.717168545851127, 9.774700509739347, 8.903196824697343, 7.942672351355408, 7.283060950544605, 7.802377386840866, 8.75308412182303, 9.759070992826983, 10.737904469976327, 11.697805103858538, 12.673028518115428, 14.521001068029713, 15.517767162924326, 15.511197789705204, 14.564177265079735, 13.520344971558847, 12.525109818463864, 11.812045957899144, 12.833862740675801, 12.713917843577981, 11.783496411356051, 10.790549408936116, 9.915157761843485, 8.874154114484961, 8.291211190286228, 8.841919856082535, 9.705949824486149, 10.657112185526598, 11.712815296589591, 12.625050411619405, 13.571003759475039, 15.521036900786092, 15.603498057527656, 14.580109854898517, 13.597491367411106, 12.572462348996595, 11.597977621286798, 10.838478463390459, 11.857807568513792, 12.76758490813947, 12.819446650406126, 11.805294117669678, 10.831994509592617, 9.886984386540036, 9.342437662594582, 9.821544061290052, 10.661419940992085, 11.679134050962784, 12.619986380406178, 13.564553296740538, 14.52623668320289, 15.611305706399051, 14.599620720663875, 13.63896875599796, 12.661348492816737, 11.71305331071272, 10.655661720024623, 9.903558643244343, 10.887207935734857, 11.737291478172438, 12.539283057452824, 12.813998180886834, 11.78925222827629, 10.814959205486486, 10.317854316719563, 10.763839255143186, 11.629962297845696, 12.619227636931935, 13.631973264017239, 14.630977894257878, 15.453075123924734], [14.628709760532605, 14.613958658390251, 13.638464009665688, 12.691793015488, 11.67553825260961, 10.795581577215405, 11.802093669460888, 12.654632194237482, 13.594289331436583, 13.564217732363531, 12.517082299508465, 11.684440863245133, 10.74289578424703, 9.734503351311222, 8.746461493105937, 9.734939113226833, 10.692324592200425, 11.7166971894287, 12.703005199517493, 13.729742795867601, 13.609803982886028, 14.530088742234406, 14.628976887969692, 13.733594416467547, 12.705567681788768, 11.77478349553266, 12.752220373081077, 13.704280150099473, 13.490513493039586, 12.527410135175705, 11.574014446745826, 10.622161074432071, 9.78846693340112, 8.77203976098385, 7.819333497535282, 8.792166482751067, 9.805995793464497, 10.734317638128674, 11.654915203684965, 12.700040450838214, 12.566081329852302, 13.496237288996516, 14.452996880825108, 14.632061381239524, 13.633220948432193, 12.814383224432207, 13.754950472416596, 13.48973929011586, 12.474076301333481, 11.573382023033652, 10.553168753281382, 9.622375764492212, 8.786865604161028, 7.845339691204214, 6.871040917942452, 7.809673953468575, 8.752717827912527, 9.786510027009806, 10.729517052601798, 11.681346382273631, 11.547733284855017, 12.485147349875314, 13.508004695777094, 14.436613715281744, 14.695058214835077, 13.797712371123584, 13.434816732102691, 12.443708197700468, 11.458157847542187, 10.648541174315739, 9.687578296414928, 8.634010898671564, 7.827342714233019, 6.864794273877269, 5.851134962000859, 6.895165290969736, 7.823683917409868, 8.758801993216577, 9.743682864257353, 10.694602796774301, 10.622157633431403, 11.571119253294928, 12.571033227929476, 13.6000890570696, 14.4199057713663, 13.492365696023203, 12.44706819899909, 11.506364799717216, 10.466031737417815, 9.582002538471043, 8.632362569082876, 7.6946411982590135, 6.879986387737208, 5.892641073542077, 4.872305715771276, 5.89456809222001, 6.856277514427746, 7.785140864204948, 8.797820082394434, 9.72438398082827, 9.61405554003538, 10.675795230514536, 11.625033126949562, 12.550420044593402, 13.477342934745923, 12.449763147570637, 11.512587693779574, 10.544057932582753, 9.53407837978263, 8.606544568152914, 7.660397676497442, 6.733711574405431, 5.853213419014048, 4.924254470678924, 3.9464441007537934, 4.925681623451599, 5.840017383621826, 6.798052273083984, 7.850138054936872, 8.663712480774704, 8.73342354227934, 9.747595591235159, 10.708778067827277, 11.715772545734852, 12.528161971195287, 11.578109139960475, 10.636487578765118, 9.589391680647443, 8.621674616215827, 7.676438104873946, 6.638933590529967, 5.709825967458917, 4.857152926053562, 3.952460948827296, 2.993964177324755, 3.945662059173562, 4.8777637389867685, 5.822190335684089, 6.830582629240481, 7.734282151011862, 7.825159481444551, 8.825618480861086, 9.821870574739112, 10.83174807770502, 11.50280612231589, 10.609832070797129, 9.675387591029748, 8.608009696714278, 7.6587548513305075, 6.734964068263288, 5.778363014903773, 4.777896561493303, 3.82399195534072, 2.9487752417128004, 1.920605709209648, 2.8916028741177886, 3.821189474218427, 4.76014479857045, 5.811199013727632, 6.797195921137317, 7.04770082360089, 8.101522762367255, 9.095223445526692, 10.023261036704717, 10.572045493816859, 9.567500961322043, 8.631219864091404, 7.603961674706689, 6.639391038687184, 5.699441708363106, 4.766319823192001, 3.7987525296377065, 2.860105694104976, 1.920707089047243, 0.9947319041253226, 1.9579441421682717, 2.8856617248638363, 3.9592367631978087, 5.0260543800150215, 6.029617941391493, 6.109621120840664, 7.114760196102855, 8.085463829463281, 9.066588905962476, 9.675227801057618, 8.664347913543393, 7.691203982319287, 6.74906918871487, 5.705591300707656, 4.774936365288174, 3.7977288263793687, 2.872555367642326, 1.9335951325634584, 0.986986592232927, 0.0, 0.9958264377038643, 1.9352098730057756, 3.009468501355295, 4.034161668198028, 5.048929416208464, 6.7893590552398235, 7.824031589063431, 8.768151255146357, 9.837516916337588, 10.60897044835003, 9.660437382271986, 8.591977350556268, 7.600434549868706, 6.634555097984755, 5.735644727039546, 4.773118627438654, 3.9038314872591724, 2.9576157170936206, 2.022944791731944, 0.9572332292901373, 1.9080417759852422, 2.8923551767077633, 3.9039772528348156, 4.8689221006888035, 5.846974254252045, 7.7152438209609455, 8.643196932906587, 9.661089807381531, 10.699709564899727, 11.537998939796376, 10.468251172115151, 9.535588037584079, 8.590142249812173, 7.585319103614758, 6.704337563604704, 5.724468185736182, 4.958800526008457, 3.9584482758499124, 2.9528385204766474, 1.9178946610968746, 2.867086926481523, 3.83115393644616, 4.757967764959503, 5.732221077384529, 6.75963844256803, 8.708900801529294, 9.61276051582894, 10.666145510305673, 11.733016458377904, 12.475910509314227, 11.466158953937523, 10.482850004406497, 9.579532960969708, 8.610516244926423, 7.7066854514071625, 6.773935636802277, 5.886337788153181, 5.00468954756043, 4.018551866097869, 2.949040148122124, 3.9381677550262486, 4.853283998280888, 5.763570500189605, 6.718553487506207, 7.688122842753773, 9.621279153945657, 10.55302808540279, 11.573610428692964, 12.541729928451817, 13.411087383897128, 12.396425265325155, 11.447773541725475, 10.533279123496445, 9.597487954893591, 8.637809910031208, 7.8333875585183526, 6.866912247530521, 5.923701503819071, 4.908916583112839, 3.8849830290156895, 4.909247973075002, 5.892955480013669, 6.814467302441806, 7.69723326391499, 8.643802704448944, 10.594161104846895, 11.535686485692455, 12.576564752163035, 13.538026758682781, 14.381913397972275, 13.449176884753978, 12.48730893062875, 11.513679645650887, 10.661616854345215, 9.699925597372827, 8.80470661013491, 7.866587015865218, 6.84385947768418, 5.775948573513082, 4.849149125860826, 5.83515592618739, 6.849308636813048, 7.776732568054275, 8.7206383473434, 9.698910855026895, 11.653405737190079, 12.569909006935129, 13.571215918595383, 14.468897073895606, 14.53715183574741, 13.60482803404094, 13.461372850695657, 12.473842190259305, 11.721661669753184, 10.705081402120904, 9.808122466685596, 8.811977575873904, 7.781157330214708, 6.798733133921639, 5.800588019800852, 6.793161167142257, 7.772785480179424, 8.731742112412944, 9.73973802120752, 10.706828146476852, 12.653740407243172, 13.599561236340618, 14.529112286472518, 14.465266385725068, 13.533404393812042, 12.53002439647718, 13.46456127759105, 13.437188806235982, 12.704557382704298, 11.704155138084054, 10.72235555447532, 9.700222740430466, 8.739698267088531, 7.742751264628009, 6.815390794607938, 7.766097529590102, 8.772084400594055, 9.7509178777434, 10.710818511625613, 11.686041925882503, 13.534014475796788, 14.5307805706914, 14.542898028109237, 13.595877503483768, 12.55204520996288, 11.556810056867898, 12.501098255198267, 13.522915037974924, 13.652287447613146, 12.721866015391216, 11.67491641794555, 10.712183677576608, 9.671180030218084, 8.750901504369633, 7.854933263849608, 8.718963232253222, 9.67012559329367, 10.725828704356664, 11.63806381938648, 12.584017167242113, 14.534050308553166, 14.635198295931689, 13.61181009330255, 12.629191605815139, 11.604162587400628, 10.629677859690831, 11.597469762857143, 12.653048711630023, 13.65449791430362, 13.694012907145828, 12.622416648501884, 11.62902042532574, 10.684010302273158, 9.802127976677987, 8.834557469057124, 9.674433348759157, 10.692147458729856, 11.632999788173251, 12.57756670450761, 13.539250090969965, 14.643005944803084, 13.631320959067908, 12.670668994401993, 11.693048731220772, 10.744753549116755, 9.687361958428657, 10.662549942711028, 11.682449078851088, 12.624204484336587, 13.526269649685752, 13.611024096619957, 12.586278144009412, 11.61198512121961, 10.777544630802968, 9.776852662910258, 10.642975705612768, 11.632241044699008, 12.644986671784311, 13.64399130202495, 14.466088531691808], [13.727646012864465, 13.704805308633356, 12.859422904856544, 11.969653232592636, 10.953398469714244, 11.79140801491927, 12.797920107164753, 13.650458631941346, 14.590115769140446, 14.560044170067396, 13.512908737212328, 12.680267300948998, 11.697958811045236, 10.689566378109427, 9.701524519904142, 9.141293051515895, 9.885705725111393, 10.910078322339668, 11.801941451849354, 12.828679048199461, 12.708740235217888, 13.629024994566265, 13.849935783160547, 13.011454633572182, 11.983427898893403, 12.770609933236525, 13.748046810784942, 14.700106587803337, 14.486339930743451, 13.523236572879568, 12.56984088444969, 11.617987512135935, 10.743529960199325, 9.727102787782055, 8.774396524333488, 8.135412246967258, 8.960258047622089, 9.888579892286266, 10.753851456016825, 11.798976703170075, 11.665017582184161, 12.595173541328375, 13.551933133156965, 13.909921598344159, 12.911081165536828, 13.810209662136073, 14.75077691012046, 14.485565727819726, 13.469902739037346, 12.569208460737515, 11.548995190985245, 10.618202202196075, 9.741928630959235, 8.80040271800242, 7.826103944740659, 7.152919717684766, 7.887323781102305, 8.921115980199582, 9.828453304933658, 10.780282634605491, 10.646669537186876, 11.584083602207173, 12.606940948108953, 13.535549967613603, 13.972918431939712, 14.79353880882745, 14.430643169806556, 13.439534635404334, 12.453984285246053, 11.644367612019602, 10.683404734118792, 9.629837336375427, 8.782405741031226, 7.819857300675476, 6.806197988799066, 6.141843449098387, 6.958289870599645, 7.893407946406354, 8.842619116589214, 9.79353904910616, 9.721093885763262, 10.670055505626786, 11.669969480261335, 12.699025309401458, 13.630748594579494, 14.488192133727068, 13.442894636702956, 12.502191237421082, 11.46185817512168, 10.577828976174906, 9.628189006786739, 8.690467635962877, 7.835049414535417, 6.847704100340284, 5.827368742569483, 5.080698586992599, 5.959194008845831, 6.8880573586230325, 7.896756334726294, 8.823320233160128, 8.712991792367239, 9.774731482846395, 10.72396937928142, 11.64935629692526, 12.688185757959117, 13.445589585274503, 12.50841413148344, 11.539884370286618, 10.529904817486495, 9.60237100585678, 8.656224114201306, 7.729538012109295, 6.808276445812256, 5.879317497477132, 4.9015071275520015, 4.111812118224188, 4.938953635953686, 5.8969885254158445, 6.949074307268732, 7.762648733106563, 7.8323597946112, 8.84653184356702, 9.807714320159137, 10.814708798066713, 11.88360186371598, 12.573935577664338, 11.632314016468982, 10.585218118351307, 9.617501053919693, 8.672264542577809, 7.634760028233831, 6.705652405162781, 5.852979363757426, 4.9296001648861925, 3.949027204122963, 3.0445983115054216, 3.976699991318628, 4.921126588015949, 5.92951888157234, 6.8332184033437215, 6.9240957337764115, 7.924554733192948, 8.920806827070972, 9.93068433003688, 10.902240805019488, 11.605658508500992, 10.671214028733612, 9.603836134418142, 8.654581289034372, 7.730790505967152, 6.7741894526076365, 5.773722999197167, 4.819818393044584, 3.9259144577716967, 2.875668736007856, 1.9905391264496481, 2.9201257265502867, 3.8590810509023097, 4.910135266059491, 5.8961321734691765, 6.051874385897026, 7.105696324663391, 8.099397007822828, 9.027434599000854, 9.974698916494823, 10.563327399025907, 9.627046301795268, 8.599788112410552, 7.635217476391047, 6.69526814606697, 5.7621462608958645, 4.794578967341571, 3.8559321318088404, 2.9165335267511074, 1.9497949309235307, 0.9621177044644075, 1.889835287159972, 2.9634103254939443, 4.030227942311157, 5.033791503687629, 5.113794683136801, 6.118933758398992, 7.089637391759417, 8.07076246825861, 9.028651350852487, 9.660174351247257, 8.68703042002315, 7.744895626418734, 6.7014177384115206, 5.770762802992039, 4.793555264083233, 3.8683818053461905, 2.9294215702673227, 1.9828130299367912, 0.9958264377038643, 0.0, 0.9393834353019114, 2.0136420636514307, 3.0383352304941638, 4.053102978504601, 5.800436907061985, 6.835109440885592, 7.7792291069685175, 8.84859476815975, 9.849262807074624, 10.656263819975852, 9.587803788260134, 8.59626098757257, 7.6303815356886195, 6.73147116474341, 5.7689450651425185, 4.899657924963036, 3.953442154797485, 3.018771229435808, 1.9530596669940015, 1.0627096451411668, 1.9034330285299246, 2.915055104656977, 3.879999952510965, 4.858052106074206, 6.726321672783108, 7.6542747847287504, 8.672167659203694, 9.710787416721892, 10.758175142595627, 11.464077609819014, 10.531414475287942, 9.585968687516036, 8.581145541318623, 7.700164001308568, 6.720294623440046, 5.954626963712321, 4.954274713553777, 3.9486649581805118, 2.913721098800739, 2.0390579250433234, 2.8422317882683217, 3.7690456167816646, 4.743298929206691, 5.770716294390192, 7.719978653351458, 8.623838367651103, 9.677223362127837, 10.744094310200069, 11.77559677043654, 12.461985391641386, 11.47867644211036, 10.575359398673573, 9.606342682630288, 8.702511889111026, 7.769762074506142, 6.882164225857045, 6.000515985264295, 5.014378303801735, 3.9448665858259884, 3.110138753588049, 3.8643618501030494, 4.774648352011766, 5.729631339328369, 6.699200694575936, 8.63235700576782, 9.564105937224953, 10.584688280515127, 11.55280778027398, 12.626060952475907, 13.392251703029018, 12.443599979429338, 11.52910556120031, 10.593314392597456, 9.633636347735074, 8.829213996222217, 7.862738685234384, 6.919527941522936, 5.904743020816704, 4.880809466719554, 4.117777225795563, 4.918617799560501, 5.825545154263968, 6.708311115737152, 7.654880556271108, 9.605238956669059, 10.546764337514619, 11.587642603985199, 12.549104610504944, 13.474466106489977, 14.445003322457842, 13.483135368332613, 12.509506083354752, 11.65744329204908, 10.695752035076692, 9.800533047838774, 8.862413453569083, 7.839685915388046, 6.771775011216947, 5.844975563564692, 5.0436851789079515, 5.935381036029866, 6.787810419876436, 7.731716199165561, 8.709988706849058, 10.664483589012242, 11.580986858757292, 12.582293770417547, 13.47997492571777, 14.161304019551848, 14.559891060839146, 14.457199288399522, 13.46966862796317, 12.717488107457049, 11.700907839824769, 10.803948904389461, 9.807804013577769, 8.776983767918573, 7.794559571625504, 6.796414457504717, 6.071021384246893, 6.936603660534671, 7.835177447664092, 8.750815873029682, 9.717905998299015, 11.664818259065335, 12.610639088162781, 13.540190138294681, 13.99394765312726, 13.157556577616479, 13.485087423275385, 14.419624304389256, 14.433015243939847, 13.700383820408163, 12.69998157578792, 11.718181992179183, 10.696049178134329, 9.735524704792395, 8.738577702331874, 7.811217232311804, 7.043957746694738, 7.935902580949303, 8.854353212994548, 9.721896363447774, 10.697119777704664, 12.54509232761895, 13.541858422513563, 13.867025760298954, 12.920005235673486, 12.176197393767318, 12.511873083666103, 13.456161281996472, 14.47797806477313, 14.64811388531701, 13.71769245309508, 12.670742855649413, 11.708010115280471, 10.667006467921947, 9.746727942073498, 8.850759701553473, 7.996823449357857, 8.891084488484527, 9.879487752321458, 10.64914167120864, 11.595095019064274, 13.545128160375327, 13.806776113087565, 12.874187591843388, 11.915984311603365, 11.112604811726438, 11.584740886489037, 12.552532789655348, 13.608111738428228, 14.609560941101826, 14.689839344849691, 13.618243086205748, 12.624846863029603, 11.679836739977022, 10.797954414381852, 9.83038390676099, 8.952293565863792, 9.913106353920712, 10.853958683364107, 11.668413354750715, 12.550327942792126, 13.751162876960638, 12.739477891225462, 11.86405012731296, 10.915013906172351, 10.151107487405817, 10.642424985226862, 11.617612969509233, 12.637512105649293, 13.579267511134793, 14.522096087389613, 14.60685053432382, 13.582104581713276, 12.607811558923473, 11.773371068506833, 10.772679100614123, 9.920835922717403, 10.910101261803643, 11.865945566975167, 12.734837952268055, 13.47716638351397], [12.868365305931928, 12.765421873331446, 11.920039469554633, 11.10789388574111, 11.720837405510638, 12.675951216557497, 13.703295030175475, 14.589842067243259, 15.52949920444236, 15.499427605369306, 14.45229217251424, 13.619650736250907, 12.637342246347147, 11.628949813411339, 10.640907955206053, 9.966275141205644, 9.026425018178857, 10.050797615407133, 10.942660744916818, 11.969398341266924, 11.849459528285351, 12.76974428763373, 12.910552347858637, 12.149695286720656, 12.750866834689797, 13.655153134874752, 14.653421733795664, 15.63949002310525, 15.425723366045363, 14.46262000818148, 13.5092243197516, 12.557370947437846, 11.682913395501236, 10.666486223083966, 9.7137799596354, 8.960394336657007, 8.100977340689553, 9.02929918535373, 9.89457074908429, 10.939695996237539, 10.805736875251625, 11.73589283439584, 12.69265242622443, 13.139482365065147, 13.678520101333222, 14.691333745676637, 15.656151833131183, 15.424949163121637, 14.409286174339258, 13.508591896039427, 12.488378626287156, 11.557585637497986, 10.681312066261146, 9.739786153304332, 8.76548738004257, 7.977901807374515, 7.028043074169769, 8.061835273267047, 8.969172598001123, 9.921001927672956, 9.78738883025434, 10.724802895274637, 11.747660241176417, 12.676269260681067, 13.715528772230442, 14.74097073115315, 15.370026605108468, 14.378918070706245, 13.393367720547964, 12.583751047321513, 11.622788169420703, 10.569220771677339, 9.721789176333138, 8.759240735977388, 7.745581424100977, 7.027527790107241, 6.09900916366711, 7.034127239473818, 7.983338409656677, 8.934258342173626, 8.861813178830726, 9.81077479869425, 10.810688773328799, 11.839744602468922, 12.771467887646958, 13.83727605756216, 14.382278072004867, 13.441574672722993, 12.401241610423591, 11.517212411476818, 10.56757244208865, 9.629851071264788, 8.774432849837329, 7.787087535642195, 6.766752177871394, 5.975892398674554, 5.099913301913295, 6.028776651690497, 7.037475627793758, 7.964039526227594, 7.853711085434703, 8.91545077591386, 9.864688672348885, 10.790075589992725, 11.828905051026581, 12.856484838201869, 13.44779756678535, 12.47926780558853, 11.469288252788406, 10.541754441158691, 9.595607549503217, 8.668921447411206, 7.747659881114167, 6.818700932779043, 5.840890562853913, 5.007005929906143, 4.079672929021151, 5.037707818483309, 6.089793600336196, 6.903368026174027, 6.973079087678665, 7.987251136634484, 8.948433613226602, 9.955428091134177, 10.99143195857134, 12.042221966244808, 12.571697451770895, 11.52460155365322, 10.556884489221604, 9.61164797787972, 8.574143463535743, 7.6450358404646925, 6.792362799059338, 5.868983600188105, 4.888410639424874, 3.983981746807333, 3.1174192843860933, 4.061845881083413, 5.070238174639805, 5.973937696411186, 6.064815026843876, 7.065274026260412, 8.061526120138439, 9.071403623104347, 9.966076109691944, 11.016071139307812, 11.610597464035525, 10.543219569720055, 9.593964724336283, 8.670173941269063, 7.713572887909548, 6.713106434499078, 5.759201828346495, 4.865297893073609, 3.815052171309768, 2.9299225617515594, 2.0608450196177515, 2.999800343969774, 4.050854559126956, 5.036851466536641, 5.112490950595115, 6.16631288936148, 7.160013572520917, 8.088051163698943, 9.035315481192912, 10.039860013687727, 10.566429737097181, 9.539171547712465, 8.57460091169296, 7.634651581368881, 6.701529696197776, 5.733962402643482, 4.795315567110752, 3.8559169620530187, 2.889178366225442, 1.9015011397663188, 1.0026953450601017, 2.0685465395245837, 3.1353641563417964, 4.094408068385718, 4.17441124783489, 5.1795503230970805, 6.150253956457505, 7.1313790329566995, 8.089267915550575, 9.1001478030648, 9.626413855325062, 8.684279061720645, 7.640801173713432, 6.71014623829395, 5.732938699385144, 4.807765240648101, 3.868805005569234, 2.9221964652387027, 1.9352098730057756, 0.9393834353019114, 0.0, 1.0742586283495195, 2.0989517951922525, 3.1137195432026896, 4.861053471760074, 5.895726005583681, 6.839845671666606, 7.909211332857837, 8.90987937177271, 9.883507241408834, 10.527187223562043, 9.53564442287448, 8.56976497099053, 7.670854600045321, 6.70832850044443, 5.839041360264948, 4.892825590099396, 3.9581546647377195, 2.892443102295913, 1.9483629939505345, 0.9640495932280132, 1.9756716693550658, 2.9406165172090537, 3.918668670772295, 5.786938237481196, 6.714891349426838, 7.732784223901781, 8.77140398141998, 9.818791707293714, 10.839540916956778, 11.470797910589852, 10.525352122817946, 9.520528976620533, 8.63954743661048, 7.6596780587419575, 6.894010399014232, 5.893658148855688, 4.888048393482423, 3.8531045341026506, 2.924711273852691, 1.90284835296641, 2.829662181479753, 3.8039154939047792, 4.83133285908828, 6.7805952180495455, 7.684454932349191, 8.737839926825925, 9.804710874898156, 10.836213335134627, 11.84596489051133, 12.41805987741227, 11.514742833975482, 10.545726117932197, 9.641895324412937, 8.709145509808053, 7.821547661158956, 6.939899420566206, 5.953761739103646, 4.8842500211279, 3.8775776893844416, 2.9249784148011377, 3.835264916709855, 4.790247904026457, 5.7598172592740235, 7.692973570465909, 8.62472250192304, 9.645304845213214, 10.613424344972067, 11.686677517173994, 12.701339635745967, 13.382983414731248, 12.46848899650222, 11.532697827899366, 10.573019783036983, 9.768597431524128, 8.802122120536296, 7.858911376824848, 6.844126456118616, 5.820192902021466, 4.885216161591956, 3.9792343642585895, 4.8861617189620565, 5.76892768043524, 6.715497120969195, 8.665855521367147, 9.607380902212707, 10.648259168683285, 11.609721175203031, 12.535082671188064, 13.53112892911183, 14.422518803634523, 13.448889518656662, 12.59682672735099, 11.635135470378602, 10.739916483140686, 9.801796888870994, 8.779069350689957, 7.7111584465188585, 6.784358998866603, 5.811124114704344, 4.9959976007279545, 5.848426984574525, 6.79233276386365, 7.770605271547145, 9.725100153710331, 10.641603423455381, 11.642910335115634, 12.540591490415856, 13.553673778844924, 14.463155298831417, 15.396582723701432, 14.40905206326508, 13.656871542758958, 12.640291275126678, 11.743332339691372, 10.747187448879682, 9.716367203220486, 8.733943006927415, 7.735797892806628, 6.838460320043286, 5.99722022523276, 6.895794012362181, 7.811432437727771, 8.778522562997102, 10.725434823763424, 11.67125565286087, 12.600806702992768, 13.134666946194724, 13.982538667306226, 14.424470858577296, 15.359007739691167, 15.372398679241757, 14.639767255710073, 13.63936501108983, 12.657565427481096, 11.635432613436242, 10.674908140094308, 9.677961137633785, 8.750600667613716, 7.8113966824911305, 6.996519145647392, 7.914969777692637, 8.782512928145865, 9.757736342402755, 11.60570889231704, 12.602474987211652, 13.007745053366419, 12.06072452874095, 13.001179483457065, 13.451256518968014, 14.395544717298383, 15.41736150007504, 15.587497320618922, 14.657075888396992, 13.610126290951326, 12.647393550582384, 11.60638990322386, 10.68611137737541, 9.739898033960348, 8.76426238515425, 7.9517010531826156, 8.940104317019546, 9.709758235906731, 10.655711583762365, 12.605744725073418, 12.947495406155028, 12.01490688491085, 11.05670360467083, 11.937586901416186, 12.524124321790948, 13.49191622495726, 14.54749517373014, 15.548944376403737, 15.629222780151604, 14.557626521507661, 13.564230298331516, 12.619220175278935, 11.725351687202684, 10.719522239167864, 9.719732501660186, 8.973722918618801, 9.914575248062196, 10.729029919448806, 11.610944507490217, 12.891882170028103, 11.880197184292927, 11.004769420380425, 10.055733199239816, 10.976089577095564, 11.581808420528773, 12.556996404811144, 13.576895540951204, 14.518650946436704, 15.461479522691526, 15.546233969625733, 14.521488017015189, 13.547194994225386, 12.700768341327665, 11.661817433020998, 10.688274858513797, 10.048341914952116, 10.926562131673256, 11.795454516966146, 12.53778294821206], [11.819101882916566, 11.936277027569224, 11.249147027930473, 12.182152514090628, 12.795096033860156, 13.750209844907015, 14.777553658524994, 15.664100695592778, 16.603757832791878, 16.573686233718828, 15.526550800863761, 14.69390936460043, 13.691365085861522, 12.682972652925713, 11.694930794720428, 10.897210872164795, 9.957360749138008, 9.223072024500341, 9.972504631351764, 10.99924222770187, 10.80019610526999, 11.720480864618368, 12.239659906234476, 13.188197127438167, 13.825125463039315, 14.72941176322427, 15.727680362145183, 16.713748651454768, 16.499981994394883, 15.536878636531002, 14.583482948101123, 13.631629575787368, 12.73693623501561, 11.72050906259834, 10.767802799149774, 9.891330067616158, 9.031913071648704, 8.192747188036062, 8.924414635519236, 9.969539882672485, 9.756473452236264, 10.686629411380478, 11.64338900320907, 12.609554723372723, 13.608395156180054, 14.621208800523469, 15.646777367100773, 16.499207791471157, 15.483544802688778, 14.582850524388949, 13.562637254636678, 12.631844265847509, 11.73533490577552, 10.793808992818706, 9.819510219556944, 8.908837538333666, 7.95897880512892, 7.1793453430107945, 7.99901648443607, 8.9455345270912, 8.738125407238979, 9.675539472259276, 10.698396818161056, 11.627005837665706, 12.666265349215081, 13.691707308137788, 14.64018808559036, 15.453176699055765, 14.467626348897484, 13.658009675671034, 12.697046797770223, 11.64347940002686, 10.775812015847512, 9.813263575491762, 8.79960426361535, 7.958463521066392, 7.029944894626261, 6.151637309217566, 7.0131822960916255, 7.884994919158265, 7.812549755815365, 8.76151137567889, 9.761425350313438, 10.790481179453561, 11.722204464631597, 12.7880126345468, 13.789072605839175, 14.515833301072513, 13.475500238773112, 12.591471039826338, 11.64183107043817, 10.70410969961431, 9.828455689351703, 8.84111037515657, 7.820775017385769, 6.919655925582922, 6.030849032872446, 5.101985683095244, 6.067319514228706, 6.914776103212233, 6.804447662419342, 7.866187352898499, 8.815425249333524, 9.740812166977364, 10.77964162801122, 11.807221415186508, 12.74439686897757, 13.55352643393805, 12.543546881137926, 11.616013069508211, 10.669866177852738, 9.743180075760728, 8.801682720628541, 7.8727237722934165, 6.894913402368286, 5.950769456814511, 5.023436455929519, 4.103560696687631, 5.119637486771144, 5.8541046031586665, 5.923815664663304, 6.9379877136191235, 7.899170190211241, 8.906164668118816, 9.917173330221821, 10.96796333789529, 11.89740845451164, 12.598860182002738, 11.631143117571122, 10.68590660622924, 9.648402091885263, 8.719294468814214, 7.866621427408858, 6.943242228537623, 5.942433478939248, 4.988254331682532, 4.0611828112944615, 3.127698759287736, 4.100082061074753, 4.9246742733958255, 5.007651462882469, 6.008110462299006, 7.004362556177031, 8.01424005914294, 8.891817481342425, 9.941812510958293, 10.92111700762076, 11.617478198069573, 10.668223352685802, 9.744432569618583, 8.787831516259068, 7.787365062848599, 6.833460456696016, 5.939556521423127, 4.889310799659286, 3.934195146626758, 3.0046085465261196, 2.0656532221740966, 3.049520361637267, 3.9875880435212805, 4.038232322245595, 5.0920542610119615, 6.0857549441713985, 7.013792535349424, 7.961056852843393, 8.965601385338209, 9.901882482568848, 10.613430176061984, 9.648859540042478, 8.7089102097184, 7.775788324547296, 6.8082210309930025, 5.869574195460272, 4.930175590402539, 3.9634369945749612, 2.975759768115838, 2.0678629495090366, 0.9942879111750643, 2.0611055279922774, 3.0201494400361986, 3.1001526194853697, 4.105291694747561, 5.075995328107986, 6.05712040460718, 7.015009287201057, 8.025889174715282, 8.999033105939388, 9.758537690070165, 8.715059802062951, 7.784404866643469, 6.807197327734664, 5.882023868997621, 4.9430636339187535, 3.996455093588222, 3.009468501355295, 2.0136420636514307, 1.0742586283495195, 0.0, 1.024693166842733, 2.03946091485317, 3.9160914241885703, 4.950763958012177, 5.894883624095103, 6.964249285286334, 7.948751934493469, 8.922379804129593, 9.99083983584531, 10.609903051224, 9.64402359934005, 8.74511322839484, 7.782587128793949, 6.913299988614467, 5.967084218448916, 5.032413293087239, 3.9667017306454326, 3.0226216223000537, 2.0383082215775326, 1.030709621783562, 1.9956544696375498, 2.9737066232007914, 4.859599249387209, 5.7875523613328514, 6.805445235807794, 7.844064993325992, 8.891452719199727, 9.878413479677537, 10.81107661420861, 11.599610751167466, 10.594787604970053, 9.71380606496, 8.733936687091477, 7.9682690273637515, 6.9679167772052075, 5.9623070218319425, 4.92736316245217, 3.9989699022022105, 2.9771069813159294, 2.0633610187003724, 2.931007392745681, 3.9039938709942934, 5.853256229955559, 6.7571159442552045, 7.810500938731938, 8.877371886804168, 9.908874347040639, 10.918625902417343, 11.758338581031028, 12.589001462325001, 11.619984746281716, 10.716153952762458, 9.783404138157572, 8.895806289508476, 8.014158048915725, 7.0280203674531645, 5.9585086494774195, 4.951836317733961, 3.999237043150657, 3.0689637539304746, 3.917339802867359, 4.886909158114925, 6.820065469306811, 7.697383513829054, 8.717965857119228, 9.686085356878081, 10.759338529080008, 11.774000647651981, 12.72265237125166, 13.542747624851739, 12.606956456248884, 11.647278411386505, 10.842856059873647, 9.876380748885817, 8.933170005174366, 7.9183850844681345, 6.894451530370985, 5.959474789941475, 5.053492992608109, 4.119860556182676, 4.896019579276142, 5.842589019810097, 7.7929474202080495, 8.708134873511787, 9.7209201805893, 10.682382187109045, 11.607743683094078, 12.603789941017844, 13.566713073881878, 14.52314814700618, 13.671085355700509, 12.709394098728124, 11.814175111490204, 10.876055517220513, 9.853327979039475, 8.785417074868377, 7.8586176272161214, 6.885382743053864, 6.070256229077474, 5.082125821795144, 5.963187918101427, 6.897697170388048, 8.852192052551233, 9.74235739475446, 10.715571347021648, 11.61325250232187, 12.626334790750938, 13.535816310737431, 14.540776993948786, 15.483310691614598, 14.731130171108477, 13.7145499034762, 12.817590968040891, 11.8214460772292, 10.790625831570004, 9.808201635276934, 8.810056521156147, 7.912718948392805, 7.0714788535822795, 6.129492849582801, 6.982287591965549, 7.905614461838004, 9.852526722604326, 10.78752040011628, 11.673467714898782, 12.585918405228997, 13.517780397142023, 14.536580959750554, 15.471117840864425, 16.446657307591277, 15.714025884059595, 14.713623639439351, 13.731824055830614, 12.70969124178576, 11.749166768443827, 10.752219765983304, 9.824859295963234, 8.885655310840649, 8.07077777399691, 7.148668614913257, 7.953368082383642, 8.928591496640532, 10.776564046554817, 11.718739734467063, 12.207645284739952, 12.991660259700101, 13.932115214416218, 14.505279358482388, 15.449567556812758, 16.471384339589413, 16.66175594896844, 15.73133451674651, 14.684384919300845, 13.721652178931903, 12.680648531573379, 11.760370005724928, 10.814156662309866, 9.838521013503769, 9.025959681532134, 8.173803154240167, 8.880613390144509, 9.826566738000142, 11.776599879311195, 11.977339292589974, 11.18718129400406, 11.98763933562998, 12.868522632375338, 13.578147161305322, 14.545939064471634, 15.601518013244513, 16.602967215918113, 16.703481408501123, 15.63188514985718, 14.638488926681035, 13.693478803628453, 12.799610315552203, 11.793780867517382, 10.793991130009704, 10.04798154696832, 9.243682806438036, 9.899885073686583, 10.781799661727995, 11.921726056463049, 10.910041070727873, 10.177043829473634, 10.986668930198967, 11.907025308054717, 12.635831260043147, 13.611019244325519, 14.630918380465578, 15.572673785951078, 16.53573815104105, 16.62049259797525, 15.595746645364708, 14.621453622574904, 13.775026969677183, 12.736076061370516, 11.762533486863315, 11.122600543301635, 10.255669690049096, 10.966309671203923, 11.708638102449838], [10.794408716073836, 11.006905557648048, 11.920544741592204, 12.911419883064784, 13.720692116307104, 14.675805927353963, 15.703149740971941, 16.626427392608992, 17.566084529808094, 17.598379400561562, 16.551243967706494, 15.673114800521397, 14.60705128640989, 13.598658853474081, 12.610616995268796, 11.766611776704737, 10.809226297731145, 9.949221974772534, 8.948295847163678, 9.975033443513784, 9.775502938427259, 10.695787697775636, 11.598070297697, 12.546607518900691, 13.511355255980744, 14.500589882490555, 15.564018586988817, 16.556014400782463, 17.524675161237617, 16.561571803373734, 15.608176114943856, 14.6563227426301, 13.652622435563979, 12.636195263146709, 11.683488999698142, 10.779055913861681, 9.883778620241841, 8.955456775577664, 7.900205851331148, 8.945331098484399, 8.731780285393532, 9.661936244537745, 10.618695836366335, 11.584861556529988, 12.58370198933732, 13.596515633680735, 14.62208420025804, 15.643972709684984, 16.50823796953151, 15.607543691231681, 14.587330421479411, 13.656537432690241, 12.705470027804768, 11.709495193367074, 10.735196420105312, 9.796563384579189, 8.846704651374443, 7.990010669736406, 6.974807700247982, 7.920841360248465, 7.713432240396246, 8.650846305416543, 9.673703651318323, 10.602312670822974, 11.641572182372348, 12.667014141295056, 13.615494918747627, 14.60660345314985, 15.492319515740217, 14.682702842513766, 13.721739964612956, 12.668172566869593, 11.786524586279775, 10.823976145924025, 9.810316834047613, 8.846189367311917, 7.917670740871785, 6.982552665065076, 5.988973511903537, 6.860301752315531, 6.787856588972632, 7.736818208836157, 8.736732183470705, 9.765788012610829, 10.697511297788864, 11.763319467704068, 12.764379438996441, 13.650540330466121, 14.500193405615844, 13.61616420666907, 12.666524237280903, 11.728802866457043, 10.839168259783966, 9.851822945588832, 8.831487587818032, 7.930368496015185, 6.987415844027766, 6.058552494250565, 5.043110730040618, 5.8900829363695, 5.77975449557661, 6.841494186055766, 7.790732082490791, 8.716119000134631, 9.754948461168487, 10.782528248343773, 11.719703702134836, 12.688233463331658, 13.568240047980659, 12.640706236350944, 11.69455934469547, 10.76787324260346, 9.812395291060804, 8.88343634272568, 7.905625972800549, 6.961482027246774, 6.034149026361782, 5.060127507842951, 4.095428702583056, 4.829411436315933, 4.899122497820571, 5.91329454677639, 6.874477023368508, 7.881471501276083, 8.892480163379087, 9.943270171052555, 10.872715287668905, 11.87858434570984, 12.655836284413855, 11.710599773071973, 10.673095258727995, 9.743987635656946, 8.89131459425159, 7.967935395380357, 6.953146049371511, 5.998966902114795, 5.0718953817267245, 4.084265570443056, 3.0758732768866643, 3.899981106553092, 3.982958296039736, 4.983417295456272, 5.979669389334298, 6.989546892300206, 7.867124314499691, 8.917119344115559, 9.896423840778025, 10.897202361776674, 11.692916519528534, 10.769125736461316, 9.8125246831018, 8.812058229691331, 7.8581536235387475, 6.964249688265861, 5.91400396650202, 4.944907717059021, 4.015321116958383, 3.07636579260636, 2.0253115774491786, 2.9628948766785475, 3.013539155402862, 4.067361094169228, 5.061061777328665, 5.98909936850669, 6.936363686000659, 7.940908218495475, 8.877189315726115, 9.893154339769085, 10.67355270688521, 9.733603376561133, 8.800481491390029, 7.832914197835734, 6.894267362303004, 5.95486875724527, 4.988130161417694, 4.000452934958571, 3.0925561163517696, 2.0189810780177972, 1.0368967438041894, 1.9954562731934655, 2.0754594526426366, 3.080598527904828, 4.051302161265253, 5.0324272377644474, 5.990316120358324, 7.001196007872549, 7.974339939096656, 8.916474732701072, 9.739752968905684, 8.809098033486201, 7.831890494577396, 6.906717035840353, 5.967756800761486, 5.021148260430954, 4.034161668198028, 3.0383352304941638, 2.0989517951922525, 1.024693166842733, 0.0, 1.014767748010437, 2.9738572816705746, 4.008529815494182, 4.952649481577107, 6.022015142768338, 6.924058767650736, 7.89768663728686, 8.966146669002578, 9.957689469690141, 10.668716766182783, 9.769806395237573, 8.807280295636682, 7.9379931554572, 6.991777385291648, 6.043683433556848, 4.977971871115042, 4.027163324419937, 3.042849923697416, 2.0312278475703636, 1.0662829997163756, 2.0314724806827957, 3.9173651068692132, 4.845318218814856, 5.863211093289799, 6.901830850807996, 7.949218576681731, 8.853720312834804, 9.786383447365877, 10.731829235137782, 11.619480771812785, 10.738499231802733, 9.75862985393421, 8.992962194206484, 7.933803401921986, 6.928193646548721, 5.893249787168948, 4.944057521784299, 3.902703063762876, 2.975889235249533, 2.001635922824507, 2.9617597284762978, 4.911022087437563, 5.814881801737209, 6.868266796213943, 7.9351377442861715, 8.966640204522642, 9.91273423241017, 10.733645414188295, 11.760795856976156, 12.64467791312445, 11.74084711960519, 10.808097305000304, 9.920499456351209, 8.980044673632504, 7.99126636025189, 6.920835346493636, 5.877432400180908, 4.924833125597604, 3.9814919704796354, 2.987968332946185, 3.957537688193751, 5.890693999385637, 6.755149371311059, 7.775731714601233, 8.743851214360086, 9.817104386562013, 10.831766505133986, 11.698568951507273, 12.636243347605603, 13.631649623091619, 12.671971578229236, 11.86754922671638, 10.90107391572855, 9.895496702190583, 8.88071178148435, 7.856778227387201, 6.885070872388422, 5.979089075055056, 5.007192728097702, 3.966648109354968, 4.913217549888923, 6.863575950286876, 7.76590073099379, 8.778686038071303, 9.74014804459105, 10.665509540576082, 11.661555798499847, 12.624478931363882, 13.616643869760045, 14.571933760858657, 13.734087265570855, 12.838868278332937, 11.838382214236729, 10.815654676055692, 9.747743771884593, 8.820944324232338, 7.81097882550081, 6.983998720156826, 5.96945799371017, 5.033816448180254, 5.968325700466874, 7.922820582630059, 8.800123252236464, 9.773337204503651, 10.671018359803876, 11.684100648232944, 12.593582168219434, 13.59854285143079, 14.576806414368463, 15.631978576266626, 14.739243070318931, 13.832173681962727, 12.783772774245417, 11.75295252858622, 10.77052833229315, 9.772383218172363, 8.838315030839752, 7.975781653731345, 7.0168250214978265, 6.052916122044375, 6.9762429919168305, 8.923155252683152, 9.845286257598284, 10.731233572380786, 11.643684262711002, 12.575546254624028, 13.594346817232559, 14.52888369834643, 15.54015303034514, 16.51259688122886, 15.738316806282082, 14.69415075284683, 13.672017938801977, 12.711493465460043, 11.71454646299952, 10.77356972442501, 9.811251393287597, 8.975080574145977, 8.00931215233223, 7.023996612462469, 7.9992200267193585, 9.847192576633642, 10.776505591949066, 11.716381142613677, 12.663401667239146, 13.556905438473189, 14.552140591568172, 15.496428789898541, 16.518245572675198, 17.52327731267393, 16.693661213762727, 15.646711616317061, 14.68397887594812, 13.642975228589595, 12.710877118273878, 11.739752744756814, 10.764117095950716, 9.9302624816812, 8.99982578233327, 7.951241920223334, 8.897195268078967, 10.84722840939002, 10.953130508401888, 11.856621715736129, 12.83924020322354, 13.737923536915279, 14.49383336185369, 15.461625265020002, 16.51720421379288, 17.51865341646648, 17.66580810551734, 16.594211846873396, 15.600815623697251, 14.65580550064467, 13.72520639799915, 12.71937694996433, 11.719587212456652, 10.855932849543162, 9.915080520099767, 8.970513603765408, 9.852428191806819, 10.897517272274962, 9.885832286539786, 10.846484251205702, 11.838534478792104, 12.776426212594657, 13.551517460591516, 14.526705444873887, 15.546604581013947, 16.488359986499447, 17.533765474674656, 17.582819294991467, 16.558073342380922, 15.58378031959112, 14.700623052124131, 13.661672143817464, 12.688129569310263, 11.930551845876478, 10.927067403710828, 10.036938201282748, 10.779266632528662], [9.779640968063397, 10.736324295755223, 11.573815427990567, 12.56469056946315, 13.526616937149468, 14.465024052797375, 15.492367866415353, 16.507251971142985, 17.446909108342084, 18.343635999756867, 17.2965005669018, 16.355073065664406, 15.2890095515529, 14.28061711861709, 13.292575260411805, 12.448570041847747, 11.491184562874155, 10.631180239915542, 9.630254112306686, 9.00286773038054, 8.76073519041682, 9.681019949765199, 10.583302549686564, 11.531839770890256, 12.49658750797031, 13.48582213448012, 14.549250838978383, 15.54124665277203, 16.59300927856544, 17.30682840256904, 16.35343271413916, 15.39339064043401, 14.334580700706988, 13.318153528289718, 12.365447264841151, 11.46101417900469, 10.565736885384851, 9.637415040720674, 8.582164116474157, 7.944106122493295, 7.717012537383095, 8.647168496527309, 9.6039280883559, 10.570093808519553, 11.568934241326884, 12.5817478856703, 13.607316452247604, 14.629204961674548, 15.593304509088988, 16.39070478106046, 15.37049151130819, 14.43969852251902, 13.387428292947778, 12.391453458510084, 11.417154685248322, 10.478521649722198, 9.528662916517453, 8.671968934879414, 7.65676596539099, 6.906073612238028, 6.698664492385809, 7.6360785574061065, 8.658935903307887, 9.587544922812537, 10.626804434361912, 11.652246393284619, 12.60072717073719, 13.591835705139413, 14.577386055297694, 15.554111446132158, 14.597255319016258, 13.529079988991757, 12.565176707895631, 11.602628267539881, 10.572177961423805, 9.528147632454926, 8.599629006014794, 7.664510930208085, 6.670931777046546, 5.845534004305095, 5.773088840962195, 6.72205046082572, 7.721964435460269, 8.751020264600392, 9.682743549778428, 10.74855171969363, 11.749611690986006, 12.635772582455687, 13.615398625756532, 14.507349908024107, 13.55770993863594, 12.594273268646445, 11.669597641977862, 10.682252327782729, 9.661916970011928, 8.634051401395451, 7.672341979187715, 6.743478629410514, 5.725068995183626, 4.875315188359063, 4.764986747566173, 5.82672643804533, 6.775964334480355, 7.701351252124194, 8.74018071315805, 9.767760500333338, 10.704935954124402, 11.673465715321223, 12.683445268121346, 13.53189193770598, 12.585745046050507, 11.633343644792863, 10.642824673254701, 9.713865724919577, 8.736055354994447, 7.756817832296642, 6.8294848314116505, 5.802022511066015, 4.7773869677260645, 3.8146436883054964, 3.884354749810134, 4.898526798765953, 5.859709275358071, 6.8667037532656465, 7.87771241536865, 8.928502423042119, 9.857947539658468, 10.863816597699403, 11.825240805306798, 12.72536752108241, 11.68786300673843, 10.758755383667381, 9.906082342262026, 8.875174056867595, 7.845400103162335, 6.891220955905619, 5.867231186776593, 4.826160573666121, 3.817768280109729, 2.8852133585426554, 2.968190548029299, 3.9686495474458354, 4.964901641323861, 5.974779144289769, 6.852356566489254, 7.902351596105122, 8.881656092767589, 9.882434613766238, 10.862321040421477, 11.783893484471752, 10.827292431112237, 9.826825977701766, 8.872921371549184, 7.874963062359619, 6.824717340595778, 5.853720175687638, 4.924133575587, 3.985178251234977, 2.9341240360777956, 1.9481271286681103, 1.998771407392425, 3.052593346158791, 4.0462940293182275, 4.974331620496253, 5.921595937990222, 6.926140470485039, 7.862421567715678, 8.878386591758648, 9.842957227778154, 10.74837112457157, 9.815249239400465, 8.847681945846173, 7.909035110313441, 6.969636505255708, 6.002897909428132, 5.015220682969009, 4.107323864362207, 3.0337488260282344, 2.0140956263295697, 0.9806885251830285, 1.0606917046321995, 2.065830779894391, 3.036534413254816, 4.01765948975401, 4.975548372347886, 5.986428259862111, 6.959572191086218, 7.901706984690635, 8.945184872697848, 9.82386578149664, 8.846658242587834, 7.921484783850791, 6.982524548771924, 6.035916008441392, 5.048929416208465, 4.053102978504601, 3.1137195432026896, 2.03946091485317, 1.014767748010437, 0.0, 1.9590895336601377, 2.993762067483745, 3.9378817335666705, 5.0072473947579015, 5.909291019640298, 6.8829188892764215, 7.9513789209921395, 8.942921721679703, 9.874148669974947, 10.784574143248012, 9.822048043647118, 8.952760903467638, 8.006545133302087, 6.9721573200760725, 5.906445757634266, 4.9556372109391615, 3.9713238102166404, 2.959701734089588, 1.9947568862356004, 1.016704732672359, 2.9025973588587766, 3.830550470804419, 4.848443345279362, 5.887063102797559, 6.934450828671294, 7.838952564824366, 8.771615699355438, 9.717061487127344, 10.74816225646587, 11.673283586717876, 10.773397601944646, 9.933271864298536, 8.86227728844121, 7.856667533067944, 6.8217236736881715, 5.872531408303523, 4.8311769502821, 3.9043631217687578, 2.9301098093437314, 1.946991980465861, 3.8962543394271263, 4.800114053726772, 5.853499048203506, 6.920369996275735, 7.9518724565122065, 8.897966484399731, 9.718877666177857, 10.746028108965717, 11.715044825009002, 12.675631474520333, 11.78633545658289, 10.860809126443261, 9.908518560151727, 8.919740246771113, 7.8493092330128595, 6.805906286700131, 5.853307012116828, 4.90996585699886, 3.9164422194654094, 2.9498712994593905, 4.895596802542083, 5.740381623300622, 6.760963966590796, 7.729083466349649, 8.802336638551576, 9.81699875712355, 10.683801203496834, 11.621475599595165, 12.673650028826577, 13.606755933144381, 12.845787378298965, 11.841383585820601, 10.823970588709807, 9.809185668003575, 8.785252113906425, 7.813544758907645, 6.907562961574279, 5.935666614616927, 4.8951219958741925, 4.005447473427146, 5.868478753443322, 6.7511329829833535, 7.763918290060867, 8.725380296580614, 9.650741792565647, 10.646788050489413, 11.609711183353447, 12.601876121749607, 13.557166012848219, 14.525843835641643, 13.817106429915523, 12.766856100755954, 11.744128562574916, 10.676217658403818, 9.749418210751562, 8.739452712020034, 7.912472606676051, 6.897931880229395, 5.962290334699478, 5.060555624005096, 6.927723385786504, 7.785355504226027, 8.758569456493214, 9.656250611793439, 10.669332900222507, 11.578814420209, 12.583775103420354, 13.562038666358024, 14.617210828256187, 15.53099964038972, 14.760647568481952, 13.712246660764642, 12.681426415105445, 11.699002218812375, 10.700857104691588, 9.766788917358976, 8.90425554025057, 7.945298908017051, 6.9813900085636, 6.068472915455053, 7.928058055839598, 8.830518509587847, 9.71646582437035, 10.628916514700565, 11.560778506613591, 12.579579069222122, 13.514115950335993, 14.525385282334701, 15.49782913321842, 16.498231377838664, 15.622624639366055, 14.600491825321201, 13.639967351979267, 12.643020349518745, 11.702043610944235, 10.739725279806821, 9.903554460665202, 8.937786038851455, 7.952470498981693, 7.117284600183092, 8.894164704108878, 9.76173784393863, 10.70161339460324, 11.64863391922871, 12.542137690462752, 13.537372843557735, 14.481661041888104, 15.503477824664762, 16.508509564663495, 17.438930996885425, 16.575185502836284, 15.612452762467344, 14.57144911510882, 13.639351004793102, 12.668226631276038, 11.692590982469941, 10.858736368200425, 9.928299668852494, 8.87971580674256, 8.15606550406163, 9.907022608714218, 10.740720095854948, 11.722077385339134, 12.65265484329883, 13.605730272503632, 14.464505040734801, 15.45522853639679, 16.499542410454996, 17.550648137114248, 18.4748812359355, 17.52268573339262, 16.529289510216476, 15.584279387163894, 14.653680284518375, 13.647850836483554, 12.648061098975877, 11.784406736062389, 10.843554406618994, 9.898987490284634, 9.111298427789482, 10.004642279084262, 10.567790551682794, 11.52844251634871, 12.520492743935113, 13.458384477737667, 14.233475725734525, 15.208663710016896, 16.228562846156954, 17.170318251642456, 18.215723739817665, 18.51129318151069, 17.486547228900147, 16.512254206110345, 15.629096938643356, 14.590146030336689, 13.616603455829488, 12.859025732395704, 11.855541290230054, 10.965412087801974, 10.038136868511325], [9.923637156764872, 10.880320484456696, 11.717811616692039, 12.708686758164621, 13.67061312585094, 14.609020241498847, 15.636364055116825, 16.651248159844457, 17.590905297043555, 18.61533157478916, 18.435517937467786, 17.445100583116528, 16.380047858666348, 15.37165542573054, 14.401181885107524, 13.630502510502001, 12.73639390757863, 11.73964713263068, 10.799015234880988, 9.973484533098983, 8.904731379118296, 9.825016138466673, 10.727298738388036, 11.675835959591728, 12.640583696671781, 13.629818323181592, 14.693247027679854, 15.685242841473501, 16.690092339233104, 17.703507046233582, 18.312522247799297, 17.352480174094147, 16.293670234367127, 15.277243061949857, 14.32453679850129, 13.42010371266483, 12.52482641904499, 11.596504574380813, 10.541253650134296, 9.903195656153434, 7.8610087260845685, 8.791164685228782, 9.747924277057372, 10.714089997221025, 11.712930430028356, 12.723988535007654, 13.695729447279263, 14.717617956706206, 15.673655147527, 16.680909868057995, 17.32958104496833, 16.398788056179157, 15.346517826607917, 14.350542992170222, 13.376244218908461, 12.437611183382337, 11.487752450177592, 10.631058468539553, 9.61585549905113, 8.865163145898167, 6.842660681087283, 7.78007474610758, 8.80293209200936, 9.73154111151401, 10.71521742939357, 11.740659388316278, 12.68914016576885, 13.680248700171072, 14.657736693735707, 15.63446208457017, 16.476937351654747, 15.423369953911386, 14.52426624155577, 13.56171780120002, 12.531267495083943, 11.487237166115065, 10.558718539674933, 9.623600463868224, 8.630021310706685, 7.804623537965233, 5.917085029663669, 6.866046649527194, 7.830535827025856, 8.85959165616598, 9.73295550763323, 10.798763677548433, 11.799823648840809, 12.68598454031049, 13.665610583611334, 14.609855056725303, 15.421721624322696, 14.484000253498836, 13.628687175638, 12.641341861442866, 11.621006503672065, 10.59314093505559, 9.631431512847854, 8.702568163070652, 7.684158528843764, 6.834404722019201, 4.9089829362676465, 5.935297829610917, 6.884535726045942, 7.809922643689782, 8.790392671012853, 9.817972458188141, 10.755147911979204, 11.723677673176025, 12.733657225976149, 13.628572634633267, 14.449756731737263, 13.523070629645254, 12.601914206914838, 11.672955258579714, 10.695144888654584, 9.71590736595678, 8.788574365071788, 7.761112044726154, 6.7364765013862025, 5.773733221965634, 3.9649521934725978, 4.936462493524944, 5.897644970117062, 6.904639448024637, 7.8196209333619615, 8.870410941035429, 9.79985605765178, 10.78804022964774, 11.749464437255135, 12.686818726711305, 13.428292645769789, 12.49918502269874, 11.646511981293385, 10.730037071948177, 9.749464111184947, 8.845035218567407, 7.82632072043673, 6.7852501073262586, 5.776857813769867, 4.844302892202793, 2.953720820188006, 3.9541798196045423, 4.950431913482568, 5.960309416448476, 6.794265084482565, 7.844260114098433, 8.8235646107609, 9.806658245714575, 10.786544672369814, 11.745344690100648, 12.567722070143596, 11.567255616733124, 10.613351010580542, 9.72635136483368, 8.67610564306984, 7.790976033511633, 6.883223109247138, 5.944267784895115, 4.8932135697379335, 3.9072166623282483, 1.9843016795511317, 3.03063431765373, 3.993733011188447, 4.921770602366472, 5.863504455983533, 6.854290356104446, 7.790571453335086, 8.802610223706985, 9.76718085972649, 10.707130190050568, 11.555678878431824, 10.588111584877531, 9.6494647493448, 8.710066144287067, 7.750231837985516, 6.762554611526393, 5.863748816820175, 4.9103793353636345, 3.9731851599897077, 2.9397780588431663, 1.0462219767909062, 2.04387175138933, 2.960758045203152, 3.9418831217023462, 4.8997720042962225, 5.910651891810447, 6.883795823034554, 7.8259306166389715, 8.869408504646184, 9.800063440065667, 10.587087881619192, 9.66191442288215, 8.722954187803282, 7.77634564747275, 6.7893590552398235, 5.800436907061985, 4.861053471760074, 3.9160914241885703, 2.9738572816705746, 1.9590895336601377, 0.0, 1.0346725338236074, 1.9787921999065328, 3.048157861097764, 4.048825900012638, 5.022453769648761, 6.090913801364479, 7.082456602052042, 8.048336053935992, 9.045469266714502, 9.89456284870441, 8.915736677284443, 7.969520907118891, 6.897837388391492, 5.832125825949686, 4.881317279254581, 3.89700387853206, 2.885381802405008, 1.92043695455102, 0.9423848009877787, 0.9560578366466057, 1.8840109485922483, 2.901903823067191, 3.9405235805853884, 4.987911306459123, 5.978487445196706, 6.911150579727779, 7.856596367499684, 8.88769713683821, 9.812818467090215, 10.792687844958738, 9.858951932613957, 8.78795735675663, 7.782347601383365, 6.747403742003592, 5.798211476618944, 4.75685701859752, 3.8300431900841776, 2.8557898776591513, 1.8726720487812807, 1.9497148172149554, 2.853574531514601, 3.9069595259913346, 4.973830474063565, 6.005332934300036, 7.01508448967674, 7.858412546550198, 8.885562989338059, 9.854579705381344, 10.815166354892673, 11.71201552489831, 10.786489194758682, 9.834198628467147, 8.845420315086535, 7.77498930132828, 6.731586355015552, 5.778987080432248, 4.83564592531428, 3.842122287780829, 2.8755513677748104, 2.949057280329912, 3.79384210108845, 4.814424444378624, 5.782543944137477, 6.855797116339405, 7.870459234911378, 8.819110958511057, 9.756785354609388, 10.8089597838408, 11.746290813516719, 12.771467446614386, 11.767063654136022, 10.749650657025228, 9.734865736318996, 8.710932182221846, 7.739224827223066, 6.8332430298897, 5.861346682932346, 4.820802064189612, 3.9265337298266254, 3.9219392312311503, 4.804593460771182, 5.8173787678486955, 6.778840774368441, 7.704202270353473, 8.700248528277239, 9.663171661141273, 10.687666620431475, 11.642956511530087, 12.611634334323512, 13.57027933339467, 12.692536169071374, 11.669808630890337, 10.601897726719239, 9.675098279066983, 8.665132780335455, 7.838152674991471, 6.823611948544815, 5.887970403014898, 4.868958444103852, 4.9811838635743335, 5.838815982013855, 6.8120299342810435, 7.709711089581266, 8.722793378010333, 9.632274897996826, 10.63723558120818, 11.636653476775374, 12.694049820048642, 13.616790139071588, 14.573695189945356, 13.63792672908006, 12.607106483420864, 11.624682287127795, 10.626537173007009, 9.692468985674395, 8.829935608565991, 7.870978976332472, 6.863324733714988, 5.876875735553808, 5.981518533627426, 6.883978987375675, 7.7699263021581775, 8.682376992488393, 9.61423898440142, 10.63303954700995, 11.567576428123822, 12.590487282925963, 13.562931133809682, 14.563333378429926, 15.527259825232035, 14.52617189363662, 13.565647420294686, 12.568700417834165, 11.627723679259654, 10.66540534812224, 9.829234528980622, 8.819720764002842, 7.834405224133081, 6.9256874202818475, 6.947625181896705, 7.815198321726458, 8.755073872391069, 9.702094397016538, 10.59559816825058, 11.590833321345563, 12.535121519675933, 13.55693830245259, 14.561970042451321, 15.492391474673251, 16.500865571151703, 15.538132830782763, 14.497129183424239, 13.565031073108521, 12.593906699591457, 11.61827105078536, 10.784416436515846, 9.810234394003881, 8.761650531893947, 7.89762249045138, 7.960483086502046, 8.794180573642777, 9.775537863126962, 10.706115321086658, 11.65919075029146, 12.51796551852263, 13.508689014184618, 14.553002888242826, 15.604108614902078, 16.528341713723325, 17.44836580170804, 16.454969578531895, 15.509959455479313, 14.579360352833794, 13.573530904798973, 12.573741167291296, 11.666341461213776, 10.72548913177038, 9.780922215436021, 8.852855414179231, 8.971709984395261, 9.86147879550488, 10.785675327657387, 11.707085726517672, 12.62068807461208, 13.460281419784804, 14.443608834330734, 15.463507970470793, 16.405263375956295, 17.450668864131504, 18.43697324982611, 17.412227297215566, 16.437934274425764, 15.554777006958775, 14.515826098652107, 13.542283524144906, 12.740960457547091, 11.737476015381441, 10.83831336585289, 9.779693854901074], [10.891753472801877, 10.077903362855583, 10.902627486189015, 11.893502627661597, 12.70006485779543, 13.638471973443338, 14.613913716411362, 15.628797821138992, 16.568454958338094, 17.5928812360837, 17.497928548516843, 16.507511194165584, 15.442458469715408, 14.4340660367796, 13.463592496156584, 12.692913121551062, 11.79880451862769, 10.80205774367974, 9.861425845930048, 10.860074754533636, 9.8728476951553, 9.02259901686556, 9.912114607885012, 10.860651829088704, 11.670035428616272, 12.659270055126083, 13.663787012791174, 14.65578282658482, 15.655419805409496, 16.668834512409973, 17.62223020083985, 17.418663867320095, 16.359853927593075, 15.343426755175805, 14.390720491727238, 13.698793926099698, 12.724252196116995, 11.832382580144019, 10.909515841762577, 10.912606905960418, 8.829125042121575, 7.988747563627669, 8.932740146554348, 9.898905866718001, 10.742382161972847, 11.689316001184046, 12.661056913455655, 13.682945422882598, 14.63898261370339, 15.646237334234385, 16.626286425135994, 17.381112583809557, 16.381190360431525, 15.385215525993829, 14.410916752732067, 13.472283717205944, 12.522424984001198, 11.66573100236316, 10.650528032874735, 9.874574395705151, 7.8107769971242895, 6.977657624506466, 7.948896225244268, 8.877505244748917, 9.680544895569962, 10.70598685449267, 11.654467631945241, 12.645576166347464, 13.623064159912097, 14.59978955074656, 15.56722761238262, 16.39274771798891, 15.558938775379376, 14.596390335023626, 13.56594002890755, 12.521909699938671, 11.59339107349854, 10.65827299769183, 9.66469384453029, 8.833406711070444, 6.8852013457006755, 6.038643702528816, 6.892914585699334, 7.921970414839457, 8.698282973809622, 9.764091143724826, 10.765151115017199, 11.65131200648688, 12.630938049787725, 13.575182522901693, 14.512011885050567, 15.45337801757636, 14.663359709461607, 13.676014395266474, 12.655679037495673, 11.627813468879197, 10.66610404667146, 9.737240696894258, 8.718831062667372, 7.869077255842808, 5.877099252304653, 4.997676588284395, 5.94691448471942, 6.872301402363259, 7.755720137189245, 8.783299924364531, 9.720475378155594, 10.689005139352416, 11.698984692152539, 12.59390010080966, 13.540046992465134, 14.492448393722778, 13.636586740738446, 12.707627792403322, 11.729817422478192, 10.750579899780387, 9.823246898895396, 8.79578457854976, 7.77114903520981, 6.8084057557892415, 4.933068509509605, 3.9988412521984222, 4.96002372879054, 5.967018206698116, 6.784948399538354, 7.835738407211822, 8.765183523828172, 9.753367695824132, 10.714791903431527, 11.652146192887699, 12.578928438083956, 13.508036061155005, 12.681184515116993, 11.764709605771785, 10.784136645008555, 9.879707752391015, 8.860993254260338, 7.819922641149866, 6.811530347593474, 5.8789754260264, 3.9218371362250135, 3.016558578278021, 3.996210157608654, 4.940739172666647, 5.759592550658958, 6.809587580274826, 7.788892076937293, 8.771985711890967, 9.751872138546206, 10.710672156277042, 11.617622733109837, 12.601928150556734, 11.64802354440415, 10.761023898657289, 9.710778176893449, 8.825648567335241, 7.917895643070745, 6.978940318718722, 5.927886103561541, 4.941889196151855, 2.9524179955881396, 1.9959617838301227, 2.9590604773648392, 3.887098068542864, 4.828831922159926, 5.819617822280838, 6.755898919511478, 7.767937689883377, 8.732508325902883, 9.67245765622696, 10.605579541398065, 11.622784118701137, 10.684137283168408, 9.744738678110675, 8.784904371809123, 7.79722714535, 6.898421350643782, 5.945051869187242, 5.007857693813315, 3.9744505926667735, 2.0143382928279143, 1.0091992175657227, 1.9260855113795448, 2.9072105878787387, 3.865099470472615, 4.875979357986839, 5.849123289210946, 6.7912580828153635, 7.834735970822577, 8.76539090624206, 9.742598445150865, 10.667771903887907, 9.75762672162689, 8.811018181296358, 7.824031589063431, 6.835109440885592, 5.895726005583681, 4.950763958012177, 4.008529815494182, 2.993762067483745, 1.0346725338236074, 0.0, 0.9441196660829254, 2.0134853272741564, 3.0141533661890296, 3.987781235825153, 5.056241267540871, 6.047784068228434, 7.0136635201123845, 8.010796732890894, 9.012261735160852, 9.95040921110805, 9.0041934409425, 7.932509922215099, 6.866798359773293, 5.9159898130781885, 4.931676412355667, 3.920054336228615, 2.955109488374627, 1.977057334811386, 1.8743746715869516, 0.946421559641309, 1.924463536927192, 2.963083294445389, 4.010471020319124, 4.943814911373098, 5.876478045904171, 6.821923833676076, 7.853024603014601, 8.778145933266607, 9.75801531113513, 10.762764621380551, 9.789564894260845, 8.783955138887581, 7.749011279507809, 6.799819014123161, 5.758464556101737, 4.831650727588395, 3.8573974151633683, 2.8299800499798673, 2.868031652155301, 1.9159851425636618, 2.9693701370403955, 3.996390187923565, 5.027892648160036, 6.002828830948462, 6.82374001272659, 7.850890455514451, 8.819907171557736, 9.780493821069065, 10.74852045929735, 11.674046789436979, 10.835806165971363, 9.847027852590752, 8.776596838832498, 7.733193892519769, 6.780594617936465, 5.837253462818497, 4.802428724220963, 3.8328593689733967, 3.867374115270258, 2.856252712137511, 3.8768350554276854, 4.844954555186538, 5.918207727388465, 6.932869845960438, 7.788663550045567, 8.726337946143897, 9.778512375375309, 10.711618279693113, 11.739072405859984, 12.654621248814319, 11.751258194529445, 10.736473273823213, 9.712539719726063, 8.740832364727282, 7.8103404964570595, 6.82165311937248, 5.781108500629746, 4.844850564766972, 4.808529452665804, 3.867004071820243, 4.879789378897756, 5.841251385417502, 6.766612881402534, 7.762659139326301, 8.725582272190335, 9.706738468298338, 10.66202835939695, 11.630706182190375, 12.589351181261533, 13.6409577734672, 12.671416168394554, 11.603505264223456, 10.6767058165712, 9.666740317839672, 8.751155825047856, 7.736615098601201, 6.792709319312076, 5.755548665538504, 5.867774085008986, 4.901226593062917, 5.8744405453301045, 6.772121700630327, 7.785203989059395, 8.694685509045888, 9.699646192257244, 10.666901012906756, 11.722073174804919, 12.635861986938451, 13.59276703781222, 14.624531182161117, 13.608714020925081, 12.626289824632012, 11.628144710511226, 10.694076523178612, 9.742938758622376, 8.783982126388857, 7.749914955149641, 6.763465956988461, 6.86810875506208, 5.946389598424737, 6.8323369132072385, 7.744787603537454, 8.67664959545048, 9.69545015805901, 10.629987039172882, 11.630247628883433, 12.602691479767152, 13.603093724387396, 14.546331673098898, 15.527779431140837, 14.567254957798903, 13.570307955338382, 12.629331216763871, 11.667012885626457, 10.736204861122587, 9.706310985437495, 8.720995445567734, 7.8122776417165, 7.834215403331359, 6.877608932775519, 7.817484483440129, 8.764505008065598, 9.65800877929964, 10.653243932394624, 11.597532130724993, 12.61934891350165, 13.624380653500381, 14.554802085722311, 15.562180572295667, 16.52491331266461, 15.498736720928456, 14.566638610612738, 13.595514237095674, 12.619878588289577, 11.69138676865781, 10.696824615438535, 9.6482407533286, 8.784212711886035, 8.8470733079367, 7.856591184691838, 8.837948474176022, 9.768525932135718, 10.72160136134052, 11.58037612957169, 12.571099625233678, 13.615413499291886, 14.666519225951138, 15.590752324772387, 16.57692528102923, 17.456577116036115, 16.511566992983532, 15.58096789033801, 14.57513844230319, 13.572158666622459, 12.55293168264843, 11.612079353205035, 10.667512436870675, 9.739445635613887, 9.858300205829915, 8.92388940655394, 9.848085938706447, 10.769496337566732, 11.68309868566114, 12.522692030833865, 13.506019445379794, 14.525918581519853, 15.467673987005353, 16.51307947518056, 17.584646625045835, 17.54217461433083, 16.567881591541028, 15.638462755069282, 14.657200887748484, 13.732627404792272, 12.95305459845059, 11.896104824070392, 11.047870719220883, 10.66628407633573], [11.835223733893201, 11.021373623946905, 10.063934651059363, 11.054809792531945, 11.755945191712506, 12.694352307360411, 13.669794050328438, 14.68467815505607, 15.62433529225517, 16.648761570000776, 16.687235128997447, 15.696817774646188, 14.638984250027592, 13.630591817091783, 12.660118276468769, 11.889438901863247, 11.001714486705922, 10.00496771175797, 10.805545512012975, 11.804194420616563, 10.816317956246625, 9.966069277956882, 9.07342177275536, 10.021958993959052, 10.725915762533347, 11.715150389043156, 12.719667346708249, 13.711663160501896, 14.711300139326573, 15.72471484632705, 16.67811053475693, 16.61518964763228, 15.55637970790526, 14.53995253548799, 13.587246272039422, 12.895319706411884, 11.927162164195225, 11.03529254822225, 11.853635507845503, 11.85607716705174, 9.772595303212897, 8.932217824718991, 8.094047311424696, 9.060213031588349, 9.798262495889922, 10.745196335101122, 11.71693724737273, 12.738825756799674, 13.694862947620468, 14.702117668151462, 15.682166759053068, 16.43699291772663, 16.505812459331707, 15.509837624894013, 14.535538851632252, 13.877812235694376, 13.00009643071501, 12.048694393247517, 11.59464769895766, 10.818044656796474, 8.754247258215612, 7.921127885597788, 7.1102033901146156, 8.038812409619265, 8.736425229487038, 9.761867188409745, 10.710347965862317, 11.70145650026454, 12.678944493829174, 13.655669884663638, 14.623107946299694, 15.448628051905985, 16.41253133300211, 15.54051000110655, 14.510059694990474, 13.466029366021596, 12.537510739581464, 11.602392663774754, 10.608813510613215, 9.776876972161766, 7.828671606791998, 6.982113963620138, 6.054221750569681, 7.083277579709804, 7.754163307726698, 8.8199714776419, 9.821031448934276, 10.707192340403957, 11.686818383704802, 12.63106285681877, 13.567892218967641, 14.509258351493434, 15.543876487509785, 14.6201340613494, 13.5997987035786, 12.571933134962123, 11.610223712754387, 10.681360362977184, 9.662950728750296, 8.813196921925734, 6.820569513395975, 5.941146849375717, 5.108221649589767, 6.033608567233607, 6.8116004711063205, 7.8391802582816075, 8.776355712072672, 9.744885473269493, 10.754865026069616, 11.649780434726734, 12.595927326382208, 13.548328727639852, 14.538847699178014, 13.651747458486248, 12.673937088561118, 11.694699565863313, 10.767366564978323, 9.739904244632687, 8.715268701292734, 7.752525421872167, 5.876538770600927, 4.942311513289744, 4.034401568677166, 5.0276964521652046, 5.84082873345543, 6.891618741128897, 7.821063857745247, 8.809248029741205, 9.7706722373486, 10.708026526804773, 11.63480877200103, 12.563916395072079, 13.546084236243644, 12.70882927185471, 11.72825631109148, 10.82382741847394, 9.805112920343264, 8.764042307232792, 7.7556500136764, 6.823095092109326, 4.865307397316335, 3.9600288393693424, 3.0520904915257288, 3.9966195065837216, 4.8154728845760335, 5.8654679141919015, 6.844772410854368, 7.827866045808041, 8.80775247246328, 9.766552490194115, 10.67350306702691, 11.714771925978823, 12.592143210487075, 11.705143564740213, 10.654897842976373, 9.769768233418166, 8.862015309153671, 7.923059984801648, 6.872005769644466, 5.886008862234781, 3.895888256679461, 2.9394320449214444, 2.014940811281914, 2.942978402459939, 3.8847122560770013, 4.875498156197914, 5.811779253428553, 6.8238180238004515, 7.788388659819956, 8.728337990144034, 9.661459875315138, 10.713161991180613, 11.628256949251332, 10.6888583441936, 9.729024037892048, 8.741346811432924, 7.842541016726708, 6.889171535270167, 5.95197735989624, 4.918570258749699, 2.957808553919236, 1.9526694786570444, 0.9819658452966193, 1.9630909217958135, 2.92097980438969, 3.9318596919039144, 4.905003623128021, 5.847138416732438, 6.890616304739652, 7.821271240159134, 8.798478779067938, 9.72365223780498, 10.662612472883849, 9.755137847379283, 8.768151255146355, 7.7792291069685175, 6.839845671666606, 5.894883624095103, 4.952649481577107, 3.9378817335666705, 1.9787921999065328, 0.9441196660829254, 0.0, 1.0693656611912312, 2.070033700106104, 3.043661569742228, 4.112121601457945, 5.103664402145507, 6.069543854029458, 7.066677066807967, 8.068142069077924, 9.046968240497892, 9.948313107025424, 8.876629588298025, 7.8109180258562185, 6.860109479161114, 5.875796078438593, 4.8641740023115405, 3.8992291544575526, 2.9211770008943114, 2.8184943376698772, 1.8905412257242344, 0.9803438708442667, 2.0189636283624637, 3.0663513542361986, 3.999695245290172, 4.932358379821245, 5.877804167593151, 6.908904936931677, 7.834026267183683, 8.813895645052206, 9.818644955297627, 10.733684560343772, 9.728074804970507, 8.693130945590735, 7.743938680206085, 6.7025842221846625, 5.77577039367132, 4.801517081246294, 3.7740997160627927, 3.812151318238227, 2.8601048086465872, 2.0390695544148674, 3.0522705218406396, 4.083772982077111, 5.058709164865537, 5.879620346643665, 6.906770789431525, 7.87578750547481, 8.83637415498614, 9.804400793214427, 10.729927123354056, 11.717004454878564, 10.791147518673677, 9.720716504915423, 8.677313558602695, 7.72471428401939, 6.781373128901422, 5.7465483903038885, 4.776979035056322, 4.8114937813531835, 3.8003723782204366, 3.0797450235059145, 4.041480335498721, 5.036592544167464, 6.004751037008353, 6.844543883962642, 7.782218280060972, 8.834392709292384, 9.767498613610186, 10.794952739777058, 11.710501582731396, 12.653190180834187, 11.680592939906138, 10.656659385808988, 9.684952030810209, 8.754460162539985, 7.765772785455406, 6.725228166712672, 5.788970230849897, 5.752649118748728, 4.811123737903168, 4.082699346975986, 5.037777165729685, 5.9631386617147175, 6.959184919638484, 7.8840792728659155, 8.762618802215414, 9.717908693314026, 10.68658651610745, 11.645231515178608, 12.696838107384275, 13.615535834477479, 12.54762493030638, 11.620825482654125, 10.610859983922598, 9.695275491130781, 8.680734764684125, 7.736828985395, 6.699668331621429, 6.811893751091911, 5.845346259145842, 5.077350513408334, 5.9686474809425105, 6.981729769371578, 7.891211289358072, 8.858143192932824, 9.722781346823831, 10.777953508721994, 11.691742320855527, 12.648647371729295, 13.680411516078191, 14.552833687008008, 13.570409490714937, 12.57226437659415, 11.638196189261539, 10.6870584247053, 9.728101792471781, 8.694034621232566, 7.7075856230713855, 7.812228421145004, 6.890509264507662, 6.035246881285468, 6.9413133838496375, 7.8731753757626635, 8.891975938371194, 9.826512819485066, 10.686127962800509, 11.658571813684228, 12.658974058304471, 13.602212007015973, 14.624344821060827, 15.51137462388183, 14.514427621421307, 13.573450882846798, 12.611132551709384, 11.680324527205512, 10.65043065152042, 9.665115111650659, 8.756397307799425, 8.778335069414284, 7.821728598858444, 7.020394451518358, 7.967414976143828, 8.854534559611825, 9.849769712706808, 10.794057911037177, 11.748560943431285, 12.720618012801562, 13.651039445023493, 14.618060906212742, 15.580793646581684, 16.442856387011382, 15.510758276695665, 14.5396339031786, 13.563998254372503, 12.635506434740735, 11.64094428152146, 10.592360419411525, 9.72833237796896, 9.791192974019626, 8.800710850774763, 8.040858442254251, 8.97143590021395, 9.918127141652704, 10.776901909883874, 11.767625405545862, 12.744625529221521, 13.773553437782184, 14.686989684073568, 15.632805614946305, 16.53993130537944, 16.551736744404554, 15.661205863553512, 14.655376415518692, 13.757050095562958, 13.010251201995194, 12.0693988725518, 11.6116321029536, 10.683565301696811, 10.802419871912841, 9.868009072636866, 9.050995906784678, 9.972406305644963, 10.879624465973325, 11.719217811146049, 12.702545225691978, 13.715225162000456, 14.656980567485956, 15.702386055661163, 16.652288988193842, 16.598054948247906, 15.623761925458103, 14.694343088986358, 13.713081221665558, 12.788507738709347, 12.114361763320938, 11.05741198894074, 11.991340980312206, 11.610403742418654], [12.862127819817047, 11.979708401186985, 11.000371387749773, 10.351183687633466, 10.769376073530102, 11.70778318917801, 12.683224932146034, 13.698109036873664, 14.637766174072764, 15.662192451818369, 15.617869467806214, 14.627452113454957, 13.59765459610368, 12.589262163167872, 11.618788622544857, 10.848109247939334, 10.008225657941594, 10.893492869585717, 11.837709468654449, 12.864447065004555, 11.84322204217047, 10.955778546626828, 10.00985850944577, 9.30938228665392, 9.739346644350944, 10.728581270860754, 11.733098228525845, 12.725094042319492, 13.72473102114417, 14.738145728144648, 15.691541416574527, 15.573859993708368, 14.515050053981348, 13.498622881564078, 12.54591661811551, 11.85399005248797, 10.933673335430898, 11.861995180095075, 12.885799464486977, 12.882981252975588, 10.799499389136745, 9.921927093388938, 9.030484048115106, 8.319595208309428, 8.811693377707519, 9.758627216918718, 10.730368129190326, 11.75225663861727, 12.708293829438064, 13.715548549969059, 14.695597640870663, 15.450423799544227, 15.464482805407796, 14.468507970970101, 13.49420919770834, 12.836482581770463, 12.006607601950682, 12.875397025120343, 12.628813880270298, 11.844948742720321, 9.78115134413946, 8.910837154267735, 8.046640126805027, 7.255040841203703, 7.749856111304634, 8.775298070227342, 9.723778847679913, 10.714887382082136, 11.69237537564677, 12.669100766481236, 13.636538828117288, 14.46205893372358, 15.425962214819705, 15.456244270186858, 14.514115153649934, 13.847558850356842, 12.93564151245334, 12.636558845087393, 11.642979691925854, 10.803781058085614, 8.855575692715846, 7.971823232290086, 6.990658487260092, 6.19052240550613, 6.767594189544294, 7.833402359459497, 8.834462330751872, 9.720623222221553, 10.700249265522398, 11.644493738636367, 12.581323100785236, 13.522689233311029, 14.55730736932738, 15.49937704457891, 14.633964884891236, 13.606099316274761, 12.644389894067025, 11.715526544289823, 10.697116910062935, 9.84736310323837, 7.847473599319823, 6.930856118045666, 6.044658386280178, 5.13547566751506, 5.825031352923917, 6.852611140099204, 7.789786593890268, 8.75831635508709, 9.768295907887213, 10.663211316544329, 11.609358208199803, 12.561759609457447, 13.552278580995608, 14.481237529330732, 13.708103269873755, 12.72886574717595, 11.80153274629096, 10.774070425945323, 9.749434882605373, 8.786691603184805, 6.903442856524775, 5.932020781959693, 4.970838305367575, 4.108058006499564, 4.854259615273025, 5.905049622946493, 6.834494739562842, 7.822678911558802, 8.784103119166197, 9.721457408622367, 10.648239653818626, 11.577347276889675, 12.55951511806124, 13.588126251626347, 12.797621972282712, 11.863268870784928, 10.839279101655901, 9.798208488545429, 8.789816194989037, 7.857261273421964, 5.8922114832401835, 4.9656750255796585, 3.988527228216139, 3.0769810609180817, 3.828903766393629, 4.878898796009497, 5.858203292671964, 6.841296927625637, 7.821183354280876, 8.77998337201171, 9.686933948844507, 10.72820280779642, 11.625636859293154, 12.584440544511851, 11.724263504167606, 10.825768090566946, 9.896181490466308, 8.957226166114285, 7.906171950957104, 6.9201750435474185, 4.92279234260331, 3.945078231131761, 2.951377547972324, 2.023339956794299, 2.8981431378945968, 3.888929038015509, 4.825210135246149, 5.837248905618047, 6.801819541637553, 7.74176887196163, 8.674890757132735, 9.726592872998209, 10.661750598057411, 11.556372391846294, 10.79838969908328, 9.810712472624157, 8.911906677917939, 7.958537196461398, 7.00556298071136, 5.972155879564819, 3.9847126398430843, 2.979573564580893, 2.0088699312204676, 1.0277448547212737, 1.9344106862072854, 2.94529057372151, 3.9184345049456164, 4.8605692985500335, 5.904047186557247, 6.834702121976729, 7.811909660885535, 8.737083119622577, 9.676043354701445, 10.622651895031977, 9.837516916337588, 8.84859476815975, 7.909211332857837, 6.964249285286334, 6.022015142768338, 5.0072473947579015, 3.0481578610977635, 2.0134853272741564, 1.0693656611912312, 0.0, 1.0006680389148732, 1.9742959085509968, 3.0427559402667144, 4.034298740954277, 5.000178192838228, 5.9973114056167365, 6.998776407886694, 7.977602579306661, 8.923818349472214, 9.945995249489258, 8.88028368704745, 7.929475140352345, 6.945161739629824, 5.9335396635027715, 4.968594815648784, 3.9905426620855424, 3.8878599988611082, 2.9599068869154657, 2.01625373195675, 0.9776339744385528, 2.0250217003122875, 2.930329584098941, 3.862992718630014, 4.808438506401919, 5.839539275740445, 6.764660605992451, 7.744529983860973, 8.749279294106394, 9.82027386996372, 10.797440466161738, 9.762496606781966, 8.813304341397316, 7.7719498833758935, 6.845136054862551, 5.870882742437525, 4.843465377254024, 4.881516979429458, 3.9294704698378182, 3.074979415527351, 2.010940867916729, 3.0424433281531993, 3.9893435036743057, 4.810254685452433, 5.8374051282402935, 6.806421844283578, 7.7670084937949095, 8.735035132023196, 9.660561462162825, 10.647638793687333, 11.69038091695263, 10.790082166106654, 9.746679219793926, 8.79407994521062, 7.850738790092653, 6.8159140514951195, 5.846344696247553, 5.8808594425444145, 4.869738039411668, 3.968270181333663, 3.0001506815748105, 3.995262890243552, 4.9353853758171224, 5.77517822277141, 6.71285261886974, 7.765027048101151, 8.698132952418955, 9.725587078585827, 10.641135921540165, 11.583824519642956, 12.598609440349188, 11.726025047000219, 10.75431769200144, 9.823825823731216, 8.835138446646637, 7.794593827903903, 6.858335892041128, 6.822014779939959, 5.880489399094399, 4.971224504803734, 3.9964475118057745, 4.921809007790807, 5.917855265714573, 6.814713611674684, 7.693253141024183, 8.648543032122795, 9.61722085491622, 10.575865853987377, 11.627472446193044, 12.607917922917517, 13.616990591497611, 12.690191143845356, 11.680225645113829, 10.764641152322012, 9.750100425875356, 8.806194646586231, 7.76903399281266, 7.881259412283142, 6.914711920337073, 5.965875671236082, 4.9273178270186, 5.940400115447668, 6.849881635434161, 7.788777531741592, 8.6534156856326, 9.708587847530763, 10.622376659664296, 11.579281710538064, 12.61104585488696, 13.545215775448046, 14.585044528250215, 13.641630037785381, 12.70756185045277, 11.756424085896532, 10.797467453663012, 9.763400282423795, 8.776951284262616, 8.881594082336235, 7.959874925698893, 6.923772039113216, 5.899983729925727, 6.831845721838753, 7.850646284447283, 8.785183165561154, 9.616762301609278, 10.589206152492997, 11.58960839711324, 12.532846345824742, 13.554979159869596, 14.503756712321868, 15.516177619055277, 14.642816544038029, 13.680498212900615, 12.749690188396741, 11.71979631271165, 10.734480772841888, 9.825762968990654, 9.847700730605515, 8.891094260049675, 7.908919609346107, 6.9739261473795, 7.813204905687913, 8.808440058782896, 9.752728257113265, 10.679195282240054, 11.651252351610331, 12.581673783832262, 13.548695245021511, 14.511427985390453, 15.43523847545142, 15.61955587606087, 14.648431502543806, 13.72595109388649, 13.50737652019196, 12.710309942712689, 11.661726080602755, 10.79769803916019, 10.860558635210857, 9.870076511965994, 8.929383600082, 7.977947071449621, 8.876797487728792, 9.735572255959962, 10.72629575162195, 11.67525986803029, 12.704187776590953, 13.617624022882337, 14.563439953755074, 15.47056564418821, 15.56516762622215, 14.67463674537111, 13.66880729733629, 12.770480977380554, 12.485354654755774, 13.00583560924221, 12.680997764144829, 11.752930962888042, 11.871785533104072, 10.90017302927834, 9.939521064612425, 8.978917476880635, 9.838294812049412, 10.677888157222137, 11.661215571768066, 12.645859500809225, 13.587614906294725, 14.633020394469932, 15.582923327002613, 15.611485830065503, 14.6371928072757, 13.707773970803954, 12.726512103483156, 11.801938620526943, 11.410735658422459, 11.99384872563115, 12.949675757552285, 12.679769403609885], [13.609100133098675, 12.650124877825744, 11.670787864388533, 10.796942674246274, 9.768708034615226, 10.707115150263132, 11.68255689323116, 12.69744099795879, 13.63709813515789, 14.661524412903495, 14.61720142889134, 13.626784074540083, 12.597375519630152, 11.703210686598192, 10.767076035832856, 10.026576209823745, 10.917776509375349, 11.815070783678337, 12.759287382747068, 13.786024979097174, 12.642537909439074, 11.691511569820346, 10.680274986084529, 9.7985289992139, 8.738678605436068, 9.727913231945877, 10.732430189610971, 11.724426003404618, 12.724062982229293, 13.73747768922977, 14.69087337765965, 14.689063863353145, 13.634449643740554, 12.646910294852077, 11.69420403140351, 11.032457014372381, 11.843224186864653, 12.77154603152883, 13.807377378579597, 13.68229712024419, 11.598815256405347, 10.657660116582456, 9.700900524753864, 8.809865771599974, 7.811025338792644, 8.757959178003844, 9.729700090275452, 10.751588599702396, 11.707625790523188, 12.714880511054183, 13.69492960195579, 14.449755760629355, 14.612770218695795, 13.6167953842581, 12.64249661099634, 12.014949543654874, 12.916158453384437, 13.784947876554098, 13.492700555435313, 12.644264609988923, 10.632516154998875, 9.696992805689387, 8.717056603443785, 7.788447583939135, 6.74918807238976, 7.774630031312467, 8.723110808765039, 9.714219343167262, 10.691707336731895, 11.668432727566358, 12.635870789202416, 13.461390894808707, 14.425294175904833, 14.604531683474857, 13.662402566937933, 13.026025812241253, 13.845192363887096, 13.500445520252407, 12.506866367090868, 11.655145868945029, 9.706940503575261, 8.757978883711736, 7.729673827682094, 6.776428596885516, 5.76692615062942, 6.832734320544623, 7.833794291836998, 8.719955183306677, 9.699581226607522, 10.643825699721491, 11.580655061870363, 12.522021194396157, 13.556639330412505, 14.498709005664038, 14.641231813167515, 14.08717067434704, 13.508276569232038, 12.579413219454835, 11.56100358522795, 10.711249778403385, 8.71136027448484, 7.7329116231372055, 6.7836737267021805, 5.858286809058341, 4.824363314009043, 5.85194310118433, 6.789118554975394, 7.757648316172214, 8.767627868972337, 9.662543277629457, 10.60869016928493, 11.561091570542574, 12.551610542080736, 13.48056949041586, 14.45837986034099, 13.592752422340965, 12.665419421455974, 11.637957101110338, 10.613321557770387, 9.650578278349819, 7.767329531689791, 6.753163259170825, 5.791980782578707, 4.830869148042845, 3.853591576358152, 4.904381584031619, 5.833826700647969, 6.8220108726439275, 7.783435080251323, 8.720789369707495, 9.647571614903752, 10.576679237974801, 11.558847079146366, 12.587458212711475, 13.584247795037829, 12.727155545949941, 11.703165776820915, 10.662095163710443, 9.653702870154051, 8.721147948586978, 6.756098158405199, 5.787074485259053, 4.809669705427271, 3.7997922024613624, 2.8282357274787557, 3.8782307570946237, 4.85753525375709, 5.840628888710763, 6.820515315366002, 7.779315333096837, 8.686265909929633, 9.727534768881545, 10.624968820378282, 11.58377250559698, 12.510889326922722, 11.68965476573196, 10.760068165631322, 9.8211128412793, 8.770058626122118, 7.784061718712433, 5.786679017768325, 4.766477690811155, 3.7727770076517184, 2.8447394164736934, 1.8974750989797236, 2.888260999100636, 3.8245420963312755, 4.836580866703174, 5.8011515027226785, 6.741100833046756, 7.6742227182178615, 8.725924834083337, 9.661082559142539, 10.555704352931421, 11.585015521838397, 10.81138051153903, 9.912574716832813, 8.93626727269359, 7.869449655876376, 6.8360425547298345, 4.8485993150081, 3.843460239745908, 2.8727566063854826, 1.8916315298862885, 0.9337426472924122, 1.9446225348066366, 2.917766466030743, 3.8599012596351603, 4.903379147642374, 5.834034083061856, 6.8112416219706615, 7.736415080707705, 8.675375315786573, 9.621983856117104, 10.608970448350032, 9.849262807074622, 8.90987937177271, 7.948751934493469, 6.924058767650736, 5.9092910196403, 4.048825900012637, 3.0141533661890296, 2.070033700106104, 1.0006680389148732, 0.0, 0.9736278696361235, 2.042087901351841, 3.0336307020394035, 3.9995101539233544, 4.996643366701863, 5.99810836897182, 6.976934540391788, 7.9231503105573395, 8.994833829284739, 9.880951725962325, 8.930143179267219, 7.945829778544697, 6.934207702417645, 5.969262854563657, 4.991210701000416, 4.888528037775981, 3.960574925830339, 3.0169217708716234, 1.9783020133534261, 1.0395696632480869, 1.929661545184068, 2.8623246797151407, 3.807770467487046, 4.838871236825572, 5.763992567077578, 6.7438619449461, 7.74861125519152, 8.819605831048847, 9.825215586422111, 10.76316464569684, 9.81397238031219, 8.772617922290767, 7.845804093777424, 6.871550781352398, 5.844133416168897, 5.882185018344331, 4.930138508752692, 4.075647454442224, 3.011608906831602, 2.056991291088999, 2.9886754647594325, 3.80958664653756, 4.83673708932542, 5.805753805368705, 6.766340454880036, 7.734367093108322, 8.65989342324795, 9.64697075477246, 10.689712878037756, 11.76014389179601, 10.7473472587088, 9.794747984125495, 8.851406829007527, 7.816582090409993, 6.847012735162426, 6.881527481459288, 5.870406078326542, 4.968938220248536, 4.000818720489684, 3.009810853179352, 3.9347173369022492, 4.7745101838565365, 5.712184579954867, 6.764359009186278, 7.697464913504083, 8.724919039670954, 9.640467882625291, 10.583156480728082, 11.597941401434314, 12.621874955531464, 11.754985730916314, 10.824493862646088, 9.835806485561509, 8.795261866818775, 7.859003930956002, 7.822682818854833, 6.881157438009273, 5.90219319247846, 4.90599836323953, 3.980636867254498, 4.976683125178265, 5.81404557275981, 6.692585102109309, 7.64787499320792, 8.616552816001345, 9.575197815072503, 10.62680440727817, 11.607249884002643, 12.62196188503345, 13.548761332685705, 12.680893684028703, 11.765309191236886, 10.75076846479023, 9.806862685501105, 8.769702031727535, 8.881927451198017, 7.915379959251947, 6.896844358910808, 5.836868678452356, 5.006565241787795, 5.9087094948978525, 6.7881094928267185, 7.652747646717726, 8.707919808615888, 9.621708620749422, 10.57861367162319, 11.610377815972086, 12.544547736533172, 13.584376489335341, 14.500200226625731, 13.708229889367644, 12.757092124811406, 11.798135492577886, 10.764068321338671, 9.777619323177491, 9.848187673239392, 8.902366844141946, 7.854740726787942, 6.8095345813594825, 6.010312683723163, 6.9835131324616135, 7.792820229007805, 8.616094262694403, 9.588538113578123, 10.588940358198366, 11.532178306909868, 12.554311120954722, 13.503088673406994, 14.515509580140403, 14.640467088772148, 13.678148757634734, 13.750358227311617, 12.720464351626525, 11.735148811756764, 10.82643100790553, 10.814294321508672, 9.833586178492729, 8.830497523438725, 7.883476998813256, 6.9916718675723235, 7.956727472070895, 8.866676780543585, 9.67852724332518, 10.650584312695457, 11.581005744917388, 12.548027206106637, 13.510759946475579, 14.434570436536546, 14.618887837145992, 13.647763463628928, 12.725283054971614, 13.676445416012063, 13.710977981627565, 12.66239411951763, 11.764291630063347, 11.827152226114013, 10.812568430409048, 9.850961514174617, 8.887497922883377, 8.055264449613203, 8.883859669247961, 9.840244275052271, 10.674591829115416, 11.703519737676078, 12.616955983967463, 13.5627719148402, 14.469897605273335, 14.564499587307276, 13.673968706456233, 12.668139258421412, 11.769812938465678, 12.789039922439708, 13.67625208588097, 13.681665803059705, 12.7195245537912, 12.833435929106136, 11.82175094337096, 10.861098978705044, 9.88846832831439, 9.016761773933823, 9.826175570510136, 10.775164095198386, 11.64519146189435, 12.58694686737985, 13.632352355555058, 14.582255288087739, 14.610817791150629, 13.636524768360825, 12.70710593188908, 11.725844064568278, 10.801270581612068, 11.790535920698307, 12.66426520226991, 13.620092234191045, 13.646362994513042], [14.582728002734797, 13.623752747461866, 12.644415734024655, 11.7705705438824, 10.742335904251352, 10.155091837110607, 11.041465169872609, 12.05634927460024, 12.935062721945261, 13.929739219740476, 13.643573559255218, 12.653156204903961, 11.62374764999403, 10.729582816962068, 9.804233997349542, 10.792711617470438, 11.75009709644403, 12.774469693672305, 13.725228115405812, 14.751965711755918, 13.616165779075196, 12.665139439456468, 11.653902855720652, 10.772156868850026, 9.712306475072193, 9.175889918793352, 10.09133846625242, 11.083334280046067, 11.879516915552172, 12.892931622552648, 13.805935956670345, 13.715435993717023, 12.660821774104432, 11.684068256368763, 10.731361992920196, 11.798592422019075, 12.675544773933334, 13.603866618597511, 14.659117542844028, 14.655924989880312, 12.572443126041469, 11.631287986218577, 10.674528394389988, 9.783493641236099, 8.784653208428768, 8.136290189893804, 9.088608366916901, 10.045145638508627, 10.863079723846067, 11.870334444377061, 12.7850902632059, 13.539916421879465, 13.64992818021248, 12.653953345774786, 11.679654572513025, 12.618287608039148, 13.568146341243894, 14.617268463622779, 14.466328425071437, 13.617892479625045, 11.606144024634999, 10.670620675325509, 9.690684473079909, 8.762075453575259, 7.722815942025884, 7.152961043202429, 8.082019085406488, 8.978077478519072, 9.847161270054773, 10.823886660889237, 11.726031450452526, 12.551551556058817, 13.515454837154943, 13.641689644991542, 12.699560528454619, 13.629363876625527, 14.497180251746553, 14.474073389888531, 13.480494236726992, 12.628773738581152, 10.680568373211385, 9.73160675334786, 8.703301697318217, 7.75005646652164, 6.740554020265543, 6.0970023500384265, 7.028049014346735, 7.914209905816414, 8.8550351599304, 9.79927963304437, 10.670815723120473, 11.612181855646266, 12.646799991662615, 13.588869666914148, 13.6783897746842, 14.690508738731316, 14.481904438868163, 13.55304108909096, 12.534631454864073, 11.684877648039508, 9.684988144120963, 8.706539492773329, 7.757301596338304, 6.8319146786944644, 5.797991183645166, 5.046197823694067, 5.98337327748513, 6.951903038681951, 7.923081802295215, 8.752703938879566, 9.69885083053504, 10.651252231792684, 11.641771203330846, 12.57073015166597, 13.5485405215911, 14.527778044288905, 13.639047291092098, 12.611584970746462, 11.58694942740651, 10.624206147985943, 8.740957401325915, 7.726791128806949, 6.765608652214831, 5.804497017678969, 4.827219445994276, 4.075884381614949, 4.986503881334371, 5.941152318746157, 6.9025765263535535, 7.810950030957604, 8.737732276153862, 9.666839899224911, 10.649007740396476, 11.63892514663343, 12.635714728959783, 13.587412610808592, 12.676793646457039, 11.635723033346567, 10.627330739790175, 9.694775818223102, 7.7297260280413225, 6.7607023548951775, 5.783297575063394, 4.773420072097486, 3.8018635971148793, 3.0497335546779527, 4.010212434443492, 4.959770334812993, 5.939656761468233, 6.869475994346946, 7.7764265711797425, 8.799754600623286, 9.676435754300236, 10.635239439518934, 11.562356260844677, 12.533353425752818, 11.733696035267446, 10.794740710915423, 9.743686495758242, 8.757689588348557, 6.7603068874044485, 5.7401055604472795, 4.746404877287842, 3.818367286109817, 2.871102968615847, 2.0074024452028665, 2.943683542433506, 3.955722312805404, 4.920292948824909, 5.831261494296865, 6.76438337946797, 7.777391768005292, 8.712549493064493, 9.607171286853376, 10.636482455760351, 11.618381524440258, 10.886202586468936, 9.909895142329711, 8.843077525512498, 7.809670424365958, 5.822227184644223, 4.8170881093820315, 3.846384476021606, 2.865259399522412, 1.9073705169285358, 1.0637639809088673, 2.036907912132974, 2.979042705737391, 3.95484608156433, 4.885501016983811, 5.862708555892617, 6.78788201462966, 7.726842249708527, 8.673450790039059, 9.660437382271986, 10.65626381997585, 9.883507241408834, 8.922379804129593, 7.89768663728686, 6.882918889276423, 5.02245376964876, 3.987781235825153, 3.043661569742228, 1.9742959085509968, 0.9736278696361235, 0.0, 1.0684600317157176, 2.06000283240328, 3.025882284287231, 4.02301549706574, 5.024480499335697, 6.003306670755665, 6.949522440921216, 8.021205959648615, 9.08691752209042, 9.903771048903343, 8.91945764818082, 7.907835572053768, 6.94289072419978, 5.964838570636539, 5.862155907412105, 4.9342027954664625, 3.990549640507747, 2.9519298829895497, 2.0131975328842104, 0.9560336755479445, 1.8886968100790174, 2.8341425978509225, 3.865243367189448, 4.790364697441454, 5.770234075309976, 6.774983385555396, 7.845977961412722, 8.851587716785987, 9.88653157616576, 10.787600249948314, 9.74624579192689, 8.819431963413548, 7.8451786509885215, 6.8177612858050205, 6.855812887980455, 5.9037663783888155, 5.049275324078348, 3.9852367764677257, 3.024799150500013, 2.0150475951233093, 2.8359587769014367, 3.8631092196892967, 4.832125935732582, 5.792712585243913, 6.760739223472198, 7.686265553611827, 8.673342885136336, 9.716085008401633, 10.786516022159887, 11.720975128344923, 10.768375853761619, 9.82503469864365, 8.790209960046116, 7.82064060479855, 7.855155351095411, 6.844033947962665, 5.94256608988466, 4.974446590125807, 3.9757515858380987, 2.961089467266126, 3.8008823142204133, 4.738556710318743, 5.790731139550155, 6.7238370438679596, 7.751291170034831, 8.666840012989168, 9.609528611091958, 10.62431353179819, 11.64824708589534, 12.672512029954653, 11.798121732282212, 10.809434355197633, 9.768889736454899, 8.832631800592125, 8.796310688490957, 7.854785307645397, 6.868133925137206, 5.871939095898277, 4.946577599913245, 4.013841086694949, 4.840417703123688, 5.718957232473185, 6.674247123571797, 7.642924946365222, 8.60156994543638, 9.653176537642047, 10.63362201436652, 11.648334015397324, 12.57513346304958, 13.598419983067043, 12.73893706087301, 11.724396334426354, 10.780490555137229, 9.743329901363659, 9.85555532083414, 8.88900782888807, 7.862785091569554, 6.802809411111102, 5.972505974446543, 4.945867456414537, 5.814481623190596, 6.679119777081603, 7.734291938979765, 8.648080751113298, 9.604985801987066, 10.636749946335964, 11.570919866897047, 12.610748619699216, 13.526572356989606, 14.51914550433101, 13.73071999444753, 12.77176336221401, 11.737696190974795, 10.751247192813615, 10.814128405898138, 9.868307576800692, 8.82068145944669, 7.775475314018229, 6.976253416381911, 6.020671093978298, 6.819192359371682, 7.642466393058281, 8.614910243942001, 9.615312488562244, 10.558550437273745, 11.580683251318598, 12.529460803770869, 13.541881710504278, 14.135282619718073, 14.65177662727086, 14.72398609694774, 13.694092221262649, 12.708776681392887, 11.800058877541654, 11.780235054167418, 10.799526911151474, 9.79643825609747, 8.849417731472002, 7.957612600231071, 6.99388543358758, 7.893048910907462, 8.704899373689058, 9.676956443059336, 10.607377875281266, 11.574399336470513, 12.537132076839455, 13.460942566900421, 14.066864523993468, 13.095740150476404, 13.69891092460774, 14.650073285648189, 14.684605851263688, 13.636021989153754, 12.730232362722093, 12.79309295877276, 11.778509163067794, 10.816902246833363, 9.853438655542123, 8.895502358474443, 7.921017630764646, 8.866616405416147, 9.700963959479294, 10.729891868039957, 11.643328114331341, 12.589144045204076, 13.496269735637213, 13.923407863948725, 13.04143086265551, 12.116115945268888, 12.743440808101804, 13.762667792075833, 14.649879955517092, 14.651463490824824, 13.685465286449945, 13.79937666176488, 12.787691676029704, 11.827039711363788, 10.80529486489908, 9.856999682795063, 8.863333532026822, 9.801536225562263, 10.671563592258229, 11.613318997743729, 12.658724485918937, 13.608627418451615, 13.969726067792077, 12.995433045002274, 12.066014208530529, 11.173820751415754, 11.774898451248193, 12.764163790334432, 13.637893071906031, 14.593720103827167, 14.612303727171788], [15.651188034450517, 14.692212779177586, 13.712875765740375, 12.839030575598118, 11.81079593596707, 11.09527571907599, 10.194749270987392, 11.193487807920377, 11.946574009155286, 12.917804425944691, 12.716714316106708, 11.726296961755452, 10.69688840684552, 9.802723573813562, 10.610432900708288, 11.598910520829184, 12.556295999802776, 13.580668597031051, 14.556690143819898, 15.583427740170006, 14.684625810790916, 13.733599471172187, 12.72236288743637, 11.840616900565744, 10.780766506787911, 10.116073800758736, 9.244622567367204, 10.143839852058386, 10.891028202762197, 11.880996828756864, 12.737475924954627, 12.788576750568513, 11.733962530955923, 10.765187164140935, 11.537560896278942, 12.604791325377821, 13.48174367729208, 14.410065521956257, 15.465316446202774, 15.724385021596031, 13.640903157757188, 12.699748017934297, 11.742988426105706, 10.851953672951817, 9.853113240144486, 9.076474071859188, 8.241892468031685, 9.084546968583645, 9.874591011056092, 10.858399650581276, 11.716630231490182, 12.471456390163747, 12.749178156631455, 11.82106308578882, 12.485853475871771, 13.424486511397895, 14.37434524460264, 15.423467366981525, 15.534788456787155, 14.686352511340765, 12.674604056350717, 11.739080707041229, 10.759144504795627, 9.830535485290977, 8.791275973741602, 8.093144925167811, 7.235303186521271, 8.01747880859409, 8.858672557264798, 9.79972393093646, 10.657571418736808, 11.483091524343099, 12.446994805439225, 12.808799385005576, 13.505759431813365, 14.435562779984274, 15.303379155105299, 15.542533421604249, 14.54895426844271, 13.69723377029687, 11.749028404927103, 10.800066785063578, 9.771761729033935, 8.818516498237358, 7.809014051981261, 7.037186232003808, 6.181333115461518, 6.953611235891431, 7.866546447140426, 8.733185295091765, 9.602355691404755, 10.543721823930548, 11.578339959946899, 12.52040963519843, 13.405942104892864, 14.428204481341597, 15.389913903549333, 14.621501120806677, 13.60309148657979, 12.753337679755226, 10.75344817583668, 9.774999524489047, 8.825761628054021, 7.900374710410182, 6.866451215360884, 5.98638170565945, 5.136657378599914, 5.991304368756968, 6.93459308950524, 7.684243907163849, 8.630390798819322, 9.582792200076966, 10.573311171615128, 11.502270119950252, 12.480080489875382, 13.459318012573187, 14.386651013458177, 13.68004500246218, 12.655409459122229, 11.69266617970166, 9.80941743304163, 8.795251160522666, 7.834068683930548, 6.872957049394686, 5.895679477709993, 5.0160682635803315, 4.074446702384974, 4.952663605956184, 5.9140878135635795, 6.7424899992418865, 7.669272244438144, 8.598379867509193, 9.580547708680758, 10.570465114917711, 11.567254697244065, 12.518952579092874, 13.45105425890608, 12.704183065062285, 11.695790771505893, 10.76323584993882, 8.79818605975704, 7.829162386610894, 6.8517576067791115, 5.841880103813203, 4.870323628830596, 4.007532704336192, 3.098155255494095, 3.97128162202302, 4.951168048678259, 5.8010159626312285, 6.707966539464025, 7.73129456890757, 8.60797572258452, 9.566779407803216, 10.493896229128959, 11.4648933940371, 12.394479994137738, 11.863200742631141, 10.81214652747396, 9.826149620064275, 7.828766919120165, 6.808565592162996, 5.814864909003559, 4.886827317825534, 3.9395630003315647, 2.9652015948611057, 2.0316263634841096, 2.9672336000154305, 3.9318042360349357, 4.762801462581148, 5.695923347752253, 6.708931736289575, 7.644089461348776, 8.538711255137658, 9.568022424044633, 10.54992149272454, 11.477639075420104, 10.978355174045427, 9.911537557228215, 8.878130456081674, 6.8906872163599395, 5.885548141097749, 4.914844507737324, 3.9337194312381296, 2.9758305486442533, 2.021563130567107, 1.0484191993430003, 1.9905539929474174, 2.8863860498486122, 3.817040985268094, 4.7942485241769, 5.719421982913943, 6.65838221799281, 7.604990758323342, 8.591977350556268, 9.587803788260132, 10.527187223562043, 9.990839835845309, 8.966146669002576, 7.9513789209921395, 6.090913801364478, 5.056241267540871, 4.112121601457946, 3.0427559402667144, 2.042087901351841, 1.0684600317157176, 0.0, 0.9915428006875625, 1.9574222525715133, 2.9545554653500217, 3.956020467619979, 4.934846639039947, 5.881062409205498, 6.952745927932897, 8.018457490374704, 8.96926603706981, 9.953579437792332, 8.976295603769486, 8.0113507559155, 7.033298602352257, 6.930615939127823, 6.0026628271821805, 5.05025595253474, 4.011636195016543, 2.9642484691428077, 1.8945007014615824, 0.9618375669305097, 1.907283354702415, 2.908186258201516, 3.833307588453522, 4.813176966322044, 5.817926276567464, 6.88892085242479, 7.894530607798055, 8.929474467177828, 9.878666732562477, 10.814705823642608, 9.887891995129266, 8.913638682704239, 7.8862213175207385, 7.924272919696173, 6.9722264101045335, 6.039380828469224, 4.967468826818434, 3.902160038660658, 2.8924084832839543, 1.9090995337529288, 2.936249976540789, 3.9052666925840733, 4.8356554762559805, 5.803682114484266, 6.729208444623895, 7.716285776148403, 8.7590278994137, 9.829458913171955, 10.872861859484683, 11.825461134067988, 10.893494730359368, 9.858669991761834, 8.889100636514268, 8.92361538281113, 7.899291928494511, 6.878709585204337, 5.9105900854454845, 4.837336913243558, 3.8226747946715847, 2.8740230710719055, 3.8116974671702355, 4.863871896401647, 5.766779934880027, 6.7942340610468985, 7.7097829040012344, 8.652471502104026, 9.667256422810258, 10.691189976907408, 11.715454920966721, 12.699162427905389, 11.87789438691335, 10.837349768170617, 9.901091832307843, 9.717705914407494, 8.776180533561934, 7.729719252542665, 6.733524423303736, 5.808162927318704, 4.875426414100408, 3.91355845997518, 4.792097989324677, 5.747387880423289, 6.716065703216714, 7.6747107022878716, 8.726317294493539, 9.676564905378587, 10.691276906409392, 11.618076354061648, 12.64136287407911, 13.65551558470477, 12.645791560342891, 11.701885781053766, 10.664725127280196, 10.776950546750678, 9.776847065911863, 8.724370418975013, 7.664394738516561, 6.834091301852002, 5.807452783819996, 4.887622380042088, 5.752260533933095, 6.807432695831257, 7.721221507964791, 8.678126558838558, 9.709890703187455, 10.613862757909114, 11.653691510711283, 12.569515248001673, 13.562088395343078, 14.541712708380246, 13.693158588130547, 12.659091416891332, 11.672642418730153, 11.6757137333036, 10.729892904206153, 9.682266786852148, 8.637060641423687, 7.83783874378737, 6.826869997337045, 5.892333116223174, 6.715607149909773, 7.688051000793492, 8.688453245413735, 9.631691194125237, 10.65382400817009, 11.572403694782937, 12.584824601516345, 13.58431802280876, 14.535024757790923, 15.541011628794877, 14.615487447179186, 13.630171907309425, 12.697411955213468, 12.64182038157288, 11.661112238556935, 10.65802358350293, 9.711003058877461, 8.79531949004131, 7.800084336946327, 6.966189667758954, 7.778040130540549, 8.750097199910826, 9.680518632132756, 10.647540093322005, 11.610272833690948, 12.503885457912489, 13.245941436078647, 14.035924032441788, 14.767370956323457, 15.718533317363907, 15.586354900093122, 14.537771037983187, 13.591817690127554, 13.654678286178221, 12.640094490473254, 11.678487574238822, 10.715023982947582, 9.70170126183319, 8.727216534123393, 7.93975716226764, 8.774104716330784, 9.803032624891447, 10.716468871182832, 11.662284802055568, 12.569410492488704, 13.076691965063509, 12.194714963770293, 13.056299827234271, 13.811900839817522, 14.831127823791551, 15.718339987232811, 15.513048818230285, 14.547050613855406, 14.630838690178965, 13.61915370444379, 12.658501739777874, 11.611493768257828, 10.663198586153811, 9.669532435385568, 8.874676982413757, 9.74470434910972, 10.68645975459522, 11.731865242770427, 12.681768175303107, 13.00872248990654, 12.148717146117058, 11.219298309645312, 12.114004633381137, 12.843358482963911, 13.83262382205015, 14.706353103621751, 15.662180135542886, 15.47388905457725], [16.62689580817814, 15.66792055290521, 14.688583539467999, 13.814738349325742, 12.786503709694694, 11.960151337088243, 10.968985850193613, 10.25474286741481, 10.978418821756513, 11.92626162525713, 11.890886585088278, 10.900469230737022, 9.87106067582709, 10.776039494598423, 11.583748821493149, 12.572226441614045, 13.529611920587637, 14.553984517815913, 15.530006064604757, 16.556743660954865, 15.66033358451854, 14.709307244899811, 13.698070661163994, 12.816324674293368, 11.756474280515535, 10.980949418770988, 10.018859146573424, 9.20509491155282, 9.922873015363423, 10.889454028069302, 11.745933124267065, 11.962749019550085, 10.908134799937493, 11.738503084925796, 12.510876817063803, 13.578107246162682, 14.455059598076941, 15.383381442741118, 16.438632366987633, 16.700092795323656, 14.616610931484812, 13.675455791661921, 12.71869619983333, 11.827661446679441, 10.82882101387211, 9.94134968987144, 9.016129047237905, 8.145802028078078, 8.906435823657318, 9.866856849893713, 10.72508743080262, 11.479913589476185, 11.923350425613025, 12.794379006573681, 13.459169396656632, 14.397802432182756, 15.347661165387501, 16.396783287766386, 16.521627062347328, 15.662060285068389, 13.65031183007834, 12.714788480768853, 11.73485227852325, 10.8062432590186, 9.766983747469226, 8.958020543180064, 8.009539765727492, 7.0787338680885235, 7.890517369866025, 8.808181130248897, 9.666028618049246, 10.491548723655537, 11.455452004751663, 12.418000445107413, 13.393228550434884, 14.437258879403762, 15.365777505843894, 16.300895581650604, 15.535792874002883, 14.672941544024495, 12.724736178654727, 11.775774558791202, 10.74746950276156, 9.794224271964982, 8.784721825708885, 7.982710878707074, 6.955569694667739, 6.014866295385865, 6.898391259741652, 7.741642494404203, 8.610812890717193, 9.552179023242987, 10.586797159259337, 11.528866834510868, 12.414399304205302, 13.436661680654035, 14.398371102861772, 15.327234452638974, 14.589930092139964, 13.7401762853154, 11.729161726001157, 10.750707298216671, 9.801469401781645, 8.876082484137806, 7.842158989088508, 6.931906352362716, 6.0210891894482215, 5.052559428251401, 5.966437902106467, 6.692701106476287, 7.6388479981317605, 8.591249399389405, 9.581768370927566, 10.51072731926269, 11.48853768918782, 12.467775211885625, 13.395108212770616, 14.379799992315732, 13.642248064682402, 12.679504785261834, 10.785130983206109, 9.77095893425029, 8.809776457658172, 7.84866482312231, 6.871387251437617, 5.961592910283597, 5.01997134908824, 4.013918665450618, 4.945932626164805, 5.750947198554324, 6.677729443750581, 7.606837066821631, 8.589004907993196, 9.578922314230148, 10.575711896556504, 11.527409778405312, 12.459511458218518, 13.403938054915837, 12.687333572193456, 11.754778650626383, 9.789728860444603, 8.804870160338517, 7.827465380506736, 6.817587877540827, 5.8460314025582205, 4.953057351039458, 4.043679902197361, 3.0325366815174526, 3.983012861279485, 4.809473161943666, 5.716423738776463, 6.739751768220007, 7.6164329218969575, 8.575236607115652, 9.502353428441397, 10.473350593349538, 11.402937193450176, 12.341892517802199, 11.803689328161523, 10.817692420751838, 8.820309719807728, 7.78427336589062, 6.790572682731183, 5.862535091553158, 4.915270774059189, 3.9107262415643724, 2.9771510101873764, 2.028488659509863, 2.9636490486361615, 3.7712586618935857, 4.704380547064691, 5.7173889356020124, 6.652546660661214, 7.547168454450095, 8.576479623357072, 9.558378692036978, 10.486096274732542, 11.559671313066515, 10.903080357915778, 9.869673256769238, 7.882230017047503, 6.877090941785311, 5.906387308424886, 4.925262231925692, 3.9673733493318157, 2.9670877772703736, 1.993943846046267, 1.05180905244185, 1.8948432491610496, 2.825498184580532, 3.8027057234893373, 4.72787918222638, 5.666839417305248, 6.613447957635779, 7.600434549868706, 8.59626098757257, 9.535644422874482, 10.609903051224002, 9.95768946969014, 8.942921721679703, 7.082456602052041, 6.047784068228434, 5.103664402145508, 4.034298740954277, 3.0336307020394035, 2.06000283240328, 0.9915428006875625, 0.0, 0.9658794518839507, 1.9630126646624593, 2.9644776669324164, 3.943303838352384, 4.8895196085179355, 5.9612031272453345, 7.026914689687141, 7.9777232363822455, 8.962036637104767, 9.967838404457048, 9.00289355660306, 8.024841403039819, 7.922158739815385, 6.994205627869743, 6.023571873319602, 4.984952115801405, 3.9375643899276698, 2.8678166222464445, 1.9351534877153718, 0.9897076999434665, 1.9166434575139535, 2.8417647877659595, 3.821634165634482, 4.8263834758799025, 5.8973780517372285, 6.9029878071104935, 7.937931666490266, 8.887123931874916, 9.900835396843163, 10.827649225356506, 9.905181483391802, 8.877764118208301, 8.915815720383735, 7.963769210792096, 7.012696749254086, 5.9407847476032964, 4.87547595944552, 3.8657244040688163, 2.882415454537791, 2.032123573625068, 2.9418405988256175, 3.844112675568418, 4.8121393137967035, 5.7376656439363325, 6.724742975460841, 7.767485098726137, 8.837916112484391, 9.88131905879712, 10.833918333380424, 11.822618716675104, 10.850212792449396, 9.88064343720183, 9.915158183498692, 8.872607849279373, 7.852025505989198, 6.883906006230346, 5.810652834028419, 4.795990715456447, 3.8473389918567675, 2.985869736151805, 3.9288123087927853, 4.775237134192465, 5.802691260359337, 6.718240103313672, 7.660928701416465, 8.675713622122696, 9.699647176219846, 10.72391212027916, 11.707619627217827, 12.696307004302406, 11.828892568858178, 10.892634632995405, 10.691021835192355, 9.749496454346795, 8.703035173327526, 7.706840344088597, 6.781478848103565, 5.84874233488527, 4.886874380760042, 3.9662702583062472, 4.921560149404859, 5.8373528215340835, 6.7740103119758945, 7.746208722400366, 8.685022104691026, 9.69973410572183, 10.626533553374086, 11.649820073391549, 12.663972784017208, 13.619107481127752, 12.675201701838628, 11.638041048065057, 11.750266467535539, 10.750162986696724, 9.697686339759874, 8.637710659301423, 7.807407222636863, 6.780768704604858, 5.86093830082695, 4.926432802914665, 5.981604964812827, 6.842508626282161, 7.777426168526581, 8.729782131094282, 9.622319957221553, 10.662148710023722, 11.577972447314112, 12.570545594655517, 13.550169907692684, 14.509126539926203, 13.632407337676193, 12.645958339515014, 12.649029654088459, 11.703208824991012, 10.65558270763701, 9.610376562208549, 8.811154664572232, 7.800185918121906, 6.865649037008036, 5.889779418891343, 6.862223269775062, 7.841582362245311, 8.73099080381326, 9.753123617858114, 10.580860894095375, 11.593281800828784, 12.5927752221212, 13.543481957103362, 14.549468828107315, 15.528302305256659, 14.603487828094286, 13.670727875998328, 13.615136302357739, 12.634428159341795, 11.63133950428779, 10.684318979662322, 9.768635410826171, 8.773400257731188, 7.939505588543816, 6.952212399522119, 7.924269468892396, 8.854690901114326, 9.746839703010028, 10.70957244337897, 11.512342657224927, 12.472999891768962, 13.444124265286026, 14.419759914092124, 15.370922275132573, 16.426625386195568, 15.511086958768047, 14.565133610912413, 14.62799420696308, 13.613410411258114, 12.651803495023684, 11.688339903732443, 10.67501718261805, 9.700532454908254, 8.913073083052502, 7.948276985312354, 8.977204893873019, 9.890641140164401, 10.761584411743591, 11.668710102176728, 12.225364759379135, 12.968951542976514, 13.921175445246524, 14.787608613545146, 15.806835597519175, 16.694047760960434, 16.486364739015144, 15.520366534640265, 15.604154610963825, 14.592469625228649, 13.631817660562733, 12.584809689042688, 11.63651450693867, 10.642848356170429, 9.847992903198618, 8.91887661809129, 9.86063202357679, 10.906037511751997, 11.78106778499113, 12.040567302507768, 11.297389940432684, 11.993534888851533, 12.97888025139339, 13.819066256691535, 14.808331595777775, 15.682060877349375, 16.63788790927051, 16.44720497536211], [17.547528441020603, 16.588553185747674, 15.609216172310461, 14.735370982168204, 13.707136342537156, 12.851908373903326, 11.860742887008696, 10.952196507071662, 10.012539369872561, 10.96038217337318, 11.060087022576578, 10.266609567904114, 10.783914965186973, 11.723417377713266, 12.54364434753848, 13.532121967659377, 14.489507446632969, 15.513880043861244, 16.489901590650092, 17.516639187000198, 16.580966217361002, 15.629939877742274, 14.618703294006457, 13.73695730713583, 12.677106913357997, 11.872706455586071, 10.910616183388507, 10.00875618927288, 8.956993563479472, 9.923574576185352, 10.780053672383113, 11.328889356717177, 11.820989089297376, 12.685880968040639, 13.470772343109134, 14.538002772208014, 15.414955124122272, 16.34327696878645, 17.398527893032966, 17.620725428166118, 15.537243564327275, 14.596088424504384, 13.639328832675792, 12.748294079521903, 11.749453646714572, 10.833106726686523, 9.907886084052988, 8.956219360555746, 7.940556371773367, 8.900977398009763, 9.759207978918669, 10.514034137592233, 11.44909544279572, 12.439857292440218, 13.41415606570198, 14.352789101228103, 15.302647834432848, 16.355343428027044, 17.311461605189276, 16.58269291791085, 14.570944462920805, 13.635421113611315, 12.655484911365713, 11.726875891861063, 10.687616380311688, 9.849777579995147, 8.901296802542575, 7.910188268140353, 6.924637917982073, 7.842301678364947, 8.700149166165295, 9.525669271771585, 10.489572552867712, 11.452120993223462, 12.427349098550932, 13.47137942751981, 14.399898053959943, 15.335016129766652, 16.32562741684483, 15.593574176866959, 13.64536881149719, 12.696407191633666, 11.668102135604023, 10.714856904807444, 9.705354458551348, 8.903343511549537, 7.876202327510201, 6.935498928228327, 5.932511807857701, 6.775763042520252, 7.644933438833242, 8.586299571359035, 9.620917707375384, 10.562987382626916, 11.44851985232135, 12.470782228770084, 13.43249165097782, 14.361355000755022, 15.37976463498191, 14.660808918157864, 12.649794358843621, 11.671339931059135, 10.72210203462411, 9.79671511698027, 8.76279162193097, 7.852538985205178, 6.941721822290684, 5.973192061093863, 5.000558450222515, 5.726821654592336, 6.672968546247809, 7.625369947505453, 8.615888919043615, 9.544847867378738, 10.522658237303869, 11.501895760001673, 12.429228760886664, 13.413920540431782, 14.46600632228467, 13.600137418104298, 11.705763616048573, 10.691591567092754, 9.730409090500636, 8.769297455964773, 7.79201988428008, 6.88222554312606, 5.940603981930703, 4.93455129829308, 3.9800531742808545, 4.785067746670373, 5.71184999186663, 6.64095761493768, 7.6231254561092445, 8.613042862346198, 9.609832444672552, 10.56153032652136, 11.493632006334566, 12.438058603031887, 13.44645089658828, 12.686005598921627, 10.720955808739847, 9.725502793180983, 8.7480980133492, 7.73822051038329, 6.766664035400684, 5.873689983881922, 4.9643125350398245, 3.953169314359915, 3.017133409395534, 3.8435937100597153, 4.750544286892511, 5.773872316336057, 6.650553470013007, 7.609357155231702, 8.536473976557446, 9.507471141465587, 10.437057741566225, 11.376013065918247, 12.427067281075429, 11.748919369047082, 9.751536668102972, 8.704905998733084, 7.711205315573647, 6.783167724395621, 5.835903406901652, 4.831358874406836, 3.897783643029839, 2.949121292352326, 1.9977695967522107, 2.805379210009635, 3.7385010951807396, 4.751509483718062, 5.686667208777263, 6.581289002566145, 7.610600171473121, 8.592499240153026, 9.52021682284859, 10.593791861182563, 11.660609477999776, 10.800900205064481, 8.813456965342747, 7.808317890080556, 6.837614256720131, 5.856489180220937, 4.898600297627061, 3.887720410112837, 2.91457647888873, 1.9724416852843127, 0.9289637972770989, 1.859618732696581, 2.8368262716053865, 3.761999730342429, 4.700959965421297, 5.647568505751829, 6.634555097984755, 7.6303815356886195, 8.569764970990532, 9.644023599340052, 10.668716766182785, 9.874148669974947, 8.04833605393599, 7.013663520112384, 6.069543854029458, 5.000178192838227, 3.9995101539233544, 3.025882284287231, 1.9574222525715133, 0.9658794518839507, 0.0, 0.9971332127785085, 1.998598215048466, 2.977424386468434, 3.923640156633986, 4.995323675361385, 6.061035237803192, 7.011843784498296, 7.9961571852208175, 9.00777926134787, 9.96877300848701, 8.990720854923769, 8.888038191699335, 7.960085079753693, 6.989451325203553, 5.950831567685356, 4.903443841811621, 3.8336960741303954, 2.9010329395993226, 1.9555871518274173, 0.9507640056300027, 1.875885335882009, 2.8557547137505312, 3.8605040239959516, 4.931498599853278, 5.937108355226543, 6.9720522146063155, 7.921244479990964, 8.934955944959214, 9.861769773472556, 10.836023085897583, 9.84364357009225, 9.881695172267685, 8.929648662676046, 7.978576201138036, 6.906664199487246, 5.84135541132947, 4.831603855952767, 3.8482949064217418, 2.9449778629849512, 1.9759611469416667, 2.878233223684467, 3.8462598619127526, 4.771786192052382, 5.75886352357689, 6.801605646842186, 7.872036660600441, 8.91543960691317, 9.868038881496474, 10.856739264791154, 11.816092244333346, 10.84652288908578, 10.881037635382642, 9.838487301163324, 8.81790495787315, 7.849785458114297, 6.776532285912371, 5.761870167340398, 4.813218443740719, 3.8987240255116884, 2.9629328569088345, 3.809357682308514, 4.836811808475385, 5.752360651429721, 6.695049249532514, 7.709834170238746, 8.733767724335895, 9.758032668395208, 10.741740175333875, 11.730427552418455, 12.770972171161189, 11.858514084879355, 11.656901287076307, 10.715375906230747, 9.668914625211478, 8.672719795972549, 7.747358299987517, 6.814621786769221, 5.852753832643993, 4.87912454766613, 4.0270617563604585, 4.871473369650133, 5.808130860091943, 6.7803292705164155, 7.719142652807075, 8.73385465383788, 9.660654101490136, 10.683940621507597, 11.698093332133256, 12.692692818030922, 13.636598597320047, 12.603920499949009, 12.71614591941949, 11.716042438580676, 10.663565791643826, 9.603590111185374, 8.773286674520815, 7.746648156488809, 6.826817752710901, 5.839287092274548, 5.087106571768427, 5.87662917439821, 6.81154671664263, 7.763902679210332, 8.656440505337603, 9.696269258139772, 10.612092995430162, 11.604666142771567, 12.584290455808734, 13.543247088042254, 14.598286789560145, 13.611837791398965, 13.614909105972412, 12.669088276874966, 11.621462159520961, 10.5762560140925, 9.777034116456184, 8.760081444167238, 7.825544563053366, 6.802633708251226, 6.081497306678892, 6.87570291036136, 7.765111351929308, 8.787244165974162, 9.614981442211425, 10.627402348944834, 11.62689577023725, 12.577602505219412, 13.583589376223365, 14.56242285337271, 15.54773839324247, 14.636607327882281, 14.581015754241692, 13.600307611225748, 12.597218956171742, 11.650198431546274, 10.728530936871502, 9.73329578377652, 8.88688347165866, 7.865066688882002, 7.1435435057962255, 7.942030775866284, 8.780960251126077, 9.743692991495019, 10.546463205340977, 11.507120439885012, 12.478244813402076, 13.453880462208174, 14.405042823248623, 15.460745934311616, 16.474983701003335, 15.531013062796367, 15.593873658847034, 14.579289863142067, 13.617682946907635, 12.654219355616394, 11.634912708663382, 10.660427980953585, 9.860450966167345, 8.861131274672237, 8.196478930776848, 8.97798101491636, 9.79570495985964, 10.702830650292775, 11.559293477396052, 12.538536259929636, 13.457869018609593, 14.40935057871411, 15.427064688684808, 16.367917018128203, 17.312483934462563, 16.486245986524217, 16.564050137009158, 15.552365151273982, 14.591713186608066, 13.54470521508802, 12.596410032984004, 11.60274388221576, 10.79537078631346, 9.831730907451172, 9.226772360743881, 10.050899672399293, 10.815188333107178, 11.074687850623816, 11.994843580089535, 12.885291925666616, 13.870637288208473, 14.739698889533997, 15.728964228620237, 16.602693510191838, 17.558520542112976, 17.413084427246062], [18.46567304472336, 17.50669778945043, 16.527360776013218, 15.586724351537896, 14.558489711906848, 13.606795018957653, 12.615629532063023, 11.707083152125989, 10.767426014926889, 10.06147180242797, 10.206197367162524, 11.141628614782048, 11.780267970276933, 12.719770382803224, 13.539997352628438, 14.528474972749335, 15.485860451722926, 16.510233048951203, 17.48625459574005, 18.512992192090156, 17.50745055374046, 16.556346960368177, 15.536847897709213, 14.588310676505522, 13.52846028272769, 12.627593100640398, 11.665502828442834, 10.763642834327207, 9.711880208533799, 9.024664205240143, 9.881143301437904, 10.614909076586883, 11.565400697526043, 12.581827869943313, 13.463538274349599, 14.436371259565385, 15.450200570278815, 16.378522414942992, 17.33794938532723, 18.38307463248048, 16.463727900706733, 15.52257276088384, 14.565813169055248, 13.599647448891595, 12.600807016084264, 11.58799337174085, 10.662772729107315, 9.711106005610073, 8.695443016827694, 8.002067027064554, 8.86029760797346, 9.615123766647024, 10.55018507185051, 11.540946921495008, 12.51524569475677, 13.453878730282893, 14.403737463487639, 15.456433057081835, 16.412551234244066, 17.3643805639159, 15.511768457214528, 14.576245107905038, 13.591402939674879, 12.662793920170229, 11.623534408620854, 10.604664225049474, 9.656183447596902, 8.66507491319468, 7.6795245630363995, 6.943391307419738, 7.801238795220084, 8.626758900826376, 9.590662181922502, 10.553210622278252, 11.528438727605723, 12.572469056574601, 13.500987683014733, 14.436105758821443, 15.42671704589962, 16.411560693176888, 14.586192805790914, 13.637231185927389, 12.608926129897746, 11.65077493311661, 10.641272486860514, 9.713732411517414, 8.668434914493302, 7.727731515211428, 6.687398452912027, 5.876852671575042, 6.746023067888032, 7.687389200413826, 8.722007336430174, 9.664077011681707, 10.549609481376141, 11.571871857824874, 12.53358128003261, 13.462444629809813, 14.4808542640367, 15.441341877230856, 13.59296357646015, 12.612163925352858, 11.662926028917832, 10.737539111273993, 9.698709650240136, 8.671129863064849, 7.733954409273784, 6.765424648076964, 5.7554450952768414, 4.8279112836471265, 5.774058175302599, 6.726459576560243, 7.716978548098404, 8.645937496433529, 9.62374786635866, 10.602985389056464, 11.530318389941455, 12.515010169486573, 13.56709595133946, 14.38067037717729, 12.648932833665102, 11.634760784709282, 10.673578308117165, 9.712466673581302, 8.735189101896609, 7.785136270661795, 6.843514709466438, 5.796418811348763, 4.828701746917147, 3.8861573757251637, 4.812939620921421, 5.742047243992471, 6.724215085164036, 7.714132491400989, 8.710922073727344, 9.662619955576151, 10.594721635389357, 11.539148232086678, 12.54754052564307, 13.45124004741445, 11.669131010214047, 10.668672010797511, 9.691267230965728, 8.68138972799982, 7.709833253017212, 6.816859201498451, 5.8824147217310685, 4.815036827415598, 3.865781982031827, 2.944683339114506, 3.8516339159473025, 4.874961945390846, 5.751643099067797, 6.710446784286493, 7.637563605612237, 8.608560770520377, 9.538147370621015, 10.477102694973038, 11.52815691013022, 12.514153817539905, 10.71126001365935, 9.648075216349612, 8.654374533190175, 7.72633694201215, 6.7790726245181805, 5.774528092023364, 4.8382469947927245, 3.8109888054080088, 2.8464181693885036, 1.9064688390644258, 2.8395907242355305, 3.8525991127728516, 4.787756837832053, 5.682378631620935, 6.711689800527911, 7.693588869207818, 8.621306451903383, 9.694881490237355, 10.761699107054568, 11.76062355062086, 9.775856465236501, 8.77071738997431, 7.800013756613885, 6.818888680114691, 5.860999797520815, 4.850119910006591, 3.8769759787824847, 2.9348411851780676, 1.8913632971708538, 0.9607083617513718, 1.937915900660177, 2.8630893593972195, 3.8020495944760873, 4.748658134806619, 5.735644727039546, 6.73147116474341, 7.670854600045321, 8.74511322839484, 9.769806395237573, 10.78457414324801, 9.0454692667145, 8.010796732890892, 7.066677066807967, 5.997311405616736, 4.996643366701862, 4.023015497065739, 2.9545554653500217, 1.9630126646624593, 0.9971332127785085, 0.0, 1.0014650022699574, 1.9802911736899254, 2.926506943855477, 3.998190462582876, 5.0639020250246825, 6.014710571719787, 6.999023972442308, 8.010646048569361, 8.975590896423348, 9.95364304998659, 9.885171404477843, 8.9572182925322, 7.986584537982062, 6.947964780463865, 5.90057705459013, 4.830829286908904, 3.898166152377831, 2.9527203646059257, 1.9471170107199605, 1.0219956804679544, 1.952814560567485, 2.957563870812905, 3.9961909800051383, 5.001800735378403, 6.0245634568314195, 6.973755722216068, 7.937822732180705, 8.864636560694048, 9.838889873119076, 10.840776782870758, 10.878828385046193, 9.926781875454553, 8.975709413916546, 7.903797412265756, 6.838488624107979, 5.828737068731276, 4.845428119200251, 3.941330868074909, 2.9723141520316245, 2.024343568270413, 2.9923702064986983, 3.8851011329576286, 4.872178464482137, 5.914920587747433, 6.985351601505688, 8.028754547818416, 8.959952794015432, 9.87023929592415, 10.825222283240754, 11.79479163848832, 11.87817084816115, 10.835620513941834, 9.81503817065166, 8.846918670892807, 7.77366549869088, 6.759003380118907, 5.810351656519227, 4.895077030601646, 3.9592858619987923, 2.9554680268944598, 3.9829221530613315, 4.865675592334968, 5.808364190437761, 6.823149111143993, 7.8470826652411425, 8.871347609300456, 9.855055116239123, 10.843742493323703, 11.803902059649536, 12.75047150018349, 12.654034499854816, 11.712509119009257, 10.666047837989987, 9.669853008751058, 8.744491512766027, 7.8117549995477304, 6.849887045422501, 5.875477552756088, 4.986261537029503, 4.017583714236078, 4.9542412046778885, 5.8936442114216625, 6.832457593712322, 7.847169594743128, 8.773969042395382, 9.797255562412845, 10.811408273038504, 11.80600775893617, 12.749913538225295, 13.601053712727518, 13.713279132198, 12.713175651359185, 11.660699004422336, 10.600723323963884, 9.770419887299324, 8.743781369267317, 7.823950965489409, 6.8356400973645055, 6.046306352437472, 5.022739518984156, 5.957657061228575, 6.877217620115579, 7.76975544624285, 8.80958419904502, 9.725407936335408, 10.717981083676813, 11.69760539671398, 12.6565620289475, 13.727821858704973, 14.608971004177475, 14.61204231875092, 13.666221489653473, 12.61859537229947, 11.57338922687101, 10.774167329234693, 9.756434449257195, 8.821897568143324, 7.798986713341184, 7.022215499567548, 6.021813254947306, 6.911221696515254, 7.920871291941665, 8.728296383116673, 9.740717289850082, 10.740210711142495, 11.690917446124658, 12.696904317128611, 13.675737794277955, 14.661053334147716, 15.633740540660789, 15.5781489670202, 14.597440824004256, 13.594352168950252, 12.647331644324783, 11.72488394196146, 10.729648788866477, 9.883236476748618, 8.86141969397196, 8.01856255267416, 7.08814112045223, 7.9270705957120216, 8.889803336080963, 9.659778146246225, 10.62043538079026, 11.591559754307324, 12.567195403113422, 13.51835776415387, 14.574060875216864, 15.588298641908583, 16.528146275574876, 16.59100687162554, 15.576423075920575, 14.614816159686145, 13.651352568394904, 12.63126571375334, 11.656780986043543, 10.856803971257303, 9.857484279762197, 9.071497977654783, 8.124091359502305, 8.941815304445585, 9.84894099487872, 10.6726084183013, 11.651851200834884, 12.57118395951484, 13.522665519619357, 14.540379629590056, 15.481231959033451, 16.42579887536781, 17.39179707974269, 17.560403142099116, 16.54871815636394, 15.588066191698024, 14.541058220177979, 13.592763038073961, 12.599096887305718, 11.791723791403419, 10.828083912541132, 10.101791407621816, 9.197010016985239, 9.961298677693124, 10.83592484961233, 11.60058323724775, 12.530002073719496, 13.513479153367975, 14.491207876472968, 15.480473215559208, 16.49321884264451, 17.49222347288515, 18.318635520464532], [18.27934933041255, 17.460725826980497, 16.485231178255933, 15.514091516081072, 14.485856876450024, 13.530743065403165, 12.55308611010746, 11.641765307995668, 10.939637221100469, 10.108809601078793, 9.988946759423225, 10.818980147541787, 11.744266103778285, 12.686082742412525, 13.50089328990763, 14.489370910028526, 15.446756389002118, 16.471128986230394, 17.45743699631919, 18.484174592669294, 18.36423577968772, 17.524288664196874, 16.50478960153791, 15.556252380334222, 14.49640198655639, 13.595534804469096, 12.633444532271533, 11.731584538155904, 10.679821912362495, 9.992605909068839, 9.045878906660587, 9.756700358728724, 10.707191979667883, 11.723619152085153, 12.573765294336976, 13.546598279552763, 14.560427590266192, 15.48874943493037, 16.409347000486658, 17.454472247639906, 17.320513126653996, 16.49051446471254, 15.533754872883948, 14.567589152720295, 13.568748719912964, 12.555935075569549, 11.630714432936013, 10.67904770943877, 9.66338472065639, 8.97000873089325, 8.025033213196142, 8.756915048788864, 9.69197635399235, 10.682738203636848, 11.625472714744147, 12.56410575027027, 13.507149624714222, 14.540941823811501, 15.483948849403493, 16.435778179075328, 16.30216508165671, 15.544186811733734, 14.559344643503575, 13.630735623998925, 12.59147611244955, 11.572605928878172, 10.6241251514256, 9.633016617023378, 8.647466266865097, 7.911333011248434, 6.965974400442767, 7.768550182968216, 8.732453464064342, 9.695001904420092, 10.605566758802553, 11.649597087771431, 12.578115714211563, 13.513233790018273, 14.498114661059049, 15.449034593575997, 15.376589430233098, 14.605172889756085, 13.576867833726443, 12.618716636945306, 11.60921419068921, 10.68167411534611, 9.636376618321998, 8.695673219040124, 7.655340156740724, 6.8447943754037395, 5.910758673110715, 6.829180482555666, 7.863798618572015, 8.78341507552306, 9.626737512572971, 10.648999889021704, 11.61070931122944, 12.539572661006643, 13.55225187919613, 14.478815777629965, 14.368487336837076, 13.580105629181555, 12.630867732746529, 11.705480815102689, 10.666651354068833, 9.639071566893545, 8.701896113102482, 7.733366351905661, 6.723386799105539, 5.795852987475824, 4.938793780525282, 5.868250858702083, 6.858769830240244, 7.765275560274881, 8.70087589755549, 9.680113420253294, 10.594449180423524, 11.55248406988568, 12.604569851738567, 13.418144277576399, 13.487855339081037, 12.605394628687879, 11.644212152095761, 10.683100517559899, 9.705822945875205, 8.755770114640391, 7.814148553445035, 6.76705265532736, 5.799335590895744, 4.854099079553861, 3.9173296945578078, 4.844365251755569, 5.822277970179748, 6.751606391800097, 7.748395974126452, 8.70009385597526, 9.632195535788465, 10.576622132485785, 11.585014426042177, 12.488713947813558, 12.579591278246248, 11.639305854776108, 10.661901074944325, 9.652023571978416, 8.680467096995809, 7.7874930454770475, 6.853048565709665, 5.785670671394195, 4.836415826010423, 3.9126250429432035, 2.956023989583689, 3.912435845789955, 4.789116999466906, 5.747920684685601, 6.675037506011345, 7.6460346709194855, 8.575621271020124, 9.514576595372146, 10.565630810529328, 11.551627717939013, 11.681893857637947, 10.618709060328209, 9.625008377168772, 8.696970785990747, 7.749706468496777, 6.745161936001961, 5.808880838771321, 4.781622649386605, 3.8170520133670998, 2.877102683043022, 1.943980797871917, 2.89007301317196, 3.825230738231162, 4.7198525320200435, 5.74916370092702, 6.731062769606926, 7.65878035230249, 8.732355390636464, 9.799173007453676, 10.802736568830147, 10.76774544345322, 9.76260636819103, 8.791902734830604, 7.810777658331411, 6.852888775737535, 5.84200888822331, 4.868864956999203, 3.926730163394786, 2.8832522753875724, 1.9525973399680905, 0.9753898010592852, 1.900563259796328, 2.8395234948751957, 3.7861320352057275, 4.773118627438654, 5.7689450651425185, 6.70832850044443, 7.782587128793949, 8.807280295636682, 9.822048043647118, 9.89456284870441, 9.012261735160852, 8.068142069077926, 6.998776407886694, 5.99810836897182, 5.024480499335697, 3.9560204676199793, 2.964477666932417, 1.998598215048466, 1.0014650022699574, 0.0, 0.978826171419968, 1.9250419415855196, 2.996725460312919, 4.062437022754725, 5.01324556944983, 5.997558970172351, 7.009181046299403, 7.974125894153391, 8.952178047716632, 10.820447614425534, 9.939198083607662, 8.921305209132719, 7.88268545161452, 6.835297725740785, 5.76554995805956, 4.8328868235284865, 3.8874410357565816, 2.8563402664180564, 1.9312189361660501, 0.9513495582975277, 1.9560988685429477, 2.9947259777351807, 4.000335733108446, 5.023098454561462, 5.972290719946111, 6.936357729910748, 7.86317155842409, 8.837424870849118, 9.864842236032619, 11.814104594993884, 10.908761666530015, 9.910430085067201, 8.83851808341641, 7.773209295258635, 6.7634577398819316, 5.780148790350906, 4.850554123773005, 3.8815374077297204, 2.9335668239685084, 2.000817009363623, 2.8836361306876714, 3.8707134622121804, 4.913455585477477, 5.983886599235731, 7.027289545548459, 7.958487791745476, 8.868774293654193, 9.823757280970796, 10.793326636218362, 12.726482947410245, 11.76724353982068, 10.746661196530505, 9.778541696771653, 8.705288524569726, 7.690626405997753, 6.741974682398073, 5.804300286299743, 4.868509117696888, 3.8646912825925552, 3.0602689310796984, 3.864210590065011, 4.806899188167804, 5.821684108874035, 6.845617662971185, 7.8698826070304975, 8.853590113969165, 9.842277491053744, 10.802437057379578, 11.749006497913532, 13.585657525733662, 12.644132144888102, 11.597670863868833, 10.601476034629904, 9.676114538644873, 8.743378025426576, 7.781510071301347, 6.784700808454184, 5.895484792727599, 4.926806969934174, 4.031587982696256, 4.892179209151705, 5.830992591442365, 6.8457045924731705, 7.772504040125426, 8.795790560142887, 9.809943270768546, 10.804542756666212, 11.748448535955337, 12.785609189728907, 14.644902158076846, 13.64479867723803, 12.592322030301181, 11.53234634984273, 10.70204291317817, 9.675404395146163, 8.744281248629795, 7.744863353062602, 6.955529608135567, 5.931962774682251, 5.035003839246943, 5.875752617845622, 6.768290443972893, 7.8081191967750625, 8.723942934065452, 9.716516081406857, 10.696140394444024, 11.655097026677543, 12.726356856435016, 13.712805854596196, 15.543665344629765, 14.59784451553232, 13.550218398178316, 12.505012252749856, 11.684458267563823, 10.665657704955292, 9.73112082384142, 8.70820996903928, 7.931438755265644, 6.931036510645401, 5.98856847453362, 6.9194062896717075, 7.726831380846716, 8.739252287580124, 9.738745708872539, 10.689452443854702, 11.695439314858655, 12.674272792007999, 13.65958833187776, 14.63481174613465, 16.482784296048933, 15.529063849883102, 14.525975194829098, 13.578954670203629, 12.634107197659556, 11.638872044564573, 10.792459732446712, 9.770642949670055, 8.927785808372256, 7.997364376150325, 7.004417373730388, 7.93136722681785, 8.658313143976269, 9.618970378520304, 10.590094752037368, 11.565730400843465, 12.516892761883915, 13.572595872946907, 14.586833639638627, 15.53278698749426, 17.385132295055936, 16.50804610179942, 15.54643918556499, 14.565517987865947, 13.540488969451436, 12.56600424174164, 11.766027226955398, 10.766707535460291, 9.980721233352877, 9.0333146152004, 8.019162082463952, 8.890504885615606, 9.671143416031343, 10.650386198564927, 11.569718957244884, 12.521200517349401, 13.5389146273201, 14.479766956763495, 15.424333873097854, 16.390332077472735, 18.3760174982422, 17.457941412062034, 16.49728944739612, 15.450281475876073, 14.501986293772056, 13.508320143003814, 12.700947047101513, 11.737307168239226, 11.01101466331991, 10.106233272683333, 9.03864545571149, 9.877488740349214, 10.599118234977794, 11.52853707144954, 12.512014151098018, 13.489742874203012, 14.479008213289251, 15.491753840374555, 16.490758470615194, 17.31717051819458], [17.378219500618883, 16.559595997186833, 15.58410134846227, 14.61296168628741, 13.584727046656361, 12.629613235609503, 11.651956280313797, 10.740635478202005, 10.038507391306807, 11.016025222748809, 10.809432025014296, 9.976790588750966, 10.902076544987464, 11.843893183621704, 12.63160614972815, 13.620083769849046, 14.577469248822638, 15.601841846050913, 16.588149856139708, 17.614887452489814, 17.49494863950824, 17.594113289425234, 16.574614226766272, 15.654763087266955, 14.598049780436568, 13.608815153926757, 12.602082983933986, 11.790283434063996, 11.094053197699896, 10.819759860681536, 9.866364172251657, 8.914510799937903, 9.865002420877062, 10.881429593294332, 11.704478154157496, 12.677311139373282, 13.691140450086712, 14.619462294750889, 15.54005986030718, 16.58518510746043, 16.451225986474515, 17.38138194561873, 16.512581044303918, 15.546415324140263, 14.547574891332932, 13.534761246989516, 12.609540604355981, 11.657873880858737, 10.642210892076358, 9.865731748539483, 8.845518478787213, 7.914725489998043, 8.84978679520153, 9.840548644846027, 10.756185574564666, 11.69481861009079, 12.637862484534741, 13.67165468363202, 14.614661709224013, 15.566491038895846, 15.43287794147723, 16.37029200649753, 15.538170814923543, 14.609561795418893, 13.570302283869518, 12.55143210029814, 11.602951322845568, 10.611842788443345, 9.626292438285065, 8.890159182668402, 7.944800571862735, 6.926360624177395, 7.890263905273521, 8.852812345629271, 9.736279618623072, 10.78030994759195, 11.708828574032083, 12.643946649838792, 13.628827520879568, 14.579747453396514, 14.507302290053616, 15.45626390991714, 14.55569400514641, 13.597542808365274, 12.588040362109178, 11.66050028676608, 10.615202789741968, 9.674499390460094, 8.634166328160692, 7.823620546823707, 6.889584844530683, 5.986990923764845, 7.021609059781194, 7.914127935343577, 8.75745037239349, 9.779712748842224, 10.74142217104996, 11.670285520827163, 12.682964739016649, 13.609528637450483, 13.499200196657593, 14.558931800601522, 13.609693904166496, 12.684306986522657, 11.6454775254888, 10.617897738313514, 9.680722284522451, 8.71219252332563, 7.7022129705255065, 6.7746791588957915, 5.91761995194525, 5.026061299911262, 6.016580271449423, 6.8959884200953985, 7.831588757376008, 8.810826280073814, 9.725162040244042, 10.683196929706199, 11.735282711559087, 12.548857137396917, 12.618568198901555, 13.584220800107847, 12.623038323515729, 11.661926688979866, 10.684649117295173, 9.73459628606036, 8.792974724865003, 7.745878826747328, 6.778161762315712, 5.832925250973829, 4.896155865977775, 4.002175692964748, 4.952990830000266, 5.882319251620615, 6.87910883394697, 7.830806715795777, 8.762908395608983, 9.707334992306304, 10.715727285862696, 11.619426807634076, 11.710304138066766, 12.618132026196076, 11.640727246364293, 10.630849743398384, 9.659293268415777, 8.766319216897015, 7.831874737129633, 6.764496842814163, 5.815241997430391, 4.891451214363171, 3.9348501610036566, 3.070246286999134, 3.9198298592874234, 4.878633544506119, 5.805750365831863, 6.776747530740003, 7.7063341308406414, 8.645289455192664, 9.696343670349846, 10.68234057775953, 10.900038356835575, 11.597535231748177, 10.60383454858874, 9.675796957410714, 8.728532639916745, 7.7239881074219285, 6.787707010191289, 5.760448820806573, 4.7958781847870675, 3.8559288544629897, 2.922806969291885, 2.047883454381139, 2.9559435980516797, 3.8505653918405613, 4.879876560747538, 5.861775629427444, 6.789493212123008, 7.863068250456981, 8.929885867274194, 9.933449428650665, 9.96195865407535, 10.741432539610997, 9.770728906250572, 8.789603829751378, 7.8317149471575025, 6.8208350596432785, 5.8476911284191715, 4.905556334814754, 3.8620784468075406, 2.9314235113880587, 1.9542159724792532, 1.058373701005507, 1.970236354695714, 2.9168448950262453, 3.9038314872591724, 4.899657924963036, 5.839041360264948, 6.913299988614467, 7.9379931554572, 8.952760903467636, 8.915736677284443, 9.95040921110805, 9.046968240497893, 7.977602579306661, 6.976934540391788, 6.003306670755665, 4.9348466390399475, 3.9433038383523846, 2.9774243864684338, 1.9802911736899254, 0.978826171419968, 0.0, 0.9462157701655517, 2.017899288892951, 3.083610851334757, 4.034419398029862, 5.018732798752383, 6.030354874879436, 6.9952997227334235, 7.973351876296665, 9.841621443005565, 10.769574554951207, 9.900131380552686, 8.861511623034488, 7.814123897160753, 6.7443761294795275, 5.811712994948454, 4.866267207176549, 3.835166437838024, 2.910045107586018, 1.9301757297174955, 1.0549690387492847, 2.015899806315213, 3.021509561688478, 4.044272283141495, 4.993464548526143, 5.95753155849078, 6.884345387004123, 7.858598699429149, 8.88601606461265, 10.835278423573914, 11.73913813787356, 10.889256256487169, 9.817344254836378, 8.752035466678603, 7.742283911301899, 6.758974961770874, 5.829380295192973, 4.860363579149688, 3.876059269261923, 2.9080326310336377, 1.9825063008940087, 2.9695836324185176, 4.012325755683814, 5.0754177701667444, 6.064545377070869, 6.979661620325508, 7.889948122234225, 8.844931109550828, 9.814500464798394, 11.747656775990277, 12.67940570744741, 11.725487367950473, 10.75736786819162, 9.684114695989694, 8.66945257741772, 7.720800853818041, 6.78312645771971, 5.836374461634368, 4.80718372788597, 3.9674845527497133, 2.9630807602713483, 3.9057693583741413, 4.920554279080373, 5.944487833177523, 6.968752777236835, 7.952460284175503, 8.940844924486427, 9.82361088595961, 10.770180326493564, 12.720538726891515, 13.62295831630807, 12.576497035288801, 11.580302206049872, 10.65494071006484, 9.722204196846544, 8.760336242721316, 7.763526979874152, 6.837977238021014, 5.869299415227589, 4.938803604366271, 3.9910493793580426, 4.929862761648702, 5.944574762679508, 6.871374210331764, 7.894660730349224, 8.908813440974882, 9.903110190098895, 10.84701596938802, 11.825288477071515, 13.779783359234699, 14.623624848657998, 13.571148201721149, 12.511172521262697, 11.680869084598138, 10.654230566566131, 9.723107420049763, 8.72368952448257, 7.898022053428982, 6.874455219975666, 5.942219460916958, 4.97462278805196, 5.86716061417923, 6.9069893669814, 7.822813104271789, 8.815386251613194, 9.795010564650362, 10.753967196883881, 11.825227026641354, 12.811676024802534, 14.755380138250857, 15.576670686952287, 14.529044569598284, 13.483838424169823, 12.66328443898379, 11.64448387637526, 10.709946995261388, 9.687036140459247, 8.87393120055906, 7.873528955938816, 6.895784096203636, 6.018276459878045, 6.825701551053053, 7.838122457786461, 8.837615879078877, 9.78832261406104, 10.794309485064993, 11.773142962214337, 12.758458502084098, 13.733681916340988, 15.581654466255273, 16.50789002130307, 15.504801366249065, 14.557780841623597, 13.612933369079524, 12.617698215984541, 11.77128590386668, 10.749469121090023, 9.87027825366567, 8.93985682144374, 7.911632995400404, 7.030237397024187, 7.7571833141826065, 8.717840548726642, 9.688964922243706, 10.664600571049803, 11.615762932090252, 12.671466043153245, 13.685703809844965, 14.631657157700598, 16.48400246526227, 17.486872273219387, 16.52526535698496, 15.544344159285915, 14.519315140871404, 13.544830413161607, 12.744853398375366, 11.74553370688026, 10.923213678646292, 9.975807060493816, 8.926377704133968, 7.989375055821944, 8.770013586237681, 9.749256368771265, 10.668589127451222, 11.620070687555739, 12.637784797526438, 13.578637126969832, 14.523204043304192, 15.48920224767907, 17.47488766844853, 17.516465615690123, 16.555813651024206, 15.578193387842985, 14.629898205738968, 13.57250661505087, 12.77193977502151, 11.854260602723265, 11.016627795911198, 11.01742822724678, 9.945861077381506, 8.976358910555552, 9.697988405184132, 10.627407241655877, 11.610884321304356, 12.58861304440935, 13.57787838349559, 14.590624010580893, 15.589628640821532, 16.416040688400912], [16.524561176060544, 15.705937672628494, 14.73044302390393, 13.75930336172907, 12.731068722098023, 11.775954911051164, 10.79829795575546, 9.886977153643668, 10.826634290842769, 11.851060568588373, 11.666704433289617, 10.834062997026287, 10.099400235384051, 10.946141176705233, 11.685390379562598, 12.673867999683495, 13.631253478657086, 14.655626075885362, 15.641934085974157, 16.668671682324263, 16.54873286934269, 16.740454964866895, 15.720955902207933, 14.801104762708617, 13.74439145587823, 12.755156829368419, 11.74842465937565, 10.936625109505659, 11.882180097235858, 11.677032268956857, 10.723636580526978, 9.771783208213224, 9.062326111273649, 9.98367758637786, 10.758262383991944, 11.73109536920773, 12.74492467992116, 13.673246524585338, 14.593844090141628, 15.638969337294878, 15.505010216308964, 16.43516617545318, 16.63705087549264, 15.670885155328985, 14.672044722521655, 13.782357361208891, 12.751154758711168, 11.9959179929804, 11.576149197943177, 10.723004156814804, 9.702790887062534, 8.771997898273364, 8.047110485598116, 8.927801664729975, 9.809969804399115, 10.748602839925239, 11.69164671436919, 12.72543891346647, 13.668445939058461, 14.620275268730294, 14.486662171311679, 15.424076236331976, 16.446933582233754, 15.543500101285714, 14.50424058973634, 13.485370406164959, 12.536889628712387, 11.545781094310165, 10.560230744151884, 9.798163308096889, 8.837200430196079, 7.783633032452716, 7.087587595670107, 7.9400653655132185, 8.790063848457521, 9.8340941774264, 10.762612803866531, 11.69773087967324, 12.682611750714017, 13.633531683230963, 13.561086519888065, 14.51004813975159, 15.489632311013231, 14.531481114232095, 13.521978667975999, 12.5944385926329, 11.549141095608787, 10.608437696326913, 9.568104634027511, 8.731624672252194, 7.781984702864027, 6.844263332040166, 6.099251799512434, 6.967912165178026, 7.811234602227939, 8.833496978676672, 9.795206400884409, 10.724069750661611, 11.736748968851098, 12.663312867284931, 12.552984426492042, 13.614724116971198, 14.543632210033318, 13.618245292389478, 12.579415831355622, 11.551836044180334, 10.61466059038927, 9.64613082919245, 8.636151276392326, 7.708617464762611, 6.810019810278594, 5.8833337081865835, 5.072478830789273, 5.949772649929847, 6.885372987210457, 7.864610509908262, 8.77894627007849, 9.736981159540647, 10.789066941393536, 11.602641367231366, 11.672352428736003, 12.686524477691822, 13.556976629382547, 12.595864994846684, 11.61858742316199, 10.668534591927179, 9.726913030731822, 8.679817132614147, 7.712100068182531, 6.766863556840648, 5.788555724311119, 4.859448101240069, 4.006775059834714, 4.9361034814550635, 5.932893063781418, 6.884590945630226, 7.816692625443432, 8.761119222140753, 9.769511515697145, 10.673211037468525, 10.764088367901214, 11.76454736731775, 12.57466555223111, 11.564788049265202, 10.593231574282594, 9.700257522763833, 8.765813042996452, 7.698435148680982, 6.74918030329721, 5.82538952022999, 4.868788466870476, 3.927518695274455, 2.973614089121872, 3.9324177743405673, 4.859534595666312, 5.830531760574452, 6.76011836067509, 7.699073685027113, 8.750127900184294, 9.73612480759398, 9.953822586670023, 11.000155224772621, 11.537772854455557, 10.609735263277532, 9.662470945783562, 8.657926413288747, 7.721645316058108, 6.6943871266733925, 5.729816490653887, 4.789867160329809, 3.8567452751587044, 2.948374663418859, 2.0097278278861284, 2.90434962167501, 3.9336607905819863, 4.915559859261893, 5.843277441957457, 6.916852480291429, 7.983670097108642, 8.987233658485113, 9.015742883909798, 10.013392658508222, 10.704667212117393, 9.723542135618198, 8.765653253024322, 7.754773365510098, 6.781629434285991, 5.839494640681574, 4.79601675267436, 3.865361817254878, 2.8881542783460725, 1.96298081960903, 1.0240205845301622, 1.9706291248606937, 2.9576157170936206, 3.953442154797485, 4.892825590099396, 5.967084218448916, 6.991777385291648, 8.006545133302085, 7.969520907118891, 9.0041934409425, 9.948313107025424, 8.923818349472214, 7.9231503105573395, 6.949522440921216, 5.881062409205499, 4.889519608517936, 3.9236401566339856, 2.926506943855477, 1.9250419415855196, 0.9462157701655517, 0.0, 1.0716835187273992, 2.1373950811692053, 3.08820362786431, 4.072517028586831, 5.084139104713883, 6.049083952567871, 7.027136106131112, 8.895405672840013, 9.823358784785656, 10.8412516592606, 9.807727393200041, 8.760339667326306, 7.690591899645081, 6.757928765114007, 5.812482977342102, 4.781382208003576, 3.85626087775157, 2.8763914998830473, 2.0011848089148363, 1.0696840361496611, 2.075293791522926, 3.0980565129759428, 4.047248778360592, 5.011315788325228, 5.93812961683857, 6.912382929263597, 7.939800294447098, 9.889062653408363, 10.792922367708009, 11.835472026652724, 10.763560025001933, 9.698251236844156, 8.688499681467452, 7.705190731936427, 6.775596065358525, 5.80657934931524, 4.822275039427474, 3.854248401199189, 2.92872207105956, 2.115925307860179, 3.1410071371441486, 4.129202000001192, 5.118329606905317, 6.033445850159955, 6.943732352068673, 7.898715339385275, 8.868284694632841, 10.801441005824724, 11.733189937281859, 12.671703138116024, 11.703583638357172, 10.630330466155245, 9.615668347583272, 8.667016623983592, 7.729342227885263, 6.782590231799919, 5.753399498051521, 4.913700322915265, 3.9092965304368996, 3.0521110338158026, 4.0668959545220345, 5.065144880894758, 6.08940982495407, 7.073117331892738, 7.994629154320874, 8.877395115794057, 9.823964556328011, 11.774322956725962, 12.715848337571522, 13.522712805454352, 12.526517976215423, 11.601156480230392, 10.668419967012095, 9.706552012886867, 8.709742750039705, 7.7841930081865645, 6.8155151853931395, 5.885019374531822, 4.9372651495235935, 4.076204437090364, 5.09091643812117, 6.017715885773425, 7.015317778066459, 8.029470488692118, 8.956894419933342, 9.900800199222466, 10.879072706905962, 12.833567589069146, 13.750070858814196, 14.5173639718867, 13.457388291428249, 12.62708485476369, 11.600446336731682, 10.669323190215316, 9.669905294648123, 8.844237823594533, 7.820670990141217, 6.888435231082509, 5.92083855821751, 5.013502289620892, 6.0533310424230615, 6.969154779713451, 7.961727927054856, 8.941352240092023, 9.900308872325542, 10.919899873086587, 11.886989998355919, 13.833902259122238, 14.779723088219685, 15.475260339763835, 14.430054194335375, 13.609500209149344, 12.590699646540813, 11.656162765426942, 10.6332519106248, 9.820146970724611, 8.819744726104368, 7.8419998663691874, 6.932567699836649, 5.972043226494715, 6.984464133228123, 7.983957554520537, 8.9346642895027, 9.940651160506654, 10.919484637655998, 11.89098036350468, 12.86620377776157, 14.714176327675855, 15.710942422570467, 16.451017136414617, 15.503996611789148, 14.559149139245077, 13.563913986150094, 12.717501674032233, 11.695684891255576, 10.816494023831222, 9.886072591609292, 8.857848765565956, 7.944528636982791, 6.903524989624268, 7.864182224168303, 8.835306597685367, 9.810942246491464, 10.762104607531914, 11.817807718594906, 12.818225671265546, 13.76417901912118, 15.630344140703933, 16.688457611480498, 16.550738979759213, 15.5681204922718, 14.54309147385729, 13.568606746147493, 12.809107588251154, 12.022183925898787, 11.869429448811843, 10.922022830659367, 9.85476160790807, 8.861365384731926, 7.916355261679343, 8.895598044212928, 9.814930802892883, 10.7664123629974, 11.784126472968099, 12.724978802411494, 13.669545718745853, 14.635543923120732, 16.621229343890196, 16.57024984552457, 15.609597880858654, 14.631977617677434, 13.683682435573417, 12.626290844885318, 11.874187768105038, 11.051584293119852, 11.87390020418652, 11.914936205891417, 10.843369056026143, 9.818623103415598, 8.844330080625795, 9.77374891709754, 10.757225996746017, 11.734954719851011, 12.72422005893725, 13.736965686022554, 14.735970316263193, 15.562382363842575], [15.536745677061445, 14.72243699154192, 13.746942342817357, 12.80027134863967, 11.784016585761279, 10.904059910367074, 10.27074603131044, 10.877208338480177, 11.816865475679277, 12.841291753424882, 12.60175303134258, 11.769111595079249, 11.0066812020661, 10.047169375911581, 10.769406284837878, 11.757883904958774, 12.715269383932366, 13.739641981160641, 14.725949991249436, 15.752687587599542, 15.632748774617973, 15.756954283780326, 14.737455221121362, 13.842072749619216, 12.814046014940438, 11.88326182868433, 11.220872734930628, 11.926856294342167, 12.872411282072367, 12.612080867009821, 11.658685178579942, 10.706831806266187, 9.969607077955697, 9.084705785584209, 9.842278289267224, 10.81511127448301, 11.82894058519644, 12.757262429860617, 13.677859995416908, 14.722985242570157, 14.589026121584245, 15.51918208072846, 15.706705434554847, 14.740539714391193, 13.741699281583863, 12.922861557583877, 12.223602834266147, 12.986149177816909, 12.558747033167599, 11.658052754867768, 10.637839485115498, 9.707046496326328, 8.954391452280165, 8.028829863936323, 8.893985709674395, 9.832618745200518, 10.77566261964447, 11.809454818741749, 12.752461844333741, 13.704291174005574, 13.57067807658696, 14.508092141607257, 15.530949487509037, 15.805094081496918, 14.803536547986747, 13.906190704275254, 13.23019211577656, 12.528378929534586, 11.542828579376305, 10.733211906149855, 9.772249028249044, 8.71868163050568, 7.994868562352155, 7.041093564719567, 7.874079753732802, 8.918110082701679, 9.846628709141811, 10.78174678494852, 11.766627655989296, 12.717547588506244, 12.645102425163346, 13.59406404502687, 14.593978019661419, 15.514078949456517, 14.50457650320042, 13.57703642785732, 12.531738930833209, 11.591035531551334, 10.550702469251933, 9.666673270305159, 8.717033300916992, 7.7793119300931295, 7.006532766194482, 6.068940364384376, 6.895250507503219, 7.917512883951954, 8.87922230615969, 9.808085655936893, 10.820764874126377, 11.747328772560213, 11.637000331767323, 12.69874002224648, 13.647977918681505, 14.573364836325345, 13.562013666580043, 12.534433879404755, 11.597258425613692, 10.62872866441687, 9.618749111616747, 8.691215299987032, 7.745068408331559, 6.818382306239547, 5.979759797471321, 5.050800849136197, 5.969388892485737, 6.948626415183543, 7.862962175353771, 8.820997064815929, 9.873082846668815, 10.686657272506647, 10.756368334011285, 11.770540382967104, 12.731722859559222, 13.590110274714096, 12.612832703029403, 11.66277987179459, 10.721158310599234, 9.67406241248156, 8.706345348049943, 7.761108836708062, 6.723604322364084, 5.794496699293034, 4.941823657887679, 4.037131680661413, 5.016908969056699, 5.9686068509055055, 6.900708530718713, 7.845135127416033, 8.853527420972425, 9.757226942743806, 9.848104273176496, 10.848563272593031, 11.844815366471057, 12.559033329132614, 11.587476854150006, 10.694502802631245, 9.760058322863864, 8.692680428548394, 7.7434255831646235, 6.819634800097404, 5.863033746737889, 4.8625672933274195, 3.9086626871748367, 3.0334459735469173, 3.9435505009415923, 4.9145476658497325, 5.844134265950371, 6.783089590302394, 7.834143805459576, 8.82014071286926, 8.882139067942624, 9.928471706045222, 10.891570399579939, 11.603980543144944, 10.656716225650975, 9.65217169315616, 8.71589059592552, 7.688632406540805, 6.7240617705213, 5.784112440197222, 4.850990555026117, 3.8834232614718234, 2.944776425939093, 2.00537782088136, 3.0176766958572667, 3.9808889339002156, 4.90860651659578, 5.982181554929753, 7.048999171746965, 7.952845845259101, 7.944059365182398, 8.941709139780823, 9.858595433594644, 10.717787415485612, 9.759898532891736, 8.749018645377511, 7.775874714153404, 6.833739920548987, 5.790262032541773, 4.859607097122291, 3.8823995582134856, 2.957226099476443, 2.0182658643975753, 1.071657324067044, 2.022944791731944, 3.0187712294358082, 3.9581546647377195, 5.032413293087239, 6.043683433556848, 6.9721573200760725, 6.897837388391492, 7.932509922215099, 8.876629588298025, 9.945995249489256, 8.994833829284739, 8.021205959648615, 6.952745927932898, 5.961203127245335, 4.9953236753613846, 3.998190462582876, 2.996725460312919, 2.017899288892951, 1.0716835187273992, 0.0, 1.0657115624418063, 2.016520109136911, 3.000833509859432, 4.012455585986484, 4.977400433840472, 5.955452587403713, 7.823722154112614, 8.751675266058257, 9.7695681405332, 10.808187898051397, 9.832023186053704, 8.762275418372479, 7.829612283841406, 6.884166496069501, 5.853065726730975, 4.927944396478969, 3.9480750186104467, 3.0728683276422357, 2.0599152209861717, 1.0543054656129065, 2.026372994248544, 2.9755652596331923, 3.939632269597829, 4.8664460981111715, 5.840699410536198, 6.868116775719699, 8.817379134680964, 9.72123884898061, 10.774623843457343, 11.83524354372933, 10.769934755571555, 9.76018320019485, 8.776874250663825, 7.847279584085924, 6.878262868042639, 5.893958558154874, 4.9259319199265885, 4.0004055897869595, 3.1061564926966896, 2.1200188112341287, 3.057518481273793, 4.046646088177918, 4.961762331432556, 5.872048833341274, 6.827031820657876, 7.796601175905442, 9.729757487097327, 10.66150641855446, 11.682088761844634, 12.650208261603487, 11.702013984882644, 10.68735186631067, 9.738700142710991, 8.80102574661266, 7.854273750527319, 6.825083016778921, 5.985383841642664, 4.980980049164299, 4.042342218652313, 3.1684847652340844, 3.9934613621673587, 5.017726306226671, 6.001433813165339, 6.922945635593475, 7.805711597066659, 8.752281037600614, 10.702639437998565, 11.644164818844125, 12.685043085314705, 13.598201494942824, 12.672839998957791, 11.740103485739494, 10.778235531614266, 9.781426268767103, 8.855876526913963, 7.887198704120539, 6.956702893259221, 6.008948668250993, 5.066435621926874, 4.1925052488332195, 4.957627459012496, 5.94363425933906, 6.957786969964718, 7.8852109012059435, 8.829116680495067, 9.807389188178565, 11.761884070341749, 12.678387340086799, 13.679694251747053, 14.52907181015565, 13.698768373491088, 12.672129855459081, 11.741006708942713, 10.74158881337552, 9.915921342321932, 8.892354508868616, 7.960118749809908, 6.99252207694491, 6.003733474457402, 5.26738549577119, 5.909066352952522, 6.901639500293927, 7.881263813331094, 8.840220445564613, 9.848216354359188, 10.815306479628521, 12.762218740394841, 13.708039569492287, 14.637590619624188, 15.501737713062775, 14.681183727876741, 13.66238316526821, 12.727846284154339, 11.704935429352197, 10.891830489452008, 9.891428244831765, 8.913683385096586, 7.922798884673159, 6.962274411331225, 6.21140362647756, 6.923869127759608, 7.8745758627417715, 8.880562733745725, 9.859396210895069, 10.81929684477728, 11.79452025903417, 13.642492808948456, 14.63925890384307, 15.62273818985708, 15.61882229521571, 14.574990001694822, 13.579754848599839, 12.883703281966188, 12.767368409982973, 11.87486359185584, 10.94444215963391, 9.897492562188244, 8.934759821819302, 7.893756174460778, 7.219553866219185, 7.9634115970012775, 8.827441565404891, 9.77860392644534, 10.834307037508333, 11.746542152538147, 12.69249550039378, 14.642528641704834, 15.618241155759389, 15.634754885034491, 14.65213639754708, 13.62710737913257, 12.652622651422773, 11.910135787457502, 12.929464892580835, 12.924153944316188, 11.916589051388522, 10.844992792744579, 9.851596569568434, 8.906586446515853, 8.270780338527539, 8.943035802208794, 9.782911681910827, 10.800625791881526, 11.74147812132492, 12.68604503765928, 13.647728424121633, 15.633413844891095, 15.65426575079985, 14.693613786133934, 13.715993522952713, 12.767698340848696, 11.710306750160598, 10.975215967311387, 11.9588652598019, 12.808948802239481, 12.905167390727925, 11.833600240862651, 10.808854288252107, 9.834561265462304, 9.24619699265252, 9.885330996061928, 10.751454038764438, 11.740719377850677, 12.75346500493598, 13.75246963517662, 14.574566864843476], [14.47103411461964, 13.656725429100115, 12.681230780375552, 11.734559786197863, 10.718305023319472, 9.838348347925269, 10.844860440170752, 11.697398964947345, 12.637056102146445, 13.66148237989205, 13.4743155287986, 12.641674092535268, 11.700129013537165, 10.691736580601356, 9.70369472239607, 10.692172342516967, 11.649557821490559, 12.673930418718834, 13.66023842880763, 14.686976025157737, 14.567037212176164, 14.69124272133852, 13.671743658679556, 12.77636118717741, 11.74833445249863, 10.817550266242524, 11.79498714379094, 12.747046920809336, 13.692601908539535, 13.48464336446584, 12.531247676035962, 11.579394303722207, 10.745700162691254, 9.729272990273984, 8.776566726825417, 9.749399712041203, 10.763229022754633, 11.69155086741881, 12.612148432975102, 13.657273680128352, 13.523314559142438, 14.453470518286652, 14.64099387211304, 13.674828151949386, 12.675987719142055, 11.857149995142072, 12.79771724312646, 13.806339804284077, 13.431309530623619, 12.530615252323788, 11.510401982571517, 10.579608993782347, 9.744098833451163, 8.802572920494349, 7.828274147232587, 8.766907182758711, 9.709951057202662, 10.743743256299942, 11.686750281891936, 12.638579611563769, 12.504966514145153, 13.44238057916545, 14.46523792506723, 14.73938251905511, 13.73782498554494, 12.840479141833448, 13.78895991928602, 13.400941426990606, 12.415391076832325, 11.605774403605874, 10.644811525705064, 9.5912441279617, 8.784575943523155, 7.822027503167405, 6.808368191290994, 7.852398520259872, 8.780917146700004, 9.716035222506713, 10.700916093547491, 11.651836026064437, 11.579390862721539, 12.528352482585063, 13.528266457219612, 14.557322286359735, 14.72008690730528, 13.896437834997451, 13.404301428289228, 12.463598029007354, 11.423264966707952, 10.539235767761179, 9.589595798373011, 8.65187442754915, 7.837219617027346, 6.849874302832212, 5.829538945061412, 6.8518013215101465, 7.813510743717883, 8.742374093495085, 9.755053311684572, 10.681617210118405, 10.571288769325516, 11.633028459804672, 12.582266356239698, 13.507653273883538, 14.434576164036063, 13.406996376860775, 12.469820923069712, 11.50129116187289, 10.491311609072767, 9.563777797443052, 8.617630905787578, 7.690944803695567, 6.810446648304184, 5.88148769996906, 4.90367733004393, 5.882914852741735, 6.797250612911964, 7.755285502374122, 8.80737128422701, 9.62094571006484, 9.690656771569477, 10.704828820525297, 11.666011297117414, 12.67300577502499, 13.485395200485424, 12.535342369250612, 11.593720808055256, 10.54662490993758, 9.578907845505967, 8.633671334164083, 7.5961668198201036, 6.667059196749054, 5.814386155343699, 4.909694178117434, 3.9511974066148916, 4.902895288463699, 5.834996968276906, 6.779423564974226, 7.787815858530617, 8.691515380301999, 8.782392710734689, 9.782851710151224, 10.77910380402925, 11.788981306995158, 12.460039351606028, 11.567065300087267, 10.632620820319886, 9.565242926004416, 8.615988080620646, 7.692197297553426, 6.735596244193911, 5.735129790783439, 4.781225184630856, 3.9060084710029375, 2.877838938499785, 3.8488361034079257, 4.778422703508564, 5.717378027860587, 6.768432243017768, 7.754429150427454, 7.816427505500818, 8.862760143603417, 9.825858837138133, 10.753896428316159, 11.529278723106996, 10.52473419061218, 9.588453093381542, 8.561194903996826, 7.5966242679773215, 6.656674937653244, 5.7235530524821385, 4.755985758927844, 3.817338923395113, 2.87794031833738, 1.95196513341546, 2.915177371458409, 3.842894954153973, 4.916469992487945, 5.983287609305158, 6.8871342828172954, 6.878347802740593, 7.8759975773390165, 8.792883871152839, 9.774008947652032, 10.632461030347756, 9.62158114283353, 8.648437211609425, 7.7063024180050075, 6.662824529997794, 5.732169594578312, 4.754962055669506, 3.8297885969324637, 2.890828361853596, 1.9442198215230642, 0.9572332292901373, 1.9530596669940015, 2.8924431022959127, 3.966701730645432, 4.9779718711150425, 5.906445757634267, 5.832125825949687, 6.866798359773294, 7.810918025856219, 8.88028368704745, 9.880951725962323, 9.086917522090422, 8.018457490374704, 7.026914689687142, 6.061035237803191, 5.0639020250246825, 4.062437022754725, 3.083610851334757, 2.1373950811692053, 1.0657115624418063, 0.0, 0.9508085466951048, 1.9351219474176262, 2.946744023544679, 3.911688871398667, 4.889741024961908, 6.758010591670809, 7.685963703616451, 8.703856578091395, 9.742476335609592, 10.789864061483327, 9.827986980814284, 8.895323846283212, 7.949878058511307, 6.918777289172781, 5.993655958920775, 5.013786581052253, 4.072209622417102, 3.0012150465597753, 1.9956052911865103, 0.9606614318067374, 1.909853697191386, 2.873920707156023, 3.800734535669366, 4.774987848094392, 5.802405213277893, 7.751667572239159, 8.655527286538804, 9.708912281015538, 10.775783229087768, 11.807285689324239, 10.825894762636656, 9.84258581310563, 8.88212721572078, 7.9131104996774955, 6.89329985292974, 5.925273214701455, 4.999746884561826, 4.047456318270293, 3.0613186368077328, 1.991806918831987, 2.980934525736112, 3.896050768990751, 4.806337270899468, 5.76132025821607, 6.730889613463637, 8.664045924655522, 9.595794856112654, 10.616377199402828, 11.584496699161681, 12.657749871363608, 11.722199497945528, 10.773547774345849, 9.835873378247518, 8.853615045302185, 7.824424311553787, 6.98472513641753, 5.980321343939165, 4.966468274528934, 3.951683353822702, 2.9277497997255524, 3.952014743784865, 4.935722250723533, 5.85723407315167, 6.740000034624853, 7.686569475158809, 9.63692787555676, 10.57845325640232, 11.6193315228729, 12.580793529392645, 13.506155025377677, 12.774951117374352, 11.813083163249123, 10.810507712787441, 9.855217821688829, 8.886539998895405, 7.956044188034087, 6.90935378657508, 5.886626248394043, 4.818715344222945, 3.8919158965706897, 4.8779226968972536, 5.892075407522912, 6.819499338764138, 7.763405118053262, 8.74167762573676, 10.696172507899943, 11.612675777644993, 12.613982689305248, 13.51166384460547, 14.524746133034538, 13.706977487093939, 12.770088152963051, 11.770670257395858, 10.915262637096797, 9.891695803643481, 8.903145254301077, 7.854744346583766, 6.823924100924571, 5.841499904631503, 4.843354790510716, 5.835927937852121, 6.815552250889288, 7.774508883122807, 8.782504791917383, 9.749594917186716, 11.696507177953036, 12.642328007050482, 13.571879057182382, 14.484329747512596, 14.490637623102176, 13.487257625767313, 13.756927728174677, 12.734016873372536, 11.833652793018397, 10.833250548398153, 9.765122325185182, 8.742989511140328, 7.782465037798394, 6.785518035337873, 5.858157565317803, 6.808864300299966, 7.81485117130392, 8.793684648453263, 9.753585282335475, 10.728808696592365, 12.57678124650665, 13.573547341401264, 14.557026627415274, 14.553110732773902, 13.509278439253015, 12.514043286158032, 13.4583314844884, 13.70008595832174, 12.695054218323008, 11.764632786101078, 10.717683188655412, 9.75495044828647, 8.713946800927946, 7.793668275079497, 6.897700034559472, 7.761730002963085, 8.712892364003535, 9.768595475066528, 10.680830590096342, 11.626783937951975, 13.576817079263028, 14.552529593317583, 14.569043322592684, 13.586424835105273, 12.561395816690762, 11.586911088980965, 12.554702992147277, 13.610281940920157, 13.744344570783358, 12.73677967785569, 11.665183419211747, 10.671787196035602, 9.72677707298302, 8.844894747387851, 7.877324239766988, 8.71720011946902, 9.73491422943972, 10.675766558883115, 11.620333475217475, 12.582016861679827, 14.56770228244929, 14.588554188358042, 13.627902223692127, 12.650281960510904, 11.701986778406887, 10.64459518771879, 11.619783172001162, 12.639682308141222, 13.581437713626721, 13.725358017195093, 12.65379086732982, 11.629044914719275, 10.654751891929472, 9.820311401512832, 8.819619433620122, 9.68574247632263, 10.67500781540887, 11.687753442494175, 12.686758072734815, 13.50885530240167], [13.520225567924538, 12.785685680825955, 11.853614581629158, 10.906943587451469, 9.890688824573077, 10.789156894620373, 11.795668986865856, 12.64820751164245, 13.58786464884155, 14.612290926587155, 14.425124075493706, 13.592482639230376, 12.65093756023227, 11.642545127296462, 10.654503269091176, 10.204002696657062, 10.948415370252558, 11.972787967480834, 12.86465109699052, 13.891388693340627, 13.716372401355983, 13.840990026815978, 12.844127459933162, 11.948744988431015, 10.920718253752236, 11.768358812937628, 12.745795690486045, 13.697855467504441, 14.64341045523464, 14.435451911160946, 13.482056222731067, 12.530202850417313, 11.69650870938636, 10.68008153696909, 9.727375273520522, 9.198121892108425, 10.022967692763254, 10.951289537427431, 11.816561101157992, 12.861686348311242, 12.672649748322257, 13.602805707466471, 13.813377673366645, 12.847211953202992, 11.848371520395661, 12.807958541837175, 13.748525789821564, 14.757148350979183, 14.382118077318724, 13.481423799018893, 12.461210529266623, 11.530417540477453, 10.694907380146269, 9.753381467189454, 8.779082693927693, 8.215629362825933, 8.95003342624347, 9.98382562534075, 10.891162950074825, 11.842992279746658, 11.654301703324972, 12.591715768345269, 13.61457311424705, 13.911766320308717, 12.910208786798545, 13.791287688528552, 14.739768465981124, 14.351749973685711, 13.36619962352743, 12.55658295030098, 11.59562007240017, 10.542052674656805, 9.73538449021826, 8.77283604986251, 7.7591767379861, 7.204553094239554, 8.020999515740812, 8.956117591547521, 9.905328761730381, 10.801171215244256, 10.728726051901358, 11.677687671764883, 12.677601646399431, 13.706657475539554, 13.892470708558886, 14.847246381692555, 14.355109974984334, 13.41440657570246, 12.374073513403058, 11.490044314456284, 10.540404345068117, 9.602682974244255, 8.788028163722451, 7.800682849527318, 6.780347491756517, 6.143408232133766, 7.021903653986998, 7.9507670037641995, 8.959465979867462, 9.830952399298225, 9.720623958505335, 10.782363648984491, 11.731601545419517, 12.656988463063357, 13.671709950267434, 14.35780492355588, 13.420629469764817, 12.452099708567996, 11.442120155767872, 10.514586344138158, 9.568439452482684, 8.641753350390672, 7.76125519499929, 6.832296246664166, 5.8544858767390355, 5.174521763365355, 6.001663281094853, 6.959698170557012, 8.0117839524099, 8.770280899244659, 8.839991960749295, 9.817779772779524, 10.778962249371641, 11.785956727279217, 12.700938212616544, 13.486150915945718, 12.544529354750361, 11.497433456632686, 10.52971639220107, 9.584479880859186, 8.546975366515209, 7.617867743444159, 6.765194702038804, 5.860502724812538, 4.902005953309997, 4.107307956646588, 5.039409636459795, 5.983836233157116, 6.992228526713507, 7.840850569481817, 7.835038099442587, 8.835497098859122, 9.831749192737147, 10.841626695703056, 11.675582363737147, 12.517873846782372, 11.583429367014991, 10.516051472699521, 9.56679662731575, 8.64300584424853, 7.686404790889014, 6.685938337478545, 5.732033731325962, 4.8568170176980425, 3.8286474851948906, 3.053248771590815, 3.9828353716914537, 4.921790696043477, 5.972844911200658, 6.903764339607272, 6.865618958805713, 7.911951596908311, 8.875050290443028, 9.803087881621053, 10.744821735238116, 11.475542737307286, 10.539261640076647, 9.512003450691932, 8.547432814672426, 7.607483484348347, 6.674361599177242, 5.706794305622949, 4.768147470090218, 3.8287488650324852, 2.902773680110565, 2.0248273496055744, 2.951058339010636, 4.016909533475118, 5.064060068224126, 5.93632573612219, 5.927539256045487, 6.925189030643911, 7.842075324457733, 8.823200400956928, 9.781089283550804, 10.572389689528636, 9.59924575830453, 8.657110964700113, 7.613633076692898, 6.682978141273416, 5.705770602364611, 4.780597143627568, 3.8416369085487005, 2.8950283682181692, 1.9080417759852422, 1.0627096451411668, 1.9483629939505345, 3.022621622300054, 4.027163324419937, 4.9556372109391615, 4.881317279254581, 5.9159898130781885, 6.860109479161114, 7.929475140352345, 8.930143179267219, 9.903771048903343, 8.969266037069808, 7.9777232363822455, 7.011843784498295, 6.014710571719786, 5.013245569449829, 4.034419398029861, 3.08820362786431, 2.016520109136911, 0.9508085466951048, 0.0, 0.9843134007225213, 1.9959354768495738, 2.9608803247035613, 3.9389324782668025, 5.807202044975704, 6.735155156921347, 7.75304803139629, 8.791667788914488, 9.839055514788223, 10.778795527509388, 9.846132392978316, 8.90068660520641, 7.869585835867885, 6.944464505615879, 5.964595127747357, 5.023018169112206, 3.95202359325488, 2.946413837881615, 1.911469978501842, 0.9763482799021567, 1.923112160460918, 2.849925988974261, 3.8241793013992877, 4.851596666582789, 6.800859025544054, 7.7047187398437, 8.758103734320434, 9.824974682392664, 10.856477142629135, 11.77670330933176, 10.793394359800734, 9.832935762415884, 8.8639190463726, 7.844108399624845, 6.876081761396559, 5.95055543125693, 4.998264864965398, 4.012127183502837, 2.9426154655270915, 2.0474291084468823, 2.945242222295646, 3.855528724204363, 4.810511711520966, 5.780081066768532, 7.713237377960417, 8.644986309417549, 9.665568652707723, 10.633688152466576, 11.706941324668502, 12.673008044640632, 11.724356321040952, 10.786681924942622, 9.804423591997288, 8.775232858248891, 7.935533683112634, 6.93112989063427, 5.917276821224038, 4.9024919005178065, 3.878558346420657, 3.0550675806543963, 3.999498171753097, 4.906425526456565, 5.789191487929749, 6.735760928463703, 8.686119328861656, 9.627644709707216, 10.668522976177794, 11.62998498269754, 12.555346478682573, 13.551392736606338, 12.763891709944227, 11.761316259482546, 10.806026368383934, 9.83734854559051, 8.906852734729192, 7.8601623332701855, 6.837434795089148, 5.76952389091805, 4.842724443265794, 3.9809755337667854, 4.995128244392443, 5.868690792069033, 6.812596571358158, 7.790869079041654, 9.74536396120484, 10.66186723094989, 11.663174142610142, 12.560855297910365, 13.573937586339433, 14.483419106325925, 13.720896699658157, 12.721478804090964, 11.866071183791902, 10.842504350338587, 9.853953800996182, 8.805552893278872, 7.774732647619676, 6.7923084513266065, 5.79416333720582, 5.008311739105727, 5.987936052142894, 6.9160578198566895, 7.83169624522228, 8.79878637049161, 10.745698631257932, 11.691519460355378, 12.621070510487277, 13.533521200817491, 14.220266222757644, 14.438066172462419, 14.707736274869783, 13.684825420067641, 12.784461339713502, 11.784059095093259, 10.715930871880287, 9.693798057835433, 8.7332735844935, 7.7363265820329765, 6.808966112012906, 5.981248101553572, 6.987234972557526, 7.935233585187145, 8.802776735640373, 9.778000149897263, 11.625972699811548, 12.62273879470616, 13.606218080720168, 13.982714880814651, 13.238907038908483, 13.464851832853137, 14.409140031183506, 14.650894505016845, 13.645862765018114, 12.715441332796184, 11.668491735350518, 10.705758994981576, 9.664755347623052, 8.744476821774601, 7.848508581254576, 6.9341138042166905, 7.88527616525714, 8.940979276320133, 9.73002204340124, 10.675975391256873, 12.626008532567926, 13.60172104662248, 13.936897236984553, 12.97869395674453, 12.175314456867603, 12.537719635676071, 13.505511538842383, 14.561090487615262, 14.695153117478462, 13.687588224550796, 12.615991965906852, 11.622595742730708, 10.677585619678126, 9.795703294082955, 8.828132786462092, 7.889583920722625, 8.907298030693326, 9.84815036013672, 10.749293726943314, 11.631208314984725, 13.616893735754187, 13.80218753636663, 12.926759772454126, 11.977723551313517, 11.213817132546982, 11.595403734413896, 12.570591718696267, 13.590490854836327, 14.532246260321827, 14.676166563890199, 13.604599414024925, 12.57985346141438, 11.605560438624577, 10.771119948207936, 9.770427980315226, 8.858126277576236, 9.847391616662476, 10.860137243747781, 11.815718324460654, 12.558046755706568], [12.535912167202016, 11.801372280103433, 10.955989876326619, 10.143844292513096, 10.756787812282624, 11.711901623329483, 12.73924543694746, 13.632520912364972, 14.572178049564073, 15.596604327309677, 15.40943747621623, 14.5767960399529, 13.601391839575161, 12.592999406639352, 11.604957548434067, 10.930324734433658, 9.99047461140687, 11.014847208635146, 11.906710338144832, 12.93344793449494, 12.732059000633463, 12.856676626093456, 11.946502754630622, 11.185645693492642, 11.786817241461783, 12.691103541646738, 13.689372140567649, 14.681367954361296, 15.627723855957163, 15.41976531188347, 14.466369623453591, 13.514516251139836, 12.64696298872925, 11.63053581631198, 10.677829552863413, 9.92444392988502, 9.065026933917567, 9.993348778581744, 10.858620342312303, 11.903745589465553, 11.688336347599735, 12.61849230674395, 12.925877215961286, 12.175432771837134, 12.714470508105208, 13.727284152448622, 14.692102239903168, 15.713990749330112, 15.366431478041246, 14.465737199741417, 13.445523929989147, 12.514730941199977, 11.64536165948916, 10.703835746532345, 9.729536973270584, 8.941951400602528, 7.992092667397783, 9.02588486649506, 9.933222191229136, 10.877397422454669, 10.66998830260245, 11.607402367622747, 12.630259713524527, 13.239987138942858, 13.776307774508092, 14.710613299139998, 15.65909407659257, 15.336063374408234, 14.350513024249953, 13.540896351023502, 12.579933473122692, 11.526366075379329, 10.685838769561151, 9.723290329205401, 8.70963101732899, 7.991577383335255, 7.063058756895123, 7.998176832701832, 8.947388002884692, 9.816857814521734, 9.744412651178836, 10.69337427104236, 11.693288245676909, 12.722344074817032, 13.62995938616529, 14.695767556080494, 15.339423375706856, 14.398719976424982, 13.35838691412558, 12.474357715178806, 11.524717745790639, 10.586996374966779, 9.738482443065342, 8.751137128870209, 7.730801771099408, 6.939941991902567, 6.063962895141309, 6.99282624491851, 8.001525221021772, 8.846638998575703, 8.736310557782813, 9.79805024826197, 10.747288144696995, 11.672675062340835, 12.687396549544912, 13.714976336720198, 14.40494287048734, 13.436413109290518, 12.426433556490394, 11.49889974486068, 10.552752853205206, 9.626066751113196, 8.71170947434218, 7.782750526007056, 6.804940156081925, 5.971055523134156, 5.043722522249165, 6.001757411711322, 7.05384319356421, 7.785967498522137, 7.8556785600267744, 8.833466372057003, 9.794648848649121, 10.801643326556697, 11.716624811894022, 12.76741481956749, 13.528842755472882, 12.481746857355207, 11.51402979292359, 10.568793281581708, 9.531288767237731, 8.602181144166682, 7.749508102761326, 6.833033193416117, 5.852460232652887, 4.948031340035346, 4.081468877614107, 5.025895474311427, 6.034287767867818, 6.856537168759296, 6.850724698720065, 7.851183698136602, 8.847435792014627, 9.857313294980536, 10.691268963014625, 11.741263992630493, 12.567742767737512, 11.500364873422042, 10.55111002803827, 9.627319244971051, 8.670718191611536, 7.670251738201067, 6.716347132048484, 5.8293474863016215, 4.7791017645377805, 3.893972154979573, 3.024894612845765, 3.9638499371977876, 5.014904152354969, 5.919450938884751, 5.881305558083191, 6.927638196185789, 7.890736889720507, 8.818774480898531, 9.760508334515594, 10.751294234636505, 11.523575040799168, 10.496316851414452, 9.531746215394946, 8.591796885070869, 7.658674999899764, 6.691107706345471, 5.75246087081274, 4.813062265755007, 3.8532279594534553, 2.865550732994332, 1.966744938288115, 3.0325961327525968, 4.079746667501605, 4.952012335399669, 4.943225855322966, 5.94087562992139, 6.857761923735212, 7.838887000234406, 8.796775882828282, 9.807655770342507, 10.58355915902705, 9.641424365422633, 8.59794647741542, 7.6672915419959375, 6.690084003087132, 5.764910544350089, 4.825950309271222, 3.8793417689406904, 2.8923551767077633, 1.9034330285299246, 0.9640495932280132, 2.0383082215775326, 3.042849923697416, 3.9713238102166404, 3.89700387853206, 4.931676412355667, 5.875796078438593, 6.945161739629824, 7.945829778544697, 8.91945764818082, 9.95357943779233, 8.962036637104767, 7.996157185220817, 6.999023972442308, 5.997558970172351, 5.018732798752383, 4.072517028586832, 3.0008335098594325, 1.9351219474176262, 0.9843134007225213, 0.0, 1.0116220761270525, 1.9765669239810402, 2.9546190775442813, 4.822888644253183, 5.750841756198826, 6.768734630673769, 7.807354388191966, 8.8547421140657, 9.875491323728765, 10.808154458259837, 9.885000005928934, 8.853899236590408, 7.928777906338401, 6.948908528469879, 6.007331569834728, 4.9363369939774016, 3.9307272386041365, 2.8957833792243637, 1.960661680624678, 0.9387987597383969, 1.8656125882517398, 2.8398659006767666, 3.8672832658602676, 5.816545624821533, 6.720405339121179, 7.773790333597912, 8.840661281670142, 9.872163741906613, 10.881915297283317, 11.755416425082256, 10.817249163138406, 9.848232447095121, 8.828421800347366, 7.86039516211908, 6.934868831979451, 5.98257826568792, 4.996440584225359, 3.926928866249613, 2.9135280961564285, 1.9609288215731246, 2.871215323481842, 3.8261983107984445, 4.795767666046011, 6.728923977237897, 7.6606729086950285, 8.681255251985203, 9.649374751744055, 10.722627923945982, 11.737290042517955, 12.685941766117635, 11.770995325665144, 10.788736992719809, 9.759546258971412, 8.919847083835156, 7.915443291356791, 6.90159022194656, 5.8868053012403285, 4.862871747143179, 3.9211665683639425, 3.015184771030576, 3.922112125734044, 4.804878087207228, 5.751447527741183, 7.701805928139136, 8.643331308984695, 9.684209575455274, 10.64567158197502, 11.571033077960053, 12.567079335883818, 13.530002468747853, 12.745629660205067, 11.790339769106454, 10.82166194631303, 9.891166135451714, 8.844475733992708, 7.82174819581167, 6.753837291640572, 5.827037843988316, 4.8470745214763316, 4.031948007499941, 4.884377391346512, 5.828283170635636, 6.806555678319134, 8.76105056048232, 9.67755383022737, 10.678860741887622, 11.576541897187845, 12.589624185616913, 13.499105705603405, 14.50406638881476, 13.705792204813484, 12.850384584514423, 11.826817751061107, 10.838267201718706, 9.789866294001396, 8.7590460483422, 7.776621852049129, 6.778476737928342, 5.874410726815273, 5.0331706320047465, 5.931744419134169, 6.847382844499758, 7.81447296976909, 9.761385230535412, 10.707206059632858, 11.636757109764757, 12.54920780009497, 13.481069792007997, 14.499870354616528, 15.434407235730399, 14.669138820790161, 13.768774740436024, 12.76837249581578, 11.70024427260281, 10.678111458557956, 9.717586985216021, 8.720639982755499, 7.793279512735428, 6.847347089263118, 6.0324695524193785, 6.950920184464625, 7.818463334917851, 8.793686749174741, 10.641659299089026, 11.63842539398364, 12.621904679997648, 13.024774121968964, 13.96522907668508, 14.415306112196028, 15.359594310526397, 15.635207905739367, 14.630176165740636, 13.699754733518706, 12.65280513607304, 11.690072395704098, 10.649068748345574, 9.728790222497123, 8.775848440732334, 7.800212791926237, 6.987651459954602, 7.976054723791535, 8.745708642678718, 9.691661990534351, 11.641695131845404, 12.61740764589996, 12.978956478138866, 12.020753197898843, 12.901636494644201, 13.488173915018962, 14.455965818185273, 15.511544766958153, 15.679466518200986, 14.671901625273318, 13.600305366629375, 12.60690914345323, 11.661899020400648, 10.76130209397467, 9.75547264593985, 8.755682908432172, 8.009673325390787, 8.950525654834182, 9.764980326220792, 10.646894914262203, 12.632580335031665, 12.84424677752094, 11.968819013608439, 11.01978279246783, 11.94013917032358, 12.545858013756787, 13.521045998039158, 14.540945134179218, 15.482700539664718, 15.66047996461272, 14.588912814747447, 13.564166862136902, 12.5898738393471, 11.736718748099651, 10.697767839792984, 9.724225265285783, 9.084292321724103, 9.962512538445242, 10.831404923738132, 11.573733354984046], [11.640107292884244, 10.90556740578566, 10.21843740614691, 11.15546636864015, 11.768409888409677, 12.723523699456535, 13.750867513074514, 14.644142988492023, 15.583800125691123, 16.608226403436728, 16.421059552343284, 15.58841811607995, 14.613013915702213, 13.604621482766404, 12.616579624561119, 11.927920493948356, 10.98807037092157, 10.253781646283905, 10.979523694734041, 11.96256946447013, 11.720436924506409, 11.960871751775684, 11.208950284450914, 12.157487505654606, 12.798439317588835, 13.70272561777379, 14.700994216694703, 15.69299003048835, 16.63934593208421, 16.431387388010524, 15.477991699580643, 14.526138327266889, 13.658585064856302, 12.642157892439032, 11.689451628990465, 10.92203968939972, 10.062622693432266, 9.223456809819625, 9.931433698901513, 10.903807856582885, 10.676714271472683, 11.606870230616897, 12.188324745781578, 13.147274583999097, 13.72609258423226, 14.738906228575676, 15.703724316030222, 16.725612825457166, 16.3780535541683, 15.47735927586847, 14.457146006116199, 13.526353017327029, 12.656983735616212, 11.715457822659397, 10.741159049397636, 9.939547160117227, 8.989688426912481, 8.210054964794358, 9.006035547818346, 9.865775346327618, 9.658366226475398, 10.595780291495695, 11.618637637397475, 12.547246656902125, 13.5865061684515, 14.611948127374207, 15.560428904826779, 16.347685450535284, 15.362135100377005, 14.552518427150554, 13.591555549249744, 12.537988151506381, 11.697460845688203, 10.734912405332453, 9.721253093456042, 8.989173142849955, 8.060654516409823, 7.182346931001129, 8.020201359473901, 8.805235738394684, 8.732790575051784, 9.681752194915308, 10.681666169549857, 11.71072199868998, 12.618337310038237, 13.68414547995344, 14.685205451245816, 15.410342052552034, 14.370008990252632, 13.485979791305859, 12.536339821917691, 11.59861845109383, 10.750104519192394, 9.762759204997261, 8.74242384722646, 7.950365547366483, 7.061558654656008, 6.132695304878807, 7.074338577610981, 7.835016922448651, 7.724688481655761, 8.786428172134917, 9.735666068569943, 10.661052986213782, 11.67577447341786, 12.703354260593148, 13.640529714384211, 14.44803518541757, 13.438055632617447, 12.510521820987732, 11.564374929332258, 10.637688827240249, 9.723331550469233, 8.794372602134109, 7.8165622322089785, 6.981479078598072, 6.0541460777130816, 5.134270318471193, 6.126656550153419, 6.7743454223950845, 6.844056483899722, 7.821844295929951, 8.783026772522069, 9.790021250429644, 10.70500273576697, 11.755792743440438, 12.685237860056787, 13.493368933482259, 12.525651869050643, 11.58041535770876, 10.542910843364783, 9.613803220293734, 8.76113017888838, 7.84465526954317, 6.86408230877994, 5.959653416162398, 5.091892433078024, 4.158408381071299, 5.107101124457028, 5.8449150926322435, 5.839102622593013, 6.839561622009549, 7.835813715887575, 8.845691218853483, 9.679646886887573, 10.729641916503441, 11.708946413165908, 12.511986949549094, 11.562732104165322, 10.638941321098104, 9.682340267738589, 8.681873814328119, 7.727969208175536, 6.840969562428675, 5.790723840664834, 4.905594231106625, 4.035318168309682, 3.096362843957659, 4.056539425019542, 4.9078288627576985, 4.869683481956139, 5.916016120058737, 6.879114813593454, 7.807152404771479, 8.748886258388541, 9.739672158509453, 10.675953255740092, 11.507938927541504, 10.543368291521999, 9.60341896119792, 8.670297076026817, 7.702729782472523, 6.7640829469397925, 5.824684341882059, 4.864850035580508, 3.8771728091213844, 2.9783670144151673, 2.0249975329586265, 3.068124591374553, 3.9403902592726165, 3.931603779195914, 4.929253553794338, 5.84613984760816, 6.827264924107354, 7.78515380670123, 8.796033694215454, 9.76917762543956, 10.653046441549687, 9.609568553542474, 8.67891361812299, 7.701706079214185, 6.776532620477142, 5.837572385398275, 4.890963845067743, 3.9039772528348164, 2.915055104656977, 1.9756716693550658, 1.030709621783562, 2.0312278475703636, 2.959701734089588, 2.885381802405008, 3.920054336228615, 4.8641740023115405, 5.9335396635027715, 6.934207702417645, 7.907835572053768, 8.976295603769486, 9.96783840445705, 9.00777926134787, 8.010646048569361, 7.009181046299403, 6.030354874879436, 5.084139104713884, 4.012455585986485, 2.946744023544679, 1.9959354768495738, 1.0116220761270525, 0.0, 0.9649448478539877, 1.942997001417229, 3.8288896276036466, 4.756842739549289, 5.774735614024232, 6.813355371542429, 7.860743097416164, 8.863869247601713, 9.796532382132785, 10.74197816990469, 9.86552131271746, 8.940399982465454, 7.960530604596931, 7.01895364596178, 5.947959070104454, 4.942349314731189, 3.9074054553514164, 2.9722837567517306, 1.9504208358654493, 1.0326513969168103, 1.900297770962119, 2.873284249210731, 4.822546608171996, 5.726406322471642, 6.779791316948376, 7.846662265020605, 8.878164725257076, 9.88791628063378, 10.743794348955204, 11.770944791743064, 10.859854523222173, 9.840043876474418, 8.872017238246134, 7.946490908106504, 6.994200341814972, 6.008062660352412, 4.938550942376666, 3.925150172283481, 2.9725508977001773, 2.0382541321469123, 2.886630181083797, 3.8561995363313635, 5.789355847523249, 6.666673892045492, 7.687256235335666, 8.65537573509452, 9.728628907296446, 10.74329102586842, 11.6919427494681, 12.62961714556643, 11.800359068846863, 10.771168335098466, 9.931469159962209, 8.927065367483843, 7.9132122980736135, 6.898427377367382, 5.874493823270232, 4.932788644490995, 4.026806847157629, 3.0891509343991137, 3.86530995749258, 4.8118793980265355, 6.762237798424488, 7.6774252517282235, 8.690210558805736, 9.651672565325484, 10.577034061310517, 11.573080319234283, 12.536003452098317, 13.560498411388519, 12.801961845233508, 11.833284022440084, 10.902788211578766, 9.85609781011976, 8.833370271938723, 7.765459367767624, 6.838659920115369, 5.858696597603384, 5.043570083626994, 4.051416200011582, 4.932478296317866, 5.866987548604486, 7.821482430767671, 8.711647772970897, 9.684861725238084, 10.582542880538309, 11.595625168967377, 12.50510668895387, 13.510067372165224, 14.509485267732417, 13.862006660641477, 12.83843982718816, 11.849889277845756, 10.801488370128446, 9.77066812446925, 8.78824392817618, 7.790098814055394, 6.886032802942325, 6.0447927081318, 5.098783227799238, 5.9515779701819875, 6.874904840054443, 8.821817100820764, 9.756810778332717, 10.64275809311522, 11.555208783445435, 12.487070775358461, 13.505871337966992, 14.440408219080863, 15.463319073883005, 14.780396816563075, 13.779994571942831, 12.71186634872986, 11.689733534685006, 10.729209061343072, 9.73226205888255, 8.804901588862482, 7.85896916539017, 7.044091628546432, 6.117958993129694, 6.922658460600081, 7.897881874856971, 9.745854424771254, 10.6880301126835, 11.62790566334811, 12.57492618797358, 13.468429959207622, 14.463665112302605, 15.407953310632974, 16.42977009340963, 15.641798241867686, 14.711376809645756, 13.66442721220009, 12.701694471831148, 11.660690824472624, 10.740412298624175, 9.787470516859386, 8.811834868053289, 7.999273536081656, 7.143093532456604, 7.849903768360947, 8.79585711621658, 10.745890257527632, 11.667012364599818, 12.217890915787624, 13.018348957413542, 13.8992322541589, 14.499795991146014, 15.467587894312326, 16.523166843085203, 16.691088594328036, 15.683523701400368, 14.611927442756425, 13.61853121958028, 12.673521096527699, 11.772924170101723, 10.767094722066902, 9.767304984559225, 9.021295401517841, 8.212973184654473, 8.86917545190302, 9.751090039944431, 11.736775460713893, 11.91706013411015, 11.207753451257197, 12.017378551982528, 12.937734929838278, 13.557480089883839, 14.53266807416621, 15.55256721030627, 16.49432261579177, 16.672102040739773, 15.600534890874497, 14.575788938263953, 13.60149591547415, 12.748340824226704, 11.709389915920037, 10.735847341412835, 10.095914397851157, 9.224960068265533, 9.93560004942036, 10.677928480666274], [10.675162445030256, 9.940622557931674, 10.85426174187583, 11.84513688334841, 12.654409116590728, 13.609522927637586, 14.636866741255563, 15.560144392892619, 16.49980153009172, 17.524227807837324, 17.38600440019727, 16.55336296393394, 15.5779587635562, 14.569566330620392, 13.581524472415106, 12.832894776421114, 11.875509297447522, 11.015504974488909, 10.014578846880053, 10.997624616616141, 10.75549207665242, 10.995926903921697, 11.844774620179834, 12.793311841383526, 13.684438545769886, 14.588724845954841, 15.586993444875752, 16.5789892586694, 17.555347336484807, 17.39633223586451, 16.44293654743463, 15.491083175120876, 14.62352991271029, 13.60710274029302, 12.654396476844452, 11.845338913578058, 10.950061619958218, 10.02173977529404, 8.966488851047524, 9.938863008728896, 9.711769423618694, 10.641925382762908, 11.5986849745915, 12.564850694755153, 13.563691127562484, 14.576504771905899, 15.602073338483203, 16.62396184791015, 17.342998402022285, 16.442304123722455, 15.422090853970186, 14.491297865181016, 13.621928583470199, 12.680402670513384, 11.706103897251623, 10.862846384295565, 9.91298765109082, 9.056293669452781, 8.041090699964357, 8.90083049847363, 8.693421378621409, 9.630835443641706, 10.653692789543486, 11.582301809048136, 12.621561320597511, 13.647003279520218, 14.59548405697279, 15.586592591375013, 16.327079948230992, 15.517463275004541, 14.556500397103731, 13.502932999360368, 12.66240569354219, 11.69985725318644, 10.686197941310029, 9.912472367028293, 8.983953740588161, 8.048835664781452, 7.055256511619913, 7.840290890540695, 7.767845727197795, 8.71680734706132, 9.716721321695868, 10.745777150835991, 11.65339246218425, 12.719200632099454, 13.720260603391827, 14.606421494861507, 15.33495383810662, 14.450924639159846, 13.501284669771678, 12.563563298947818, 11.715049367046381, 10.727704052851248, 9.707368695080447, 8.91531039522047, 8.026503502509996, 7.097640152732794, 6.109393729756993, 6.870072074594663, 6.759743633801772, 7.821483324280929, 8.770721220715954, 9.696108138359794, 10.710829625563873, 11.73840941273916, 12.675584866530222, 13.644114627727044, 14.403000480471434, 13.475466668841719, 12.529319777186245, 11.602633675094236, 10.68827639832322, 9.759317449988096, 8.781507080062966, 7.946423926452059, 7.019090925567069, 6.09921516632518, 5.161711702299431, 5.809400574541097, 5.879111636045734, 6.856899448075963, 7.818081924668081, 8.825076402575657, 9.740057887912982, 10.79084789558645, 11.7202930122028, 12.708477184198758, 13.49059671690463, 12.545360205562748, 11.50785569121877, 10.578748068147721, 9.726075026742365, 8.809600117397157, 7.829027156633927, 6.924598264016387, 6.056837280932011, 5.123353228925286, 4.14215627660304, 4.879970244778256, 4.874157774739025, 5.8746167741555615, 6.870868868033587, 7.880746370999495, 8.714702039033586, 9.764697068649454, 10.74400156531192, 11.727095200265593, 12.52767695201931, 11.60388616895209, 10.647285115592576, 9.646818662182106, 8.692914056029522, 7.805914410282662, 6.755668688518821, 5.870539078960613, 5.000263016163669, 4.061307691811646, 3.091594577165554, 3.942884014903711, 3.9047386341021513, 4.95107127220475, 5.914169965739466, 6.842207556917492, 7.7839414105345535, 8.774727310655466, 9.711008407886105, 10.723047178258003, 11.508313139375986, 10.568363809051908, 9.635241923880804, 8.667674630326509, 7.7290277947937795, 6.789629189736046, 5.829794883434495, 4.842117656975372, 3.943311862269155, 2.989942380812614, 2.103179743520565, 2.975445411418629, 2.966658931341926, 3.9643087059403497, 4.881194999754172, 5.862320076253366, 6.8202089588472425, 7.831088846361467, 8.804232777585574, 9.74636757118999, 10.574513401396459, 9.643858465976978, 8.666650927068172, 7.741477468331129, 6.802517233252262, 5.85590869292173, 4.8689221006888035, 3.8799999525109645, 2.9406165172090533, 1.9956544696375498, 1.0662829997163756, 1.9947568862356004, 1.92043695455102, 2.955109488374627, 3.8992291544575526, 4.968594815648784, 5.969262854563657, 6.94289072419978, 8.011350755915498, 9.00289355660306, 9.96877300848701, 8.975590896423348, 7.97412589415339, 6.995299722733423, 6.049083952567871, 4.977400433840472, 3.911688871398666, 2.9608803247035613, 1.9765669239810402, 0.9649448478539877, 0.0, 0.9780521535632414, 2.863944779749659, 3.7918978916953017, 4.809790766170245, 5.848410523688442, 6.895798249562177, 7.898924399747725, 8.831587534278798, 9.777033322050704, 10.80813409138923, 9.905344830319441, 8.925475452450918, 7.938514978062936, 6.86752040220561, 5.861910646832345, 4.826966787452572, 3.8777745220679236, 2.8364200640465005, 1.9096062355331578, 0.9353529231081312, 1.9083394013567434, 3.857601760318009, 4.761461474617654, 5.8148464690943875, 6.881717417166618, 7.9132198774030895, 8.922971432779793, 9.778849501101217, 10.805999943889077, 11.775016659932362, 10.759605208575575, 9.791578570347289, 8.86605224020766, 7.913761673916127, 6.924983360535514, 5.85455234677726, 4.811149400464532, 3.8585501258812283, 2.91520897076326, 1.9216853332298092, 2.8912546884773755, 4.824410999669261, 5.701729044191504, 6.722311387481678, 7.690430887240531, 8.763684059442458, 9.77834617801443, 10.72699790161411, 11.66467229771244, 12.716846726943853, 11.690729667199623, 10.851030492063364, 9.846626699585, 8.829213702474208, 7.814428781767976, 6.790495227670826, 5.818787872672046, 4.91280607533868, 3.9409097283813264, 2.9003651096385923, 3.846934550172547, 5.797292950570499, 6.7124804038742365, 7.725265710951749, 8.686727717471495, 9.612089213456528, 10.608135471380294, 11.571058604244328, 12.59555356353453, 13.550843454633142, 12.752845354541241, 11.822349543679922, 10.772099214520354, 9.749371676339317, 8.681460772168219, 7.754661324515963, 6.744695825784435, 5.917715720440451, 4.903174993993795, 3.967533448463878, 4.902042700750497, 6.856537582913682, 7.74670292511691, 8.719916877384097, 9.61759803268432, 10.630680321113388, 11.54016184109988, 12.545122524311235, 13.544540419878428, 14.601936763151697, 13.758001159289318, 12.765890682246352, 11.717489774529042, 10.686669528869846, 9.704245332576775, 8.706100218455989, 7.772032031123376, 6.90949865401497, 5.950542021781452, 4.986633122328, 5.909959992200454, 7.856872252966776, 8.79186593047873, 9.677813245261232, 10.590263935591446, 11.522125927504472, 12.540926490113003, 13.475463371226875, 14.498374226029016, 15.470818076912735, 14.695995976343427, 13.627867753130456, 12.605734939085602, 11.645210465743668, 10.648263463283145, 9.707286724708634, 8.74496839357122, 7.908797574429602, 6.943029152615853, 5.957713612746093, 6.932937027002982, 8.780909576917267, 9.723085264829512, 10.662960815494124, 11.609981340119592, 12.503485111353633, 13.498720264448616, 14.443008462778986, 15.464825245555643, 16.469856985554376, 15.627378214046352, 14.580428616600686, 13.617695876231744, 12.57669222887322, 11.644594118557501, 10.673469745040437, 9.69783409623434, 8.863979481964826, 7.933542782616894, 6.884958920506959, 7.830912268362592, 9.780945409673645, 10.702067516745831, 11.683424806230017, 12.614002264189713, 13.567077693394513, 14.425852461625682, 15.416575957287671, 16.460889831345877, 17.51199555800513, 16.599525105800964, 15.527928847157021, 14.534532623980876, 13.589522500928295, 12.658923398282774, 11.653093950247953, 10.653304212740276, 9.789649849826787, 8.848797520383393, 7.904230604049033, 8.786145192090444, 10.771830612859906, 10.952115286256161, 11.912767250922077, 12.90481747850848, 13.842709212311036, 14.522424937737826, 15.497612922020197, 16.517512058160257, 17.45926746364576, 17.588103445140366, 16.516536295275092, 15.49179034266455, 14.517497319874746, 13.634340052407754, 12.595389144101087, 11.621846569593886, 10.864268846160103, 9.860784403994453, 8.970655201566373, 9.712983632812287], [9.983610948056935, 10.918674711494914, 11.83231389543907, 12.82318903691165, 13.63246127015397, 14.587575081200828, 15.614918894818807, 16.538196546455858, 17.477853683654956, 18.50227996140056, 18.313205299574157, 17.37177779833677, 16.30571428422526, 15.29732185128945, 14.309279993084164, 13.465274774520106, 12.507889295546514, 11.647884972587901, 10.646958844979045, 10.0195724630529, 9.77743992308918, 10.697724682437558, 11.600007282358924, 12.548544503562615, 13.513292240642668, 14.50252686715248, 15.565955571650742, 16.557951385444387, 17.609714011237795, 18.323533135241398, 17.37013744681152, 16.41009537310637, 15.351285433379347, 14.334858260962077, 13.38215199751351, 12.47771891167705, 11.58244161805721, 10.654119773393033, 9.598868849146516, 8.960810855165654, 8.733717270055454, 9.663873229199668, 10.62063282102826, 11.586798541191913, 12.585638973999243, 13.598452618342659, 14.624021184919963, 15.645909694346907, 16.610009241761347, 17.40740951373282, 16.38719624398055, 15.456403255191379, 14.404133025620137, 13.408158191182443, 12.433859417920681, 11.495226382394558, 10.545367649189812, 9.688673667551774, 8.67347069806335, 7.9227783449103875, 7.7153692250581685, 8.652783290078466, 9.675640635980246, 10.604249655484896, 11.64350916703427, 12.668951125956978, 13.61743190340955, 14.608540437811772, 15.594090787970053, 16.49551542856778, 15.534552550666971, 14.480985152923608, 13.58188144056799, 12.61933300021224, 11.588882694096164, 10.544852365127285, 9.616333738687153, 8.681215662880444, 7.687636509718905, 6.862238736977454, 6.7897935736345545, 7.738755193498079, 8.738669168132628, 9.767724997272751, 10.675340308621006, 11.74114847853621, 12.742208449828583, 13.628369341298264, 14.607995384599109, 15.428976792723086, 14.479336823334918, 13.541615452511058, 12.686302374650221, 11.698957060455088, 10.678621702684287, 9.65075613406781, 8.689046711860074, 7.760183362082873, 6.7417737278559855, 5.892019921031422, 5.781691480238532, 6.843431170717689, 7.792669067152714, 8.718055984796553, 9.73277747200063, 10.760357259175915, 11.697532712966979, 12.6660624741638, 13.676042026963923, 14.453518822404959, 13.507371930749486, 12.580685828657476, 11.65952940592706, 10.730570457591936, 9.752760087666806, 8.773522564969001, 7.84618956408401, 6.818727243738374, 5.794091700398424, 4.831348420977855, 4.901059482482493, 5.878847294512722, 6.84002977110484, 7.847024249012415, 8.762005734349739, 9.812795742023207, 10.742240858639557, 11.730425030635516, 12.691849238242911, 13.523412359125988, 12.48590784478201, 11.556800221710962, 10.704127180305605, 9.787652270960399, 8.80707931019717, 7.902650417579629, 6.883935919448952, 5.84286530633848, 4.834473012782088, 3.9019180912150144, 3.896105621175784, 4.89656462059232, 5.892816714470346, 6.902694217436254, 7.736649885470343, 8.78664491508621, 9.765949411748677, 10.74904304670235, 11.72892947335759, 12.581938322515331, 11.625337269155816, 10.624870815745346, 9.670966209592763, 8.783966563845903, 7.733720842082063, 6.848591232523855, 5.940838308259359, 5.001882983907336, 3.9508287687501547, 2.9648318613404694, 2.92668648053891, 3.9730191186415085, 4.936117812176225, 5.86415540335425, 6.805889256971311, 7.796675157092224, 8.732956254322863, 9.744995024694761, 10.709565660714267, 11.546415962615148, 10.613294077444044, 9.64572678388975, 8.70707994835702, 7.767681343299287, 6.807847036997737, 5.820169810538614, 4.921364015832396, 3.9679945343758556, 3.030800359001929, 1.9973932578553875, 1.9886067777786849, 2.9862565523771085, 3.9031428461909305, 4.884267922690125, 5.8421568052840005, 6.853036692798225, 7.826180624022332, 8.768315417626749, 9.811793305633962, 10.621910619540218, 9.644703080631412, 8.71952962189437, 7.780569386815503, 6.833960846484971, 5.846974254252045, 4.858052106074206, 3.9186686707722944, 2.9737066232007914, 2.0314724806827957, 1.016704732672359, 0.9423848009877787, 1.977057334811386, 2.9211770008943114, 3.9905426620855424, 4.991210701000416, 5.964838570636539, 7.033298602352257, 8.02484140303982, 8.99072085492377, 9.95364304998659, 8.952178047716632, 7.973351876296664, 7.027136106131112, 5.955452587403713, 4.889741024961907, 3.9389324782668025, 2.9546190775442813, 1.942997001417229, 0.9780521535632414, 0.0, 1.8858926261864177, 2.81384573813206, 3.831738612607003, 4.8703583701252, 5.917746095998935, 6.920872246184484, 7.853535380715557, 8.798981168487462, 9.830081937825987, 10.755203268077993, 9.90352760601416, 8.916567131626179, 7.845572555768852, 6.839962800395587, 5.805018941015814, 4.855826675631166, 3.814472217609742, 2.887658389096399, 1.9134050766713726, 0.930287247793502, 2.8795496067547672, 3.7834093210544126, 4.836794315531146, 5.903665263603376, 6.9351677238398475, 7.944919279216551, 8.800797347537976, 9.827947790325837, 10.796964506369122, 11.737657362138819, 10.769630723910533, 9.844104393770904, 8.89181382747937, 7.9030355140987565, 6.832604500340502, 5.789201554027774, 4.83660227944447, 3.8932611243265014, 2.8997374867930508, 1.9331665667870315, 3.878892069869724, 4.723676890628262, 5.744259233918436, 6.712378733677289, 7.785631905879216, 8.800294024451189, 9.748945748050868, 10.686620144149199, 11.738794573380611, 12.668781820762867, 11.829082645626608, 10.824678853148244, 9.80726585603745, 8.792480935331218, 7.768547381234068, 6.796840026235288, 5.890858228901922, 4.9189618819445675, 3.8784172632018334, 2.9887427407547866, 4.8517740207709625, 5.7344282503109945, 6.747213557388507, 7.708675563908253, 8.634037059893284, 9.63008331781705, 10.593006450681084, 11.617501409971286, 12.572791301069898, 13.541469123863322, 12.800401697243165, 11.750151368083596, 10.727423829902559, 9.65951292573146, 8.732713478079205, 7.722747979347677, 6.895767874003692, 5.881227147557036, 4.945585602027119, 4.043850891332737, 5.911018653114145, 6.768650771553668, 7.741864723820855, 8.639545879121078, 9.652628167550146, 10.562109687536637, 11.567070370747992, 12.566488266315185, 13.623884609588453, 14.546624928611399, 13.743942835809593, 12.695541928092283, 11.664721682433086, 10.682297486140017, 9.68415237201923, 8.750084184686617, 7.887550807578211, 6.928594175344692, 5.964685275891241, 5.051768182782694, 6.911353323167239, 7.813813776915488, 8.69976109169799, 9.612211782028204, 10.54407377394123, 11.562874336549761, 12.497411217663632, 13.520322072465774, 14.492765923349493, 15.493168167969737, 14.605919906693696, 13.583787092648842, 12.623262619306908, 11.626315616846387, 10.685338878271876, 9.723020547134462, 8.886849727992843, 7.921081306179095, 6.935765766309334, 6.100579867510733, 7.877459971436518, 8.74503311126627, 9.684908661930882, 10.63192918655635, 11.525432957790391, 12.520668110885374, 13.464956309215744, 14.4867730919924, 15.491804831991132, 16.422226264213062, 15.558480770163927, 14.595748029794985, 13.55474438243646, 12.622646272120743, 11.65152189860368, 10.675886249797582, 9.842031635528066, 8.911594936180135, 7.8630110740702, 7.1393607713892715, 8.890317876041859, 9.72401536318259, 10.705372652666775, 11.63595011062647, 12.58902553983127, 13.44780030806244, 14.43852380372443, 15.482837677782637, 16.53394340444189, 17.458176503263136, 16.50598100072026, 15.512584777544117, 14.567574654491535, 13.636975551846016, 12.631146103811195, 11.631356366303518, 10.767702003390028, 9.826849673946633, 8.882282757612273, 8.094593695117123, 9.901544773935074, 10.79131358504469, 11.715510117197201, 12.636920516057485, 13.55052286415189, 14.390116209324615, 15.373443623870545, 16.393342760010604, 17.335098165496106, 18.380503653671315, 17.494588448838332, 16.469842496227788, 15.495549473437986, 14.612392205970997, 13.57344129766433, 12.599898723157128, 11.842320999723343, 10.838836557557693, 9.948707355129613, 9.021432135838966], [9.785814830472438, 10.744790085745368, 11.72412709918258, 12.71500224065516, 13.702078937059014, 14.657192748105873, 15.68453656172385, 16.6078142133609, 17.547471350560002, 18.532772777002183, 17.47946010082118, 16.48904274646992, 15.423990022019742, 14.415597589083934, 13.445124048460919, 12.674444673855398, 11.780336070932025, 10.783589295984076, 9.84295739823438, 9.017426696452377, 9.8607892157649, 10.781073975113276, 11.68335657503464, 12.631893796238332, 13.544410100203223, 14.533644726713032, 15.538161684378125, 16.53015749817177, 17.52979447699645, 18.543209183996925, 18.36023749332958, 17.40019541962443, 16.34138547989741, 15.32495830748014, 14.372252044031573, 13.680325478404034, 12.705783748421329, 11.813914132448355, 10.89104739406691, 10.076188304339622, 8.817066562731172, 9.747222521875386, 10.703982113703976, 11.67014783386763, 12.616756833559798, 13.563690672770997, 14.535431585042605, 15.55732009446955, 16.513357285290343, 17.520612005821338, 18.26841257424233, 17.337619585453158, 16.290025651806555, 15.294050817368861, 14.3197520441071, 13.381119008580976, 12.43126027537623, 11.574566293738192, 10.559363324249768, 9.808670971096806, 7.798718517733887, 8.736132582754184, 9.758989928655964, 10.687598948160614, 11.554919567156913, 12.58036152607962, 13.528842303532192, 14.519950837934415, 15.49743883149905, 16.474164222333513, 17.402822117375873, 16.349254719632512, 15.467774066754409, 14.505225626398659, 13.474775320282582, 12.430744991313704, 11.502226364873572, 10.567108289066862, 9.573529135905323, 8.748131363163871, 6.873142866310273, 7.822104486173798, 8.767289257286285, 9.796345086426408, 10.572657645396573, 11.638465815311775, 12.639525786604151, 13.525686678073832, 14.505312721374677, 15.449557194488646, 16.347606390043822, 15.409885019219962, 14.561371087318525, 13.574025773123392, 12.553690415352591, 11.53664876025423, 10.574939338046494, 9.646075988269292, 8.627666354042404, 7.77791254721784, 5.86504077291425, 6.872051259871347, 7.821289156306372, 8.746676073950212, 9.630094808776196, 10.657674595951484, 11.594850049742547, 12.563379810939368, 13.573359363739492, 14.46827477239661, 15.375641497458389, 14.44895539536638, 13.534598118595364, 12.60563917026024, 11.62782880033511, 10.659415191155418, 9.732082190270427, 8.704619869924793, 7.679984326584841, 6.717241047164273, 4.921010030119202, 5.873215923785374, 6.834398400377491, 7.841392878285067, 8.659323071125305, 9.710113078798775, 10.639558195415125, 11.627742367411082, 12.589166575018478, 13.526520864474648, 14.354177411490914, 13.425069788419865, 12.572396747014508, 11.6559218376693, 10.675348876906071, 9.77091998428853, 8.769828545635368, 7.728757932524897, 6.720365638968506, 5.787810717401432, 3.909778656834611, 4.890933249864972, 5.8705848291956055, 6.815113844253599, 7.63396722224591, 8.683962251861779, 9.663266748524245, 10.646360383477917, 11.626246810133157, 12.58504682786399, 13.491997404696788, 12.49314038245425, 11.539235776301666, 10.652236130554805, 9.601990408790964, 8.716860799232757, 7.826730934445776, 6.887775610093754, 5.836721394936572, 4.850724487526887, 2.940359516197737, 3.8703364554170743, 4.833435148951791, 5.7614727401298165, 6.703206593746878, 7.693992493867791, 8.63027359109843, 9.642312361470328, 10.606882997489834, 11.546832327813911, 12.479954212985016, 11.513996350598653, 10.575349515065923, 9.63595091000819, 8.676116603706639, 7.688439377247516, 6.789633582541298, 5.853887160562273, 4.916692985188346, 3.883285884041805, 2.0022798134375117, 2.8835738891526743, 3.8004601829664963, 4.7815852594656905, 5.739474142059567, 6.750354029573792, 7.723497960797899, 8.665632754402315, 9.709110642409529, 10.63976557782901, 11.512972647340316, 10.587799188603274, 9.648838953524406, 8.702230413193874, 7.715243820960946, 6.726321672783108, 5.786938237481197, 4.859599249387209, 3.9173651068692132, 2.9025973588587766, 0.9560578366466057, 1.8743746715869516, 2.8184943376698772, 3.8878599988611082, 4.888528037775981, 5.862155907412105, 6.930615939127822, 7.9221587398153845, 8.888038191699335, 9.885171404477845, 10.820447614425534, 9.841621443005566, 8.895405672840015, 7.823722154112615, 6.758010591670809, 5.807202044975704, 4.822888644253183, 3.8288896276036466, 2.863944779749659, 1.8858926261864177, 0.0, 0.9279531119456426, 1.9458459864205857, 2.9844657439387827, 4.031853469812518, 5.101601237493743, 6.034264372024817, 6.979710159796722, 8.010810929135248, 8.935932259387254, 9.915801637255777, 8.986184798531221, 7.915190222673895, 6.90958046730063, 5.874636607920857, 4.925444342536209, 3.8840898845147858, 2.957276056001443, 1.9830227435764165, 0.9556053783929157, 0.9936569805683496, 1.8975166948679951, 2.950901689344729, 4.017772637416959, 5.04927509765343, 6.059026653030134, 6.981526338847236, 8.008676781635096, 8.97769349767838, 9.938280147189712, 10.839248390815575, 9.913722060675946, 8.961431494384414, 7.9726531810038, 6.9022221672455455, 5.858819220932817, 4.9062199463495135, 3.962878791231545, 2.9280540526340113, 1.9584846973864452, 1.9929994436833063, 2.8377842644418445, 3.8583666077320187, 4.826486107490871, 5.899739279692799, 6.914401398264772, 7.863053121864452, 8.800727517962782, 9.852901947194194, 10.86940460581376, 11.89685873198063, 10.894296520053286, 9.876883522942492, 8.86209860223626, 7.8381650481391105, 6.866457693140331, 5.935965824870108, 4.9472784477855285, 3.9067338290427944, 2.9704758931800197, 2.9658813945845446, 3.8485356241245765, 4.86132093120209, 5.822782937721835, 6.748144433706868, 7.744190691630634, 8.707113824494668, 9.73160878378487, 10.686898674883482, 11.655576497676906, 12.614221496748064, 11.819769034988639, 10.797041496807601, 9.729130592636503, 8.802331144984247, 7.79236564625272, 6.908507766966597, 5.893967040519941, 4.950061261230817, 3.912900607457246, 4.025126026927728, 4.882758145367251, 5.855972097634438, 6.753653252934661, 7.766735541363728, 8.676217061350222, 9.681177744561577, 10.68059564012877, 11.737991983402038, 12.660732302424982, 13.61763735329875, 12.765159594997325, 11.734339349338128, 10.75191515304506, 9.753770038924273, 8.819701851591661, 7.900290700541116, 6.941334068307597, 5.907266897068382, 4.9208178989072024, 5.02546069698082, 5.92792115072907, 6.813868465511572, 7.726319155841788, 8.658181147754814, 9.676981710363345, 10.611518591477216, 11.634429446279357, 12.606873297163077, 13.60727554178332, 14.571201988585429, 13.653404759553885, 12.69288028621195, 11.69593328375143, 10.75495654517692, 9.792638214039506, 8.893556803041328, 7.863662927356236, 6.878347387486476, 5.969629583635242, 5.9915673452500995, 6.859140485079852, 7.7990160357444624, 8.746036560369932, 9.639540331603975, 10.634775484698958, 11.579063683029327, 12.600880465805984, 13.605912205804715, 14.536333638026646, 15.583283235472312, 14.665365696700027, 13.624362049341503, 12.692263939025787, 11.721139565508723, 10.745503916702626, 9.848738710576551, 8.854176557357276, 7.805592695247341, 6.941564653804774, 7.004425249855441, 7.83812273699617, 8.819480026480356, 9.750057484440052, 10.703132913644854, 11.561907681876024, 12.552631177538013, 13.59694505159622, 14.648050778255472, 15.572283877076721, 16.575598667625304, 15.582202444449159, 14.637192321396578, 13.70659321875106, 12.70076377071624, 11.700974033208562, 10.71028362456717, 9.769431295123775, 8.824864378789416, 7.8967975775326265, 8.015652147748655, 8.905420958858272, 9.829617491010783, 10.751027889871066, 11.664630237965476, 12.504223583138199, 13.487550997684128, 14.507450133824188, 15.449205539309688, 16.494611027484897, 17.564206115743374, 16.53946016313283, 15.565167140343029, 14.68200987287604, 13.643058964569374, 12.669516390062173, 11.784902620900485, 10.781418178734835, 9.882255529206285, 8.823636018254469], [10.682041328912389, 11.024324922496891, 11.849049045830323, 12.839924187302906, 13.64648641743674, 14.584893533084646, 15.560335276052673, 16.575219380780304, 17.514876517979403, 17.60481966505654, 16.551506988875534, 15.561089634524278, 14.4960369100741, 13.487644477138291, 12.517170936515276, 11.746491561909753, 10.852382958986382, 9.855636184038431, 8.91500428628874, 9.913653194892328, 10.78874232771054, 9.969020576506868, 10.85853616752632, 11.807073388730013, 12.616456988257582, 13.605691614767391, 14.610208572432484, 15.60220438622613, 16.60184136505081, 17.615256072051285, 17.432284381383937, 16.472242307678787, 15.413432367951767, 14.397005195534497, 13.44429893208593, 12.75237236645839, 11.777830636475686, 10.88596102050271, 9.963094282121268, 10.972414802779573, 9.745019674676815, 8.935169123268977, 9.879161706195656, 10.84532742635931, 11.688803721614157, 12.635737560825357, 13.607478473096965, 14.629366982523909, 15.585404173344703, 16.592658893875697, 17.572707984777303, 17.41513534894946, 16.362865119378217, 15.36689028494052, 14.39259151167876, 13.734864895740882, 12.85076490299547, 11.899362865527978, 10.888492433204435, 10.736624083042448, 8.72667162967953, 7.924079184147774, 8.895317784885577, 9.823926804390227, 10.626966455211273, 11.65240841413398, 12.600889191586552, 13.591997725988774, 14.569485719553409, 15.546211110387873, 16.51364917202393, 17.27720783157815, 16.39572717870005, 15.4331787383443, 14.402728432228223, 13.358698103259345, 12.430179476819212, 11.495061401012503, 10.501482247850964, 9.676084475109514, 7.8010959782559155, 6.985065262170124, 7.839336145340643, 8.868391974480767, 9.644704533450932, 10.710512703366135, 11.71157267465851, 12.597733566128191, 13.577359609429037, 14.521604082543005, 15.458433444691876, 16.3378381311656, 15.489324199264166, 14.501978885069033, 13.481643527298232, 12.464601872199871, 11.502892449992135, 10.574029100214933, 9.555619465988045, 8.705865659163482, 6.792993884859893, 5.944098147925704, 6.893336044360729, 7.818722962004569, 8.702141696830555, 9.729721484005843, 10.666896937796906, 11.635426698993728, 12.645406251793851, 13.540321660450969, 14.486468552106443, 15.37690850731202, 14.462551230541004, 13.53359228220588, 12.55578191228075, 11.587368303101062, 10.660035302216071, 9.632572981870435, 8.607937438530483, 7.6451941591099155, 5.848963142064845, 4.945262811839731, 5.906445288431849, 6.913439766339424, 7.731369959179664, 8.782159966853131, 9.711605083469482, 10.699789255465442, 11.661213463072837, 12.598567752529007, 13.525349997725266, 14.353022900365506, 13.50034985896015, 12.583874949614941, 11.603301988851712, 10.698873096234172, 9.697781657581013, 8.65671104447054, 7.648318750914148, 6.7157638293470745, 4.8377317687802535, 3.9629801379193297, 4.942631717249963, 5.887160732307956, 6.706014110300267, 7.756009139916135, 8.735313636578603, 9.718407271532277, 10.698293698187516, 11.65709371591835, 12.564044292751147, 13.42109349439989, 12.467188888247307, 11.580189242500445, 10.529943520736605, 9.644813911178398, 8.75468404639142, 7.815728722039396, 6.764674506882215, 5.7786775994725295, 3.8683126281433795, 2.9423833434714317, 3.9054820370061485, 4.833519628184174, 5.7752534818012355, 6.766039381922148, 7.702320479152788, 8.714359249524687, 9.678929885544193, 10.61887921586827, 11.552001101039375, 12.441949462544294, 11.503302627011564, 10.563904021953832, 9.60406971565228, 8.616392489193156, 7.71758669448694, 6.781840272507916, 5.844646097133989, 4.8112389959874475, 2.9302329253831543, 1.9556207772070318, 2.872507071020854, 3.853632147520048, 4.811521030113925, 5.8224009176281495, 6.7955448488522565, 7.737679642456674, 8.781157530463886, 9.71181246588337, 10.689020004792175, 11.515752300548915, 10.576792065470046, 9.630183525139515, 8.643196932906587, 7.65427478472875, 6.714891349426838, 5.7875523613328514, 4.845318218814856, 3.830550470804419, 1.8840109485922483, 0.946421559641309, 1.8905412257242344, 2.9599068869154657, 3.960574925830339, 4.9342027954664625, 6.00266282718218, 6.994205627869742, 7.960085079753693, 8.957218292532202, 9.939198083607662, 10.769574554951207, 9.823358784785656, 8.751675266058257, 7.6859637036164505, 6.735155156921346, 5.750841756198825, 4.756842739549289, 3.7918978916953012, 2.81384573813206, 0.9279531119456426, 0.0, 1.0178928744749431, 2.05651263199314, 3.103900357866875, 4.173648125548101, 5.106311260079174, 6.05175704785108, 7.0828578171896055, 8.007979147441612, 8.987848525310135, 9.914137910476864, 8.843143334619537, 7.837533579246272, 6.802589719866499, 5.853397454481851, 4.812042996460428, 3.8852291679470854, 2.910975855522059, 1.8835584903385583, 1.9216100925139923, 0.9695635829223527, 2.0229485773990863, 3.089819525471316, 4.121321985707787, 5.131073541084492, 6.053573226901594, 7.080723669689454, 8.049740385732738, 9.01032703524407, 9.978353673472355, 10.841675172621589, 9.889384606330054, 8.90060629294944, 7.830175279191187, 6.786772332878459, 5.834173058295155, 4.890831903177188, 3.856007164579654, 2.8864378093320875, 2.920952555628949, 1.9098311524962022, 2.930413495786376, 3.898532995545229, 4.971786167747156, 5.9864482863191295, 6.935100009918809, 7.87277440601714, 8.924948835248552, 9.941451493868115, 10.968905620034986, 11.822249631998929, 10.804836634888135, 9.790051714181903, 8.766118160084753, 7.794410805085973, 6.86391893681575, 5.875231559731171, 4.834686940988437, 3.8984290051256623, 3.8621078930244948, 2.9205825121789344, 3.933367819256447, 4.894829825776193, 5.820191321761225, 6.816237579684992, 7.779160712549025, 8.803655671839227, 9.75894556293784, 10.727623385731263, 11.686268384802421, 12.737874977008088, 11.724994608753244, 10.657083704582146, 9.73028425692989, 8.720318758198362, 7.804734265406548, 6.790193538959892, 5.846287759670767, 4.809127105897196, 4.921352525367678, 3.9548050334216085, 4.928018985688795, 5.825700140989018, 6.838782429418085, 7.7482639494045795, 8.753224632615932, 9.752642528183125, 10.810038871456394, 11.73277919047934, 12.689684241353108, 13.69311270694297, 12.662292461283773, 11.679868264990702, 10.681723150869916, 9.747654963537304, 8.796517198981068, 7.837560566747548, 6.803493395508332, 5.817044397347153, 5.9216871954207715, 4.999968038783428, 5.885915353565929, 6.798366043896145, 7.730228035809171, 8.749028598417702, 9.683565479531573, 10.706476334333715, 11.678920185217434, 12.679322429837677, 13.643248876639786, 14.581357871499529, 13.620833398157595, 12.623886395697072, 11.682909657122563, 10.720591325985149, 9.789783301481279, 8.759889425796187, 7.774573885926426, 6.865856082075192, 6.8877938436900505, 5.93118737313421, 6.87106292379882, 7.818083448424289, 8.711587219658332, 9.706822372753315, 10.651110571083684, 11.672927353860342, 12.677959093859073, 13.608380526081003, 14.655330123526669, 15.593318808645671, 14.552315161287147, 13.62021705097143, 12.649092677454366, 11.673457028648269, 10.744965209016502, 9.750403055797227, 8.701819193687292, 7.8377911522447254, 7.900651748295392, 6.9101696250505285, 7.8915269145347136, 8.82210437249441, 9.775179801699212, 10.633954569930381, 11.62467806559237, 12.668991939650578, 13.72009766630983, 14.644330765131079, 15.670074832260232, 16.510155556394803, 15.565145433342222, 14.634546330696702, 13.628716882661882, 12.62573710698115, 11.606510123007121, 10.665657793563726, 9.721090877229367, 8.793024075972577, 8.911878646188606, 7.9774678469126306, 8.901664379065139, 9.823074777925424, 10.736677126019831, 11.576270471192556, 12.559597885738485, 13.579497021878545, 14.521252427364045, 15.566657915539253, 16.638225065404527, 17.467413275078474, 16.493120252288673, 15.609962984821683, 14.571012076515016, 13.594279463834761, 12.681129119340437, 11.677644677174786, 10.778482027646236, 9.71986251669442], [11.699934203387333, 12.00171749479117, 11.044278521903628, 12.03515366337621, 12.736289062556772, 13.674696178204677, 14.650137921172703, 15.665022025900335, 16.604679163099433, 16.767423134165764, 15.71411045798476, 14.723693103633503, 13.658640379183325, 12.650247946247516, 11.679774405624501, 10.909095031018978, 10.021370615861652, 9.024623840913703, 9.932897160763682, 10.93154606936727, 11.79666182709089, 10.946413148801145, 10.053765643599625, 11.002302864803317, 11.706259633377613, 12.695494259887422, 13.700011217552515, 14.692007031346161, 15.691644010170839, 16.705058717171315, 16.594887850493162, 15.634845776788012, 14.576035837060992, 13.559608664643722, 12.606902401195155, 11.914975835567615, 10.946818293350956, 10.054948677377983, 10.98098715659621, 11.990307677254515, 10.752939174057165, 9.912561695563255, 9.074391182268961, 10.040556902432614, 10.778606366734188, 11.725540205945387, 12.697281118216996, 13.71916962764394, 14.675206818464734, 15.682461538995728, 16.662510629897334, 16.57773881805868, 15.52546858848744, 14.529493754049746, 13.555194980787984, 12.897468364850107, 12.01975255987074, 11.06835052240325, 11.906385307679377, 11.75451695751739, 9.73459112905988, 8.901471756442053, 8.090547260958882, 9.019156280463532, 9.716769100331303, 10.74221105925401, 11.690691836706582, 12.681800371108805, 13.65928836467344, 14.636013755507904, 15.60345181714396, 16.42897192275025, 16.479778493622252, 15.517230053266502, 14.575100936729578, 13.877305096813531, 12.948786470373399, 12.096058556196478, 11.519375122325908, 10.693977349584456, 8.809015477636265, 7.962457834464404, 7.0345656214139485, 8.063621450554072, 8.734507178570963, 9.800315348486166, 10.801375319778542, 11.687536211248222, 12.667162254549067, 13.611406727663036, 14.548236089811907, 15.4896022223377, 16.50721707373911, 15.519871759543976, 14.499536401773176, 13.482494746674814, 12.520785324467077, 11.591921974689875, 10.573512340462988, 9.723758533638424, 7.800913384240243, 6.921490720219984, 6.0885655204340345, 7.013952438077874, 7.791944341950586, 8.819524129125874, 9.756699582916937, 10.725229344113759, 11.735208896913882, 12.630124305571, 13.576271197226474, 14.528672598484118, 15.480444105015948, 14.551485156680824, 13.573674786755694, 12.605261177576004, 11.677928176691013, 10.650465856345377, 9.625830313005427, 8.663087033584858, 6.856882641445194, 5.922655384134011, 5.014745439521432, 6.008040323009472, 6.821172604299695, 7.871962611973163, 8.801407728589513, 9.789591900585473, 10.751016108192868, 11.688370397649038, 12.615152642845297, 13.544260265916346, 14.518242733435093, 13.601767824089885, 12.621194863326656, 11.716765970709115, 10.715674532055955, 9.674603918945483, 8.66621162538909, 7.733656703822017, 5.845651268160602, 4.940372710213609, 4.032434362369996, 4.976963377427989, 5.795816755420299, 6.845811785036167, 7.825116281698634, 8.808209916652308, 9.788096343307547, 10.746896361038381, 11.653846937871178, 12.69511579682309, 13.48508176272225, 12.59808211697539, 11.547836395211549, 10.662706785653342, 9.772576920866362, 8.83362159651434, 7.782567381357158, 6.796570473947472, 4.876232127523728, 3.9197759157657113, 2.9952846821261807, 3.9233222733042057, 4.865056126921267, 5.855842027042179, 6.792123124272819, 7.804161894644718, 8.768732530664224, 9.708681860988301, 10.641803746159406, 11.69350586202488, 12.521195501486508, 11.581796896428775, 10.621962590127223, 9.6342853636681, 8.735479568961884, 7.7997331469828595, 6.862538971608932, 5.8291318704623905, 3.9381524247635027, 2.9330133495013113, 1.962309716140886, 2.94343479264008, 3.9013236752339564, 4.91220356274818, 5.885347493972287, 6.8274822875767045, 7.870960175583918, 8.8016151110034, 9.778822649912206, 10.703996108649248, 11.59468493994499, 10.648076399614459, 9.661089807381531, 8.672167659203692, 7.732784223901781, 6.805445235807795, 5.863211093289799, 4.848443345279362, 2.901903823067191, 1.924463536927192, 0.9803438708442667, 2.01625373195675, 3.0169217708716234, 3.990549640507747, 5.050255952534741, 6.023571873319603, 6.989451325203554, 7.986584537982062, 8.921305209132717, 9.900131380552684, 10.841251659260598, 9.769568140533199, 8.703856578091393, 7.753048031396289, 6.768734630673768, 5.774735614024233, 4.809790766170245, 3.8317386126070034, 1.9458459864205857, 1.0178928744749431, 0.0, 1.0386197575181972, 2.086007483391932, 3.155755251073158, 4.088418385604231, 5.033864173376136, 6.064964942714662, 6.990086272966668, 7.96995565083519, 8.97470496108061, 9.861036209094479, 8.855426453721215, 7.820482594341443, 6.871290328956794, 5.829935870935371, 4.903122042422028, 3.928868729997002, 2.9014513648135014, 2.939502966988935, 1.987456457397296, 1.0587256835706007, 2.071926650996373, 3.1034291112328445, 4.113180666609548, 5.035680352426651, 6.062830795214511, 7.031847511257796, 7.992434160769126, 8.960460798997412, 9.88598712913704, 10.87306446066155, 9.918499167424386, 8.848068153666132, 7.804665207353403, 6.852065932770099, 5.9087247776521306, 4.873900039054597, 3.904330683807031, 3.9388454301038918, 2.9277240269711453, 2.0994011526616476, 3.0611364646544548, 4.056248673323197, 5.059222538752365, 6.000603889745627, 6.938278285843958, 7.990452715075369, 8.923558619393173, 9.951012745560044, 10.866561588514381, 11.809250186617172, 10.807944588656847, 9.784011034559697, 8.812303679560916, 7.881811811290693, 6.893124434206114, 5.85257981546338, 4.916321879600606, 4.880000767499437, 3.9384753866538773, 3.1023554761317182, 4.057433294885419, 4.982794790870451, 5.978841048794218, 6.941764181658252, 7.9186788079984005, 8.873968699097013, 9.842646521890437, 10.801291520961595, 11.852898113167262, 12.742887483228188, 11.67497657905709, 10.748177131404834, 9.738211632673305, 8.82262713988149, 7.808086413434834, 6.8641806341457094, 5.827019980372138, 5.93924539984262, 4.972697907896551, 4.097006642564066, 4.988303610098244, 6.001385898527312, 6.9108674185138055, 7.91582810172516, 8.878841352606818, 9.934013514504981, 10.847802326638513, 11.804707377512281, 12.836471521861178, 13.680185335758715, 12.697761139465646, 11.69961602534486, 10.765547838012246, 9.81441007345601, 8.85545344122249, 7.821386269983274, 6.834937271822095, 6.9395800698957135, 6.017860913258371, 5.0549030104412, 5.960969513005371, 6.892831504918397, 7.911632067526927, 8.846168948640798, 9.842187968583495, 10.814631819467214, 11.815034064087458, 12.75827201279896, 13.780404826843814, 14.638726272632537, 13.641779270172016, 12.700802531597505, 11.738484200460091, 10.807676175956221, 9.777782300271129, 8.792466760401368, 7.883748956550134, 7.905686718164993, 6.949080247609153, 6.040050580674091, 6.98707110529956, 7.874190688767557, 8.86942584186254, 9.81371404019291, 10.835530822969567, 11.840562562968298, 12.770983995190228, 13.774120911995729, 14.73685365236467, 15.57020803576209, 14.638109925446372, 13.666985551929308, 12.69134990312321, 11.762858083491444, 10.768295930272169, 9.719712068162234, 8.855684026719668, 8.918544622770334, 7.928062499525471, 7.060514571409985, 7.991092029369681, 8.937783270808437, 9.796558039039606, 10.787281534701595, 11.831595408759803, 12.882701135419055, 13.806934234240304, 14.788865620729291, 15.695991311162427, 16.583038307817166, 15.652439205171644, 14.646609757136824, 13.643629981456092, 12.624402997482063, 11.683550668038668, 10.738983751704309, 9.81091695044752, 9.929771520663548, 8.995360721387573, 8.07065203594041, 8.992062434800694, 9.899280595129056, 10.738873940301781, 11.72220135484771, 12.74210049098777, 13.68385589647327, 14.729261384648478, 15.800828534513752, 16.682975165896035, 16.60410579630237, 15.674686959830623, 14.693425092509823, 13.768851609553613, 13.094705634165203, 12.037755859785005, 11.79637490212118, 10.737755391169364], [12.699939144617732, 12.957342375625535, 11.978005362188323, 11.328817662072018, 11.747010047968654, 12.68541716361656, 13.660858906584586, 14.675743011312218, 15.615400148511318, 15.728803376647566, 14.675490700466563, 13.685073346115306, 12.620020621665129, 11.61162818872932, 10.641154648106303, 9.87047527350078, 9.03059168350304, 9.915858895147167, 10.860075494215899, 11.886813090566005, 12.820856016609024, 11.933412521065382, 10.98749248388432, 10.287016261092472, 10.716980618789496, 11.706215245299305, 12.710732202964397, 13.702728016758044, 14.702364995582721, 15.715779702583198, 15.556268092974964, 14.596226019269814, 13.537416079542794, 12.520988907125524, 11.568282643676957, 10.876356078049417, 9.956039360992344, 10.884361205656521, 11.908165490048427, 12.94557469845325, 11.777133363575299, 10.899561067827491, 10.008118022553656, 9.29722918274798, 9.78932735214607, 10.73626119135727, 11.708002103628878, 12.729890613055822, 13.685927803876616, 14.69318252440761, 15.673231615309216, 15.539119060540484, 14.486848830969242, 13.490873996531548, 12.516575223269786, 11.85884860733191, 11.028973627512128, 11.897763050681789, 12.833563641131594, 12.793136715035587, 10.758785318578013, 9.88847112870629, 9.024274101243577, 8.232674815642255, 8.727490085743186, 9.752932044665894, 10.701412822118465, 11.692521356520688, 12.670009350085323, 13.646734740919786, 14.614172802555842, 15.439692908162133, 15.441158736104054, 14.478610295748304, 13.53648117921138, 12.869924875918288, 11.958007538014787, 12.893125613821496, 12.557994879844104, 11.732597107102652, 9.8332096671544, 8.949457206728638, 7.968292461698644, 7.168156379944682, 7.745228163982846, 8.811036333898048, 9.812096305190424, 10.698257196660105, 11.67788323996095, 12.622127713074919, 13.55895707522379, 14.500323207749583, 15.534941343765933, 15.450763496083496, 14.515310425440962, 13.918812821976339, 12.957103399768602, 12.630541732208073, 11.612132097981185, 10.76237829115662, 8.825107573758377, 7.908490092484218, 7.02229236071873, 6.113109641953613, 6.802665327362469, 7.830245114537756, 8.76742056832882, 9.735950329525641, 10.745929882325765, 11.640845290982883, 12.586992182638356, 13.539393583896, 14.529912555434162, 15.458871503769286, 14.61229454427389, 13.6438809350942, 12.71654793420921, 11.689085613863574, 10.664450070523623, 9.701706791103055, 7.881076830963329, 6.909654756398245, 5.948472279806127, 5.085691980938117, 5.831893589711578, 6.8826835973850455, 7.812128714001395, 8.800312885997354, 9.761737093604749, 10.699091383060921, 11.625873628257178, 12.554981251328227, 13.537149092499792, 14.563874430031554, 13.659814620844852, 12.755385728227312, 11.754294289574151, 10.713223676463679, 9.704831382907287, 8.772276461340214, 6.8698454576787364, 5.943309000018211, 4.966161202654691, 4.054615035356634, 4.806537740832182, 5.85653277044805, 6.8358372671105165, 7.8189309020641895, 8.798817328719428, 9.757617346450264, 10.664567923283059, 11.705836782234972, 12.60138503769836, 13.560188722917058, 12.586456152729745, 11.701326543171538, 10.811196678384558, 9.872241354032536, 8.821187138875354, 7.83519023146567, 5.9004263170418625, 4.922712205570313, 3.9290115224108764, 3.0009739312328514, 3.8757771123331497, 4.866563012454062, 5.802844109684702, 6.8148828800566, 7.779453516076105, 8.719402846400182, 9.652524731571287, 10.702341051403415, 11.637498776462618, 12.5321205702515, 11.66058234764542, 10.672905121186297, 9.77409932648008, 8.838352904501056, 7.901158729127129, 6.867751627980588, 4.962346614281637, 3.957207539019446, 2.9865039056590206, 2.0053788291598265, 2.9120446606458383, 3.9229245481600628, 4.896068479384169, 5.838203272988586, 6.879795364962455, 7.8104503003819366, 8.787657839290741, 9.712831298027783, 10.651791533106651, 11.598400073437183, 10.69970956489973, 9.710787416721889, 8.771403981419978, 7.844064993325992, 6.901830850807996, 5.887063102797559, 3.9405235805853884, 2.963083294445389, 2.0189636283624637, 0.9776339744385528, 1.9783020133534261, 2.9519298829895497, 4.011636195016543, 4.984952115801405, 5.950831567685356, 6.947964780463864, 7.8826854516145195, 8.861511623034488, 9.80772739320004, 10.808187898051397, 9.742476335609592, 8.791667788914486, 7.807354388191965, 6.813355371542429, 5.848410523688441, 4.8703583701252, 2.9844657439387827, 2.05651263199314, 1.0386197575181972, 0.0, 1.0473877258737347, 2.1171354935549602, 3.049798628086033, 3.9952444158579383, 5.026345185196464, 5.95146651544847, 6.931335893316992, 7.936085203562412, 9.007079779419739, 9.894046211239413, 8.85910235185964, 7.909910086474991, 6.868555628453568, 5.9417417999402256, 4.967488487515199, 3.940071122331698, 3.9781227245071324, 3.0260762149154927, 2.097345441088798, 1.033306893478176, 2.064809353714647, 3.0745609090913506, 3.997060594908452, 5.024211037696312, 5.993227753739597, 6.953814403250928, 7.9218410414792135, 8.847367371618843, 9.834444703143351, 10.877186826408648, 9.886687911184328, 8.8432849648716, 7.890685690288295, 6.947344535170328, 5.912519796572794, 4.942950441325228, 4.977465187622089, 3.966343784489342, 2.9906362068951102, 2.0225167071362575, 3.017628915805, 4.020602781234167, 4.961984132227429, 5.89965852832576, 6.951832957557171, 7.884938861874975, 8.912392988041846, 9.827941830996183, 10.770630429098974, 11.785415349805206, 10.822630792077893, 9.850923437079114, 8.92043156880889, 7.931744191724311, 6.891199572981577, 5.954941637118803, 5.918620525017634, 4.977095144172074, 3.9935905303651813, 3.0188135373672216, 3.944175033352254, 4.94022129127602, 5.903144424140054, 6.880059050480202, 7.835348941578814, 8.804026764372239, 9.762671763443397, 10.814278355649064, 11.794723832373535, 12.713596336575286, 11.78679688892303, 10.776831390191504, 9.861246897399687, 8.84670617095303, 7.902800391663906, 6.865639737890334, 6.977865157360816, 6.011317665414747, 4.988241696797529, 3.949683852580047, 4.962766141009114, 5.872247660995608, 6.877208344206962, 7.84022159508862, 8.895393756986781, 9.809182569120315, 10.766087619994083, 11.79785176434298, 12.732021684904062, 13.736380896983842, 12.738235782863056, 11.804167595530444, 10.853029830974206, 9.894073198740687, 8.860006027501472, 7.873557029340291, 7.939585011126113, 6.993764182028667, 5.946138064674663, 4.922349755487174, 5.8542117474002, 6.873012310008731, 7.807549191122602, 8.803568211065297, 9.776012061949016, 10.77641430656926, 11.719652255280762, 12.741785069325616, 13.690562621777884, 14.680399027690212, 13.739422289115703, 12.777103957978289, 11.846295933474417, 10.816402057789325, 9.831086517919564, 8.92236871406833, 8.905691659395393, 7.9249835163794495, 6.931285634907554, 5.996292172940947, 6.83557093124936, 7.830806084344343, 8.775094282674713, 9.79691106545137, 10.801942805450102, 11.732364237672032, 12.73550115447753, 13.698233894846473, 14.622044384907436, 15.582701619451472, 14.705605309447506, 13.729969660641409, 12.80147784100964, 11.806915687790365, 10.75833182568043, 9.855688967950067, 9.918549564000735, 8.903965768295768, 7.951749625643448, 7.000313097011068, 7.8991635132902385, 8.757938281521408, 9.748661777183399, 10.792975651241607, 11.844081377900858, 12.768314476722107, 13.750245863211093, 14.657371553644229, 15.60238167669681, 15.65227071980966, 14.64644127177484, 13.748114951819106, 13.462988629194326, 12.721487012387158, 11.776920096052798, 10.81092189167792, 10.92977646189395, 9.92253905483979, 8.961887090173875, 8.001283502442082, 8.860660837610858, 9.700254182783583, 10.683581597329514, 11.703480733469574, 12.645236138955074, 13.690641627130281, 14.762208776995555, 15.644355408377837, 15.614826781714251, 14.685407945242506, 13.704146077921706, 12.779572594965495, 12.38836963286101, 12.9714827000697, 12.796379843351579, 11.737760332399763], [13.568972143482924, 13.689694541073832, 12.71035752763662, 11.836512337494364, 10.808277697863316, 11.746684813511223, 12.722126556479248, 13.737010661206877, 14.676667798405978, 14.7925056559522, 13.7572876513885, 12.766870297037244, 11.706372346143594, 10.697979913207785, 9.727506372584768, 8.987006546575659, 9.878206846127263, 10.775501120430249, 11.71971771949898, 12.746455315849087, 13.682107572687162, 12.731081233068434, 11.719844649332616, 10.83809866246199, 9.778248268684157, 10.767482895193968, 11.771999852859059, 12.763995666652706, 13.763632645477383, 14.777047352477862, 14.64261981745343, 13.68257774374828, 12.62376780402126, 11.60734063160399, 10.654634368155422, 9.992887351124295, 10.803654523616567, 11.731976368280744, 12.767807715331509, 13.805216923736332, 12.638384919653435, 11.697229779830543, 10.740470188001952, 9.849435434848063, 8.850595002040732, 9.797528841251932, 10.76926975352354, 11.791158262950484, 12.747195453771278, 13.754450174302272, 14.66265182073029, 14.62547078501895, 13.573200555447707, 12.577225721010013, 11.602926947748252, 10.975379880406788, 11.876588790136351, 12.745378213306012, 13.693205866414676, 13.68383427323701, 11.672085818246963, 10.736562468937475, 9.756626266691873, 8.828017247187223, 7.788757735637848, 8.814199694560555, 9.762680472013127, 10.75378900641535, 11.731276999979984, 12.70800239081445, 13.603593007976915, 14.429113113583206, 14.52751046058252, 13.56496202022677, 12.622832903689845, 11.986456148993167, 12.80562270063901, 13.740740776445719, 13.546436030338954, 12.694715532193117, 10.746510166823349, 9.797548546959824, 8.769243490930181, 7.815998260133604, 6.806495813877508, 7.872303983792711, 8.873363955085086, 9.759524846554767, 10.739150889855612, 11.67920688433187, 12.548377280644862, 13.489743413170656, 14.524361549187006, 14.537115220561962, 13.601662149919427, 13.047601011098955, 13.804718562392825, 13.618982882702923, 12.600573248476035, 11.75081944165147, 9.750929937732925, 8.772481286385293, 7.823243389950267, 6.897856472306428, 5.8639329772571305, 6.8915127644324174, 7.828688218223482, 8.797217979420303, 9.807197532220426, 10.630265496403956, 11.57641238805943, 12.528813789317073, 13.519332760855235, 14.448291709190359, 14.527523764936909, 14.016487479867365, 13.70498908470406, 12.677526764358424, 11.652891221018473, 10.690147941597905, 8.806899194937877, 7.792732922418912, 6.831550445826794, 5.870438811290932, 4.893161239606239, 5.943951247279706, 6.873396363896056, 7.861580535892015, 8.82300474349941, 9.688511588481994, 10.615293833678251, 11.5444014567493, 12.526569297920865, 13.51648670415782, 14.513276286484174, 13.766725209198029, 12.742735440069001, 11.70166482695853, 10.693272533402137, 9.760717611835064, 7.795667821653285, 6.82664414850714, 5.849239368675358, 4.839361865709449, 3.8678053907268426, 4.917800420342711, 5.897104917005177, 6.88019855195885, 7.86008497861409, 8.747037551871337, 9.653988128704132, 10.677316158147677, 11.553997311824627, 12.512800997043325, 13.439917818369068, 12.729224428980046, 11.799637828879408, 10.860682504527386, 9.809628289370204, 8.823631381960519, 6.826248681016411, 5.806047354059242, 4.812346670899805, 3.8843090797217803, 2.9370447622278104, 3.9278306623487227, 4.864111759579362, 5.876150529951261, 6.840721165970766, 7.7088230518212555, 8.64194493699236, 9.654953325529682, 10.590111050588884, 11.484732844377767, 12.514044013284742, 11.720292847060033, 10.821487052353817, 9.88574063037479, 8.90901931912446, 7.87561221797792, 5.888168978256186, 4.883029902993995, 3.9123262696335694, 2.9312011931343753, 1.973312310540499, 2.9841921980547235, 3.95733612927883, 4.899470922883247, 5.83240763908872, 6.763062574508202, 7.740270113417007, 8.66544357215405, 9.604403807232918, 10.55101234756345, 11.537998939796378, 10.758175142595626, 9.818791707293714, 8.891452719199727, 7.949218576681731, 6.934450828671294, 4.987911306459123, 4.010471020319124, 3.0663513542361986, 2.0250217003122875, 1.0395696632480869, 2.0131975328842104, 2.964248469142808, 3.93756438992767, 4.903443841811621, 5.900577054590129, 6.835297725740785, 7.814123897160753, 8.760339667326305, 9.832023186053704, 10.789864061483328, 9.839055514788223, 8.8547421140657, 7.860743097416164, 6.895798249562176, 5.917746095998935, 4.031853469812518, 3.103900357866875, 2.086007483391932, 1.0473877258737347, 0.0, 1.0697477676812255, 2.0024109022122984, 2.947856689984204, 3.9789574593227295, 4.9040787895747355, 5.883948167443258, 6.888697477688678, 7.959692053546004, 8.965301808919268, 9.906490077733375, 8.957297812348726, 7.915943354327303, 6.9891295258139605, 6.014876213388934, 4.987458848205433, 5.025510450380867, 4.073463940789228, 3.144733166962533, 2.0806946193519105, 1.017421627840912, 2.0271731832176156, 2.9496728690347176, 3.976823311822578, 4.945840027865863, 5.906426677377194, 6.8744533156054795, 7.7999796457451085, 8.787056977269618, 9.829799100534915, 10.90023011429317, 9.890672690745335, 8.93807341616203, 7.994732261044063, 6.959907522446529, 5.990338167198963, 6.024852913495824, 5.013731510363078, 4.011613861892045, 3.0434943621331922, 1.970241189931265, 2.9732150553604324, 3.914596406353694, 4.852270802452025, 5.904445231683436, 6.837551136001241, 7.865005262168113, 8.780554105122448, 9.72324270322524, 10.738027623931472, 11.761961178028622, 10.898311162952849, 9.967819294682625, 8.979131917598046, 7.938587298855312, 7.002329362992538, 6.8506101910952015, 5.909084810249642, 4.8626235292303726, 3.8664286999914435, 2.941067204006411, 3.9371134619301773, 4.900036594794211, 5.832671324606467, 6.787961215705079, 7.756639038498504, 8.715284037569662, 9.766890629775329, 10.747336106499802, 11.762048107530607, 12.688847555182862, 11.807389274102913, 10.793236563477254, 9.778695837030599, 8.834790057741474, 7.797629403967902, 7.909854823438384, 6.90975134259957, 5.857274695662721, 4.797299015204269, 3.966995578539709, 4.869139831649765, 5.874100514861119, 6.792833869214885, 7.848006031113047, 8.76179484324658, 9.718699894120348, 10.750464038469246, 11.684633959030329, 12.724462711832498, 13.640286449122888, 12.764643810088941, 11.785019497051774, 10.826062864818255, 9.791995693579038, 8.805546695417858, 8.808618009991305, 7.862797180893859, 6.815171063539855, 5.769964918111396, 4.970743020475077, 5.943943469213526, 6.878480350327397, 7.756180485191563, 8.728624336075283, 9.729026580695527, 10.672264529407027, 11.69439734345188, 12.643174895904151, 13.65559580263756, 14.655089223929975, 13.737580172536786, 12.778285599551984, 11.748391723866892, 10.76307618399713, 9.830316231901174, 9.774724658260585, 8.79401651524464, 7.790927860190639, 6.843907335565169, 5.9521022043242375, 6.917157808822807, 7.8614460071531775, 8.81861346582234, 9.790670535192618, 10.721091967414548, 11.688113428603796, 12.650846168972738, 13.574656659033703, 14.535313893577738, 14.68733312687702, 13.764852718219704, 13.733467507087207, 12.719259176780827, 11.670675314670893, 10.72472196681526, 10.787582562865925, 9.77299876716096, 8.811391850926531, 7.84792825963529, 7.015694786365117, 7.8442900059998735, 8.835013501661864, 9.814678051612576, 10.843605960173239, 11.757042206464623, 12.702858137337358, 13.609983827770495, 14.554993950823077, 14.713538369704324, 13.707708921669504, 12.809382601713768, 13.828609585687797, 13.59052001125235, 12.64595309491799, 11.679954890543112, 11.793866265858048, 10.782181280122872, 9.821529315456957, 8.848898665066304, 7.9771921106857375, 8.786605907262048, 9.76993332180798, 10.785277684391511, 11.727033089877011, 12.772438578052219, 13.722341510584897, 14.596967682504104, 14.676094431608913, 13.746675595137168, 12.76541372781637, 11.840840244860157, 12.830105583946397, 13.703834865517997, 13.66541284221677, 12.606793331264955], [14.618448863841813, 14.579786423009812, 13.600449409572601, 12.726604219430344, 11.698369579799296, 11.111125512658553, 11.997498845420553, 13.012382950148183, 13.84107471061687, 13.722757888270973, 12.687539883707272, 11.697122529356015, 10.667713974446084, 9.773549141414126, 8.848200321801597, 9.836677941922494, 10.794063420896086, 11.81843601812436, 12.76919443985787, 13.795932036207976, 14.572199454623142, 13.621173115004414, 12.609936531268596, 11.72819054439797, 10.668340150620137, 10.131923594341298, 11.047372141800365, 12.03834055351997, 12.78552890422378, 13.757270650315743, 13.63060773646991, 12.759402318169077, 11.704788098556486, 10.728034580820818, 9.775328317372251, 10.84255874647113, 11.71951109838539, 12.647832943049567, 13.703083867296083, 14.748209114449333, 13.528476801589415, 12.587321661766524, 11.630562069937932, 10.739527316784043, 9.740686883976712, 9.09232386544175, 10.044642042464845, 10.979047670045228, 11.769091712517675, 12.734673472140155, 13.592904053049063, 13.746164734235778, 12.693894504664536, 11.697919670226842, 10.72362089696508, 11.662253932491204, 12.61211266569595, 13.661234788074834, 14.62848201837925, 14.573926155172991, 12.562177700182945, 11.626654350873455, 10.646718148627853, 9.718109129123203, 8.678849617573828, 8.108994718750374, 9.038052760954432, 9.911979510055673, 10.753173258726381, 11.67599775249534, 12.533845240295689, 13.35936534590198, 13.648204409799348, 12.685655969443598, 11.743526852906674, 12.673330201077583, 13.541146576198608, 14.476264652005318, 14.436527912274938, 13.584807414129099, 11.63660204875933, 10.687640428895806, 9.659335372866163, 8.706090142069584, 7.696587695813488, 7.053036025586371, 7.984082689894679, 8.848111937353014, 9.761047148602009, 10.609459116650644, 11.478629512963636, 12.41999564548943, 13.454613781505778, 13.65780916977879, 12.722356099136256, 13.734475063183371, 14.540242437952422, 14.509074764638907, 13.490665130412019, 12.640911323587455, 10.641021819668907, 9.662573168321275, 8.71333527188625, 7.787948354242409, 6.754024859193111, 6.002231499242011, 6.939406953033075, 7.8858050702185505, 8.829093790966823, 9.56051772872273, 10.506664620378203, 11.459066021635847, 12.449584993174009, 13.378543941509133, 13.648217714153738, 14.627455236851542, 14.595080966640044, 13.567618646294408, 12.542983102954457, 11.580239823533889, 9.696991076873859, 8.682824804354894, 7.721642327762775, 6.760530693226913, 5.78325312154222, 5.031918057162893, 5.942537556882315, 6.847164307417767, 7.808588515025162, 8.618763820800767, 9.545546065997026, 10.474653689068075, 11.45682153023964, 12.446738936476594, 13.443528518802948, 14.395226400651756, 13.632827322004985, 12.591756708894513, 11.58336441533812, 10.650809493771048, 8.685759703589268, 7.716736030443122, 6.739331250611339, 5.72945374764543, 4.757897272662824, 4.0057672302258975, 4.966246109991436, 5.865782323484603, 6.845668750139842, 7.67728978419011, 8.584240361022907, 9.607568390466453, 10.4842495441434, 11.443053229362098, 12.370170050687841, 13.341167215595982, 12.689729710815392, 11.75077438646337, 10.699720171306188, 9.713723263896503, 7.716340562952393, 6.696139235995224, 5.702438552835787, 4.774400961657761, 3.8271366441637915, 2.963436120750811, 3.8997172179814505, 4.861734301477013, 5.826304937496518, 6.63907528414003, 7.572197169311135, 8.585205557848457, 9.520363282907658, 10.41498507669654, 11.444296245603516, 12.426195314283422, 11.84223626201688, 10.865928817877656, 9.799111201060443, 8.765704099913902, 6.778260860192168, 5.773121784929976, 4.802418151569551, 3.8212930750703564, 2.86340419247648, 2.0197976564568116, 2.9429199008045828, 3.885054694409, 4.762659871407494, 5.693314806826976, 6.670522345735781, 7.595695804472824, 8.534656039551692, 9.481264579882223, 10.468251172115151, 11.464077609819014, 10.839540916956778, 9.878413479677537, 8.853720312834804, 7.838952564824368, 5.978487445196705, 4.943814911373098, 3.999695245290172, 2.930329584098941, 1.929661545184068, 0.9560336755479445, 1.8945007014615824, 2.8678166222464445, 3.8336960741303954, 4.830829286908904, 5.76554995805956, 6.7443761294795275, 7.690591899645079, 8.762275418372479, 9.827986980814284, 10.77879552750939, 9.875491323728765, 8.863869247601713, 7.898924399747725, 6.920872246184484, 5.101601237493743, 4.173648125548101, 3.1557552510731575, 2.1171354935549602, 1.0697477676812255, 0.0, 0.9326631345310729, 1.878108922302978, 2.909209691641504, 3.83433102189351, 4.814200399762032, 5.818949710007452, 6.889944285864778, 7.895554041238043, 8.930497900617816, 9.879690166002465, 8.985691122008529, 8.058877293495186, 7.08462398107016, 6.057206615886659, 6.095258218062093, 5.143211708470454, 4.205986264760635, 3.134074263109845, 2.0687654749520688, 1.0590139195753647, 1.8799251013534921, 2.9070755441413523, 3.876092260184637, 4.836678909695968, 5.804705547924254, 6.730231878063883, 7.717309209588391, 8.760051332853688, 9.830482346611943, 10.87388529292467, 10.007821183843257, 9.064480028725288, 8.029655290127755, 7.060085934880188, 7.09460068117705, 6.081672925541108, 5.061090582250934, 4.092971082492081, 3.0197179102901544, 2.0050557917181817, 2.844848638672469, 3.782523034770799, 4.83469746400221, 5.767803368320015, 6.795257494486886, 7.710806337441222, 8.653494935544014, 9.668279856250246, 10.692213410347396, 11.716478354406709, 11.03756706236385, 10.048879685279271, 9.008335066536537, 8.072077130673764, 7.900086911454091, 6.958561530608531, 5.912100249589262, 4.915905420350333, 3.9905439243653005, 3.057807411147005, 3.8843840275757433, 4.762923556925241, 5.718213448023852, 6.686891270817277, 7.645536269888435, 8.697142862094102, 9.677588338818575, 10.692300339849382, 11.619099787501638, 12.642386307519098, 11.842713283836144, 10.828172557389488, 9.884266778100363, 8.847106124326793, 8.959331543797274, 7.959228062958459, 6.90675141602161, 5.846775735563158, 5.016472298898599, 3.9898337808665927, 4.858447947642651, 5.723086101533658, 6.7782582634318205, 7.6920470755653545, 8.648952126439122, 9.680716270788018, 10.614886191349104, 11.654714944151273, 12.570538681441663, 13.563111828783068, 12.834496217410663, 11.875539585177144, 10.841472413937929, 9.85502341577675, 9.858094730350194, 8.912273901252748, 7.864647783898744, 6.819441638470285, 6.020219740833967, 5.064637418430354, 5.8631586838237375, 6.686432717510336, 7.658876568394056, 8.659278813014298, 9.6025167617258, 10.624649575770654, 11.573427128222926, 12.585848034956335, 13.58534145624875, 14.536048191230913, 13.827762319910875, 12.797868444225783, 11.812552904356021, 10.879792952260063, 10.824201378619474, 9.84349323560353, 8.840404580549528, 7.8933840559240585, 7.001578924683127, 6.037851758039635, 6.937015235359517, 7.748865698141112, 8.72092276751139, 9.65134419973332, 10.618365660922569, 11.581098401291511, 12.504908891352478, 13.465566125896514, 14.05177382602435, 14.654944600155684, 14.782944227446098, 13.768735897139717, 12.720152035029782, 11.774198687174149, 11.837059283224814, 10.82247548751985, 9.86086857128542, 8.89740497999418, 7.939468682926498, 6.964983955216701, 7.910582729868204, 8.744930283931348, 9.77385819249201, 10.687294438783395, 11.633110369656132, 12.540236060089267, 13.485246183141848, 13.997464538203454, 13.072149620816834, 13.699474483649748, 14.718701467623777, 14.63999673161124, 13.69542981527688, 12.729431610902001, 12.843342986216937, 11.831658000481761, 10.871006035815846, 9.849261189351136, 8.900966007247119, 7.907299856478877, 8.84550255001432, 9.715529916710283, 10.657285322195783, 11.70269081037099, 12.65259374290367, 13.527219914822876, 13.951466720550219, 13.022047884078473, 12.1298544269637, 12.730932126796137, 13.720197465882377, 14.593926747453978, 14.71488956257566, 13.656270051623844], [15.47423029986471, 15.512449557540885, 14.533112544103673, 13.659267353961416, 12.631032714330368, 12.043788647189626, 11.156586837917901, 12.155325374850888, 12.908411576085797, 12.7900947537399, 11.7548767491762, 10.764459394824943, 9.735050839915012, 8.840886006883052, 9.648595333777777, 10.637072953898674, 11.594458432872266, 12.61883103010054, 13.594852576889386, 14.621590173239493, 15.504862589154214, 14.553836249535486, 13.542599665799669, 12.660853678929042, 11.60100328515121, 11.06458672887237, 10.206460134297712, 11.105677418988897, 11.852865769692707, 12.824607515784674, 12.697944601938838, 11.826739183638004, 10.772124964025414, 9.803349597210424, 10.575723329348431, 11.64295375844731, 12.51990611036157, 13.448227955025747, 14.503478879272263, 15.548604126425513, 14.461139936120487, 13.519984796297596, 12.563225204469004, 11.672190451315116, 10.673350018507785, 10.024986999972823, 9.203730034962193, 10.046384535514155, 10.836428577986602, 11.802010337609085, 12.660240918517992, 12.826524493577864, 11.787340589700946, 10.85922551885831, 11.52401590894126, 12.462648944467384, 13.41250767767213, 14.461629800051014, 15.42887703035543, 15.506589289704063, 13.494840834714017, 12.559317485404527, 11.579381283158925, 10.650772263654275, 9.6115127521049, 9.041657853281446, 8.19714075345178, 8.9793163755246, 9.820510124195309, 10.743334617964269, 11.601182105764618, 12.426702211370909, 12.746863479628955, 11.846961818075066, 12.543921864882854, 13.473725213053763, 14.341541588174788, 15.276659663981498, 15.36919104680601, 14.517470548660171, 12.569265183290403, 11.620303563426878, 10.591998507397236, 9.638753276600657, 8.62925083034456, 7.985699160117443, 7.143170682392027, 7.915448802821942, 8.828384014070936, 9.676795982119573, 10.545966378432565, 11.487332510958359, 12.521950646974709, 12.819115018410258, 13.522751111112436, 14.534870075159551, 15.340637449928604, 15.44173789916998, 14.423328264943091, 13.573574458118527, 11.57368495419998, 10.595236302852348, 9.645998406417322, 8.720611488773482, 7.686687993724183, 6.934894633773084, 6.0984949455304225, 6.953141935687478, 7.896430656435751, 8.627854594191659, 9.574001485847132, 10.526402887104776, 11.516921858642938, 12.445880806978062, 13.423691176903192, 14.402928699600997, 15.330261700485988, 14.50028178082548, 13.47564623748553, 12.512902958064961, 10.629654211404931, 9.615487938885966, 8.654305462293848, 7.693193827757986, 6.715916256073292, 5.9645811916939655, 5.036284269315483, 5.914501172886695, 6.87592538049409, 7.686100686269696, 8.612882931465954, 9.541990554537003, 10.524158395708568, 11.514075801945522, 12.510865384271876, 13.462563266120684, 14.39466494593389, 13.524419843425585, 12.516027549869193, 11.58347262830212, 9.61842283812034, 8.649399164974195, 7.671994385142411, 6.662116882176503, 5.690560407193896, 4.93843036475697, 4.059992822424604, 4.93311918895353, 5.913005615608769, 6.744626649659038, 7.651577226491835, 8.674905255935379, 9.551586409612328, 10.510390094831026, 11.437506916156769, 12.40850408106491, 13.338090681165548, 12.683437520994442, 11.63238330583726, 10.646386398427575, 8.649003697483465, 7.628802370526296, 6.635101687366859, 5.707064096188834, 4.759799778694864, 3.896099255281883, 2.9934639304146193, 3.92907116694594, 4.893641802965446, 5.7064121496089575, 6.639534034780063, 7.652542423317384, 8.587700148376586, 9.482321942165468, 10.511633111072443, 11.49353217975235, 12.421249762447914, 11.798591952408728, 10.731774335591515, 9.698367234444975, 7.71092399472324, 6.705784919461048, 5.735081286100623, 4.753956209601429, 3.796067327007553, 2.9524607909878844, 2.01025676627351, 2.952391559877927, 3.8299967368764216, 4.760651672295904, 5.737859211204709, 6.663032669941752, 7.601992905020619, 8.548601445351151, 9.535588037584079, 10.531414475287942, 11.470797910589853, 10.81107661420861, 9.786383447365877, 8.77161569935544, 6.911150579727778, 5.876478045904171, 4.932358379821245, 3.862992718630014, 2.8623246797151407, 1.8886968100790174, 0.9618375669305097, 1.9351534877153718, 2.9010329395993226, 3.898166152377831, 4.832886823528487, 5.811712994948455, 6.7579287651140065, 7.8296122838414055, 8.895323846283212, 9.846132392978317, 10.808154458259837, 9.796532382132785, 8.831587534278798, 7.853535380715557, 6.034264372024816, 5.106311260079173, 4.08841838560423, 3.049798628086033, 2.0024109022122984, 0.9326631345310729, 0.0, 0.9454457877719054, 1.9765465571104308, 2.901667887362437, 3.8815372652309597, 4.88628657547638, 5.957281151333706, 6.962890906706971, 7.9978347660867435, 8.947027031471393, 9.918354256539601, 8.991540428026259, 8.017287115601231, 6.989869750417731, 7.027921352593165, 6.075874843001526, 5.077543261538715, 4.005631259887925, 2.9403224717301484, 1.9305709163534446, 0.9472619668224193, 1.9744124096102795, 2.943429125653564, 3.904015775164895, 4.872042413393181, 5.79756874353281, 6.784646075057318, 7.827388198322614, 8.897819212080869, 9.941222158393597, 10.893821432976901, 9.99714316325636, 8.962318424658827, 7.992749069411261, 7.988244174208699, 6.937454361564002, 5.9168720182738275, 4.948752518514975, 3.8754993463130476, 2.860837227741075, 1.912185504141396, 2.8498599002397262, 3.902034329471138, 4.835140233788942, 5.862594359955814, 6.778143202910149, 7.720831801012942, 8.735616721719174, 9.759550275816324, 10.783815219875637, 11.767522726814304, 10.9528346829821, 9.912290064239366, 8.965720623705412, 8.755868347476985, 7.8143429666314255, 6.767881685612156, 5.771686856373226, 4.846325360388194, 3.9135888471698985, 2.95172089304467, 3.8302604223941685, 4.78555031349278, 5.754228136286205, 6.712873135357363, 7.76447972756303, 8.744925204287503, 9.75963720531831, 10.686436652970565, 11.709723172988026, 12.698494719859038, 11.683953993412382, 10.740048214123258, 9.702887560349687, 9.815112979820169, 8.815009498981354, 7.7625328520445045, 6.702557171586052, 5.872253734921491, 4.845615216889486, 3.9257848131115782, 4.790422967002586, 5.845595128900748, 6.759383941034282, 7.7162889919080495, 8.748053136256946, 9.682223056818032, 10.7220518096202, 11.63787554691059, 12.630448694251996, 13.610073007289163, 12.731321021200039, 11.697253849960823, 10.710804851799644, 10.71387616637309, 9.768055337275644, 8.72042921992164, 7.675223074493179, 6.876001176856859, 5.865032430406535, 4.930495549292664, 5.753769582979264, 6.726213433862983, 7.726615678483226, 8.669853627194728, 9.691986441239582, 10.640763993691854, 11.653184900425263, 12.652678321717678, 13.60338505669984, 14.609371927703794, 13.653649880248677, 12.668334340378916, 11.73557438828296, 11.67998281464237, 10.699274671626426, 9.69618601657242, 8.749165491946952, 7.833481923110799, 6.838246770015816, 6.004352100828444, 6.81620256361004, 7.788259632980317, 8.718681065202247, 9.685702526391497, 10.648435266760439, 11.572245756821406, 12.532902991365441, 13.504027364882505, 14.479663013688603, 15.430825374729052, 14.624517333162613, 13.575933471052679, 12.629980123197045, 12.692840719247712, 11.678256923542746, 10.716650007308314, 9.753186416017073, 8.73986369490268, 7.765378967192882, 6.977919595337131, 7.812267149400276, 8.841195057960938, 9.754631304252323, 10.70044723512506, 11.607572925558195, 12.552583048610776, 13.156552530700802, 14.004812755347906, 14.63213761818082, 15.65136460215485, 15.495778167634136, 14.551211251299776, 13.585213046924897, 13.669001123248453, 12.657316137513277, 11.696664172847361, 10.649656201327316, 9.701361019223299, 8.707694868455057, 7.912839415483246, 8.78286678217921, 9.72462218766471, 10.770027675839918, 11.719930608372598, 12.594556780291803, 13.110554713047566, 12.181135876575821, 13.062517561494772, 13.66359526132721, 14.65286060041345, 15.52658988198505, 15.570670998598557, 14.51205148764674], [16.419676087636613, 16.457895345312792, 15.478558331875579, 14.604713141733322, 13.576478502102274, 12.94985903703171, 11.95869355013708, 11.244450567358276, 11.968126521699979, 11.936396889708513, 10.901178885144812, 9.910761530793556, 8.881352975883624, 9.786331794654958, 10.594041121549683, 11.58251874167058, 12.539904220644171, 13.564276817872447, 14.540298364661291, 15.567035961011399, 16.45030837692612, 15.499282037307392, 14.488045453571575, 13.606299466700948, 12.546449072923116, 11.970657118714454, 11.00856684651689, 10.194802611496286, 10.91258071530689, 11.879161728012768, 11.84424673790745, 10.973041319606619, 9.918427099994027, 10.74879538498233, 11.521169117120337, 12.588399546219216, 13.465351898133475, 14.393673742797652, 15.44892466704417, 16.49404991419742, 15.406585723892393, 14.465430584069502, 13.50867099224091, 12.617636239087021, 11.61879580627969, 10.931057389814907, 10.005836747181371, 9.135509728021544, 9.896143523600784, 10.85656454983718, 11.714795130746086, 11.972826629546478, 10.933642725669559, 11.804671306630215, 12.469461696713166, 13.40809473223929, 14.357953465444036, 15.40707558782292, 16.374322818127336, 16.45203507747597, 14.44028662248592, 13.50476327317643, 12.524827070930831, 11.596218051426181, 10.556958539876806, 9.94772824312353, 8.999247465670958, 8.06844156803199, 8.880225069809491, 9.797888830192365, 10.655736317992712, 11.481256423599003, 11.893165615597567, 12.792407605846972, 13.48936765265476, 14.419171000825669, 15.286987375946694, 16.222105451753404, 16.314636834577914, 15.462916336432073, 13.514710971062305, 12.56574935119878, 11.537444295169138, 10.584199064372562, 9.574696618116466, 8.931144947889349, 7.945277394611205, 7.004573995329331, 7.888098959685118, 8.73135019434767, 9.60052059066066, 10.541886723186453, 11.576504859202803, 12.518574534454334, 13.404107004148768, 14.426369380597501, 15.388078802805238, 16.31694215258244, 15.368774052714995, 14.519020245890431, 12.519130741971884, 11.54068209062425, 10.591444194189224, 9.666057276545384, 8.632133781496089, 7.8803404215449895, 7.010796889391687, 6.042267128194867, 6.956145602049933, 7.682408806419754, 8.628555698075226, 9.58095709933287, 10.571476070871032, 11.500435019206156, 12.478245389131287, 13.457482911829091, 14.384815912714082, 15.369507692259198, 14.421092025257433, 13.458348745836865, 11.575099999176835, 10.56093372665787, 9.599751250065752, 8.63863961552989, 7.661362043845197, 6.910026979465871, 5.981730057087389, 5.003626365394084, 5.935640326108272, 6.740654898497791, 7.667437143694048, 8.596544766765097, 9.578712607936662, 10.568630014173616, 11.56541959649997, 12.517117478348778, 13.449219158161984, 14.393645754859303, 13.461473337641097, 12.528918416074024, 10.563868625892244, 9.594844952746097, 8.617440172914316, 7.607562669948408, 6.636006194965801, 5.883876152528876, 5.00543861019651, 4.022244381460919, 4.9727205612229515, 5.799180861887133, 6.70613143871993, 7.729459468163473, 8.606140621840423, 9.56494430705912, 10.492061128384863, 11.463058293293004, 12.392644893393642, 13.331600217745665, 12.577829093609164, 11.591832186199479, 9.59444948525537, 8.5742481582982, 7.580547475138763, 6.652509883960739, 5.705245566466769, 4.841545043053789, 3.9389097181865247, 3.0181963594533294, 3.953356748579628, 4.760966361837053, 5.694088247008158, 6.707096635545478, 7.64225436060468, 8.536876154393562, 9.566187323300538, 10.548086391980444, 11.475803974676008, 12.54937901300998, 11.67722012336342, 10.643813022216879, 8.656369782495144, 7.651230707232953, 6.680527073872528, 5.699401997373334, 4.741513114779458, 3.8979065787597897, 2.9557025540454154, 2.0415167523853164, 2.8845509491045163, 3.8152058845239982, 4.792413423432803, 5.717586882169846, 6.656547117248714, 7.603155657579245, 8.590142249812173, 9.585968687516036, 10.525352122817948, 11.599610751167468, 10.73182923513778, 9.717061487127344, 7.856596367499683, 6.821923833676076, 5.87780416759315, 4.808438506401919, 3.807770467487046, 2.8341425978509225, 1.907283354702415, 0.9897076999434665, 1.9555871518274173, 2.9527203646059257, 3.887441035756582, 4.86626720717655, 5.812482977342102, 6.884166496069501, 7.949878058511307, 8.900686605206412, 9.885000005928934, 10.74197816990469, 9.777033322050704, 8.798981168487462, 6.9797101597967215, 6.051757047851079, 5.033864173376136, 3.9952444158579388, 2.947856689984204, 1.878108922302978, 0.9454457877719054, 0.0, 1.0311007693385255, 1.9562220995905317, 2.9360914774590543, 3.9408407877044747, 5.011835363561801, 6.017445118935066, 7.052388978314839, 8.001581243699487, 9.04293570172091, 9.936986215798164, 8.962732903373137, 7.935315538189637, 7.973367140365071, 7.021320630773432, 6.0229890493106195, 4.95107704765983, 3.8857682595020537, 2.87601670412535, 1.8927077545943245, 1.0424158736816012, 2.011432589724886, 2.9585699873929903, 3.9265966256212756, 4.852122955760905, 5.839200287285413, 6.881942410550709, 7.952373424308964, 8.995776370621693, 9.948375645204997, 10.937076028499677, 9.907764212430733, 8.938194857183166, 8.933689961980605, 7.8829001493359065, 6.862317806045732, 5.89419830628688, 4.820945134084953, 3.8062830155129803, 2.857631291913301, 1.9961620362083385, 2.9984042996920537, 3.889694446017037, 4.917148572183908, 5.832697415138244, 6.775386013241037, 7.790170933947269, 8.814104488044418, 9.83836943210373, 10.822076939042399, 11.810764316126978, 10.857735852011272, 9.911166411477318, 9.70131413524889, 8.75978875440333, 7.71332747338406, 6.717132644145131, 5.791771148160099, 4.859034634941803, 3.897166680816575, 2.976562558362781, 3.9318524494613927, 4.900530272254818, 5.8591752713259755, 6.860666034224939, 7.799479416515598, 8.814191417546404, 9.74099086519866, 10.76427738521612, 11.77843009584178, 12.629399781184286, 11.685494001895162, 10.648333348121591, 10.760558767592073, 9.760455286753258, 8.707978639816409, 7.648002959357957, 6.817699522693397, 5.791061004661391, 4.871230600883483, 3.9367251029711983, 4.991897264869361, 5.905686077002895, 6.862591127876662, 7.844239442918855, 8.736777269046126, 9.776606021848295, 10.692429759138685, 11.68500290648009, 12.664627219517257, 13.623583851750777, 12.642699637732727, 11.656250639571548, 11.659321954144993, 10.713501125047546, 9.665875007693543, 8.620668862265083, 7.821446964628765, 6.8104782181784405, 5.875941337064569, 4.900071718947876, 5.872515569831595, 6.872917814451838, 7.816155763163341, 8.838288577208194, 9.695318205919948, 10.707739112653357, 11.707232533945772, 12.657939268927935, 13.663926139931888, 14.599095668020581, 13.61378012815082, 12.681020176054862, 12.625428602414273, 11.644720459398329, 10.641631804344325, 9.694611279718856, 8.778927710882705, 7.783692557787722, 6.949797888600349, 5.962504699578652, 6.934561768948929, 7.86498320117086, 8.83200466236011, 9.794737402729051, 10.6267999690495, 11.587457203593535, 12.5585815771106, 13.534217225916697, 14.485379586957146, 15.541082698020139, 14.521379258824581, 13.575425910968947, 13.638286507019615, 12.623702711314648, 11.662095795080218, 10.698632203788977, 9.685309482674585, 8.710824754964788, 7.923365383109036, 6.958569285368888, 7.987497193929551, 8.900933440220935, 9.846749371093672, 10.75387506152681, 11.639630241104575, 12.618873023638159, 13.538205782318116, 14.489687342422632, 15.507401452393331, 16.441223955406038, 15.496657039071678, 14.5306588346968, 14.614446911020359, 13.602761925285183, 12.642109960619267, 11.595101989099222, 10.646806806995205, 9.653140656226963, 8.858285203255152, 7.929168918147823, 8.870924323633323, 9.91632981180853, 10.866232744341211, 11.740858916260418, 12.28709764037615, 12.983242588795, 13.968587951336856, 14.609041049099115, 15.598306388185355, 16.472035669756956, 16.516116786370457, 15.457497275418643], [17.44767921170333, 17.488996114651314, 16.5096591012141, 15.635813911071846, 14.607579271440798, 13.802672379533332, 12.811506892638702, 11.902960512701666, 10.963303375502566, 10.934588472844478, 10.109323016946576, 9.315845562274111, 9.833150959556972, 10.772653372083264, 11.592880341908478, 12.581357962029374, 13.538743441002966, 14.563116038231241, 15.539137585020088, 16.565875181370195, 17.481409146264642, 16.530382806645914, 15.519146222910098, 14.637400236039472, 13.57754984226164, 12.823470461216077, 11.861380189018513, 10.959520194902886, 9.907757569109476, 10.874338581815355, 11.052390869709214, 10.378125351087174, 10.870225083667375, 11.735116962410636, 12.520008337479132, 13.587238766578011, 14.46419111849227, 15.392512963156447, 16.447763887402964, 17.492889134556215, 16.437686493230917, 15.496531353408024, 14.539771761579434, 13.648737008425545, 12.649896575618214, 11.78387073231653, 10.858650089682994, 9.90698336618575, 8.891320377403371, 9.851741403639766, 10.709971984548671, 11.377910661027034, 11.885440709342907, 12.790992884058522, 13.46830091707196, 14.406933952598084, 15.35679268580283, 16.405914808181716, 17.37316203848613, 17.48313584681449, 15.471387391824445, 14.535864042514955, 13.555927840269355, 12.627318820764705, 11.58805930921533, 10.800541585625153, 9.852060808172581, 8.860952273770359, 7.875401923612078, 8.79306568399495, 9.650913171795297, 10.476433277401588, 11.440336558497714, 12.402884998853464, 13.378113104180935, 14.422143433149813, 15.350662059589945, 16.285780135396653, 17.276391422474834, 16.4940171057706, 14.545811740400831, 13.596850120537306, 12.568545064507664, 11.615299833711086, 10.60579738745499, 9.854107517179543, 8.826966333140204, 7.88626293385833, 6.883275813487705, 7.726527048150254, 8.595697444463244, 9.537063576989038, 10.571681713005386, 11.51375138825692, 12.399283857951353, 13.421546234400086, 14.383255656607822, 15.312119006385025, 16.330528640611913, 15.550121015228957, 13.55023151131041, 12.571782859962775, 11.62254496352775, 10.69715804588391, 9.663234550834613, 8.803302990835183, 7.892485827920686, 6.923956066723866, 5.9513224558525195, 6.677585660222339, 7.623732551877811, 8.576133953135455, 9.566652924673617, 10.495611873008741, 11.473422242933871, 12.452659765631676, 13.379992766516667, 14.364684546061785, 15.416770327914673, 14.48944951517539, 12.606200768515361, 11.592034495996396, 10.630852019404278, 9.669740384868415, 8.692462813183722, 7.832989548756064, 6.891367987560707, 5.8853153039230826, 4.930817179910858, 5.735831752300376, 6.662613997496633, 7.591721620567683, 8.573889461739249, 9.5638068679762, 10.560596450302555, 11.512294332151363, 12.44439601196457, 13.38882260866189, 14.397214902218282, 13.56001918541255, 11.59496939523077, 10.625945722084623, 9.648540942252842, 8.638663439286933, 7.667106964304327, 6.824453989511925, 5.915076540669828, 4.9039333199899175, 3.9678974150255373, 4.794357715689718, 5.701308292522515, 6.724636321966059, 7.601317475643009, 8.560121160861705, 9.487237982187448, 10.45823514709559, 11.387821747196227, 12.32677707154825, 13.377831286705431, 12.622932955538005, 10.625550254593895, 9.605348927636726, 8.611648244477289, 7.683610653299264, 6.736346335805295, 5.782122880036838, 4.848547648659842, 3.8998852979823284, 2.9485336023822137, 3.7561432156396375, 4.689265100810743, 5.702273489348064, 6.637431214407266, 7.532053008196147, 8.561364177103123, 9.543263245783029, 10.470980828478593, 11.544555866812566, 12.611373483629778, 11.674913791555404, 9.68747055183367, 8.682331476571479, 7.711627843211054, 6.73050276671186, 5.772613884117984, 4.8384844157428395, 3.8653404845187325, 2.9232056909143154, 1.8797278029071016, 2.8103827383265836, 3.787590277235389, 4.712763735972432, 5.651723971051299, 6.598332511381831, 7.585319103614758, 8.581145541318621, 9.520528976620533, 10.594787604970051, 11.619480771812784, 10.74816225646587, 8.88769713683821, 7.853024603014601, 6.908904936931676, 5.839539275740445, 4.838871236825572, 3.865243367189448, 2.908186258201516, 1.9166434575139535, 0.9507640056300027, 1.9471170107199605, 2.8563402664180564, 3.8351664378380246, 4.781382208003576, 5.853065726730975, 6.918777289172781, 7.869585835867886, 8.853899236590408, 9.86552131271746, 10.80813409138923, 9.830081937825987, 8.010810929135246, 7.082857817189605, 6.064964942714662, 5.0263451851964644, 3.9789574593227295, 2.909209691641504, 1.9765465571104308, 1.0311007693385255, 0.0, 0.9251213302520062, 1.9049907081205286, 2.909740018365949, 3.980734594223275, 4.98634434959654, 6.021288208976313, 6.970480474360961, 8.011834932382385, 8.938648760895727, 9.912902073320755, 8.966416307528162, 9.004467909703596, 8.052421400111957, 7.054089818649146, 5.982177816998356, 4.91686902884058, 3.9071174734638756, 2.92380852393285, 1.9942138573549486, 1.025197141311664, 1.9274692180544646, 2.89549585628275, 3.821022186422379, 4.8080995179468875, 5.850841641212184, 6.921272654970438, 7.964675601283166, 8.91727487586647, 9.90597525916115, 10.899234483442433, 9.969295626521692, 9.96169308604732, 8.910903273402623, 7.890320930112448, 6.922201430353596, 5.848948258151669, 4.834286139579696, 3.8856344159800162, 2.9479600198816858, 2.012168851278832, 2.8585936766785114, 3.886047802845383, 4.801596645799719, 5.744285243902511, 6.759070164608743, 7.783003718705893, 8.807268662765205, 9.790976169703873, 10.779663546788452, 11.820208165531186, 10.939169535544034, 10.729317259315605, 9.787791878470046, 8.741330597450776, 7.745135768211847, 6.819774272226815, 5.8870377590085194, 4.92516980488329, 3.928360542036128, 3.076297750730456, 3.92070936402013, 4.85736685446194, 5.829565264886413, 6.768378647177072, 7.783090648207878, 8.709890095860134, 9.733176615877595, 10.747329326503253, 11.74192881240092, 12.685834591690044, 11.676336472188307, 11.788561891658789, 10.788458410819974, 9.735981763883125, 8.676006083424673, 7.845702646760113, 6.819064128728107, 5.88794098221174, 4.888523086644546, 4.136342566138424, 4.925865168768207, 5.860782711012627, 6.81313867358033, 7.7056764997076, 8.74550525250977, 9.66132898980016, 10.653902137141564, 11.633526450178731, 12.592483082412251, 13.663742912169724, 12.684253763638264, 12.68732507821171, 11.741504249114264, 10.69387813176026, 9.648671986331799, 8.828118001145766, 7.809317438537235, 6.874780557423365, 5.851869702621224, 5.130733301048889, 5.924938904731357, 6.814347346299305, 7.836480160344159, 8.664217436581422, 9.676638343314831, 10.676131764607247, 11.62683849958941, 12.632825370593363, 13.611658847742707, 14.596974387612468, 13.70902330012158, 13.65343172648099, 12.672723583465046, 11.66963492841104, 10.722614403785572, 9.7777669312415, 8.782531778146517, 7.936119466028657, 6.914302683252, 6.192779500166223, 6.991266770236281, 7.830196245496073, 8.792928985865014, 9.595699199710975, 10.55635643425501, 11.527480807772074, 12.503116456578171, 13.45427881761862, 14.509981928681613, 15.524219695373334, 14.603429035035665, 14.666289631086332, 13.651705835381366, 12.690098919146934, 11.70917772144789, 10.68414870303338, 9.709663975323583, 8.909686960537343, 7.910367269042236, 7.245714925146845, 8.027217009286357, 8.844940954229637, 9.752066644662772, 10.60852947176605, 11.587772254299633, 12.50710501297959, 13.458586573084107, 14.476300683054806, 15.4171530124982, 16.36171992883256, 15.558661958763517, 15.613286131379155, 14.60160114564398, 13.640949180978064, 12.593941209458018, 11.645646027354001, 10.651979876585758, 9.844606780683458, 8.880966901821171, 8.276008355113879, 9.10013566676929, 9.864424327477176, 10.739050499396381, 11.5365042907125, 12.465923127184245, 13.449400206832724, 14.427128929937718, 15.416394269023957, 16.42913989610926, 17.4281445263499, 16.48550039948536], [18.291614055895252, 17.472990552463198, 16.497495903738635, 15.526356241563773, 14.498121601932725, 13.543007790885866, 12.565350835590161, 11.654030033478369, 10.876077649895628, 10.009467142592468, 9.184201686694568, 10.119632934314094, 10.758272289808977, 11.697774702335268, 12.518001672160484, 13.50647929228138, 14.463864771254972, 15.488237368483247, 16.464258915272094, 17.4909965116222, 18.40653047651665, 17.455504136897922, 16.444267553162106, 15.56252156629148, 14.502671172513647, 13.649588781108354, 12.68749850891079, 11.785638514795163, 10.733875889001753, 10.046659885708095, 10.127269539457206, 11.087311613162356, 11.795346413919379, 12.66023829266264, 13.445129667731138, 14.512360096830017, 15.389312448744276, 16.317634293408453, 17.372885217654968, 18.41801046480822, 17.362807823482925, 16.42165268366003, 15.464893091831442, 14.573858338677553, 13.575017905870222, 12.609989052208807, 11.684768409575272, 10.733101686078028, 9.717438697295648, 9.024062707532508, 9.882293288441415, 10.63711944711498, 11.572180752318467, 12.562942601962964, 13.537241375224726, 14.47587441075085, 15.425733143955595, 16.47216075997755, 17.415167785569544, 18.36699711524138, 16.39650872207645, 15.460985372766963, 14.481049170521363, 13.552440151016713, 12.513180639467338, 11.62665990551743, 10.678179128064858, 9.687070593662636, 8.701520243504355, 7.965386987887692, 8.823234475688041, 9.648754581294332, 10.612657862390458, 11.575206302746208, 12.536785694968604, 13.580816023937482, 14.509334650377614, 15.444452726184323, 16.4293335972251, 17.38025352974205, 15.470933070652839, 14.521971450789314, 13.493666394759671, 12.540421163963094, 11.530918717706998, 10.735728091985369, 9.690430594961256, 8.749727195679382, 7.709394133379982, 6.8988483520429975, 7.768018748355988, 8.709384880881782, 9.74400301689813, 10.686072692149663, 11.557956448739022, 12.580218825187755, 13.541928247395491, 14.470791597172694, 15.48347081536218, 16.410034713796016, 14.475352841562415, 13.496904190214783, 12.547666293779757, 11.622279376135918, 10.58835588108662, 9.693125543532803, 8.75595008974174, 7.787420328544919, 6.777440775744797, 5.849906964115082, 6.796053855770555, 7.7484552570281995, 8.738974228566361, 9.667933176901485, 10.63209483372154, 11.611332356419345, 12.525668116589575, 13.48370300605173, 14.535788787904618, 15.34936321374245, 13.531322098767367, 12.517155826248404, 11.555973349656286, 10.594861715120423, 9.61758414343573, 8.75811087900807, 7.816489317812713, 6.810436634175089, 5.850697427385103, 4.908153056193119, 5.834935301389375, 6.764042924460425, 7.74621076563199, 8.682825327966146, 9.679614910292502, 10.63131279214131, 11.563414471954516, 12.507841068651835, 13.516233362208228, 14.419932883979609, 12.520090725482776, 11.55106705233663, 10.57366227250485, 9.563784769538941, 8.592228294556334, 7.749575319763931, 6.840197870921834, 5.8290546502419245, 4.887777662499782, 3.966679019582461, 4.873629596415257, 5.843654781956005, 6.7203359356329555, 7.67913962085165, 8.606256442177395, 9.577253607085536, 10.506840207186174, 11.445795531538197, 12.496849746695379, 13.482846654105064, 11.550671584845901, 10.530470257888734, 9.536769574729297, 8.608731983551271, 7.661467666057301, 6.707244210288844, 5.773668978911848, 4.825006628234335, 3.8684138498564584, 2.9284645195323806, 3.8615864047034854, 4.82129194933801, 5.756449674397212, 6.651071468186093, 7.68038263709307, 8.662281705772976, 9.58999928846854, 10.663574326802513, 11.730391943619725, 12.60003512180741, 10.612591882085676, 9.607452806823485, 8.636749173463059, 7.655624096963866, 6.69773521436999, 5.7636057459948455, 4.7904618147707385, 3.8483270211663214, 2.8048491331591077, 1.9827040422193263, 2.9066087372253353, 3.831782195962378, 4.770742431041246, 5.717350971371777, 6.704337563604704, 7.700164001308568, 8.63954743661048, 9.71380606496, 10.738499231802733, 11.673283586717876, 9.812818467090215, 8.778145933266607, 7.834026267183682, 6.764660605992451, 5.763992567077578, 4.790364697441454, 3.833307588453522, 2.8417647877659595, 1.875885335882009, 1.0219956804679544, 1.9312189361660501, 2.910045107586018, 3.85626087775157, 4.927944396478969, 5.993655958920775, 6.94446450561588, 7.928777906338401, 8.940399982465454, 9.905344830319441, 10.755203268077993, 8.935932259387254, 8.007979147441612, 6.990086272966668, 5.9514665154484705, 4.9040787895747355, 3.83433102189351, 2.901667887362437, 1.9562220995905317, 0.9251213302520062, 0.0, 0.9798693778685225, 1.9846186881139425, 3.055613263971269, 4.061223019344534, 5.096166878724307, 6.045359144108955, 7.086713602130379, 8.013527430643721, 8.987780743068749, 9.89153763778017, 9.929589239955604, 8.977542730363965, 7.979211148901152, 6.907299147250362, 5.841990359092586, 4.832238803715882, 3.8489298541848562, 2.9193351876069547, 1.95031847156367, 1.0023478878024583, 1.9703745260307437, 2.895900856170373, 3.882978187694882, 4.925720310960179, 5.996151324718433, 7.039554271031161, 7.992153545614465, 8.980853928909143, 9.974113153190427, 10.8944169567737, 10.886814416299327, 9.836024603654629, 8.815442260364454, 7.847322760605602, 6.774069588403675, 5.759407469831702, 4.810755746232022, 3.873081350133692, 2.937290181530838, 1.9334723464265051, 2.9609264725933766, 3.8764753155477125, 4.819163913650505, 5.833948834356737, 6.857882388453887, 7.882147332513199, 8.865854839451867, 9.854542216536446, 10.89508683527918, 11.841656275813135, 11.654438589567611, 10.712913208722052, 9.666451927702782, 8.670257098463853, 7.744895602478821, 6.8121590892605255, 5.850291135135296, 4.853481872288134, 3.9642658565615485, 2.995588033768124, 3.9322455242099337, 4.904443934634407, 5.843257316925066, 6.857969317955872, 7.784768765608128, 8.808055285625588, 9.822207996251247, 10.816807482148914, 11.760713261438038, 12.601457802440313, 12.713683221910795, 11.71357974107198, 10.66110309413513, 9.601127413676679, 8.77082397701212, 7.744185458980113, 6.813062312463745, 5.813644416896551, 5.024310671969516, 4.000743838516201, 4.93566138076062, 5.888017343328324, 6.780555169455594, 7.820383922257764, 8.736207659548153, 9.728780806889558, 10.708405119926725, 11.667361752160245, 12.738621581917718, 13.60937509389027, 13.612446408463715, 12.666625579366269, 11.618999462012265, 10.573793316583805, 9.753239331397772, 8.734438768789241, 7.79990188767537, 6.776991032873229, 6.000219819099594, 4.999817574479351, 5.889226016047298, 6.911358830092151, 7.739096106329417, 8.751517013062825, 9.75101043435524, 10.701717169337403, 11.707704040341357, 12.6865375174907, 13.671853057360462, 14.634144630373584, 14.578553056732995, 13.59784491371705, 12.594756258663047, 11.647735734037578, 10.702888261493506, 9.707653108398523, 8.861240796280661, 7.839424013504005, 6.996566872206206, 6.066145439984275, 6.905074915244065, 7.867807655613007, 8.67057786945897, 9.631235104003006, 10.60235947752007, 11.577995126326167, 12.529157487366616, 13.584860598429609, 14.599098365121328, 15.52855036528767, 15.591410961338337, 14.57682716563337, 13.61522024939894, 12.634299051699896, 11.609270033285386, 10.634785305575589, 9.834808290789347, 8.83548859929424, 8.049502297186828, 7.102095679034351, 7.919819623977628, 8.826945314410764, 9.683408141514045, 10.662650924047629, 11.581983682727586, 12.533465242832103, 13.551179352802802, 14.492031682246196, 15.436598598580556, 16.402596802955436, 16.53840746163116, 15.526722475895983, 14.566070511230068, 13.519062539710022, 12.570767357606005, 11.577101206837764, 10.769728110935462, 9.806088232073176, 9.079795727153861, 8.175014336517282, 8.939302997225166, 9.813929169144373, 10.611382960460496, 11.540801796932241, 12.52427887658072, 13.502007599685713, 14.491272938771953, 15.504018565857256, 16.503023196097896, 17.32943524367728], [17.32799977211502, 16.509376268682967, 15.533881619958404, 14.562741957783544, 13.534507318152496, 12.579393507105637, 11.601736551809934, 10.690415749698142, 9.988287662802941, 9.157460042781263, 10.164071064563089, 11.099502312182617, 11.738141667677501, 12.677644080203793, 13.497871050029007, 14.486348670149903, 15.443734149123495, 16.468106746351772, 17.44412829314062, 18.33817740407506, 18.346905549761598, 17.54389356092137, 16.524394498262406, 15.60454335876309, 14.547830051932703, 13.558595425422892, 12.551863255430122, 11.740063705560132, 11.04383346919603, 10.194267639969091, 9.997228464958114, 10.70804991702625, 11.658541537965409, 12.674968710382679, 13.525114852634504, 14.49794783785029, 15.51177714856372, 16.4400989932279, 17.360696558784188, 18.405821805937435, 18.271862684951525, 17.401522061528553, 16.444762469699963, 15.518938711017821, 14.52009827821049, 13.507284633867076, 12.582063991233541, 11.630397267736297, 10.614734278953918, 9.921358289190778, 8.97638277149367, 9.70826460708639, 10.643325912289876, 11.634087761934374, 12.576822273041675, 13.515455308567798, 14.45849918301175, 15.492291382109029, 16.435298407701023, 17.387127737372857, 17.25351463995424, 16.440854750635484, 15.460918548389884, 14.532309528885234, 13.49305001733586, 12.5239554871757, 11.575474709723128, 10.584366175320906, 9.598815825162625, 8.862682569545962, 7.917323958740295, 8.719899741265742, 9.683803022361868, 10.646351462717618, 11.55691631710008, 12.600946646068959, 13.529465272509091, 14.4645833483158, 15.449464219356578, 16.400384151873524, 16.327938988530626, 15.501840828657835, 14.473535772628193, 13.520290541831615, 12.510788095575519, 11.63302367364364, 10.587726176619528, 9.647022777337654, 8.606689715038252, 7.796143933701267, 6.862108231408243, 7.780530040853192, 8.815148176869542, 9.734764633820586, 10.578087070870499, 11.600349447319232, 12.562058869526968, 13.49092221930417, 14.503601437493659, 15.430165335927493, 15.319836895134603, 14.476773568083305, 13.527535671648279, 12.602148754004439, 11.568225258955142, 10.590421125191074, 9.653245671400011, 8.68471591020319, 7.6747363574030665, 6.7472025457733515, 5.89014333882281, 6.819600416999609, 7.81011938853777, 8.716625118572408, 9.652225455853017, 10.631462978550822, 11.545798738721052, 12.503833628183209, 13.555919410036097, 14.369493835873927, 14.439204897378564, 13.497025204116925, 12.535842727524807, 11.574731092988944, 10.597453521304251, 9.70711967293792, 8.765498111742563, 7.718402213624888, 6.750685149193272, 5.805448637851389, 4.868679252855335, 5.795714810053096, 6.773627528477275, 7.702955950097623, 8.699745532423979, 9.651443414272787, 10.583545094085993, 11.527971690783314, 12.536363984339706, 13.440063506111086, 13.4999601033513, 12.530936430205152, 11.55353165037337, 10.543654147407462, 9.572097672424855, 8.729444697632454, 7.804398124007193, 6.737020229691723, 5.787765384307951, 4.863974601240731, 3.9073735478812166, 4.863785404087482, 5.7404665577644325, 6.699270242983127, 7.626387064308872, 8.597384229217013, 9.526970829317651, 10.465926153669674, 11.516980368826855, 12.50297727623654, 12.530540962714426, 11.510339635757255, 10.516638952597818, 9.588601361419792, 8.641337043925823, 7.687113588157367, 6.753538356780371, 5.732972207684133, 4.7684015716646275, 3.8284522413405493, 2.8953303561694446, 3.8414225714694874, 4.776580296528689, 5.67120209031757, 6.700513259224547, 7.682412327904453, 8.610129910600017, 9.68370494893399, 10.750522565751202, 11.754086127127673, 11.5924612599542, 10.58732218469201, 9.616618551331584, 8.635493474832389, 7.677604592238512, 6.743475123863369, 5.7703311926392615, 4.828196399034844, 3.7847185110276302, 2.903946898265618, 1.9267393593568127, 2.8519128180938553, 3.790873053172723, 4.737481593503254, 5.724468185736181, 6.720294623440045, 7.659678058741957, 8.733936687091475, 9.758629853934208, 10.773397601944644, 10.792687844958737, 9.758015311135129, 8.813895645052204, 7.744529983860973, 6.7438619449461, 5.770234075309976, 4.813176966322045, 3.821634165634482, 2.8557547137505312, 1.952814560567485, 0.9513495582975277, 1.9301757297174955, 2.8763914998830473, 3.9480750186104467, 5.013786581052253, 5.964595127747358, 6.948908528469879, 7.960530604596931, 8.925475452450918, 9.90352760601416, 9.915801637255775, 8.987848525310133, 7.96995565083519, 6.931335893316993, 5.883948167443258, 4.814200399762032, 3.881537265230959, 2.936091477459054, 1.9049907081205286, 0.9798693778685225, 0.0, 1.0047493102454201, 2.0757438861027464, 3.0813536414760114, 4.116297500855785, 5.065489766240433, 6.106844224261856, 7.033658052775198, 8.007911365200226, 9.035328730383727, 10.909458617824125, 9.957412108232486, 8.959080526769673, 7.8871685251188834, 6.821859736961107, 5.812108181584404, 4.828799232053378, 3.8992045654754772, 2.9301878494321927, 1.9822172656709807, 1.0494674510660953, 1.9322865723901441, 2.919363903914653, 3.9621060271799493, 5.0325370409382035, 6.075939987250932, 7.0285392618342355, 8.017239645128914, 8.994243775321904, 9.96381313056947, 11.85551844152962, 10.815893981523152, 9.795311638232977, 8.827192138474125, 7.753938966272198, 6.739276847700225, 5.790625124100545, 4.852950728002215, 3.9171595593993604, 2.9133417242950275, 2.1089193727821707, 2.9128610317674837, 3.8555496298702767, 4.8703345505765085, 5.8942681046736585, 6.918533048732971, 7.902240555671638, 8.890927932756219, 9.931472551498953, 10.878041992032907, 12.634307967436136, 11.692782586590576, 10.646321305571307, 9.650126476332378, 8.724764980347345, 7.7920284671290485, 6.830160513003819, 5.833351250156657, 4.944135234430071, 3.975457411636646, 3.0802384243987277, 3.940829650854178, 4.879643033144838, 5.894355034175644, 6.821154481827899, 7.844441001845359, 8.858593712471018, 9.853193198368686, 10.79709897765781, 11.834259631431381, 13.69355259977932, 12.693449118940505, 11.640972472003655, 10.580996791545203, 9.750693354880642, 8.724054836848635, 7.792931690332268, 6.793513794765074, 6.004180049838039, 4.980613216384723, 4.083654280949414, 4.924403059548094, 5.816940885675366, 6.856769638477536, 7.772593375767926, 8.76516652310933, 9.744790836146498, 10.703747468380017, 11.77500729813749, 12.76145629629867, 14.59231578633224, 13.646494957234793, 12.59886883988079, 11.55366269445233, 10.733108709266295, 9.714308146657764, 8.779771265543893, 7.756860410741752, 6.980089196968116, 5.9796869523478735, 5.0372189162360925, 5.96805673137418, 6.775481822549189, 7.787902729282598, 8.787396150575013, 9.738102885557176, 10.744089756561129, 11.722923233710473, 12.708238773580234, 13.683462187837124, 15.53143473775141, 14.577714291585576, 13.574625636531572, 12.627605111906103, 11.682757639362029, 10.687522486267046, 9.841110174149186, 8.819293391372529, 7.976436250074729, 7.0460148178527975, 6.05306781543286, 6.980017668520322, 7.706963585678742, 8.667620820222776, 9.63874519373984, 10.614380842545938, 11.565543203586387, 12.62124631464938, 13.635484081341101, 14.581437429196734, 16.433782736758406, 15.556696543501895, 14.595089627267464, 13.61416842956842, 12.589139411153909, 11.614654683444112, 10.814677668657872, 9.815357977162765, 9.029371675055351, 8.081965056902872, 7.067812524166423, 7.939155327318079, 8.719793857733817, 9.699036640267401, 10.618369398947356, 11.569850959051873, 12.587565069022572, 13.528417398465967, 14.472984314800327, 15.438982519175205, 17.42466793994467, 16.506591853764508, 15.545939889098593, 14.498931917578547, 13.55063673547453, 12.556970584706287, 11.749597488803987, 10.7859576099417, 10.059665105022384, 9.154883714385804, 8.087295897413961, 8.926139182051687, 9.647768676680268, 10.577187513152014, 11.56066459280049, 12.538393315905484, 13.527658654991724, 14.540404282077027, 15.539408912317667, 16.36582095989705], [16.3232504618696, 15.504626958437548, 14.529132309712985, 13.557992647538125, 12.529758007907077, 11.574644196860218, 10.596987241564513, 9.68566643945272, 8.98353835255752, 9.96105618399952, 10.97164653867478, 11.03175962750025, 11.957045583736749, 12.898862222370989, 13.686575188477432, 14.675052808598329, 15.63243828757192, 16.656810884800198, 17.643118894888993, 17.33342809382964, 17.342156239516175, 16.53914425067595, 15.519645188016987, 14.599794048517671, 13.543080741687284, 12.553846115177473, 11.547113945184702, 10.735314395314711, 10.03908415895061, 10.997863781187348, 10.921333211000942, 9.969479838687187, 10.919971459626346, 11.936398632043616, 12.759447192906778, 13.732280178122565, 14.746109488835994, 15.674431333500172, 16.595028899056462, 17.64015414620971, 17.5061950252238, 17.392499753130284, 16.435740161301695, 15.46957444113804, 14.470734008330709, 13.581046647017942, 12.54984404452022, 11.794607278789453, 11.055521350656715, 10.920700787288768, 9.900487517536497, 8.969694528747327, 9.904755833950814, 10.895517683595312, 11.81115461331395, 12.749787648840073, 13.692831523284024, 14.726623722381303, 15.669630747973297, 16.621460077645132, 16.487846980226514, 17.425261045246813, 16.465667858635307, 15.537058839130655, 14.49779932758128, 13.52870479742112, 12.580224019968549, 11.589115485566326, 10.603565135408045, 9.867431879791383, 8.922073268985715, 7.9813296629266794, 8.945232944022806, 9.907781384378556, 10.791248657372355, 11.835278986341233, 12.763797612781365, 13.698915688588075, 14.683796559628853, 15.634716492145799, 15.5622713288029, 16.506590138903256, 15.478285082873615, 14.525039852077036, 13.51553740582094, 12.637772983889061, 11.592475486864949, 10.651772087583074, 9.611439025283673, 8.800893243946687, 7.866857541653663, 7.041959962514129, 8.07657809853048, 8.969096974092862, 9.812419411142773, 10.834681787591506, 11.796391209799243, 12.725254559576445, 13.737933777765933, 14.664497676199767, 14.554169235406878, 15.481522878328727, 14.532284981893701, 13.606898064249862, 12.572974569200563, 11.595170435436495, 10.657994981645432, 9.68946522044861, 8.679485667648487, 7.751951856018772, 6.89489264906823, 6.081030338660547, 7.071549310198708, 7.950957458844683, 8.886557796125292, 9.865795318823096, 10.780131078993326, 11.738165968455483, 12.790251750308371, 13.603826176146201, 13.673537237650839, 14.501774514362346, 13.540592037770228, 12.579480403234365, 11.602202831549672, 10.711868983183338, 9.770247421987982, 8.723151523870307, 7.755434459438692, 6.81019794809681, 5.873428563100755, 5.0571447317140334, 6.00795986874955, 6.937288290369899, 7.934077872696254, 8.885775754545062, 9.817877434358268, 10.762304031055589, 11.770696324611981, 12.67439584638336, 12.76527317681605, 13.535685740450575, 12.558280960618792, 11.548403457652883, 10.576846982670276, 9.734194007877873, 8.809147434252612, 7.741769539937142, 6.792514694553371, 5.868723911486152, 4.9121228581266365, 4.125215325748419, 4.974798898036708, 5.933602583255404, 6.860719404581148, 7.831716569489288, 8.761303169589926, 9.700258493941949, 10.75131270909913, 11.737309616508815, 11.843253612165087, 12.515088946002676, 11.521388262843239, 10.593350671665213, 9.646086354171244, 8.691862898402787, 7.75828766702579, 6.737721517929552, 5.773150881910047, 4.83320155158597, 3.900079666414865, 3.102852493130424, 4.010912636800964, 4.905534430589846, 5.934845599496822, 6.916744668176729, 7.844462250872293, 8.918037289206264, 9.984854906023477, 10.913960389481565, 10.905173909404862, 11.592071494937429, 10.621367861577003, 9.640242785077808, 8.682353902483932, 7.748224434108788, 6.7750805028846806, 5.8329457092802635, 4.78946782127305, 3.9086962085110386, 2.931488669602233, 2.113342739754792, 3.0252053934449985, 3.97181393377553, 4.958800526008456, 5.954626963712321, 6.894010399014232, 7.9682690273637515, 8.992962194206484, 9.933271864298536, 9.858951932613955, 10.762764621380551, 9.818644955297625, 8.749279294106394, 7.748611255191521, 6.774983385555397, 5.817926276567464, 4.826383475879902, 3.860504023995951, 2.957563870812905, 1.9560988685429477, 1.0549690387492847, 2.0011848089148363, 3.0728683276422357, 4.072209622417101, 5.0230181691122056, 6.007331569834727, 7.018953645961779, 7.938514978062935, 8.916567131626177, 8.98618479853122, 9.914137910476862, 8.974704961080612, 7.936085203562413, 6.8886974776886785, 5.818949710007453, 4.88628657547638, 3.9408407877044738, 2.9097400183659485, 1.9846186881139425, 1.0047493102454201, 0.0, 1.0709945758573263, 2.076604331230591, 3.111548190610364, 4.060740455995012, 5.102094914016435, 6.028908742529778, 7.003162054954804, 8.030579420138304, 9.97984177909957, 10.883701493399215, 9.963829837015094, 8.891917835364303, 7.826609047206528, 6.816857491829825, 5.833548542298799, 4.809917593303679, 3.8409008772603936, 2.821090230512638, 1.853063592284353, 0.9275372621447239, 1.9146145936692327, 2.9573567169345294, 4.027787730692784, 5.071190677005512, 6.023789951588816, 7.012490334883494, 7.989494465076482, 8.959063820324047, 10.8507691312842, 11.726607009351353, 10.706024666061179, 9.737905166302326, 8.6646519941004, 7.649989875528426, 6.701338151928747, 5.763663755830416, 4.781405422885083, 3.752214689136685, 2.9125155140004284, 1.9081117215220635, 2.850800319624856, 3.8655852403310877, 4.889518794428238, 5.91378373848755, 6.897491245426218, 7.886178622510797, 8.926723241253532, 9.873292681787486, 11.776529534058662, 12.603495614418778, 11.557034333399509, 10.56083950416058, 9.635478008175546, 8.70274149495725, 7.740873540832021, 6.73829809037034, 5.783008199271729, 4.814330376478304, 3.8838345656169855, 2.9360803406087577, 3.874893722899417, 4.889605723930223, 5.8164051715824785, 6.839691691599938, 7.853844402225596, 8.848443888123265, 9.79234966741239, 10.82951032118596, 12.802550682629105, 13.604162146768706, 12.551685499831857, 11.491709819373405, 10.661406382708844, 9.634767864676837, 8.697878530545951, 7.698460634978757, 6.843053014679697, 5.819486181226381, 4.887250422167672, 3.9196537493026744, 4.812191575429945, 5.852020328232115, 6.767844065522505, 7.76041721286391, 8.740041525901077, 9.698998158134597, 10.77025798789207, 11.75670698605325, 13.700411099501572, 14.557207985062995, 13.509581867708992, 12.464375722280531, 11.63805554947998, 10.619254986871448, 9.684718105757577, 8.661807250955436, 7.8189621618097735, 6.818559917189531, 5.84081505745435, 4.96330742112876, 5.770732512303768, 6.783153419037177, 7.782646840329591, 8.733353575311755, 9.739340446315708, 10.718173923465052, 11.703489463334813, 12.678712877591703, 14.526685427505988, 15.488427319413777, 14.485338664359773, 13.538318139734304, 12.587704479575713, 11.59246932648073, 10.746057014362869, 9.724240231586212, 8.815309214916386, 7.884887782694455, 6.856663956651118, 5.975268358274902, 6.702214275433321, 7.662871509977356, 8.633995883494421, 9.609631532300519, 10.560793893340968, 11.61649700440396, 12.63073477109568, 13.576688118951314, 15.429033426512987, 16.467409571330094, 15.501733757269514, 14.519115269782104, 13.494086251367593, 12.519601523657796, 11.719624508871554, 10.720304817376448, 9.868244639897007, 8.92083802174453, 7.87140866538468, 6.934406017072659, 7.715044547488397, 8.69428733002198, 9.613620088701937, 10.565101648806454, 11.582815758777153, 12.523668088220548, 13.468235004554908, 14.434233208929786, 16.41991862969925, 17.411538693978194, 16.450886729312277, 15.40387875779223, 14.455583575688213, 13.461917424919971, 12.65454432901767, 11.690904450155383, 10.89853806986404, 9.962459188497492, 8.890892038632218, 7.921389871806267, 8.643019366434848, 9.572438202906593, 10.555915282555071, 11.533644005660065, 12.522909344746305, 13.535654971831608, 14.534659602072248, 15.36107164965163], [15.454877139910883, 14.636253636478832, 13.660758987754269, 12.68961932557941, 11.661384685948361, 10.706270874901502, 9.728613919605799, 8.817293117494005, 9.756950254693106, 10.78137653243871, 11.834689208619713, 11.903747033175947, 11.169084271533713, 12.015825212854892, 12.704909768955847, 13.693387389076744, 14.650772868050336, 15.67514546527861, 16.661453475367406, 16.465054771870925, 16.473782917557457, 15.670770928717237, 14.651271866058273, 13.731420726558955, 12.674707419728566, 11.685472793218757, 10.678740623225988, 9.866941073355996, 10.812496061086195, 11.818184129626538, 11.793320616676638, 10.841467244362883, 10.13201014742331, 11.05336162252752, 11.777781773385193, 12.75061475860098, 13.76444406931441, 14.692765913978587, 15.613363479534877, 16.658488726688127, 16.524529605702213, 16.524126431171567, 15.567366839342975, 14.601201119179322, 13.602360686371991, 12.712673325059228, 11.681470722561507, 10.926233956830737, 11.8289332527923, 11.792688192964464, 10.772474923212194, 9.841681934423024, 9.116794521747778, 9.997485700879635, 10.829489193792364, 11.768122229318488, 12.711166103762439, 13.744958302859718, 14.68796532845171, 15.639794658123543, 15.506181560704928, 16.443595625725223, 16.551210760653056, 15.665755486285047, 14.661982740447199, 13.636540781524491, 12.68806000407192, 11.993302116820292, 11.629914780301545, 10.86784734424655, 9.90688446634574, 8.853317068602376, 8.15727163181977, 9.009749401662878, 9.80958323785077, 10.853613566819648, 11.78213219325978, 12.71725026906649, 13.702131140107266, 14.653051072624212, 14.580605909281314, 15.529567529144838, 16.529481503779387, 15.596034427934363, 14.586531981678267, 13.664122628782561, 12.618825131758449, 11.678121732476574, 10.637788670177173, 9.801308708401855, 8.851668739013688, 7.913947368189826, 7.168935835662095, 8.037596201327686, 8.830753991621188, 9.853016368069921, 10.814725790277658, 11.74358914005486, 12.756268358244347, 13.68283225667818, 13.572503815885291, 14.634243506364447, 15.583481402799473, 14.677892640107189, 13.64396914505789, 12.621520080329995, 11.684344626538932, 10.71581486534211, 9.705835312541987, 8.778301500912272, 7.879703846428255, 6.953017744336243, 6.142162866938934, 7.019456686079507, 7.904892376603706, 8.884129899301511, 9.79846565947174, 10.756500548933897, 11.808586330786785, 12.622160756624615, 12.691871818129252, 13.706043867085071, 14.611586613627555, 13.650474979091692, 12.673197407406999, 11.73821862807684, 10.796597066881484, 9.749501168763809, 8.781784104332193, 7.83654759299031, 6.85823976046078, 5.92913213738973, 5.076459095984375, 6.005787517604723, 6.952412453174667, 7.904110335023475, 8.836212014836681, 9.780638611534002, 10.789030905090394, 11.692730426861774, 11.741678176944637, 12.742137176361172, 13.629275536476118, 12.61939803351021, 11.647841558527603, 10.769941558913494, 9.835497079146114, 8.768119184830644, 7.818864339446872, 6.895073556379652, 5.9384725030201375, 4.997202731424116, 4.043298125271533, 5.0021018104902275, 5.879053985059561, 6.850051149967701, 7.779637750068339, 8.718593074420362, 9.769647289577543, 10.755644196987229, 10.772259036307762, 11.785526678090967, 12.592382838700566, 11.66434524752254, 10.71708093002857, 9.727610449438409, 8.79132935220777, 7.764071162823054, 6.799500526803548, 5.859551196479471, 4.9264293113083655, 4.0180586995685195, 3.079411864035789, 3.9740336578246707, 4.953180179975235, 5.916392418018185, 6.844110000713749, 7.917685039047721, 8.970700145726175, 9.842965813624238, 9.834179333547537, 10.798764111826568, 11.69236243743433, 10.711237360935135, 9.753348478341259, 8.819219009966114, 7.8460750787420075, 6.90394028513759, 5.860462397130377, 4.935045853404539, 3.9578383144957336, 3.032664855758691, 2.0937046206798233, 3.0403131610103546, 3.9584482758499124, 4.954274713553777, 5.893658148855688, 6.9679167772052075, 7.933803401921986, 8.86227728844121, 8.78795735675663, 9.789564894260845, 10.733684560343772, 9.82027386996372, 8.819605831048847, 7.845977961412724, 6.888920852424791, 5.8973780517372285, 4.931498599853278, 3.996190980005138, 2.9947259777351807, 2.015899806315213, 1.0696840361496611, 2.0599152209861717, 3.0012150465597753, 3.9520235932548804, 4.9363369939774016, 5.947959070104454, 6.86752040220561, 7.845572555768851, 7.915190222673895, 8.843143334619537, 9.86103620909448, 9.00707977941974, 7.959692053546005, 6.88994428586478, 5.9572811513337065, 5.011835363561801, 3.980734594223275, 3.055613263971269, 2.0757438861027464, 1.0709945758573263, 0.0, 1.005609755373265, 2.040553614753038, 2.9897458801376864, 4.03110033815911, 4.957914166672452, 5.932167479097479, 6.95958484428098, 8.908847203242244, 9.81270691754189, 10.866091912018623, 9.96291241122163, 8.897603623063855, 7.8878520676871515, 6.904543118156126, 5.880912169161005, 4.91189545311772, 3.8920848063699647, 2.9240581681416793, 1.9985318380020503, 1.0462412717105178, 2.0713231009944875, 3.0716991017782873, 4.060826708682412, 5.013425983265716, 5.963516901902555, 6.918499889219157, 7.888069244466723, 9.821225555658607, 10.75297448711574, 11.773556830405914, 10.808899742159651, 9.735646569957725, 8.720984451385752, 7.772332727786073, 6.834658331687742, 5.852399998742409, 4.823209264994011, 3.983510089857755, 2.97910629737939, 1.9824269976661413, 2.9972119183723733, 4.007641982671853, 5.031906926731165, 6.015614433669833, 7.004301810754412, 7.89717966562794, 8.843749106161894, 10.794107506559845, 11.735632887405405, 12.628028909256832, 11.631834080017903, 10.706472584032872, 9.773736070814575, 8.811868116689347, 7.809292666227666, 6.854002775129055, 5.88532495233563, 4.954829141474312, 4.007074916466085, 3.006520400940702, 4.021232401971508, 4.948031849623764, 5.9578148798435535, 6.9719675904692116, 7.96656707636688, 8.910472855656005, 9.898857256739845, 11.853352138903029, 12.769855408648079, 13.62268007568918, 12.562704395230728, 11.732400958566169, 10.705762440534162, 9.768873106403277, 8.769455210836083, 7.914047590537023, 6.890480757083707, 5.958244998024999, 4.974638499130426, 3.94381825347123, 4.9836470062734, 5.899470743563789, 6.892043890905194, 7.871668203942361, 8.83062483617588, 9.901884665933354, 10.888333664094533, 12.832037777542856, 13.777858606640303, 14.580576443566315, 13.535370298137854, 12.709050125337304, 11.690249562728773, 10.755712681614902, 9.73280182681276, 8.8899567376671, 7.889554493046857, 6.885016477731841, 5.862883663686987, 4.902359190345053, 5.914780097078461, 6.914273518370876, 7.864980253353039, 8.870967124356993, 9.849800601506336, 10.835116141376098, 11.810339555632988, 13.658312105547273, 14.709077940991085, 15.556333240217096, 14.609312715591628, 13.658699055433038, 12.663463902338055, 11.817051590220194, 10.795234807443537, 9.814948370869667, 8.884526938647737, 7.8375773412020715, 6.874844600833129, 5.833840953474606, 6.7944981880186415, 7.7656225615357055, 8.741258210341803, 9.692420571382252, 10.748123682445245, 11.762361449136964, 12.708314796992598, 14.560660104554271, 15.618773575330835, 16.57272833312684, 15.590109845639429, 14.565080827224918, 13.590596099515121, 12.79061908472888, 11.791299393233773, 10.864238723330018, 9.856673830402352, 8.785077571758409, 7.791681348582264, 6.846671225529682, 7.825914008063266, 8.745246766743222, 9.696728326847738, 10.714442436818437, 11.655294766261832, 12.599861682596192, 13.56585988697107, 15.551545307740533, 16.56323029347571, 16.629117270251903, 15.651497007070683, 14.703201824966666, 13.645810234278567, 12.943871804254698, 12.121268329269514, 11.890657657916961, 10.845252169741753, 9.77368501987648, 8.748939067265935, 7.774646044476133, 8.704064880947879, 9.687541960596356, 10.66527068370135, 11.654536022787589, 12.667281649872892, 13.666286280113532, 14.492698327692914], [14.5496313601052, 13.73100785667315, 12.755513207948587, 11.808842213770898, 10.792587450892507, 9.912630775498304, 9.216440565697534, 9.822902872867271, 10.762560010066371, 11.786986287811976, 12.840298963992979, 12.823417060692154, 12.060986667679005, 11.101474841524489, 11.699300013582581, 12.687777633703478, 13.64516311267707, 14.669535709905345, 15.655843719994142, 15.559808992065241, 15.568537137751777, 14.765525148911555, 13.746026086252591, 12.850643614750444, 11.822616880071665, 10.891832693815559, 10.166567269317722, 10.872550828729262, 11.818105816459461, 12.823793884999802, 12.712990644192848, 11.761137271879093, 11.023912543568603, 10.139011251197116, 10.772172018011927, 11.745005003227714, 12.758834313941144, 13.68715615860532, 14.607753724161613, 15.652878971314863, 15.518919850328949, 15.672035891514664, 14.715276299686074, 13.749110579522421, 12.75027014671509, 11.931432422715107, 11.169297368653242, 11.931843712204003, 12.834543008165566, 12.712358220480674, 11.692144950728403, 10.761351961939233, 10.00869691789307, 9.083135329549231, 9.823879438419098, 10.762512473945222, 11.705556348389173, 12.739348547486452, 13.682355573078446, 14.63418490275028, 14.500571805331663, 15.43798587035196, 15.699120220996154, 14.813664946628146, 13.812107413117975, 12.914761569406483, 12.175886650163655, 12.998911872193558, 12.597134044989211, 11.78751737176276, 10.82655449386195, 9.772987096118586, 9.049174027965062, 8.095399030332475, 8.803973482477504, 9.848003811446382, 10.776522437886515, 11.711640513693224, 12.696521384734002, 13.647441317250948, 13.57499615390805, 14.523957773771574, 15.523871748406123, 15.803871781134411, 14.794369334878315, 13.970720262570486, 13.229856721223408, 12.64534099716424, 11.605007934864839, 10.720978735918065, 9.771338766529897, 8.833617395706035, 8.060838231807388, 7.123245829997282, 7.825144236247922, 8.847406612696657, 9.809116034904394, 10.737979384681596, 11.750658602871082, 12.677222501304916, 12.566894060512027, 13.628633750991183, 14.577871647426209, 15.503258565070048, 14.616319132192949, 13.588739345017661, 12.651563891226598, 11.683034130029776, 10.673054577229653, 9.745520765599938, 8.799373873944464, 7.872687771852453, 7.034065263084227, 6.105106314749103, 6.899282621230441, 7.878520143928246, 8.792855904098476, 9.750890793560632, 10.80297657541352, 11.61655100125135, 11.686262062755988, 12.700434111711807, 13.661616588303925, 14.644415740327004, 13.66713816864231, 12.717085337407498, 11.775463776212142, 10.728367878094467, 9.760650813662853, 8.815414302320969, 7.77790978797699, 6.84880216490594, 5.996129123500585, 5.09143714627432, 5.946802697801402, 6.898500579650209, 7.830602259463417, 8.775028856160738, 9.78342114971713, 10.68712067148851, 10.736068421571371, 11.736527420987906, 12.732779514865932, 13.613338794745522, 12.641782319762914, 11.748808268244153, 10.814363788476772, 9.746985894161302, 8.797731048777532, 7.873940265710312, 6.917339212350797, 5.916872758940325, 4.9629681527877425, 4.087751439159824, 4.873444229686296, 5.844441394594436, 6.774027994695075, 7.7129833190470976, 8.764037534204279, 9.750034441613964, 9.766649280934496, 10.779916922717703, 11.743015616252421, 12.658286008757852, 11.711021691263882, 10.706477158769067, 9.770196061538428, 8.742937872153712, 7.7783672361342076, 6.83841790581013, 5.905296020639025, 4.93772872708473, 3.9990818915519992, 3.0596832864942662, 3.9475704246019703, 4.91078266264492, 5.838500245340484, 6.912075283674456, 7.96509039035291, 8.837356058250974, 8.828569578174271, 9.793154356453304, 10.710040650267127, 11.691165726766322, 10.758958233714525, 9.803324110990417, 8.83018017976631, 7.8880453861618935, 6.84456749815468, 5.913912562735198, 4.936705023826392, 4.011531565089349, 3.072571330010482, 2.1259627896799502, 2.9528385204766474, 3.9486649581805118, 4.888048393482423, 5.9623070218319425, 6.928193646548721, 7.856667533067945, 7.782347601383365, 8.783955138887581, 9.728074804970507, 10.797440466161738, 9.825215586422113, 8.851587716785989, 7.894530607798055, 6.902987807110493, 5.937108355226542, 5.001800735378403, 4.000335733108446, 3.021509561688478, 2.075293791522926, 1.0543054656129065, 1.9956052911865103, 2.9464138378816154, 3.9307272386041365, 4.942349314731189, 5.861910646832345, 6.839962800395586, 6.90958046730063, 7.837533579246273, 8.855426453721217, 9.894046211239413, 8.96530180891927, 7.895554041238044, 6.962890906706971, 6.017445118935065, 4.986344349596539, 4.061223019344533, 3.081353641476011, 2.076604331230591, 1.005609755373265, 0.0, 1.0349438593797728, 1.9841361247644214, 3.0254905827858445, 3.9523044112991874, 4.926557723724214, 5.953975088907715, 7.90323744786898, 8.807097162168626, 9.860482156645359, 10.92735310471759, 9.903213378437119, 8.893461823060415, 7.91015287352939, 6.88652192453427, 5.917505208490985, 4.897694561743229, 3.929667923514944, 3.004141593375315, 2.051851027083783, 1.0657133456212224, 2.0660893464050223, 3.055216953309147, 4.007816227892451, 4.95790714652929, 5.912890133845892, 6.882459489093458, 8.815615800285343, 9.747364731742476, 10.76794707503265, 11.736066574791503, 10.74125632533099, 9.726594206759017, 8.777942483159338, 7.840268087061007, 6.858009754115674, 5.828819020367276, 4.989119845231019, 3.9847160527526544, 2.988036753039406, 2.114179299621178, 3.0020322272985878, 4.0262971713579, 5.010004678296568, 5.998692055381147, 6.891569910254675, 7.83813935078863, 9.788497751186581, 10.73002313203214, 11.77090139850272, 12.63744383539117, 11.712082339406138, 10.779345826187841, 9.817477872062613, 8.814902421600932, 7.85961253050232, 6.890934707708895, 5.9604388968475766, 5.012684671839349, 4.012130156313967, 3.1381997832203132, 3.966198324143725, 4.9522051244702885, 5.9663578350959465, 6.960957320993615, 7.904863100282739, 8.89324750136658, 10.847742383529765, 11.764245653274815, 12.765552564935069, 13.568314150603996, 12.738010713939435, 11.711372195907428, 10.774482861776542, 9.77506496620935, 8.919657345910288, 7.896090512456972, 6.963854753398263, 5.980248254503691, 4.949428008844495, 4.2130800301582845, 4.917637218083751, 5.910210365425156, 6.889834678462323, 7.848791310695842, 8.920051140453316, 9.901164792816537, 11.848077053582857, 12.793897882680303, 13.723448932812204, 14.540980053511122, 13.71465988071057, 12.69585931810204, 11.761322436988168, 10.738411582186027, 9.895566493040366, 8.895164248420123, 7.890626233105106, 6.868493419060252, 5.907968945718318, 5.1570981608646544, 5.932439992890838, 6.883146727873001, 7.889133598876955, 8.867967076026298, 9.85328261589606, 10.82850603015295, 12.676478580067235, 13.725117217031086, 14.708596503045095, 15.614922470964895, 14.664308810806304, 13.669073657711321, 12.82266134559346, 11.800844562816803, 10.820558126242933, 9.890136694021002, 8.843187096575337, 7.8804543562063945, 6.839450708847871, 6.165248400606279, 6.971982462132507, 7.83601243053612, 8.78717479157657, 9.842877902639563, 10.780527923656926, 11.72648127151256, 13.65541432474859, 14.704099468947405, 15.727487671576544, 15.582030126291784, 14.557001107877273, 13.582516380167476, 12.96444125307041, 12.796909148607039, 11.869848478703283, 10.862283585775616, 9.790687327131673, 8.797291103955528, 7.852280980902947, 7.216474872914633, 7.951606667340023, 8.791482547042055, 9.809196657012755, 10.75004898645615, 11.69461590279051, 12.660614107165388, 14.64629952793485, 15.657984513670026, 15.623507514878638, 14.645887251697415, 13.697592069593398, 12.640200478905301, 12.029521432924295, 13.013170725414806, 12.896267413290227, 11.85086192511502, 10.779294775249745, 9.754548822639201, 8.780255799849398, 8.191891527039614, 8.893901861193157, 9.760024903895665, 10.749290242981905, 11.76203587006721, 12.76104050030785, 13.587452547887231], [13.514687500725428, 12.696063997293377, 11.720569348568814, 10.773898354391125, 9.757643591512734, 8.877686916118533, 9.884199008364014, 10.736737533140609, 11.67639467033971, 12.700820948085314, 13.754133624266316, 13.602335524342006, 12.660790445343903, 11.652398012408094, 10.664356154202808, 11.652833774323705, 12.610219253297297, 13.634591850525572, 14.620899860614369, 14.524865132685468, 14.533593278372004, 13.730581289531782, 12.711082226872819, 11.815699755370671, 10.787673020691892, 9.856888834435788, 10.834325711984203, 11.7863854890026, 12.731940476732799, 13.73762854527314, 13.4919091078427, 12.540055735528945, 11.706361594497992, 10.689934422080722, 9.737228158632155, 10.710061143847941, 11.72389045456137, 12.652212299225548, 13.57280986478184, 14.61793511193509, 14.483975990949176, 14.637092032134891, 13.680332440306302, 12.714166720142648, 11.715326287335317, 10.896488563335335, 11.837055811319722, 12.845678372477341, 13.748377668438904, 13.491276684130526, 12.471063414378255, 11.540270425589085, 10.704760265257901, 9.763234352301087, 8.788935579039325, 9.727568614565449, 10.6706124890094, 11.70440468810668, 12.647411713698673, 13.599241043370506, 13.46562794595189, 14.403042010972188, 14.66417636161638, 13.778721087248373, 12.777163553738202, 11.879817710026712, 12.828298487479284, 13.819407021881506, 13.376052508639063, 12.566435835412612, 11.605472957511802, 10.551905559768437, 9.745237375329893, 8.782688934974143, 7.769029623097732, 8.81305995206661, 9.741578578506742, 10.676696654313451, 11.661577525354229, 12.612497457871175, 12.540052294528277, 13.489013914391801, 14.48892788902635, 14.768927921754639, 13.759425475498542, 12.935776403190715, 13.882268558539037, 13.424259460814092, 12.38392639851469, 11.499897199567917, 10.55025723017975, 9.612535859355887, 8.797881048834084, 7.81053573463895, 6.79020037686815, 7.8124627533168844, 8.77417217552462, 9.703035525301823, 10.71571474349131, 11.642278641925143, 11.531950201132254, 12.59368989161141, 13.542927788046436, 14.468314705690275, 14.70198831211892, 13.986580929535075, 13.43048235487645, 12.461952593679628, 11.451973040879505, 10.52443922924979, 9.578292337594316, 8.651606235502305, 7.771108080110922, 6.842149131775798, 5.864338761850668, 6.843576284548473, 7.757912044718702, 8.71594693418086, 9.768032716033748, 10.581607141871578, 10.651318203376215, 11.665490252332035, 12.626672728924152, 13.633667206831728, 14.446056632292162, 13.49600380105735, 12.554382239861994, 11.507286341744319, 10.539569277312703, 9.594332765970819, 8.556828251626841, 7.6277206285557915, 6.7750475871504365, 5.870355609924171, 4.9118588384216295, 5.863556720270436, 6.795658400083644, 7.740084996780964, 8.748477290337355, 9.652176812108737, 9.701124562191598, 10.701583561608134, 11.69783565548616, 12.689750452174456, 13.420700783412766, 12.527726731894004, 11.593282252126624, 10.525904357811154, 9.576649512427382, 8.652858729360162, 7.696257676000647, 6.695791222590177, 5.741886616437594, 4.866669902809675, 3.838500370306523, 4.809497535214663, 5.739084135315302, 6.678039459667325, 7.729093674824506, 8.715090582234192, 8.731705421554723, 9.744973063337932, 10.708071756872648, 11.636109348050674, 12.489940154913734, 11.485395622418919, 10.54911452518828, 9.521856335803564, 8.557285699784059, 7.61733636945998, 6.684214484288875, 5.716647190734581, 4.778000355201851, 3.8386017501441176, 2.9126265652221974, 3.8758388032651463, 4.803556385960711, 5.877131424294683, 6.930146530973137, 7.802412198871201, 7.793625718794498, 8.758210497073533, 9.675096790887354, 10.656221867386549, 11.593122462154492, 10.582242574640267, 9.60909864341616, 8.666963849811744, 7.623485961804531, 6.692831026385049, 5.715623487476243, 4.7904500287392, 3.851489793660333, 2.9048812533298016, 1.9178946610968746, 2.913721098800739, 3.85310453410265, 4.92736316245217, 5.893249787168948, 6.821723673688172, 6.747403742003592, 7.749011279507809, 8.693130945590735, 9.762496606781966, 10.76316464569684, 9.88653157616576, 8.929474467177828, 7.9379316664902655, 6.972052214606315, 6.0245634568314195, 5.023098454561462, 4.044272283141495, 3.098056512975943, 2.026372994248544, 0.9606614318067374, 1.911469978501842, 2.8957833792243632, 3.907405455351416, 4.826966787452572, 5.805018941015813, 5.874636607920857, 6.8025897198665, 7.820482594341443, 8.85910235185964, 9.906490077733375, 8.930497900617816, 7.9978347660867435, 7.052388978314838, 6.021288208976312, 5.096166878724306, 4.116297500855784, 3.111548190610364, 2.040553614753038, 1.0349438593797728, 0.0, 0.9491922653846486, 1.9905467234060716, 2.9173605519194146, 3.891613864344441, 4.919031229527942, 6.868293588489207, 7.772153302788853, 8.825538297265586, 9.892409245337817, 10.923911705574287, 9.928405682440188, 8.945096732909162, 7.9214657839140425, 6.952449067870758, 5.932638421123002, 4.964611782894717, 4.039085452755088, 3.0867948864635557, 2.1006572050009953, 1.0311454870252494, 2.0202730939293745, 2.9728723685126783, 3.922963287149517, 4.877946274466119, 5.847515629713685, 7.780671940905571, 8.712420872362703, 9.733003215652877, 10.70112271541173, 11.774375887613656, 10.76153806613879, 9.81288634253911, 8.87521194644078, 7.892953613495447, 6.863762879747049, 6.024063704610792, 5.019659912132427, 4.005806842722197, 2.991021922015965, 1.967088367918815, 2.991353311978127, 3.975060818916795, 4.963748196001374, 5.856626050874902, 6.803195491408857, 8.75355389180681, 9.69507927265237, 10.735957539122948, 11.697419545642694, 12.622781041627725, 11.814289685567614, 10.852421731442385, 9.849846280980705, 8.894556389882093, 7.925878567088668, 6.995382756227349, 5.948692354768342, 4.925964816587305, 3.8580539124162074, 2.9312544647639522, 3.9172612650905156, 4.931413975716174, 5.9260134616138425, 6.869919240902966, 7.858303641986808, 9.812798524149994, 10.729301793895043, 11.730608705555296, 12.628289860855519, 13.641372149284587, 12.7463160552872, 11.809426721156315, 10.810008825589122, 9.95460120529006, 8.931034371836745, 7.942483822494339, 6.894082914777028, 5.863262669117833, 4.880838472824765, 3.8826933587039782, 4.875266506045383, 5.85489081908255, 6.813847451316069, 7.885107281073543, 8.866220933436765, 10.813133194203086, 11.758954023300532, 12.688505073432431, 13.600955763762645, 14.532817755675671, 13.730803177481812, 12.796266296367941, 11.7733554415658, 10.872991361211659, 9.872589116591415, 8.804460893378444, 7.78232807933359, 6.821803605991656, 5.824856603531135, 4.897496133511065, 5.848202868493228, 6.8541897394971825, 7.833023216646525, 8.818338756516285, 9.793562170773175, 11.64153472068746, 12.690173357651314, 13.673652643665323, 14.620673168290791, 14.469939871059752, 13.47470471796477, 13.761241309291659, 12.739424526515002, 11.73439278651627, 10.80397135429434, 9.757021756848674, 8.794289016479732, 7.753285369121209, 6.833006843272759, 5.937038602752734, 6.801068571156347, 7.752230932196796, 8.80793404325979, 9.745584064277152, 10.691537412132785, 12.620470465368816, 13.669155609567634, 14.692543812196773, 14.547086266912011, 13.5220572484975, 12.547572520787703, 13.515364423954015, 13.735489112305238, 12.78368313897662, 11.776118246048954, 10.70452198740501, 9.711125764228866, 8.766115641176285, 7.884233315581113, 6.91666280796025, 7.756538687662282, 8.774252797632982, 9.715105127076377, 10.659672043410737, 11.625670247785616, 13.611355668555078, 14.623040654290254, 14.588563655498865, 13.610943392317642, 12.662648210213625, 11.605256619525528, 12.5804446038079, 13.60034373994796, 13.810102073563565, 12.764696585388357, 11.693129435523083, 10.668383482912539, 9.694090460122736, 8.859649969706094, 7.858958001813385, 8.725081044515893, 9.714346383602132, 10.727092010687437, 11.726096640928077, 12.552508688507459], [12.638467865485042, 11.852760950451563, 10.877266301727, 9.93059530754931, 8.91434054467092, 9.82687918150318, 10.833391273748662, 11.685929798525256, 12.625586935724357, 13.650013213469961, 14.703325889650964, 14.55152778972666, 13.609982710728552, 12.601590277792743, 11.613548419587458, 11.180350976559218, 11.924763650154716, 12.949136247382992, 13.840999376892675, 13.648645497445083, 13.657373643131619, 12.887278242689968, 11.867779180031004, 10.972396708528857, 9.944369973850078, 10.806081099820435, 11.78351797736885, 12.735577754387247, 13.681132742117446, 14.686820810657789, 14.441101373227351, 13.489248000913596, 12.655553859882641, 11.639126687465371, 10.686420424016804, 10.174470172010581, 10.999315972665412, 11.92763781732959, 12.792909381060147, 13.816637530796818, 13.589543945686618, 13.793788985293077, 12.837029393464487, 11.870863673300834, 10.872023240493503, 11.845680828719983, 12.78624807670437, 13.794870637861989, 14.697569933823551, 14.440468949515177, 13.420255679762906, 12.489462690973737, 11.65395253064255, 10.712426617685736, 9.738127844423975, 9.191977642728089, 9.926381706145628, 10.960173905242907, 11.86751122997698, 12.778605020541551, 12.571195900689332, 13.50860996570963, 13.820873314774566, 12.935418040406558, 11.933860506896387, 12.82900997541136, 13.777490752863931, 14.768599287266154, 14.325244774023712, 13.515628100797262, 12.554665222896451, 11.501097825153089, 10.694429640714542, 9.731881200358792, 8.71822188848238, 8.18090137414171, 8.99734779564297, 9.93246587144968, 10.881677041632535, 11.718065412608617, 11.645620249265718, 12.594581869129243, 13.594495843763791, 13.925624874912824, 12.916122428656728, 13.884968668575363, 14.831460823923685, 14.373451726198741, 13.33311866389934, 12.449089464952566, 11.499449495564399, 10.561728124740538, 9.747073314218733, 8.7597280000236, 7.739392642252799, 7.119756512035923, 7.998251933889154, 8.927115283666357, 9.935814259769616, 10.747846596662585, 10.637518155869696, 11.699257846348852, 12.648495742783878, 13.573882660427717, 13.858685265277105, 14.88626505245239, 14.379674620261099, 13.411144859064278, 12.401165306264154, 11.47363149463444, 10.527484602978966, 9.600798500886956, 8.720300345495572, 7.791341397160447, 6.8135310272353165, 6.150870043267512, 6.97801156099701, 7.936046450459168, 8.988132232312054, 9.68717509660902, 9.756886158113657, 10.734673970143886, 11.695856446736004, 12.70285092464358, 13.584767413661515, 14.445196066441998, 13.503574505246641, 12.456478607128966, 11.48876154269735, 10.543525031355468, 9.50602051701149, 8.576912893940442, 7.724239852535086, 6.819547875308819, 5.861051103806278, 5.0836562365487445, 6.015757916361952, 6.960184513059272, 7.968576806615664, 8.757744766846178, 8.751932296806949, 9.752391296223484, 10.74864339010151, 11.740558186789809, 12.559411564782119, 13.476918997278652, 12.542474517511272, 11.475096623195801, 10.52584177781203, 9.602050994744811, 8.645449941385296, 7.644983487974827, 6.691078881822244, 5.8158621681943234, 4.7876926356911715, 4.0295970514929715, 4.9591836515936105, 5.898138975945633, 6.949193191102815, 7.820658536971634, 7.782513156170075, 8.795780797953283, 9.758879491488, 10.686917082666026, 11.628650936283087, 12.434587887803566, 11.498306790572927, 10.471048601188212, 9.506477965168706, 8.566528634844628, 7.633406749673524, 6.6658394561192305, 5.7271926205865, 4.787794015528767, 3.861818830606846, 3.0011756295077308, 3.9274066189127925, 4.993257813377275, 5.980954265588489, 6.853219933486552, 6.84443345340985, 7.809018231688883, 8.725904525502706, 9.7070296020019, 10.664918484595775, 11.531434840024916, 10.55829090880081, 9.616156115196393, 8.57267822718918, 7.642023291769697, 6.664815752860892, 5.739642294123849, 4.8006820590449815, 3.85407351871445, 2.867086926481523, 2.0390579250433234, 2.924711273852691, 3.9989699022022105, 4.944057521784299, 5.872531408303524, 5.798211476618944, 6.799819014123161, 7.743938680206086, 8.813304341397318, 9.81397238031219, 10.787600249948314, 9.878666732562477, 8.887123931874914, 7.921244479990963, 6.973755722216068, 5.972290719946111, 4.993464548526143, 4.047248778360592, 2.9755652596331923, 1.909853697191386, 0.9763482799021567, 1.960661680624678, 2.9722837567517306, 3.8777745220679236, 4.855826675631165, 4.925444342536209, 5.8533974544818514, 6.871290328956794, 7.909910086474992, 8.957297812348726, 9.879690166002463, 8.947027031471391, 8.001581243699485, 6.9704804743609605, 6.0453591441089545, 5.065489766240432, 4.060740455995012, 2.9897458801376864, 1.9841361247644214, 0.9491922653846486, 0.0, 1.0413544580214231, 1.968168286534766, 2.9424215989597924, 3.9698389641432934, 5.919101323104559, 6.8229610374042045, 7.876346031880939, 8.943216979953167, 9.974719440189638, 10.877597947824835, 9.89428899829381, 8.87065804929869, 7.901641333255406, 6.881830686507651, 5.913804048279365, 4.988277718139736, 4.035987151848204, 3.049849470385644, 1.980337752409898, 1.0710808285447257, 2.02368010312803, 2.9737710217648683, 3.9287540090814703, 4.898323364329037, 6.831479675520922, 7.763228606978054, 8.78381095026823, 9.751930450027082, 10.825183622229009, 11.710730331523438, 10.762078607923758, 9.824404211825428, 8.842145878880094, 7.812955145131697, 6.97325596999544, 5.968852177517076, 4.954999108106845, 3.9402141874006134, 2.9162806333034634, 2.0787193007522395, 3.0624268076909074, 4.02466782401707, 4.907433785490253, 5.854003226024208, 7.8043616264221605, 8.74588700726772, 9.7867652737383, 10.748227280258046, 11.67358877624308, 12.669635034166845, 11.801613996827033, 10.799038546365352, 9.84374865526674, 8.875070832473316, 7.944575021611998, 6.8978846201529915, 5.875157081971954, 4.807246177800856, 3.8804467301486008, 3.004627253864628, 4.018779964490286, 4.986933089629538, 5.930838868918663, 6.909111376602159, 8.863606258765344, 9.780109528510394, 10.781416440170648, 11.679097595470871, 12.69217988389994, 13.601661403886432, 12.758618986540963, 11.75920109097377, 10.903793470674708, 9.880226637221392, 8.891676087878988, 7.843275180161678, 6.812454934502482, 5.830030738209413, 4.831885624088627, 4.03196345920357, 5.011587772240738, 5.970544404474256, 6.9499385427827844, 7.917028668052115, 9.863940928818437, 10.809761757915883, 11.739312808047783, 12.651763498377997, 13.583625490291023, 14.602426052899554, 13.745458561752589, 12.722547706950447, 11.822183626596308, 10.821781381976065, 9.753653158763093, 8.73152034471824, 7.770995871376305, 6.774048868915783, 5.846688398895713, 5.0048998216514144, 6.01088669265537, 6.989720169804712, 7.921019033200878, 8.896242447457768, 10.744214997372053, 11.740981092266665, 12.724460378280675, 13.671480902906143, 14.215255318810641, 14.423896983349419, 14.710433574676308, 13.688616791899651, 12.68358505190092, 11.75316361967899, 10.706214022233324, 9.743481281864382, 8.702477634505858, 7.782199108657408, 6.886230868137383, 5.957765524314533, 6.9089278853549825, 7.964630996417975, 8.848264340961745, 9.794217688817378, 11.744250830128431, 12.719963344182984, 13.743351546812123, 13.955042236646689, 13.151662736769762, 13.496764786172353, 14.464556689338664, 14.684681377689888, 13.73287540436127, 12.725310511433602, 11.653714252789658, 10.660318029613514, 9.715307906560932, 8.833425580965761, 7.865855073344899, 6.913235640820468, 7.930949750791169, 8.871802080234563, 9.816368996568922, 10.74945061254523, 12.735136033314692, 13.746821019049868, 13.903108052356284, 12.954071831215675, 12.19016541244914, 12.554448884910178, 13.529636869192549, 14.549536005332609, 14.759294338948212, 13.713888850773005, 12.64232170090773, 11.617575748297186, 10.643282725507383, 9.808842235090742, 8.808150267198034, 7.881777997674078, 8.871043336760318, 9.883788963845623, 10.882793594086262, 11.676289053267073], [11.597113407463617, 10.862573520365034, 10.017191116588224, 9.205045532774701, 9.817989052544226, 10.773102863591085, 11.800446677209063, 12.723724328846119, 13.66338146604522, 14.687807743790824, 15.741120419971827, 15.515594799691296, 14.540190599313558, 13.53179816637775, 12.543756308172464, 11.869123494172054, 10.929273371145268, 11.953645968373543, 12.845509097883228, 12.607291039423657, 12.616019185110193, 11.917877866355058, 11.007703994892228, 10.246846933754247, 10.848018481723384, 11.75230478190834, 12.750573380829252, 13.742569194622899, 14.71892727243831, 15.724615340978652, 15.405168383191988, 14.453315010878233, 13.585761748467647, 12.569334576050377, 11.61662831260181, 10.863242689623418, 10.003825693655964, 10.932147538320141, 11.7974191020507, 12.775283072775396, 12.548189487665196, 12.943838048051482, 11.987078456222893, 11.236634012098738, 11.77567174836681, 12.788485392710225, 13.753303480164771, 14.775191989591715, 15.735364464144414, 15.404535959479814, 14.384322689727544, 13.453529700938374, 12.584160419227556, 11.642634506270742, 10.66833573300898, 9.880750160340925, 8.93089142713618, 9.964683626233459, 10.872020950967533, 11.73725056252013, 11.52984144266791, 12.467255507688208, 12.970922377532972, 12.301188379204463, 12.837509014769694, 13.771814539401602, 14.720295316854173, 15.711403851256396, 15.28931178398835, 14.479695110761899, 13.518732232861089, 12.465164835117726, 11.624637529299548, 10.662089088943798, 9.648429777067387, 8.930376143073653, 8.001857516633521, 8.93697559244023, 9.886186762623089, 10.676710954587195, 10.604265791244297, 11.553227411107821, 12.55314138574237, 13.365706814902037, 13.819770936530034, 14.827773232565605, 15.774265387913927, 15.337518736163378, 14.297185673863977, 13.413156474917203, 12.463516505529036, 11.525795134705175, 10.677281202803739, 9.689935888608606, 8.669600530837805, 7.878740751640964, 7.002761654879706, 7.931625004656907, 8.94032398076017, 9.706492138641163, 9.596163697848274, 10.65790338832743, 11.607141284762456, 12.532528202406295, 13.514184693290982, 14.54176448046627, 15.343741630225736, 14.375211869028915, 13.365232316228791, 12.437698504599076, 11.491551612943603, 10.564865510851593, 9.650508234080577, 8.721549285745454, 7.743738915820322, 6.909854282872553, 5.9825212819875615, 6.940556171449719, 7.9926419533026065, 8.645820638587598, 8.715531700092235, 9.693319512122464, 10.654501988714582, 11.661496466622157, 12.543412955640092, 13.59420296331356, 14.467641515211279, 13.420545617093603, 12.452828552661988, 11.507592041320105, 10.470087526976128, 9.540979903905079, 8.688306862499722, 7.771831953154514, 6.791258992391284, 5.886830099773743, 5.020267637352504, 5.964694234049824, 6.973086527606215, 7.7163903088247565, 7.710577838785526, 8.711036838202062, 9.707288932080088, 10.699203728768383, 11.518057106760695, 12.568052136376563, 13.506541527475909, 12.439163633160438, 11.489908787776667, 10.566118004709448, 9.609516951349933, 8.609050497939464, 7.65514589178688, 6.768146246040018, 5.717900524276177, 4.832770914717969, 3.963693372584162, 4.902648696936184, 5.928014641212054, 6.7793040789502115, 6.741158698148652, 7.754426339931859, 8.717525033466575, 9.645562624644601, 10.587296478261663, 11.578082378382575, 12.462373800537565, 11.435115611152849, 10.470544975133343, 9.530595644809265, 8.597473759638161, 7.629906466083867, 6.691259630551136, 5.751861025493403, 4.792026719191852, 3.8043494927327286, 2.905543698026512, 3.9713948924909936, 4.939599807567065, 5.8118654754651295, 5.803078995388427, 6.76766377366746, 7.684550067481282, 8.665675143980476, 9.623564026574352, 10.634443914088576, 11.522357918765447, 10.58022312516103, 9.536745237153816, 8.606090301734334, 7.628882762825529, 6.703709304088486, 5.764749069009619, 4.818140528679087, 3.83115393644616, 2.8422317882683212, 1.90284835296641, 2.9771069813159294, 3.902703063762876, 4.831176950282101, 4.756857018597521, 5.758464556101737, 6.7025842221846625, 7.7719498833758935, 8.772617922290767, 9.74624579192689, 10.814705823642608, 9.900835396843163, 8.934955944959214, 7.937822732180704, 6.936357729910747, 5.957531558490779, 5.011315788325228, 3.939632269597829, 2.8739207071560227, 1.923112160460918, 0.9387987597383969, 1.9504208358654493, 2.8364200640465005, 3.814472217609742, 3.8840898845147853, 4.812042996460428, 5.829935870935371, 6.868555628453568, 7.915943354327303, 8.985691122008529, 9.918354256539601, 9.04293570172091, 8.011834932382385, 7.086713602130378, 6.106844224261856, 5.102094914016436, 4.03110033815911, 3.0254905827858445, 1.9905467234060716, 1.0413544580214231, 0.0, 0.9268138285133428, 1.9010671409383693, 2.92848450612187, 4.877746865083135, 5.781606579382781, 6.834991573859515, 7.9018625219317435, 8.933364982168214, 9.943116537544919, 10.86561622336202, 9.912012507320114, 8.942995791276829, 7.923185144529074, 6.955158506300789, 6.02963217616116, 5.077341609869627, 4.088563296489014, 3.01813228273076, 1.9747293364180316, 1.0221300618347278, 1.9324165637434452, 2.887399551060047, 3.856968906307613, 5.790125217499498, 6.721874148956631, 7.742456492246805, 8.710575992005658, 9.783829164207585, 10.798491282779558, 11.747143006379238, 10.865758669846851, 9.883500336901518, 8.854309603153121, 8.014610428016864, 7.010206635538499, 5.992793638427707, 4.978008717721475, 3.9540751636243257, 2.9823678086255456, 2.076386011292179, 2.983313365995647, 3.86607932746883, 4.812648768002784, 6.763007168400737, 7.704532549246297, 8.745410815716875, 9.706872822236623, 10.632234318221656, 11.628280576145421, 12.591203709009456, 11.840393004386776, 10.885103113288164, 9.91642529049474, 8.985929479633421, 7.935679150473854, 6.912951612292817, 5.845040708121719, 4.918241260469463, 3.9082757617379347, 3.093149247761544, 3.9455786316081154, 4.889484410897239, 5.867756918580735, 7.82225180074392, 8.73875507048897, 9.740061982149223, 10.637743137449448, 11.650825425878516, 12.560306945865008, 13.565267629076363, 12.800555548995193, 11.945147928696132, 10.921581095242816, 9.92947061819985, 8.88106971048254, 7.850249464823345, 6.867825268530275, 5.8696801544094885, 4.935611967076876, 4.09437187226635, 4.992945659395772, 5.908584084761361, 6.875674210030692, 8.822586470797013, 9.76840729989446, 10.697958350026358, 11.610409040356574, 12.5422710322696, 13.56107159487813, 14.495608475992002, 13.76390216497187, 12.85997815691717, 11.859575912296927, 10.791447689083956, 9.769314875039102, 8.808790401697168, 7.811843399236645, 6.870866660662134, 5.908548329524721, 5.093670792680982, 6.012121424726228, 6.879664575179454, 7.854887989436344, 9.702860539350628, 10.699626634245242, 11.68310592025925, 12.630126444884718, 13.523630216118761, 14.518865369213744, 15.463153567544113, 14.726411322220514, 13.721379582221783, 12.790958149999852, 11.744008552554186, 10.781275812185244, 9.74027216482672, 8.808174054511003, 7.837049680993938, 6.86141403218784, 6.048852700216205, 7.037255964053138, 7.80690988294032, 8.752863230795953, 10.702896372107006, 11.67860888616156, 12.7019970887907, 12.95955195763724, 13.840435254382598, 14.426972674757359, 15.39476457792367, 15.72247590801075, 14.770669934682132, 13.763105041754464, 12.691508783110521, 11.698112559934376, 10.753102436881795, 9.822503334236274, 8.816673886201453, 7.816884148693775, 7.0708745656523915, 8.011726895095787, 8.826181566482393, 9.708096154523805, 11.693781575293267, 12.705466561028443, 12.907617773346836, 11.958581552206226, 12.878937930061976, 13.484656773495184, 14.459844757777555, 15.479743893917615, 15.797088869269075, 14.751683381093867, 13.680116231228594, 12.655370278618049, 11.681077255828246, 10.797919988361254, 9.758969080054587, 8.785426505547385, 8.145493561985708, 9.023713778706847, 9.892606163999734, 10.634934595245648], [10.670299578950274, 9.935759691851691, 9.1857860092301, 10.131859361288045, 10.74480288105757, 11.699916692104429, 12.727260505722406, 13.650538157359462, 14.590195294558562, 15.614621572304166, 16.66793424848517, 16.44240862820464, 15.4670044278269, 14.458611994891092, 13.470570136685806, 12.795937322685397, 11.85608719965861, 11.286433043200715, 11.92418508241321, 11.680477210910315, 11.689205356596851, 10.991064037841715, 10.176298887534102, 11.124836108737794, 11.774832310236729, 12.679118610421684, 13.677387209342594, 14.669383023136241, 15.645741100951652, 16.651429169491994, 16.33198221170533, 15.380128839391576, 14.51257557698099, 13.49614840456372, 12.543442141115152, 11.79005651813676, 10.930639522169306, 10.256108206736435, 10.876095086580682, 11.848469244262054, 11.621375659151854, 12.024915491079605, 11.155673348864767, 12.114623187082286, 12.702485576880154, 13.715299221223567, 14.680117308678113, 15.702005818105057, 16.662178292657757, 16.331349787993155, 15.311136518240886, 14.380343529451716, 13.510974247740899, 12.569448334784084, 11.595149561522323, 10.807563988854268, 9.857705255649522, 9.242706361711168, 9.950696935497515, 10.810436734006787, 10.603027614154568, 11.540441679174865, 12.139517270174846, 13.068126289679496, 13.764322843283038, 14.698628367914944, 15.647109145367516, 16.63821767976974, 16.216125612501692, 15.406508939275241, 14.445546061374431, 13.391978663631068, 12.55145135781289, 11.58890291745714, 10.575243605580729, 9.857189971586996, 8.928671345146864, 8.21499832791794, 8.96486274715307, 9.749897126073853, 9.677451962730954, 10.626413582594479, 11.626327557229027, 12.65538338636915, 13.529933701398017, 14.59574187131322, 15.596801842605595, 16.26433256467672, 15.22399950237732, 14.339970303430546, 13.390330334042378, 12.452608963218518, 11.604095031317081, 10.616749717121948, 9.596414359351147, 8.805554580154306, 7.929575483393048, 7.165346701795617, 8.018999965290151, 8.77967831012782, 8.669349869334932, 9.731089559814087, 10.680327456249113, 11.605714373892953, 12.58737086477764, 13.614950651952928, 14.55212610574399, 15.302025697542257, 14.292046144742134, 13.364512333112419, 12.418365441456945, 11.491679339364936, 10.57732206259392, 9.648363114258796, 8.670552744333666, 7.836668111385896, 6.909335110500904, 6.166921715388003, 7.071317937832589, 7.719006810074255, 7.788717871578893, 8.76650568360912, 9.727688160201238, 10.734682638108813, 11.616599127126749, 12.667389134800217, 13.596834251416567, 14.347359445606946, 13.37964238117533, 12.434405869833448, 11.39690135548947, 10.467793732418421, 9.615120691013065, 8.698645781667857, 7.718072820904627, 6.813643928287087, 5.947081465865846, 5.191059777988108, 6.0517625121361975, 6.789576480311414, 6.783764010272183, 7.784223009688719, 8.780475103566744, 9.77238990025504, 10.591243278247353, 11.64123830786322, 12.620542804525687, 13.365977461673781, 12.41672261629001, 11.49293183322279, 10.536330779863276, 9.535864326452806, 8.581959720300222, 7.694960074553362, 6.644714352789521, 5.759584743231313, 4.890507201097504, 4.1290142408744686, 5.001200812698712, 5.852490250436869, 5.814344869635309, 6.827612511418517, 7.790711204953234, 8.718748796131258, 9.660482649748321, 10.651268549869233, 11.587549647099872, 12.361929439666191, 11.397358803646686, 10.457409473322608, 9.524287588151504, 8.55672029459721, 7.61807345906448, 6.678674854006746, 5.718840547705195, 4.731163321246072, 3.8323575265398544, 3.0576489298754366, 4.012785979053723, 4.885051646951787, 4.876265166875084, 5.840849945154117, 6.757736238967939, 7.738861315467133, 8.69675019806101, 9.707630085575234, 10.68077401679934, 11.507036953674373, 10.463559065667159, 9.532904130247678, 8.555696591338872, 7.630523132601829, 6.691562897522962, 5.74495435719243, 4.757967764959504, 3.769045616781664, 2.829662181479753, 2.0633610187003724, 2.975889235249533, 3.904363121768758, 3.8300431900841776, 4.831650727588395, 5.77577039367132, 6.845136054862551, 7.845804093777424, 8.819431963413548, 9.887891995129266, 10.827649225356508, 9.861769773472558, 8.864636560694048, 7.86317155842409, 6.884345387004123, 5.938129616838571, 4.866446098111172, 3.800734535669366, 2.849925988974261, 1.8656125882517398, 1.0326513969168103, 1.9096062355331578, 2.887658389096399, 2.957276056001443, 3.8852291679470854, 4.903122042422028, 5.9417417999402256, 6.9891295258139605, 8.058877293495186, 8.991540428026259, 9.936986215798164, 8.938648760895727, 8.013527430643721, 7.033658052775198, 6.0289087425297785, 4.957914166672452, 3.9523044112991874, 2.9173605519194146, 1.968168286534766, 0.9268138285133428, 0.0, 0.9742533124250266, 2.0016706776085273, 3.9509330365697926, 4.854792750869438, 5.908177745346173, 6.975048693418401, 8.006551153654872, 9.016302709031576, 9.938802394848677, 10.838826335833458, 9.869809619790173, 8.849998973042418, 7.881972334814131, 6.956446004674502, 6.00415543838297, 5.015377125002357, 3.9449461112441027, 2.9015431649313745, 1.9489438903480707, 1.0056027352301022, 1.9605857225467047, 2.9301550777942706, 4.863311388986156, 5.795060320443288, 6.815642663733462, 7.783762163492315, 8.857015335694243, 9.871677454266216, 10.820329177865895, 11.758003573964226, 10.810314165414862, 9.781123431666465, 8.941424256530206, 7.937020464051842, 6.91960746694105, 5.9048225462348185, 4.880888992137669, 3.9091816371388886, 3.0031998398055224, 2.0564995374823036, 2.9392654989554874, 3.8858349394894423, 5.836193339887394, 6.777718720732954, 7.8185969872035335, 8.78005899372328, 9.705420489708313, 10.701466747632079, 11.664389880496113, 12.688884839786315, 11.811916941801508, 10.843239119008084, 9.912743308146764, 8.862492978987197, 7.8397654408061594, 6.771854536635061, 5.8450550889828055, 4.835089590251277, 4.0199630762748875, 3.018764803094772, 3.9626705823838964, 4.9409430900673925, 6.895437972230577, 7.811941241975628, 8.81324815363588, 9.710929308936105, 10.724011597365173, 11.633493117351666, 12.63845380056302, 13.637871696130214, 12.871961757209476, 11.84839492375616, 10.856284446713195, 9.807883538995885, 8.777063293336688, 7.794639097043618, 6.796493982922831, 5.862425795590219, 5.021185700779693, 4.066131830882428, 4.9817702562480175, 5.948860381517349, 7.895772642283671, 8.841593471381117, 9.771144521513015, 10.683595211843231, 11.615457203756257, 12.634257766364788, 13.56879464747866, 14.591705502280801, 13.786791985430513, 12.78638974081027, 11.718261517597298, 10.696128703552445, 9.73560423021051, 8.738657227749988, 7.797680489175477, 6.8353621580380635, 6.020484621194325, 5.085307596212884, 5.952850746666111, 6.928074160923, 8.776046710837285, 9.772812805731899, 10.756292091745907, 11.703312616371376, 12.596816387605418, 13.592051540700401, 14.53633973903077, 15.558156521807428, 14.648193410735125, 13.717771978513195, 12.670822381067529, 11.708089640698587, 10.667085993340063, 9.734987883024344, 8.76386350950728, 7.788227860701182, 6.975666528729549, 6.1104421355397935, 6.880096054426977, 7.82604940228261, 9.776082543593663, 10.751795057648218, 11.775183260277357, 12.707333540441496, 13.660408969646298, 14.519183737877468, 15.509907233539456, 16.554221107597662, 15.697483763195475, 14.689918870267807, 13.618322611623864, 12.624926388447719, 11.679916265395137, 10.749317162749616, 9.743487714714796, 8.743697977207118, 7.997688394165736, 7.180321787737663, 7.899367737969051, 8.781282326010462, 10.766967746779924, 11.7786527325151, 12.240404848174007, 12.885395380719569, 13.805751758575319, 14.411470602008526, 15.386658586290897, 16.406557722430957, 16.723902697782417, 15.67849720960721, 14.606930059741936, 13.582184107131392, 12.607891084341588, 11.724733816874597, 10.68578290856793, 9.712240334060729, 9.072307390499052, 8.192308671348723, 8.965792335486391, 9.708120766732305], [9.739809521922124, 9.005269634823541, 9.918908818767695, 10.909783960240276, 11.719056193482597, 12.674170004529456, 13.701513818147433, 14.624791469784485, 15.564448606983586, 16.58887488472919, 17.642187560910195, 17.41666194062966, 16.441257740251928, 15.432865307316119, 14.444823449110833, 13.768247699529246, 12.810862220555654, 11.950857897597041, 10.949931769988185, 10.749987153882165, 10.758715299568701, 10.060573980813565, 10.9094216970717, 11.857958918275392, 12.749085622661756, 13.653371922846711, 14.651640521767622, 15.643636335561268, 16.619994413376673, 17.625682481917018, 17.306235524130354, 16.354382151816598, 15.486828889406016, 14.470401716988746, 13.51769545354018, 12.764309830561787, 11.88541454306635, 10.957092698402173, 9.901841774155656, 10.874215931837028, 10.647122346726826, 11.094425434051455, 11.888796158402364, 12.847745996619883, 13.676738889305181, 14.689552533648595, 15.65437062110314, 16.676259130530084, 17.636431605082777, 17.30560310041818, 16.28538983066591, 15.35459684187674, 14.485227560165926, 13.543701647209112, 12.56940287394735, 11.781817301279295, 10.83195856807455, 9.991646592560913, 8.97644362307249, 9.836183421581762, 9.62877430172954, 10.566188366749838, 11.589045712651618, 12.517654732156268, 13.537942310733332, 14.563384269656039, 15.51186504710861, 16.502973581510833, 17.19037892492672, 16.380762251700265, 15.419799373799455, 14.366231976056092, 13.525704670237918, 12.563156229882168, 11.549496918005756, 10.831443284012023, 9.90292465757189, 8.984188587889584, 7.990609434728044, 8.775643813648827, 8.703198650305927, 9.652160270169452, 10.652074244804, 11.681130073944123, 12.555680388972991, 13.621488558888196, 14.622548530180568, 15.508709421650249, 16.198252814802345, 15.31422361585557, 14.364583646467402, 13.426862275643542, 12.578348343742109, 11.591003029546975, 10.570667671776175, 9.779807892579331, 8.903828795818075, 8.032993075840926, 7.044746652865125, 7.8054249977027945, 7.695096556909904, 8.75683624738906, 9.706074143824086, 10.631461061467926, 11.613117552352614, 12.6406973395279, 13.577872793318964, 14.546402554515785, 15.266299457167158, 14.338765645537443, 13.392618753881969, 12.46593265178996, 11.551575375018947, 10.622616426683823, 9.644806056758693, 8.810921423810921, 7.88358842292593, 7.0345680894333125, 6.097064625407563, 6.744753497649228, 6.8144645591538655, 7.7922523711840945, 8.753434847776212, 9.760429325683788, 10.642345814701724, 11.693135822375192, 12.622580938991542, 13.610765110987499, 14.353895693600355, 13.408659182258473, 12.371154667914494, 11.442047044843445, 10.58937400343809, 9.672899094092884, 8.692326133329654, 7.7878972407121125, 6.9213347782908725, 6.058706152033417, 5.077509199711171, 5.815323167886387, 5.8095106978471565, 6.809969697263693, 7.806221791141718, 8.798136587830015, 9.616989965822327, 10.666984995438195, 11.646289492100662, 12.629383127054334, 13.390975928715035, 12.467185145647816, 11.510584092288301, 10.51011763887783, 9.556213032725248, 8.669213386978388, 7.618967665214547, 6.733838055656339, 5.864760513522531, 4.996660614919778, 4.026947500273685, 4.878236938011842, 4.8400915572102825, 5.853359198993491, 6.8164578925282076, 7.744495483706233, 8.686229337323295, 9.677015237444207, 10.613296334674846, 11.625335105046744, 12.371612116071711, 11.431662785747633, 10.498540900576529, 9.530973607022236, 8.592326771489505, 7.6529281664317725, 6.6930938601302215, 5.705416633671098, 4.806610838964881, 3.925295303920745, 3.0385326666286963, 3.91079833452676, 3.9020118544500573, 4.866596632729091, 5.783482926542913, 6.764608003042107, 7.722496885635984, 8.733376773150209, 9.706520704374315, 10.648655497978732, 11.437812378092186, 10.507157442672703, 9.529949903763898, 8.604776445026856, 7.665816209947988, 6.7192076696174565, 5.73222107738453, 4.7432989292066905, 3.8039154939047792, 2.931007392745681, 2.001635922824507, 2.9301098093437314, 2.8557898776591513, 3.8573974151633683, 4.801517081246294, 5.870882742437525, 6.871550781352398, 7.8451786509885215, 8.913638682704239, 9.905181483391802, 10.836023085897585, 9.838889873119076, 8.837424870849118, 7.858598699429149, 6.912382929263598, 5.840699410536199, 4.774987848094392, 3.8241793013992873, 2.839865900676766, 1.900297770962119, 0.9353529231081312, 1.9134050766713726, 1.9830227435764165, 2.910975855522059, 3.928868729997002, 4.967488487515199, 6.014876213388934, 7.08462398107016, 8.017287115601233, 8.962732903373139, 9.912902073320755, 8.987780743068749, 8.007911365200226, 7.003162054954805, 5.932167479097479, 4.926557723724214, 3.891613864344441, 2.9424215989597924, 1.9010671409383693, 0.9742533124250266, 0.0, 1.0274173651835008, 2.9766797241447662, 3.8805394384444116, 4.933924432921145, 6.000795380993376, 7.0322978412298465, 8.04204939660655, 8.964549082423652, 9.991699525211512, 10.8440629322152, 9.824252285467445, 8.856225647239159, 7.930699317099529, 6.978408750807997, 5.989630437427383, 4.919199423669129, 3.875796477356401, 2.923197202773097, 1.9798560476551288, 0.986332410121678, 1.9559017653692443, 3.8890580765611293, 4.820807008018261, 5.841389351308435, 6.809508851067288, 7.8827620232692155, 8.897424141841189, 9.846075865440868, 10.783750261539199, 11.78456747783989, 10.755376744091492, 9.915677568955234, 8.911273776476868, 7.893860779366076, 6.879075858659844, 5.855142304562694, 4.883434949563915, 3.9774531522305487, 3.005556805273195, 1.965012186530461, 2.911581627064416, 4.861940027462368, 5.803465408307929, 6.844343674778506, 7.805805681298252, 8.731167177283284, 9.72721343520705, 10.690136568071084, 11.714631527361286, 12.669921418459898, 11.817492431433111, 10.886996620571791, 9.836746291412222, 8.814018753231185, 7.7461078490600865, 6.819308401407831, 5.8093429026763035, 4.9823627973323195, 3.9678220708856635, 3.032180525355747, 3.9666897776423666, 5.921184659805551, 6.837687929550603, 7.838994841210854, 8.736675996511076, 9.749758284940144, 10.659239804926637, 11.664200488137993, 12.663618383705186, 13.721014726978455, 12.822648236181188, 11.830537759138219, 10.782136851420908, 9.751316605761712, 8.768892409468643, 7.7707472953478565, 6.836679108015245, 5.974145730906838, 5.01518909867332, 4.051280199219868, 4.974607069092323, 6.9215193298586435, 7.86734015895609, 8.796891209087988, 9.709341899418202, 10.641203891331228, 11.66000445393976, 12.59454133505363, 13.617452189855772, 14.589896040739491, 13.760643053235293, 12.692514830022322, 11.670382015977468, 10.709857542635534, 9.712910540175013, 8.771933801600504, 7.80961547046309, 6.97344465132147, 6.007676229507722, 5.022360689637962, 5.997584103894852, 7.845556653809136, 8.798559493306872, 9.78203877932088, 10.729059303946348, 11.62256307518039, 12.617798228275372, 13.562086426605742, 14.583903209382399, 15.58893494938113, 14.692025290938219, 13.645075693492553, 12.68234295312361, 11.641339305765086, 10.709241195449371, 9.738116821932307, 8.76248117312621, 7.928626558856694, 6.998189859508763, 5.949605997398828, 6.895559345254461, 8.845592486565513, 9.777541745223191, 10.80092994785233, 11.733080228016469, 12.686155657221269, 13.544930425452439, 14.535653921114427, 15.579967795172635, 16.631073521831887, 15.66417218269283, 14.592575924048887, 13.599179700872742, 12.654169577820161, 11.723570475174643, 10.717741027139823, 9.717951289632145, 8.854296926718654, 7.91344459727526, 6.968877680940901, 7.850792268982313, 9.836477689751774, 10.844839967085292, 11.805491931751208, 12.734050633447483, 13.647652981541889, 14.487246326714613, 15.470573741260543, 16.490472877400602, 17.432228282886104, 16.652750522032235, 15.58118337216696, 14.556437419556415, 13.582144396766612, 12.698987129299624, 11.660036220992957, 10.686493646485756, 9.928915923051969, 8.925431480886319, 8.035302278458241, 8.777630709704155], [9.053323700263434, 9.991385898942958, 10.905025082887114, 11.895900224359696, 12.746473558666098, 13.701587369712957, 14.728931183330936, 15.652208834967988, 16.59186597216709, 17.616292249912693, 18.435065479214096, 17.444648124862837, 16.379595400412658, 15.371202967476849, 14.400729426853834, 13.630050052248311, 12.73594144932494, 11.73919467437699, 10.798562776627298, 9.973032074845293, 10.07222947791001, 11.046690244932982, 11.895537961191117, 12.844075182394809, 13.776502987845257, 14.680789288030212, 15.679057886951124, 16.67105370074477, 17.647411778560176, 18.65309984710052, 18.30042469460502, 17.34038262089987, 16.28157268117285, 15.26514550875558, 14.312439245307013, 13.408006159470553, 12.512728865850713, 11.584407021186536, 10.529156096940019, 9.891098102959157, 9.664004517848955, 10.594160476993169, 11.55092006882176, 12.517085788985414, 13.515926221792744, 14.519296051163915, 15.491036963435523, 16.512925472862467, 17.46896266368326, 18.33302046560168, 17.312807195849413, 16.38201420706024, 15.33442027341364, 14.338445438975945, 13.364146665714184, 12.42551363018806, 11.475654896983315, 10.618960915345276, 9.603757945856852, 8.85306559270389, 8.64565647285167, 9.583070537871967, 10.605927883773747, 11.534536903278397, 12.51052494554983, 13.535966904472538, 14.48444768192511, 15.475556216327332, 16.453044209891967, 17.408179616883764, 16.447216738982956, 15.393649341239595, 14.512168688361493, 13.549620248005743, 12.519169941889666, 11.475139612920788, 10.546620986480656, 9.611502910673947, 8.617923757512408, 7.792525984770956, 7.720080821428056, 8.66904244129158, 9.668956415926129, 10.698012245066252, 11.52826302378949, 12.594071193704693, 13.595131164997069, 14.48129205646675, 15.460918099767595, 16.34164098103907, 15.392001011650905, 14.454279640827044, 13.605765708925608, 12.618420394730474, 11.598085036959674, 10.581043381861313, 9.619333959653577, 8.690470609876375, 7.6720609756494875, 6.822307168824924, 6.711978728032033, 7.77371841851119, 8.722956314946215, 9.648343232590054, 10.585700187169113, 11.613279974344401, 12.550455428135464, 13.518985189332286, 14.528964742132409, 15.366183010720945, 14.420036119065472, 13.493350016973462, 12.578992740202446, 11.650033791867322, 10.672223421942192, 9.703809812762502, 8.776476811877512, 7.749014491531877, 6.724378948191926, 5.7616356687713575, 5.831346730275995, 6.809134542306224, 7.770317018898342, 8.777311496805918, 9.614928449518223, 10.66571845719169, 11.59516357380804, 12.583347745803998, 13.544771953411393, 14.436076547441974, 13.398572033097997, 12.469464410026948, 11.616791368621591, 10.700316459276383, 9.719743498513154, 8.815314605895614, 7.814223167242453, 6.773152554131982, 5.76476026057559, 4.8322053390085165, 4.826392868969286, 5.826851868385822, 6.823103962263848, 7.770719222646514, 8.589572600638826, 9.639567630254694, 10.61887212691716, 11.601965761870833, 12.581852188526073, 13.494602510831317, 12.538001457471802, 11.537535004061333, 10.583630397908749, 9.696630752161887, 8.646385030398047, 7.76125542083984, 6.871125556052861, 5.932170231700838, 4.881116016543657, 3.8951191091339714, 3.856973728332412, 4.82594183380999, 5.7890405273447065, 6.717078118522732, 7.658811972139794, 8.649597872260706, 9.585878969491345, 10.597917739863243, 11.562488375882749, 12.459080150931134, 11.52595826576003, 10.558390972205736, 9.619744136673006, 8.680345531615274, 7.7205112253137225, 6.732833998854599, 5.834028204148382, 4.898281782169358, 3.961087606795431, 2.9276805056488895, 2.918894025572187, 3.83917926754559, 4.756065561359412, 5.737190637858606, 6.695079520452483, 7.7059594079667075, 8.679103339190814, 9.62123813279523, 10.664716020802445, 11.534574807856204, 10.557367268947399, 9.632193810210357, 8.693233575131488, 7.7466250348009575, 6.759638442568031, 5.7707162943901915, 4.83133285908828, 3.9039938709942934, 2.9617597284762978, 1.946991980465861, 1.8726720487812807, 2.8299800499798673, 3.7740997160627927, 4.843465377254024, 5.844133416168897, 6.8177612858050205, 7.886221317520738, 8.877764118208301, 9.84364357009225, 10.84077678287076, 9.864842236032619, 8.886016064612651, 7.939800294447099, 6.8681167757197, 5.802405213277893, 4.851596666582789, 3.867283265860267, 2.873284249210731, 1.9083394013567434, 0.930287247793502, 0.9556053783929157, 1.8835584903385583, 2.9014513648135014, 3.9400711223316986, 4.987458848205433, 6.057206615886659, 6.989869750417732, 7.935315538189638, 8.966416307528164, 9.89153763778017, 9.035328730383727, 8.030579420138306, 6.95958484428098, 5.953975088907715, 4.919031229527942, 3.9698389641432934, 2.9284845061218703, 2.0016706776085273, 1.0274173651835008, 0.0, 1.9492623589612652, 2.853122073260911, 3.906507067737645, 4.973378015809875, 6.0048804760463454, 7.01463203142305, 7.937131717240152, 8.964282160028011, 9.933298876071296, 10.851669650650944, 9.88364301242266, 8.95811668228303, 8.005826115991498, 7.017047802610884, 5.94661678885263, 4.903213842539902, 3.950614567956598, 3.0072734128386296, 1.9724486742410956, 1.0028793189935294, 2.9486048220762218, 3.7933896428347604, 4.813971986124935, 5.782091485883788, 6.8553446580857145, 7.8700067766576876, 8.818658500257367, 9.756332896355698, 10.80850732558711, 11.782794109274992, 10.943094934138735, 9.938691141660371, 8.921278144549577, 7.906493223843345, 6.882559669746195, 5.910852314747416, 4.980360446477192, 3.991673069392613, 2.9511284506498785, 2.0584554929612846, 3.92148677297746, 4.804141002517492, 5.816926309595006, 6.778388316114752, 7.703749812099784, 8.69979607002355, 9.662719202887585, 10.687214162177787, 11.642504053276399, 12.611181876069823, 11.914413985755292, 10.864163656595723, 9.841436118414686, 8.773525214243588, 7.846725766591332, 6.8367602678598045, 5.968479061451737, 4.953938335005081, 4.018296789475164, 3.1135636435392353, 4.980731405320643, 5.838363523760167, 6.811577476027354, 7.709258631327577, 8.722340919756645, 9.631822439743138, 10.636783122954494, 11.636201018521687, 12.693597361794955, 13.6163376808179, 12.857955124321721, 11.809554216604411, 10.778733970945215, 9.796309774652144, 8.798164660531357, 7.864096473198746, 6.960261995026257, 6.001305362792738, 5.037396463339285, 4.121480934989192, 5.981066075373736, 6.883526529121987, 7.769473843904488, 8.681924534234703, 9.613786526147729, 10.63258708875626, 11.567123969870131, 12.590034824672273, 13.562478675555992, 14.562880920176235, 13.719932195205825, 12.697799381160971, 11.737274907819037, 10.740327905358514, 9.799351166784005, 8.83703283564659, 7.959560915440889, 6.993792493627139, 6.008476953757379, 5.170292619717231, 6.947172723643015, 7.814745863472769, 8.754621414137379, 9.701641938762847, 10.59514570999689, 11.590380863091873, 12.534669061422242, 13.5564858441989, 14.561517584197631, 15.491939016419561, 14.672493058676055, 13.709760318307113, 12.66875667094859, 11.736658560632872, 10.765534187115808, 9.78989853830971, 8.914742822976113, 7.98430612362818, 6.935722261518245, 6.2090735235957695, 7.960030628248356, 8.793728115389088, 9.775085404873272, 10.705662862832968, 11.65873829203777, 12.51751306026894, 13.508236555930928, 14.552550429989136, 15.603656156648388, 16.527889255469635, 15.61999328923239, 14.626597066056245, 13.681586943003664, 12.750987840358144, 11.745158392323324, 10.745368654815646, 9.840413190838072, 8.899560861394678, 7.954993945060318, 7.1643064473236215, 8.97125752614157, 9.86102633725119, 10.785222869403697, 11.706633268263982, 12.62023561635839, 13.459828961531114, 14.443156376077043, 15.463055512217103, 16.404810917702605, 17.450216405877814, 16.60860073735046, 15.583854784739918, 14.609561761950115, 13.726404494483125, 12.687453586176458, 11.713911011669257, 10.915032187171388, 9.911547745005738, 9.021418542577658, 8.091144888045465], [8.79215784990409, 9.75113310517702, 10.730470118614232, 11.721345260086814, 12.736958531823301, 13.69207234287016, 14.719416156488137, 15.697113511935248, 16.63677064913435, 17.64122063903807, 16.587907962857066, 15.597490608505808, 14.53243788405563, 13.524045451119822, 12.553571910496807, 11.782892535891285, 10.879226215610961, 9.869748123278328, 8.892660793015228, 8.023769715884029, 9.811063627550666, 10.806437451167044, 11.720982996918234, 12.669520218121926, 13.729370611899759, 14.671274261187415, 15.669542860108326, 16.661538673901973, 17.692316455527436, 18.422081043795348, 17.46868535536547, 16.50864328166032, 15.449833341933298, 14.433406169516028, 13.48069990606746, 12.788773340439922, 11.804673893100265, 10.900072959742607, 9.940750788847756, 9.082531323771274, 9.810723543299522, 10.740879502443736, 11.697639094272326, 12.663804814435979, 13.61041381412815, 14.557347653339349, 15.529088565610957, 16.550977075037903, 17.507014265858693, 18.514268986389688, 18.38232931172016, 17.451536322930988, 16.399266093359746, 15.403291258922051, 14.42899248566029, 13.771265869722415, 12.87760815962005, 11.881351909419347, 10.866148939930923, 10.120563834026541, 8.792375498302237, 9.729789563322534, 10.752646909224314, 11.681255928728964, 12.548576547725265, 13.574018506647972, 14.522499284100544, 15.513607818502766, 16.4910958120674, 17.467821202901863, 18.39647909794422, 17.342911700200855, 16.46143104732276, 15.498882606967006, 14.46843230085093, 13.424401971882052, 12.49588334544192, 11.56076526963521, 10.567186116473671, 9.741788343732221, 7.866799846878623, 8.815761466742147, 9.760946237854636, 10.79000206699476, 11.566314625964925, 12.632122795880129, 13.633182767172501, 14.519343658642182, 15.498969701943027, 16.443214175056994, 17.341263370612168, 16.403541999788306, 15.555028067886873, 14.56768275369174, 13.547347395920939, 12.530305740822577, 11.56859631861484, 10.639732968837638, 9.621323334610752, 8.77156952778619, 6.8586977534826, 7.865708240439697, 8.814946136874722, 9.740333054518562, 10.623751789344547, 11.651331576519834, 12.588507030310897, 13.557036791507718, 14.567016344307842, 15.46193175296496, 16.369298478026735, 15.442612375934726, 14.528255099163712, 13.599296150828588, 12.621485780903457, 11.65307217172377, 10.725739170838779, 9.698276850493142, 8.67364130715319, 7.710898027732623, 5.914667010687552, 6.866872904353724, 7.828055380945842, 8.835049858853417, 9.652980051693657, 10.703770059367125, 11.633215175983475, 12.621399347979432, 13.582823555586828, 14.520177845042998, 15.34783439205926, 14.418726768988211, 13.566053727582856, 12.649578818237648, 11.669005857474419, 10.764576964856879, 9.76348552620372, 8.722414913093248, 7.7140226195368555, 6.781467697969782, 4.903435637402961, 5.884590230433322, 6.864241809763955, 7.8087708248219485, 8.62762420281426, 9.677619232430128, 10.656923729092595, 11.640017364046267, 12.619903790701507, 13.57870380843234, 14.485654385265137, 13.486797363022596, 12.532892756870014, 11.645893111123153, 10.595647389359312, 9.710517779801105, 8.820387915014127, 7.881432590662103, 6.830378375504922, 5.844381468095237, 3.9340164967660867, 4.863993435985424, 5.827092129520141, 6.755129720698166, 7.696863574315228, 8.68764947443614, 9.62393057166678, 10.635969342038678, 11.600539978058183, 12.540489308382261, 13.473611193553365, 12.507653331167003, 11.569006495634271, 10.629607890576539, 9.669773584274987, 8.682096357815864, 7.783290563109647, 6.847544141130623, 5.910349965756696, 4.876942864610155, 2.9959367940058614, 3.877230869721024, 4.794117163534846, 5.77524224003404, 6.733131122627917, 7.744011010142142, 8.717154941366248, 9.659289734970665, 10.702767622977879, 11.63342255839736, 12.506629627908664, 11.581456169171622, 10.642495934092754, 9.695887393762222, 8.708900801529294, 7.719978653351457, 6.7805952180495455, 5.853256229955559, 4.911022087437563, 3.8962543394271263, 1.9497148172149554, 2.8680316521553015, 3.812151318238227, 4.881516979429458, 5.882185018344331, 6.855812887980455, 7.924272919696172, 8.915815720383735, 9.881695172267685, 10.878828385046194, 11.814104594993882, 10.835278423573914, 9.889062653408363, 8.817379134680964, 7.751667572239158, 6.800859025544053, 5.816545624821532, 4.822546608171996, 3.8576017603180084, 2.8795496067547672, 0.9936569805683496, 1.9216100925139923, 2.939502966988935, 3.9781227245071324, 5.025510450380867, 6.095258218062093, 7.027921352593166, 7.973367140365072, 9.004467909703598, 9.929589239955604, 10.909458617824127, 9.979841779099571, 8.908847203242244, 7.903237447868979, 6.868293588489206, 5.919101323104558, 4.877746865083135, 3.9509330365697926, 2.9766797241447662, 1.9492623589612652, 0.0, 1.0059645569038829, 2.059349551380617, 3.1312615530314067, 4.196570341189183, 5.206321896565887, 6.189630846096913, 7.216781288884773, 8.185798004928058, 9.205608651675814, 10.072679316576973, 9.147152986437344, 8.160075654912836, 7.11733353164754, 6.0469025178892855, 5.003499571576557, 4.0509002969932535, 3.0621999136985747, 2.012480790749163, 1.042911435501597, 0.9993424631149568, 1.9462321264777325, 2.9668144697679066, 3.9349339695267593, 5.008187141728687, 6.02284926030066, 6.97150098390034, 7.90917537999867, 8.961349809230082, 9.99054054297848, 11.01799466914535, 10.03518025841757, 8.999311274774302, 7.984526354068069, 6.960592799970919, 5.936327855911607, 4.952620348972939, 3.96393297188836, 2.9233883531456253, 1.9768189126116704, 1.9722244140161953, 2.9137497948617557, 3.960211075881025, 4.931230799757723, 5.856592295742756, 6.852638553666522, 7.815561686530556, 8.840056645820757, 9.79534653691937, 10.764024359712794, 11.722669358783952, 10.940340475700115, 9.917612937519078, 8.84970203334798, 7.9229025856957245, 6.862235809023995, 5.914850786398247, 4.900310059951591, 3.9564042806624675, 2.919243626888896, 3.031469046359378, 3.94797231610443, 4.954862242313373, 5.862101114970549, 6.875183403399616, 7.78466492338611, 8.789625606597465, 9.789043502164658, 10.846439845437926, 11.76918016446087, 12.726085215334638, 11.885731035708801, 10.854910790049605, 9.872486593756538, 8.874341479635751, 7.886258033009934, 6.906633719972766, 5.9476770877392475, 4.913609916500032, 3.9271609183388527, 4.031803716412471, 4.977624545509917, 5.912758610190507, 6.834767017877676, 7.766629009790702, 8.785429572399233, 9.719966453513104, 10.742877308315245, 11.715321159198965, 12.715723403819208, 13.679649850621317, 12.773976200265361, 11.813451726923427, 10.816504724462908, 9.821512726595193, 8.859194395457779, 7.899899822472979, 6.870005946787886, 5.884690406918126, 4.975972603066892, 4.99791036468175, 5.908843879860699, 6.897906180423398, 7.844926705048867, 8.747988193639863, 9.743223346734846, 10.687511545065215, 11.709328327841872, 12.714360067840603, 13.644781500062534, 14.6917310975082, 13.772993172044144, 12.71366134791585, 11.753004113371814, 10.78187973985475, 9.806244091048653, 8.855081730008203, 7.860519576788927, 6.811935714678992, 5.947907673236425, 6.010768269287091, 6.887826131777017, 7.911214334406155, 8.848947629118989, 9.811580775680742, 10.670355543911912, 11.6610790395739, 12.705392913632108, 13.75649864029136, 14.680731739112609, 15.66489796619965, 14.671501743023505, 13.726491619970924, 12.761099040057589, 11.755269592022769, 10.73585362797285, 9.71662664399882, 8.775774314555425, 7.831207398221066, 6.903140596964277, 7.0219951671803065, 7.955124353639119, 8.915776318305035, 9.849918034550003, 10.773078100001364, 11.612671445174087, 12.595998859720016, 13.615897995860076, 14.557653401345576, 15.603058889520783, 16.65350541431772, 15.628759461707178, 14.654466438917375, 13.73651569418257, 12.697564785875903, 11.70439598482646, 10.791245640332136, 9.787761198166486, 8.888598548637935, 7.82997903768612], [9.712477745990038, 10.671453001262968, 11.65079001470018, 12.64166515617276, 13.657278427909247, 14.612392238956106, 15.639736052574083, 16.617433408021192, 17.55709054522029, 16.635256082134184, 15.58194340595318, 14.591526051601923, 13.526473327151745, 12.518080894215936, 11.547607353592921, 10.776927978987398, 9.88281937606403, 8.886072601116078, 7.945440703366387, 8.944089611969977, 10.731383523636614, 10.938584159429219, 11.828099750448672, 12.776636971652364, 13.586020571179933, 14.575255197689742, 15.579772155354835, 16.571767969148482, 17.571404947973157, 17.41611648689146, 16.462720798461582, 15.502678724756432, 14.443868785029412, 13.427441612612142, 12.474735349163575, 11.782808783536035, 10.808267053553333, 9.916397437580358, 8.993530699198915, 10.002851219857222, 10.714583257599168, 9.904732706191329, 10.848725289118008, 11.814891009281661, 12.658367304536508, 13.605301143747708, 14.577042056019316, 15.59893056544626, 16.554967756267054, 17.56222247679805, 17.376364754816272, 16.4455717660271, 15.39330153645586, 14.397326702018166, 13.423027928756404, 12.765301312818528, 11.881201320073117, 10.929799282605625, 9.918928850282082, 10.870758179953915, 9.696235212601882, 8.893642767070126, 9.864881367807929, 10.793490387312579, 11.596530038133624, 12.621971997056331, 13.570452774508903, 14.561561308911125, 15.53904930247576, 16.515774693310224, 17.48321275494628, 17.3115147226868, 16.347611441590672, 15.385063001234922, 14.442933884697998, 13.738753857015908, 12.810235230575776, 11.898342191788066, 10.904763038626527, 10.645648058031867, 8.770659561178269, 7.954628845092477, 8.808899728262995, 9.837955557403118, 10.614268116373283, 11.680076286288486, 12.681136257580862, 13.567297149050543, 14.546923192351388, 15.491167665465357, 16.42799702761423, 17.307401714087955, 16.45888778218652, 15.471542467991387, 14.451207110220587, 13.434165455122226, 12.47245603291449, 11.543592683137287, 10.5251830489104, 9.675429242085835, 7.762557467782246, 6.913661730848057, 7.862899627283082, 8.788286544926923, 9.671705279752906, 10.699285066928194, 11.636460520719258, 12.604990281916079, 13.614969834716202, 14.50988524337332, 15.456032135028794, 16.346472090234375, 15.43211481346336, 14.503155865128235, 13.525345495203105, 12.556931886023415, 11.629598885138424, 10.602136564792788, 9.577501021452838, 8.61475774203227, 6.818526724987198, 5.914826394762084, 6.876008871354202, 7.883003349261777, 8.700933542102016, 9.751723549775486, 10.681168666391835, 11.669352838387793, 12.630777045995188, 13.568131335451358, 14.494913580647617, 15.32258648328786, 14.469913441882504, 13.553438532537296, 12.572865571774066, 11.668436679156526, 10.667345240503366, 9.626274627392894, 8.617882333836501, 7.6853274122694275, 5.8072953517026065, 4.932543720841682, 5.912195300172316, 6.856724315230309, 7.67557769322262, 8.72557272283849, 9.704877219500956, 10.687970854454628, 11.667857281109868, 12.626657298840701, 13.533607875673498, 14.390657077322246, 13.436752471169662, 12.5497528254228, 11.49950710365896, 10.614377494100752, 9.724247629313773, 8.78529230496175, 7.734238089804568, 6.7482411823948825, 4.8378762110657325, 3.9119469263937847, 4.8750456199285015, 5.803083211106527, 6.7448170647235886, 7.735602964844501, 8.67188406207514, 9.683922832447038, 10.648493468466544, 11.588442798790622, 12.521564683961726, 13.411513045466648, 12.472866209933919, 11.533467604876186, 10.573633298574634, 9.585956072115511, 8.687150277409293, 7.751403855430269, 6.814209680056342, 5.7808025789098005, 3.8997965083055073, 2.9251843601293848, 3.842070653943207, 4.823195730442401, 5.781084613036278, 6.7919645005505025, 7.7651084317746095, 8.707243225379026, 9.75072111338624, 10.68137604880572, 11.658583587714526, 12.48531588347127, 11.546355648392401, 10.59974710806187, 9.612760515828942, 8.623838367651103, 7.684454932349191, 6.7571159442552045, 5.814881801737209, 4.800114053726772, 2.853574531514601, 1.9159851425636618, 2.8601048086465872, 3.9294704698378187, 4.930138508752692, 5.9037663783888155, 6.972226410104533, 7.963769210792095, 8.929648662676046, 9.926781875454555, 10.908761666530015, 11.739138137873562, 10.79292236770801, 9.721238848980612, 8.655527286538804, 7.704718739843699, 6.720405339121178, 5.726406322471642, 4.761461474617654, 3.783409321054413, 1.8975166948679951, 0.9695635829223527, 1.987456457397296, 3.026076214915493, 4.073463940789228, 5.143211708470454, 6.075874843001527, 7.021320630773433, 8.052421400111959, 8.977542730363965, 9.957412108232488, 10.883701493399215, 9.812706917541888, 8.807097162168624, 7.772153302788852, 6.822961037404204, 5.781606579382781, 4.854792750869438, 3.880539438444412, 2.853122073260911, 1.0059645569038829, 0.0, 1.0533849944767337, 2.125296996127524, 3.1906057842853004, 4.200357339662004, 5.183666289193029, 6.21081673198089, 7.179833448024175, 8.19964409477193, 9.167670733000215, 10.093197063139844, 9.16604021181672, 8.123298088551422, 7.052867074793168, 6.00946412848044, 5.056864853897136, 4.068164470602458, 3.0184453476530457, 2.04887599240548, 1.9910573822185471, 0.9402675695738495, 1.9608499128640235, 2.9289694126228762, 4.002222584824803, 5.0168847033967765, 5.965536426996456, 6.903210823094787, 7.955385252326198, 8.984575986074596, 10.012030112241467, 11.026895177521158, 9.99102619387789, 8.976241273171658, 7.952307719074509, 6.9280427750151965, 5.944335268076529, 4.9556478909919495, 3.9151032722492154, 2.9685338317152605, 2.8925443101021417, 1.9510189292565814, 2.963804236334094, 3.9252662428538403, 4.850627738838872, 5.846673996762639, 6.809597129626672, 7.834092088916874, 8.789381980015486, 9.75805980280891, 10.716704801880068, 11.768311394085735, 10.904700521604935, 9.836789617433837, 8.909990169781581, 7.849323393109853, 6.835170682484195, 5.820629956037539, 4.876724176748414, 3.839563522974843, 3.951788942445325, 2.9852414504992555, 3.958455402766442, 4.856136558066665, 5.869218846495732, 6.7787003664822265, 7.78366104969358, 8.783078945260774, 9.840475288534043, 10.763215607556987, 11.720120658430755, 12.751884802779653, 11.837124943360243, 10.797296190558074, 9.799151076437287, 8.806577929095882, 7.826953616058714, 6.867996983825195, 5.833929812585979, 4.8474808144248, 4.9521236124984185, 4.030404455861075, 4.916351770643576, 5.828802460973792, 6.760664452886818, 7.779465015495349, 8.71400189660922, 9.736912751411362, 10.709356602295081, 11.709758846915324, 12.673685293717433, 13.695818107762287, 12.753735227997852, 11.741314321264444, 10.741832622681141, 9.779514291543727, 8.820219718558926, 7.790325842873833, 6.805010303004073, 5.896292499152839, 5.9182302607676975, 4.961623790211857, 5.901499340876467, 6.848519865501936, 7.742023636735978, 8.73725878983096, 9.68154698816133, 10.703363770937987, 11.708395510936718, 12.638816943158648, 13.685766540604314, 14.648499280973256, 13.633981244001795, 12.67332400945776, 11.702199635940696, 10.726563987134599, 9.77540162609415, 8.780839472874874, 7.7322556107649385, 6.868227569322372, 6.931088165373039, 5.9406060421281754, 6.9219633316123605, 7.852540789572057, 8.805616218776857, 9.664390987008026, 10.655114482670015, 11.699428356728223, 12.750534083387475, 13.674767182208724, 14.700511249337877, 15.591821639109451, 14.64681151605687, 13.681418936143535, 12.675589488108715, 11.656173524058795, 10.636946540084766, 9.696094210641371, 8.751527294307012, 7.8234604930502245, 7.942315063266254, 7.0079042639902775, 7.9321007961427865, 8.85351119500307, 9.767113543097476, 10.606706888270201, 11.59003430281613, 12.60993343895619, 13.55168884444169, 14.597094332616898, 15.668661482482172, 16.549079357793122, 15.57478633500332, 14.656835590268516, 13.617884681961849, 12.624715880912406, 11.711565536418082, 10.708081094252432, 9.808918444723885, 8.750298933772068], [10.749978406813666, 11.708953662086596, 12.103004205474228, 13.09387934694681, 13.795014746127373, 14.73342186177528, 15.708863604743305, 16.723747709470935, 16.7365948314829, 15.715081638361207, 14.661768962180204, 13.671351607828948, 12.60629888337877, 11.597906450442961, 10.627432909819946, 9.856753535214423, 8.962644932291052, 7.965898157343102, 8.910114756411835, 9.936852352761942, 11.768884184460243, 11.991969153905956, 11.112491327170225, 12.061028548373917, 12.764985316948215, 13.754219943458025, 14.758736901123116, 15.750732714916763, 16.75036969374144, 16.495942043118486, 15.542546354688607, 14.582504280983457, 13.523694341256437, 12.507267168839167, 11.5545609053906, 10.86263433976306, 9.888092609780356, 8.996222993807383, 9.958204752244363, 10.995613960649187, 11.767968252075901, 10.958117700668065, 10.133116865839561, 11.099282586003214, 11.83733205030479, 12.78426588951599, 13.756006801787597, 14.777895311214541, 15.733932502035334, 16.741187222566328, 16.456190311043297, 15.525397322254127, 14.473127092682885, 13.47715225824519, 12.50285348498343, 11.845126869045552, 10.96102687630014, 10.00962483883265, 10.88360290332753, 11.835432232999363, 10.749620207078616, 9.947027761546863, 9.149272944529482, 10.077881964034132, 10.775494783901905, 11.800936742824613, 12.749417520277184, 13.740526054679407, 14.71801404824404, 15.694739439078504, 16.662177500714563, 16.391340278913823, 15.427436997817697, 14.464888557461947, 13.522759440925023, 12.818579413242931, 11.890060786802799, 11.037332872625878, 11.869437091671974, 11.699033052508598, 9.824044555655002, 9.008013839569212, 8.093291304984549, 9.122347134124672, 9.793232862141565, 10.85904103205677, 11.860101003349142, 12.746261894818822, 13.725887938119667, 14.670132411233636, 15.60696177338251, 16.5483279059083, 16.41577279397537, 15.43704175779714, 14.501588687154605, 13.85086607076435, 12.889156648556614, 12.086984498748201, 11.578568043387131, 10.728814236562567, 8.81594246225898, 7.967046725324791, 7.147291204004635, 8.072678121648474, 8.850670025521188, 9.878249812696474, 10.815425266487537, 11.783955027684359, 12.793934580484482, 13.688849989141604, 14.634996880797077, 15.587398282054721, 16.48549980794009, 15.556540859604967, 14.578730489679836, 13.610316880500147, 12.682983879615156, 11.65552155926952, 10.630886015929569, 9.668142736509001, 7.871911719463931, 6.968211389238818, 6.073471123092032, 7.066766006580072, 7.879898287870296, 8.930688295543764, 9.860133412160115, 10.848317584156074, 11.80974179176347, 12.747096081219642, 13.673878326415899, 14.602985949486948, 15.523298436359237, 14.606823527014027, 13.626250566250798, 12.721821673633258, 11.720730234980097, 10.679659621869625, 9.671267328313233, 8.73871240674616, 6.86068034617934, 5.985928715318416, 5.091160045940596, 6.035689060998589, 6.8545424389909, 7.904537468606768, 8.883841965269236, 9.86693560022291, 10.846822026878149, 11.805622044608985, 12.71257262144178, 13.752448517474093, 14.490137465646395, 13.603137819899532, 12.552892098135692, 11.667762488577484, 10.777632623790504, 9.838677299438482, 8.7876230842813, 7.801626176871616, 5.891261205542466, 4.9653319208705184, 4.054010365696781, 4.982047956874807, 5.923781810491868, 6.914567710612781, 7.850848807843421, 8.86288757821532, 9.827458214234825, 10.767407544558903, 11.700529429730008, 12.730085684856098, 13.526251204410652, 12.58685259935292, 11.627018293051366, 10.639341066592243, 9.740535271886026, 8.804788849907002, 7.867594674533075, 6.834187573386534, 4.953181502782241, 3.978569354606118, 3.0210353997114865, 4.002160476210681, 4.960049358804557, 5.970929246318782, 6.944073177542889, 7.886207971147306, 8.907539998415137, 9.838194933834618, 10.815402472743424, 11.740575931480466, 12.599740642869135, 11.653132102538603, 10.666145510305675, 9.677223362127835, 8.737839926825924, 7.810500938731938, 6.868266796213942, 5.853499048203505, 3.9069595259913346, 2.9693701370403955, 2.0390695544148674, 3.074979415527351, 4.075647454442224, 5.049275324078348, 6.039380828469224, 7.012696749254087, 7.978576201138038, 8.975709413916547, 9.910430085067203, 10.88925625648717, 11.835472026652722, 10.774623843457345, 9.708912281015538, 8.758103734320432, 7.773790333597911, 6.7797913169483754, 5.8148464690943875, 4.836794315531146, 2.950901689344729, 2.0229485773990863, 1.0587256835706007, 2.097345441088798, 3.144733166962533, 4.205986264760635, 5.077543261538715, 6.02298904931062, 7.054089818649146, 7.979211148901152, 8.959080526769675, 9.963829837015096, 10.866091912018625, 9.860482156645359, 8.825538297265586, 7.876346031880937, 6.834991573859514, 5.908177745346172, 4.933924432921145, 3.9065070677376443, 2.059349551380617, 1.0533849944767337, 0.0, 1.0719120016507901, 2.1372207898085662, 3.14697234518527, 4.130281294716295, 5.157431737504155, 6.12644845354744, 7.146259100295196, 8.114285738523481, 9.03981206866311, 10.026889400187619, 9.176683083028156, 8.106252069269901, 7.062849122957173, 6.110249848373869, 5.121549465079191, 4.07183034212978, 3.1022609868822135, 3.0444423766952804, 1.993652564050583, 1.040675469091047, 2.0087949688499, 3.082048141051827, 4.093014217328087, 5.041665940927766, 5.9793403370260965, 7.031514766257508, 8.060705500005906, 9.088159626172777, 10.02038652804045, 10.963075126143242, 10.029626267648393, 9.005692713551243, 7.98142776949193, 6.997720262553262, 6.009032885468683, 4.968488266725949, 4.021918826191994, 3.9459293045788755, 3.004403923733315, 2.0436297925611178, 3.005091799080864, 3.930453295065896, 4.926499552989663, 5.889422685853697, 6.913917645143899, 7.86920753624251, 8.837885359035935, 9.796530358107093, 10.84813695031276, 11.870864488493797, 10.890174611910572, 9.963375164258316, 8.902708387586587, 7.888555676960928, 6.8740149505142725, 5.930109171225148, 4.892948517451576, 5.005173936922058, 4.038626444975989, 3.0382809589934654, 3.935962114293689, 4.949044402722757, 5.8585259227092505, 6.863486605920605, 7.862904501487799, 8.920300844761067, 9.843041163784012, 10.79994621465778, 11.831710359006678, 12.808162341024325, 11.850681185034807, 10.85253607091402, 9.859962923572615, 8.880338610535448, 7.921381978301929, 6.887314807062713, 5.900865808901533, 5.989624273322049, 5.043803444224603, 3.9961773268705993, 4.908628017200816, 5.840490009113842, 6.859290571722372, 7.7938274528362435, 8.816738307638385, 9.789182158522104, 10.789584403142348, 11.753510849944458, 12.775643663989312, 13.736168137331246, 12.794699315741177, 11.795217617157874, 10.83289928602046, 9.87360471303566, 8.843710837350567, 7.858395297480806, 6.949677493629572, 6.955730921591328, 5.9750227785753856, 4.98132489710349, 5.9283454217289595, 6.821849192963002, 7.817084346057985, 8.761372544388355, 9.783189327165012, 10.788221067163743, 11.718642499385673, 12.76559209683134, 13.728324837200281, 14.667649900460798, 13.726709003934493, 12.75558463041743, 11.779948981611332, 10.828786620570883, 9.834224467351607, 8.785640605241673, 7.905728230146003, 7.968588826196669, 6.954005030491704, 6.001788887839384, 6.93236634579908, 7.885441775003882, 8.744216543235051, 9.73494003889704, 10.779253912955248, 11.8303596396145, 12.754592738435749, 13.780336805564902, 14.687462495998037, 15.632472619050619, 14.73480393062027, 13.72897448258545, 12.70955851853553, 11.690331534561501, 10.749479205118107, 9.804912288783747, 8.860961153873854, 8.979815724089883, 7.972578317035725, 7.01192635236981, 7.933336751230094, 8.846939099324501, 9.686532444497226, 10.669859859043155, 11.689758995183215, 12.631514400668715, 13.676919888843923, 14.748487038709197, 15.674446350731646, 16.56044743799707, 15.710220584745251, 14.671269676438584, 13.678100875389141, 12.764950530894817, 11.761466088729167, 10.846419105547513, 9.787799594595697], [11.666632251139557, 12.625607506412488, 13.0113122556665, 12.362124555550196, 12.78031694144683, 13.718724057094736, 14.694165800062763, 15.709049904790394, 15.71427369617864, 14.695496483169391, 13.642183806988388, 12.651766452637132, 11.586713728186954, 10.578321295251145, 9.607847754628128, 8.837168380022606, 7.997284790024864, 8.88255200166899, 9.826768600737722, 10.853506197087828, 12.685538028786134, 12.966719414543558, 12.020799377362497, 11.32032315457065, 11.750287512267672, 12.739522138777481, 13.744039096442574, 14.73603491023622, 15.735671889060898, 15.47635688792667, 14.522961199496791, 13.562919125791641, 12.50410918606462, 11.48768201364735, 10.534975750198782, 9.843049184571242, 8.922732467514168, 9.851054312178345, 10.87485859657025, 11.912267804975073, 12.810440257053475, 11.932867961305668, 11.041424916031833, 10.330536076226158, 10.822634245624247, 11.769568084835447, 12.741308997107055, 13.763197506533999, 14.719234697354793, 15.726489417885787, 15.43660515585148, 14.50581216706231, 13.453541937491067, 12.457567103053373, 11.483268329791612, 10.825541713853735, 9.995666734033952, 10.864456157203612, 11.800256747653417, 12.75208607732525, 11.79209221205619, 10.921778022184466, 10.057580994721754, 9.265981709120434, 9.760796979221363, 10.78623893814407, 11.734719715596642, 12.725828249998864, 13.7033162435635, 14.680041634397963, 15.606813365652542, 15.371755123722005, 14.40785184262588, 13.44530340227013, 12.503174285733206, 11.836617982440114, 10.92470064453661, 11.85981872034332, 12.786090935997862, 12.76590400058083, 10.866516560632576, 9.982764100206815, 9.00159935517682, 8.20146327342286, 8.778535057461022, 9.844343227376225, 10.8454031986686, 11.731564090138281, 12.711190133439127, 13.655434606553095, 14.551597638320489, 15.492963770846282, 15.396187638783553, 14.417456602605322, 13.482003531962787, 12.885505928498162, 11.923796506290426, 12.852659856067628, 12.645438991459363, 11.795685184634799, 9.858414467236553, 8.941796985962394, 8.055599254196906, 7.14641653543179, 7.835972220840645, 8.863552008015933, 9.800727461806996, 10.769257223003818, 11.779236775803941, 12.633485854079582, 13.579632745735056, 14.5320341469927, 15.522553118530862, 15.3856755169054, 14.407865146980269, 13.854392397266572, 12.94403687918257, 12.722392507341752, 11.697756964001801, 10.735013684581233, 8.914383724441505, 7.9429616498764215, 6.981779173284304, 6.118998874416294, 6.865200483189754, 7.915990490863221, 8.84543560747957, 9.83361977947553, 10.795043987082925, 11.69173194615762, 12.618514191353878, 13.547621814424927, 14.529789655596492, 15.519707061833445, 14.693121514323028, 13.788692621705488, 12.78760118305233, 11.746530569941857, 10.738138276385465, 9.805583354818392, 7.903152351156913, 6.976615893496388, 5.999468096132867, 5.087921928834811, 5.839844634310357, 6.889839663926225, 7.869144160588692, 8.852237795542365, 9.832124222197605, 10.750257909546963, 11.657208486379758, 12.680536515823302, 13.557217669500252, 14.51602135471895, 13.619763046207922, 12.734633436649714, 11.844503571862736, 10.905548247510714, 9.854494032353532, 8.868497124943847, 6.933733210520039, 5.95601909904849, 4.962318415889053, 4.034280824711028, 4.909084005811326, 5.8998699059322375, 6.836151003162877, 7.848189773534776, 8.812760409554281, 9.712043409496882, 10.645165294667986, 11.658173683205307, 12.59333140826451, 13.487953202053392, 12.693889241123596, 11.706212014664473, 10.807406219958256, 9.871659797979232, 8.934465622605305, 7.901058521458764, 5.995653507759814, 4.990514432497622, 4.019810799137197, 3.038685722638003, 3.9453515541240143, 4.956231441638239, 5.929375372862346, 6.871510166466763, 7.835627996764346, 8.766282932183827, 9.743490471092633, 10.668663929829675, 11.607624164908543, 12.554232705239075, 11.733016458377906, 10.744094310200065, 9.804710874898154, 8.877371886804168, 7.935137744286172, 6.920369996275736, 4.973830474063565, 3.9963901879235655, 3.05227052184064, 2.010940867916729, 3.011608906831602, 3.9852367764677257, 4.967468826818434, 5.9407847476032964, 6.906664199487247, 7.903797412265756, 8.83851808341641, 9.817344254836378, 10.76356002500193, 11.835243543729328, 10.775783229087768, 9.824974682392662, 8.84066128167014, 7.846662265020606, 6.881717417166618, 5.903665263603377, 4.017772637416959, 3.0898195254713166, 2.071926650996373, 1.033306893478176, 2.0806946193519105, 3.134074263109845, 4.005631259887925, 4.95107704765983, 5.982177816998355, 6.907299147250361, 7.8871685251188834, 8.891917835364303, 9.96291241122163, 10.92735310471759, 9.892409245337817, 8.943216979953167, 7.901862521931744, 6.975048693418402, 6.000795380993376, 4.973378015809875, 3.1312615530314067, 2.125296996127524, 1.0719120016507901, 0.0, 1.0653087881577763, 2.07506034353448, 3.0583692930655055, 4.0855197358533655, 5.0545364518966505, 6.074347098644406, 7.042373736872691, 7.96790006701232, 8.95497739853683, 9.997719521802127, 9.178164070920692, 8.134761124607964, 7.18216185002466, 6.193461466729982, 5.14374234378057, 4.1741729885330034, 4.028701469351806, 2.977911656707109, 1.9573293134169347, 0.9892098136580818, 2.018128350248129, 3.021102215677297, 3.969753939276976, 4.9074283353753065, 5.959602764606718, 6.988793498355116, 8.016247624521988, 8.94847452638966, 9.891163124492452, 10.905948045198684, 9.989951806207769, 8.965686862148456, 7.981979355209788, 6.9932919781252085, 5.9527473593824745, 5.00617791884852, 4.930188397235401, 3.988663016389841, 2.960283636887006, 1.985506643889046, 2.9108681398740783, 3.9069143977978444, 4.869837530661878, 5.887828857529749, 6.843118748628361, 7.811796571421786, 8.770441570492943, 9.82204816269861, 10.844775700879648, 11.874433704567098, 10.947634256914842, 9.886967480243113, 8.872814769617454, 7.858274043170798, 6.9143682638816735, 5.877207610108102, 5.989433029578584, 5.007411450256203, 3.9549348033193534, 2.9163769591018713, 3.929459247530939, 4.838940767517432, 5.8439014507287865, 6.8433193462959805, 7.90071568956925, 8.816952376169862, 9.77385742704363, 10.805621571392528, 11.782073553410175, 12.821902306212344, 11.836795163570546, 10.844222016229141, 9.864597703191974, 8.905641070958454, 7.871573899719238, 6.885124901558059, 6.906278117647938, 5.960457288550492, 4.912831171196488, 3.8890428620089983, 4.820904853922024, 5.839705416530554, 6.774242297644426, 7.797153152446566, 8.769597003330286, 9.76999924795053, 10.727422062330309, 11.749554876375162, 12.710079349717097, 13.722500256450505, 12.7794767098144, 11.817158378676986, 10.857863805692185, 9.827969930007093, 8.842654390137332, 7.927976339557807, 7.872384765917217, 6.891676622901274, 5.8979787414293785, 4.962985279462772, 5.8022640377711845, 6.7974991908661675, 7.741787389196538, 8.763604171973196, 9.768635911971927, 10.699057344193857, 11.743270961527077, 12.70600370189602, 13.641561112846649, 14.602218347390684, 13.739843723073955, 12.764208074267858, 11.813045713227408, 10.81691928443746, 9.768335422327526, 8.822382074471893, 8.885242670522558, 7.870658874817592, 6.918442732165272, 5.967006203532892, 6.865856619812064, 7.724631388043234, 8.715354883705224, 9.759668757763432, 10.810774484422684, 11.735007583243933, 12.75801567026064, 13.665141360693777, 14.610151483746359, 15.589394266279943, 14.667675396376326, 13.648259432326407, 12.629032448352378, 11.688180118908983, 10.743613202574624, 9.777614998199745, 9.896469568415773, 8.889232161361614, 7.928580196695698, 6.967976608963906, 7.8273539441326845, 8.666947289305408, 9.65027470385134, 10.6701738399914, 11.6119292454769, 12.657334733652107, 13.72890188351738, 14.652125215427386, 15.53812630269281, 15.718714838720683, 14.737452971399883, 13.812879488443672, 13.421676526339189, 12.700167002520043, 11.763072949873404, 10.704453438921588], [12.551550515642012, 13.510525770914942, 13.727779155477531, 12.853933965335276, 11.825699325704228, 12.764106441352133, 13.73954818432016, 14.754432289047791, 14.648964908020861, 13.782354400717704, 12.744420797104118, 11.754003442752861, 10.688950718302683, 9.680558285366875, 8.710084744743858, 7.969584918734746, 8.860785218286349, 9.758079492589339, 10.70229609165807, 11.729033688008176, 13.570456293288588, 13.748502860909344, 12.737266277173529, 11.855520290302902, 10.79566989652507, 11.784904523034879, 12.789421480699971, 13.781417294493618, 14.781054273318295, 14.578593878042398, 13.625198189612519, 12.665156115907369, 11.606346176180349, 10.589919003763079, 9.637212740314512, 8.975465723283383, 9.786232895775653, 10.71455474043983, 11.750386087490599, 12.787795295895421, 13.655806547494345, 12.714651407671454, 11.757891815842864, 10.866857062688975, 9.868016629881645, 10.814950469092844, 11.786691381364452, 12.808579890791396, 13.76461708161219, 14.742332809339233, 14.538842145967209, 13.608049157178039, 12.555778927606797, 11.559804093169102, 10.585505319907341, 9.957958252565875, 10.859167162295437, 11.727956585465098, 12.675784238573765, 13.627613568245598, 12.689507446087875, 11.753984096778385, 10.774047894532785, 9.845438875028135, 8.80617936347876, 9.831621322401467, 10.780102099854039, 11.771210634256262, 12.748698627820897, 13.683657089694417, 14.541504577494766, 14.473992113837735, 13.510088832741609, 12.547540392385859, 11.605411275848935, 10.969034521152254, 11.788201072798095, 12.723319148604805, 13.66161842691821, 13.712137160034029, 11.763931794664261, 10.814970174800736, 9.786665118771094, 8.833419887974516, 7.82391744171842, 8.889725611633622, 9.890785582925998, 10.776946474395679, 11.756572517696524, 12.617118453849722, 13.486288850162714, 14.427654982688507, 14.498424628899283, 13.519693592721051, 12.584240522078517, 12.030179383258043, 12.787296934551911, 13.716160284329113, 13.61799487631695, 12.768241069492385, 10.768351565573838, 9.789902914226206, 8.84066501779118, 7.91527810014734, 6.881354605098043, 7.90893439227333, 8.846109846064394, 9.814639607261215, 10.824619160061339, 11.568177065921807, 12.51432395757728, 13.466725358834925, 14.457244330373086, 14.487912507021129, 13.510102137095998, 12.999065852026453, 13.807537307444056, 13.694948392199338, 12.670312848859387, 11.707569569438819, 9.82432082277879, 8.810154550259824, 7.848972073667706, 6.8878604391318445, 5.910582867447151, 6.9613728751206185, 7.890817991736968, 8.854823644616843, 9.816247852224238, 10.626423157999845, 11.553205403196102, 12.482313026267152, 13.464480867438716, 14.45439827367567, 14.462582060525037, 14.06627965874522, 13.760157067909915, 12.719086454799443, 11.710694161243051, 10.778139239675978, 8.813089449494198, 7.844065776348052, 6.86666099651627, 5.8567834935503615, 4.885227018567755, 5.935222048183623, 6.9145265448460895, 7.873441660683679, 8.853328087338918, 9.684949121389188, 10.591899698221983, 11.615227727665527, 12.491908881342477, 13.450712566561174, 14.377829387886917, 13.74664605682096, 12.817059456720322, 11.8781041323683, 10.827049917211118, 9.841053009801433, 7.843670308857323, 6.823468981900154, 5.829768298740717, 4.901730707562693, 3.9544663900687227, 4.945252290189634, 5.881533387420274, 6.869393638676089, 7.833964274695594, 8.646734621339107, 9.579856506510211, 10.592864895047532, 11.528022620106734, 12.422644413895616, 13.451955582802592, 12.737714474900946, 11.838908680194729, 10.903162258215701, 9.926440946965373, 8.893033845818833, 6.905590606097098, 5.900451530834906, 4.929747897474481, 3.9486228209752876, 2.9907339383814113, 4.001613825895635, 4.950579238003659, 5.892714031608076, 6.77031920860657, 7.700974144026052, 8.678181682934857, 9.6033551416719, 10.542315376750768, 11.4889239170813, 12.475910509314227, 11.775596770436538, 10.836213335134627, 9.908874347040637, 8.966640204522644, 7.9518724565122065, 6.005332934300036, 5.027892648160036, 4.083772982077111, 3.0424433281531997, 2.056991291088999, 3.024799150500013, 3.902160038660658, 4.87547595944552, 5.841355411329471, 6.838488624107979, 7.773209295258635, 8.752035466678603, 9.698251236844154, 10.769934755571553, 11.80728568932424, 10.856477142629135, 9.872163741906613, 8.878164725257076, 7.913219877403089, 6.9351677238398475, 5.04927509765343, 4.121321985707787, 3.103429111232844, 2.064809353714647, 1.017421627840912, 2.0687654749520688, 2.9403224717301484, 3.8857682595020537, 4.916869028840579, 5.841990359092585, 6.821859736961107, 7.826609047206527, 8.897603623063853, 9.903213378437119, 10.92391170557429, 9.97471944018964, 8.933364982168216, 8.006551153654874, 7.0322978412298465, 6.0048804760463454, 4.196570341189183, 3.1906057842853, 2.1372207898085662, 1.0653087881577763, 0.0, 1.0097515553767038, 1.9930605049077292, 3.020210947695589, 3.9892276637388737, 5.009038310486629, 5.977064948714914, 6.902591278854543, 7.889668610379052, 8.932410733644348, 10.002841747402602, 9.200069912765741, 8.247470638182437, 7.258770254887757, 6.209051131938346, 5.23948177669078, 5.065564389986005, 4.014774577341307, 2.994192234051133, 2.0260727342922804, 0.952819562090353, 1.9557934275195206, 2.9044451511191998, 3.8421195472175302, 4.8942939764489415, 5.923484710197339, 6.950938836364211, 7.883165738231883, 8.825854336334675, 9.840639257040907, 10.864572811138057, 10.002549782782655, 9.018842275843987, 8.030154898759408, 6.989610280016674, 6.043040839482718, 5.833188563254291, 4.891663182408731, 3.845201901389461, 2.8490070721505316, 1.9236455761654994, 2.9196918340892655, 3.8826149669532994, 4.822520069371972, 5.7778099604705835, 6.746487783264008, 7.705132782335166, 8.756739374540834, 9.77946691272187, 10.847377816892969, 11.774177264545225, 10.789967646262003, 9.775814935636344, 8.761274209189688, 7.817368429900563, 6.780207776126992, 6.892433195597474, 5.892329714758659, 4.839853067821809, 3.779877387363357, 2.949573950698797, 3.8517182038088533, 4.856678887020207, 5.7826826139803895, 6.837854775878552, 7.751643588012086, 8.708548638885853, 9.74031278323475, 10.7167647652524, 11.756593518054569, 12.72561615848525, 11.74722218224803, 10.767597869210864, 9.808641236977344, 8.774574065738129, 7.7881250675769484, 7.7911963821503925, 6.845375553052947, 5.797749435698943, 4.752543290270483, 3.953321392634165, 4.926521841372614, 5.861058722486485, 6.746029229957068, 7.718473080840787, 8.71887532546103, 9.662113274172532, 10.684246088217385, 11.64477056155932, 12.657191468292728, 13.657225408896934, 12.720158544695876, 11.760863971711075, 10.730970096025983, 9.745654556156222, 8.812894604060261, 8.757303030419672, 7.776594887403729, 6.773506232349726, 5.826485707724257, 4.934680576483325, 5.899736180981896, 6.844024379312266, 7.808462210587844, 8.78051927995812, 9.71094071218005, 10.6779621733693, 11.640694913738242, 12.576252324688872, 13.536909559232907, 14.50803393274997, 13.667208240286747, 12.716045879246298, 11.701837548939915, 10.65325368682998, 9.707300338974347, 9.770160935025014, 8.755577139320048, 7.79397022308562, 6.8305066317943774, 5.998273158524205, 6.826868378158962, 7.817591873820953, 8.80452679637808, 9.833454704938742, 10.746890951230126, 11.692706882102863, 12.599832572535998, 13.54484269558858, 14.524085478122164, 14.725130549510414, 13.82680422955468, 13.513950712854832, 12.573098383411438, 11.628531467077078, 10.6625332627022, 10.776444638017137, 9.764759652281962, 8.804107687616046, 7.831477037225391, 6.959770482844825, 7.769184279421138, 8.752511693967069, 9.772410830107129, 10.714166235592629, 11.759571723767836, 12.712190255350402, 13.586816427269607, 14.47281751453503, 14.76409722297808, 13.78283535565728, 12.85826187270107, 13.847527211787309, 13.585085267022498, 12.647991214375859, 11.589371703424042], [13.559434944266448, 14.518410199539378, 14.659463329147965, 13.78561813900571, 12.757383499374662, 12.170139432233917, 13.056512764995917, 14.071396869723547, 13.639213352644159, 12.772602845341, 11.7373848407773, 10.746967486426044, 9.717558931516113, 8.759659942849249, 7.789186402226233, 8.777664022347128, 9.73504950132072, 10.759422098548995, 11.710180520282506, 12.736918116632612, 14.578340721913024, 14.680187034579777, 13.668950450843962, 12.787204463973335, 11.727354070195503, 11.190937513916662, 12.106386061375728, 13.036248335342341, 13.783436686046151, 13.633848381969818, 12.680452693539939, 11.744257773389744, 10.685447833662725, 9.669020661245455, 8.716314397796888, 9.783544826895765, 10.660497178810024, 11.588819023474201, 12.644069947720718, 13.689195194873967, 14.587490721164778, 13.646335581341887, 12.689575989513298, 11.798541236359409, 10.799700803552078, 10.151337785017114, 11.103655962040209, 11.9769554518676, 12.766999494340046, 13.732581253962527, 13.617943803449585, 12.687150814660415, 11.634880585089173, 10.638905750651478, 9.664606977389717, 10.60324001291584, 11.553098746120586, 12.602220868499469, 13.569468098803885, 14.521297428475718, 13.621191619758308, 12.685668270448819, 11.705732068203218, 10.777123048698568, 9.737863537149194, 9.168008638325738, 10.097066680529796, 10.909887291878045, 11.751081040548753, 12.673905534317711, 13.53175302211806, 13.55309377132011, 12.589190490223984, 11.626642049868234, 10.68451293333131, 11.61431628150222, 12.482132656623245, 13.417250732429954, 14.410829885591493, 14.643821333704462, 12.695615968334694, 11.74665434847117, 10.718349292441527, 9.76510406164495, 8.755601615388853, 8.112049945161734, 9.043096609470043, 9.846019719175386, 10.75895493042438, 11.607366898473016, 12.476537294786008, 13.417903427311801, 13.577526286381659, 12.598795250203427, 11.663342179560892, 12.675461143608008, 13.481228518377058, 14.410091868154261, 14.549679049987382, 13.699925243162818, 11.70003573924427, 10.721587087896639, 9.772349191461613, 8.846962273817773, 7.813038778768476, 7.061245418817375, 7.998420872608438, 8.883712852040922, 9.827001572789195, 10.558425510545101, 11.504572402200575, 12.456973803458219, 13.44749277499638, 13.567014164503505, 12.589203794578374, 13.568441317276179, 14.49577431816117, 14.626632565869771, 13.60199702252982, 12.639253743109252, 10.756004996449223, 9.741838723930258, 8.78065624733814, 7.819544612802278, 6.8422670411175845, 6.090931976738257, 6.966855185668929, 7.845072089240139, 8.806496296847534, 9.61667160262314, 10.543453847819398, 11.472561470890447, 12.454729312062012, 13.444646718298966, 13.541683718007413, 14.49586286526413, 14.691841241580349, 13.650770628469877, 12.642378334913484, 11.709823413346411, 9.744773623164631, 8.775749950018486, 7.798345170186703, 6.788467667220795, 5.816911192238188, 5.064781149801261, 5.99056373877805, 6.863690105306975, 7.8435765319622135, 8.675197566012482, 9.582148142845279, 10.605476172288823, 11.482157325965773, 12.44096101118447, 13.368077832510213, 14.339074997418354, 13.748743630390756, 12.809788306038733, 11.758734090881552, 10.772737183471866, 8.775354482527757, 7.7551531555705875, 6.76145247241115, 5.833414881233126, 4.8861505637391565, 4.022450040326175, 4.924034846768064, 5.859642083299385, 6.82421271931889, 7.636983065962402, 8.570104951133507, 9.583113339670827, 10.51827106473003, 11.412892858518912, 12.442204027425888, 13.424103096105794, 12.848660235571431, 11.912913813592406, 10.858125120635806, 9.824718019489266, 7.837274779767531, 6.83213570450534, 5.8614320711449155, 4.880306994645721, 3.922418112051845, 3.0788115760321766, 3.9408276826269546, 4.882962476231372, 5.760567653229866, 6.691222588649348, 7.668430127558153, 8.593603586295195, 9.532563821374064, 10.479172361704595, 11.466158953937523, 12.461985391641386, 11.845964890511329, 10.918625902417341, 9.912734232410168, 8.897966484399731, 7.015084489676739, 6.002828830948463, 5.058709164865538, 3.989343503674306, 2.988675464759433, 2.0150475951233093, 2.8924084832839543, 3.8657244040688163, 4.831603855952767, 5.828737068731275, 6.7634577398819316, 7.742283911301899, 8.688499681467452, 9.76018320019485, 10.825894762636658, 11.776703309331763, 10.881915297283316, 9.88791628063378, 8.922971432779793, 7.944919279216551, 6.059026653030133, 5.131073541084491, 4.113180666609548, 3.0745609090913506, 2.0271731832176156, 1.0590139195753647, 1.9305709163534446, 2.87601670412535, 3.9071174734638756, 4.832238803715882, 5.812108181584404, 6.816857491829824, 7.88785206768715, 8.893461823060415, 9.928405682440188, 10.877597947824837, 9.943116537544919, 9.016302709031576, 8.042049396606549, 7.014632031423049, 5.206321896565886, 4.200357339662004, 3.1469723451852705, 2.07506034353448, 1.0097515553767038, 0.0, 0.9833089495310253, 2.0104593923188854, 2.97947610836217, 3.9992867551099254, 4.967313393338211, 5.89283972347784, 6.879917055002348, 7.9226591782676445, 8.9930901920259, 10.036493138338628, 9.25722219355914, 8.268521810264462, 7.2188026873150495, 6.249233332067483, 6.073448818610441, 5.022659005965743, 4.002076662675569, 3.0339571629167166, 1.9607039907147894, 0.9460418721428169, 1.894693595742496, 2.832367991840826, 3.8845424210722372, 4.913733154820635, 5.941187280987506, 6.873414182855179, 7.816102780957972, 8.830887701664205, 9.854821255761355, 10.879086199820668, 10.026726704468423, 9.038039327383844, 7.99749470864111, 7.050925268107155, 6.841072991878727, 5.899547611033167, 4.853086330013897, 3.856891500774968, 2.9315300047899355, 1.9987934915716403, 2.9342289846457703, 3.8127685139952683, 4.76805840509388, 5.736736227887305, 6.695381226958463, 7.74698781916413, 8.769715357345166, 9.837626261516265, 10.76442570916852, 11.797852074886439, 10.78369936426078, 9.769158637814124, 8.825252858525, 7.788092204751428, 7.90031762422191, 6.900214143383095, 5.847737496446245, 4.787761815987793, 3.957458379323233, 2.930819861291228, 3.9082929047126784, 4.772931058603686, 5.828103220501848, 6.741892032635382, 7.69879708350915, 8.730561227858047, 9.707013209875694, 10.746841962677863, 11.715864603108546, 12.708437750449951, 11.7754822978353, 10.81652566560178, 9.782458494362563, 8.796009496201384, 8.799080810774829, 7.853259981677383, 6.805633864323379, 5.76042771889492, 4.961205821258601, 4.005623498854989, 4.9130036408937645, 5.736277674580364, 6.7087215254640835, 7.709123770084326, 8.652361718795827, 9.674494532840681, 10.635019006182615, 11.647439912916024, 12.64747385352023, 13.609792184657644, 12.76874840033551, 11.738854524650417, 10.753538984780656, 9.820779032684698, 9.765187459044109, 8.784479316028166, 7.7813906609741625, 6.834370136348693, 5.942565005107761, 4.978837838464271, 5.923126036794641, 6.79871065521114, 7.770767724581417, 8.701189156803348, 9.668210617992596, 10.630943358361538, 11.566500769312167, 12.527158003856202, 13.498282377373267, 14.473918026179364, 13.723930307870733, 12.709721977564351, 11.661138115454417, 10.715184767598783, 10.77804536364945, 9.763461567944486, 8.801854651710055, 7.838391060418814, 6.880454763351134, 5.905970035641337, 6.8966935313033275, 7.794775241001377, 8.82370314956204, 9.737139395853424, 10.682955326726159, 11.590081017159296, 12.535091140211877, 13.514333922745461, 14.131163540392198, 14.758488403225114, 14.521835141479269, 13.580982812035874, 12.636415895701514, 11.670417691326636, 11.784329066641574, 10.772644080906398, 9.811992116240482, 8.790247269775772, 7.841952087671754, 6.848285936903513, 7.831613351449443, 8.765374873780312, 9.707130279265812, 10.75253576744102, 11.702438699973698, 12.577064871892905, 13.463065959158328, 14.081061803653837, 13.188868346539063, 13.789946046371503, 14.779211385457742, 14.592969695646934, 13.655875643000295, 12.597256132048479], [14.526968333042287, 15.485943588315218, 15.480374510926094, 14.606529320783837, 13.578294681152789, 12.991050614012044, 12.103848804740322, 13.102587341673306, 12.709443294220641, 11.842832786917482, 10.807614782353781, 9.817197428002524, 8.787788873092593, 7.893624040060632, 8.70133336695536, 9.689810987076257, 10.647196466049849, 11.671569063278124, 12.647590610066969, 13.674328206417076, 15.545874110688864, 15.501098216357907, 14.48986163262209, 13.608115645751463, 12.54826525197363, 12.01184869569479, 11.153722101120133, 12.052939385811316, 12.800127736515126, 12.704078323546298, 11.75068263511642, 10.879477216815587, 9.824862997202995, 8.856087630388005, 9.628461362526014, 10.695691791624894, 11.572644143539152, 12.50096598820333, 13.556216912449846, 14.601342159603096, 15.408401902942908, 14.467246763120016, 13.510487171291425, 12.619452418137536, 11.620611985330205, 10.972248966795242, 10.150992001784614, 10.993646502336574, 11.783690544809021, 12.749272304431502, 12.771528328580864, 11.879262526755447, 10.840078622878528, 9.91196355203589, 10.576753942118843, 11.515386977644967, 12.465245710849713, 13.514367833228597, 14.481615063533013, 15.433444393204846, 14.442102801536434, 13.506579452226944, 12.526643249981346, 11.598034230476696, 10.558774718927321, 9.988919820103865, 9.1444027202742, 9.92657834234702, 10.767772091017727, 11.690596584786686, 12.548444072587035, 12.763504793902662, 11.799601512806536, 10.899699851252647, 11.596659898060437, 12.526463246231346, 13.394279621352371, 14.32939769715908, 15.32297685032062, 15.464732515482588, 13.51652715011282, 12.567565530249295, 11.539260474219653, 10.586015243423077, 9.57651279716698, 8.932961126939862, 8.090432649214447, 8.86271076964436, 9.775645980893355, 10.62405794894199, 11.493228345254982, 12.434594477780776, 12.78793730896421, 11.87185305158784, 12.57548914429002, 13.587608108337134, 14.393375483106187, 15.32223883288339, 15.37059023176551, 14.520836424940946, 12.520946921022398, 11.542498269674764, 10.593260373239739, 9.667873455595899, 8.633949960546603, 7.882156600595502, 7.045756912352843, 7.900403902509897, 8.84369262325817, 9.575116561014076, 10.52126345266955, 11.473664853927193, 12.464183825465355, 12.889992566836018, 13.5013507593075, 14.480588282005305, 15.407921282890296, 15.447543747647899, 14.422908204307948, 13.46016492488738, 11.57691617822735, 10.562749905708385, 9.601567429116267, 8.640455794580404, 7.663178222895712, 6.911843158516384, 5.983546236137903, 6.8617631397091134, 7.823187347316509, 8.633362653092114, 9.560144898288373, 10.489252521359422, 11.471420362530987, 12.46133776876794, 13.458127351094294, 14.409825232943103, 15.341926912756309, 14.471681810248004, 13.463289516691612, 12.530734595124539, 10.565684804942759, 9.596661131796612, 8.61925635196483, 7.609378848998922, 6.637822374016316, 5.8856923315793885, 5.007254789247024, 5.880381155775949, 6.860267582431188, 7.691888616481457, 8.598839193314253, 9.622167222757799, 10.498848376434747, 11.457652061653445, 12.384768882979188, 13.355766047887329, 14.285352647987967, 13.63069948781686, 12.579645272659679, 11.593648365249994, 9.596265664305884, 8.576064337348715, 7.582363654189278, 6.654326063011253, 5.707061745517284, 4.843361222104303, 3.9407258972370385, 4.87633313376836, 5.8409037697878645, 6.653674116431376, 7.586796001602481, 8.599804390139804, 9.534962115199004, 10.429583908987887, 11.458895077894862, 12.440794146574769, 13.368511729270333, 12.745853919231147, 11.679036302413934, 10.645629201267393, 8.658185961545659, 7.653046886283468, 6.682343252923043, 5.701218176423849, 4.743329293829973, 3.899722757810304, 2.957518733095929, 3.8996535267003463, 4.77725870369884, 5.707913639118322, 6.685121178027128, 7.610294636764171, 8.549254871843038, 9.49586341217357, 10.482850004406497, 11.47867644211036, 12.418059877412272, 11.758338581031028, 10.733645414188295, 9.718877666177859, 7.858412546550197, 6.8237400127265895, 5.879620346643664, 4.810254685452433, 3.8095866465375603, 2.8359587769014367, 1.9090995337529288, 2.882415454537791, 3.8482949064217418, 4.845428119200251, 5.780148790350906, 6.758974961770874, 7.705190731936425, 8.776874250663825, 9.842585813105632, 10.793394359800738, 11.755416425082256, 10.743794348955204, 9.778849501101217, 8.800797347537975, 6.981526338847235, 6.053573226901593, 5.03568035242665, 3.9970605949084526, 2.9496728690347176, 1.8799251013534921, 0.9472619668224193, 1.8927077545943245, 2.92380852393285, 3.8489298541848562, 4.828799232053378, 5.833548542298798, 6.904543118156124, 7.910152873529389, 8.945096732909162, 9.894288998293812, 10.865616223362021, 9.938802394848679, 8.964549082423652, 7.937131717240151, 6.189630846096912, 5.183666289193029, 4.130281294716296, 3.0583692930655055, 1.9930605049077292, 0.9833089495310253, 0.0, 1.0271504427878602, 1.996167158831145, 3.0159778055789, 3.9840044438071853, 4.909530773946814, 5.896608105471323, 6.939350228736619, 8.009781242494874, 9.053184188807602, 10.005783463390907, 9.251830759795487, 8.202111636846075, 7.2325422815985085, 7.040982207386279, 5.990192394741582, 4.969610051451408, 4.001490551692555, 2.9282373794906285, 1.9135752609186558, 0.9649235373189767, 1.902597933417307, 2.9547723626487183, 3.9471022642029467, 4.974556390369818, 5.890105233324154, 6.8327938314269465, 7.847578752133178, 8.871512306230327, 9.89577725028964, 10.879484757228308, 10.005572716159682, 8.965028097416948, 8.018458656882993, 7.808606380654565, 6.867080999809005, 5.820619718789736, 4.824424889550807, 3.8990633935657746, 2.966326880347479, 2.004458926222251, 2.8829984555717494, 3.8382883466703612, 4.806966169463786, 5.765611168534944, 6.817217760740611, 7.8399452989216485, 8.871599235732313, 9.798398683384569, 10.82168520340203, 11.751232753036618, 10.736692026589962, 9.792786247300837, 8.755625593527267, 8.867851012997749, 7.867747532158933, 6.815270885222084, 5.755295204763632, 4.924991768099073, 3.898353250067067, 2.978522846289159, 3.843161000180167, 4.8983331620783295, 5.8121219742118635, 6.769027025085631, 7.800791169434528, 8.777243151452176, 9.817071904254345, 10.749837577324595, 11.742410724666, 12.722035037703167, 11.784059054377618, 10.749991883138403, 9.763542884977223, 9.766614199550668, 8.820793370453222, 7.773167253099218, 6.727961107670759, 5.928739210034441, 4.917770463584116, 3.983233582470245, 4.8065076161568445, 5.778951467040564, 6.779353711660806, 7.722591660372309, 8.744724474417163, 9.705248947759097, 10.717669854492506, 11.717703795096712, 12.680022126234126, 13.716582947195544, 12.706387913426257, 11.721072373556495, 10.788312421460537, 10.732720847819948, 9.752012704804004, 8.748924049750002, 7.801903525124533, 6.886219956288381, 5.890984803193398, 5.057090134006025, 5.8689405967876205, 6.8409976661578975, 7.771419098379829, 8.738440559569078, 9.70117329993802, 10.63673071088865, 11.597387945432684, 12.568512318949749, 13.544147967755846, 14.495310328796295, 13.67725536634019, 12.628671504230256, 11.682718156374623, 11.745578752425288, 10.730994956720323, 9.769388040485895, 8.805924449194654, 7.79260172808026, 6.818117000370464, 6.030657628514711, 6.865005182577857, 7.8939330911385195, 8.807369337429904, 9.75318526830264, 10.660310958735778, 11.60532108178836, 12.584563864321943, 13.548136524157265, 14.499618084261781, 15.489368530255108, 14.548516200811713, 13.603949284477354, 12.637951080102475, 12.721739156426036, 11.71005417069086, 10.749402206024945, 9.702394234504899, 8.754099052400882, 7.760432901632639, 6.965577448660827, 7.835604815356792, 8.777360220842292, 9.8227657090175, 10.77266864155018, 11.647294813469387, 12.53329590073481, 13.128397843398242, 14.00977952831719, 14.61085722814963, 15.60012256723587, 15.560503084422773, 14.623409031776134, 13.564789520824318], [15.45346535434838, 16.41244060962131, 16.50752495371395, 15.633679763571696, 14.605445123940648, 13.992274910713311, 13.001109423818681, 12.286866441039878, 11.760591523330067, 10.89398101602691, 9.85876301146321, 8.868345657111954, 7.838937102202022, 8.778439514728316, 9.59866648455353, 10.587144104674426, 11.544529583648018, 12.568902180876293, 13.544923727665138, 14.571661324015245, 16.472371131994954, 16.528248659145763, 15.517012075409948, 14.635266088539321, 13.575415694761489, 13.013072992396056, 12.050982720198492, 11.237218485177888, 11.901971426464424, 11.755226552655728, 10.801830864225849, 9.930625445925017, 8.876011226312425, 9.740903105055688, 10.525794480124183, 11.593024909223063, 12.469977261137322, 13.398299105801499, 14.453550030048016, 15.498675277201265, 16.435552345730766, 15.494397205907873, 14.537637614079284, 13.646602860925395, 12.647762428118064, 11.973473263496508, 11.048252620862973, 10.177925601703146, 10.88553423475832, 11.845955260994714, 11.822676557690293, 10.930410755864877, 9.891226851987957, 10.796779026703573, 11.474087059717013, 12.412720095243136, 13.362578828447882, 14.411700950826766, 15.378948181131182, 16.330777510803017, 15.469253244324294, 14.533729895014805, 13.553793692769204, 12.625184673264554, 11.58592516171518, 10.990144116805132, 10.04166333935256, 9.110857441713591, 9.869615780967026, 10.787279541349898, 11.645127029150247, 11.814653023012092, 10.850749741915966, 11.78451532592033, 12.493993015658607, 13.423796363829515, 14.29161273895054, 15.22673081475725, 16.22030996791879, 16.49188295827045, 14.54367759290068, 13.594715973037156, 12.566410917007513, 11.613165686210936, 10.60366323995484, 9.960111569727722, 8.987693268292807, 8.046989869010932, 8.877489670842653, 9.720740905505203, 10.589911301818194, 11.531277434343988, 11.83908553807364, 12.756668526255522, 13.472822261888188, 14.484941225935303, 15.290708600704356, 16.21957195048156, 16.39774067455337, 15.547986867728806, 13.548097363810259, 12.569648712462625, 11.620410816027599, 10.69502389838376, 9.661100403334462, 8.909307043383363, 8.05321276307329, 7.084683001876469, 7.945536313207468, 8.671799517577288, 9.617946409232761, 10.570347810490405, 11.560866782028567, 12.489825730363691, 13.467636100288821, 14.446873622986626, 15.374206623871617, 16.358898403416735, 15.450058647095808, 14.48731536767524, 12.60406662101521, 11.589900348496245, 10.628717871904128, 9.667606237368265, 8.690328665683571, 7.938993601304245, 7.010696678925764, 6.046042239075685, 6.925031037265806, 7.730045609655325, 8.656827854851583, 9.585935477922632, 10.568103319094197, 11.55802072533115, 12.554810307657505, 13.506508189506313, 14.438609869319519, 15.38303646601684, 14.490439959479472, 13.5578850379124, 11.59283524773062, 10.623811574584472, 9.646406794752691, 8.636529291786783, 7.664972816804175, 6.912842774367249, 6.034405232034885, 5.06466025514252, 5.962111272380485, 6.788571573044667, 7.695522149877464, 8.718850179321008, 9.595531332997957, 10.554335018216655, 11.481451839542398, 12.45244900445054, 13.382035604551177, 14.3209909289032, 13.60679571544754, 12.620798808037854, 10.623416107093744, 9.603214780136575, 8.609514096977138, 7.681476505799113, 6.734212188305143, 5.870511664892163, 4.967876340024899, 4.060612233134931, 4.942747459737162, 5.7503570729945865, 6.683478958165692, 7.696487346703013, 8.631645071762215, 9.526266865551097, 10.555578034458073, 11.537477103137979, 12.465194685833543, 13.538769724167516, 12.706186745201794, 11.672779644055254, 9.685336404333519, 8.680197329071328, 7.709493695710903, 6.728368619211709, 5.770479736617832, 4.926873200598164, 3.9846691758837895, 3.0839326260669178, 3.8739416602620502, 4.804596595681533, 5.781804134590338, 6.706977593327381, 7.6459378284062485, 8.59254636873678, 9.579532960969708, 10.575359398673571, 11.514742833975482, 12.589001462325001, 11.760795856976156, 10.746028108965719, 8.885562989338057, 7.85089045551445, 6.9067707894315244, 5.8374051282402935, 4.83673708932542, 3.8631092196892967, 2.9362499765407892, 2.032123573625068, 2.9449778629849512, 3.941330868074909, 4.850554123773005, 5.829380295192973, 6.775596065358524, 7.847279584085923, 8.88212721572078, 9.832935762415886, 10.817249163138408, 11.770944791743064, 10.805999943889077, 9.827947790325835, 8.008676781635096, 7.080723669689453, 6.06283079521451, 5.024211037696313, 3.976823311822578, 2.9070755441413523, 1.9744124096102795, 1.0424158736816012, 1.9942138573549486, 2.9193351876069547, 3.8992045654754772, 4.809917593303679, 5.880912169161005, 6.88652192453427, 7.9214657839140425, 8.870658049298692, 9.912012507320116, 10.838826335833458, 9.991699525211512, 8.964282160028011, 7.216781288884772, 6.21081673198089, 5.157431737504155, 4.0855197358533655, 3.020210947695589, 2.0104593923188854, 1.0271504427878602, 0.0, 0.9690167160432847, 1.98882736279104, 2.9568540010193254, 3.8823803311589544, 4.869457662683463, 5.91219978594876, 6.982630799707014, 8.026033746019742, 8.978633020603047, 9.967333403897726, 9.229262079633935, 8.259692724386369, 7.967479228692371, 6.9166894160476735, 5.896107072757499, 4.927987572998647, 3.8547344007967195, 2.840072282224747, 1.8914205586250676, 0.9537461625267373, 1.9559884260104525, 2.919951821415087, 3.9474059475819585, 4.862954790536294, 5.805643388639087, 6.820428309345319, 7.844361863442469, 8.868626807501782, 9.85233431444045, 10.841021691525029, 9.891525118723038, 8.944955678189084, 8.735103401960657, 7.793578021115097, 6.747116740095828, 5.750921910856898, 4.825560414871866, 3.8928239016535704, 2.930955947528342, 1.9341466846811795, 2.889436575779791, 3.8581143985732154, 4.816759397644373, 5.86836598985004, 6.829736791913648, 7.844448792944454, 8.771248240596709, 9.794534760614171, 10.80868747123983, 11.663189047896054, 10.71928326860693, 9.682122614833359, 9.794348034303841, 8.794244553465026, 7.741767906528176, 6.681792226069724, 5.851488789405163, 4.824850271373158, 3.8937271248567904, 2.894309229289597, 3.949481391187759, 4.863270203321292, 5.8201752541950595, 6.851939398543957, 7.767034644444176, 8.806863397246346, 9.722687134536734, 10.71526028187814, 11.694884594915306, 12.653841227148826, 11.676488904444495, 10.690039906283316, 10.69311122085676, 9.747290391759314, 8.699664274405311, 7.6544581289768505, 6.833904143790818, 5.815103581182287, 4.880566700068416, 3.857655845266275, 4.830099696149994, 5.830501940770237, 6.773739889481737, 7.795872703526591, 8.725575581318, 9.737996488051408, 10.737489909343822, 11.688196644325984, 12.694183515329938, 13.632884934732349, 12.647569394862588, 11.71480944276663, 11.65921786912604, 10.678509726110097, 9.675421071056093, 8.728400546430624, 7.7835530738865515, 6.7883179207915685, 5.941905608673708, 4.920088825897051, 5.892145895267328, 6.822567327489259, 7.789588788678505, 8.752321529047446, 9.657057344447551, 10.617714578991587, 11.58883895250865, 12.564474601314748, 13.515636962355197, 14.57134007341819, 13.555168525536349, 12.609215177680715, 12.672075773731382, 11.657491978026416, 10.695885061791985, 9.714963864092942, 8.689934845678431, 7.715450117968635, 6.915473103182395, 5.9161534116872865, 6.94508132024795, 7.858517566539334, 8.804333497412069, 9.711459187845204, 10.656469310897785, 11.63571209343137, 12.568463157716167, 13.519944717820684, 14.537658827791383, 15.475013222117806, 14.530446305783446, 13.564448101408567, 13.619072274024205, 12.60738728828903, 11.646735323623114, 10.599727352103068, 9.651432169999051, 8.65776601923081, 7.85039292332851, 6.8867530444662215, 7.8285084499517215, 8.873913938126929, 9.823816870659607, 10.698443042578813, 11.584444129844236, 12.513862966315981, 13.5107583515693, 14.488487074674294, 15.477752413760534, 16.487000105728864, 15.549906053082227, 14.49128654213041], [16.422482070391666, 17.3814573256646, 16.51495866268393, 15.54381900050907, 14.515584360878021, 13.560470549831162, 12.582813594535457, 11.671492792423665, 10.893540408840924, 10.026929901537766, 9.201664445639864, 8.290648420962446, 8.807953818245307, 9.7474562307716, 10.567683200596814, 11.556160820717711, 12.513546299691303, 13.537918896919578, 14.513940443708423, 15.54067804005853, 17.441387848038243, 17.49726537518905, 16.486028791453233, 15.604282804582606, 14.544432410804774, 13.84866760252774, 12.886577330330176, 11.984717336214548, 10.93295471042114, 11.063737498725594, 10.144732298402502, 9.35292820977551, 9.84502794235571, 10.709919821098973, 11.494811196167468, 12.562041625266348, 13.438993977180607, 14.367315821844784, 15.4225667460913, 16.46769199324455, 17.40456906177405, 16.463413921951158, 15.506654330122569, 14.61561957696868, 13.616779144161349, 12.809067873628193, 11.883847230994657, 10.932180507497414, 9.916517518715034, 10.876938544951429, 11.165577991866947, 10.352713519715369, 10.860243568031242, 11.765795742746858, 12.443103775760298, 13.381736811286421, 14.331595544491167, 15.380717666870051, 16.347964897174467, 17.299794226846302, 16.438269960367577, 15.50274661105809, 14.52281040881249, 13.59420138930784, 12.554941877758464, 11.825738726936816, 10.877257949484244, 9.886149415082022, 8.90059906492374, 9.818262825306613, 10.676110313106962, 11.341078385536017, 11.81976645795925, 12.753532041963615, 13.463009731701892, 14.3928130798728, 15.260629454993826, 16.195747530800535, 17.189326683962076, 17.46089967431373, 15.512694308943965, 14.56373268908044, 13.535427633050798, 12.58218240225422, 11.572679955998124, 10.879304658491206, 9.852163474451869, 8.911460075169995, 7.908472954799368, 8.751724189461918, 9.62089458577491, 10.562260718300703, 11.596878854317051, 12.538948529568584, 13.424480999263018, 14.446743375711751, 15.408452797919487, 16.33731614769669, 17.355725781923578, 16.517003583772095, 14.517114079853545, 13.53866542850591, 12.589427532070884, 11.664040614427044, 10.630117119377747, 9.828500132146846, 8.917682969232352, 7.949153208035531, 6.976519597164183, 7.702782801534003, 8.648929693189476, 9.60133109444712, 10.591850065985282, 11.520809014320406, 12.498619384245536, 13.477856906943341, 14.405189907828332, 15.38988168737345, 16.419075363139093, 15.456332083718527, 13.573083337058497, 12.55891706453953, 11.597734587947413, 10.63662295341155, 9.659345381726856, 8.858186690067727, 7.91656512887237, 6.9105124452347475, 5.956014321222522, 6.76102889361204, 7.687811138808297, 8.616918761879347, 9.599086603050912, 10.589004009287866, 11.58579359161422, 12.537491473463028, 13.469593153276234, 14.414019749973555, 15.422412043529947, 14.526901753955686, 12.561851963773906, 11.592828290627757, 10.615423510795976, 9.605546007830068, 8.63398953284746, 7.849651130823588, 6.940273681981491, 5.9291304613015825, 4.993094556337201, 5.819554857001382, 6.726505433834179, 7.749833463277723, 8.626514616954672, 9.58531830217337, 10.512435123499113, 11.483432288407254, 12.413018888507892, 13.351974212859915, 14.403028428017096, 13.589815524081141, 11.592432823137031, 10.57223149617986, 9.578530813020423, 8.650493221842398, 7.703228904348428, 6.807320021348502, 5.873744789971505, 4.925082439293993, 3.973730743693878, 4.7813403569513016, 5.714462242122407, 6.727470630659728, 7.66262835571893, 8.557250149507812, 9.586561318414788, 10.568460387094694, 11.496177969790258, 12.56975300812423, 13.636570624941443, 12.64179636009854, 10.654353120376806, 9.649214045114615, 8.67851041175419, 7.697385335254994, 6.739496452661117, 5.863681557054504, 4.8905376258303965, 3.9484028322259794, 2.9049249442187657, 3.8355798796382476, 4.812787418547053, 5.737960877284096, 6.6769211123629635, 7.623529652693495, 8.610516244926423, 9.606342682630286, 10.545726117932197, 11.619984746281716, 12.644677913124449, 11.715044825009006, 9.854579705381342, 8.819907171557734, 7.875787505474809, 6.806421844283578, 5.805753805368705, 4.832125935732582, 3.9052666925840738, 2.9418405988256175, 1.9759611469416667, 2.9723141520316245, 3.8815374077297204, 4.860363579149689, 5.80657934931524, 6.878262868042639, 7.913110499677495, 8.8639190463726, 9.848232447095121, 10.859854523222173, 11.775016659932362, 10.79696450636912, 8.97769349767838, 8.049740385732738, 7.031847511257794, 5.993227753739597, 4.945840027865862, 3.876092260184637, 2.943429125653564, 2.011432589724886, 1.025197141311664, 1.95031847156367, 2.9301878494321927, 3.8409008772603936, 4.91189545311772, 5.917505208490985, 6.952449067870758, 7.901641333255406, 8.942995791276829, 9.869809619790171, 10.844062932215198, 9.933298876071296, 8.185798004928058, 7.179833448024175, 6.12644845354744, 5.0545364518966505, 3.989227663738874, 2.9794761083621704, 1.996167158831145, 0.9690167160432847, 0.0, 1.0198106467477552, 1.9878372849760406, 2.91336361511567, 3.900440946640179, 4.9431830699054755, 6.01361408366373, 7.057017029976458, 8.009616304559762, 8.998316687854441, 10.048035810803853, 9.228709440429656, 8.936495944735656, 7.885706132090958, 6.8651237888007834, 5.897004289041931, 4.823751116840004, 3.8090889982680314, 2.860437274668352, 1.922762878570022, 0.9869717099671679, 1.950935105371802, 2.9783892315386735, 3.8939380744930094, 4.836626672595802, 5.851411593302034, 6.875345147399184, 7.899610091458496, 8.883317598397165, 9.872004975481744, 10.860541834766323, 9.913972394232369, 9.70412011800394, 8.76259473715838, 7.7161334561391115, 6.719938626900182, 5.79457713091515, 4.8618406176968545, 3.899972663571626, 2.9031634007244644, 2.051100609418792, 3.013050792713421, 3.9497082831552306, 4.921906693579704, 5.860720075870363, 6.875432076901169, 7.802231524553425, 8.825518044570885, 9.839670755196543, 10.834270241094211, 11.688299984650213, 10.651139330876642, 10.763364750347124, 9.763261269508309, 8.71078462257146, 7.650808942113008, 6.820505505448448, 5.793866987416442, 4.862743840900076, 3.863325945332882, 3.11114542482676, 4.018206597461498, 4.953124139705917, 5.9054801022736205, 6.798017928400891, 7.837846681203061, 8.753670418493451, 9.746243565834856, 10.725867878872023, 11.684824511105543, 12.645505620487778, 11.659056622326599, 11.662127936900045, 10.7163071078026, 9.668680990448594, 8.623474845020134, 7.802920859834103, 6.784120297225572, 5.849583416111701, 4.82667256130956, 4.105536159737225, 5.017280333424648, 5.906688774992595, 6.928821589037449, 7.756558865274714, 8.768979772008123, 9.768473193300538, 10.719179928282701, 11.725166799286654, 12.704000276435998, 13.616586110905871, 12.683826158809914, 12.628234585169325, 11.647526442153382, 10.644437787099376, 9.697417262473907, 8.752569789929836, 7.7573346368348535, 6.910922324716993, 5.889105541940336, 5.167582358854559, 6.083608198929572, 6.922537674189363, 7.885270414558305, 8.688040628404266, 9.648697862948302, 10.619822236465366, 11.595457885271463, 12.546620246311912, 13.602323357374905, 14.524185241579634, 13.578231893724, 13.641092489774667, 12.6265086940697, 11.664901777835269, 10.683980580136227, 9.658951561721716, 8.68446683401192, 7.88448981922568, 6.8851701277305715, 6.220517783835181, 7.119558437979647, 7.937282382922926, 8.844408073356062, 9.700870900459341, 10.680113682992925, 11.599446441672882, 12.550928001777399, 13.568642111748098, 14.509494441191492, 15.454061357525852, 14.533464817451852, 14.58808899006749, 13.576404004332314, 12.615752039666399, 11.568744068146353, 10.620448886042336, 9.626782735274094, 8.819409639371795, 7.8557697605095065, 7.250811213802214, 8.192477095462579, 8.956765756170464, 9.831391928089669, 10.628845719405792, 11.558264555877537, 12.541741635526016, 13.51947035863101, 14.508735697717249, 15.521481324802552, 16.51892276912551, 15.460303258173695], [17.289266168092787, 16.470642664660737, 15.495148015936174, 14.524008353761314, 13.495773714130266, 12.540659903083407, 11.563002947787703, 10.651682145675911, 9.87372976209317, 9.00711925479001, 8.18185379889211, 9.117285046511636, 9.821998277378546, 10.761500689904837, 11.581727659730051, 12.570205279850947, 13.52759075882454, 14.551963356052815, 15.527984902841661, 16.55472249919177, 18.308171945739364, 17.50515995689914, 16.485660894240176, 15.56580975474086, 14.509096447910473, 13.519861821400662, 12.513129651407892, 11.701330101537902, 10.92927556848626, 10.043926851977837, 9.124921651654748, 10.084963725359898, 10.859072401488948, 11.72396428023221, 12.508855655300705, 13.576086084399584, 14.453038436313843, 15.38136028097802, 16.436611205224537, 17.48173645237779, 18.365155711285382, 17.42400057146249, 16.4672409796339, 15.57620622648001, 14.57736579367268, 13.612336940011266, 12.687116297377731, 11.735449573880487, 10.719786585098108, 10.026410595334967, 10.145767345119193, 11.076560333908363, 11.87428802716448, 12.779840201880095, 13.457148234893534, 14.395781270419658, 15.345640003624403, 16.39476212600329, 17.362009356307702, 18.313838685979537, 17.39885660987891, 16.46333326056942, 15.48339705832382, 14.55478803881917, 13.515528527269796, 12.62900779331989, 11.680527015867318, 10.689418481465095, 9.703868131306814, 8.967734875690152, 9.825582363490499, 10.65110246909679, 11.615005750192916, 12.577554190548666, 13.539133582771061, 14.58316391173994, 15.511682538180072, 16.44680061398678, 17.43168148502756, 18.382601417544507, 16.473280958455295, 15.524319338591772, 14.496014282562129, 13.542769051765552, 12.533266605509455, 11.738075979787828, 10.692778482763716, 9.752075083481841, 8.711742021182442, 7.901196239845456, 8.770366636158446, 9.71173276868424, 10.746350904700588, 11.68842057995212, 12.56030433654148, 13.582566712990213, 14.544276135197949, 15.473139484975151, 16.48581870316464, 17.412382601598473, 15.477700729364877, 14.499252078017241, 13.550014181582215, 12.624627263938375, 11.590703768889078, 10.695473431335262, 9.7582979775442, 8.789768216347378, 7.779788663547255, 6.85225485191754, 7.798401743573013, 8.750803144830657, 9.741322116368819, 10.670281064703943, 11.634442721523998, 12.613680244221802, 13.528016004392033, 14.486050893854188, 15.538136675707076, 16.351711101544907, 14.533669986569828, 13.519503714050861, 12.558321237458744, 11.59720960292288, 10.619932031238188, 9.760458766810528, 8.818837205615171, 7.812784521977548, 6.853045315187561, 5.910500943995578, 6.837283189191835, 7.766390812262885, 8.74855865343445, 9.685173215768605, 10.68196279809496, 11.633660679943768, 12.565762359756974, 13.510188956454293, 14.518581250010685, 15.422280771782066, 13.522438613285237, 12.553414940139088, 11.576010160307307, 10.566132657341399, 9.594576182358791, 8.751923207566389, 7.842545758724292, 6.831402538044383, 5.8901255503022405, 4.96902690738492, 5.875977484217716, 6.846002669758464, 7.722683823435414, 8.68148750865411, 9.608604329979853, 10.579601494887994, 11.509188094988632, 12.448143419340655, 13.499197634497836, 14.485194541907521, 12.553019472648362, 11.532818145691191, 10.539117462531754, 9.611079871353729, 8.66381555385976, 7.709592098091303, 6.776016866714306, 5.827354516036793, 4.870761737658917, 3.930812407334839, 4.863934292505944, 5.823639837140469, 6.75879756219967, 7.653419355988552, 8.682730524895527, 9.664629593575434, 10.592347176270998, 11.66592221460497, 12.732739831422183, 13.602383009609872, 11.614939769888137, 10.609800694625946, 9.63909706126552, 8.657971984766325, 7.7000831021724485, 6.765953633797304, 5.792809702573197, 4.85067490896878, 3.807197020961566, 2.985051930021785, 3.908956625027794, 4.834130083764837, 5.773090318843704, 6.719698859174236, 7.7066854514071625, 8.702511889111026, 9.641895324412937, 10.716153952762458, 11.74084711960519, 12.675631474520337, 10.815166354892673, 9.780493821069065, 8.83637415498614, 7.7670084937949095, 6.766340454880036, 5.792712585243913, 4.8356554762559805, 3.844112675568418, 2.878233223684467, 2.024343568270413, 2.9335668239685084, 3.8760592692619227, 4.822275039427474, 5.893958558154873, 6.893299852929739, 7.844108399624844, 8.828421800347366, 9.840043876474418, 10.759605208575575, 11.737657362138817, 9.938280147189712, 9.01032703524407, 7.992434160769126, 6.953814403250929, 5.906426677377194, 4.836678909695968, 3.9040157751648956, 2.9585699873929903, 1.9274692180544646, 1.0023478878024583, 1.9822172656709807, 2.821090230512638, 3.8920848063699642, 4.897694561743229, 5.932638421123002, 6.881830686507651, 7.923185144529073, 8.849998973042416, 9.824252285467443, 10.851669650650944, 9.205608651675812, 8.199644094771928, 7.146259100295195, 6.074347098644405, 5.009038310486629, 3.9992867551099254, 3.0159778055789, 1.98882736279104, 1.0198106467477552, 0.0, 0.9680266382282854, 1.8935529683679144, 2.8806302998924234, 3.92337242315772, 4.993803436915974, 6.037206383228702, 6.989805657812006, 7.978506041106685, 9.028225164056096, 9.997794519303662, 9.956306591483411, 8.905516778838713, 7.884934435548539, 6.916814935789686, 5.8435617635877595, 4.828899645015786, 3.8802479214161076, 2.942573525317777, 1.9603151923724444, 0.9311244586240468, 1.9585785847909185, 2.874127427745254, 3.8168160258480466, 4.831600946554278, 5.855534500651428, 6.8797994447107405, 7.863506951649408, 8.852194328733988, 9.892738947476722, 10.839308388010677, 10.723930764751696, 9.782405383906136, 8.735944102886867, 7.739749273647938, 6.814387777662906, 5.88165126444461, 4.9197833103193815, 3.917207859857702, 2.96191796875909, 1.9932401459656655, 2.9298976364074756, 3.9020960468319483, 4.840909429122608, 5.8556214301534135, 6.782420877805669, 7.805707397823129, 8.819860108448788, 9.814459594346456, 10.75836537363558, 11.670949977624398, 11.78317539709488, 10.783071916256064, 9.730595269319215, 8.670619588860763, 7.840316152196204, 6.813677634164198, 5.876788300033313, 4.877370404466119, 4.021962784167059, 2.9983959507137428, 3.9333134929581623, 4.885669455525865, 5.778207281653136, 6.8180360344553055, 7.733859771745696, 8.7264329190871, 9.706057232124268, 10.665013864357787, 11.73627369411526, 12.678867269074354, 12.6819385836478, 11.736117754550353, 10.68849163719635, 9.64328549176789, 8.81696531896734, 7.798164756358808, 6.863627875244938, 5.840717020442797, 4.997871931297135, 3.997469686676893, 4.88687812824484, 5.909010942289694, 6.736748218526959, 7.749169125260368, 8.748662546552783, 9.699369281534945, 10.705356152538899, 11.684189629688243, 12.669505169558004, 13.644728583814894, 13.648045231917079, 12.667337088901135, 11.664248433847131, 10.717227909221663, 9.766614249063073, 8.77137909596809, 7.9249667838502305, 6.903150001073573, 5.994218984403748, 5.063797552181817, 5.902727027441608, 6.86545976781055, 7.668229981656512, 8.628887216200546, 9.60001158971761, 10.575647238523707, 11.526809599564157, 12.58251271062715, 13.59675047731887, 14.542703825174504, 14.660903136522421, 13.646319340817454, 12.680643526756874, 11.698025039269464, 10.672996020854953, 9.698511293145156, 8.898534278358916, 7.89921458686381, 7.04715440938437, 6.099747791231891, 6.9174717361751705, 7.824597426608307, 8.681060253711587, 9.660303036245171, 10.579635794925126, 11.531117355029643, 12.548831465000342, 13.489683794443737, 14.434250710778096, 15.400248915152975, 15.602133449200728, 14.590448463465552, 13.629796498799637, 12.582788527279591, 11.634493345175574, 10.640827194407331, 9.833454098505031, 8.869814219642745, 8.077447839351404, 7.172666448714824, 7.936955109422708, 8.811581281341915, 9.609035072658038, 10.538453909129784, 11.52193098877826, 12.499659711883254, 13.488925050969494, 14.501670678054797, 15.500675308295436, 16.327087355874816], [16.321239529864503, 15.502616026432452, 14.52712137770789, 13.55598171553303, 12.527747075901981, 11.572633264855122, 10.594976309559419, 9.683655507447627, 8.974603099018328, 8.107992591715169, 9.118582946390426, 10.08531168473992, 10.79002491560683, 11.729527328133122, 12.549754297958337, 13.538231918079234, 14.495617397052825, 15.5199899942811, 16.496011541069947, 17.331417161824543, 17.34014530751108, 16.537133318670854, 15.517634256011892, 14.597783116512575, 13.541069809682188, 12.551835183172377, 11.545103013179608, 10.733303463309618, 10.030148905411417, 9.144800188902995, 10.061650799153064, 11.021692872858214, 11.827099039717233, 12.691990918460494, 13.476882293528991, 14.54411272262787, 15.42106507454213, 16.349386919206307, 17.40463784345282, 18.385925651771405, 18.33164396094808, 17.39048882112519, 16.4337292292966, 15.467563509132944, 14.468723076325613, 13.57903571501285, 12.547833112515127, 11.792596346784359, 11.046586097117522, 10.167397367078582, 10.025850222559765, 10.757732058152486, 11.692793363355973, 12.68355521300047, 13.62628972410777, 14.564922759633893, 15.507966634077844, 16.541758833175123, 17.484765858767116, 18.43659518843895, 18.302982091020333, 17.43135989879771, 16.451423696552105, 15.522814677047457, 14.483555165498082, 13.573422938241794, 12.624942160789223, 11.633833626387, 10.64828327622872, 9.912150020612057, 8.96679140980639, 9.769367192331838, 10.733270473427964, 11.695818913783715, 12.606383768166175, 13.650414097135053, 14.578932723575186, 15.514050799381895, 16.49893167042267, 17.44985160293962, 17.37740643959672, 16.492345976820058, 15.464040920790417, 14.510795689993838, 13.501293243737742, 12.682491124709735, 11.637193627685622, 10.696490228403748, 9.656157166104347, 8.845611384767361, 7.9115756824743375, 8.829997491919288, 9.864615627935638, 10.784232084886682, 11.627554521936593, 12.649816898385327, 13.611526320593063, 14.540389670370265, 15.553068888559752, 16.479632786993587, 16.369304346200696, 15.467278716245529, 14.518040819810503, 13.592653902166663, 12.558730407117364, 11.639888576257169, 10.702713122466106, 9.734183361269285, 8.724203808469161, 7.796669996839446, 6.939610789888905, 7.869067868065706, 8.859586839603868, 9.766092569638504, 10.701692906919112, 11.680930429616916, 12.595266189787147, 13.553301079249302, 14.60538686110219, 15.418961286940021, 15.48867234844466, 14.487530352279148, 13.52634787568703, 12.565236241151167, 11.587958669466474, 10.728485405038814, 9.786863843843458, 8.767869664690982, 7.800152600259366, 6.854916088917483, 5.91814670392143, 6.845182261119192, 7.82309497954337, 8.75242340116372, 9.749212983490073, 10.700910865338882, 11.633012545152088, 12.577439141849407, 13.5858314354058, 14.48953095717718, 14.490465251513521, 13.521441578367376, 12.544036798535593, 11.534159295569685, 10.562602820587077, 9.719949845794675, 8.810572396952578, 7.786487680757817, 6.837232835374046, 5.913442052306825, 4.956840998947311, 5.913252855153578, 6.789934008830528, 7.748737694049224, 8.675854515374967, 9.646851680283108, 10.576438280383746, 11.515393604735769, 12.56644781989295, 13.552444727302635, 13.521046110876647, 12.500844783919478, 11.50714410076004, 10.579106509582015, 9.631842192088046, 8.67761873631959, 7.744043504942592, 6.782439658750228, 5.817869022730722, 4.877919692406644, 3.9447978072355396, 4.890890022535583, 5.826047747594784, 6.720669541383666, 7.749980710290642, 8.731879778970548, 9.659597361666112, 10.733172400000084, 11.799990016817297, 12.76702398176592, 12.582966408116421, 11.57782733285423, 10.607123699493805, 9.62599862299461, 8.668109740400734, 7.7339802720255895, 6.760836340801482, 5.818701547197065, 4.775223659189852, 3.95307856825007, 2.976206810422908, 3.9013802691599504, 4.840340504238818, 5.78694904456935, 6.7739356368022765, 7.769762074506141, 8.709145509808053, 9.783404138157572, 10.808097305000304, 11.786335456582892, 11.71201552489831, 10.748520459297353, 9.804400793214427, 8.735035132023196, 7.734367093108323, 6.760739223472199, 5.803682114484266, 4.8121393137967035, 3.8462598619127526, 2.9923702064986983, 2.000817009363623, 2.9080326310336377, 3.8542484011991895, 4.9259319199265885, 5.925273214701455, 6.876081761396559, 7.86039516211908, 8.872017238246134, 9.79157857034729, 10.769630723910533, 10.839248390815575, 9.978353673472357, 8.960460798997413, 7.921841041479215, 6.87445331560548, 5.804705547924255, 4.8720424133931814, 3.9265966256212756, 2.89549585628275, 1.9703745260307437, 1.0494674510660953, 1.853063592284353, 2.9240581681416793, 3.9296679235149443, 4.964611782894718, 5.913804048279366, 6.955158506300789, 7.881972334814131, 8.856225647239159, 9.88364301242266, 10.072679316576975, 9.167670733000215, 8.114285738523481, 7.042373736872691, 5.977064948714915, 4.967313393338211, 3.9840044438071853, 2.9568540010193254, 1.9878372849760406, 0.9680266382282854, 0.0, 0.9255263301396291, 1.912603661664138, 2.9553457849294347, 4.025776798687689, 5.069179745000417, 6.021779019583721, 7.010479402878399, 8.060198525827811, 9.029767881075378, 10.848758199279104, 9.873543417067, 8.852961073776825, 7.8848415740179725, 6.811588401816046, 5.796926283244073, 4.848274559644393, 3.9106001635460625, 2.92834183060073, 1.8991510968523322, 1.0594519217160754, 1.9061007895169688, 2.848789387619761, 3.863574308325993, 4.887507862423143, 5.911772806482455, 6.895480313421123, 7.884167690505702, 8.924712309248436, 9.87128174978239, 11.691957402979982, 10.750432022134422, 9.703970741115153, 8.707775911876224, 7.782414415891192, 6.849677902672896, 5.887809948547667, 4.885234498085987, 3.9299446069873754, 2.961266784193951, 2.0307709733326327, 2.934069408603663, 3.872882790894322, 4.887594791925128, 5.814394239577384, 6.837680759594844, 7.851833470220502, 8.84643295611817, 9.790338735407294, 10.827499389180865, 12.751202035323166, 11.75109855448435, 10.698621907547501, 9.63864622708905, 8.80834279042449, 7.781704272392484, 6.844814938261599, 5.845397042694405, 4.989989422395343, 3.966422588942028, 3.0341868298833194, 3.9176428172975797, 4.81018064342485, 5.85000939622702, 6.765833133517409, 7.758406280858814, 8.738030593895981, 9.696987226129501, 10.768247055886974, 11.754696054048154, 13.649965221876087, 12.704144392778641, 11.656518275424636, 10.611312129996175, 9.784991957195626, 8.766191394587095, 7.831654513473223, 6.808743658671083, 5.965898569525421, 4.965496324905178, 3.9877514651699975, 4.961296489123665, 5.768721580298673, 6.781142487032081, 7.780635908324496, 8.73134264330666, 9.737329514310613, 10.716162991459957, 11.701478531329718, 12.676701945586608, 14.524674495500893, 13.635363727129423, 12.632275072075418, 11.685254547449949, 10.73464088729136, 9.739405734196376, 8.892993422078515, 7.871176639301859, 6.962245622632033, 6.031824190410102, 5.003600364366766, 5.966333104735708, 6.700203343428226, 7.660860577972262, 8.631984951489326, 9.607620600295423, 10.558782961335872, 11.614486072398865, 12.628723839090584, 13.574677186946218, 15.427022494507892, 14.614345979045742, 13.64867016498516, 12.66605167749775, 11.641022659083239, 10.666537931373442, 9.8665609165872, 8.867241225092094, 8.015181047612655, 7.067774429460178, 6.0183450731003285, 6.925470763533465, 7.713033615483302, 8.692276398016887, 9.611609156696842, 10.563090716801359, 11.580804826772058, 12.521657156215452, 13.466224072549812, 14.43222227692469, 16.417907697694154, 15.558475101693837, 14.597823137027921, 13.550815165507876, 12.602519983403859, 11.608853832635617, 10.801480736733316, 9.83784085787103, 9.045474477579688, 8.10939559621314, 7.037828446347866, 7.9124546182670725, 8.641008434429754, 9.570427270901499, 10.553904350549976, 11.53163307365497, 12.520898412741209, 13.533644039826513, 14.532648670067152, 15.359060717646534], [15.395713199724874, 14.577089696292823, 13.60159504756826, 12.6304553853934, 11.602220745762352, 10.647106934715493, 9.669449979419788, 8.758129177307996, 8.056001090412797, 9.033518921854798, 10.044109276530055, 11.01083801487955, 11.715551245746461, 12.655053658272752, 13.475280628097966, 14.463758248218863, 15.421143727192455, 16.44551632442073, 17.421537871209576, 16.405890831684914, 16.41461897737145, 15.611606988531227, 14.592107925872263, 13.672256786372946, 12.61554347954256, 11.626308853032748, 10.619576683039977, 9.807777133169987, 9.111546896805887, 10.070326519042624, 10.987177129292693, 10.89701710083191, 11.847508721771069, 12.863935894188339, 13.686984455051505, 14.659817440267291, 15.673646750980721, 16.601968595644898, 17.522566161201187, 17.460399321631776, 17.406117630808453, 16.46496249098556, 15.508202899156968, 14.542037178993315, 13.543196746185984, 12.653509384873217, 11.622306782375496, 10.867070016644728, 10.127984088511992, 11.092923697218211, 10.82802477968122, 9.89723179089205, 10.832293096095537, 11.823054945740035, 12.738691875458676, 13.6773249109848, 14.62036878542875, 15.65416098452603, 16.597168010118022, 17.548997339789857, 17.41538424237124, 17.476052430106762, 16.49204682046705, 15.60659154609904, 14.602818800261188, 13.57737684133848, 12.62889606388591, 11.934138176634283, 11.143902542303286, 10.794969141936107, 9.849610531130441, 8.908866925071402, 9.872770206167528, 10.835318646523278, 11.718785919517082, 12.76281624848596, 13.691334874926092, 14.626452950732801, 15.611333821773577, 16.562253754290523, 16.489808590947625, 17.417872306959687, 16.389567250930046, 15.436322020133467, 14.42681957387737, 13.565310246033786, 12.520012749009673, 11.579309349727799, 10.538976287428397, 9.728430506091412, 8.794394803798388, 7.969497224658852, 9.0041153606752, 9.896634236237587, 10.7399566732875, 11.762219049736233, 12.72392847194397, 13.652791821721172, 14.665471039910658, 15.592034938344492, 15.481706497551603, 16.392805046385156, 15.443567149950132, 14.518180232306293, 13.484256737256993, 12.52270769758122, 11.585532243790157, 10.617002482593335, 9.607022929793212, 8.679489118163497, 7.8224299112129545, 7.00856760080527, 7.999086572343431, 8.878494720989409, 9.814095058270018, 10.793332580967823, 11.707668341138051, 12.665703230600208, 13.717789012453096, 14.531363438290926, 14.601074499795564, 15.413056682418777, 14.451874205826659, 13.490762571290796, 12.513484999606103, 11.639406245328063, 10.697784684132706, 9.650688786015031, 8.682971721583415, 7.737735210241534, 6.80096582524548, 5.984681993858756, 6.935497130894275, 7.864825552514624, 8.86161513484098, 9.813313016689786, 10.745414696502992, 11.689841293200313, 12.698233586756706, 13.601933108528085, 13.692810438960775, 14.446967908507006, 13.469563128675222, 12.459685625709314, 11.488129150726706, 10.645476175934302, 9.736098727092207, 8.669306802081866, 7.720051956698096, 6.796261173630876, 5.839660120271361, 5.052752587893142, 5.902336160181433, 6.861139845400128, 7.788256666725872, 8.759253831634012, 9.68884043173465, 10.627795756086673, 11.678849971243855, 12.66484687865354, 12.770790874309812, 13.426371114059107, 12.43267043089967, 11.504632839721644, 10.557368522227675, 9.603145066459216, 8.669569835082221, 7.665258780074277, 6.700688144054772, 5.760738813730694, 4.827616928559589, 4.030389755275148, 4.938449898945689, 5.8330716927345705, 6.862382861641547, 7.844281930321453, 8.771999513017018, 9.84557455135099, 10.912392168168203, 11.84149765162629, 11.832711171549587, 12.50335366299386, 11.532650029633434, 10.551524953134239, 9.593636070540363, 8.659506602165218, 7.6863626709411115, 6.744227877336694, 5.700749989329481, 4.836233470655762, 3.859025931746957, 3.0408800018995157, 3.9527426555897227, 4.8993511959202545, 5.886337788153181, 6.8821642258570455, 7.821547661158957, 8.895806289508476, 9.920499456351209, 10.860809126443261, 10.78648919475868, 11.674046789436982, 10.729927123354056, 9.660561462162825, 8.65989342324795, 7.686265553611828, 6.729208444623895, 5.7376656439363325, 4.771786192052382, 3.8851011329576295, 2.883636130687672, 1.9825063008940087, 2.9287220710595605, 4.0004055897869595, 4.999746884561826, 5.95055543125693, 6.934868831979451, 7.946490908106504, 8.86605224020766, 9.844104393770902, 9.913722060675944, 10.841675172621587, 9.885987129137042, 8.847367371618844, 7.799979645745109, 6.730231878063884, 5.7975687435328105, 4.852122955760905, 3.821022186422379, 2.895900856170373, 1.9322865723901441, 0.9275372621447239, 1.9985318380020503, 3.0041415933753153, 4.039085452755089, 4.988277718139737, 6.02963217616116, 6.956446004674502, 7.930699317099529, 8.958116682283029, 9.147152986437346, 10.093197063139844, 9.03981206866311, 7.96790006701232, 6.902591278854544, 5.89283972347784, 4.909530773946814, 3.8823803311589544, 2.91336361511567, 1.8935529683679144, 0.9255263301396291, 0.0, 0.9870773315245088, 2.029819454789805, 3.1002504685480594, 4.143653414860788, 5.096252689444092, 6.08495307273877, 7.134672195688182, 8.104241550935749, 9.923231869139475, 10.799069747206628, 9.778487403916454, 8.810367904157602, 7.737114731955675, 6.722452613383702, 5.773800889784022, 4.836126493685692, 3.853868160740359, 2.8246774269919612, 1.9849782518557046, 0.9805744593773397, 1.9232630574801322, 2.938047978186364, 3.961981532283514, 4.986246476342826, 5.969953983281494, 6.958641360366073, 7.999185979108807, 8.945755419642762, 10.848992271913938, 11.675958352274053, 10.629497071254784, 9.633302242015855, 8.707940746030822, 7.775204232812525, 6.813336278687296, 5.810760828225616, 4.855470937127005, 3.88679311433358, 2.9562973034722617, 2.008543078464034, 2.947356460754693, 3.962068461785499, 4.888867909437755, 5.912154429455215, 6.926307140080873, 7.9209066259785414, 8.864812405267665, 9.901973059041236, 11.87501342048438, 12.676624884623982, 11.624148237687132, 10.56417255722868, 9.733869120564119, 8.707230602532112, 7.770341268401228, 6.770923372834034, 5.915515752534973, 4.891948919081657, 3.9597131600229485, 2.9921164871579506, 3.884654313285221, 4.924483066087391, 5.84030680337778, 6.832879950719185, 7.812504263756352, 8.771460895989872, 9.842720725747345, 10.829169723908525, 12.772873837356848, 13.62967072291827, 12.582044605564267, 11.536838460135806, 10.710518287335255, 9.691717724726724, 8.757180843612852, 7.734269988810712, 6.89142489966505, 5.891022655044807, 4.913277795309627, 4.035770158984036, 4.843195250159044, 5.855616156892452, 6.855109578184867, 7.80581631316703, 8.811803184170984, 9.790636661320328, 10.775952201190089, 11.751175615446979, 13.599148165361264, 14.560890057269052, 13.557801402215048, 12.61078087758958, 11.660167217430988, 10.664932064336005, 9.818519752218146, 8.796702969441489, 7.887771952771662, 6.957350520549731, 5.929126694506395, 5.047731096130178, 5.774677013288597, 6.735334247832633, 7.706458621349697, 8.682094270155794, 9.633256631196243, 10.688959742259236, 11.703197508950955, 12.649150856806589, 14.501496164368262, 15.539872309185371, 14.57419649512479, 13.591578007637379, 12.566548989222868, 11.592064261513071, 10.792087246726831, 9.792767555231725, 8.940707377752284, 7.993300759599807, 6.9438714032399576, 6.006868754927935, 6.787507285343673, 7.766750067877257, 8.686082826557213, 9.63756438666173, 10.655278496632429, 11.596130826075823, 12.540697742410183, 13.506695946785062, 15.492381367554524, 16.484001431833466, 15.52334946716755, 14.476341495647505, 13.528046313543488, 12.534380162775246, 11.727007066872947, 10.76336718801066, 9.971000807719317, 9.03492192635277, 7.9633547764874955, 6.993852609661543, 7.715482104290124, 8.644900940761868, 9.628378020410347, 10.60610674351534, 11.59537208260158, 12.608117709686884, 13.607122339927523, 14.433534387506905], [14.408635868200367, 13.590012364768317, 12.614517716043753, 11.643378053868892, 10.615143414237844, 9.660029603190985, 8.68237264789528, 7.7710518457834885, 8.710708982982588, 9.735135260728192, 10.788447936909195, 11.778865291260452, 12.21532554324423, 13.062066484565412, 13.751151040666365, 14.739628660787261, 15.697014139760853, 16.72138673698913, 16.445551096510513, 15.418813500160407, 15.427541645846944, 14.62452965700672, 13.605030594347756, 12.685179454848438, 11.628466148018049, 10.63923152150824, 9.632499351515468, 8.82069980164548, 9.766254789375678, 10.77194285791602, 11.725338546345899, 11.88409443235642, 11.178251419133828, 12.09960289423804, 12.82402304509571, 13.796856030311497, 14.810685341024927, 15.739007185689104, 16.659604751245393, 16.47332199010727, 16.419040299283942, 15.47788515946105, 14.521125567632458, 13.554959847468805, 12.556119414661474, 11.66643205334871, 10.635229450850987, 9.879992685120222, 10.782691981081783, 11.789946701612777, 11.81510211120573, 10.88430912241656, 10.163035793458295, 11.043726972590154, 11.875730465502881, 12.814363501029005, 13.757407375472956, 14.791199574570236, 15.734206600162228, 16.686035929834063, 16.552422832415445, 16.48897509858225, 15.504969488942537, 14.61951421457453, 13.61574146873668, 12.590299509813972, 11.6418187323614, 10.947060845109776, 11.798610434873076, 11.782046473460614, 10.836687862654948, 9.895944256595913, 9.203512903530287, 10.055990673373397, 10.855824509561288, 11.899854838530166, 12.828373464970298, 13.763491540777007, 14.748372411817783, 15.699292344334731, 15.626847180991833, 16.575808800855356, 16.56095112848747, 15.607505836753116, 14.59800339049702, 13.646258202977975, 12.695788803421154, 12.010928417812435, 11.526053618952904, 10.715507837615919, 9.781472135322895, 8.956574556183362, 8.215177107372613, 9.083837473038205, 9.876995263331706, 10.899257639780439, 11.860967061988175, 12.789830411765378, 13.802509629954864, 14.7290735283887, 14.61874508759581, 15.680484778074966, 16.430644481474644, 15.505257563830803, 14.471334068781504, 13.509785029105727, 12.572609575314663, 11.604079814117842, 10.594100261317719, 9.666566449688004, 8.809507242737462, 7.99564493232978, 7.188404138649452, 8.065697957790027, 8.951133648314224, 9.930371171012029, 10.844706931182259, 11.802741820644414, 12.854827602497302, 13.668402028335134, 13.738113089839771, 14.75228513879559, 15.43895153735117, 14.477839902815306, 13.500562331130613, 12.626483576852571, 11.684862015657215, 10.63776611753954, 9.670049053107924, 8.724812541766042, 7.788043156769988, 6.971759325383267, 6.122700367694893, 7.0520287893152425, 7.998653724885186, 8.950351606733992, 9.8824532865472, 10.82687988324452, 11.835272176800911, 12.738971698572293, 12.787919448655154, 13.78837844807169, 14.456640460199733, 13.446762957233824, 12.475206482251217, 11.63255350745881, 10.723176058616716, 9.656384133606375, 8.707129288222603, 7.783338505155385, 6.82673745179587, 6.039829919417652, 5.089539396982051, 6.048343082200747, 6.925295256770079, 7.896292421678219, 8.825879021778858, 9.76483434613088, 10.815888561288062, 11.801885468697748, 11.81850030801828, 12.831767949801485, 13.41974776242418, 12.491710171246154, 11.544445853752185, 10.590222397983725, 9.65664716660673, 8.652336111598785, 7.687765475579281, 6.747816145255203, 5.814694260084098, 5.017467086799657, 4.125653135746307, 5.020274929535189, 5.999421451685754, 6.962633689728703, 7.890351272424267, 8.96392631075824, 10.01694141743669, 10.889207085334757, 10.880420605258054, 11.845005383537085, 12.519727361157944, 11.538602284658749, 10.580713402064873, 9.646583933689726, 8.67344000246562, 7.731305208861203, 6.687827320853989, 5.823310802180272, 4.846103263271466, 4.027957333424025, 3.139945892390341, 4.086554432720873, 5.004689547560431, 6.000515985264295, 6.939899420566206, 8.014158048915725, 8.980044673632502, 9.908518560151728, 9.834198628467147, 10.835806165971363, 11.717004454878566, 10.647638793687335, 9.646970754772461, 8.673342885136337, 7.716285776148403, 6.724742975460841, 5.75886352357689, 4.872178464482138, 3.870713462212181, 2.9695836324185176, 2.115925307860179, 3.106156492696689, 4.047456318270293, 4.998264864965398, 5.982578265687919, 6.994200341814971, 7.913761673916127, 8.89181382747937, 8.961431494384412, 9.889384606330054, 10.87306446066155, 9.834444703143353, 8.787056977269618, 7.717309209588392, 6.784646075057319, 5.839200287285413, 4.8080995179468875, 3.8829781876948815, 2.919363903914653, 1.9146145936692327, 1.0462412717105178, 2.051851027083783, 3.0867948864635557, 4.035987151848205, 5.077341609869627, 6.00415543838297, 6.978408750807996, 8.005826115991496, 8.160075654912836, 9.16604021181672, 10.02688940018762, 8.95497739853683, 7.8896686103790525, 6.879917055002349, 5.896608105471324, 4.869457662683463, 3.9004409466401784, 2.8806302998924234, 1.912603661664138, 0.9870773315245088, 0.0, 1.0427421232652965, 2.1131731370235505, 3.1565760833362786, 4.109175357919582, 5.097875741214261, 6.147594864163672, 7.117164219411238, 8.936154537614966, 9.986944350259664, 10.765564735440963, 9.79744523568211, 8.724192063480183, 7.70952994490821, 6.760878221308531, 5.823203825210201, 4.840945492264868, 3.81175475851647, 2.9720555833802136, 1.9676517909018485, 0.9361857259556234, 1.9509706466618555, 2.9749042007590054, 3.9991691448183175, 4.982876651756985, 5.971564028841565, 7.012108647584299, 7.958678088118253, 9.861914940389429, 10.803440321234989, 11.61657440277929, 10.620379573540362, 9.69501807755533, 8.762281564337034, 7.800413610211805, 6.797838159750125, 5.842548268651513, 4.873870445858088, 3.9433746349967707, 2.983006667411221, 1.9602791292301844, 2.9749911302609906, 3.9017905779132462, 4.925077097930706, 5.939229808556364, 6.933829294454033, 7.877735073743157, 8.914895727516727, 10.887936088959872, 11.837662842477663, 12.611225569211639, 11.551249888753187, 10.720946452088628, 9.69430793405662, 8.757418599925735, 7.758000704358542, 6.902593084059482, 5.879026250606166, 4.946790491547457, 3.9283972274199086, 2.8975769817607127, 3.9374057345628826, 4.853229471853272, 5.845802619194677, 6.825426932231844, 7.7843835644653625, 8.855643394222836, 9.842092392384016, 11.785796505832339, 12.731617334929785, 13.569121937088774, 12.523915791660313, 11.697595618859763, 10.678795056251232, 9.744258175137361, 8.72134732033522, 7.878502231189558, 6.878099986569316, 5.838775206021324, 4.81664239197647, 3.856117918634536, 4.868538825367944, 5.868032246660358, 6.818738981642522, 7.824725852646476, 8.803559329795819, 9.78887486966558, 10.76409828392247, 12.612070833836755, 13.662836669280567, 14.544878733739555, 13.597858209114086, 12.647244548955497, 11.652009395860514, 10.79555562193454, 9.773738839157883, 8.768707099159151, 7.83828566693722, 6.791336069491554, 5.828603329122612, 4.787599681764089, 5.748256916308124, 6.719381289825188, 7.695016938631286, 8.646179299671736, 9.70188241073473, 10.716120177426447, 11.66207352528208, 13.514418832843756, 14.572532303620319, 15.561273826649298, 14.578655339161887, 13.553626320747377, 12.57914159303758, 11.769123116443225, 10.769803424948119, 9.817997451619501, 8.810432558691835, 7.7388363000478915, 6.745440076871747, 5.800429953819164, 6.779672736352748, 7.699005495032704, 8.650487055137221, 9.668201165107922, 10.609053494551317, 11.553620410885676, 12.519618615260555, 14.505304036030017, 15.516989021765193, 16.47764098643111, 15.463418827172015, 14.515123645067998, 13.521457494299755, 12.70404293658934, 11.740403057727054, 10.844416386206444, 9.799010898031236, 8.727443748165962, 7.702697795555419, 6.728404772765615, 7.657823609237361, 8.641300688885838, 9.619029411990832, 10.608294751077072, 11.621040378162377, 12.620045008403016, 13.446457055982398], [13.553973027458433, 12.735349524026383, 11.75985487530182, 10.81318388112413, 9.796929118245739, 8.916972442851538, 8.150727220076309, 8.813793969048785, 9.753451106247885, 10.77787738399349, 11.831190060174492, 12.821607414525749, 13.12670001330023, 12.167188187145712, 12.765013359203804, 13.7534909793247, 14.710876458298292, 15.735249055526568, 15.59088825576858, 14.564150659418473, 14.57287880510501, 13.769866816264786, 12.750367753605822, 11.854985282103677, 10.826958547424898, 9.896174361168793, 9.100853923696498, 9.863441924910775, 10.808996912640975, 11.814684981181315, 12.768080669611194, 12.826850617500318, 12.089625889189827, 11.20472459681834, 11.83788536363315, 12.810718348848937, 13.824547659562366, 14.752869504226544, 15.673467069782836, 15.618659149365335, 15.616601458138735, 14.676377558867898, 13.719617967039307, 12.753452246875653, 11.754611814068323, 10.93577409006834, 10.103584023032017, 10.922734808385517, 11.82543410434708, 12.832688824878074, 12.757858296349628, 11.827065307560458, 11.074410263514295, 10.148848675170454, 10.889592784040321, 11.828225819566445, 12.771269694010396, 13.805061893107675, 14.74806891869967, 15.699898248371502, 15.566285150952886, 15.6874674979891, 14.703461888349386, 13.818006613981378, 12.816449080471207, 11.919103236759717, 11.11017330454243, 11.989802968375072, 12.841352558138373, 12.824788596725911, 11.879429985920247, 10.83870044173981, 10.114887373586287, 9.161112375953698, 9.869686828098727, 10.913717157067605, 11.842235783507737, 12.777353859314447, 13.762234730355225, 14.71315466287217, 14.640709499529272, 15.589671119392797, 15.75944352789432, 14.808213448487644, 13.798711002231547, 12.97506192992372, 12.164143375602183, 13.05367054107773, 12.568795742218201, 11.758249960881216, 10.824214258588194, 9.89933074132726, 9.126551577428613, 8.188959175618505, 8.890857581869145, 9.913119958317878, 10.874829380525615, 11.803692730302817, 12.816371948492305, 13.74293584692614, 13.63260740613325, 14.694347096612406, 15.643584993047432, 15.78010329988578, 14.741273838851924, 14.02586645626808, 13.208819112463788, 12.64682193738314, 11.636842384583016, 10.7093085729533, 9.852249366002761, 8.938401117473678, 8.099778608705451, 7.170819660370326, 7.964995966851664, 8.944233489549468, 9.858569249719698, 10.816604139181855, 11.868689921034743, 12.682264346872573, 12.751975408377211, 13.76614745733303, 14.727329933925148, 15.5205820260806, 14.543304454395907, 13.66922570011787, 12.727604138922514, 11.680508240804839, 10.712791176373223, 9.767554665031339, 8.830785280035286, 7.914515510527163, 7.0618424691218085, 6.157150491895543, 7.012516043422625, 7.964213925271432, 8.89631560508464, 9.84074220178196, 10.849134495338353, 11.752834017109732, 11.79914113527454, 12.799600134691076, 13.795852228569101, 14.489505080499118, 13.51794860551651, 12.675295630724108, 11.765918181882013, 10.699126256871674, 9.749871411487902, 8.826080628420682, 7.869479575061167, 6.982586104561549, 6.028681498408966, 5.153464784781047, 5.939157575307519, 6.910154740215659, 7.839741340316298, 8.77869666466832, 9.829750879825502, 10.815747787235187, 10.829721994637666, 11.84298963642087, 12.806088329955589, 13.534452294511448, 12.587187977017479, 11.632964521249022, 10.699389289872027, 9.695078234864084, 8.730507598844579, 7.7905582685205, 6.857436383349395, 6.003442072705953, 5.0647952371732226, 4.125396632115489, 5.013283770223193, 5.9764960082661425, 6.904213590961707, 7.977788629295679, 9.028163104056079, 9.900428771954141, 9.89164229187744, 10.856227070156471, 11.773113363970294, 12.581344407924043, 11.623455525330167, 10.689326056955023, 9.716182125730917, 8.7740473321265, 7.730569444119285, 6.866052925445568, 5.8888453865367625, 5.07069945668932, 4.138284675631704, 3.1916761353011727, 4.01855186609787, 5.014378303801735, 5.953761739103646, 7.028020367453165, 7.991266360251889, 8.919740246771113, 8.845420315086534, 9.847027852590749, 10.791147518673675, 11.690380916952627, 10.689712878037755, 9.716085008401631, 8.7590278994137, 7.767485098726137, 6.801605646842186, 5.914920587747434, 4.913455585477477, 4.012325755683814, 3.1410071371441486, 2.1200188112341287, 3.0613186368077328, 4.012127183502837, 4.9964405842253585, 6.008062660352411, 6.9249833605355136, 7.903035514098755, 7.972653181003799, 8.90060629294944, 9.918499167424384, 10.877186826408646, 9.829799100534911, 8.760051332853687, 7.827388198322614, 6.881942410550709, 5.850841641212184, 4.925720310960178, 3.9621060271799493, 2.957356716934529, 2.0713231009944875, 1.0657133456212224, 2.1006572050009953, 3.049849470385644, 4.0885632964890135, 5.015377125002356, 5.989630437427382, 7.017047802610883, 7.11733353164754, 8.123298088551422, 9.176683083028156, 9.997719521802125, 8.93241073364435, 7.922659178267645, 6.93935022873662, 5.91219978594876, 4.943183069905475, 3.9233724231577196, 2.9553457849294342, 2.029819454789805, 1.0427421232652965, 0.0, 1.0704310137582542, 2.1138339600709823, 3.066433234654286, 4.0551336179489645, 5.104852740898377, 6.074422096145943, 7.967624231507782, 9.018414044152479, 10.038996387442653, 10.840187358947407, 9.76693418674548, 8.752272068173507, 7.803620344573828, 6.865945948475497, 5.883687615530165, 4.854496881781767, 4.01479770664551, 3.0103939141671447, 1.97892784922092, 1.0484659539999557, 2.0063738946518197, 3.0306388387111323, 4.0143463456498, 5.003033722734379, 6.043578341477113, 6.990147782011068, 8.893384634282244, 9.834910015127804, 10.881371296147073, 11.66312169680566, 10.737760200820627, 9.805023687602331, 8.843155733477102, 7.840580283015422, 6.8852903919168105, 5.9166125691233855, 4.986116758262067, 4.025748790676518, 3.003021252495481, 2.072486437599091, 2.970539991496957, 3.956546791823521, 4.970699502449179, 5.965298988346848, 6.909204767635972, 7.946365421409543, 9.952629266625427, 10.869132536370477, 11.87602246257942, 12.593992012018486, 11.763688575353925, 10.737050057321918, 9.800160723191032, 8.80074282762384, 7.945335207324779, 6.921768373871463, 5.989532614812754, 4.971139350685204, 3.940319105026009, 3.1473666845370616, 3.921978885436983, 4.9145520327783885, 5.894176345815556, 6.853132978049074, 7.924392807806548, 8.910841805967728, 10.854545919416049, 11.800366748513495, 12.833918830456556, 13.566657914925612, 12.74033774212506, 11.72153717951653, 10.787000298402658, 9.764089443600517, 8.921244354454856, 7.920842109834613, 6.88151732928662, 5.859384515241766, 4.898860041899832, 4.091384815243432, 4.93678166024407, 5.887488395226233, 6.893475266230188, 7.87230874337953, 8.85762428324929, 9.83284769750618, 11.680820247420465, 12.731586082864277, 13.75947004839665, 14.640600332379385, 13.689986672220794, 12.694751519125811, 11.838297745199835, 10.816480962423178, 9.811449222424447, 8.881027790202516, 7.83407819275685, 6.871345452387908, 5.830341805029385, 5.099535054985056, 5.976324129485739, 6.840354097889352, 7.791516458929801, 8.847219569992795, 9.784869591010157, 10.73082293886579, 12.659755992101822, 13.710568334780596, 14.733956537409735, 15.621397462427185, 14.596368444012674, 13.621883716302877, 12.81186523970852, 11.812545548213414, 10.860739574884796, 9.85317468195713, 8.781578423313187, 7.788182200137043, 6.843172077084461, 6.15076152729341, 6.955948334693256, 7.795824214395287, 8.813538324365988, 9.754390653809383, 10.698957570143742, 11.66495577451862, 13.650641195288083, 14.662326181023259, 15.622978145689174, 15.711600597318638, 14.76330541521462, 13.705913824526524, 13.095234778545517, 12.78314518099235, 11.88715850947174, 10.841753021296533, 9.77018587143126, 8.745439918820715, 7.771146896030912, 7.12617818141839, 7.898243528546391, 8.764366571248898, 9.753631910335137, 10.766377537420443, 11.765382167661082, 12.591794215240464], [12.483542013700179, 11.664918510268128, 10.689423861543565, 9.742752867365875, 8.726498104487483, 7.846541429093284, 8.853053521338763, 9.705592046115362, 10.645249183314462, 11.669675461060066, 12.72298813724107, 13.713405491592326, 13.691935932369153, 12.683543499433345, 11.69550164122806, 12.683979261348956, 13.641364740322548, 14.665737337550823, 14.520457242010327, 13.493719645660219, 13.502447791346755, 12.699435802506533, 11.67993673984757, 10.78455426834542, 9.756527533666642, 8.825743347410539, 9.803180224958952, 10.755240001977352, 11.700794989707552, 12.706483058247894, 13.659878746677773, 13.571201222554198, 12.737507081523242, 11.721079909105972, 10.768373645657405, 11.741206630873192, 12.755035941586621, 13.683357786250799, 14.60395535180709, 14.548228135607081, 14.546170444380483, 13.605946545109642, 12.64918695328105, 11.683021233117397, 10.684180800310067, 9.865343076310086, 10.805910324294471, 11.814532885452094, 12.717232181413657, 13.724486901944651, 13.502208901403508, 12.571415912614338, 11.735905752283152, 10.794379839326337, 9.820081066064576, 10.7587141015907, 11.701757976034651, 12.73555017513193, 13.678557200723922, 14.630386530395755, 14.49677343297714, 14.617036484230844, 13.63303087459113, 12.747575600223122, 11.746018066712951, 10.848672223001463, 11.797153000454035, 12.788261534856257, 13.73315063520495, 13.597581322437863, 12.636618444537053, 11.58305104679369, 10.776382862355144, 9.813834421999394, 8.800175110122982, 9.84420543909186, 10.772724065531992, 11.707842141338702, 12.692723012379478, 13.643642944896424, 13.571197781553526, 14.52015940141705, 14.689012514136063, 13.737782434729388, 12.728279988473291, 11.904630916165466, 12.851123071513788, 13.791826470795662, 13.415071885539941, 12.531042686593167, 11.581402717205, 10.64368134638114, 9.829026535859335, 8.841681221664201, 7.8213458638934, 8.843608240342133, 9.80531766254987, 10.734181012327072, 11.746860230516559, 12.673424128950392, 12.563095688157503, 13.624835378636659, 14.574073275071685, 14.709672286127525, 13.670842825093668, 12.955435442509826, 13.892610896300889, 13.493098080704879, 12.483118527904756, 11.55558471627504, 10.609437824619567, 9.682751722527557, 8.802253567136173, 7.873294618801048, 6.895484248875918, 7.874721771573723, 8.789057531743952, 9.747092421206109, 10.799178203058997, 11.612752628896827, 11.682463690401464, 12.696635739357284, 13.657818215949401, 14.664812693856977, 14.641614562744559, 13.925748884588945, 13.585527726887243, 12.538431828769568, 11.570714764337952, 10.62547825299607, 9.587973738652092, 8.658866115581043, 7.806193074175687, 6.901501096949421, 5.943004325446879, 6.894702207295687, 7.826803887108893, 8.771230483806214, 9.779622777362606, 10.683322299133986, 10.728710121516288, 11.729169120932823, 12.725421214810849, 13.717336011499144, 14.451846270438015, 13.558872218919253, 12.624427739151873, 11.557049844836403, 10.607794999452631, 9.684004216385413, 8.727403163025897, 7.726936709615428, 6.773032103462845, 5.897815389834925, 4.869645857331773, 5.840643022239913, 6.770229622340551, 7.709184946692574, 8.760239161849755, 9.74623606925944, 9.759290980879413, 10.77255862266262, 11.735657316197337, 12.663694907375362, 13.521085641938983, 12.516541109444168, 11.580260012213529, 10.553001822828813, 9.588431186809308, 8.64848185648523, 7.715359971314125, 6.747792677759832, 5.809145842227101, 4.869747237169368, 3.9437720522474473, 4.906984290290397, 5.834701872985961, 6.908276911319933, 7.957732090297826, 8.82999775819589, 8.821211278119188, 9.78579605639822, 10.702682350212042, 11.683807426711237, 12.624267949179742, 11.613388061665518, 10.640244130441411, 9.698109336836994, 8.65463144882978, 7.723976513410299, 6.746768974501493, 5.82159551576445, 4.882635280685583, 3.9360267403550515, 2.9490401481221244, 3.944866585825989, 4.8842500211279, 5.9585086494774195, 6.920835346493637, 7.849309233012861, 7.774989301328281, 8.776596838832498, 9.720716504915423, 10.790082166106654, 11.76014389179601, 10.786516022159887, 9.829458913171955, 8.837916112484391, 7.8720366606004415, 6.9853516015056885, 5.983886599235731, 5.075417770166744, 4.129202000001192, 3.057518481273793, 1.991806918831987, 2.9426154655270915, 3.9269288662496127, 4.938550942376665, 5.854552346777261, 6.832604500340502, 6.902222167245546, 7.830175279191189, 8.848068153666132, 9.886687911184328, 10.900230114293167, 9.830482346611943, 8.89781921208087, 7.9523734243089645, 6.921272654970439, 5.996151324718433, 5.0325370409382035, 4.027787730692784, 3.0716991017782873, 2.0660893464050223, 1.0311454870252494, 1.980337752409898, 3.01813228273076, 3.944946111244103, 4.91919942366913, 5.946616788852631, 6.0469025178892855, 7.052867074793168, 8.106252069269901, 9.178164070920692, 10.002841747402604, 8.9930901920259, 8.009781242494874, 6.982630799707015, 6.01361408366373, 4.993803436915974, 4.025776798687689, 3.1002504685480594, 2.1131731370235505, 1.0704310137582542, 0.0, 1.0434029463127283, 1.9960022208960324, 2.984702604190711, 4.034421727140122, 5.003991082387689, 6.897193217749527, 7.947983030394225, 8.968565373684399, 9.936684873443252, 10.837365200503735, 9.822703081931762, 8.874051358332082, 7.936376962233752, 6.954118629288419, 5.924927895540021, 5.053971704930833, 4.010530339340216, 2.9746613556969472, 1.9598764349907152, 0.9359428808935655, 1.9602078249528778, 2.943915331891546, 3.932602708976125, 4.973147327718859, 5.919716768252814, 7.82295362052399, 8.76447900136955, 9.810940282388819, 10.807135111627748, 11.73249660761278, 10.83918426506619, 9.876261132202156, 8.851766172911955, 7.896476281813343, 6.927798459019918, 5.96915345994876, 4.917546867743093, 3.8948193295620563, 2.8269084253909584, 1.9001089777387028, 2.8861157780652666, 3.9002684886909247, 4.8948679745885935, 5.838773753877717, 6.875934407651289, 8.882198252867173, 9.798701522612223, 10.805591448821167, 11.738005426840573, 12.751087715269641, 11.771210634785778, 10.811346613087565, 9.811928717520372, 8.956521097221312, 7.9329542637679955, 6.911338335469091, 5.862937427751781, 4.832117182092585, 3.849692985799516, 2.851547871678729, 3.8441210190201343, 4.823745332057301, 5.78270196429082, 6.853961794048294, 7.8404107922094735, 9.784114905657795, 10.72993573475524, 11.763487816698301, 12.710671329747699, 13.642533321660725, 12.732723069413062, 11.79818618829919, 10.77527533349705, 9.841845874186411, 8.841443629566168, 7.773315406353196, 6.751182592308342, 5.790658118966408, 4.793711116505886, 3.8663506464858157, 4.817057381467979, 5.8230442524719335, 6.801877729621276, 7.787193269491036, 8.762416683747926, 10.610389233662211, 11.661155069106023, 12.689039034638396, 13.636059559263865, 14.623892505509886, 13.67438402059678, 12.73009582226641, 11.708279039489753, 10.703247299491021, 9.772825867269091, 8.725876269823425, 7.763143529454484, 6.722139882095961, 5.80186135624751, 4.905893115727485, 5.769923084131098, 6.721085445171547, 7.77678855623454, 8.714438577251903, 9.660391925107536, 11.589324978343567, 12.640137321022342, 13.663525523651481, 14.640080483333985, 14.553202735522751, 13.578718007812954, 13.703663316775096, 12.70434362527999, 11.752537651951375, 10.744972759023707, 9.673376500379764, 8.679980277203619, 7.7349701541510365, 6.853087828555864, 5.885517320935001, 6.725393200637033, 7.7431073106077335, 8.683959640051128, 9.628526556385488, 10.594524760760367, 12.580210181529829, 13.591895167265005, 14.55254713193092, 14.642088879342895, 13.693793697238878, 12.63640210655078, 13.61159009083315, 13.674943258058924, 12.778956586538317, 11.73355109836311, 10.661983948497836, 9.637237995887292, 8.662944973097488, 7.828504482680844, 6.827812514788136, 7.693935557490643, 8.683200896576881, 9.695946523662188, 10.694951153902828, 11.52136320148221], [11.593833397698731, 10.781680121906838, 9.806185473182275, 8.859514479004584, 7.843259716126194, 8.798373527173053, 9.82571734079103, 10.748994992428088, 11.688652129627188, 12.713078407372793, 13.766391083553795, 14.756808437905052, 14.681063539273278, 13.67267110633747, 12.684629248132184, 12.251431805103945, 12.904002707563297, 13.928375304791572, 13.630748626008877, 12.604011029658771, 12.612739175345308, 11.816197414145241, 10.796698351486278, 9.90131587998413, 8.873289145305353, 9.777575445490308, 10.775844044411219, 11.767839858204866, 12.744197936020278, 13.749886004560619, 14.703281692990497, 14.560328829458323, 13.726634688427367, 12.710207516010097, 11.75750125256153, 11.245551000555308, 11.978555030073993, 12.90687687473817, 13.772148438468731, 13.658519519605633, 13.656461828379033, 12.722708156748354, 11.765948564919762, 10.799782844756109, 9.800942411948778, 10.813756056292192, 11.778574143746738, 12.800462653173682, 13.760635127726383, 14.767889848257377, 14.491336508307633, 13.560543519518463, 12.725033359187277, 11.783507446230463, 10.809208672968701, 10.263058471272815, 10.905620763554209, 11.939412962651488, 12.846750287385564, 13.71197989893816, 13.504570779085942, 13.733798095869556, 12.749792486229842, 11.864337211861834, 10.862779678351663, 11.797085202983569, 12.74556598043614, 13.736674514838363, 14.722224864996644, 14.586708929341988, 13.625746051441178, 12.572178653697815, 11.765510469259269, 10.802962028903519, 9.789302717027107, 9.251982202686436, 9.97658685305155, 10.91170492885826, 11.86091609904112, 12.651440291005226, 12.578995127662328, 13.527956747525852, 13.805774125774775, 12.8545440463681, 11.845041600112003, 12.853043896147572, 13.799536051495894, 14.740239450777768, 14.404199492444066, 13.520170293497292, 12.570530324109125, 11.632808953285265, 10.81815414276346, 9.830808828568326, 8.810473470797525, 8.190837340580648, 8.977490991297737, 9.90635434107494, 10.9150533171782, 11.681221475059195, 11.570893034266305, 12.632632724745461, 13.581870621180487, 13.826433897766236, 12.78760443673238, 13.815184223907668, 14.752359677698731, 14.482225687609004, 13.47224613480888, 12.544712323179166, 11.598565431523692, 10.671879329431682, 9.791381174040298, 8.862422225705174, 7.884611855780043, 7.221950871812238, 7.957250618405593, 8.91528550786775, 9.967371289720639, 10.620549975005629, 10.690261036510266, 11.668048848540495, 12.629231325132613, 13.636225803040189, 13.75837617438327, 14.785497665986787, 14.574655333791368, 13.527559435673693, 12.559842371242077, 11.614605859900195, 10.577101345556217, 9.647993722485168, 8.795320681079811, 7.890628703853546, 6.9321319323510044, 6.154737065093471, 6.994996973770535, 7.939423570467855, 8.947815864024246, 9.691119645242788, 9.685307175203558, 10.685766174620094, 11.682018268498119, 12.673933065186416, 13.492786443178728, 14.542781472794596, 13.613555346055998, 12.546177451740528, 11.596922606356756, 10.673131823289538, 9.716530769930023, 8.716064316519553, 7.762159710366969, 6.88694299673905, 5.858773464235898, 5.100677880037697, 5.938422709002193, 6.877378033354216, 7.902743977630086, 8.754033415368243, 8.715888034566683, 9.729155676349892, 10.692254369884608, 11.620291961062634, 12.562025814679696, 13.505668716348293, 12.569387619117654, 11.542129429732938, 10.577558793713433, 9.637609463389355, 8.70448757821825, 7.736920284663956, 6.7982734491312256, 5.858874844073492, 4.932899659151572, 4.072256458052457, 4.880273034444543, 5.946124228909025, 6.914329143985097, 7.786594811883161, 7.777808331806458, 8.742393110085493, 9.659279403899314, 10.640404480398509, 11.598293362992385, 12.602515668569643, 11.629371737345537, 10.68723694374112, 9.643759055733906, 8.713104120314423, 7.735896581405618, 6.810723122668575, 5.871762887589708, 4.925154347259176, 3.9381677550262495, 3.110138753588049, 3.8775776893844416, 4.951836317733961, 5.877432400180908, 6.805906286700132, 6.731586355015552, 7.733193892519769, 8.677313558602695, 9.746679219793926, 10.7473472587088, 11.720975128344923, 10.872861859484683, 9.88131905879712, 8.91543960691317, 8.028754547818416, 7.0272895455484585, 6.064545377070869, 5.118329606905317, 4.046646088177918, 2.980934525736112, 2.0474291084468823, 2.9135280961564285, 3.925150172283481, 4.811149400464532, 5.789201554027773, 5.858819220932817, 6.78677233287846, 7.804665207353403, 8.8432849648716, 9.890672690745335, 10.873885292924669, 9.941222158393597, 8.99577637062169, 7.964675601283166, 7.03955427103116, 6.075939987250931, 5.071190677005511, 4.060826708682413, 3.0552169533091473, 2.0202730939293745, 1.0710808285447257, 1.9747293364180316, 2.9015431649313745, 3.875796477356401, 4.903213842539902, 5.003499571576557, 6.00946412848044, 7.062849122957173, 8.134761124607964, 9.200069912765741, 10.036493138338628, 9.053184188807602, 8.026033746019742, 7.057017029976457, 6.0372063832287015, 5.069179745000416, 4.143653414860787, 3.1565760833362786, 2.1138339600709823, 1.0434029463127283, 0.0, 0.952599274583304, 1.9412996578779826, 2.9910187808273943, 3.9605881360749606, 5.8937444472668465, 6.944534259911544, 7.965116603201718, 8.93323610296057, 10.006489275162497, 10.86610602824449, 9.91745430464481, 8.97977990854648, 7.997521575601146, 6.968330841852748, 6.097374651243561, 5.053933285652944, 4.018064302009676, 3.0032793813034435, 1.9793458272062938, 1.007638472207514, 1.9913459791461818, 2.980033356230761, 3.9696985572361774, 4.916267997770133, 6.866626398168085, 7.808151779013645, 8.854613060032914, 9.850807889271843, 10.776169385256875, 11.77221564318064, 10.919664078514884, 9.895169119224683, 8.93987922812607, 7.971201405332646, 7.0125564062614885, 5.960949814055821, 4.938222275874784, 3.8703113717036866, 2.943511924051431, 1.9335464253199028, 2.947699135945561, 3.9422986218432294, 4.886204401132353, 5.923365054905925, 7.925871030511268, 8.842374300256319, 9.849264226465262, 10.781678204484669, 11.794760492913737, 12.704242012900227, 11.854749559400293, 10.8553316638331, 9.999924043534039, 8.976357210080723, 7.954741281781818, 6.9063403740645075, 5.875520128405312, 4.893095932112244, 3.894950817991457, 2.960882630658844, 3.9405069436960116, 4.899463575929531, 5.905304074996475, 6.891753073157655, 8.873306201581327, 9.819127030678773, 10.807160594342397, 11.754344107391795, 12.68620609930482, 13.705006661913352, 12.841589134611919, 11.818678279809777, 10.885248820499138, 9.884846575878894, 8.816718352665923, 7.794585538621069, 6.834061065279135, 5.837114062818614, 4.896137324244102, 3.933818993106689, 4.939805864110643, 5.918639341259986, 6.876384565414568, 7.851607979671458, 9.699580529585742, 10.750346365029555, 11.778230330561929, 12.725250855187397, 13.667565283153982, 14.662800436248965, 13.773498768579138, 12.751681985802481, 11.74665024580375, 10.81622881358182, 9.769279216136153, 8.806546475767211, 7.765542828408688, 6.83344471809297, 5.862320344575906, 4.886684695769808, 5.837847056810257, 6.89355016787325, 7.803629873175434, 8.749583221031067, 10.69961636234212, 11.729328616945875, 12.752716819575014, 13.729271779257518, 14.222743565314488, 14.56784561471708, 14.747066263087824, 13.747746571592717, 12.7959405982641, 11.788375705336433, 10.71677944669249, 9.723383223516345, 8.778373100463764, 7.847773997818243, 6.841944549783422, 5.8421548122757425, 6.859868922246443, 7.800721251689838, 8.745288168024198, 9.704816144758919, 11.69050156552838, 12.702186551263557, 13.662838515929472, 13.933310888624256, 13.261246240993867, 13.625529713454904, 14.600717697737275, 14.718346204371652, 13.822359532851044, 12.776954044675836, 11.705386894810562, 10.680640942200018, 9.706347919410215, 8.823190651943223, 7.784239743636557, 6.8106971691293525, 7.799962508215591, 8.812708135300898, 9.811712765541538, 10.631654585480762], [10.65339722701485, 9.918857339916267, 8.995061054753496, 8.182915470939975, 8.795858990709498, 9.750972801756356, 10.778316615374333, 11.70159426701139, 12.641251404210491, 13.665677681956096, 14.718990358137098, 15.709407712488355, 15.562320661148284, 14.553928228212476, 13.56588637000719, 12.891253556006781, 11.951403432979994, 12.97577603020827, 12.690312455324996, 11.66357485897489, 11.672303004661426, 10.97416168590629, 9.985573933057498, 9.22471687191952, 9.825888419888656, 10.730174720073611, 11.728443318994522, 12.720439132788169, 13.696797210603581, 14.702485279143922, 15.6558809675738, 15.47544507271296, 14.607891810302373, 13.591464637885103, 12.638758374436536, 11.885372751458144, 11.02595575549069, 11.954277600154867, 12.819549163885426, 12.718083348921752, 12.716025657695152, 11.921707986216752, 10.964948394388163, 10.214503950264012, 10.753541686532081, 11.766355330875495, 12.731173418330041, 13.753061927756985, 14.713234402309686, 15.72048912284068, 15.40645275156227, 14.4756597627731, 13.606290481062283, 12.664764568105468, 11.690465794843707, 10.902880222175652, 9.953021488970906, 10.986813688068185, 11.89415101280226, 12.759380624354856, 12.551971504502637, 12.932797925337955, 11.948792315698242, 11.279058317369737, 11.815378952934966, 12.749684477566872, 13.698165255019443, 14.689273789421666, 15.674824139579947, 15.501825172596625, 14.540862294695815, 13.487294896952452, 12.646767591134275, 11.684219150778524, 10.670559838902113, 9.95250620490838, 9.023987578468248, 9.959105654274957, 10.908316824457815, 11.698841016421921, 11.626395853079023, 12.575357472942548, 13.004773955243177, 12.34357675306731, 12.797640874695306, 13.805643170730875, 14.752135326079197, 15.69283872536107, 15.319315735698703, 14.43528653675193, 13.485646567363762, 12.547925196539902, 11.699411264638465, 10.712065950443332, 9.691730592672531, 8.90087081347569, 8.024891716714434, 8.953755066491636, 9.962454042594896, 10.72862220047589, 10.618293759683, 11.680033450162156, 12.629271346597182, 13.39862349105838, 13.740203711315683, 14.76778349849097, 15.704958952282034, 15.397341930863641, 14.387362378063518, 13.459828566433803, 12.51368167477833, 11.58699557268632, 10.672638295915304, 9.74367934758018, 8.76586897765505, 7.9319843447072795, 7.004651343822289, 7.962686233284446, 9.014772015137334, 9.667950700422324, 9.737661761926962, 10.71544957395719, 11.676632050549308, 12.683626528456884, 13.565543017474821, 14.61633302514829, 15.489771577046005, 14.44267567892833, 13.474958614496714, 12.529722103154832, 11.492217588810854, 10.563109965739805, 9.71043692433445, 8.793962014989242, 7.813389054226012, 6.908960161608471, 6.042397699187231, 6.986824295884551, 7.995216589440942, 8.738520370659483, 8.732707900620253, 9.733166900036789, 10.729418993914814, 11.721333790603113, 12.540187168595425, 13.590182198211293, 14.528671589310635, 13.461293694995165, 12.512038849611393, 11.588248066544175, 10.63164701318466, 9.63118055977419, 8.677275953621608, 7.790276307874747, 6.7400305861109056, 5.854900976552697, 4.985823434418889, 5.924778758770912, 6.9501447030467824, 7.801434140784939, 7.7632887599833795, 8.776556401766587, 9.739655095301305, 10.66769268647933, 11.609426540096393, 12.600212440217305, 13.484503862372291, 12.457245672987575, 11.49267503696807, 10.552725706643992, 9.619603821472888, 8.652036527918595, 7.7133896923858645, 6.773991087328131, 5.81415678102658, 4.826479554567457, 3.9276737598612392, 4.993524954325721, 5.961729869401793, 6.833995537299857, 6.825209057223154, 7.789793835502188, 8.70668012931601, 9.687805205815206, 10.645694088409082, 11.656573975923306, 12.544487980600174, 11.602353186995757, 10.558875298988543, 9.628220363569062, 8.651012824660256, 7.725839365923214, 6.786879130844347, 5.840270590513815, 4.853283998280888, 3.864361850103049, 2.9249784148011377, 3.999237043150657, 4.924833125597604, 5.8533070121168285, 5.778987080432248, 6.780594617936465, 7.724714284019391, 8.794079945210623, 9.794747984125497, 10.76837585376162, 11.825461134067988, 10.833918333380424, 9.868038881496474, 8.959952794015432, 7.958487791745475, 6.9796616203255075, 6.033445850159956, 4.961762331432557, 3.896050768990751, 2.945242222295646, 1.9609288215731246, 2.9725508977001773, 3.8585501258812283, 4.836602279444469, 4.9062199463495135, 5.834173058295156, 6.852065932770099, 7.890685690288296, 8.93807341616203, 10.007821183843255, 10.893821432976903, 9.948375645204997, 8.917274875866472, 7.992153545614465, 7.0285392618342355, 6.023789951588816, 5.013425983265717, 4.007816227892452, 2.9728723685126783, 2.02368010312803, 1.0221300618347278, 1.9489438903480707, 2.923197202773097, 3.950614567956598, 4.0509002969932535, 5.056864853897136, 6.11024984837387, 7.18216185002466, 8.247470638182437, 9.25722219355914, 10.005783463390907, 8.978633020603047, 8.009616304559762, 6.989805657812006, 6.021779019583721, 5.096252689444092, 4.109175357919583, 3.0664332346542866, 1.9960022208960324, 0.952599274583304, 0.0, 0.9887003832946786, 2.0384195062440904, 3.007988861491657, 4.941145172683542, 5.991934985328239, 7.012517328618413, 7.980636828377266, 9.053890000579193, 10.068552119151166, 10.870053579228115, 9.932379183129784, 8.950120850184451, 7.920930116436053, 7.0499739258268646, 6.006532560236248, 4.97066357659298, 3.955878655886748, 2.931945101789598, 1.9602377467908179, 1.0542559494574515, 2.03959718554688, 3.0170992826528735, 3.9636687231868284, 5.9140271235847806, 6.8555525044303405, 7.9020137854496095, 8.898208614688539, 9.823570110673572, 10.819616368597337, 11.782539501461372, 10.847768393807987, 9.892478502709375, 8.923800679915951, 7.965155680844793, 6.913549088639126, 5.890821550458089, 4.82291064628699, 3.896111198634735, 2.8861456999032065, 2.0710191859268168, 3.001862451159348, 3.9457682304484725, 4.982928884222043, 6.973271755927963, 7.889775025673014, 8.896664951881958, 9.829078929901364, 10.842161218330432, 11.751642738316924, 12.756603421528279, 11.807930938416405, 10.952523318117343, 9.928956484664027, 8.907340556365122, 7.858939648647812, 6.828119402988617, 5.845695206695548, 4.847550092574761, 3.913481905242148, 3.0722418104316223, 4.031198442665141, 4.964867904312594, 5.951316902473773, 7.932870030897446, 8.878690859994892, 9.854561319759092, 10.80174483280849, 11.733606824721516, 12.752407387330047, 13.686944268443918, 12.771277554393082, 11.837848095082443, 10.837445850462199, 9.769317627249228, 8.747184813204374, 7.78666033986244, 6.789713337401918, 5.848736598827406, 4.886418267689993, 4.071540730846254, 5.050374207995596, 5.935948394730687, 6.911171808987577, 8.75914435890186, 9.809910194345674, 10.837794159878047, 11.784814684503516, 12.714966008570677, 13.71020116166566, 14.65448935999603, 13.704281260385786, 12.699249520387054, 11.768828088165124, 10.721878490719458, 9.759145750350516, 8.718142102991992, 7.786043992676275, 6.81491961915921, 5.839283970353112, 5.026722638381479, 6.075508747322506, 6.863193702491553, 7.809147050347186, 9.759180191658238, 10.788892446261993, 11.812280648891132, 12.788835608573637, 13.778558590611556, 14.637333358842726, 15.628056854504715, 14.700345846176022, 13.748539872847402, 12.740974979919736, 11.669378721275793, 10.675982498099648, 9.730972375047067, 8.800373272401547, 7.794543824366726, 6.794754086859046, 6.048744503817665, 6.98959683326106, 7.882465386033626, 8.764379974075037, 10.7500653948445, 11.761750380579675, 12.722402345245591, 12.980711614040953, 13.901067991896703, 14.50678683532991, 15.481974819612281, 15.670945478954957, 14.774958807434347, 13.72955331925914, 12.657986169393865, 11.63324021678332, 10.658947193993518, 9.775789926526528, 8.736839018219861, 7.763296443712656, 7.123363500150981, 8.00158371687212, 8.948889983550966, 9.69121841479688], [9.664696843720172, 8.93015695662159, 8.180183273999997, 9.130159388394198, 9.784559374004177, 10.739673185051036, 11.767016998669014, 12.69029465030607, 13.62995178750517, 14.654378065250775, 15.707690741431778, 16.698108095783034, 16.472607163057003, 15.464214730121194, 14.476172871915908, 13.8015400579155, 12.861689934888712, 12.292035778430817, 11.701612072030319, 10.674874475680213, 10.683602621366749, 9.985461302611613, 9.170696152304, 10.119233373507692, 10.814588803183335, 11.71887510336829, 12.717143702289203, 13.70913951608285, 14.68549759389826, 15.691185662438603, 16.64458135086848, 16.385731574621676, 15.518178312211091, 14.501751139793821, 13.549044876345254, 12.795659253366862, 11.936242257399408, 11.261710941966538, 11.881697821810784, 11.729382965627074, 11.727325274400474, 11.019312755849503, 10.150070613634664, 11.109020451852183, 11.74224206982676, 12.755055714170176, 13.719873801624722, 14.741762311051666, 15.701934785604365, 16.70918950613536, 16.31673925347099, 15.385946264681818, 14.516576982971001, 13.575051070014187, 12.600752296752425, 11.81316672408437, 10.863307990879624, 10.24830909694127, 10.956299670727617, 11.81603946923689, 11.60863034938467, 12.030402694970705, 11.133914534944743, 12.062523554449394, 12.804079336229645, 13.738384860861553, 14.686865638314124, 15.677974172716347, 16.663524522874628, 16.412111674505343, 15.451148796604533, 14.39758139886117, 13.557054093042993, 12.594505652687243, 11.580846340810831, 10.862792706817098, 9.934274080376966, 9.220601063148042, 9.970465482383172, 10.755499861303955, 10.683054697961056, 11.632016317824581, 12.189896174489679, 13.127041990146967, 13.786341257989985, 14.794343554025556, 15.740835709373878, 16.681539108655752, 16.229602237607423, 15.345573038660648, 14.39593306927248, 13.45821169844862, 12.609697766547184, 11.62235245235205, 10.60201709458125, 9.811157315384408, 8.93517821862315, 8.170949437025719, 9.024602700520253, 9.785281045357923, 9.674952604565034, 10.73669229504419, 11.685930191479216, 12.611317109123055, 13.592973600007742, 14.62055338718303, 15.557728840974093, 16.307628432772358, 15.297648879972236, 14.370115068342521, 13.423968176687048, 12.497282074595038, 11.582924797824022, 10.653965849488898, 9.676155479563768, 8.842270846615998, 7.914937845731006, 7.172524450618106, 8.076920673062691, 8.724609545304357, 8.794320606808993, 9.772108418839222, 10.73329089543134, 11.740285373338915, 12.622201862356851, 13.67299187003032, 14.60243698664667, 15.352962180837048, 14.385245116405432, 13.44000860506355, 12.402504090719573, 11.473396467648524, 10.620723426243167, 9.704248516897959, 8.72367555613473, 7.819246663517189, 6.952684201095948, 6.19666251321821, 7.0573652473663, 7.795179215541515, 7.789366745502285, 8.78982574491882, 9.786077838796846, 10.777992635485143, 11.596846013477455, 12.646841043093323, 13.62614553975579, 14.371580196903883, 13.422325351520112, 12.498534568452893, 11.541933515093378, 10.541467061682908, 9.587562455530325, 8.700562809783463, 7.650317088019623, 6.765187478461415, 5.896109936327607, 5.134616976104571, 6.006803547928814, 6.85809298566697, 6.819947604865411, 7.833215246648619, 8.796313940183335, 9.72435153136136, 10.666085384978423, 11.656871285099335, 12.593152382329974, 13.367532174896294, 12.402961538876788, 11.46301220855271, 10.529890323381606, 9.562323029827311, 8.623676194294582, 7.6842775892368484, 6.724443282935297, 5.736766056476174, 4.837960261769957, 4.063251665105539, 5.018388714283825, 5.890654382181888, 5.881867902105186, 6.846452680384219, 7.763338974198041, 8.744464050697236, 9.702352933291111, 10.713232820805336, 11.686376752029442, 12.512639688904475, 11.469161800897261, 10.53850686547778, 9.561299326568975, 8.636125867831932, 7.697165632753064, 6.750557092422532, 5.763570500189606, 4.774648352011766, 3.835264916709855, 3.0689637539304746, 3.9814919704796354, 4.90996585699886, 4.83564592531428, 5.837253462818497, 6.781373128901422, 7.850738790092653, 8.851406829007527, 9.82503469864365, 10.893494730359368, 11.822618716675102, 10.856739264791152, 9.87023929592415, 8.868774293654193, 7.889948122234225, 6.943732352068674, 5.872048833341275, 4.806337270899468, 3.855528724204363, 2.871215323481842, 2.0382541321469123, 2.91520897076326, 3.893261124326501, 3.962878791231545, 4.890831903177188, 5.9087247776521306, 6.947344535170328, 7.994732261044063, 9.064480028725288, 9.99714316325636, 10.937076028499675, 9.90597525916115, 8.980853928909143, 8.017239645128914, 7.012490334883494, 5.963516901902555, 4.95790714652929, 3.922963287149517, 2.9737710217648683, 1.9324165637434452, 1.0056027352301022, 1.9798560476551288, 3.0072734128386296, 3.0621999136985742, 4.068164470602457, 5.121549465079191, 6.193461466729981, 7.258770254887757, 8.268521810264462, 9.251830759795487, 9.967333403897724, 8.99831668785444, 7.978506041106685, 7.010479402878399, 6.08495307273877, 5.097875741214262, 4.055133617948965, 2.984702604190711, 1.9412996578779826, 0.9887003832946786, 0.0, 1.0497191229494116, 2.0192884781969775, 3.9524447893888626, 5.00323460203356, 6.023816945323734, 6.991936445082587, 8.065189617284513, 9.079851735856487, 10.028503459456166, 10.921079566424462, 9.938821233479128, 8.909630499730731, 8.038674309121543, 6.995232943530926, 5.959363959887658, 4.944579039181426, 3.9206454850842767, 2.9489381300854967, 2.039584179336781, 1.0508968022522016, 2.0283988993581943, 2.974968339892149, 4.925326740290101, 5.866852121135661, 6.91331340215493, 7.909508231393859, 8.83486972737889, 9.830915985302656, 10.79383911816669, 11.818334077456893, 10.881178886004054, 9.91250106321063, 8.953856064139472, 7.902249471933805, 6.879521933752768, 5.81161102958167, 4.884811581929414, 3.8748460831978857, 3.0277027943113257, 2.01316206786467, 2.957067847153794, 3.994228500927365, 5.984571372633284, 6.901074642378335, 7.907964568587278, 8.840378546606685, 9.853460835035753, 10.762942355022243, 11.767903038233598, 12.767320933800791, 11.941223701412023, 10.917656867958707, 9.896040939659802, 8.847640031942491, 7.816819786283296, 6.834395589990226, 5.83625047586944, 4.902182288536827, 4.019485727885845, 3.0605290956523263, 3.9761675210179153, 4.962616519179095, 6.944169647602767, 7.889990476700213, 8.865860936464413, 9.81304444951381, 10.744906441426837, 11.763707004035368, 12.698243885149239, 13.72115473995138, 12.826548478377122, 11.826146233756878, 10.758018010543907, 9.735885196499053, 8.77536072315712, 7.778413720696596, 6.837436982122085, 5.875118650984672, 5.018784648300477, 4.079704860982782, 4.947248011436009, 5.922471425692898, 7.770443975607183, 8.821209811050995, 9.849093776583368, 10.796114301208837, 11.726265625275998, 12.72150077837098, 13.66578897670135, 14.687605759478007, 13.687949903681734, 12.757528471459803, 11.710578874014137, 10.747846133645195, 9.706842486286671, 8.774744375970954, 7.803620002453889, 6.827984353647791, 5.973966555835702, 5.104839400309692, 5.8744933191968745, 6.820446667052508, 8.770479808363561, 9.800192062967314, 10.823580265596453, 11.800135225278957, 12.789858207316877, 13.648632975548047, 14.639356471210036, 15.683670345268244, 14.737240256142083, 13.729675363214415, 12.658079104570472, 11.664682881394327, 10.719672758341746, 9.789073655696225, 8.783244207661404, 7.783454470153726, 6.995988421271888, 6.174719052507561, 6.893765002738949, 7.77567959078036, 9.761365011549822, 10.773049997284998, 11.733701961950914, 12.780709933470959, 13.729005115574976, 14.590948876810222, 15.574276291356151, 16.59417542749621, 15.763659190729026, 14.718253702553818, 13.646686552688545, 12.621940600078, 11.647647577288197, 10.764490309821205, 9.725539401514538, 8.751996827007336, 8.070607417605205, 7.18670593611862, 7.960189600256289, 8.702518031502203], [8.753477111800448, 8.018937224701864, 8.932576408646018, 9.9234515501186, 10.827240523093446, 11.782354334140305, 12.809698147758283, 13.740013773255479, 14.679670910454579, 15.704097188200183, 16.757409864381188, 17.526048917192533, 16.460996192742357, 15.452603759806546, 14.482130219183531, 13.711410855868433, 12.782609418935454, 11.773131326602824, 10.790392340110596, 9.763654743760489, 9.772382889447025, 9.074241570691887, 9.92308928695002, 10.871626508153712, 11.857269952272604, 12.76155625245756, 13.759824851378472, 14.751820665172119, 15.735216716847669, 16.74090478538801, 17.69430047381789, 17.340714561938277, 16.473161299527696, 15.456734127110424, 14.504027863661857, 13.750642240683467, 12.871746953188026, 11.943425108523849, 10.888174184277332, 10.81816323370735, 10.816105542480752, 10.108093023929777, 10.902463748280685, 11.861413586498204, 12.78492321891603, 13.797736863259445, 14.76255495071399, 15.784443460140935, 16.751653908553774, 17.758908629084768, 17.27172224078759, 16.340929251998418, 15.471559970287604, 14.53003405733079, 13.555735284069028, 12.768149711400975, 11.818290978196229, 10.97797900268259, 9.962776033194165, 10.822515831703438, 10.615106711851219, 11.11918296305098, 11.886307669590764, 12.814916689095414, 13.846760485318914, 14.781066009950822, 15.729546787403393, 16.720655321805616, 17.706205671963897, 17.36709466182194, 16.406131783921133, 15.352564386177772, 14.512037080359596, 13.549488640003846, 12.535829328127434, 11.817775694133703, 10.88925706769357, 9.97052099801126, 8.976941844849721, 9.761976223770503, 9.689531060427605, 10.63849268029113, 11.638406654925678, 12.667462484065801, 13.500711698030585, 14.56651986794579, 15.567579839238162, 16.453740730707842, 17.184585224924025, 16.300556025977247, 15.350916056589082, 14.413194685765221, 13.564680753863787, 12.577335439668653, 11.557000081897852, 10.766140302701011, 9.890161205939755, 9.019325485962604, 8.031079062986802, 8.791757407824472, 8.681428967031582, 9.743168657510738, 10.692406553945764, 11.617793471589604, 12.558148861410208, 13.585728648585494, 14.522904102376557, 15.491433863573379, 16.252631867288837, 15.325098055659122, 14.378951164003649, 13.452265061911639, 12.537907785140625, 11.608948836805501, 10.63113846688037, 9.7972538339326, 8.86992083304761, 8.02090049955499, 7.083397035529241, 7.731085907770906, 7.8007969692755434, 8.778584781305772, 9.73976725789789, 10.746761735805466, 11.587377123759317, 12.638167131432786, 13.567612248049135, 14.555796420045093, 15.340228103722033, 14.394991592380151, 13.357487078036174, 12.428379454965125, 11.575706413559768, 10.659231504214562, 9.678658543451332, 8.774229650833792, 7.907667188412551, 7.045038562155095, 6.063841609832849, 6.801655578008065, 6.795843107968834, 7.796302107385371, 8.792554201263396, 9.74316789688761, 10.562021274879921, 11.61201630449579, 12.591320801158256, 13.574414436111928, 14.377308338836713, 13.453517555769494, 12.496916502409979, 11.49645004899951, 10.542545442846926, 9.655545797100066, 8.605300075336226, 7.720170465778018, 6.8510929236442095, 5.982993025041456, 5.013279910395363, 5.86456934813352, 5.82642396733196, 6.798390508051085, 7.761489201585802, 8.689526792763827, 9.63126064638089, 10.622046546501801, 11.55832764373244, 12.570366414104338, 13.35794452619339, 12.417995195869311, 11.484873310698207, 10.517306017143913, 9.578659181611183, 8.63926057655345, 7.6794262702519, 6.691749043792777, 5.7929432490865596, 4.911627714042424, 4.024865076750374, 4.897130744648438, 4.888344264571735, 5.811627941786686, 6.728514235600508, 7.709639312099702, 8.667528194693578, 9.678408082207802, 10.651552013431909, 11.593686807036326, 12.424144788213862, 11.493489852794381, 10.516282313885576, 9.591108855148534, 8.652148620069665, 7.7055400797391345, 6.718553487506208, 5.729631339328369, 4.790247904026458, 3.9173398028673594, 2.987968332946185, 3.9164422194654094, 3.842122287780829, 4.802428724220963, 5.7465483903038885, 6.8159140514951195, 7.816582090409993, 8.790209960046116, 9.858669991761834, 10.850212792449398, 11.816092244333348, 10.825222283240754, 9.823757280970796, 8.844931109550828, 7.898715339385276, 6.827031820657877, 5.76132025821607, 4.810511711520966, 3.8261983107984445, 2.886630181083797, 1.9216853332298092, 2.8997374867930503, 2.9280540526340113, 3.856007164579654, 4.873900039054597, 5.912519796572794, 6.959907522446529, 8.029655290127755, 8.962318424658827, 9.907764212430733, 10.899234483442433, 9.974113153190427, 8.994243775321904, 7.989494465076484, 6.918499889219158, 5.912890133845893, 4.87794627446612, 3.9287540090814708, 2.8873995510600476, 1.9605857225467047, 0.986332410121678, 1.9724486742410956, 2.012480790749163, 3.0184453476530457, 4.071830342129779, 5.143742343780569, 6.209051131938345, 7.2188026873150495, 8.202111636846075, 9.229262079633935, 10.048035810803851, 9.028225164056096, 8.060198525827811, 7.134672195688181, 6.147594864163673, 5.104852740898377, 4.034421727140122, 2.9910187808273943, 2.0384195062440904, 1.0497191229494116, 0.0, 0.9695693552475662, 2.9027256664394514, 3.9535154790841487, 4.974097822374323, 5.9422173221331755, 7.015470494335103, 8.030132612907076, 8.978784336506756, 9.916458732605086, 10.968633161836499, 9.959349622680143, 9.088393432070955, 8.044952066480338, 7.009083082837069, 5.994298162130837, 4.970364608033687, 3.9916192791747642, 3.0079117722360964, 2.019224395151517, 0.9786797764087829, 1.9252492169427378, 3.8756076173406897, 4.81713299818625, 5.86359427920552, 6.859789108444449, 7.785150604429481, 8.781196862353248, 9.744119995217282, 10.768614954507484, 11.723904845606096, 10.96222018616004, 10.003575187088883, 8.951968594883216, 7.929241056702178, 6.86133015253108, 5.934530704878824, 4.917527232287153, 3.9960303872106415, 2.9814896607639856, 2.045848115234069, 2.9803573675206882, 4.934852249683873, 5.851355519428925, 6.858245445637868, 7.790659423657274, 8.803741712086342, 9.713223232072835, 10.71818391528419, 11.717601810851383, 12.774998154124651, 11.967375990908117, 10.945760062609212, 9.897359154891902, 8.866538909232705, 7.8841147129396365, 6.88596959881885, 5.944863437626094, 4.98781332078516, 4.028856688551642, 3.0649477890981904, 3.988274658970645, 5.9351869197369655, 6.881007748834412, 7.816141813515002, 8.7633253265644, 9.695187318477426, 10.713987881085957, 11.648524762199829, 12.67143561700197, 13.64387946788569, 12.875865356706287, 11.807737133493315, 10.785604319448462, 9.825079846106528, 8.828132843646006, 7.880118131211352, 6.917799800073939, 5.987112241199792, 5.021343819386044, 4.036028279516284, 5.011251693773174, 6.859224243687458, 7.812227083185194, 8.801289383747893, 9.748309908373361, 10.676546502326588, 11.67178165542157, 12.61606985375194, 13.637886636528597, 14.642918376527328, 13.807247594409212, 12.760297996963546, 11.797565256594604, 10.75656160923608, 9.81742552506022, 8.846301151543155, 7.870665502737058, 6.942294148735016, 6.011857449387085, 4.96327358727715, 5.909226935132783, 7.859260076443836, 8.791209335101513, 9.814597537730652, 10.752330832443482, 11.740139084367467, 12.598913852598637, 13.589637348260625, 14.633951222318833, 15.685056948978085, 14.779394486163824, 13.70779822751988, 12.714402004343736, 11.769391881291154, 10.831754804785492, 9.825925356750671, 8.826135619242994, 7.8679645165969765, 6.927112187153582, 5.982545270819223, 6.864459858860635, 8.850145279630098, 9.858507556963616, 10.819159521629532, 11.753301237874496, 12.701596419978513, 13.541229753860812, 14.52455716840674, 15.5444563045468, 16.4862117100323, 15.767972825503227, 14.696405675637953, 13.671659723027409, 12.697366700237605, 11.807171458910473, 10.768220550603806, 9.794677976096605, 8.942583512930293, 7.939099070764641, 7.048969868336563, 7.791298299582478], [8.050444381269905, 8.98850657994943, 9.902145763893584, 10.893020905366164, 11.796809878341012, 12.751923689387871, 13.779267503005848, 14.709583128503047, 15.649240265702147, 16.67366654344775, 17.63081939835866, 16.640402044007402, 15.575349319557226, 14.566956886621417, 13.596483345998402, 12.82580397139288, 11.912936375960472, 10.90345828362784, 9.92637095336474, 9.05747987623354, 9.069350158916482, 10.043810925939454, 10.892658642197588, 11.84119586340128, 12.82683930752017, 13.731125607705126, 14.729394206626036, 15.721390020419683, 16.704786072095235, 17.71047414063558, 18.511596790867063, 17.551554717161913, 16.492744777434893, 15.476317605017623, 14.523611341569056, 13.831684775941516, 12.838384053449776, 11.93378312009212, 10.974460949197269, 10.115130503176808, 10.113072811950207, 11.054227951773099, 11.872033103528253, 12.830982941745772, 13.754492574163596, 14.76730621850701, 15.732124305961555, 16.7540128153885, 17.721223263801342, 18.728477984332336, 18.241291596035158, 17.310498607245986, 16.33729959240717, 15.341324757969474, 14.367025984707713, 13.428392949181589, 12.478534215976843, 11.621840234338805, 10.60663726485038, 9.85594491169742, 9.6485357918452, 10.585949856865497, 11.608807202767277, 12.537416222271927, 13.51340426454336, 14.538846223466066, 15.487327000918638, 16.47843553532086, 17.4559235288855, 18.33666401706951, 17.3757011391687, 16.32213374142534, 15.481606435607162, 14.519057995251412, 13.505398683375, 12.478018931914317, 11.549500305474185, 10.614382229667475, 9.620803076505936, 8.795405303764486, 8.722960140421586, 9.67192176028511, 10.671835734919659, 11.700891564059782, 12.531142342783019, 13.596950512698221, 14.598010483990597, 15.484171375460278, 16.463797418761125, 17.270125381224815, 16.32048541183665, 15.38276404101279, 14.534250109111353, 13.54690479491622, 12.526569437145419, 11.583922700854842, 10.622213278647106, 9.693349928869903, 8.674940294643017, 7.825186487818454, 7.714858047025563, 8.77659773750472, 9.725835633939745, 10.651222551583585, 11.588579506162642, 12.61615929333793, 13.553334747128993, 14.521864508325814, 15.531844061125938, 16.29466741090669, 15.348520519251217, 14.421834417159207, 13.507477140388191, 12.578518192053068, 11.600707822127937, 10.706689131756033, 9.779356130871042, 8.751893810525406, 7.727258267185455, 6.764514987764887, 6.834226049269525, 7.812013861299754, 8.773196337891871, 9.780190815799447, 10.617807768511751, 11.66859777618522, 12.598042892801569, 13.586227064797527, 14.547651272404922, 15.36456094762772, 14.327056433283742, 13.397948810212693, 12.545275768807336, 11.628800859462128, 10.648227898698899, 9.743799006081359, 8.817102486235983, 7.776031873125511, 6.76763957956912, 5.835084658002046, 5.8292721879628155, 6.829731187379352, 7.825983281257377, 8.773598541640043, 9.592451919632355, 10.642446949248223, 11.62175144591069, 12.604845080864362, 13.584731507519601, 14.423086911017062, 13.466485857657547, 12.466019404247078, 11.512114798094494, 10.625115152347632, 9.574869430583792, 8.689739821025585, 7.820662278891776, 6.935049550694368, 5.883995335537186, 4.897998428127501, 4.859853047325942, 5.828821152803519, 6.791919846338236, 7.7199574375162605, 8.661691291133323, 9.652477191254235, 10.588758288484874, 11.600797058856772, 12.565367694876278, 13.38756455111688, 12.454442665945775, 11.48687537239148, 10.548228536858751, 9.608829931801019, 8.648995625499467, 7.6613183990403435, 6.762512604334126, 5.88119706928999, 4.96396692578896, 3.930559824642419, 3.9217733445657164, 4.842058586539119, 5.758944880352941, 6.740069956852135, 7.697958839446011, 8.708838726960236, 9.681982658184342, 10.62411745178876, 11.667595339795973, 12.46305920804195, 11.485851669133144, 10.560678210396102, 9.621717975317233, 8.675109434986702, 7.688122842753774, 6.699200694575936, 5.759817259274024, 4.886909158114926, 3.957537688193751, 2.9498712994593905, 2.8755513677748104, 3.8328593689733967, 4.776979035056322, 5.846344696247553, 6.847012735162426, 7.82064060479855, 8.889100636514268, 9.880643437201831, 10.846522889085781, 11.79479163848832, 10.793326636218362, 9.814500464798394, 8.868284694632843, 7.796601175905443, 6.730889613463637, 5.780081066768532, 4.795767666046011, 3.8561995363313635, 2.8912546884773755, 1.9331665667870315, 1.9584846973864452, 2.8864378093320875, 3.9043306838070304, 4.942950441325228, 5.990338167198963, 7.060085934880188, 7.9927490694112615, 8.938194857183166, 9.969295626521692, 10.894416956773698, 9.96381313056947, 8.95906382032405, 7.888069244466723, 6.882459489093458, 5.847515629713685, 4.898323364329037, 3.8569689063076136, 2.9301550777942706, 1.9559017653692443, 1.0028793189935294, 1.042911435501597, 2.04887599240548, 3.1022609868822135, 4.1741729885330034, 5.23948177669078, 6.249233332067483, 7.2325422815985085, 8.259692724386369, 9.228709440429654, 9.99779451930366, 9.029767881075376, 8.104241550935747, 7.117164219411238, 6.074422096145942, 5.003991082387688, 3.9605881360749597, 3.007988861491656, 2.0192884781969775, 0.9695693552475662, 0.0, 2.0330526234644686, 2.989143561979329, 4.009725905269503, 4.977845405028356, 6.051098577230283, 7.065760695802256, 8.014412419401935, 8.952086815500266, 10.004261244731678, 10.928918977927708, 10.057962787318521, 9.014521421727904, 7.9786524380846355, 6.963867517378404, 5.939933963281254, 4.961188634422331, 3.977481127483663, 2.9887937503990836, 1.948249131656349, 1.0555761739677552, 3.005934574365707, 3.9474599552112672, 4.993921236230537, 5.97414223525932, 6.899503731244352, 7.895549989168119, 8.858473122032153, 9.882968081322355, 10.838257972420967, 11.806935795214391, 10.973144542336449, 9.921537950130782, 8.898810411949745, 7.830899507778646, 6.904100060126391, 5.887096587534719, 4.965599742458208, 3.951059016011552, 3.0154174704816348, 2.110684324545706, 4.06517920670889, 4.981682476453941, 5.988572402662885, 6.905012550472145, 7.918094838901213, 8.827576358887706, 9.832537042099062, 10.831954937666255, 11.889351280939524, 12.812091599962468, 11.91532941785678, 10.86692851013947, 9.836108264480274, 8.853684068187203, 7.855538954066416, 6.914432792873661, 5.957382676032727, 4.998426043799208, 4.034517144345756, 3.1186016159956624, 5.065513876761983, 6.011334705859429, 6.946468770540019, 7.877678453379272, 8.809540445292297, 9.828341007900828, 10.7628778890147, 11.785788743816841, 12.75823259470056, 13.758634839320804, 12.777306488740884, 11.75517367469603, 10.794649201354096, 9.797702198893573, 8.849687486458919, 7.8873691553215055, 6.956681596447359, 5.99091317463361, 5.005597634763849, 4.167413300723702, 6.031620525031262, 6.9425540402102115, 7.9316163407729094, 8.878636865398379, 9.790899629141459, 10.786134782236442, 11.73042298056681, 12.752239763343468, 13.7572715033422, 14.68769293556413, 13.729867352211114, 12.767134611842172, 11.726130964483648, 10.786994880307786, 9.815870506790722, 8.840234857984624, 7.911863503982582, 6.98142680463465, 5.932842942524715, 5.20619420460224, 7.044478429636603, 7.92153629212653, 8.944924494755668, 9.8826577894685, 10.854492211182338, 11.713266979413508, 12.703990475075496, 13.748304349133704, 14.799410075792956, 15.723643174614205, 14.677367582767449, 13.683971359591304, 12.738961236538723, 11.801324160033058, 10.795494711998238, 9.79570497449056, 8.837533871844542, 7.896681542401148, 6.952114626066789, 6.161427128330092, 8.055705327529818, 8.988834513988632, 9.949486478654547, 10.883628194899513, 11.815989535502958, 12.655582880675682, 13.638910295221612, 14.658809431361671, 15.600564836847171, 16.64597032502238, 15.665975030885521, 14.641229078274977, 13.666936055485174, 12.776740814158039, 11.737789905851372, 10.764247331344171, 9.912152868177857, 8.908668426012207, 8.01853922358413, 7.088265569051935], [7.792815386789133, 8.751790642062064, 9.731127655499275, 10.722002796971857, 11.737616068708343, 12.692729879755202, 13.72007369337318, 14.697771048820291, 15.637428186019392, 16.661854463764996, 15.613740605104338, 14.623323250753081, 13.558270526302904, 12.549878093367095, 11.57940455274408, 10.808685189428981, 9.879883752496003, 8.870405660163371, 7.893318329900272, 7.0244272527690725, 8.81172116443571, 9.807094988052087, 10.721640533803278, 11.67017775500697, 12.730028148784802, 13.671931798072457, 14.67020039699337, 15.662196210787016, 16.69297399241248, 17.44791368604262, 16.494517997612743, 15.534475923907593, 14.475665984180571, 13.459238811763301, 12.506532548314734, 11.814565993977618, 10.805331429985307, 9.90073049662765, 8.941408325732802, 8.083188860656318, 9.855443817469435, 10.796598957292327, 11.701014995133942, 12.659964833351461, 13.657681415428227, 14.670495059771643, 15.672930496328888, 16.694819005755832, 17.709411184118586, 18.4283752237197, 17.408161953967433, 16.47736896517826, 15.425098735607019, 14.429123901169325, 13.454825127907563, 12.79705852326011, 11.87826569650509, 10.882009446304393, 9.866806476815968, 9.121221370911584, 9.791717961417193, 10.72913202643749, 11.75198937233927, 12.68059839184392, 13.547919010840221, 14.573360969762929, 15.5218417472155, 16.512950281617723, 17.49043827518236, 18.467163666016823, 18.41148725186246, 17.34331192183796, 16.379408640741833, 15.41686020038608, 14.474731083849157, 13.709856520568794, 12.781337894128662, 11.846219818321952, 10.852640665160413, 10.181760978844519, 8.86614230999358, 9.815103929857104, 10.760288700969593, 11.789344530109716, 12.565657089079881, 13.631465258995085, 14.632525230287458, 15.518686121757138, 16.498312165057985, 17.442556638171954, 18.253641723028533, 17.31592035220467, 16.467406420303238, 15.480061106108105, 14.459725748337304, 13.529648203937537, 12.5679387817298, 11.639075431952598, 10.62066579772571, 9.770911990901146, 7.858040216597557, 8.865050703554653, 9.814288599989679, 10.739675517633518, 11.623094252459504, 12.65067403963479, 13.587849493425853, 14.556379254622675, 15.566358807422798, 16.461274216079918, 17.2816768304431, 16.35499072835109, 15.440633451580076, 14.511674503244953, 13.533864133319822, 12.652414634838726, 11.725081633953735, 10.697619313608099, 9.672983770268148, 8.71024049084758, 6.914009473802508, 7.866215367468681, 8.8273978440608, 9.834392321968375, 10.652322514808613, 11.703112522482082, 12.632557639098431, 13.620741811094389, 14.582166018701784, 15.519520308157954, 16.260212744475627, 15.331105121404576, 14.478432079999221, 13.561957170654013, 12.581384209890784, 11.676955317273244, 10.762827989318676, 9.721757376208204, 8.713365082651812, 7.780810161084738, 5.902778100517917, 6.883932693548279, 7.863584272878912, 8.808113287936905, 9.626966665929217, 10.676961695545085, 11.656266192207552, 12.639359827161224, 13.619246253816463, 14.578046271547297, 15.399642168849432, 14.399175715438961, 13.445271109286379, 12.558271463539517, 11.508025741775677, 10.62289613221747, 9.753818590083661, 8.880775053777061, 7.829720838619878, 6.843723931210193, 4.933358959881043, 5.863335899100381, 6.826434592635097, 7.754472183813123, 8.696206037430185, 9.686991937551097, 10.623273034781736, 11.635311805153634, 12.59988244117314, 13.539831771497218, 14.38759897713766, 13.420031683583368, 12.481384848050636, 11.541986242992904, 10.582151936691352, 9.594474710232229, 8.69566891552601, 7.814353380481875, 6.909692428871653, 5.876285327725111, 3.995279257120818, 4.876573332835981, 5.793459626649803, 6.774584703148997, 7.7324735857428735, 8.743353473257098, 9.716497404481204, 10.658632198085622, 11.702110086092835, 12.632765021512316, 13.419007980325029, 12.493834521587987, 11.554874286509119, 10.608265746178587, 9.62127915394566, 8.63235700576782, 7.692973570465909, 6.820065469306811, 5.890693999385636, 4.895596802542083, 2.949057280329912, 3.867374115270258, 4.8114937813531835, 5.8808594425444145, 6.881527481459288, 7.855155351095411, 8.923615382811128, 9.915158183498692, 10.881037635382642, 11.878170848161151, 12.726482947410245, 11.747656775990277, 10.801441005824726, 9.729757487097327, 8.664045924655522, 7.713237377960416, 6.728923977237895, 5.7893558475232485, 4.824410999669261, 3.878892069869724, 1.9929994436833063, 2.920952555628949, 3.9388454301038918, 4.977465187622089, 6.024852913495824, 7.09460068117705, 7.988244174208701, 8.933689961980606, 9.961693086047323, 10.886814416299329, 11.85551844152962, 10.8507691312842, 9.821225555658607, 8.815615800285343, 7.780671940905569, 6.831479675520921, 5.790125217499498, 4.863311388986156, 3.8890580765611293, 2.9486048220762218, 0.9993424631149568, 1.9910573822185471, 3.044442376695281, 4.028701469351806, 5.065564389986005, 6.073448818610442, 7.040982207386281, 7.967479228692373, 8.936495944735658, 9.956306591483413, 10.848758199279104, 9.923231869139475, 8.936154537614966, 7.967624231507781, 6.8971932177495265, 5.893744447266846, 4.941145172683542, 3.952444789388863, 2.9027256664394514, 2.0330526234644686, 0.0, 1.0507898126446975, 2.0713721559348715, 3.039491655693724, 4.112744827895652, 5.127406946467625, 6.0760586700673045, 7.013733066165635, 8.065907495397047, 9.095098229145444, 10.079279160893229, 9.035837795302612, 7.999968811659343, 6.985183890953111, 5.9612503368559615, 4.936985392796649, 3.9532778858579816, 2.9645905087734024, 1.9240458900306683, 0.9774764494967135, 0.9728819509012384, 1.9144073317467987, 2.960868612766068, 3.9570634420049977, 4.88242493799003, 5.8784711959137965, 6.841394328777831, 7.865889288068033, 8.821179179166645, 9.789857001960069, 10.748502001031227, 9.940998012585158, 8.918270474404121, 7.850359570233023, 6.923560122580767, 5.862893345909038, 4.915508323283292, 3.9009675968366353, 2.957061817547511, 1.9199011637739396, 2.0321265832444215, 2.9486298529894728, 3.955519779198416, 4.887933757217823, 5.901016045646891, 6.810497565633384, 7.815458248844739, 8.814876144411933, 9.872272487685201, 10.795012806708145, 11.751917857581914, 10.886388572593845, 9.855568326934648, 8.87314413064158, 7.874999016520793, 6.8869155698949776, 5.90729125685781, 4.948334624624292, 3.914267453385076, 2.927818455223896, 3.0324612532975146, 3.9782820823949603, 4.91341614707555, 5.86059966012495, 6.792461652037976, 7.811262214646506, 8.745799095760377, 9.768709950562519, 10.741153801446238, 11.741556046066481, 12.705482492868592, 11.774633737150404, 10.81410926380847, 9.81716226134795, 8.822170263480237, 7.859851932342822, 6.9005573593580225, 5.87066348367293, 4.885347943803169, 3.9766301399519355, 3.998567901566794, 4.9095014167457425, 5.89856371730844, 6.84558424193391, 7.773820835887136, 8.76905598898212, 9.713344187312488, 10.735160970089145, 11.740192710087877, 12.670614142309807, 13.717563739755473, 12.773650708929187, 11.714318884800893, 10.753661650256857, 9.782537276739793, 8.806901627933696, 7.855739266893247, 6.86117711367397, 5.812593251564035, 4.948565210121469, 5.011425806172135, 5.888483668662061, 6.911871871291199, 7.8496051660040305, 8.837413417928015, 9.696188186159185, 10.686911681821174, 11.731225555879382, 12.782331282538633, 13.706564381359883, 14.665555503084693, 13.672159279908549, 12.727149156855967, 11.76175657694263, 10.75592712890781, 9.736511164857891, 8.717284180883862, 7.776431851440468, 6.831864935106109, 5.903798133849321, 6.022652704065351, 6.955781890524163, 7.916433855190078, 8.850575571435044, 9.798870753539061, 10.63850408742136, 11.62183150196729, 12.641730638107349, 13.583486043592849, 14.628891531768057, 15.654162951202766, 14.629416998592221, 13.655123975802418, 12.737173231067612, 11.698222322760945, 10.705053521711502, 9.791903177217177, 8.788418735051527, 7.88925608552298, 6.830636574571164], [8.772210176416188, 9.731185431689118, 10.71052244512633, 11.701397586598912, 12.717010858335398, 13.672124669382256, 14.699468483000235, 15.677165838447344, 16.616822975646443, 15.694988512560334, 14.641675836379331, 13.651258482028075, 12.586205757577897, 11.577813324642088, 10.607339784019073, 9.83666040941355, 8.94255180649018, 7.94580503154223, 7.005173133792538, 8.003822042396127, 9.791115954062764, 10.786489777679142, 11.701035323430332, 12.649572544634024, 13.709422938411857, 14.651326587699511, 15.649595186620424, 16.64159100041407, 17.54823522170097, 16.475848917317613, 15.522453228887734, 14.562411155182584, 13.503601215455564, 12.487174043038294, 11.534467779589727, 10.842541213962187, 9.867999483979483, 8.97612986800651, 8.053263129625067, 9.062583650283372, 10.83483860709649, 10.84500027576518, 11.78899285869186, 12.755158578855513, 13.598634874110358, 14.545568713321558, 15.517309625593166, 16.53919813502011, 17.495235325840902, 17.456310454994693, 16.436097185242424, 15.505304196453254, 14.453033966882012, 13.457059132444318, 12.482760359182556, 11.82503374324468, 10.940933750499267, 9.989531713031777, 8.978661280708234, 9.930490610380067, 10.636502782175732, 9.833910336643978, 10.80514893738178, 11.73375795688643, 12.536797607707474, 13.562239566630181, 14.510720344082753, 15.501828878484975, 16.47931687204961, 17.456042262884072, 17.439422483137452, 16.37124715311295, 15.407343872016824, 14.444795431661074, 13.50266631512415, 12.798486287442058, 11.869967661001926, 10.958074622214218, 9.964495469052679, 10.97307815297476, 9.710927130752118, 8.894896414666327, 9.749167297836845, 10.778223126976968, 11.554535685947133, 12.620343855862338, 13.62140382715471, 14.50756471862439, 15.487190761925236, 16.431435235039203, 17.368264597188073, 17.3106168535255, 16.3956796681745, 15.416948631996267, 14.481495561353732, 13.819340657127423, 12.857631234919687, 11.928767885142484, 10.910358250915598, 10.615696811659683, 8.702825037356096, 7.853929300421906, 8.803167196856931, 9.72855411450077, 10.611972849326756, 11.639552636502042, 12.576728090293106, 13.545257851489927, 14.55523740429005, 15.450152812947168, 16.39629970460264, 17.286739659808223, 16.37238238303721, 15.443423434702083, 14.465613064776953, 13.497199455597263, 12.569866454712272, 11.542404134366636, 10.517768591026686, 9.555025311606117, 7.7587942945610475, 6.855093964335933, 7.816276440928051, 8.823270918835625, 9.641201111675866, 10.691991119349334, 11.621436235965684, 12.609620407961641, 13.571044615569036, 14.508398905025206, 15.435181150221466, 16.26285405286171, 15.410181011456354, 14.493706102111144, 13.513133141347915, 12.608704248730374, 11.607612810077214, 10.566542196966742, 9.55814990341035, 8.625594981843276, 6.747562921276455, 5.872811290415531, 6.852462869746166, 7.796991884804157, 8.61584526279647, 9.665840292412337, 10.645144789074804, 11.628238424028476, 12.608124850683716, 13.56692486841455, 14.473875445247346, 15.330924646896094, 14.377020040743512, 13.490020394996648, 12.439774673232808, 11.5546450636746, 10.66451519888762, 9.725559874535598, 8.674505659378417, 7.688508751968731, 5.7781437806395815, 4.852214495967633, 5.81531318950235, 6.743350780680375, 7.685084634297437, 8.67587053441835, 9.612151631648988, 10.624190402020886, 11.588761038040392, 12.52871036836447, 13.461832253535574, 14.3517806150405, 13.413133779507769, 12.473735174450036, 11.513900868148482, 10.52622364168936, 9.627417846983143, 8.691671425004118, 7.754477249630191, 6.7210701484836495, 4.840064077879356, 3.8654519297032337, 4.782338223517056, 5.76346330001625, 6.721352182610126, 7.7322320701243505, 8.705376001348457, 9.647510794952874, 10.690988682960088, 11.621643618379569, 12.598851157288374, 13.42558345304512, 12.486623217966251, 11.54001467763572, 10.553028085402792, 9.564105937224952, 8.62472250192304, 7.697383513829053, 6.755149371311058, 5.740381623300621, 3.79384210108845, 2.856252712137511, 3.8003723782204366, 4.869738039411668, 5.870406078326541, 6.844033947962664, 7.899291928494512, 8.872607849279374, 9.838487301163324, 10.835620513941834, 11.767243539820681, 12.67940570744741, 11.733189937281859, 10.66150641855446, 9.595794856112654, 8.644986309417549, 7.660672908695027, 6.666673892045491, 5.701729044191503, 4.723676890628262, 2.8377842644418445, 1.9098311524962022, 2.9277240269711453, 3.9663437844893425, 5.013731510363077, 6.081672925541108, 6.9374543615640025, 7.882900149335908, 8.910903273402624, 9.83602460365463, 10.815893981523153, 11.726607009351355, 10.75297448711574, 9.747364731742476, 8.712420872362703, 7.763228606978053, 6.72187414895663, 5.795060320443287, 4.820807008018261, 3.79338964283476, 1.9462321264777325, 0.9402675695738495, 1.993652564050583, 2.977911656707109, 4.014774577341307, 5.022659005965743, 5.990192394741583, 6.916689416047674, 7.885706132090959, 8.905516778838715, 9.873543417067001, 10.79906974720663, 9.986944350259664, 9.018414044152479, 7.947983030394225, 6.944534259911542, 5.991934985328238, 5.00323460203356, 3.9535154790841487, 2.989143561979329, 1.0507898126446975, 0.0, 1.0205823432901742, 1.9887018430490269, 3.061955015250954, 4.076617133822927, 5.025268857422606, 5.962943253520937, 7.015117682752348, 8.044308416500746, 9.071762542667617, 10.08662760794731, 9.050758624304041, 8.03597370359781, 7.01204014950066, 5.987775205441348, 5.00406769850268, 4.0153803214181005, 2.974835702675366, 2.028266262141411, 1.9522767405282924, 1.010751359682732, 2.0235366667602452, 2.984998673279991, 3.910360169265023, 4.90640642718879, 5.869329560052824, 6.893824519343026, 7.849114410441637, 8.817792233235062, 9.77643723230622, 10.828043824511887, 9.964432952031085, 8.896522047859987, 7.969722600207732, 6.909055823536003, 5.894903112910345, 4.880362386463689, 3.9364566071745646, 2.899295953400993, 3.011521372871475, 2.044973880925406, 3.018187833192593, 3.915868988492816, 4.928951276921884, 5.838432796908378, 6.843393480119732, 7.842811375686926, 8.900207718960194, 9.822948037983139, 10.779853088856907, 11.811617233205805, 10.896857373786393, 9.857028620984224, 8.858883506863437, 7.866310359522032, 6.886686046484864, 5.9277294142513455, 4.8936622430121295, 3.90721324485095, 4.011856042924569, 3.0901368862872256, 3.9760842010697273, 4.888534891399943, 5.820396883312969, 6.839197445921499, 7.7737343270353705, 8.796645181837512, 9.769089032721231, 10.769491277341475, 11.733417724143585, 12.755550538188439, 11.813467658424003, 10.801046751690594, 9.801565053107291, 8.839246721969877, 7.879952148985076, 6.850058273299983, 5.864742733430223, 4.956024929578989, 4.977962691193848, 4.021356220638008, 4.961231771302618, 5.908252295928087, 6.801756067162129, 7.796991220257112, 8.741279418587482, 9.763096201364139, 10.76812794136287, 11.6985493735848, 12.745498971030466, 13.708231711399408, 12.693713674427945, 11.73305643988391, 10.761932066366846, 9.786296417560749, 8.8351340565203, 7.840571903301024, 6.791988041191089, 5.927959999748523, 5.990820595799189, 5.0003384725543265, 5.981695762038512, 6.912273219998208, 7.865348649203009, 8.724123417434178, 9.714846913096167, 10.759160787154375, 11.810266513813627, 12.734499612634876, 13.760243679764029, 14.651554069535601, 13.70654394648302, 12.741151366569685, 11.735321918534865, 10.715905954484946, 9.696678970510916, 8.755826641067522, 7.811259724733162, 6.883192923476375, 7.002047493692404, 6.067636694416429, 6.991833226568938, 7.913243625429222, 8.826845973523628, 9.666439318696353, 10.649766733242283, 11.669665869382342, 12.611421274867842, 13.65682676304305, 14.728393912908324, 15.608811788219274, 14.63451876542947, 13.716568020694666, 12.677617112387999, 11.684448311338556, 10.771297966844232, 9.767813524678582, 8.868650875150033, 7.810031364198218], [9.70930293772262, 10.668278192995551, 11.647615206432762, 12.638490347905343, 13.66672498753639, 14.62183879858325, 15.649182612201226, 16.562419041923896, 15.695919362391855, 14.674406169270162, 13.621093493089159, 12.630676138737902, 11.565623414287725, 10.557230981351916, 9.5867574407289, 8.816078066123376, 7.921969463200005, 6.925222688252056, 7.869439287320788, 8.896176883670895, 10.728208715369197, 11.723582538985575, 12.153166796261274, 13.101704017464966, 13.707616825684605, 14.696851452194416, 15.701368409859507, 16.693364223653152, 16.527652878410798, 15.45526657402744, 14.501870885597562, 13.541828811892412, 12.48301887216539, 11.46659169974812, 10.513885436299553, 9.821958870672013, 8.84741714068931, 7.955547524716336, 8.917529283153318, 9.95493849155814, 11.771931368402925, 11.865582619055353, 11.17379233493061, 12.139958055094263, 12.77996355904118, 13.72689739825238, 14.698638310523988, 15.720526819950932, 16.676564010771724, 16.43572811170452, 15.41551484195225, 14.48472185316308, 13.432451623591838, 12.436476789154144, 11.462178015892382, 10.804451399954505, 9.920351407209093, 8.968949369741605, 9.842927434236485, 10.794756763908318, 11.657085125465906, 10.85449267993415, 10.189948413620531, 11.118557433125181, 11.718126292638296, 12.743568251561003, 13.692049029013575, 14.683157563415797, 15.66064555698043, 16.637370947814894, 16.418840139847276, 15.350664809822776, 14.38676152872665, 13.4242130883709, 12.482083971833976, 11.777903944151884, 10.849385317711752, 9.996657403534833, 10.82876162258093, 11.83734430650301, 10.731509474042292, 9.9154787579565, 9.133966774075596, 10.158792586839795, 10.735864370877955, 11.80167254079316, 12.802732512085532, 13.688893403555213, 14.668519446856058, 15.593668000393402, 16.462838396706395, 16.290034510235326, 15.375097324884324, 14.396366288706092, 13.460913218063558, 12.810190601673302, 11.848481179465566, 11.046309029657156, 11.774624404443848, 11.636279154949857, 9.72340738064627, 8.87451164371208, 8.187966673095682, 9.103745848848725, 9.793301534257578, 10.820881321432864, 11.758056775223928, 12.726586536420749, 13.736566089220872, 14.544726612465487, 15.49087350412096, 16.443274905378605, 16.293544151341294, 15.36458520300617, 14.38677483308104, 13.779077070441712, 12.86872155235771, 12.04473401606477, 11.53835093431686, 10.575607654896292, 8.779376637851222, 7.875676307626107, 7.114146592183079, 8.076328187833228, 8.822529796606688, 9.873319804280156, 10.802764920896506, 11.790949092892465, 12.75237330049986, 13.602972704543525, 14.529754949739782, 15.458862572810832, 16.430763354746528, 15.514288445401318, 14.533715484638089, 13.629286592020549, 12.628195153367388, 11.587124540256916, 10.578732246700524, 9.64617732513345, 7.76814526456663, 6.893393633705705, 6.131835515031643, 7.045251242251746, 7.797173947727292, 8.84716897734316, 9.826473474005626, 10.8095671089593, 11.78945353561454, 12.661498667932868, 13.568449244765663, 14.591777274209207, 15.397602384033686, 14.510602738286822, 13.460357016522982, 12.575227406964775, 11.685097542177795, 10.746142217825772, 9.69508800266859, 8.709091095258906, 6.798726123929756, 5.872796839257807, 5.094685834787828, 5.991610138127963, 6.86641331922826, 7.857199219349173, 8.793480316579812, 9.80551908695171, 10.770089722971216, 11.623284167882787, 12.556406053053891, 13.569414441591212, 14.433716122797943, 13.49431751774021, 12.534483211438657, 11.546805984979533, 10.648000190273317, 9.71225376829429, 8.775059592920364, 7.741652491773824, 5.86064642116953, 4.886034272993408, 4.061710868802534, 4.996015036054938, 5.9026808675409494, 6.913560755055174, 7.886704686279281, 8.828839479883698, 9.74686875515025, 10.677523690569732, 11.654731229478537, 12.57990468821558, 13.507205561256425, 12.560597020925893, 11.573610428692966, 10.584688280515126, 9.645304845213214, 8.717965857119227, 7.775731714601232, 6.760963966590795, 4.814424444378624, 3.8768350554276854, 3.0797450235059145, 3.9682701813336636, 4.968938220248537, 5.942566089884661, 6.878709585204338, 7.852025505989201, 8.817904957873152, 9.815038170651661, 10.746661196530507, 11.725487367950475, 12.671703138116026, 11.682088761844636, 10.616377199402828, 9.665568652707723, 8.6812552519852, 7.687256235335665, 6.722311387481677, 5.744259233918436, 3.8583666077320187, 2.930413495786376, 2.0994011526616476, 2.9906362068951107, 4.011613861892045, 5.061090582250934, 5.916872018273828, 6.862317806045734, 7.890320930112449, 8.815442260364456, 9.79531163823298, 10.706024666061179, 11.773556830405916, 10.76794707503265, 9.733003215652877, 8.783810950268228, 7.742456492246804, 6.8156426637334615, 5.841389351308435, 4.813971986124934, 2.9668144697679066, 1.9608499128640235, 1.040675469091047, 1.9573293134169347, 2.994192234051133, 4.002076662675569, 4.969610051451409, 5.8961070727575, 6.865123788800785, 7.884934435548541, 8.852961073776825, 9.778487403916454, 10.765564735440963, 10.038996387442653, 8.968565373684399, 7.965116603201716, 7.012517328618412, 6.023816945323734, 4.974097822374323, 4.009725905269503, 2.0713721559348715, 1.0205823432901742, 0.0, 0.9681194997588528, 2.04137267196078, 3.0560347905327525, 4.004686514132432, 4.942360910230763, 5.994535339462174, 7.023726073210572, 8.051180199377443, 9.09462156496806, 10.071340967594216, 9.056556046887984, 8.032622492790834, 7.008357548731521, 6.024650041792853, 5.035962664708274, 3.9954180459655397, 3.048848605431585, 2.9728590838184665, 2.031333702972906, 1.0029543234700709, 1.964416329989817, 2.889777825974849, 3.885824083898615, 4.848747216762649, 5.873242176052852, 6.828532067151463, 7.797209889944888, 8.755854889016046, 9.807461481221713, 10.83018901940275, 9.917104391150161, 8.990304943497906, 7.9296381668261775, 6.9154854562005195, 5.9009447297538635, 4.957038950464739, 3.9198782966911674, 4.032103716161649, 3.0500821368392685, 1.9976054899024187, 2.895286645202642, 3.9083689336317096, 4.8178504536182025, 5.822811136829557, 6.822229032396751, 7.87962537567002, 8.802365694692964, 9.759270745566733, 10.791034889915629, 11.76748687193328, 10.877610964274398, 9.879465850153611, 8.886892702812206, 7.907268389775038, 6.94831175754152, 5.914244586302304, 4.927795588141124, 4.948948804231003, 4.003127975133557, 2.955501857779553, 3.867952548109769, 4.799814540022795, 5.818615102631325, 6.753151983745196, 7.776062838547337, 8.748506689431057, 9.7489089340513, 10.712835380853411, 11.734968194898265, 12.695492668240199, 11.821629094980768, 10.822147396397465, 9.859829065260051, 8.90053449227525, 7.8706406165901575, 6.885325076720397, 5.970647026140872, 5.915055452500282, 4.934347309484339, 3.9406494280124438, 4.887669952637913, 5.781173723871955, 6.776408876966938, 7.720697075297308, 8.742513858073966, 9.747545598072698, 10.677967030294628, 11.724916627740294, 12.687649368109236, 13.626974431369751, 12.753638783174084, 11.78251440965702, 10.806878760850923, 9.855716399810474, 8.859589971020526, 7.811006108910591, 6.865052761054957, 6.9279133571056235, 5.913329561400658, 4.9611134187483374, 5.891690876708034, 6.8447663059128345, 7.703541074144004, 8.694264569805995, 9.738578443864203, 10.789684170523454, 11.713917269344703, 12.739661336473857, 13.646787026906992, 14.591797149959573, 13.716175530994212, 12.710346082959392, 11.690930118909472, 10.671703134935443, 9.730850805492048, 8.786283889157689, 7.820285684782809, 7.939140254998839, 6.931902847944679, 5.971250883278763, 6.892661282139048, 7.806263630233455, 8.64585697540618, 9.62918438995211, 10.64908352609217, 11.59083893157767, 12.636244419752877, 13.707811569618151, 14.6337708816406, 15.519771968906024, 14.691592185119193, 13.652641276812526, 12.659472475763083, 11.746322131268759, 10.742837689103109, 9.805743636456468, 8.747124125504651], [10.677422437481473, 11.636397692754404, 12.615734706191615, 13.351334369208276, 13.769526755104911, 14.707933870752818, 15.683375613720843, 15.594299542165045, 14.727799862633002, 13.706286669511309, 12.652973993330306, 11.66255663897905, 10.597503914528872, 9.589111481593063, 8.618637940970046, 7.8479585663645235, 7.008074976366782, 7.893342188010909, 8.83755878707964, 9.864296383429746, 11.69632821512805, 12.691702038744427, 13.010009191020579, 12.30953296822873, 12.739497325925752, 13.728731952435563, 14.733248910100654, 15.725244723894301, 15.559533378651944, 14.487147074268588, 13.533751385838709, 12.573709312133559, 11.514899372406537, 10.498472199989267, 9.5457659365407, 8.85383937091316, 7.933522653856086, 8.861844498520263, 9.885648782912169, 10.923057991316991, 12.740050868161777, 12.833702118814205, 12.030634729689915, 11.319745889884238, 11.811844059282327, 12.758777898493527, 13.730518810765135, 14.752407320192079, 15.708444511012871, 15.467608611945668, 14.447395342193397, 13.516602353404227, 12.464332123832985, 11.468357289395291, 10.49405851613353, 9.836331900195653, 9.00645692037587, 9.87524634354553, 10.811046933995335, 11.762876263667168, 12.62520462522476, 11.822612179693003, 11.046790808379836, 10.255191522778514, 10.750006792879443, 11.77544875180215, 12.723929529254722, 13.715038063656944, 14.692526057221578, 15.669251448056041, 15.450720640088424, 14.382545310063923, 13.418642028967797, 12.456093588612047, 11.513964472075124, 10.847408168782032, 9.935490830878528, 10.870608906685238, 11.79688112233978, 12.80546380626186, 11.699628973801145, 10.883598257715352, 9.990809168834902, 9.19067308708094, 9.767744871119103, 10.833553041034307, 11.83461301232668, 12.72077390379636, 13.700399947097205, 14.62554850063455, 15.494718896947541, 15.321915010476474, 14.406977825125471, 13.42824678894724, 12.492793718304705, 11.89629611484008, 10.934586692632344, 11.863450042409546, 12.7427439042027, 12.60439865470871, 10.691526880405123, 9.842631143470932, 9.044809067854988, 8.13562634908987, 8.825182034498726, 9.852761821674012, 10.789937275465075, 11.758467036661896, 12.76844658946202, 13.576607112706634, 14.522754004362108, 15.475155405619752, 15.325424651582441, 14.396465703247317, 13.418655333322187, 12.86518258360849, 11.954827065524489, 12.86187502881716, 12.506470434075712, 11.543727154655144, 9.747496137610074, 8.843795807384959, 7.970988986942386, 7.108208688074375, 7.854410296847835, 8.905200304521303, 9.834645421137653, 10.822829593133612, 11.784253800741007, 12.634853204784672, 13.56163544998093, 14.490743073051979, 15.472910914223544, 15.400909210456485, 14.371135256751225, 13.932396390327257, 12.917080710159548, 12.555244040015769, 11.546851746459376, 10.614296824892303, 8.736264764325483, 7.861513133464558, 6.988677909790949, 6.077131742492892, 6.8290544479684385, 7.8790494775843065, 8.858353974246773, 9.841447609200447, 10.821334035855687, 11.693379168174015, 12.60032974500681, 13.623657774450354, 14.500338928127304, 15.459142613346001, 14.428476516281835, 13.543346906723627, 12.653217041936648, 11.714261717584625, 10.663207502427444, 9.677210595017758, 7.766845623688608, 6.84091633901666, 5.951528229547135, 5.023490638369109, 5.898293819469407, 6.889079719590319, 7.825360816820958, 8.837399587192857, 9.801970223212363, 10.655164668123934, 11.588286553295038, 12.601294941832359, 13.536452666891561, 14.431074460680444, 13.50260271119751, 12.514925484738386, 11.61611969003217, 10.680373268053144, 9.743179092679217, 8.709771991532676, 6.828765920928383, 5.854153772752261, 5.009020612795278, 4.027895536296084, 4.934561367782096, 5.94544125529632, 6.918585186520427, 7.860719980124844, 8.778749255391398, 9.70940419081088, 10.686611729719685, 11.611785188456727, 12.550745423535595, 13.497353963866127, 12.541729928451819, 11.552807780273978, 10.613424344972067, 9.68608535687808, 8.743851214360085, 7.729083466349648, 5.782543944137477, 4.844954555186538, 4.041480335498721, 3.0001506815748105, 4.000818720489684, 4.974446590125807, 5.910590085445485, 6.883906006230348, 7.849785458114299, 8.846918670892808, 9.778541696771653, 10.75736786819162, 11.703583638357172, 12.650208261603488, 11.584496699161681, 10.633688152466576, 9.649374751744054, 8.655375735094518, 7.69043088724053, 6.712378733677289, 4.826486107490871, 3.898532995545229, 3.0611364646544548, 2.0225167071362575, 3.0434943621331927, 4.092971082492081, 4.948752518514976, 5.8941983062868815, 6.922201430353596, 7.847322760605602, 8.827192138474125, 9.737905166302326, 10.808899742159653, 11.736066574791503, 10.70112271541173, 9.75193045002708, 8.710575992005657, 7.783762163492314, 6.809508851067288, 5.782091485883787, 3.9349339695267593, 2.9289694126228762, 2.0087949688499, 0.9892098136580818, 2.0260727342922804, 3.0339571629167166, 4.001490551692556, 4.927987572998647, 5.897004289041932, 6.916814935789687, 7.8848415740179725, 8.810367904157602, 9.79744523568211, 10.840187358947407, 9.936684873443252, 8.933236102960569, 7.980636828377265, 6.991936445082587, 5.9422173221331755, 4.977845405028356, 3.039491655693724, 1.9887018430490269, 0.9681194997588528, 0.0, 1.0732531722019272, 2.0879152907739, 3.036567014373579, 3.974241410471909, 5.02641583970332, 6.055606573451718, 7.08306069961859, 8.126502065209207, 9.162371048852476, 10.024675546646836, 9.000741992549687, 7.9764770484903735, 6.992769541551706, 6.0040821644671265, 4.963537545724392, 4.016968105190438, 3.9409785835773192, 2.999453202731759, 1.9710738232289238, 0.9962968302309642, 1.9216583262159963, 2.9177045841397624, 3.8806277170037964, 4.905122676293999, 5.86041256739261, 6.829090390186035, 7.787735389257193, 8.83934198146286, 9.862069519643898, 10.885223890909016, 9.95842444325676, 8.897757666585031, 7.883604955959372, 6.869064229512716, 5.9251584502235914, 4.88799779645002, 5.000223215920502, 4.018201636598121, 2.9657249896612714, 1.9271671454437893, 2.940249433872857, 3.84973095385935, 4.8546916370707045, 5.8541095326378985, 6.911505875911168, 7.834246194934113, 8.79115124580788, 9.822915390156776, 10.799367372174427, 11.839196124976596, 10.847585349912464, 9.855012202571059, 8.875387889533892, 7.916431257300372, 6.882364086061156, 5.895915087899977, 5.917068303989856, 4.97124747489241, 3.923621357538406, 2.8998330483509163, 3.8316950402639423, 4.850495602872472, 5.785032483986344, 6.807943338788484, 7.780387189672203, 8.780789434292446, 9.744715881094558, 10.766848695139412, 11.727373168481346, 12.739794075214755, 11.790266896156318, 10.827948565018904, 9.868653992034103, 8.838760116349011, 7.85344457647925, 6.938766525899725, 6.883174952259135, 5.902466809243192, 4.9087689277712965, 3.9737754658046898, 4.8130542241131025, 5.8082893772080855, 6.752577575538456, 7.774394358315113, 8.779426098313845, 9.709847530535775, 10.756797127981441, 11.719529868350383, 12.658854931610898, 13.619512166154934, 12.750633909415873, 11.774998260609776, 10.823835899569326, 9.827709470779377, 8.779125608669442, 7.83317226081381, 7.896032856864476, 6.88144906115951, 5.92923291850719, 4.97779638987481, 5.876646806153982, 6.7354215743851515, 7.726145070047142, 8.770458944105348, 9.8215646707646, 10.74579776958585, 11.771541836715004, 12.67866752714814, 13.62367765020072, 14.602920432734305, 13.678465582718243, 12.659049618668323, 11.639822634694294, 10.6989703052509, 9.75440338891654, 8.788405184541661, 8.90725975475769, 7.900022347703532, 6.939370383037616, 5.978766795305824, 6.8381441304746025, 7.677737475647327, 8.661064890193257, 9.680964026333317, 10.622719431818817, 11.668124919994025, 12.739692069859299, 13.665651381881748, 14.551652469147172, 15.481071305618917, 14.620760776571377, 13.627591975521934, 12.71444163102761, 11.71095718886196, 10.77386313621532, 9.715243625263504], [11.598730953551659, 12.55770620882459, 13.5370432222618, 13.806753527425627, 12.77851888779458, 13.716926003442484, 14.692367746410511, 14.574333278605357, 13.707833599073314, 12.841223091770157, 11.791601235013763, 10.801183880662506, 9.736131156212329, 8.72773872327652, 7.757265182653504, 7.0167653566443935, 7.907965656195996, 8.805259930498986, 9.749476529567717, 10.776214125917825, 12.617636731198235, 13.613010554814613, 13.69008583926388, 12.808339852393253, 11.74848945861542, 12.73772408512523, 13.742241042790322, 14.73423685658397, 14.698160620335402, 13.625774315952047, 12.672378627522168, 11.712336553817018, 10.653526614089996, 9.637099441672726, 8.684393178224159, 8.02264616119303, 8.8334133336853, 9.761735178349477, 10.797566525400246, 11.83497573380507, 13.661359384231961, 13.667470969761805, 12.710711377933215, 11.819676624779326, 10.820836191971996, 11.767770031183195, 12.739510943454803, 13.761399452881747, 14.71192792429965, 14.606235853629126, 13.586022583876856, 12.655229595087686, 11.602959365516444, 10.60698453107875, 9.632685757816988, 9.005138690475523, 9.906347600205084, 10.775137023374745, 11.722964676483413, 12.674794006155246, 13.642327008178226, 12.706803658868736, 11.726867456623136, 10.798258437118486, 9.758998925569111, 10.784440884491818, 11.73292166194439, 12.724030196346613, 13.696009470508356, 14.618833964277318, 14.589347881771882, 13.521172551747382, 12.557269270651256, 11.594720830295506, 10.652591713758582, 10.016214959061902, 10.835381510707743, 11.770499586514452, 12.708798864827857, 13.717381548749938, 12.716751356754612, 11.767789736891087, 10.739484680861445, 9.786239450064867, 8.77673700380877, 9.842545173723973, 10.84360514501635, 11.72976603648603, 12.703883360383983, 13.552295328432622, 14.421465724745614, 14.460542252159932, 13.54560506680893, 12.566874030630698, 11.631420959988164, 11.07735982116769, 11.834477372461556, 12.763340722238759, 13.654661646690776, 13.677651826910639, 11.72117112766419, 10.742722476316557, 9.79348457988153, 8.868097662237691, 7.834174167188394, 8.861753954363682, 9.798929408154745, 10.767459169351566, 11.771930002748798, 12.503353940504708, 13.449500832160181, 14.401902233417825, 14.4640518932659, 13.535092944930776, 12.557282575005646, 12.0462462899361, 12.854717745353701, 13.761765708646372, 13.579723606277641, 12.616980326857073, 10.777140384869142, 9.762974112350177, 8.80179163575806, 7.840680001222196, 6.863402429537503, 7.91419243721097, 8.843637553827321, 9.790000519199742, 10.751424726807137, 11.561600032582746, 12.488382277779003, 13.417489900850052, 14.399657742021617, 14.539536452139943, 13.509762498434684, 13.113460096654867, 13.81697138998876, 13.628497212217697, 12.620104918661305, 11.687549997094232, 9.76590901158455, 8.796885338438404, 7.819480558606622, 6.809603055640713, 5.838046580658107, 6.888041610273975, 7.867346106936441, 8.808618535266577, 9.788504961921817, 10.620125995972089, 11.527076572804884, 12.550404602248427, 13.427085755925377, 14.385889441144075, 14.58312096654979, 14.167519281710641, 13.726470214138576, 12.787514889786554, 11.736460674629372, 10.750463767219687, 8.796489870947676, 7.776288543990507, 6.78258786083107, 5.8545502696530445, 4.907285952159075, 5.898071852279987, 6.8343529495106266, 7.804570513258988, 8.769141149278493, 9.581911495922007, 10.515033381093112, 11.528041769630432, 12.463199494689635, 13.357821288478517, 14.387132457385492, 13.588178656940315, 12.689372862234098, 11.75362644025507, 10.816432264881145, 9.783025163734605, 7.858410168187451, 6.85327109292526, 5.882567459564835, 4.901442383065641, 3.943553500471764, 4.954433387985988, 5.885756112586558, 6.827890906190975, 7.70549608318947, 8.636151018608953, 9.613358557517758, 10.5385320162548, 11.477492251333668, 12.4241007916642, 13.411087383897128, 12.626060952475907, 11.686677517173996, 10.759338529080006, 9.817104386562013, 8.802336638551576, 6.855797116339405, 5.918207727388466, 5.036592544167464, 3.995262890243553, 3.009810853179352, 3.9757515858380987, 4.837336913243558, 5.81065283402842, 6.776532285912371, 7.773665498690879, 8.705288524569724, 9.684114695989692, 10.630330466155243, 11.702013984882642, 12.65774987136361, 11.706941324668504, 10.722627923945982, 9.728628907296445, 8.763684059442458, 7.7856319058792165, 5.899739279692799, 4.971786167747156, 4.056248673323197, 3.017628915805, 1.970241189931265, 3.0197179102901544, 3.8754993463130476, 4.820945134084953, 5.848948258151668, 6.774069588403674, 7.753938966272196, 8.664651994100398, 9.735646569957725, 10.74125632533099, 11.774375887613658, 10.825183622229009, 9.783829164207585, 8.857015335694243, 7.8827620232692155, 6.8553446580857145, 5.008187141728686, 4.002222584824803, 3.0820481410518266, 2.018128350248129, 0.952819562090353, 1.9607039907147894, 2.9282373794906285, 3.8547344007967195, 4.823751116840004, 5.8435617635877595, 6.811588401816045, 7.737114731955674, 8.724192063480183, 9.76693418674548, 10.837365200503735, 10.0064892751625, 9.053890000579194, 8.065189617284515, 7.015470494335104, 6.051098577230283, 4.112744827895652, 3.061955015250954, 2.04137267196078, 1.0732531722019272, 0.0, 1.0146621185719726, 1.9633138421716518, 2.9009882382699823, 3.9531626675013936, 4.982353401249791, 6.009807527416664, 7.0532488930072805, 8.08911787665055, 9.103902797356781, 10.073995164751615, 9.049730220692302, 8.066022713753634, 7.077335336669055, 6.036790717926321, 5.090221277392366, 4.880369001163938, 3.9388436203183774, 2.892382339299108, 1.8961875100601784, 0.9708260140751462, 1.9668722719989125, 2.929795404862946, 3.8813887604244246, 4.836678651523036, 5.805356474316461, 6.764001473387619, 7.8156080655932865, 8.838335603774324, 9.906246507945422, 10.833045955597678, 9.83714808417165, 8.822995373545991, 7.808454647099335, 6.8645488678102105, 5.827388214036639, 5.939613633507121, 4.939510152668305, 3.8870335057314556, 2.8270578252730036, 1.9967543886084438, 2.8988986417185, 3.9038593249298543, 4.8415513050328425, 5.896723466931005, 6.810512279064539, 7.767417329938306, 8.799181474287202, 9.775633456304853, 10.815462209107022, 11.784484849537703, 10.794402620157678, 9.81477830712051, 8.855821674886991, 7.821754503647775, 6.835305505486596, 6.83837682006004, 5.8925559909625935, 4.8449298736085895, 3.7997237281801306, 3.0005018305438123, 3.973702279282261, 4.908239160396132, 5.804897921009521, 6.77734177189324, 7.777744016513482, 8.720981965224984, 9.743114779269838, 10.703639252611772, 11.716060159345181, 12.716094099949387, 11.767338982605523, 10.808044409620722, 9.77815053393563, 8.792834994065869, 7.860075041969909, 7.804483468329319, 6.823775325313376, 5.820686670259374, 4.873666145633904, 3.9818610143929725, 4.946916618891542, 5.8912048172219125, 6.867330901640297, 7.839387971010574, 8.769809403232504, 9.736830864421753, 10.699563604790695, 11.635121015741325, 12.59577825028536, 13.566902623802424, 12.714388678196395, 11.763226317155945, 10.749017986849562, 9.700434124739628, 8.754480776883995, 8.81734137293466, 7.802757577229694, 6.841150660995267, 5.877687069704025, 5.045453596433852, 5.874048816068608, 6.864772311730599, 7.863395487430532, 8.892323395991195, 9.80575964228258, 10.751575573155316, 11.658701263588451, 12.603711386641033, 13.582954169174617, 14.54652682900994, 13.580358134738509, 12.56113115076448, 11.620278821321085, 10.675711904986725, 9.709713700611847, 9.823625075926785, 8.811940090191609, 7.851288125525693, 6.8786574751350384, 6.0069509207544725, 6.816364717330784, 7.799692131876714, 8.819591268016774, 9.761346673502274, 10.806752161677482, 11.771058946402855, 12.64568511832206, 13.531686205587484, 14.461105042059229, 14.735654917747631, 13.81108143479142, 13.635750147097795, 12.632265704932145, 11.695171652285506, 10.63655214133369], [12.613393072123632, 13.572368327396562, 14.551705340833774, 14.731660011148525, 13.703425371517477, 13.116181304376735, 14.002554637138735, 13.559671160033384, 12.693171480501341, 11.826560973198184, 10.791342968634483, 9.800925614283226, 8.771517059373295, 7.81361807070643, 6.843144530083415, 7.831622150204311, 8.789007629177902, 9.813380226406178, 10.764138648139689, 11.790876244489795, 13.632298849770208, 14.627672673386586, 14.614992322986778, 13.733246336116151, 12.673395942338319, 12.13697938605948, 13.052427933518546, 13.966514646729971, 13.748717286894431, 12.687806509827, 11.734410821397121, 10.798215901246927, 9.739405961519907, 8.722978789102637, 7.77027252565407, 8.837502954752948, 9.714455306667206, 10.642777151331384, 11.6980280755779, 12.74315332273115, 14.620704909916476, 14.592377453484705, 13.635617861656113, 12.744583108502225, 11.745742675694894, 11.097379657159932, 12.049697834183027, 12.90722176325523, 13.697265805727676, 13.692115201059037, 12.671901931306767, 11.741108942517597, 10.688838712946355, 9.69286387850866, 8.718565105246899, 9.657198140773023, 10.607056873977768, 11.656178996356651, 12.623426226661067, 13.5752555563329, 14.567233491901122, 13.631710142591633, 12.651773940346034, 11.723164920841384, 10.68390540929201, 10.114050510468555, 11.043108552672614, 11.840153603265675, 12.681347351936383, 13.604171845705341, 13.675227229201793, 12.607051899177293, 11.643148618081167, 10.680600177725417, 9.738471061188493, 10.668274409359402, 11.536090784480427, 12.471208860287136, 13.464788013448675, 14.473370697370756, 13.641657840477508, 12.692696220613984, 11.664391164584341, 10.711145933787765, 9.701643487531669, 9.058091817304552, 9.98913848161286, 10.776286030563016, 11.68922124181201, 12.537633209860646, 13.406803606173638, 13.546421599589843, 12.631484414238841, 11.65275337806061, 10.717300307418075, 11.72941927146519, 12.53518664623424, 13.464049996011443, 14.410650795311595, 14.645967115305634, 12.646077611387087, 11.667628960039453, 10.718391063604427, 9.793004145960587, 8.759080650911292, 8.007287290960193, 8.944462744751256, 9.813979163428552, 10.757267884176825, 11.488691821932731, 12.434838713588205, 13.387240114845849, 13.54993124069581, 12.620972292360687, 11.643161922435556, 12.622399445133361, 13.549732446018352, 14.462474982419057, 14.548038894672636, 13.585295615252068, 11.702046868592038, 10.687880596073073, 9.726698119480956, 8.765586484945093, 7.7883089132604, 7.0369738488810745, 7.897121497056559, 8.775338400627769, 9.736762608235164, 10.546937914010769, 11.473720159207028, 12.402827782278077, 13.384995623449642, 13.625415799569854, 12.595641845864595, 13.549820993121312, 14.51198609065341, 14.596812500612693, 13.5884202070563, 12.655865285489227, 10.690815495307447, 9.7217918221613, 8.74438704232952, 7.734509539363611, 6.762953064381004, 6.010823021944079, 6.92083005016568, 7.793956416694605, 8.773842843349843, 9.605463877400112, 10.512414454232909, 11.535742483676453, 12.412423637353402, 13.3712273225721, 13.669000313979701, 14.603880178177086, 14.694785502533572, 13.755830178181549, 12.704775963024368, 11.718779055614682, 9.721396354670572, 8.701195027713403, 7.707494344553966, 6.779456753375942, 5.832192435881972, 4.968491912468992, 5.854301158155694, 6.789908394687015, 7.75447903070652, 8.567249377350032, 9.500371262521137, 10.513379651058457, 11.44853737611766, 12.343159169906542, 13.372470338813518, 14.354369407493424, 13.704034980806071, 12.768288558827045, 11.804166992778622, 10.770759891632082, 8.783316651910347, 7.778177576648156, 6.807473943287731, 5.826348866788537, 4.868459984194661, 4.024853448174993, 4.8710939940145845, 5.813228787619002, 6.690833964617497, 7.6214889000369785, 8.598696438945783, 9.523869897682825, 10.462830132761693, 11.409438673092225, 12.396425265325153, 13.392251703029016, 12.701339635745969, 11.774000647651981, 10.831766505133986, 9.81699875712355, 7.870459234911378, 6.932869845960439, 6.004751037008354, 4.935385375817123, 3.9347173369022497, 2.961089467266126, 3.8226747946715847, 4.795990715456447, 5.761870167340398, 6.759003380118906, 7.690626405997752, 8.66945257741772, 9.615668347583272, 10.68735186631067, 11.722199497945528, 12.673008044640634, 11.737290042517955, 10.74329102586842, 9.778346178014433, 8.80029402445119, 6.914401398264772, 5.9864482863191295, 5.059222538752365, 4.020602781234167, 2.9732150553604324, 2.0050557917181817, 2.860837227741075, 3.8062830155129803, 4.834286139579696, 5.759407469831702, 6.739276847700224, 7.649989875528425, 8.720984451385752, 9.726594206759017, 10.76153806613879, 11.71073033152344, 10.798491282779558, 9.871677454266216, 8.897424141841189, 7.8700067766576876, 6.022849260300659, 5.0168847033967765, 4.093014217328087, 3.021102215677297, 1.9557934275195206, 0.9460418721428169, 1.9135752609186558, 2.840072282224747, 3.8090889982680314, 4.828899645015786, 5.796926283244072, 6.722452613383701, 7.709529944908209, 8.752272068173506, 9.82270308193176, 10.866106028244488, 10.068552119151166, 9.079851735856487, 8.030132612907074, 7.065760695802256, 5.127406946467624, 4.076617133822927, 3.0560347905327525, 2.0879152907739, 1.0146621185719726, 0.0, 0.9486517235996792, 1.8863261196980095, 2.938500548929421, 3.9676912826778183, 4.9951454088446905, 6.0385867744353074, 7.074455758078575, 8.089240678784808, 9.113174232881958, 10.064392339264273, 9.080684832325606, 8.091997455241026, 7.051452836498292, 6.104883395964338, 5.8950311197359095, 4.95350573889035, 3.9070444578710806, 2.910849628632151, 1.9854881326471188, 1.0527516194288233, 1.9881871125029533, 2.866726641852452, 3.8220165329510634, 4.790694355744488, 5.749339354815646, 6.800945947021313, 7.823673485202351, 8.891584389373449, 9.818383837025705, 10.851810202743621, 9.837657492117962, 8.823116765671307, 7.879210986382182, 6.84205033260861, 6.954275752079092, 5.954172271240278, 4.901695624303429, 3.8417199438449763, 3.0114165071804164, 1.984777989148411, 2.9622510325698617, 3.8268891864608694, 4.882061348359032, 5.795850160492566, 6.752755211366333, 7.78451935571523, 8.76097133773288, 9.800800090535049, 10.76982273096573, 11.762395878307135, 10.829440425692482, 9.870483793458963, 8.836416622219748, 7.849967624058567, 7.853038938632013, 6.907218109534567, 5.859591992180563, 4.814385846752103, 4.0151639491157844, 3.059581626712172, 3.9669617687509477, 4.7902358024375475, 5.762679653321267, 6.763081897941509, 7.706319846653011, 8.728452660697865, 9.6889771340398, 10.701398040773208, 11.701431981377414, 12.663750312514829, 11.822706528192693, 10.792812652507601, 9.80749711263784, 8.874737160541882, 8.819145586901293, 7.838437443885349, 6.835348788831346, 5.888328264205876, 4.996523132964945, 4.032795966321453, 4.977084164651823, 5.8526687830683235, 6.8247258524386005, 7.755147284660532, 8.72216874584978, 9.684901486218722, 10.620458897169351, 11.581116131713387, 12.55224050523045, 13.527876154036548, 12.777888435727917, 11.763680105421535, 10.715096243311601, 9.769142895455968, 9.832003491506633, 8.817419695801668, 7.8558127795672394, 6.892349188275997, 5.934412891208316, 4.959928163498519, 5.95065165916051, 6.848733368858559, 7.8776612774192225, 8.791097523710606, 9.736913454583343, 10.644039145016478, 11.58904926806906, 12.568292050602643, 13.531864710437967, 14.483346270542484, 13.575793269336453, 12.634940939893058, 11.690374023558698, 10.72437581918382, 10.838287194498756, 9.82660220876358, 8.865950244097665, 7.844205397632954, 6.895910215528937, 5.902244064760695, 6.885571479306625, 7.819333001637494, 8.761088407122994, 9.806493895298201, 10.756396827830882, 11.631022999750087, 12.51702408701551, 13.446442923487256, 14.134910218681881, 14.735987918514319, 14.650412265669768, 13.646927823504118, 12.709833770857479, 11.651214259905663], [13.562044795723311, 14.521020050996242, 15.500357064433453, 15.57145285810281, 14.543218218471763, 13.955974151331022, 13.068772342059297, 12.611019436433702, 11.74451975690166, 10.877909249598504, 9.842691245034803, 8.852273890683547, 7.822865335773614, 6.928700502741655, 7.736409829636382, 8.724887449757277, 9.68227292873087, 10.706645525959145, 11.682667072747991, 12.709404669098099, 14.580950573369888, 15.576324396986266, 15.454785169941063, 14.573039183070437, 13.513188789292604, 12.976772233013767, 12.118645638439109, 13.017862923130293, 12.80006556329475, 11.73915478622732, 10.785759097797442, 9.91455367949661, 8.859939459884018, 7.891164093069027, 8.663537825207037, 9.730768254305914, 10.607720606220173, 11.53604245088435, 12.591293375130867, 13.636418622284117, 15.513970209469443, 15.43217030043899, 14.475410708610399, 13.58437595545651, 12.58553552264918, 11.93717250411422, 11.11591553910359, 11.958570039655552, 12.748614082127999, 12.761751964402908, 11.806604791261886, 10.91433898943647, 9.87515508555955, 8.947040014716913, 9.611830404799866, 10.55046344032599, 11.500322173530735, 12.549444295909618, 13.516691526214034, 14.468520855885867, 15.407026338855411, 14.471502989545922, 13.49156678730032, 12.56295776779567, 11.523698256246295, 10.953843357422842, 10.109326257593176, 10.891501879665997, 11.732695628336705, 12.655520122105663, 12.86566360401526, 11.798581256583685, 10.834677975487558, 9.93477631393367, 10.63173636074146, 11.561539708912369, 12.429356084033394, 13.364474159840103, 14.358053313001642, 15.366635996923723, 14.481450687431797, 13.532489067568273, 12.50418401153863, 11.550938780742051, 10.541436334485955, 9.89788466425884, 9.055356186533423, 9.827634306963338, 10.740569518212332, 11.588981486260968, 12.45815188257396, 12.737950956996235, 11.823013771645233, 10.906929514268862, 11.610565606971042, 12.622684571018157, 13.42845194578721, 14.357315295564412, 15.303916094864562, 15.485759962259921, 13.485870458341374, 12.507421806993742, 11.558183910558716, 10.632796992914876, 9.598873497865577, 8.84708013791448, 8.010680449671819, 8.865327439828874, 9.808616160577147, 10.540040098333053, 11.486186989988527, 12.43858839124617, 12.849786740368394, 11.92506902951704, 12.536427221988523, 13.515664744686328, 14.442997745571319, 15.355740281972025, 15.387831741626924, 14.425088462206356, 12.541839715546326, 11.52767344302736, 10.566490966435243, 9.60537933189938, 8.628101760214687, 7.876766695835362, 6.948469773456879, 7.826686677028091, 8.788110884635486, 9.598286190411091, 10.525068435607349, 11.454176058678398, 12.436343899849962, 12.938738197991825, 13.488907145417562, 14.443086292674277, 15.405251390206377, 15.43660534756698, 14.428213054010588, 13.495658132443515, 11.530608342261734, 10.56158466911559, 9.584179889283806, 8.574302386317898, 7.602745911335291, 6.850615868898366, 5.9721783265660005, 6.845304693094926, 7.825191119750166, 8.656812153800434, 9.56376273063323, 10.587090760076775, 11.463771913753725, 12.422575598972422, 13.349692420298165, 14.320689585206306, 15.250276185306944, 14.595623025135836, 13.544568809978655, 12.55857190256897, 10.56118920162486, 9.54098787466769, 8.547287191508254, 7.619249600330229, 6.67198528283626, 5.808284759423279, 4.9056494345560155, 5.841256671087336, 6.805827307106842, 7.618597653750353, 8.551719538921457, 9.56472792745878, 10.499885652517982, 11.394507446306864, 12.42381861521384, 13.405717683893746, 14.33343526658931, 13.710777456550122, 12.64395983973291, 11.61055273858637, 9.623109498864634, 8.617970423602443, 7.647266790242019, 6.6661417137428245, 5.708252831148949, 4.864646295129281, 3.9224422704149062, 4.864577064019323, 5.742182241017817, 6.672837176437299, 7.650044715346104, 8.575218174083147, 9.514178409162016, 10.460786949492547, 11.447773541725475, 12.443599979429338, 13.38298341473125, 12.722652371251659, 11.698568951507271, 10.683801203496834, 8.819110958511057, 7.788663550045566, 6.844543883962641, 5.77517822277141, 4.7745101838565365, 3.8008823142204133, 2.874023071071906, 3.8473389918567675, 4.813218443740718, 5.810351656519226, 6.741974682398072, 7.72080085381804, 8.667016623983592, 9.738700142710991, 10.773547774345847, 11.724356321040952, 12.685941766117635, 11.691942749468097, 10.72699790161411, 9.748945748050868, 7.863053121864452, 6.935100009918809, 6.000603889745626, 4.961984132227429, 3.914596406353694, 2.844848638672469, 1.912185504141396, 2.857631291913301, 3.8856344159800162, 4.810755746232022, 5.790625124100544, 6.701338151928746, 7.772332727786072, 8.777942483159336, 9.812886342539109, 10.762078607923758, 11.747143006379238, 10.820329177865895, 9.846075865440868, 8.818658500257367, 6.971500983900339, 5.965536426996456, 5.041665940927766, 3.969753939276976, 2.9044451511191998, 1.894693595742496, 0.9649235373189767, 1.8914205586250676, 2.860437274668352, 3.8802479214161076, 4.848274559644393, 5.773800889784022, 6.7608782213085306, 7.803620344573827, 8.874051358332082, 9.91745430464481, 10.870053579228115, 10.028503459456166, 8.978784336506754, 8.014412419401935, 6.076058670067304, 5.025268857422606, 4.004686514132432, 3.036567014373579, 1.9633138421716518, 0.9486517235996792, 0.0, 0.9376743960983303, 1.9898488253297417, 3.0190395590781396, 4.046493685245011, 5.089935050835628, 6.125804034478896, 7.140588955185128, 8.164522509282277, 9.18878745334159, 10.029336555925285, 9.040649178840706, 8.000104560097972, 7.0535351195640175, 6.843682843335589, 5.902157462490029, 4.85569618147076, 3.85950135223183, 2.934139856246798, 2.0014033430285023, 1.0395353889032741, 1.9180749182527725, 2.873364809351384, 3.8420426321448087, 4.8006876312159665, 5.852294223421634, 6.875021761602671, 7.942932665773769, 8.869732113426025, 9.930398890097754, 10.786309215717642, 9.771768489270986, 8.827862709981861, 7.79070205620829, 7.902927475678772, 6.902823994839958, 5.850347347903108, 4.7903716674446555, 3.9600682307800956, 2.93342971274809, 2.013599308970182, 2.87823746286119, 3.9334096247593524, 4.847198436892886, 5.804103487766653, 6.8358676321155505, 7.812319614133199, 8.852148366935369, 9.82117100736605, 10.813744154707456, 11.778092149292162, 10.819135517058642, 9.785068345819425, 8.798619347658246, 8.801690662231692, 7.855869833134246, 6.808243715780242, 5.763037570351782, 4.963815672715464, 3.952846926265139, 3.018310045151268, 3.841584078837868, 4.814027929721587, 5.81443017434183, 6.757668123053332, 7.7798009370981855, 8.74032541044012, 9.752746317173528, 10.752780257777735, 11.715098588915149, 12.751659409876567, 11.74146437610728, 10.756148836237518, 9.823388884141561, 9.767797310500972, 8.787089167485028, 7.784000512431025, 6.836979987805556, 5.921296418969403, 4.92606126587442, 4.092166596687048, 4.904017059468644, 5.876074128838921, 6.806495561060852, 7.7735170222500996, 8.73624976261904, 9.671807173569672, 10.632464408113707, 11.603588781630771, 12.579224430436868, 13.530386791477317, 12.712331829021215, 11.66374796691128, 10.717794619055647, 10.780655215106314, 9.766071419401348, 8.804464503166919, 7.8410009118756765, 6.827678190761283, 5.853193463051486, 5.0657340911957345, 5.900081645258879, 6.929009553819543, 7.8424458001109265, 8.788261730983663, 9.695387421416797, 10.640397544469378, 11.619640327002962, 12.583212986838287, 13.534694546942804, 14.524444992936132, 13.583592663492738, 12.639025747158378, 11.6730275427835, 11.756815619107059, 10.745130633371883, 9.784478668705967, 8.737470697185922, 7.7891755150819035, 6.795509364313662, 6.00065391134185, 6.870681278037814, 7.812436683523314, 8.857842171698522, 9.807745104231202, 10.682371276150405, 11.568372363415829, 12.497791199887574, 13.525508180691421, 14.503236903796415, 15.492502242882654, 14.595579547103798, 13.658485494457159, 12.599865983505342], [14.499719191821642, 15.458694447094572, 16.438031460531786, 15.589911149576144, 14.561676509945096, 13.606562698898237, 12.584665842447166, 11.673345040335374, 10.80684536080333, 9.940234853500172, 8.905016848936473, 7.914599494585215, 6.885190939675284, 7.824693352201577, 8.644920322026792, 9.633397942147688, 10.59078342112128, 11.615156018349555, 12.5911775651384, 13.617915161488508, 15.518624969468219, 16.513998793084596, 16.392459566039395, 15.510713579168769, 14.450863185390936, 13.914446629112097, 13.00472888272523, 12.190964647704625, 11.862391167196419, 10.80148039012899, 9.848084701699111, 8.976879283398278, 7.922265063785686, 8.78715694252895, 9.572048317597446, 10.639278746696325, 11.516231098610584, 12.444552943274761, 13.499803867521278, 14.544929114674527, 16.422480701859854, 16.36984469653732, 15.413085104708731, 14.522050351554842, 13.523209918747511, 12.87484690021255, 12.00199878338971, 11.131671764229884, 11.839280397285057, 11.824077568304578, 10.868930395163556, 9.976664593338137, 8.93748068946122, 9.843032864176836, 10.520340897190275, 11.458973932716399, 12.408832665921144, 13.457954788300029, 14.425202018604445, 15.377031348276278, 16.34470073495374, 15.409177385644252, 14.429241183398652, 13.500632163894002, 12.461372652344627, 11.891517753521173, 10.995409501879298, 10.064603604240329, 10.823361943493763, 11.741025703876634, 11.92798920791693, 10.860906860485354, 9.897003579389228, 10.830769163393592, 11.540246853131869, 12.470050201302778, 13.337866576423803, 14.272984652230512, 15.266563805392051, 16.27514648931413, 15.419125083530128, 14.470163463666603, 13.44185840763696, 12.488613176840383, 11.479110730584287, 10.83555906035717, 9.941439430819544, 9.00073603153767, 9.83123583336939, 10.674487068031938, 11.54365746434493, 11.800276560897904, 10.885339375546902, 11.802922363728785, 12.51907609936145, 13.531195063408566, 14.336962438177618, 15.265825787954821, 16.21242658725497, 16.423434358358254, 14.423544854439704, 13.445096203092072, 12.495858306657047, 11.570471389013207, 10.53654789396391, 9.78475453401281, 8.94835484577015, 8.038429164403206, 8.899282475734205, 9.625545680104024, 10.571692571759497, 11.524093973017141, 11.912112344270064, 12.821061878976963, 13.444937714378932, 14.424175237076737, 15.351508237961728, 16.264250774362434, 16.325506137725252, 15.362762858304686, 13.479514111644656, 12.465347839125693, 11.504165362533575, 10.543053727997712, 9.565776156313019, 8.814441091933691, 7.88614416955521, 6.999788401602423, 7.878777199792544, 8.683791772182062, 9.610574017378319, 10.539681640449368, 11.521849481620933, 12.511766887857888, 13.508556470184242, 14.46025435203305, 15.392356031846257, 16.336782628543578, 15.365887450108918, 14.433332528541845, 12.468282738360065, 11.49925906521392, 10.521854285382139, 9.51197678241623, 8.540420307433623, 7.788290264996695, 6.909852722664331, 6.018406417669258, 6.915857434907223, 7.742317735571404, 8.6492683124042, 9.672596341847745, 10.549277495524695, 11.508081180743392, 12.435198002069136, 13.406195166977277, 14.335781767077915, 15.274737091429937, 14.482243206076985, 13.4962462986673, 11.49886359772319, 10.478662270766023, 9.484961587606586, 8.55692399642856, 7.60965967893459, 6.745959155521609, 5.843323830654345, 5.014358395661668, 5.8964936222638995, 6.704103235521323, 7.637225120692428, 8.65023350922975, 9.585391234288952, 10.480013028077835, 11.50932419698481, 12.491223265664717, 13.41894084836028, 14.492515886694253, 13.58163423583124, 12.5482271346847, 10.560783894962965, 9.555644819700774, 8.584941186340348, 7.603816109841155, 6.645927227247279, 5.80232069122761, 4.860116666513236, 4.037678788593655, 4.827687822788787, 5.758342758208269, 6.735550297117075, 7.660723755854118, 8.599683990932986, 9.546292531263518, 10.533279123496445, 11.529105561200309, 12.46848899650222, 13.542747624851739, 12.636243347605602, 11.621475599595165, 9.756785354609388, 8.726337946143897, 7.782218280060971, 6.71285261886974, 5.712184579954867, 4.738556710318743, 3.811697467170236, 2.985869736151805, 3.8987240255116884, 4.895077030601646, 5.804300286299742, 6.7831264577197095, 7.729342227885261, 8.80102574661266, 9.835873378247516, 10.786681924942622, 11.770995325665144, 12.629617145566428, 11.66467229771244, 10.686620144149199, 8.800727517962782, 7.87277440601714, 6.938278285843957, 5.89965852832576, 4.852270802452025, 3.782523034770799, 2.8498599002397262, 1.9961620362083385, 2.9479600198816858, 3.873081350133692, 4.852950728002214, 5.763663755830415, 6.834658331687741, 7.840268087061006, 8.875211946440778, 9.824404211825428, 10.865758669846851, 11.758003573964226, 10.783750261539199, 9.756332896355698, 7.909175379998669, 6.903210823094787, 5.9793403370260965, 4.9074283353753065, 3.8421195472175302, 2.8323679918408264, 1.902597933417307, 0.9537461625267373, 1.922762878570022, 2.942573525317777, 3.9106001635460625, 4.836126493685692, 5.8232038252102, 6.865945948475496, 7.9363769622337506, 8.97977990854648, 9.932379183129784, 10.921079566424464, 9.916458732605085, 8.952086815500266, 7.013733066165634, 5.962943253520937, 4.942360910230763, 3.9742414104719095, 2.9009882382699823, 1.8863261196980095, 0.9376743960983303, 0.0, 1.0521744292314115, 2.081365162979809, 3.108819289146681, 4.152260654737297, 5.188129638380565, 6.202914559086797, 7.226848113183947, 8.25111305724326, 9.234820564181927, 9.978323574939036, 8.937778956196302, 7.991209515662348, 7.78135723943392, 6.83983185858836, 5.793370577569091, 4.797175748330161, 3.8718142523451284, 2.939077739126833, 1.9772097850016044, 0.9804005221544423, 1.935690413253054, 2.9043682360464786, 3.8630132351176365, 4.914619827323304, 5.9373473655043405, 7.005258269675439, 7.9320577173276945, 8.992724493999424, 10.006877204625082, 10.709442885369317, 9.765537106080192, 8.728376452306621, 8.840601871777103, 7.840498390938288, 6.788021744001439, 5.728046063542986, 4.897742626878426, 3.8711041088464206, 2.9399809623300532, 1.9405630667628597, 2.9957352286610224, 3.9095240407945555, 4.866429091668323, 5.898193236017221, 6.8746452180348685, 7.914473970837038, 8.88349661126772, 9.876069758609125, 10.855694071646292, 11.756809913156973, 10.722742741917758, 9.736293743756578, 9.739365058330023, 8.793544229232577, 7.745918111878573, 6.700711966450113, 5.88015798126408, 4.861357418655549, 3.926820537541678, 2.9039096827395374, 3.876353533623257, 4.8767557782435, 5.819993726955001, 6.842126540999855, 7.802651014341789, 8.815071921075198, 9.815105861679404, 10.777424192816818, 11.813985013778236, 12.679138772205611, 11.69382323233585, 10.761063280239892, 10.705471706599303, 9.724763563583359, 8.721674908529355, 7.774654383903886, 6.829806911359814, 5.834571758264831, 4.9881594461469705, 3.9663426633703134, 4.93839973274059, 5.8688211649625215, 6.835842626151769, 7.798575366520711, 8.734132777471341, 9.694790012015376, 10.66591438553244, 11.641550034338538, 12.592712395378987, 13.64841550644198, 12.601422363009611, 11.655469015153978, 11.718329611204645, 10.703745815499678, 9.742138899265248, 8.761217701566204, 7.736188683151694, 6.761703955441897, 5.961726940655657, 4.962407249160549, 5.991335157721212, 6.904771404012596, 7.850587334885332, 8.757713025318468, 9.70272314837105, 10.681965930904633, 11.645538590739957, 12.597020150844473, 13.614734260815172, 14.521267059591068, 13.576700143256708, 12.61070193888183, 12.665326111497468, 11.653641125762292, 10.692989161096376, 9.64598118957633, 8.697686007472313, 7.704019856704073, 6.896646760801772, 5.933006881939484, 6.874762287424984, 7.920167775600191, 8.87007070813287, 9.744696880052075, 10.6306979673175, 11.560116803789246, 12.58783378459309, 13.565562507698084, 14.554827846784324, 15.533253943202128, 14.596159890555489, 13.537540379603673], [15.551893621053052, 16.510868876325983, 15.689489297949574, 14.718349635774715, 13.690114996143667, 12.735001185096808, 11.713104328645736, 10.801783526533944, 9.935283847001902, 9.068673339698742, 8.221420375171494, 7.303676710995277, 7.924209208071077, 8.863711620597371, 9.683938590422585, 10.672416210543481, 11.629801689517073, 12.654174286745349, 13.630195833534193, 14.656933429884301, 16.570799398699627, 17.566173222316007, 16.680002176253577, 15.76015103675426, 14.703437729923873, 13.714203103414063, 12.663231032265925, 11.851431482395935, 10.990829653394991, 10.105480936886568, 9.164488227934132, 8.36595649980834, 8.96128333218148, 9.826175210924744, 10.611066585993239, 11.678297015092118, 12.555249367006377, 13.483571211670554, 14.538822135917071, 15.58394738307032, 17.461498970255647, 17.42201912576873, 16.46525953394014, 15.574224780786253, 14.575384347978922, 13.79603958359536, 12.870818940961826, 11.919152217464582, 10.903489228682202, 11.128078115062156, 10.185333921398577, 9.365741809748199, 9.976498957857013, 10.882051132572629, 11.559359165586068, 12.497992201112192, 13.447850934316937, 14.496973056695822, 15.464220287000238, 16.416049616672073, 17.39687516418515, 16.461351814875663, 15.481415612630062, 14.552806593125412, 13.513547081576037, 12.812710436903984, 11.864229659451413, 10.87312112504919, 9.887570774890909, 10.805234535273781, 11.244392734151951, 10.354106675568847, 10.936021847785021, 11.869787431789385, 12.579265121527662, 13.50906846969857, 14.376884844819596, 15.312002920626306, 16.305582073787846, 17.314164757709925, 16.471299512761536, 15.522337892898014, 14.49403283686837, 13.540787606071794, 12.531285159815697, 11.866276368458374, 10.839135184419035, 9.898431785137161, 8.895444664766536, 9.738695899429086, 10.607866295742078, 11.293476375981397, 11.924357643942695, 12.841940632124578, 13.558094367757244, 14.570213331804359, 15.375980706573412, 16.304844056350614, 17.251444855650767, 17.475608787589668, 15.475719283671118, 14.497270632323483, 13.548032735888457, 12.622645818244617, 11.58872232319532, 10.815471842114015, 9.904654679199519, 8.936124918002697, 7.963491307131351, 8.689754511501171, 9.635901403156645, 10.588302804414289, 11.57882177595245, 12.507780724287574, 13.485591094212705, 14.46482861691051, 15.3921616177955, 16.376853397340618, 17.37768056695667, 16.4149372875361, 14.53168854087607, 13.517522268357103, 12.556339791764985, 11.595228157229123, 10.61795058554443, 9.845158400034896, 8.903536838839539, 7.897484155201914, 6.942986031189689, 7.748000603579208, 8.674782848775466, 9.603890471846515, 10.58605831301808, 11.575975719255034, 12.572765301581388, 13.524463183430196, 14.456564863243402, 15.400991459940723, 16.409383753497114, 15.485506957773259, 13.520457167591479, 12.55143349444533, 11.574028714613549, 10.56415121164764, 9.592594736665033, 8.836622840790756, 7.927245391948659, 6.91610217126875, 5.980066266304369, 6.80652656696855, 7.713477143801347, 8.73680517324489, 9.61348632692184, 10.572290012140538, 11.499406833466281, 12.470403998374422, 13.39999059847506, 14.338945922827083, 15.390000137984265, 14.548420727898714, 12.551038026954604, 11.530836699997433, 10.537136016837996, 9.60909842565997, 8.661834108166001, 7.79429173131567, 6.860716499938674, 5.91205414926116, 4.960702453661045, 5.76831206691847, 6.701433952089575, 7.7144423406268965, 8.649600065686098, 9.54422185947498, 10.573533028381956, 11.555432097061862, 12.483149679757426, 13.556724718091399, 14.623542334908612, 13.600401563916114, 11.612958324194379, 10.607819248932188, 9.637115615571762, 8.655990539072567, 7.69810165647869, 6.850653267021671, 5.877509335797564, 4.935374542193147, 3.8918966541859334, 4.822551589605416, 5.799759128514221, 6.724932587251264, 7.663892822330132, 8.610501362660663, 9.597487954893591, 10.593314392597454, 11.532697827899366, 12.606956456248884, 13.631649623091617, 12.673650028826579, 10.808959783840798, 9.778512375375307, 8.834392709292382, 7.765027048101151, 6.764359009186278, 5.790731139550155, 4.863871896401648, 3.9288123087927853, 2.9629328569088345, 3.9592858619987923, 4.868509117696888, 5.836374461634367, 6.782590231799919, 7.854273750527318, 8.853615045302185, 9.80442359199729, 10.788736992719812, 11.800359068846864, 12.716846726943851, 11.73879457338061, 9.852901947194193, 8.92494883524855, 7.990452715075368, 6.951832957557171, 5.904445231683436, 4.83469746400221, 3.9020343294711375, 2.9984042996920537, 2.012168851278832, 2.937290181530838, 3.9171595593993604, 4.781405422885083, 5.852399998742409, 6.858009754115674, 7.892953613495447, 8.842145878880096, 9.88350033690152, 10.810314165414862, 11.78456747783989, 10.808507325587108, 8.96134980923008, 7.955385252326197, 7.031514766257508, 5.959602764606718, 4.8942939764489415, 3.8845424210722377, 2.9547723626487183, 1.9559884260104525, 0.9869717099671679, 1.9603151923724444, 2.92834183060073, 3.853868160740359, 4.840945492264868, 5.883687615530164, 6.954118629288418, 7.997521575601146, 8.950120850184451, 9.93882123347913, 10.968633161836495, 10.004261244731678, 8.065907495397045, 7.015117682752347, 5.994535339462173, 5.02641583970332, 3.9531626675013936, 2.938500548929421, 1.9898488253297417, 1.0521744292314115, 0.0, 1.0291907337483976, 2.056644859915269, 3.100086225505886, 4.135955209149154, 5.150740129855386, 6.174673683952536, 7.198938628011848, 8.182646134950517, 9.171333512035096, 9.989953385427713, 9.043383944893758, 8.83353166866533, 7.89200628781977, 6.845545006800501, 5.849350177561572, 4.92398868157654, 3.991252168358244, 3.0293842142330156, 2.0194187905502354, 1.0641288994516238, 2.0328067222450485, 2.9914517213162064, 4.043058313521874, 5.065785851702911, 6.133696755874009, 7.060496203526265, 8.121162980197994, 9.135315690823653, 10.133598777647563, 10.817711535311602, 9.780550881538032, 9.892776301008514, 8.892672820169699, 7.840196173232849, 6.780220492774397, 5.949917056109838, 4.923278538077832, 3.9789992307258464, 2.979581335158653, 2.124173714859592, 3.037962526993126, 3.994867577866893, 5.02663172221579, 6.003083704233439, 7.042912457035609, 8.01193509746629, 9.004508244807695, 9.984132557844863, 10.943089190078382, 11.774917171149168, 10.788468172987988, 10.791539487561433, 9.845718658463987, 8.798092541109984, 7.752886395681524, 6.919176249659873, 5.900375687051342, 4.965838805937471, 3.9429279511353306, 3.118564449770057, 4.037036262956276, 4.948432213153572, 5.970565027198425, 6.931089500540359, 7.943510407273768, 8.943544347877975, 9.905862679015389, 10.942423499976806, 11.962264955408838, 12.74599766156726, 11.813237709471302, 11.757646135830713, 10.77693799281477, 9.773849337760765, 8.826828813135297, 7.868825179755607, 6.873590026660624, 6.027177714542764, 5.0053609317661065, 4.180610648887391, 5.1033641284612, 5.964281112350339, 6.9270138527192815, 7.8625712636699125, 8.823228498213947, 9.79435287173101, 10.769988520537108, 11.721150881577557, 12.77685399264055, 13.653596792241022, 12.707643444385388, 12.770504040436055, 11.755920244731088, 10.782854457449409, 9.800235969961998, 8.775206951547487, 7.80072222383769, 7.00074520905145, 6.001425517556342, 5.233546073868013, 6.139314367511275, 6.979025821083902, 7.886151511517038, 8.83116163456962, 9.810404417103204, 10.773977076938527, 11.725458637043044, 12.743172747013743, 13.684025076457138, 14.628591992791497, 13.66287636811324, 13.70434437989326, 12.692659394158085, 11.73200742949217, 10.684999457972124, 9.736704275868107, 8.743038125099865, 7.9356650291975654, 6.972025150335277, 6.263839503835046, 7.212233024994208, 7.99850919433144, 8.873135366250647, 9.75913645351607, 10.688555289987816, 11.716272270791661, 12.694000993896655, 13.683266332982894, 14.696011960068198, 15.6483343197869, 14.589714808835083], [16.490928906573412, 15.67230540314136, 14.696810754416797, 13.725671092241937, 12.697436452610889, 11.74232264156403, 10.72042578511296, 9.809104983001168, 8.942605303469122, 8.075994796165965, 7.250729340268064, 8.186160587887588, 8.890873818754498, 9.830376231280791, 10.650603201106005, 11.639080821226901, 12.596466300200493, 13.620838897428769, 14.596860444217613, 15.623598040567721, 17.50983468421999, 16.706822695379763, 15.687323632720801, 14.767472493221483, 13.710759186391094, 12.721524559881285, 11.670552488733149, 10.858752938863159, 9.998151109862212, 9.112802393353792, 8.193797193030703, 9.153839266735854, 9.9279479428649, 10.792839821608164, 11.577731196676659, 12.644961625775538, 13.521913977689797, 14.450235822353974, 15.505486746600491, 16.55061199375374, 18.428163580939067, 17.560178197834095, 16.603418606005505, 15.63725288584185, 14.638412453034519, 13.704485190566391, 12.673282588068668, 11.9180458223379, 11.014588301568317, 10.13539957152938, 9.214642886495147, 10.145435875284317, 10.943163568540433, 11.848715743256049, 12.526023776269488, 13.464656811795612, 14.414515545000357, 15.463637667379242, 16.430884897683658, 17.382714227355493, 18.32998106850296, 17.394457719193472, 16.41452151694787, 15.48591249744322, 14.446652985893845, 13.560132251943935, 12.611651474491364, 11.620542940089141, 10.63499258993086, 9.898859334314198, 10.273701699248521, 11.133800741104965, 11.902686458468441, 12.836452042472805, 13.545929732211082, 14.47573308038199, 15.343549455503016, 16.278667531309726, 17.272246684471266, 18.280829368393345, 17.404405417079346, 16.45544379721582, 15.42713874118618, 14.473893510389601, 13.464391064133505, 12.669200438411876, 11.623902941387763, 10.68319954210589, 9.642866479806488, 8.832320698469502, 9.701491094782494, 10.642857227308287, 11.677475363324636, 12.619545038576168, 13.491428795165527, 14.51369117161426, 15.475400593821997, 16.404263943599197, 17.416943161788687, 18.34350706022252, 16.408825187988924, 15.430376536641292, 14.481138640206266, 13.555751722562427, 12.521828227513128, 11.62659788995931, 10.689422436168247, 9.720892674971426, 8.710913122171302, 7.783379310541587, 8.72952620219706, 9.681927603454705, 10.672446574992867, 11.60140552332799, 12.565567180148046, 13.54480470284585, 14.45914046301608, 15.417175352478235, 16.469261134331123, 17.282835560168955, 15.464794445193876, 14.45062817267491, 13.489445696082793, 12.52833406154693, 11.551056489862237, 10.691583225434576, 9.749961664239219, 8.743908980601594, 7.784169773811608, 6.841625402619624, 7.768407647815882, 8.697515270886932, 9.679683112058497, 10.616297674392653, 11.613087256719007, 12.564785138567816, 13.496886818381022, 14.44131341507834, 15.449705708634733, 16.353405230406114, 14.453563071909285, 13.48453939876314, 12.507134618931357, 11.497257115965448, 10.52570064098284, 9.683047666190436, 8.77367021734834, 7.76252699666843, 6.821250008926287, 5.900151366008966, 6.807101942841763, 7.77712712838251, 8.65380828205946, 9.612611967278157, 10.5397287886039, 11.510725953512042, 12.44031255361268, 13.379267877964702, 14.430322093121884, 15.41631900053157, 13.48414393127241, 12.46394260431524, 11.470241921155804, 10.542204329977778, 9.594940012483809, 8.64071655671535, 7.707141325338354, 6.75847897466084, 5.801886196282964, 4.861936865958886, 5.795058751129991, 6.754764295764516, 7.689922020823717, 8.5845438146126, 9.613854983519575, 10.595754052199482, 11.523471634895046, 12.597046673229018, 13.66386429004623, 14.53350746823392, 12.546064228512185, 11.540925153249994, 10.570221519889568, 9.589096443390373, 8.631207560796497, 7.697078092421351, 6.723934161197244, 5.781799367592827, 4.738321479585613, 3.9161763886458316, 4.840081083651841, 5.765254542388884, 6.704214777467751, 7.650823317798283, 8.63780991003121, 9.633636347735074, 10.573019783036985, 11.647278411386505, 12.671971578229238, 13.606755933144385, 11.74629081351672, 10.711618279693113, 9.767498613610188, 8.698132952418957, 7.697464913504084, 6.72383704386796, 5.766779934880027, 4.775237134192465, 3.809357682308514, 2.9554680268944598, 3.8646912825925552, 4.8071837278859695, 5.753399498051521, 6.82508301677892, 7.824424311553786, 8.775232858248891, 9.759546258971413, 10.771168335098466, 11.690729667199623, 12.668781820762865, 10.86940460581376, 9.941451493868117, 8.923558619393173, 7.884938861874977, 6.837551136001242, 5.767803368320016, 4.835140233788943, 3.889694446017037, 2.8585936766785114, 1.9334723464265051, 2.9133417242950275, 3.752214689136685, 4.823209264994011, 5.828819020367276, 6.863762879747049, 7.812955145131697, 8.854309603153121, 9.781123431666463, 10.75537674409149, 11.782794109274992, 9.99054054297848, 8.984575986074596, 8.060705500005906, 6.988793498355116, 5.923484710197339, 4.913733154820636, 3.9471022642029467, 2.919951821415087, 1.950935105371802, 0.9311244586240468, 1.8991510968523322, 2.8246774269919612, 3.81175475851647, 4.854496881781767, 5.924927895540021, 6.968330841852749, 7.920930116436053, 8.909630499730731, 9.959349622680143, 10.92891897792771, 9.095098229145444, 8.044308416500746, 7.023726073210572, 6.055606573451719, 4.982353401249791, 3.967691282677819, 3.0190395590781396, 2.081365162979809, 1.0291907337483976, 0.0, 1.0274541261668717, 2.0708954917574887, 3.106764475400757, 4.121549396106989, 5.145482950204139, 6.169747894263451, 7.153455401202119, 8.142142778286699, 9.182687397029433, 10.072574678642157, 9.862722402413729, 8.921197021568169, 7.8747357405489, 6.87854091130997, 5.9531794153249376, 4.973501493387891, 4.010578360523857, 2.986083401233655, 2.030793510135043, 1.0621156873416187, 1.9987731777834288, 3.050379769989096, 4.073107308170133, 5.141018212341232, 6.067817659993487, 7.0956558473758395, 8.109808558001498, 9.104408043899166, 10.048313823188291, 10.80974161528643, 10.921967034756912, 9.921863553918097, 8.869386906981248, 7.809411226522795, 6.971433512707472, 5.905527863107479, 4.945663841409266, 3.9462459458420724, 3.0908383255430114, 2.067271492089696, 3.0021890343341155, 4.033953178683013, 5.010405160700661, 6.050233913502831, 7.019256553933513, 8.011829701274918, 8.991454014312085, 9.950410646545604, 11.021670476303077, 11.817658906736387, 11.820730221309834, 10.874909392212388, 9.827283274858383, 8.782077129429922, 7.8858408603432935, 6.867040297734762, 5.932503416620891, 4.909592561818751, 4.066747472673089, 3.066345228052846, 3.9557536696207936, 4.977886483665647, 5.938410957007581, 6.950831863740989, 7.950865804345196, 8.91318413548261, 9.949744956444027, 10.96958641187606, 11.954901951745821, 12.842428443219703, 12.786836869579114, 11.80612872656317, 10.803040071509164, 9.856019546883696, 8.835489790439027, 7.840254637344044, 6.993842325226184, 5.9720255424495265, 5.063094525779701, 4.13267309355777, 4.971602568817562, 5.934335309186504, 6.869892720137134, 7.830549954681169, 8.801674328198233, 9.77730997700433, 10.72847233804478, 11.784175449107773, 12.832759311217707, 13.736834178133789, 13.799694774184456, 12.772907270761968, 11.749519068132829, 10.766900580645418, 9.741871562230907, 8.76738683452111, 7.96740981973487, 6.968090128239762, 6.116029950760323, 5.1686233326078455, 5.986347277551125, 6.893472967984261, 7.838483091036843, 8.817725873570428, 9.78129853340575, 10.732780093510266, 11.750494203480965, 12.69134653292436, 13.63591344925872, 14.601911653633598, 14.67100899057668, 13.659324004841505, 12.69867204017559, 11.651664068655544, 10.703368886551527, 9.709702735783285, 8.902329639880985, 7.938689761018697, 7.146323380727356, 6.241541990090778, 7.0058306507986625, 7.880456822717869, 8.766457909983295, 9.69587674645504, 10.723593727258883, 11.701322450363877, 12.690587789450117, 13.70333341653542, 14.70233804677606, 15.528750094355441], [15.463474780406539, 14.644851276974489, 13.669356628249925, 12.698216966075066, 11.669982326444018, 10.714868515397159, 9.692971658946087, 8.781650856834295, 7.915151177302251, 7.048540669999094, 8.05913102467435, 9.044585534426174, 9.758722182100595, 10.698224594626886, 11.5184515644521, 12.506929184572996, 13.464314663546588, 14.488687260774864, 15.464708807563708, 16.47365241236658, 16.482380558053116, 15.679368569212892, 14.659869506553928, 13.740018367054612, 12.683305060224225, 11.694070433714414, 10.643098362566276, 9.831298812696286, 8.97069698369534, 8.08534826718692, 9.002198877436989, 9.962240951142139, 10.795796306210997, 11.660688184954259, 12.445579560022754, 13.512809989121633, 14.389762341035892, 15.31808418570007, 16.373335109946584, 17.418460357099832, 17.473879211490118, 16.532724071667225, 15.575964479838634, 14.60979875967498, 13.61095832686765, 12.677031064399518, 11.645828461901795, 10.890591696171027, 9.987134175401446, 9.107945445362507, 10.023044570901433, 10.953837559690603, 11.81101193188653, 12.716564106602144, 13.393872139615583, 14.332505175141707, 15.282363908346452, 16.331486030725337, 17.29873326102975, 18.250562590701584, 18.481228075808723, 17.543814010788427, 16.559808401148715, 15.665599991336862, 14.626340479787487, 13.60089852086478, 12.652417743412208, 11.957659856160582, 11.003052629192739, 10.166621165007323, 10.026243331522467, 10.828819114047914, 11.79272239514404, 12.75527083549979, 13.665835689882252, 14.70986601885113, 15.638384645291262, 16.57350272109797, 17.558383592138753, 18.5093035246557, 18.431859543246215, 17.48289792338269, 16.45459286735305, 15.50134763655647, 14.491845190300374, 13.696654564578745, 12.651357067554633, 11.710653668272759, 10.670320605973357, 9.859774824636371, 8.971027604190414, 9.889449413635363, 10.924067549651713, 11.843684006602757, 12.68700644365267, 13.709268820101403, 14.67097824230914, 15.599841592086342, 16.612520810275832, 17.539084708709666, 17.428756267916775, 16.45783066280816, 15.508592766373136, 14.583205848729296, 13.549282353679997, 12.65405201612618, 11.716876562335116, 10.748346801138295, 9.738367248338172, 8.810833436708457, 7.999062711604981, 8.928519789781781, 9.919038761319943, 10.825544491354579, 11.761144828635189, 12.740382351332993, 13.654718111503223, 14.61275300096538, 15.664838782818268, 16.4784132086561, 16.492248571360747, 15.47808229884178, 14.516899822249663, 13.5557881877138, 12.578510616029106, 11.719037351601447, 10.77741579040609, 9.771363106768465, 8.811623899978478, 7.869079528786495, 6.977598625637506, 7.9046341828352675, 8.882546901259447, 9.811875322879795, 10.80866490520615, 11.760362787054959, 12.692464466868165, 13.636891063565486, 14.645283357121878, 15.548982878893257, 15.481017198076154, 14.51199352493001, 13.534588745098226, 12.524711242132318, 11.55315476714971, 10.710501792357306, 9.80112434351521, 8.7899811228353, 7.848704135093158, 6.927605492175837, 6.016292920663387, 6.972704776869653, 7.849385930546604, 8.808189615765299, 9.735306437091044, 10.706303601999185, 11.635890202099823, 12.574845526451846, 13.625899741609027, 14.611896649018712, 14.51159805743928, 13.49139673048211, 12.497696047322673, 11.569658456144648, 10.622394138650678, 9.66817068288222, 8.734595451505225, 7.7859331008277115, 6.829340322449834, 5.889390992125756, 5.004249728951615, 5.950341944251659, 6.88549966931086, 7.780121463099742, 8.809432632006718, 9.791331700686625, 10.719049283382189, 11.792624321716161, 12.859441938533374, 13.826475903481995, 13.573518354679054, 12.568379279416863, 11.597675646056437, 10.616550569557242, 9.658661686963367, 8.724532218588221, 7.751388287364115, 6.809253493759698, 5.765775605752484, 4.943630514812702, 4.035658732138984, 4.960832190876027, 5.899792425954894, 6.846400966285426, 7.8333875585183526, 8.829213996222217, 9.768597431524128, 10.842856059873647, 11.86754922671638, 12.845787378298967, 12.771467446614386, 11.739072405859986, 10.79495273977706, 9.725587078585828, 8.724919039670954, 7.751291170034832, 6.7942340610468985, 5.802691260359336, 4.836811808475385, 3.982922153061331, 3.0602689310796984, 3.9674845527497133, 4.913700322915265, 5.985383841642664, 6.98472513641753, 7.935533683112634, 8.919847083835156, 9.931469159962209, 10.851030492063366, 11.829082645626608, 11.896858731980632, 10.96890562003499, 9.951012745560046, 8.912392988041848, 7.865005262168113, 6.795257494486887, 5.862594359955814, 4.917148572183908, 3.8860478028453826, 2.9609264725933766, 2.1089193727821707, 2.9125155140004284, 3.983510089857755, 4.98911984523102, 6.024063704610793, 6.973255969995441, 8.014610428016864, 8.941424256530206, 9.915677568955234, 10.943094934138735, 11.01799466914535, 10.012030112241467, 9.088159626172779, 8.016247624521988, 6.950938836364211, 5.941187280987507, 4.974556390369818, 3.947405947581958, 2.9783892315386735, 1.9585785847909185, 1.0594519217160754, 1.9849782518557046, 2.9720555833802136, 4.01479770664551, 5.053971704930833, 6.097374651243561, 7.0499739258268646, 8.038674309121543, 9.088393432070955, 10.057962787318521, 10.079279160893227, 9.071762542667617, 8.051180199377443, 7.08306069961859, 6.009807527416664, 4.9951454088446905, 4.046493685245011, 3.1088192891466804, 2.056644859915269, 1.0274541261668717, 0.0, 1.043441365590617, 2.079310349233885, 3.0940952699401167, 4.118028824037267, 5.142293768096579, 6.126001275035247, 7.114688652119826, 8.15523327086256, 9.101802711396514, 10.746939101746545, 9.805413720900985, 8.758952439881716, 7.762757610642787, 6.837396114657754, 5.841349856733988, 4.8784267238699535, 3.853931764579751, 2.8986418734811394, 1.929964050687715, 0.9713190516165572, 2.0229256438222247, 3.0456531820032615, 4.113564086174359, 5.040363533826615, 6.068201721208967, 7.082354431834625, 8.076953917732293, 9.020859697021418, 10.058020350794989, 11.806183734089728, 10.806080253250913, 9.753603606314064, 8.693627925855612, 7.839281876053569, 6.773376226453576, 5.813512204755362, 4.814094309188168, 3.9586866888891077, 2.935119855435792, 1.9747349081672438, 3.0064990525161415, 3.9829510345337895, 5.022779787335959, 5.9918024277666415, 6.9843755751080465, 7.963999888145214, 8.922956520378733, 9.994216350136206, 10.980665348297386, 12.704946920642648, 11.759126091545202, 10.711499974191199, 9.666293828762738, 8.753689223689388, 7.734888661080857, 6.800351779966987, 5.777440925164846, 4.934595836019184, 3.934193591398942, 2.928299543453922, 3.9504323574987756, 4.91095683084071, 5.923377737574118, 6.923411678178325, 7.885730009315738, 8.922290830277156, 9.942132285709189, 10.92744782557895, 11.90267123983584, 13.671053568911928, 12.690345425895984, 11.68725677084198, 10.740236246216512, 9.703338153785122, 8.708103000690139, 7.8616906885722795, 6.839873905795622, 5.921519472318287, 4.991098040096356, 3.9441484426506896, 4.906881183019632, 5.842438593970263, 6.803095828514298, 7.774220202031362, 8.74985585083746, 9.701018211877908, 10.756721322940901, 11.805305185050836, 12.75125853290647, 14.569257745049928, 13.640755634108062, 12.617367431478923, 11.634748943991513, 10.609719925577002, 9.635235197867205, 8.835258183080965, 7.835938491585859, 6.974454897298909, 6.027048279146431, 4.9588931513842525, 5.866018841817389, 6.811028964869971, 7.790271747403555, 8.753844407238878, 9.705325967343395, 10.723040077314094, 11.663892406757489, 12.608459323091848, 13.574457527466727, 15.538857353922776, 14.5271723681876, 13.566520403521684, 12.519512432001639, 11.571217249897622, 10.57755109912938, 9.77017800322708, 8.806538124364794, 8.004748327265942, 7.049943674497065, 5.97837652463179, 6.8530026965509965, 7.739003783816422, 8.668422620288167, 9.696139601092012, 10.673868324197006, 11.663133663283245, 12.675879290368549, 13.674883920609188, 14.50129596818857], [14.499052896237913, 13.680429392805863, 12.7049347440813, 11.733795081906438, 10.70556044227539, 9.750446631228531, 8.772789675932826, 7.8614688738210345, 7.075426631035458, 8.09198203558971, 9.102572390264967, 10.088026900016791, 10.802163547691212, 11.741665960217503, 12.561892930042717, 13.550370550163613, 14.507756029137205, 15.53212862636548, 16.508150173154327, 15.509230528197953, 15.51795867388449, 14.714946685044266, 13.695447622385302, 12.775596482885984, 11.718883176055595, 10.729648549545786, 9.722916379553014, 8.911116829683026, 8.130972437428547, 9.128789632777536, 10.045640243027606, 11.005682316732756, 11.839237671801614, 12.704129550544875, 13.48902092561337, 14.55625135471225, 15.433203706626509, 16.361525551290686, 17.4167764755372, 16.563739018144815, 16.50945732732149, 15.568302187498595, 14.611542595670004, 13.64537687550635, 12.64653644269902, 11.756849081386257, 10.725646478888534, 9.970409713157768, 9.147409629134652, 10.151386810953124, 11.06648593649205, 10.87780625026939, 11.812867555472877, 12.803629405117375, 13.719266334836014, 14.657899370362138, 15.60094324480609, 16.634735443903367, 17.577742469495362, 17.554906680905063, 17.516806191640093, 16.579392126619798, 15.595386516980083, 14.709931242612075, 13.706158496774226, 12.680716537851518, 11.732235760398947, 11.037477873147322, 10.163328082925945, 11.14005347376041, 10.830184990507778, 9.889441384448743, 10.853344665544869, 11.815893105900619, 12.69936037889442, 13.743390707863298, 14.67190933430343, 15.60702741011014, 16.591908281150918, 17.542828213667867, 17.470383050324966, 17.51840604859745, 16.651368156525017, 15.697922864790662, 14.688420418534566, 13.736675231015521, 12.7862058314587, 12.101345445849981, 11.155454193050318, 10.709004965468749, 9.774969263175725, 8.950071684036192, 9.984689820052541, 10.877208695614925, 11.720531132664838, 12.742793509113572, 13.704502931321308, 14.63336628109851, 15.646045499287998, 16.572609397721834, 16.462280956928943, 17.3733795057625, 16.424141609327474, 15.498754691683633, 14.464831196634334, 13.503282156958557, 12.566106703167494, 11.597576941970672, 10.587597389170549, 9.660063577540834, 8.803004370590292, 7.98914206018261, 8.979661031720772, 9.859069180366747, 10.794669517647357, 11.773907040345161, 12.688242800515392, 13.646277689977548, 14.698363471830437, 15.511937897668266, 15.581648959172904, 16.393631141796117, 15.432448665204, 14.471337030668137, 13.494059458983443, 12.619980704705402, 11.678359143510045, 10.63126324539237, 9.663546180960754, 8.718309669618872, 7.781540284622818, 6.965256453236097, 7.916071590271614, 8.845400011891963, 9.842189594218318, 10.793887476067127, 11.725989155880333, 12.670415752577654, 13.678808046134046, 14.582507567905425, 14.673384898338115, 15.427542367884346, 14.450137588052563, 13.440260085086654, 12.468703610104047, 11.62605063531164, 10.716673186469546, 9.649881261459205, 8.700626416075433, 7.776835633008215, 6.8202345796487, 6.0333270472704825, 6.882910619558772, 7.841714304777467, 8.768831126103212, 9.739828291011353, 10.669414891111991, 11.608370215464014, 12.659424430621195, 13.64542133803088, 13.75136533368715, 14.406945573436447, 13.41324489027701, 12.485207299098985, 11.537942981605015, 10.583719525836555, 9.65014429445956, 8.645833239451616, 7.681262603432111, 6.741313273108033, 5.808191387936928, 5.010964214652487, 5.919024358323028, 6.81364615211191, 7.842957321018886, 8.824856389698793, 9.752573972394357, 10.82614901072833, 11.892966627545542, 12.822072111003628, 12.813285630926925, 13.4839281223712, 12.513224489010774, 11.53209941251158, 10.574210529917703, 9.640081061542556, 8.66693713031845, 7.724802336714034, 6.68132444870682, 5.816807930033102, 4.839600391124296, 4.021454461276855, 4.933317114967062, 5.879925655297594, 6.866912247530521, 7.862738685234385, 8.802122120536296, 9.876380748885815, 10.901073915728547, 11.8413835858206, 11.767063654136019, 12.654621248814323, 11.710501582731396, 10.641135921540165, 9.640467882625291, 8.666840012989168, 7.7097829040012344, 6.718240103313672, 5.752360651429721, 4.865675592334969, 3.8642105900650114, 2.9630807602713483, 3.9092965304369, 4.980980049164299, 5.980321343939164, 6.931129890634269, 7.91544329135679, 8.927065367483843, 9.846626699584998, 10.82467885314824, 10.894296520053285, 11.822249631998927, 10.86656158851438, 9.827941830996183, 8.780554105122448, 7.710806337441222, 6.778143202910149, 5.832697415138244, 4.801596645799719, 3.8764753155477125, 2.9128610317674837, 1.9081117215220635, 2.97910629737939, 3.984716052752655, 5.019659912132427, 5.968852177517076, 7.010206635538498, 7.937020464051841, 8.911273776476868, 9.93869114166037, 10.035180258417567, 11.026895177521158, 10.02038652804045, 8.94847452638966, 7.8831657382318845, 6.87341418285518, 5.890105233324155, 4.862954790536294, 3.8939380744930094, 2.874127427745254, 1.9061007895169688, 0.9805744593773397, 1.9676517909018485, 3.010393914167145, 4.010530339340216, 5.053933285652944, 6.006532560236248, 6.995232943530926, 8.044952066480338, 9.014521421727904, 9.03583779530261, 10.086627607947309, 9.09462156496806, 8.126502065209207, 7.0532488930072805, 6.0385867744353074, 5.089935050835628, 4.152260654737297, 3.100086225505886, 2.0708954917574887, 1.043441365590617, 0.0, 1.0358689836432682, 2.0506539043495002, 3.0745874584466497, 4.098852402505962, 5.08255990944463, 6.071247286529209, 7.111791905271943, 8.058361345805897, 9.961598198077073, 10.848855086491602, 9.802393805472333, 8.806198976233404, 7.880837480248371, 6.884791222324605, 5.92186808946057, 4.897373130170368, 3.9420832390717564, 2.973405416278332, 2.014760417207174, 1.0279686190866943, 2.050696157267731, 3.0746743879486353, 4.0014738356008905, 5.02476035561835, 6.0389130662440085, 7.033512552141677, 7.977418331430801, 9.014578985204372, 10.987619346647516, 11.84952161884153, 10.79704497190468, 9.737069291446229, 8.882723241644186, 7.816817592044193, 6.856953570345979, 5.857535674778785, 5.002128054479725, 3.9785612210264087, 3.0181762737578604, 2.011542027780611, 2.987994009798259, 4.027822762600429, 4.952912729540916, 5.945485876882321, 6.925110189919488, 7.884066822153007, 8.95532665191048, 9.94177565007166, 11.885479763519983, 12.802567457135819, 11.754941339781816, 10.709735194353355, 9.797130589280005, 8.778330026671474, 7.843793145557604, 6.820882290755463, 5.978037201609801, 4.977634956989559, 3.9717409090445384, 3.0551956996066965, 3.9465349466720823, 4.958955853405491, 5.958989794009698, 6.918422239330166, 7.92440911033412, 8.903242587483463, 9.888558127353225, 10.863781541610114, 12.7117540915244, 13.733786791486601, 12.730698136432597, 11.783677611807128, 10.746779519375739, 9.751544366280756, 8.905132054162896, 7.883315271386239, 6.964960837908904, 6.034539405686973, 4.987589808241307, 4.067156636752839, 4.878016709801635, 5.83867394434567, 6.809798317862734, 7.785433966668832, 8.736596327709282, 9.792299438772275, 10.815803435114091, 11.761756782969725, 13.604835860881302, 14.662949331657865, 13.66080879706954, 12.67819030958213, 11.653161291167619, 10.678676563457822, 9.878699548671582, 8.879379857176476, 8.017896262889526, 7.070489644737048, 6.002334516974869, 5.026294295550596, 5.89084698185671, 6.870089764390294, 7.78942252307025, 8.740904083174767, 9.758618193145468, 10.699470522588863, 11.644037438923222, 12.610035643298101, 14.595721064067563, 15.570613733778217, 14.609961769112301, 13.562953797592256, 12.614658615488239, 11.620992464719997, 10.813619368817697, 9.84997948995541, 9.048189692856559, 8.093385040087682, 7.021817890222407, 6.013278150284203, 6.818821800803161, 7.748240637274907, 8.731717716923384, 9.709446440028378, 10.698711779114618, 11.711457406199923, 12.710462036440562, 13.536874084019944], [13.472450142244744, 12.653826638812694, 11.67833199008813, 10.70719232791327, 9.678957688282223, 8.723843877235364, 7.746186921939656, 6.834866119827865, 7.774523257026965, 8.79894953477257, 9.852262210953572, 10.84267956530483, 11.756401389507232, 12.695903802033524, 13.597761913685986, 14.586239533806882, 15.543625012780474, 16.495427065448776, 15.509365370554892, 14.482627774204785, 14.49135591989132, 13.688343931051099, 12.668844868392135, 11.748993728892817, 10.692280422062428, 9.703045795552619, 8.696313625559846, 7.8845140756898555, 8.830069063420055, 9.835757131960396, 10.789152820390274, 11.749194894095425, 12.114437145089452, 13.035788620193662, 13.743035001354352, 14.715867986570139, 15.729697297283568, 16.658019141947747, 16.557455366387423, 15.537136264151647, 15.48285457332832, 14.541699433505428, 13.584939841676837, 12.618774121513184, 11.619933688705853, 10.730246327393086, 9.699043724895365, 8.943806959164597, 9.84650625512616, 10.853760975657154, 11.809998513854719, 11.820494848372183, 11.09922151941392, 11.979912698545776, 12.794742421761523, 13.733375457287647, 14.676419331731598, 15.710211530828877, 16.653218556420867, 16.528303926911896, 16.490203437646926, 15.55278937262663, 14.568783762986916, 13.683328488618908, 12.679555742781057, 11.65411378385835, 10.705633006405778, 10.010875119154152, 10.862424708917453, 11.839150099751919, 11.772873588610572, 10.832129982551535, 10.139698629485911, 10.99217639932902, 11.774836465819929, 12.818866794788807, 13.74738542122894, 14.682503497035649, 15.667384368076423, 16.618304300593373, 16.545859137250474, 16.49180329460428, 15.62476540253185, 14.671320110797494, 13.661817664541397, 12.710072477022353, 11.759603077465531, 11.07474269185681, 11.854550819041826, 11.651693563571541, 10.71765786127852, 9.892760282138985, 9.151362833328237, 10.020023198993828, 10.796007219590347, 11.81826959603908, 12.779979018246816, 13.708842368024019, 14.721521586213504, 15.64808548464734, 15.53775704385445, 16.599496734333606, 16.568596879839472, 15.64320996219563, 14.604380501161774, 13.741454268118199, 12.804278814327136, 12.037049558991274, 11.530285987273341, 10.602752175643626, 9.745692968693087, 8.931830658285403, 8.124589864605076, 9.00188368374565, 9.870145604572865, 10.84938312727067, 11.763718887440898, 12.721753776903054, 13.773839558755942, 14.587413984593773, 14.657125046098411, 15.67129709505423, 16.37513726330679, 15.414025628770927, 14.436748057086234, 13.562669302808196, 12.62104774161284, 11.573951843495164, 10.606234779063549, 9.660998267721665, 8.724228882725612, 7.907945051338889, 7.058886093650517, 7.988214515270865, 8.917665681143827, 9.869363562992634, 10.80146524280584, 11.745891839503159, 12.754284133059551, 13.657983654830932, 13.703371477213235, 14.70383047662977, 15.392826186155354, 14.382948683189445, 13.411392208206838, 12.568739233414433, 11.659361784572338, 10.592569859562, 9.643315014178228, 8.719524231111007, 7.762923177751492, 6.976015645373275, 6.025725122937675, 6.9845288081563695, 7.84430721302872, 8.81530437793686, 9.744890978037498, 10.68384630238952, 11.734900517546702, 12.720897424956387, 12.73395233657636, 13.747219978359565, 14.3559334883798, 13.427895897201775, 12.480631579707806, 11.526408123939348, 10.592832892562352, 9.58852183755441, 8.623951201534904, 7.684001871210826, 6.75087998603972, 5.95365281275528, 5.061838861701931, 5.956460655490813, 6.918433407944394, 7.881645645987343, 8.809363228682908, 9.88293826701688, 10.932393445994773, 11.804659113892837, 11.795872633816135, 12.760457412095166, 13.455913087113565, 12.47478801061437, 11.516899128020494, 10.582769659645349, 9.609625728421243, 8.667490934816826, 7.624013046809613, 6.7594965281358945, 5.782288989227089, 4.964143059379648, 4.076131618345965, 5.022740158676497, 5.923701503819071, 6.919527941522936, 7.858911376824847, 8.933170005174366, 9.895496702190584, 10.823970588709809, 10.749650657025228, 11.751258194529443, 12.653190180834187, 11.583824519642956, 10.583156480728082, 9.609528611091958, 8.652471502104028, 7.660928701416465, 6.695049249532514, 5.808364190437761, 4.806899188167804, 3.9057693583741404, 3.0521110338158026, 4.042342218652313, 4.966468274528934, 5.917276821224038, 6.9015902219465595, 7.913212298073612, 8.829213702474208, 9.80726585603745, 9.876883522942492, 10.804836634888135, 11.80925018661717, 10.770630429098974, 9.723242703225239, 8.653494935544014, 7.720831801012942, 6.775386013241037, 5.744285243902511, 4.819163913650505, 3.855549629870276, 2.850800319624856, 1.9824269976661413, 2.988036753039406, 4.005806842722197, 4.954999108106845, 5.992793638427708, 6.91960746694105, 7.893860779366077, 8.921278144549577, 8.999311274774302, 9.991026193877891, 10.963075126143245, 9.891163124492454, 8.825854336334677, 7.816102780957973, 6.832793831426947, 5.805643388639087, 4.836626672595802, 3.8168160258480466, 2.848789387619761, 1.9232630574801322, 0.9361857259556234, 1.97892784922092, 2.9746613556969472, 4.018064302009676, 4.97066357659298, 5.959363959887658, 7.009083082837069, 7.9786524380846355, 7.999968811659344, 9.050758624304041, 10.071340967594216, 9.162371048852474, 8.089117876650548, 7.0744557580785745, 6.125804034478896, 5.188129638380565, 4.135955209149154, 3.1067644754007566, 2.079310349233885, 1.0358689836432682, 0.0, 1.014784920706232, 2.0387184748033818, 3.062983418862694, 4.046690925801362, 5.035378302885941, 6.075922921628675, 7.02249236216263, 8.925729214433806, 9.867254595279366, 10.838262789115598, 9.842067959876669, 8.916706463891638, 7.920660205967872, 6.9577370731038375, 5.933242113813636, 4.977952222715024, 4.009274399921599, 3.050629400850442, 2.046820941455598, 1.024093403274561, 2.038805404305367, 2.9656048519576226, 3.9888913719750825, 5.0030440826007405, 5.997643568498409, 6.941549347787534, 7.978710001561105, 9.95175036300425, 10.90147711652204, 11.832913955547946, 10.772938275089494, 9.918592225287453, 8.852686575687459, 7.892822553989247, 6.893404658422053, 6.037997038122993, 5.014430204669677, 4.040612409181596, 2.992211501464285, 1.961391255805089, 3.001220008607259, 3.9170437458976486, 4.909616893239054, 5.889241206276221, 6.84819783850974, 7.9194576682672135, 8.905906666428393, 10.849610779876715, 11.79543160897416, 12.790810323425081, 11.74560417799662, 10.832999572923274, 9.814199010314743, 8.879662129200872, 7.856751274398731, 6.971119947898914, 5.970717703278671, 4.9025894800657, 3.8804566660208466, 2.919932192678912, 3.9323530994123206, 4.9318465207047355, 5.882553255686899, 6.888540126690853, 7.867373603840195, 8.852689143709956, 9.827912557966846, 11.67588510788113, 12.726650943324943, 13.754534908857316, 12.819546595450394, 11.782648503019008, 10.787413349924025, 9.859369895978917, 8.83755311320226, 7.8325213732035275, 6.902099940981596, 5.8551503435359304, 4.892417603166988, 3.8514139558084652, 4.8120711903525, 5.783195563869565, 6.758831212675664, 7.709993573716113, 8.765696684779106, 9.779934451470822, 10.725887799326456, 12.578233106888133, 13.636346577664696, 14.659734780293835, 13.714059293225398, 12.689030274810888, 11.71454554710109, 10.832937390487603, 9.833617698992496, 8.881811725663876, 7.87424683273621, 6.802650574092268, 5.809254350916123, 4.864244227863541, 5.843487010397125, 6.7628197690770815, 7.714301329181598, 8.732015439152299, 9.672867768595694, 10.617434684930053, 11.583432889304932, 13.569118310074394, 14.58080329580957, 15.541455260475486, 14.598822781235524, 13.650527599131507, 12.656861448363266, 11.767857210633718, 10.804217331771431, 9.90823066025082, 8.862825172075613, 7.7912580222103385, 6.766512069599795, 5.792219046809992, 6.721637883281737, 7.7051149629302165, 8.68284368603521, 9.672109025121449, 10.684854652206754, 11.683859282447393, 12.510271330026775], [12.534252967212867, 11.715629463780816, 10.740134815056253, 9.793463820878562, 8.777209058000171, 7.89725238260597, 7.102261266076353, 7.849651040534097, 8.789308177733197, 9.813734455478802, 10.867047131659804, 11.857464486011061, 12.771186310213462, 13.215654141145667, 13.655378076218772, 14.643855696339669, 15.60124117531326, 15.5572298904169, 14.571168195523015, 13.544430599172907, 13.553158744859443, 12.750146756019221, 11.730647693360257, 10.835265221858108, 9.80723848717933, 8.876454300923225, 8.052387969696543, 8.899298996396087, 9.844853984126287, 10.85054205266663, 11.803937741096508, 12.763979814801658, 13.129222065795684, 12.253190550818294, 12.728250080648118, 13.701083065863905, 14.714912376577335, 15.643234221241512, 15.619258191355543, 14.598939089119769, 14.59688139789317, 13.65665749862233, 12.699897906793739, 11.733732186630085, 10.734891753822755, 9.916054029822773, 9.055118069032062, 9.958591879870829, 10.861291175832392, 11.868545896363386, 12.824783434560953, 12.835279769078417, 12.114006440120152, 11.197314629170409, 11.77995750105529, 12.718590536581413, 13.661634411025364, 14.695426610122643, 15.638433635714637, 15.636971599375036, 15.60516150276383, 14.667747437743532, 13.683741828103818, 12.79828655373581, 11.796729020225639, 10.89938317651415, 10.061707350542475, 11.025660039860384, 11.877209629623685, 12.853935020458149, 12.787658509316806, 11.846914903257769, 11.154483550192143, 10.209578329953652, 10.760051545113695, 11.804081874082573, 12.732600500522706, 13.667718576329415, 14.652599447370193, 15.603519379887139, 15.53107421654424, 15.606761359721183, 14.739723467648751, 13.788493388242076, 12.77899094198598, 11.955341869678152, 11.115677421602228, 12.056380820884103, 12.869335739748058, 12.666478484277775, 11.732442781984753, 10.907545202845219, 10.16614775403447, 9.23742512961846, 9.781222298884114, 10.803484675332847, 11.765194097540583, 12.694057447317785, 13.706736665507274, 14.633300563941107, 14.522972123148218, 15.584711813627374, 15.685723568628665, 14.760383239640213, 13.721553778606356, 13.006146396022512, 12.160353158463833, 13.018687688018566, 12.545070907979575, 11.61753709634986, 10.76047788939932, 9.946615578991636, 9.139374785311308, 8.219285614370282, 8.855360683866632, 9.834598206564436, 10.748933966734667, 11.706968856196823, 12.759054638049712, 13.572629063887542, 13.64234012539218, 14.656512174347998, 15.617694650940116, 15.761218581906514, 14.692325516257247, 13.976459838101631, 13.222563834678773, 12.588736764201396, 11.62101969976978, 10.675783188427898, 9.739013803431845, 8.922729972045122, 8.07367101435675, 7.205616445895497, 7.902880760437594, 8.854578642286402, 9.786680322099608, 10.731106918796929, 11.739499212353321, 12.6431987341247, 12.688586556507001, 13.689045555923537, 14.685297649801562, 15.397733603895677, 14.42617712891307, 13.583524154120665, 12.67414670527857, 11.607354780268231, 10.65809993488446, 9.734309151817241, 8.777708098457726, 7.990800566079507, 7.0405100436439065, 6.201930738781002, 6.829522292322488, 7.800519457230628, 8.730106057331266, 9.669061381683289, 10.72011559684047, 11.706112504250155, 11.719167415870126, 12.732435057653333, 13.695533751188051, 14.442680817908007, 13.495416500414038, 12.54119304464558, 11.607617813268584, 10.603306758260642, 9.638736122241136, 8.698786791917058, 7.765664906745954, 6.968437733461512, 6.076623782408163, 5.173862586115445, 5.903648487238162, 6.866860725281112, 7.794578307976676, 8.868153346310649, 9.91760852528854, 10.789874193186604, 10.781087713109901, 11.745672491388934, 12.662558785202757, 13.489572931320602, 12.531684048726726, 11.59755458035158, 10.624410649127475, 9.682275855523057, 8.638797967515844, 7.774281448842127, 6.797073909933322, 5.97892798008588, 5.090916539052197, 4.240142089301129, 4.908916583112839, 5.904743020816704, 6.844126456118615, 7.9183850844681345, 8.88071178148435, 9.809185668003575, 9.734865736318994, 10.736473273823211, 11.680592939906138, 12.598609440349186, 11.597941401434314, 10.62431353179819, 9.66725642281026, 8.675713622122696, 7.709834170238746, 6.8231491111439935, 5.821684108874036, 4.920554279080373, 4.0668959545220345, 3.1684847652340844, 3.9516833538227023, 4.902491900517807, 5.8868053012403285, 6.898427377367381, 7.814428781767975, 8.792480935331216, 8.86209860223626, 9.790051714181903, 10.807944588656847, 11.785415349805206, 10.73802762393147, 9.668279856250246, 8.735616721719174, 7.790170933947269, 6.759070164608743, 5.833948834356737, 4.8703345505765085, 3.865585240331088, 2.9972119183723733, 2.114179299621178, 2.991021922015965, 3.9402141874006134, 4.978008717721475, 5.904822546234818, 6.879075858659844, 7.906493223843345, 7.984526354068069, 8.97624127317166, 10.029626267648393, 10.905948045198684, 9.840639257040909, 8.830887701664205, 7.847578752133179, 6.820428309345319, 5.851411593302034, 4.831600946554278, 3.8635743083259935, 2.9380479781863644, 1.9509706466618555, 1.0484659539999557, 1.9598764349907152, 3.0032793813034435, 3.9558786558867474, 4.944579039181426, 5.994298162130837, 6.963867517378404, 6.985183890953112, 8.03597370359781, 9.056556046887984, 10.024675546646836, 9.103902797356781, 8.089240678784808, 7.1405889551851285, 6.202914559086798, 5.150740129855387, 4.121549396106989, 3.094095269940117, 2.0506539043495002, 1.014784920706232, 0.0, 1.0239335540971497, 2.048198498156462, 3.03190600509513, 4.020593382179709, 5.061138000922443, 6.0077074414563985, 7.9109442937275745, 8.852469674573134, 9.898930955592403, 10.856852880582903, 9.931491384597871, 8.935445126674106, 7.972521993810071, 6.9480270345198685, 5.992737143421257, 5.024059320627832, 4.065414321556674, 3.0616058621618296, 2.038878323980793, 1.0240204835991351, 1.9508199312513905, 2.9741064512688506, 3.9882591618945087, 4.9828586477921775, 5.926764427081302, 6.963925080854874, 8.936965442298018, 9.886692195815808, 10.893582122024752, 11.787723195795728, 10.933377145993687, 9.867471496393692, 8.90760747469548, 7.908189579128286, 7.052781958829225, 6.029215125375909, 5.0553973298878265, 4.006996422170516, 2.976176176511321, 2.098900730537106, 2.9022588251914163, 3.8948319725328213, 4.874456285569989, 5.833412917803508, 6.904672747560982, 7.891121745722161, 9.834825859170483, 10.780646688267929, 11.828272805621932, 12.760389098702854, 11.847784493629508, 10.828983931020977, 9.894447049907106, 8.871536195104964, 7.985904868605146, 6.985502623984903, 5.917374400771932, 4.895241586727078, 3.934717113385144, 3.042918861243476, 3.917061599998503, 4.867768334980666, 5.873755205984621, 6.8525886831339635, 7.837904223003724, 8.813127637260614, 10.661100187174899, 11.711866022618711, 12.739749988151084, 13.686770512776553, 12.797433423725241, 11.802198270630258, 10.874154816685147, 9.85233803390849, 8.847306293909758, 7.916884861687828, 6.869935264242162, 5.90720252387322, 4.866198876514697, 4.0510691009851, 4.956604069240172, 5.820634037643785, 6.771796398684234, 7.827499509747227, 8.76514953076459, 9.711102878620224, 11.640035931856255, 12.69084827453503, 13.71423647716417, 14.690791436846673, 13.703815195517121, 12.729330467807324, 11.847722311193833, 10.848402619698726, 9.89659664637011, 8.889031753442442, 7.8174354947985, 6.824039271622355, 5.8790291485697725, 5.102295573293454, 5.936228274447688, 6.77610415414972, 7.793818264120421, 8.734670593563816, 9.679237509898176, 10.645235714273054, 12.630921135042517, 13.642606120777693, 14.603258085443608, 15.613607701941758, 14.665312519837741, 13.6716463690695, 12.782642131339948, 11.819002252477661, 10.923015580957053, 9.877610092781845, 8.806042942916571, 7.781296990306027, 6.8070039675162235, 6.077712227418434, 6.878523468300823, 7.74464651100333, 8.73391185008957, 9.746657477174876, 10.745662107415516, 11.572074154994898], [11.547599132806612, 10.728975629374562, 9.753480980649998, 8.80680998647231, 7.790555223593918, 6.910598548199717, 7.917110640445198, 8.769649165221795, 9.709306302420895, 10.7337325801665, 11.787045256347502, 12.777462610698759, 13.69118443490116, 13.61948638032691, 12.631444522121624, 13.61992214224252, 14.577307621216113, 14.570576056010646, 13.58451436111676, 12.557776764766652, 12.566504910453189, 11.763492921612967, 10.743993858954003, 9.848611387451855, 8.820584652773077, 7.889800466516972, 8.867237344065387, 9.819297121083785, 10.764852108813985, 11.770540177354327, 12.723935865784206, 13.683977939489356, 13.673449962416807, 12.657022789999537, 11.70431652655097, 12.677149511766757, 13.690978822480186, 14.619300667144364, 14.632604356949289, 13.612285254713514, 13.610227563486916, 12.670003664216075, 11.713244072387486, 10.747078352223832, 9.748237919416502, 8.92940019541652, 9.869967443400906, 10.878590004558527, 11.78128930052009, 12.788544021051084, 13.74478155924865, 13.507358793507903, 12.671848633176717, 11.730322720219903, 10.756023946958141, 11.694656982484265, 12.637700856928216, 13.671493056025495, 14.614500081617486, 14.650317764968781, 14.618507668357575, 13.681093603337278, 12.697087993697565, 11.811632719329557, 10.810075185819386, 9.912729342107896, 10.861210119560468, 11.85231865396269, 12.797207754311383, 13.773933145145847, 13.572561325430618, 12.518993927687255, 11.712325743248709, 10.749777302892959, 9.736117991016547, 10.780148319985425, 11.708666946425557, 12.643785022232267, 13.628665893273041, 14.579585825789989, 14.50714066244709, 14.620107525314928, 13.7530696332425, 12.801839553835823, 11.792337107579726, 10.9686880352719, 11.915180190620221, 12.855883589902096, 13.789333864435756, 13.466985567486732, 12.517345598098565, 11.579624227274705, 10.7649694167529, 9.777624102557766, 8.757288744786965, 9.779551121235698, 10.741260543443435, 11.670123893220637, 12.682803111410122, 13.609367009843957, 13.499038569051068, 14.560778259530224, 14.699069734222414, 13.77372940523396, 12.734899944200103, 12.019492561616259, 12.956668015407322, 13.81819045703656, 13.41906140879832, 12.491527597168606, 11.545380705513132, 10.618694603421122, 9.738196448029738, 8.809237499694614, 7.831427129769483, 8.810664652467288, 9.725000412637517, 10.683035302099672, 11.73512108395256, 12.548695509790392, 12.61840657129503, 13.632578620250849, 14.593761096842966, 14.77456474750026, 13.705671681850994, 12.989806003695378, 13.931427564890734, 13.474374709663133, 12.506657645231517, 11.561421133889635, 10.523916619545657, 9.594808996474608, 8.742135955069251, 7.837443977842986, 6.878947206340444, 7.830645088189252, 8.762746768002458, 9.707173364699777, 10.71556565825617, 11.61926518002755, 11.664653002409853, 12.665112001826389, 13.661364095704414, 14.653278892392711, 14.73102753073039, 14.015956830632375, 13.560370620045438, 12.492992725729968, 11.543737880346196, 10.619947097278978, 9.663346043919463, 8.662879590508993, 7.708974984356409, 6.83375827072849, 5.805588738225338, 6.776585903133478, 7.706172503234116, 8.645127827586139, 9.69618204274332, 10.682178950153006, 10.695233861772978, 11.708501503556185, 12.671600197090903, 13.599637788268929, 14.457028522832548, 13.452483990337733, 12.516202893107094, 11.488944703722378, 10.524374067702873, 9.584424737378795, 8.65130285220769, 7.683735558653396, 6.7450887231206655, 5.805690118062932, 4.879714933141012, 5.842927171183962, 6.770644753879526, 7.844219792213498, 8.893674971191391, 9.765940639089456, 9.757154159012753, 10.721738937291786, 11.638625231105609, 12.619750307604804, 13.555617602823878, 12.549330942559083, 11.576187011334977, 10.63405221773056, 9.590574329723346, 8.659919394303863, 7.682711855395058, 6.757538396658015, 5.818578161579148, 4.871969621248616, 3.8849830290156895, 4.880809466719554, 5.820192902021465, 6.894451530370985, 7.856778227387202, 8.785252113906427, 8.710932182221846, 9.712539719726063, 10.65665938580899, 11.72602504700022, 12.621874955531466, 11.648247085895342, 10.69118997690741, 9.699647176219846, 8.733767724335896, 7.847082665241143, 6.845617662971186, 5.944487833177523, 5.065144880894758, 3.9934613621673587, 2.9277497997255524, 3.8785583464206574, 4.862871747143179, 5.874493823270231, 6.790495227670826, 7.768547381234067, 7.838165048139111, 8.766118160084755, 9.784011034559699, 10.822630792077895, 11.761961178028622, 10.692213410347398, 9.759550275816325, 8.81410448804442, 7.783003718705894, 6.857882388453888, 5.8942681046736585, 4.889518794428239, 4.007641982671853, 3.0020322272985878, 1.967088367918815, 2.9162806333034634, 3.9540751636243257, 4.880888992137669, 5.855142304562695, 6.882559669746196, 6.960592799970919, 7.9523077190745095, 9.005692713551243, 9.989951806207769, 10.864572811138059, 9.854821255761355, 8.87151230623033, 7.84436186344247, 6.875345147399185, 5.855534500651429, 4.887507862423144, 3.9619815322835144, 2.9749042007590054, 2.0063738946518197, 0.9359428808935655, 1.9793458272062938, 2.931945101789598, 3.9206454850842762, 4.970364608033687, 5.939933963281254, 5.961250336855962, 7.01204014950066, 8.032622492790834, 9.000741992549687, 10.073995164751613, 9.113174232881958, 8.164522509282278, 7.226848113183948, 6.174673683952537, 5.145482950204139, 4.118028824037267, 3.0745874584466497, 2.0387184748033818, 1.0239335540971497, 0.0, 1.0242649440593123, 2.0079724509979804, 2.9966598280825596, 4.037204446825294, 4.9837738873592485, 6.8870107396304245, 7.8285361204759845, 8.874997401495254, 9.871192230734183, 10.796553726719214, 9.903241384172626, 8.940318251308591, 7.9158232920183895, 6.960533400919778, 5.991855578126353, 5.033210579055195, 3.9816039868495277, 2.958876448668491, 1.8909655444973927, 0.9641660968451373, 1.9501728971717012, 2.9643256077973597, 3.9589250936950275, 4.902830872984152, 5.939991526757724, 7.946255371973607, 8.862758641718658, 9.869648567927602, 10.802062545947008, 11.815144834376076, 10.835267753892213, 9.875403732194, 8.875985836626807, 8.020578216327745, 6.9970113828744305, 5.975395454575525, 4.926994546858214, 3.896174301199019, 2.9137501049059504, 1.9156049907851633, 2.9081781381265683, 3.887802451163736, 4.846759083397255, 5.918018913154729, 6.904467911315908, 8.84817202476423, 9.793992853861676, 10.827544935804736, 11.774728448854134, 12.70659044076716, 11.796780188519497, 10.862243307405626, 9.839332452603484, 8.905902993292845, 7.905500748672601, 6.83737252545963, 5.815239711414776, 4.854715238072842, 3.857768235612321, 2.93040776559225, 3.881114500574413, 4.8871013715783675, 5.8659348487277105, 6.851250388597471, 7.826473802854361, 9.674446352768644, 10.725212188212458, 11.753096153744831, 12.7001166783703, 13.687949624616321, 12.738441139703214, 11.794152941372845, 10.772336158596188, 9.767304418597456, 8.836882986375526, 7.78993338892986, 6.827200648560918, 5.786197001202395, 4.865918475353945, 3.9699502348339193, 4.833980203237532, 5.785142564277981, 6.840845675340974, 7.778495696358337, 8.72444904421397, 10.65338209745, 11.704194440128777, 12.727582642757916, 13.70413760244042, 14.640058064590077, 13.66557333688028, 12.76772043588153, 11.768400744386424, 10.816594771057808, 9.80902987813014, 8.737433619486197, 7.744037396310053, 6.799027273257471, 5.917144947662299, 4.949574440041435, 5.789450319743467, 6.807164429714168, 7.748016759157562, 8.692583675491921, 9.6585818798668, 11.644267300636262, 12.655952286371438, 13.616604251037353, 14.663612222557399, 14.62973657813244, 13.572344987444344, 13.702640256027646, 12.73900037716536, 11.84301370564475, 10.797608217469543, 9.72604106760427, 8.701295114993725, 7.7270020922039215, 6.892561601787279, 5.89186963389457, 6.757992676597077, 7.747258015683316, 8.760003642768622, 9.759008273009261, 10.585420320588643], [10.586194925491217, 9.774041649699322, 8.79854700097476, 7.85187600679707, 6.83562124391868, 7.790735054965539, 8.818078868583516, 9.769915644448892, 10.709572781647992, 11.733999059393597, 12.7873117355746, 13.777729089925856, 14.709779090898028, 14.643751324386221, 13.655709466180936, 13.259070277311459, 13.911641179770815, 13.60917184869525, 12.623110153801363, 11.596372557451257, 11.605100703137794, 10.808558941937727, 9.789059879278764, 8.893677407776616, 7.865650673097838, 8.769936973282794, 9.768205572203705, 10.760201385997352, 11.765118588041082, 12.770806656581424, 13.724202345011303, 14.684244418716453, 14.697714906476119, 13.681287734058849, 12.728581470610282, 12.253189472762822, 12.98619350228151, 13.914515346945688, 13.671200149633892, 12.65088104739812, 12.648823356171519, 11.715069684540836, 10.758310092712247, 9.792144372548593, 8.793303939741262, 9.806117584084678, 10.770935671539224, 11.792824180966168, 12.781555779747187, 13.788810500278181, 14.745048038475748, 14.531623737567214, 13.696113577236028, 12.754587664279214, 11.780288891017452, 11.27069694348033, 11.913259235761727, 12.947051434859006, 13.854388759593078, 13.688913557653386, 13.663573688682336, 12.726159623662038, 11.742154014022326, 10.856698739654318, 9.855141206144147, 10.789446730776055, 11.737927508228626, 12.729036042630849, 13.71458639278913, 14.691311783623593, 14.59682626948993, 13.543258871746566, 12.73659068730802, 11.77404224695227, 10.760382935075858, 10.25962067489395, 10.984225325259068, 11.919343401065777, 12.868554571248634, 13.65907876321274, 13.586633599869842, 13.66517354563969, 12.798135653567261, 11.846905574160584, 10.837403127904487, 11.845405423940058, 12.79189757928838, 13.732600978570254, 14.706712502913502, 14.491250511546044, 13.541610542157876, 12.603889171334016, 11.78923436081221, 10.801889046617077, 9.781553688846277, 9.198475812788162, 9.985129463505253, 10.913992813282455, 11.922691789385715, 12.688859947266709, 12.57853150647382, 13.640271196952975, 13.744135754547175, 12.81879542555872, 11.779965964524864, 12.80754575170015, 13.744721205491214, 14.694907845704718, 14.443326352857632, 13.515792541227917, 12.569645649572443, 11.642959547480434, 10.76246139208905, 9.833502443753925, 8.855692073828795, 8.229589344019752, 8.964889090613108, 9.922923980075264, 10.975009761928153, 11.628188447213143, 11.69789950871778, 12.67568732074801, 13.636869797340127, 13.819630767825021, 12.750737702175755, 13.77785919377927, 14.719480754974626, 14.498639653722444, 13.530922589290828, 12.585686077948946, 11.548181563604969, 10.61907394053392, 9.766400899128563, 8.861708921902297, 7.9032121503997566, 7.162375537300985, 8.002635445978049, 8.94706204267537, 9.955454336231762, 10.698758117450302, 10.692945647411072, 11.693404646827608, 12.689656740705633, 13.68157153739393, 13.776093551055151, 14.804010020716266, 14.58463556410475, 13.517257669789279, 12.568002824405507, 11.644212041338289, 10.687610987978774, 9.687144534568304, 8.73323992841572, 7.858023214787801, 6.82985368228465, 6.108316352245211, 6.946061181209707, 7.88501650556173, 8.9103824498376, 9.761671887575757, 9.723526506774197, 10.736794148557404, 11.699892842092122, 12.627930433270148, 13.56966428688721, 14.476748934397044, 13.540467837166405, 12.51320964778169, 11.548639011762184, 10.608689681438106, 9.675567796267002, 8.708000502712707, 7.769353667179978, 6.829955062122244, 5.9039798772003245, 5.079894930259971, 5.887911506652057, 6.953762701116539, 7.921967616192611, 8.794233284090675, 8.785446804013972, 9.750031582293005, 10.666917876106828, 11.648042952606023, 12.605931835199899, 13.573595886618394, 12.600451955394288, 11.65831716178987, 10.614839273782657, 9.684184338363176, 8.70697679945437, 7.781803340717327, 6.84284310563846, 5.896234565307928, 4.909247973075002, 4.117777225795563, 4.885216161591956, 5.959474789941475, 6.885070872388422, 7.813544758907646, 7.739224827223066, 8.740832364727282, 9.684952030810209, 10.75431769200144, 11.754985730916314, 12.672512029954653, 11.715454920966721, 10.723912120279158, 9.758032668395208, 8.871347609300456, 7.8698826070304975, 6.968752777236834, 6.089409824954069, 5.01772630622667, 3.9520147437848645, 3.0550675806543963, 3.9211665683639425, 4.932788644490995, 5.818787872672046, 6.796840026235287, 6.866457693140331, 7.794410805085974, 8.812303679560918, 9.850923437079114, 10.898311162952849, 11.716478354406709, 10.783815219875637, 9.83836943210373, 8.807268662765205, 7.882147332513199, 6.91853304873297, 5.91378373848755, 5.031906926731165, 4.0262971713579, 2.991353311978127, 2.0787193007522395, 2.9823678086255456, 3.9091816371388886, 4.883434949563915, 5.910852314747416, 5.936327855911607, 6.928042775015197, 7.981427769491932, 8.965686862148456, 10.002549782782655, 10.879086199820666, 9.89577725028964, 8.86862680750178, 7.899610091458496, 6.8797994447107405, 5.911772806482455, 4.986246476342826, 3.9991691448183175, 3.0306388387111323, 1.9602078249528778, 1.007638472207514, 1.9602377467908179, 2.948938130085496, 3.9916192791747642, 4.961188634422331, 4.93698539279665, 5.987775205441348, 7.008357548731522, 7.976477048490374, 9.049730220692302, 10.064392339264275, 9.18878745334159, 8.25111305724326, 7.198938628011848, 6.16974789426345, 5.142293768096579, 4.098852402505962, 3.062983418862694, 2.048198498156462, 1.0242649440593123, 0.0, 0.9837075069386679, 1.9723948840232473, 3.0129395027659815, 3.9595089432999364, 5.8627457955711115, 6.8042711764166715, 7.8507324574359405, 8.84692728667487, 9.772288782659903, 10.768335040583668, 9.962726884247571, 8.93823192495737, 7.982942033858758, 7.014264211065333, 6.055619211994175, 5.004012619788508, 3.981285081607471, 2.9133741774363733, 1.9865747297841176, 0.9259079531123888, 1.940060663738047, 2.9346601496357154, 3.8785659289248398, 4.915726582698411, 6.921990427914294, 7.838493697659345, 8.845383623868289, 9.777797601887695, 10.790879890316763, 11.700361410303255, 10.89781236513298, 9.898394469565787, 9.042986849266725, 8.01942001581341, 6.997804087514506, 5.949403179797196, 4.918582934138, 3.9361587378449308, 2.9380136237241437, 1.9532441584513303, 2.932868471488498, 3.891825103722017, 4.897665602788961, 5.884114600950141, 7.865667729373813, 8.81148855847126, 9.803279991745423, 10.750463504794821, 11.682325496707847, 12.701126059316378, 11.884651940344606, 10.861741085542464, 9.928311626231826, 8.927909381611583, 7.859781158398611, 6.837648344353757, 5.877123871011823, 4.880176868551301, 3.8884988520365886, 2.926180520899175, 3.9321673919031297, 4.911000869052473, 5.868746093207054, 6.843969507463944, 8.691942057378228, 9.742707892822041, 10.770591858354415, 11.717612382979883, 12.663684680557008, 13.658919833651991, 12.812747597369713, 11.790930814593056, 10.785899074594324, 9.855477642372394, 8.808528044926728, 7.845795304557786, 6.786463480429491, 5.825806245885456, 4.854681872368392, 3.879046223562294, 4.830208584602743, 5.885911695665736, 6.79599140096792, 7.7419447488235535, 9.691977890134606, 10.72169014473836, 11.7450783473675, 12.721633307050004, 13.727277262597887, 14.586052030829057, 13.786315091878398, 12.786995400383292, 11.816861250284905, 10.809296357357237, 9.737700098713294, 8.744303875537149, 7.799293752484567, 6.840135525610729, 5.834306077575908, 4.8345163400682285, 5.852230450038929, 6.793082779482324, 7.737649695816683, 8.697177672551405, 10.682863093320867, 11.694548079056043, 12.655200043721958, 13.702208015242004, 14.26888471320138, 14.596609931503655, 14.721234912024514, 13.757595033162227, 12.843280184871848, 11.79787469669664, 10.726307546831366, 9.701561594220822, 8.727268571431019, 7.815552179735709, 6.776601271429043, 5.8030586969218385, 6.792324036008077, 7.805069663093383, 8.804074293334022, 9.624016113273248], [9.60248741855255, 8.867947531453966, 7.940805105296044, 7.128659521482522, 7.819328750857348, 8.774442561904207, 9.801786375522184, 10.75362315138756, 11.69328028858666, 12.717706566332264, 13.771019242513267, 14.761436596864524, 15.693486597836698, 15.608184177669928, 14.620142319464643, 13.945509505464234, 13.005659382437447, 12.625464341756585, 11.639402646862699, 10.612665050512591, 10.621393196199127, 9.92325187744399, 8.931317983600048, 8.170460922462068, 8.849358180036507, 9.753644480221462, 10.751913079142373, 11.74390889293602, 12.74882609497975, 13.754514163520092, 14.707909851949971, 15.667951925655121, 15.662147759759826, 14.645720587342556, 13.693014323893989, 12.939628700915597, 12.080211704948143, 13.00853354961232, 12.687492642695227, 11.667173540459453, 11.665115849232855, 10.867452036759303, 9.910692444930712, 9.16024800080656, 9.777011446679932, 10.789825091023346, 11.754643178477892, 12.776531687904836, 13.765263286685855, 14.77251800721685, 15.728755545414415, 15.515331244505882, 14.660546430519735, 13.719020517562921, 12.74472174430116, 11.957136171633104, 11.007277438428359, 12.041069637525638, 12.94840696225971, 12.70520605071472, 12.68346389423014, 11.878541975880506, 10.894536366240791, 10.224802367912284, 10.838848713082816, 11.773154237714722, 12.721635015167294, 13.712743549569517, 14.698293899727798, 15.675019290562261, 15.580533776428597, 14.526966378685234, 13.701023540591727, 12.738475100235977, 11.724815788359566, 11.006762154365832, 10.0782435279257, 11.01336160373241, 11.962572773915266, 12.753096965879374, 12.680651802536476, 12.817555897858156, 11.950518005785725, 11.289320803609858, 11.821110634843157, 12.829112930878726, 13.775605086227047, 14.716308485508922, 15.69042000985217, 15.474958018484712, 14.525318049096544, 13.587596678272684, 12.753667214095918, 11.766321899900785, 10.745986542129984, 9.955126762933142, 9.079147666171886, 10.008011015949089, 11.016709992052347, 11.782878149933342, 11.672549709140453, 12.734289399619609, 12.896518106765638, 12.344367541600928, 12.763673471463534, 13.791253258638822, 14.728428712429885, 15.678615352643385, 15.4270338597963, 14.499500048166585, 13.553353156511111, 12.626667054419102, 11.726894245372756, 10.797935297037633, 9.820124927112502, 8.986240294164732, 8.058907293279741, 9.016942182741897, 10.069027964594785, 10.722206649879777, 10.791917711384414, 11.769705523414643, 12.730888000006761, 13.371785202616422, 13.734445209114424, 14.76156670071794, 15.703188261913297, 15.482347160661112, 14.514630096229496, 13.569393584887614, 12.531889070543636, 11.602781447472587, 10.75010840606723, 9.845416428840966, 8.867645003683464, 7.963216111065924, 7.096653648644683, 8.041080245342002, 9.049472538898394, 9.792776320116936, 9.786963850077706, 10.787422849494241, 11.783674943372267, 12.751079669123706, 13.569933047116018, 14.619928076731886, 15.568343071043417, 14.500965176727947, 13.551710331344175, 12.627919548276957, 11.671318494917442, 10.670852041506972, 9.716947435354388, 8.84173072172647, 7.794286535568357, 6.90915692601015, 6.040079383876341, 6.9790347082283635, 8.004400652504234, 8.85569009024239, 8.817544709440831, 9.806302280287182, 10.769400973821899, 11.697438564999924, 12.639172418616987, 13.629958318737899, 14.524175344105073, 13.496917154720357, 12.532346518700852, 11.592397188376774, 10.65927530320567, 9.691708009651375, 8.753061174118645, 7.813662569060913, 6.868412730484032, 5.8807355040249085, 4.981929709318691, 6.047780903783172, 7.015985818859245, 7.888251486757309, 7.879465006680606, 8.819539714022783, 9.736426007836604, 10.717551084335799, 11.675439966929675, 12.6863198544439, 13.584159462332956, 12.642024668728538, 11.598546780721325, 10.667891845301844, 9.690684306393038, 8.765510847655996, 7.826550612577129, 6.879942072246597, 5.89295548001367, 4.918617799560501, 3.979234364258589, 5.053492992608108, 5.979089075055056, 6.90756296157428, 6.8332430298897, 7.8103404964570595, 8.754460162539985, 9.823825823731216, 10.82449386264609, 11.798121732282214, 12.699162427905389, 11.707619627217825, 10.741740175333875, 9.855055116239123, 8.853590113969165, 7.952460284175502, 7.073117331892738, 6.001433813165339, 4.935722250723533, 3.999498171753097, 3.015184771030576, 4.026806847157628, 4.91280607533868, 5.890858228901921, 5.935965824870108, 6.86391893681575, 7.881811811290693, 8.92043156880889, 9.967819294682625, 11.03756706236385, 11.767522726814304, 10.822076939042399, 9.790976169703873, 8.865854839451867, 7.9022405556716375, 6.897491245426218, 6.015614433669833, 5.010004678296568, 3.9750608189167953, 3.0624268076909074, 2.076386011292179, 3.003199839805522, 3.9774531522305487, 4.980360446477192, 4.952620348972939, 5.94433526807653, 6.997720262553264, 7.981979355209789, 9.018842275843987, 10.026726704468425, 10.879484757228308, 9.852334314440448, 8.883317598397163, 7.863506951649408, 6.895480313421123, 5.969953983281494, 4.982876651756985, 4.0143463456498, 2.943915331891546, 1.9913459791461818, 1.0542559494574515, 2.039584179336781, 3.0079117722360964, 3.977481127483663, 3.953277885857982, 5.00406769850268, 6.024650041792854, 6.992769541551707, 8.066022713753634, 9.080684832325607, 10.029336555925287, 9.234820564181927, 8.182646134950515, 7.153455401202118, 6.126001275035247, 5.08255990944463, 4.046690925801362, 3.03190600509513, 2.0079724509979804, 0.9837075069386679, 0.0, 0.9886873770845793, 2.0292319958273137, 2.9758014363612686, 4.879038288632444, 5.820563669478004, 6.867024950497273, 7.863219779736202, 8.788581275721235, 9.784627533645, 10.747550666509035, 9.921939431896037, 8.966649540797425, 7.997971718004001, 7.039326718932843, 5.987720126727176, 4.964992588546139, 3.897081684375041, 2.9702822367227855, 1.9096154600510569, 1.016763236469365, 1.9509526426970476, 2.894858421986172, 3.932019075759743, 5.9382829209756265, 6.854786190720677, 7.861676116929621, 8.794090094949027, 9.807172383378095, 10.716653903364588, 11.721614586575942, 10.882101976504455, 10.026694356205393, 9.003127522752077, 7.981511594453172, 6.933110686735862, 5.902290441076667, 4.919866244783599, 3.9217211306628115, 2.9369516653899983, 2.0179858609741705, 2.9769424932076896, 3.913958095850293, 4.900407094011473, 6.881960222435145, 7.827781051532591, 8.819572484806756, 9.766755997856153, 10.698617989769179, 11.71741855237771, 12.651955433491581, 11.845448592481132, 10.912019133170492, 9.911616888550249, 8.843488665337278, 7.821355851292424, 6.86083137795049, 5.8638843754899685, 4.872206358975257, 3.909888027837843, 3.017284781388802, 3.9961182585381456, 4.8850385862683865, 5.860262000525276, 7.708234550439561, 8.759000385883374, 9.786884351415747, 10.733904876041215, 11.67997717361834, 12.675212326713323, 13.619500525043692, 12.774638321531725, 11.769606581532994, 10.839185149311064, 9.792235551865398, 8.829502811496456, 7.770170987368161, 6.809513752824126, 5.838389379307061, 4.8627537305009625, 3.972466688924026, 5.021252797865055, 5.812283894029252, 6.758237241884886, 8.708270383195938, 9.737982637799693, 10.761370840428832, 11.737925800111336, 12.74356975565922, 13.60234452389039, 14.593068019552378, 13.770702907321962, 12.800568757223573, 11.793003864295905, 10.721407605651962, 9.728011382475817, 8.783001259423235, 7.823843032549398, 6.818013584514577, 5.818223847006897, 4.994488554360212, 5.935340883803607, 6.831555577571326, 7.713470165612738, 9.6991555863822, 10.710840572117377, 11.671492536783292, 12.718500508303338, 13.666795690407355, 14.544660425152564, 15.527987839698493, 14.741302540100897, 13.826987691810515, 12.781582203635308, 11.710015053770034, 10.68526910115949, 9.710976078369686, 8.799259686674379, 7.760308778367712, 6.786766203860507, 6.069107550693529, 6.9473277674146665, 7.897980175088666, 8.640308606334582], [8.613800041467972, 7.879260154369388, 7.129286471747795, 8.079262586141995, 8.808016127941926, 9.763129938988785, 10.790473752606761, 11.742310528472137, 12.681967665671237, 13.706393943416842, 14.759706619597845, 15.750123973949101, 16.47573948694953, 15.46734705401372, 14.496873513390705, 13.618535040873873, 12.661149561900281, 11.636776964672006, 10.650715269778118, 9.623977673428012, 9.632705819114548, 8.93456450035941, 8.1197993500518, 9.068336571255491, 9.838045557121085, 10.74233185730604, 11.74060045622695, 12.732596270020597, 13.737513472064327, 14.74320154060467, 15.696597229034548, 16.6566393027397, 16.569075114463292, 15.552647942046022, 14.599941678597455, 13.846556055619063, 12.987139059651609, 12.31260774421874, 11.698805265610646, 10.678486163374874, 10.676428472148274, 9.968415953597301, 9.099173811382464, 10.058123649599983, 10.76569882376451, 11.778512468107923, 12.74333055556247, 13.765219064989413, 14.753950663770432, 15.761205384301427, 16.717442922498993, 16.436843066934017, 15.567473785223202, 14.625947872266387, 13.651649099004626, 12.86406352633657, 11.914204793131825, 11.299205899193472, 11.982000428345685, 11.71651867363014, 11.69477651714556, 10.979505892718503, 10.083017732692543, 11.011626752197193, 11.827536090167394, 12.7618416147993, 13.710322392251872, 14.701430926654094, 15.686981276812375, 16.66370666764684, 16.502045598856732, 15.448478201113371, 14.607950895295193, 13.645402454939443, 12.631743143063032, 11.913689509069298, 10.985170882629166, 10.271497865400244, 10.99616624000124, 11.78120061892202, 11.708755455579121, 11.918519814696154, 11.138999372237478, 12.076145187894767, 12.809798011927734, 13.817800307963303, 14.764292463311625, 15.7049958625935, 16.67910738693675, 16.396469840912847, 15.446829871524681, 14.50910850070082, 13.660594568799384, 12.67324925460425, 11.65291389683345, 10.862054117636609, 9.986075020875353, 9.221846239277921, 10.050303458138321, 10.810981802975988, 10.700653362183099, 11.762393052662254, 12.084999473217392, 13.010386390861232, 13.752360848548111, 14.779940635723399, 15.717116089514462, 16.66730272972796, 16.348545682224437, 15.421011870594722, 14.474864978939248, 13.548178876847238, 12.633821600076223, 11.704862651741099, 10.727052281815968, 9.893167648868198, 8.965834647983208, 8.223421252870308, 9.10262143068076, 9.750310302922422, 9.82002136442706, 10.797809176457289, 11.758991653049407, 12.765986130956982, 13.606601518910834, 14.657391526584302, 15.586836643200652, 16.403858983089247, 15.436141918657633, 14.49090540731575, 13.453400892971773, 12.524293269900724, 11.671620228495367, 10.75514531915016, 9.77457235838693, 8.87014346576939, 8.003581003348149, 7.247559315470412, 8.083066004984367, 8.820879973159581, 8.815067503120352, 9.815526502536887, 10.811778596414912, 11.762392292039127, 12.581245670031437, 13.631240699647305, 14.610545196309772, 15.422476999156084, 14.473222153772312, 13.549431370705094, 12.592830317345578, 11.592363863935109, 10.638459257782525, 9.751459612035664, 8.701213890271823, 7.816084280713616, 6.947006738579808, 6.185513778356773, 7.0325043055468806, 7.883793743285037, 7.845648362483478, 8.817614903202603, 9.78071359673732, 10.708751187915345, 11.650485041532406, 12.641270941653318, 13.577552038883956, 14.418428977148494, 13.453858341128988, 12.51390901080491, 11.580787125633806, 10.613219832079512, 9.674572996546782, 8.73517439148905, 7.775340085187499, 6.787662858728376, 5.888857064022158, 5.11414846735774, 6.044089471901891, 6.916355139799955, 6.907568659723252, 7.830852336938203, 8.747738630752025, 9.728863707251218, 10.686752589845094, 11.697632477359319, 12.670776408583425, 13.563536491156675, 12.520058603149462, 11.58940366772998, 10.612196128821175, 9.687022670084133, 8.748062435005265, 7.801453894674734, 6.814467302441807, 5.825545154263968, 4.8861617189620565, 4.119860556182676, 5.007192728097702, 5.935666614616927, 5.861346682932346, 6.82165311937248, 7.765772785455406, 8.835138446646637, 9.835806485561509, 10.809434355197633, 11.87789438691335, 12.696307004302403, 11.730427552418453, 10.843742493323703, 9.842277491053744, 8.940844924486427, 7.994629154320875, 6.922945635593476, 5.85723407315167, 4.906425526456565, 3.9221121257340434, 3.0891509343991137, 3.9409097283813264, 4.9189618819445675, 4.9472784477855285, 5.875231559731171, 6.893124434206114, 7.931744191724311, 8.979131917598046, 10.048879685279271, 10.952834682982104, 11.810764316126976, 10.77966354678845, 9.854542216536444, 8.890927932756217, 7.886178622510797, 7.004301810754412, 5.998692055381147, 4.963748196001374, 4.02466782401707, 2.9833133659956466, 2.0564995374823036, 3.005556805273195, 3.991673069392613, 3.96393297188836, 4.95564789099195, 6.0090328854686845, 6.993291978125209, 8.030154898759408, 9.038039327383846, 10.005572716159685, 10.841021691525027, 9.872004975481742, 8.852194328733987, 7.884167690505702, 6.958641360366073, 5.971564028841565, 5.003033722734379, 3.932602708976125, 2.980033356230761, 2.03959718554688, 1.0508968022522016, 2.019224395151517, 2.9887937503990836, 2.964590508773403, 4.0153803214181005, 5.035962664708275, 6.004082164467127, 7.077335336669055, 8.091997455241028, 9.040649178840708, 9.978323574939038, 9.171333512035094, 8.142142778286697, 7.114688652119826, 6.071247286529209, 5.035378302885941, 4.020593382179709, 2.9966598280825596, 1.9723948840232473, 0.9886873770845793, 0.0, 1.0405446187427343, 1.9871140592766892, 3.8903509115478645, 4.831876292393424, 5.8783375734126935, 6.874532402651623, 7.799893898636655, 8.795940156560421, 9.758863289424456, 10.783358248714658, 9.955336917882004, 8.98665909508858, 8.028014096017422, 6.976407503811755, 5.953679965630718, 4.88576906145962, 3.9589696138073647, 2.898302837135636, 1.9768059920591243, 0.9622652656124682, 1.9061710449015925, 2.9433316986751636, 4.949595543891047, 5.866098813636098, 6.8729887398450416, 7.805402717864448, 8.818485006293516, 9.727966526280008, 10.732927209491365, 11.732345105058558, 11.015381733289972, 9.991814899836656, 8.970198971537751, 7.921798063820441, 6.890977818161246, 5.908553621868178, 4.910408507747391, 3.9256390424745775, 2.9685889256336435, 2.0096322934001245, 2.925270718765714, 3.9117197169268936, 5.893272845350565, 6.83909367444801, 7.8308851077221755, 8.778068620771574, 9.7099306126846, 10.728731175293131, 11.663268056407002, 12.686178911209144, 11.900706510255072, 10.900304265634828, 9.832176042421857, 8.810043228377003, 7.849518755035069, 6.852571752574548, 5.860893736059835, 4.898575404922422, 3.967887846048275, 3.02880805873058, 3.896351209183807, 4.871574623440696, 6.719547173354981, 7.770313008798793, 8.798196974331166, 9.745217498956634, 10.691289796533761, 11.686524949628744, 12.630813147959113, 13.65262993073577, 12.758293958617571, 11.827872526395641, 10.780922928949975, 9.818190188581033, 8.758858364452738, 7.798201129908703, 6.827076756391639, 5.851441107585541, 4.9230697535834995, 4.05394259805749, 4.823596516944673, 5.7695498648003065, 7.7195830061113595, 8.749295260715112, 9.77268346334425, 10.749238423026755, 11.75488237857464, 12.61365714680581, 13.604380642467799, 14.648694516526007, 13.78925613430815, 12.781691241380482, 11.710094982736539, 10.716698759560394, 9.771688636507813, 8.812530409633975, 7.806700961599155, 6.8069112240914755, 5.945091619019686, 5.123822250255358, 5.8428682004867465, 6.724782788528159, 8.710468209297622, 9.722153195032798, 10.682805159698713, 11.729813131218759, 12.678108313322776, 13.555973048067985, 14.539300462613914, 15.559199598753974, 14.815675068895093, 13.770269580719885, 12.698702430854611, 11.673956478244067, 10.699663455454264, 9.787947063758956, 8.74899615545229, 7.7754535809450855, 7.019710615353002, 6.135809133866418, 6.909292798004087, 7.651621229250002], [7.774797335391663, 7.04025744829308, 7.953896632237235, 8.944771773709817, 9.848560746684662, 10.80367455773152, 11.831018371349497, 12.782855147214873, 13.722512284413973, 14.746938562159578, 15.80025123834058, 16.547369140783747, 15.482316416333571, 14.473923983397762, 13.503450442774747, 12.73273107945965, 11.80392964252667, 10.79445155019404, 9.81171256370181, 8.784974967351705, 8.793703113038239, 8.095561794283103, 8.944409510541238, 9.89294673174493, 10.87859017586382, 11.782876476048775, 12.781145074969686, 13.773140888763333, 14.778058090807063, 15.783746159347405, 16.737141847777284, 17.45852181393826, 16.39971187421124, 15.383284701793968, 14.430578438345401, 13.738611884008288, 12.729377320015974, 11.82477638665832, 10.859802559534339, 9.839483457298565, 9.837425766071966, 9.129413247520993, 9.923783971871902, 10.882733810089421, 11.806243442507245, 12.819057086850659, 13.783875174305205, 14.805763683732149, 15.794495282513168, 16.801750003044162, 17.75798754124173, 17.3196090284072, 16.450239746696386, 15.508713833739572, 14.53441506047781, 13.746829487809757, 12.796970754605011, 11.956658779091374, 10.94145580960295, 10.877515967553832, 10.855773811069252, 10.140503186642196, 10.907627893181981, 11.836236912686632, 12.86808070891013, 13.802386233542036, 14.750867010994607, 15.74197554539683, 16.72752589555511, 17.704251286389574, 17.384811560329915, 16.331244162586554, 15.490716856768378, 14.528168416412628, 13.514509104536216, 12.796455470542485, 11.867936844102353, 10.949200774420044, 9.955621621258505, 10.740656000179287, 10.668210836836389, 11.079517108619847, 11.963609532726917, 12.900755348384205, 13.85034263067047, 14.858344926706039, 15.80483708205436, 16.745540481336235, 17.719652005679485, 17.27923580238603, 16.329595832997864, 15.391874462174004, 14.543360530272569, 13.556015216077435, 12.535679858306635, 11.744820079109793, 10.868840982348537, 9.998005262371386, 9.009758839395586, 9.770437184233256, 9.660108743440366, 10.721848433919522, 11.671086330354548, 12.596473247998388, 13.536828637818992, 14.56440842499428, 15.501583878785343, 16.470113639982163, 17.23131164369762, 16.303777832067905, 15.357630940412431, 14.430944838320421, 13.516587561549407, 12.587628613214283, 11.609818243289153, 10.775933610341383, 9.848600609456392, 8.999580275963773, 8.062076811938024, 8.70976568417969, 8.779476745684326, 9.757264557714555, 10.718447034306672, 11.725441512214248, 12.566056900168102, 13.61684690784157, 14.54629202445792, 15.534476196453877, 16.318907880130816, 15.373671368788935, 14.336166854444956, 13.407059231373907, 12.554386189968552, 11.637911280623344, 10.657338319860115, 9.752909427242574, 8.886346964821334, 8.023718338563878, 7.042521386241632, 7.780335354416848, 7.7745228843776175, 8.774981883794153, 9.771233977672178, 10.721847673296393, 11.540701051288705, 12.590696080904573, 13.57000057756704, 14.553094212520712, 15.355988115245497, 14.432197332178278, 13.475596278818763, 12.475129825408292, 11.52122521925571, 10.634225573508848, 9.583979851745008, 8.6988502421868, 7.829772700052992, 6.96167280145024, 5.9919596868041465, 6.843249124542303, 6.805103743740744, 7.777070284459869, 8.740168977994585, 9.668206569172611, 10.609940422789673, 11.600726322910585, 12.537007420141224, 13.549046190513122, 14.336624302602173, 13.396674972278095, 12.463553087106991, 11.495985793552698, 10.557338958019967, 9.617940352962234, 8.658106046660683, 7.670428820201559, 6.771623025495342, 5.890307490451207, 5.003544853159157, 5.875810521057221, 5.867024040980518, 6.790307718195469, 7.707194012009291, 8.688319088508486, 9.646207971102362, 10.657087858616586, 11.630231789840693, 12.57236658344511, 13.402824564622648, 12.472169629203165, 11.49496209029436, 10.569788631557318, 9.63082839647845, 8.684219856147918, 7.69723326391499, 6.7083111157371516, 5.76892768043524, 4.8960195792761425, 3.966648109354968, 4.8951219958741925, 4.820802064189612, 5.781108500629746, 6.725228166712672, 7.794593827903903, 8.795261866818777, 9.7688897364549, 10.837349768170618, 11.828892568858182, 12.770972171161189, 11.803902059649536, 10.802437057379578, 9.82361088595961, 8.877395115794059, 7.805711597066659, 6.7400000346248525, 5.789191487929748, 4.804878087207227, 3.86530995749258, 2.9003651096385923, 3.8784172632018334, 3.9067338290427944, 4.834686940988437, 5.85257981546338, 6.891199572981577, 7.938587298855312, 9.008335066536537, 9.912290064239368, 10.857735852011274, 11.820208165531186, 10.89508683527918, 9.931472551498953, 8.926723241253532, 7.89717966562794, 6.891569910254675, 5.856626050874902, 4.907433785490253, 3.8660793274688303, 2.9392654989554874, 1.965012186530461, 2.9511284506498785, 2.923388353145625, 3.915103272249215, 4.968488266725949, 5.9527473593824745, 6.989610280016672, 7.997494708641109, 8.96502809741695, 9.89152511872304, 10.860541834766325, 9.892738947476722, 8.924712309248438, 7.999185979108808, 7.0121086475842995, 6.043578341477113, 4.973147327718859, 3.9696985572361765, 3.0170992826528726, 2.0283988993581943, 0.9786797764087829, 1.948249131656349, 1.9240458900306683, 2.9748357026753656, 3.9954180459655397, 4.963537545724392, 6.036790717926319, 7.051452836498292, 8.000104560097972, 8.937778956196302, 9.989953385427714, 9.182687397029431, 8.15523327086256, 7.111791905271944, 6.075922921628676, 5.061138000922444, 4.037204446825294, 3.0129395027659815, 2.0292319958273137, 1.0405446187427343, 0.0, 0.9465694405339549, 2.8969278409319066, 3.838453221777467, 4.884914502796736, 5.881109332035665, 6.806470828020697, 7.802517085944464, 8.765440218808498, 9.7899351780987, 10.745225069197312, 10.027203713831316, 9.068558714760158, 8.01695212255449, 6.994224584373454, 5.926313680202355, 4.9995142325501, 3.9388474558783706, 3.0173506108018584, 2.0028098843552025, 1.0671683388252857, 2.0016775911119056, 3.95617247327509, 4.872675743020141, 5.879565669229084, 6.81197964724849, 7.825061935677558, 8.73454345566405, 9.739504138875407, 10.7389220344426, 11.796318377715869, 11.032359518579392, 10.010743590280487, 8.962342682563177, 7.931522436903982, 6.949098240610912, 5.950953126490125, 4.966183661217312, 4.009133544376378, 3.050176912142859, 2.0862680126894073, 3.0095948825618617, 4.956507143328183, 5.9023279724256295, 6.837462037106218, 7.784645550155617, 8.716507542068642, 9.735308104677173, 10.669844985791045, 11.692755840593186, 12.665199691476905, 11.940848884377564, 10.872720661164593, 9.850587847119739, 8.890063373777805, 7.893116371317282, 6.90143835480257, 5.939120023665157, 5.00843246479101, 4.042664042977261, 3.0573485031075003, 4.03257191736439, 5.880544467278674, 6.833547306776412, 7.822609607339109, 8.769630131964577, 9.697866725917804, 10.693101879012787, 11.637390077343156, 12.659206860119813, 13.664238600118544, 12.868417145138377, 11.821467547692711, 10.858734807323769, 9.799402983195474, 8.838745748651439, 7.867621375134374, 6.891985726328276, 5.963614372326234, 5.033177672978301, 3.984593810868366, 4.930547158723999, 6.880580300035052, 7.81252955869273, 8.835917761321868, 9.773651056034698, 10.761459307958683, 11.620234076189853, 12.610957571851841, 13.65527144591005, 14.7063771725693, 13.822235860123218, 12.750639601479275, 11.75724337830313, 10.812233255250549, 9.85307502837671, 8.84724558034189, 7.8474558428342105, 6.889284740188193, 5.948432410744799, 5.00386549441044, 5.885780082451851, 7.871465503221314, 8.879827780554832, 9.840479745220748, 10.774621461465712, 11.722916643569729, 12.562549977452028, 13.545877391997957, 14.565776528138016, 15.507531933623516, 14.810814199462621, 13.739247049597347, 12.714501096986803, 11.740208074197, 10.82849168250169, 9.789540774195023, 8.81599819968782, 7.96390373652151, 6.960419294355858, 6.070290091927779, 6.812618523173694], [6.994868207302149, 7.95384346257508, 8.90046607277119, 9.89134121424377, 10.795130187218618, 11.750243998265477, 12.777587811883453, 13.729424587748825, 14.669081724947926, 15.69350800269353, 16.591217054601053, 15.600799700249796, 14.535746975799618, 13.52735454286381, 12.556881002240795, 11.786161638925698, 10.857360201992718, 9.847882109660084, 8.870794779396984, 8.001903702265786, 8.013773984948726, 9.009147808565103, 9.890978951075194, 10.839516172278886, 11.825159616397777, 12.729445916582732, 13.727714515503642, 14.719710329297289, 15.724627531341016, 16.730315599881358, 17.471994447109456, 16.511952373404306, 15.453142433677286, 14.436715261260016, 13.484008997811449, 12.792042443474335, 11.782807879482021, 10.878206946124363, 9.918884775229513, 9.059554329209051, 9.057496637982453, 9.998651777805344, 10.870353412405859, 11.829303250623378, 12.752812883041202, 13.765626527384615, 14.730444614839161, 15.752333124266105, 16.74106472304712, 17.748319443578115, 18.38563840346415, 17.454845414674978, 16.402575185103736, 15.40660035066604, 14.432301577404278, 13.774534972756827, 12.855742146001806, 11.859485895801104, 10.84428292631268, 10.097586839464318, 10.075844682979739, 11.009741716926547, 11.854197333715938, 12.782806353220588, 13.814650149444086, 14.748955674075992, 15.697436451528564, 16.688544985930786, 17.674095336089067, 18.65082072692353, 18.33138100086387, 17.277813603120507, 16.437286297302332, 15.474737856946582, 14.46107854507017, 13.533595105882071, 12.605076479441939, 11.66995840363523, 10.67637925047369, 9.85098147773224, 9.77853631438934, 10.727497934252865, 11.727411908887413, 12.756467738027537, 13.543133538576594, 14.608941708491798, 15.61000167978417, 16.49616257125385, 17.4757886145547, 18.225805242919986, 17.27616527353182, 16.338443902707958, 15.489929970806523, 14.50258465661139, 13.482249298840589, 12.639498874822596, 11.67778945261486, 10.748926102837657, 9.730516468610771, 8.880762661786209, 8.770434220993318, 9.832173911472474, 10.7814118079075, 11.706798725551339, 12.600570701956217, 13.628150489131503, 14.565325942922566, 15.533855704119388, 16.54383525691951, 17.25034727260186, 16.304200380946387, 15.377514278854377, 14.463157002083362, 13.534198053748238, 12.556387683823107, 11.72250305087534, 10.795170049990348, 9.807469984493162, 8.78283444115321, 7.820091161732642, 7.88980222323728, 8.843691816965393, 9.80487429355751, 10.811868771465086, 11.629798964305326, 12.680588971978795, 13.610034088595144, 14.598218260591102, 15.559642468198497, 16.32024080932289, 15.282736294978912, 14.353628671907863, 13.500955630502506, 12.584480721157298, 11.603907760394069, 10.699478867776529, 9.83291640535529, 8.831608047093267, 7.823215753536875, 6.890660831969801, 6.880254550014631, 7.861409143044992, 8.841060722375627, 9.785589737433618, 10.60444311542593, 11.654438145041798, 12.633742641704265, 13.616836276657937, 14.596722703313176, 15.378766772712233, 14.422165719352718, 13.421699265942248, 12.467794659789664, 11.580795014042803, 10.530549292278963, 9.645419682720755, 8.776342140586948, 7.908242241984194, 6.938529127338102, 5.953574602095256, 5.910835409377757, 6.840812348597094, 7.803911042131811, 8.731948633309836, 9.673682486926898, 10.66446838704781, 11.600749484278449, 12.612788254650347, 13.577358890669853, 14.34324441281205, 13.410122527640945, 12.442555234086651, 11.503908398553921, 10.564509793496189, 9.604675487194637, 8.616998260735514, 7.718192466029297, 6.836876930985161, 5.950114293693113, 4.986135998610174, 4.972755706617532, 5.8540497823326945, 6.7709360761465165, 7.752061152645711, 8.709950035239586, 9.720829922753811, 10.693973853977917, 11.636108647582335, 12.679586535589548, 13.41873906973712, 12.441531530828314, 11.516358072091272, 10.577397837012404, 9.630789296681872, 8.643802704448944, 7.654880556271107, 6.715497120969196, 5.842589019810097, 4.913217549888923, 4.005447473427146, 3.926533729826626, 4.844850564766972, 5.788970230849897, 6.858335892041128, 7.859003930956002, 8.832631800592125, 9.901091832307843, 10.892634632995406, 11.858514084879356, 12.75047150018349, 11.749006497913532, 10.770180326493564, 9.823964556328013, 8.752281037600614, 7.686569475158808, 6.735760928463703, 5.751447527741182, 4.811879398026535, 3.846934550172547, 2.9887427407547866, 2.97047589318002, 3.8984290051256627, 4.916321879600606, 5.954941637118803, 7.002329362992538, 8.072077130673764, 8.965720623705414, 9.91116641147732, 10.939169535544035, 11.841656275813136, 10.878041992032909, 9.873292681787488, 8.843749106161894, 7.838139350788629, 6.803195491408856, 5.854003226024208, 4.812648768002785, 3.8858349394894427, 2.911581627064416, 2.0584554929612846, 1.9768189126116704, 2.9685338317152605, 4.021918826191994, 5.00617791884852, 6.0430408394827175, 7.050925268107155, 8.018458656882995, 8.944955678189086, 9.91397239423237, 10.839308388010679, 9.871281749782392, 8.945755419642763, 7.958678088118254, 6.990147782011068, 5.919716768252814, 4.916267997770132, 3.963668723186828, 2.9749683398921496, 1.9252492169427378, 1.0555761739677552, 0.9774764494967135, 2.028266262141411, 3.0488486054315853, 4.016968105190438, 5.090221277392365, 6.104883395964338, 7.0535351195640175, 7.991209515662348, 9.04338394489376, 10.072574678642157, 9.101802711396516, 8.0583613458059, 7.02249236216263, 6.0077074414563985, 4.9837738873592485, 3.9595089432999364, 2.9758014363612686, 1.9871140592766892, 0.9465694405339549, 0.0, 1.950358400397952, 2.8918837812435125, 3.938345062262782, 4.934539891501712, 5.859901387486744, 6.85594764541051, 7.818870778274544, 8.843365737564746, 9.798655628663358, 10.767333451456782, 10.015128155294112, 8.963521563088445, 7.940794024907408, 6.87288312073631, 5.946083673084054, 4.885416896412325, 3.9639200513358137, 2.9493793248891573, 2.0137377793592406, 1.0551081505779507, 3.009603032741135, 3.9261063024861866, 4.93299622869513, 5.865410206714537, 6.878492495143604, 7.787974015130098, 8.792934698341451, 9.792352593908644, 10.849748937181912, 11.772489256204858, 10.957313030814442, 9.908912123097132, 8.878091877437935, 7.895667681144866, 6.89752256702408, 5.9127531017512664, 4.9557029849103325, 3.996746352676814, 3.0328374532233617, 2.0630254420279073, 4.009937702794228, 4.955758531891673, 5.890892596572264, 6.838076109621664, 7.76993810153469, 8.78873866414322, 9.723275545257092, 10.746186400059234, 11.718630250942953, 12.719032495563196, 11.819290101698545, 10.797157287653691, 9.836632814311757, 8.839685811851236, 7.848007795336525, 6.885689464199111, 5.9550019053249645, 4.9892334835112155, 4.003917943641455, 3.1118371267559466, 4.976044351063507, 5.8869778662424554, 6.876040166805154, 7.823060691430624, 8.75129728538385, 9.746532438478834, 10.690820636809203, 11.71263741958586, 12.717669159584592, 13.648090591806522, 12.768036988226664, 11.805304247857721, 10.745972423729427, 9.785315189185392, 8.814190815668328, 7.83855516686223, 6.910183812860188, 5.979747113512256, 4.931163251402321, 4.150618030634485, 5.988902255668848, 6.865960118158774, 7.889348320787912, 8.827081615500745, 9.81488986742473, 10.6736646356559, 11.664388131317889, 12.708702005376097, 13.759807732035348, 14.684040830856597, 13.697209042013228, 12.703812818837083, 11.758802695784501, 10.799644468910664, 9.793815020875844, 8.794025283368166, 7.835854180722149, 6.895001851278754, 5.950434934944395, 5.105850954362337, 7.000129153562064, 7.933258340020876, 8.893910304686791, 9.828052020931759, 10.776347203035776, 11.615980536918075, 12.599307951464004, 13.619207087604064, 14.560962493089564, 15.606367981264771, 14.6858164901313, 13.661070537520756, 12.686777514730952, 11.775061123035645, 10.736110214728978, 9.762567640221777, 8.910473177055465, 7.906988734889813, 7.016859532461735, 6.03268939508418], [6.8199334358878945, 7.778908691160825, 8.758245704598037, 9.749120846070618, 10.764734117807105, 11.719847928853964, 12.74719174247194, 13.724889097919052, 14.664546235118152, 15.688972512863756, 14.6408586542031, 13.650441299851844, 12.585388575401666, 11.576996142465857, 10.606522601842842, 9.835803238527745, 8.907001801594765, 7.897523709262133, 6.920436378999034, 6.051545301867834, 7.83883921353447, 8.834213037150848, 9.748758582902042, 10.697295804105734, 11.757146197883566, 12.699049847171219, 13.69731844609213, 14.689314259885776, 15.720092041511242, 16.475031735141382, 15.521636046711503, 14.561593973006353, 13.502784033279333, 12.486356860862063, 11.533650597413496, 10.841684043076382, 9.832449479084069, 8.927848545726413, 7.968526374831564, 7.110306909755079, 8.882561866568196, 9.823717006391087, 10.728133044232706, 11.687082882450225, 12.684799464526991, 13.697613108870407, 14.700048545427649, 15.721937054854592, 16.736529233217347, 17.45549327281846, 16.435280003066193, 15.504487014277023, 14.452216784705781, 13.456241950268087, 12.481943177006325, 11.824176572358875, 10.905383745603853, 9.909127495403155, 8.89392452591473, 8.148339420010345, 9.900909911565481, 10.83480694551229, 11.711976965542785, 12.640585985047435, 13.67984549659681, 14.680942255561783, 15.629423033014355, 16.620531567416577, 17.60608191757486, 18.439056346658127, 17.43860530096122, 16.37042997093672, 15.406526689840593, 14.443978249484843, 13.50184913294792, 12.736974569667556, 11.808455943227424, 10.873337867420714, 9.879758714259175, 9.20887902794328, 9.839024260894819, 10.787985880758344, 11.701444038365137, 12.73049986750526, 13.506812426475426, 14.572620596390628, 15.573680567683004, 16.459841459152685, 17.43946750245353, 18.3837119755675, 18.37691899568065, 17.309799671349268, 16.394862485998267, 15.416131449820035, 14.480678379177501, 13.73460390233392, 12.772894480126183, 11.84403113034898, 10.825621496122094, 10.179097843889311, 8.830922167498796, 9.806206040950197, 10.755443937385223, 11.680830855029063, 12.564249589855049, 13.591829377030336, 14.5290048308214, 15.497534592018221, 16.507514144818344, 17.383722941668648, 18.25455878134434, 17.32787267925233, 16.413515402481316, 15.48455645414619, 14.50674608422106, 13.625296585739964, 12.697963584854973, 11.670501264509337, 10.645865721169386, 9.683122441748818, 7.886891424703748, 8.807370704864224, 9.768553181456342, 10.775547659363918, 11.593477852204158, 12.644267859877626, 13.573712976493976, 14.561897148489933, 15.523321356097329, 16.441969033746684, 17.233094695376867, 16.303987072305816, 15.45131403090046, 14.534839121555251, 13.554266160792022, 12.649837268174482, 11.735709940219914, 10.694639327109442, 9.68624703355305, 8.753692111985977, 6.875660051419156, 7.8250880309438235, 8.804739610274458, 9.74926862533245, 10.568122003324762, 11.61811703294063, 12.597421529603096, 13.580515164556768, 14.560401591212008, 15.500494997136027, 16.372524119750672, 15.3720576663402, 14.418153060187619, 13.531153414440755, 12.480907692676915, 11.595778083118708, 10.7267005409849, 9.853657004678299, 8.802602789521117, 7.816605882111432, 5.906240910782282, 6.804491236495926, 7.767589930030643, 8.695627521208667, 9.63736137482573, 10.628147274946642, 11.56442837217728, 12.576467142549179, 13.541037778568684, 14.462280497085946, 15.3604809280389, 14.392913634484607, 13.454266798951876, 12.514868193894143, 11.55503388759259, 10.567356661133466, 9.66855086642725, 8.787235331383114, 7.882574379772891, 6.84916727862635, 4.968161208022057, 5.817728670231526, 6.734614964045348, 7.715740040544542, 8.673628923138418, 9.684508810652643, 10.657652741876749, 11.599787535481166, 12.585865084353408, 13.51652001977289, 14.391889931226268, 13.466716472489226, 12.527756237410358, 11.581147697079826, 10.594161104846899, 9.605238956669059, 8.665855521367147, 7.7929474202080495, 6.863575950286875, 5.868478753443322, 3.9219392312311507, 4.808529452665804, 5.752649118748729, 6.82201477993996, 7.822682818854833, 8.796310688490957, 9.717705914407496, 10.691021835192359, 11.656901287076309, 12.654034499854818, 13.585657525733664, 12.720538726891517, 11.774322956725966, 10.702639437998567, 9.636927875556761, 8.686119328861656, 7.701805928139134, 6.762237798424487, 5.797292950570499, 4.8517740207709625, 2.965881394584545, 3.8621078930244943, 4.880000767499437, 5.9186205250176345, 6.850610191095203, 7.900086911454093, 8.755868347476987, 9.701314135248893, 10.729317259315607, 11.654438589567613, 12.634307967436136, 11.776529534058662, 10.794107506559847, 9.788497751186583, 8.75355389180681, 7.8043616264221605, 6.763007168400737, 5.836193339887394, 4.861940027462368, 3.9214867729774605, 1.9722244140161953, 2.8925443101021417, 3.9459293045788755, 4.930188397235401, 5.833188563254291, 6.841072991878728, 7.808606380654568, 8.735103401960659, 9.704120118003944, 10.7239307647517, 11.691957402979984, 10.848992271913938, 9.861914940389429, 8.893384634282244, 7.82295362052399, 6.8666263981680835, 5.91402712358478, 4.925326740290101, 3.87560761734069, 3.005934574365707, 0.9728819509012384, 1.9522767405282924, 2.9728590838184665, 3.9409785835773192, 4.880369001163938, 5.895031119735911, 6.843682843335591, 7.781357239433921, 8.833531668665334, 9.86272240241373, 10.746939101746545, 9.961598198077075, 8.925729214433806, 7.910944293727574, 6.887010739630424, 5.8627457955711115, 4.879038288632444, 3.8903509115478645, 2.896927840931907, 1.950358400397952, 0.0, 0.9415253808455604, 1.9879866618648299, 2.9841814911037594, 3.9095429870887917, 4.905589245012558, 5.868512377876591, 6.893007337166793, 7.848297228265404, 8.81697505105883, 9.775620050129987, 9.03488374968383, 8.012156211502793, 6.944245307331696, 6.01744585967944, 4.956779083007711, 3.942626372382053, 2.9280856459353966, 1.9841798666462722, 0.9470192128727011, 1.059244632343183, 1.9757479020882345, 2.9826378282971775, 3.9150518063165847, 4.928134094745652, 5.837615614732146, 6.842576297943499, 7.841994193510693, 8.899390536783962, 9.822130855806906, 10.779035906680674, 9.975400878917297, 8.9445806332581, 7.904751880455931, 6.906606766335145, 5.91403361899374, 4.934409305956572, 3.975452673723053, 2.941385502483837, 1.9549365043226574, 2.0595793023962763, 3.005400131493722, 3.940534196174312, 4.887717709223711, 5.819579701136737, 6.838380263745268, 7.772917144859139, 8.795827999661281, 9.768271850545, 10.768674095165244, 11.732600541967352, 10.821715391237644, 9.86119091789571, 8.848770011162301, 7.849288312578998, 6.886969981441585, 5.927675408456784, 4.897781532771691, 3.91246599290193, 3.0037481890506967, 3.0256859506655553, 3.9366194658445046, 4.925681766407203, 5.872702291032672, 6.800938884985897, 7.79617403808088, 8.74046223641125, 9.762279019187908, 10.767310759186639, 11.69773219140857, 12.744681788854235, 11.800768758027948, 10.741436933899653, 9.780779699355618, 8.809655325838554, 7.834019677032456, 6.882857315992007, 5.888295162772732, 4.839711300662796, 3.9756832592202302, 4.0385438552708965, 4.915601717760823, 5.938989920389961, 6.876723215102793, 7.864531467026776, 8.723306235257947, 9.714029730919936, 10.758343604978144, 11.809449331637396, 12.733682430458645, 13.692673552183454, 12.699277329007309, 11.754267205954728, 10.788874626041393, 9.783045178006573, 8.763629213956653, 7.744402229982623, 6.803549900539228, 5.85898298420487, 4.930916182948082, 5.049770753164112, 5.982899939622925, 6.9435519042888405, 7.877693620533806, 8.825988802637823, 9.665622136520122, 10.648949551066051, 11.668848687206111, 12.610604092691611, 13.656009580866819, 14.681281000301526, 13.656535047690982, 12.682242024901178, 11.764291280166374, 10.725340371859707, 9.732171570810264, 8.81902122631594, 7.815536784150288, 6.916374134621741, 5.857754623669925], [7.761458816733455, 8.720434072006386, 9.699771085443597, 10.69064622691618, 11.706259498652665, 12.661373309699524, 13.688717123317502, 14.666414478764613, 15.606071615963714, 14.752645949538543, 13.69933327335754, 12.708915919006284, 11.643863194556106, 10.635470761620297, 9.664997220997282, 8.894277857682184, 7.965476420749203, 6.968729645801254, 5.994421774109806, 6.993070682713395, 8.780364594380032, 9.77573841799641, 10.6902839637476, 11.638821184951292, 12.698671578729124, 13.640575228016779, 14.638843826937691, 15.630839640731338, 16.60589265867918, 15.533506354295824, 14.580110665865945, 13.620068592160795, 12.561258652433773, 11.544831480016503, 10.592125216567936, 9.90015866223082, 8.890924098238507, 7.999054482265534, 7.042511769942335, 8.05183229060064, 9.824087247413757, 10.765242387236649, 11.669658425078264, 12.628608263295783, 13.62632484537255, 14.639138489715965, 15.64157392627321, 16.663462435700154, 17.521222612503898, 16.513967891972904, 15.493754622220633, 14.562961633431463, 13.510691403860221, 12.514716569422527, 11.540417796160765, 10.882651191513313, 9.963858364758291, 8.983112890513926, 7.967909921025502, 8.919739250697335, 10.842435292411043, 10.844661696326707, 11.815900297064513, 12.744509316569163, 13.547548967390206, 14.572990926312913, 15.521471703765485, 16.512580238167708, 17.490068231732344, 17.497530965812565, 16.49707992011566, 15.42890459009116, 14.465001308995033, 13.502452868639283, 12.56032375210236, 11.810959964778327, 10.882441338338195, 9.947323262531485, 8.953744109369946, 9.962326793292027, 10.721678490434849, 9.905647774349058, 10.759918657519577, 11.7889744866597, 12.565287045629866, 13.63109521554507, 14.632155186837442, 15.518316078307123, 16.49794212160797, 17.44218659472194, 17.435393614835093, 16.36827429050371, 15.453337105152707, 14.474606068974476, 13.539152998331941, 12.80858929744469, 11.846879875236954, 10.918016525459752, 9.899606891232866, 10.932545609238058, 9.713576397038826, 8.864680660104638, 9.813918556539663, 10.739305474183503, 11.622724209009489, 12.650303996184775, 13.587479449975838, 14.55600921117266, 15.565988763972783, 16.442197560823086, 17.38834445247856, 17.32920391435729, 16.371783931609677, 15.442824983274553, 14.465014613349423, 13.7774757662131, 12.8671202481291, 11.900285489430171, 10.847288918690428, 10.56577667128885, 8.769545654243778, 7.865845324018665, 8.827027800610784, 9.83402227851836, 10.651952471358598, 11.702742479032066, 12.632187595648416, 13.620371767644373, 14.581795975251769, 15.500443652901122, 16.42722589809738, 17.245512453151377, 16.39283941174602, 15.476364502400811, 14.495791541637582, 13.591362649020041, 12.618364169759946, 11.577293556649474, 10.568901263093082, 9.636346341526009, 7.758314280959187, 6.883562650098264, 7.8632142294288965, 8.80774324448689, 9.626596622479202, 10.67659165209507, 11.655896148757536, 12.638989783711208, 13.618876210366448, 14.558969616290465, 15.46592019312326, 16.313583047185762, 15.359678441033179, 14.472678795286315, 13.422433073522475, 12.537303463964268, 11.668225921830459, 10.73631123421833, 9.685257019061149, 8.699260111651464, 6.788895140322313, 5.862965855650366, 6.826064549185082, 7.754102140363107, 8.69583599398017, 9.686621894101082, 10.62290299133172, 11.634941761703619, 12.599512397723124, 13.520755116240384, 14.453877001411488, 15.334439015330165, 14.395792179797436, 13.456393574739703, 12.49655926843815, 11.508882041979026, 10.61007624727281, 9.70242278468685, 8.765228609312922, 7.731821508166382, 5.850815437562088, 4.876203289385965, 5.793089583199787, 6.774214659698981, 7.732103542292858, 8.742983429807083, 9.71612736103119, 10.658262154635606, 11.644339703507846, 12.574994638927329, 13.552202177836135, 14.408241853334786, 13.469281618255918, 12.522673077925386, 11.535686485692459, 10.546764337514619, 9.607380902212707, 8.708134873511785, 7.76590073099379, 6.7511329829833535, 4.804593460771182, 3.8670040718202427, 4.811123737903168, 5.880489399094399, 6.881157438009272, 7.854785307645396, 8.776180533561934, 9.749496454346797, 10.715375906230747, 11.712509119009257, 12.644132144888102, 13.62295831630807, 12.715848337571527, 11.644164818844128, 10.578453256402321, 9.627644709707216, 8.643331308984694, 7.6774252517282235, 6.712480403874236, 5.7344282503109945, 3.8485356241245765, 2.920582512178934, 3.9384753866538773, 4.9770951441720745, 5.9090848102496425, 6.958561530608531, 7.8143429666314255, 8.759788754403331, 9.787791878470046, 10.712913208722052, 11.692782586590575, 12.603495614418776, 11.735632887405409, 10.730023132032143, 9.69507927265237, 8.74588700726772, 7.704532549246297, 6.777718720732954, 5.803465408307928, 4.804141002517492, 2.9137497948617552, 1.9510189292565814, 3.004403923733315, 3.9886630163898404, 4.89166318240873, 5.899547611033166, 6.867080999809006, 7.793578021115097, 8.762594737158382, 9.782405383906138, 10.750432022134422, 11.675958352274051, 10.803440321234989, 9.834910015127804, 8.76447900136955, 7.808151779013643, 6.85555250443034, 5.866852121135661, 4.81713299818625, 3.9474599552112672, 1.9144073317467987, 1.010751359682732, 2.031333702972906, 2.999453202731759, 3.9388436203183774, 4.95350573889035, 5.902157462490029, 6.83983185858836, 7.892006287819771, 8.921197021568169, 9.805413720900985, 10.848855086491602, 9.867254595279366, 8.852469674573134, 7.8285361204759845, 6.804271176416672, 5.8205636694780045, 4.831876292393425, 3.838453221777467, 2.891883781243512, 0.9415253808455604, 0.0, 1.0464612810192695, 2.042656110258199, 2.9680176062432313, 3.9640638641669974, 4.926986997031031, 5.951481956321233, 6.9067718474198445, 7.8754496702132695, 8.834094669284427, 9.885701261490095, 8.953681592348353, 7.885770688177256, 6.958971240525, 5.898304463853271, 4.884151753227613, 3.869611026780957, 2.9257052474918326, 1.8885445937182614, 2.0007700131887436, 1.034222521242674, 2.041112447451617, 2.9735264254710243, 3.986608713900092, 4.896090233886585, 5.9010509170979395, 6.9004688126651335, 7.957865155938403, 8.880605474961346, 9.837510525835114, 10.869274670184012, 9.88610601410366, 8.846277261301491, 7.848132147180705, 6.8555589998393, 5.875934686802132, 4.916978054568613, 3.882910883329398, 2.896461885168218, 3.0011046832418367, 2.0793855266044936, 2.999008815328751, 3.9461923283781513, 4.878054320291177, 5.896854882899708, 6.8313917640135795, 7.85430261881572, 8.82674646969944, 9.827148714319684, 10.791075161121793, 11.763240772083204, 10.80271629874127, 9.790295392007861, 8.790813693424559, 7.8284953622871445, 6.869200789302345, 5.839306913617252, 4.853991373747491, 3.9452735698962567, 3.967211331511116, 3.010604860955276, 3.9841563855616418, 4.931176910187111, 5.8594135041403375, 6.8546486572353205, 7.798936855565691, 8.820753638342348, 9.82578537834108, 10.75620681056301, 11.803156408008675, 12.74229413887351, 11.682962314745215, 10.72230508020118, 9.751180706684115, 8.775545057878018, 7.824382696837569, 6.829820543618292, 5.781236681508357, 4.917208640065791, 4.980069236116457, 3.989587112871594, 5.004620376297535, 5.935197834257232, 6.923006086181216, 7.7817808544123865, 8.772504350074376, 9.816818224132584, 10.867923950791836, 11.792157049613085, 12.817901116742238, 13.64080270985287, 12.69579258680029, 11.730400006886953, 10.724570558852133, 9.705154594802213, 8.685927610828184, 7.74507528138479, 6.800508365050431, 5.872441563793643, 5.991296134009673, 5.056885334733696, 6.014757840827961, 6.936168239688246, 7.884463421792263, 8.724096755674562, 9.707424170220492, 10.727323306360551, 11.669078711846051, 12.714484200021259, 13.786051349886533, 14.598060428536543, 13.62376740574674, 12.705816661011934, 11.666865752705267, 10.673696951655824, 9.7605466071615, 8.75706216499585, 7.857899515467302, 6.799280004515486], [8.706348614252551, 9.665323869525482, 10.644660882962693, 11.635536024435275, 12.663770664066323, 13.618884475113182, 14.646228288731159, 15.594197541173012, 14.72769786164097, 13.706184668519276, 12.652871992338273, 11.662454637987016, 10.597401913536839, 9.58900948060103, 8.618535939978013, 7.847816576662915, 6.919015139729934, 5.922268364781985, 6.866484963850717, 7.893222560200824, 9.725254391899128, 10.720628215515505, 11.635173761266696, 12.583710982470388, 13.64356137624822, 14.598086393430437, 15.596354992351348, 16.588350806144994, 15.55943137765991, 14.487045073276555, 13.533649384846676, 12.573607311141526, 11.514797371414504, 10.498370198997234, 9.545663935548667, 8.853697381211552, 7.844462817219238, 6.952593201246265, 7.914574959683247, 8.95198416808807, 10.768977044932853, 11.710132184755745, 12.176746658400681, 13.142912378564334, 13.713218531271105, 14.660152370482304, 15.631893282753913, 16.653781792180858, 16.47476133148463, 15.467506610953635, 14.447293341201364, 13.516500352412194, 12.464230122840952, 11.468255288403258, 10.493956515141496, 9.836189910494044, 8.917397083739022, 7.965995046271534, 8.839973110766413, 9.791802440438246, 11.787325089930139, 11.857447003404221, 11.192902737090602, 12.121511756595252, 12.65138126486822, 13.676823223790928, 14.6253040012435, 15.616412535645722, 16.588391809807465, 16.451069684793296, 15.45061863909639, 14.38244330907189, 13.418540027975764, 12.455991587620014, 11.51386247108309, 10.774949620681813, 9.84643099424168, 8.993703080064762, 9.825807299110858, 10.834389983032938, 11.734463797512364, 10.91843308142657, 10.136921097545667, 11.161746910309862, 11.66911934310788, 12.734927513023084, 13.735987484315457, 14.622148375785137, 15.596265699683093, 16.44467766773173, 16.388932333815823, 15.32181300948444, 14.406875824133438, 13.428144787955206, 12.492691717312672, 11.80723627820323, 10.845526855995494, 10.043354706187085, 10.771670080973777, 11.80460879897897, 10.726361704116341, 9.87746596718215, 9.190920996565753, 10.106700172318792, 10.726556506487503, 11.75413629366279, 12.691311747453852, 13.659841508650674, 14.664312342047907, 15.395736279803815, 16.341883171459287, 16.28274263333802, 15.325322650590408, 14.396363702255284, 13.418553332330154, 12.776122746971641, 11.86576722888764, 11.041779692594698, 11.71935210843134, 11.578561978366363, 9.782330961321293, 8.878630631096177, 8.11710091565315, 9.079282511303298, 9.755784768836612, 10.80657477651008, 11.73601989312643, 12.682382858498851, 13.643807066106246, 14.453982371881853, 15.38076461707811, 16.30987224014916, 16.391026421544968, 15.400807209464451, 14.371033255759192, 13.843336553690408, 12.828020873522698, 12.017641629994593, 11.581686570170595, 10.649131648603522, 8.771099588036702, 7.896347957175776, 7.134789838501714, 8.048205565721815, 8.730428919957216, 9.780423949573084, 10.75972844623555, 11.701000874565686, 12.680887301220926, 13.512508335271196, 14.419458912103991, 15.442786941547535, 16.319468095224487, 15.513557061756893, 14.463311339993053, 13.578181730434846, 12.688051865647866, 11.749096541295843, 10.698042326138662, 9.712045418728977, 7.801680447399827, 6.8757511627278785, 6.0976401582578985, 6.994564461598033, 7.799668291458183, 8.790454191579096, 9.726735288809735, 10.696952852558097, 11.661523488577602, 12.474293835221115, 13.407415720392219, 14.42042410892954, 15.355581833988742, 14.497271841210281, 13.537437534908728, 12.549760308449605, 11.650954513743388, 10.715208091764362, 9.778013916390435, 8.744606815243895, 6.8636007446396015, 5.888988596463479, 5.064665192272604, 5.998969359525008, 6.8359358397708725, 7.846815727285097, 8.778138451885667, 9.720273245490084, 10.597878422488577, 11.52853335790806, 12.505740896816866, 13.430914355553908, 14.369874590632776, 13.563551344395965, 12.576564752163037, 11.587642603985197, 10.648259168683285, 9.720920180589298, 8.778686038071303, 7.763918290060866, 5.8173787678486955, 4.879789378897756, 4.082699346975985, 4.971224504803734, 5.90219319247846, 6.868133925137206, 7.729719252542666, 8.703035173327528, 9.668914625211478, 10.666047837989987, 11.597670863868833, 12.576497035288801, 13.522712805454352, 12.685043085314707, 11.6193315228729, 10.668522976177794, 9.684209575455272, 8.690210558805736, 7.725265710951748, 6.747213557388507, 4.86132093120209, 3.933367819256447, 3.1023554761317182, 3.9935905303651817, 4.862623529230373, 5.912100249589262, 6.767881685612156, 7.713327473384062, 8.741330597450776, 9.666451927702782, 10.646321305571306, 11.557034333399507, 12.628028909256834, 11.77090139850272, 10.735957539122948, 9.786765273738299, 8.745410815716875, 7.818596987203533, 6.844343674778506, 5.816926309595005, 3.960211075881025, 2.9638042363340946, 2.0436297925611178, 2.960283636887006, 3.845201901389461, 4.853086330013897, 5.820619718789737, 6.747116740095828, 7.716133456139113, 8.735944102886869, 9.703970741115153, 10.629497071254782, 11.61657440277929, 10.881371296147073, 9.810940282388819, 8.854613060032912, 7.902013785449609, 6.91331340215493, 5.863594279205519, 4.993921236230537, 2.960868612766068, 2.0235366667602452, 1.0029543234700709, 1.9710738232289238, 2.892382339299108, 3.9070444578710806, 4.85569618147076, 5.793370577569091, 6.845545006800502, 7.8747357405489, 8.758952439881716, 9.802393805472333, 10.838262789115602, 9.898930955592403, 8.874997401495254, 7.850732457435941, 6.867024950497274, 5.878337573412694, 4.884914502796736, 3.9383450622627816, 1.9879866618648299, 1.0464612810192695, 0.0, 0.9961948292389295, 1.9215563252239618, 2.917602583147728, 3.880525716011762, 4.905020675301964, 5.8603105664005755, 6.828988389194, 7.787633388265158, 8.839239980470825, 9.861967518651863, 8.932231969196524, 8.005432521544268, 6.94476574487254, 5.930613034246882, 4.916072307800226, 3.972166528511102, 2.9350058747375307, 3.0472312942080126, 2.0471278133691975, 0.9946511664323477, 1.9270651444517548, 2.9401474328808224, 3.8496289528673158, 4.85458963607867, 5.8540075316458635, 6.911403874919133, 7.834144193942078, 8.791049244815845, 9.822813389164743, 10.79926537118239, 9.89273854232076, 8.894593428199974, 7.902020280858569, 6.922395967821401, 5.963439335587882, 4.929372164348667, 3.9429231661874873, 3.9459944807609317, 3.000173651663486, 1.952547534309482, 2.8997310473588818, 3.8315930392719078, 4.850393601880438, 5.784930482994309, 6.807841337796449, 7.7802851886801685, 8.780687433300411, 9.744613880102523, 10.766746694147377, 11.727271167489311, 10.83675667302713, 9.837274974443828, 8.874956643306414, 7.915662070321614, 6.885768194636521, 5.90045265476676, 4.9676927026708, 4.912101129030211, 3.9313929860142682, 2.9376951045423727, 3.8847156291678417, 4.812952223121068, 5.808187376216051, 6.7524755745464216, 7.774292357323079, 8.77932409732181, 9.70974552954374, 10.756695126989406, 11.719427867358348, 12.658752930618864, 11.768766361220449, 10.797641987703384, 9.822006338897287, 8.870843977856838, 7.856635647550455, 6.80805178544052, 5.862098437584886, 5.924959033635552, 4.9103752379305865, 3.9581590952782664, 4.888736553237963, 5.876544805161947, 6.7353195733931175, 7.726043069055108, 8.770356943113315, 9.821462669772567, 10.745695768593816, 11.771439835722969, 12.678565526156106, 13.623575649208687, 12.713221207524139, 11.707391759489319, 10.6879757954394, 9.66874881146537, 8.727896482021976, 7.783329565687617, 6.817331361312738, 6.936185931528768, 5.928948524474608, 4.968296559808692, 5.8897069586689765, 6.838002140772994, 7.677635474655293, 8.660962889201224, 9.680862025341284, 10.622617430826784, 11.668022919001992, 12.739590068867265, 13.665549380889715, 14.551550468155138, 13.68863786164912, 12.649686953342453, 11.65651815229301, 10.743367807798686, 9.739883365633036, 8.802789312986397, 7.744169802034581], [9.70254344349148, 10.66151869876441, 11.640855712201622, 12.631730853674203, 13.65996549330525, 14.61507930435211, 15.509323514045873, 14.59800271193408, 13.731503032402038, 12.709989839280345, 11.656677163099342, 10.666259808748086, 9.601207084297908, 8.592814651362099, 7.622341110739083, 6.851661736133559, 6.011778146135818, 6.9090724204388065, 7.853289019507539, 8.880026615857645, 10.721449221138057, 11.716823044754435, 12.631368590505627, 13.305829798459696, 13.644676968675599, 14.63391159518541, 15.6384285528505, 15.61499917421439, 14.56323654842098, 13.490850244037624, 12.537454555607745, 11.577412481902595, 10.518602542175575, 9.502175369758305, 8.549469106309738, 7.857542540682196, 6.937225823625122, 7.8655476682893, 8.901379015340067, 9.93878822374489, 11.765171874171784, 12.706327013994676, 13.026931559920879, 12.316042720115204, 12.717023702032174, 13.663957541243374, 14.635698453514982, 15.657586962941926, 15.4785665022457, 14.471311781714705, 13.451098511962435, 12.520305523173265, 11.468035293602023, 10.472060459164329, 9.497761685902567, 8.840035069964689, 8.010160090144906, 8.878949513314568, 9.826777166423234, 10.778606496095067, 12.78351991916907, 12.818909009923967, 12.0430876386108, 11.25148835300948, 11.65518643562929, 12.680628394551997, 13.629109172004569, 14.620217706406791, 15.592196980568534, 15.454874855554369, 14.454423809857461, 13.386248479832961, 12.422345198736835, 11.459796758381085, 10.517667641844161, 9.851111338551068, 8.939194000647564, 9.874312076454274, 10.812611354767679, 11.82119403868976, 12.69592580403211, 11.879895087946318, 10.987105999065866, 10.186969917311906, 10.67292451386895, 11.738732683784153, 12.739792655076526, 13.625953546546206, 14.600070870444162, 15.448482838492799, 15.392737504576893, 14.325618180245511, 13.41068099489451, 12.431949958716277, 11.496496888073743, 10.899999284609116, 9.93828986240138, 10.867153212178582, 11.758474136630598, 12.79141285463579, 11.687823710636087, 10.838927973701898, 10.041105898085952, 9.131923179320836, 9.730361677248572, 10.757941464423858, 11.695116918214921, 12.663646679411743, 13.668117512808976, 14.399541450564884, 15.345688342220358, 15.286547804099094, 14.329127821351479, 13.400168873016355, 12.422358503091225, 11.868885753377526, 10.958530235293525, 11.865578198586196, 12.70615616408816, 12.540023984886108, 10.743792967841038, 9.840092637615925, 8.96728581717335, 8.10450551830534, 8.759589939597682, 9.81037994727115, 10.7398250638875, 11.68618802925992, 12.647612236867316, 13.457787542642922, 14.38456978783918, 15.313677410910229, 15.394831592306037, 14.404612380225522, 13.374838426520263, 12.936099560096293, 11.920783879928583, 12.84144013598609, 12.54314857669034, 11.610593655123267, 9.732561594556447, 8.857809963695523, 7.984974740021913, 7.0734285727238575, 7.734234090718285, 8.784229120334153, 9.76353361699662, 10.704806045326755, 11.684692471981995, 12.516313506032265, 13.42326408286506, 14.446592112308604, 15.323273265985554, 15.408298087340018, 14.44819689463537, 13.906944744797563, 12.977358144696925, 12.71055854781559, 11.659504332658408, 10.673507425248722, 8.763142453919572, 7.837213169247624, 6.947825059778099, 6.019787468600074, 6.803473462219253, 7.794259362340165, 8.730540459570804, 9.700758023319166, 10.665328659338671, 11.478099005982184, 12.411220891153288, 13.424229279690609, 14.359387004749811, 15.254008798538694, 14.498899541428473, 13.51122231496935, 12.612416520263134, 11.676670098284108, 10.73947592291018, 9.70606882176364, 7.825062751159347, 6.850450602983225, 6.005317443026243, 5.024192366527049, 5.8397410105319425, 6.8506208980461665, 7.781943622646736, 8.724078416251153, 9.601683593249648, 10.53233852866913, 11.509546067577935, 12.434719526314977, 13.373679761393845, 14.320288301724377, 13.538026758682783, 12.549104610504942, 11.609721175203031, 10.682382187109043, 9.740148044591049, 8.725380296580612, 6.778840774368441, 5.841251385417502, 5.037777165729685, 3.996447511805775, 4.90599836323953, 5.871939095898277, 6.733524423303736, 7.706840344088598, 8.672719795972549, 9.669853008751058, 10.601476034629904, 11.580302206049872, 12.526517976215423, 13.598201494942822, 12.580793529392645, 11.62998498269754, 10.645671581975018, 9.651672565325482, 8.686727717471495, 7.708675563908253, 5.822782937721835, 4.894829825776193, 4.057433294885419, 3.018813537367222, 3.8664286999914435, 4.915905420350333, 5.771686856373226, 6.717132644145131, 7.745135768211847, 8.670257098463853, 9.650126476332376, 10.560839504160578, 11.631834080017905, 12.63744383539117, 11.697419545642694, 10.748227280258044, 9.70687282223662, 8.780058993723278, 7.805805681298252, 6.778388316114751, 4.931230799757723, 3.9252662428538403, 3.005091799080864, 1.985506643889046, 2.849007072150531, 3.856891500774968, 4.824424889550807, 5.750921910856898, 6.719938626900183, 7.739749273647939, 8.707775911876224, 9.633302242015853, 10.620379573540362, 11.663121696805659, 10.807135111627751, 9.850807889271845, 8.89820861468854, 7.909508231393861, 6.85978910844445, 5.97414223525932, 3.9570634420049977, 2.984998673279991, 1.964416329989817, 0.9962968302309642, 1.8961875100601784, 2.910849628632151, 3.85950135223183, 4.797175748330161, 5.849350177561572, 6.87854091130997, 7.762757610642787, 8.806198976233404, 9.842067959876672, 10.856852880582904, 9.871192230734186, 8.846927286674873, 7.8632197797362045, 6.874532402651625, 5.881109332035667, 4.934539891501712, 2.9841814911037594, 2.042656110258199, 0.9961948292389295, 0.0, 0.9253614959850323, 1.9214077539087984, 2.8843308867728323, 3.9088258460630345, 4.864115737161646, 5.832793559955071, 6.791438559026229, 7.843045151231896, 8.865772689412934, 9.928426798435455, 9.001627350783199, 7.940960574111471, 6.926807863485813, 5.912267137039157, 4.968361357750032, 3.9312007039764607, 4.043426123446943, 3.0433226426081266, 1.9908459956712772, 0.9308703152128252, 1.9439526036418928, 2.8534341236283858, 3.8583948068397405, 4.857812702406934, 5.915209045680204, 6.837949364703149, 7.794854415576916, 8.826618559925812, 9.803070541943463, 10.842899294745632, 9.890788257438905, 8.8982151100975, 7.9185907970603315, 6.959634164826813, 5.925566993587597, 4.939117995426417, 4.942189309999861, 3.996368480902415, 2.948742363548411, 1.903536218119952, 2.8353982100329778, 3.8541987726415083, 4.78873565375538, 5.81164650855752, 6.784090359441239, 7.784492604061482, 8.748419050863594, 9.770551864908448, 10.731076338250382, 11.743497244983791, 10.833469803682759, 9.871151472545344, 8.911856899560544, 7.881963023875451, 6.89664748400569, 5.96388753190973, 5.90829595826914, 4.927587815253197, 3.9244991601991943, 2.9774786355737253, 3.8167573938821384, 4.811992546977121, 5.756280745307492, 6.778097528084149, 7.783129268082881, 8.713550700304811, 9.760500297750477, 10.72323303811942, 11.662558101379934, 12.62321533592397, 11.793836816942314, 10.818201168136216, 9.867038807095767, 8.852830476789384, 7.804246614679449, 6.858293266823815, 6.9211538628744815, 5.906570067169516, 4.944963150935088, 3.9814995596438463, 4.880349975923018, 5.7391247441541875, 6.729848239816178, 7.774162113874384, 8.825267840533636, 9.749500939354887, 10.77524500648404, 11.682370696917175, 12.627380819969757, 13.60662360250334, 12.70358658872825, 11.68417062467833, 10.664943640704301, 9.724091311260906, 8.779524394926547, 7.813526190551667, 7.927437565866606, 6.9157525801314295, 5.955100615465514, 4.98246996507486, 5.841847300243638, 6.681440645416363, 7.664768059962293, 8.684667196102353, 9.626422601587853, 10.67182808976306, 11.743395239628335, 12.669354551650784, 13.555355638916208, 14.484774475387953, 13.645881782581384, 12.652712981531941, 11.739562637037617, 10.736078194871967, 9.798984142225327, 8.740364631273511], [10.62790493947651, 11.58688019474944, 12.566217208186652, 13.557092349659232, 13.749344901869726, 14.687752017517631, 14.587729670370726, 13.676408868258934, 12.809909188726891, 11.87408789711962, 10.820775220938618, 9.830357866587361, 8.765305142137183, 7.756912709201374, 6.786439168578358, 6.0459393425692465, 6.93713964212085, 7.83443391642384, 8.778650515492572, 9.805388111842678, 11.646810717123087, 12.642184540739464, 13.556730086490656, 13.7791658664684, 12.719315472690568, 13.708550099200377, 14.71306705686547, 14.726056824120924, 13.727334606260255, 12.6549483018769, 11.70155261344702, 10.74151053974187, 9.68270060001485, 8.66627342759758, 7.713567164149013, 7.051820147117883, 7.862587319610154, 8.790909164274332, 9.8267405113251, 10.864149719729923, 12.690533370156814, 13.631688509979705, 13.681537392008362, 12.790502638854473, 11.791662206047143, 12.738596045258342, 13.71033695752995, 14.732225466956894, 14.642664560084976, 13.635409839553981, 12.61519656980171, 11.68440358101254, 10.632133351441299, 9.636158517003604, 8.661859743741843, 8.034312676400376, 8.935521586129939, 9.8043110092996, 10.752138662408267, 11.7039679920801, 13.7088814151541, 13.677629672943883, 12.697693470698283, 11.769084451193633, 10.729824939644258, 11.755266898566965, 12.703747676019537, 13.69485621042176, 14.666835484583503, 14.618972913393645, 13.618521867696737, 12.550346537672237, 11.58644325657611, 10.62389481622036, 9.681765699683437, 9.045388944986755, 9.864555496632597, 10.799673572439307, 11.737972850752712, 12.746555534674792, 13.621287300017142, 12.738615750966234, 11.710310694936592, 10.757065464140014, 9.747563017883918, 10.81337118779912, 11.814431159091496, 12.700592050561177, 13.67470937445913, 14.52312134250777, 14.556835562416168, 13.489716238084787, 12.574779052733785, 11.596048016555553, 10.660594945913019, 10.106533807092543, 10.863651358386413, 11.792514708163615, 12.683835632615631, 13.716774350620824, 12.61318520662112, 11.713548490391704, 10.764310593956678, 9.838923676312838, 8.80500018126354, 9.832579968438829, 10.769755422229892, 11.738285183426713, 12.742756016823945, 13.474179954579855, 14.420326846235328, 14.45064586193837, 13.493225879190755, 12.56426693085563, 11.5864565609305, 11.075420275860953, 11.883891731278558, 12.790939694571229, 13.631517660073193, 13.465385480871142, 11.669154463826072, 10.733800126425322, 9.772617649833204, 8.811506015297342, 7.834228443612649, 8.885018451286117, 9.814463567902468, 10.760826533274889, 11.722250740882284, 12.532426046657893, 13.45920829185415, 14.3883159149252, 14.558929650145313, 13.568710438064798, 12.538936484359539, 12.14263408257972, 12.846145375913617, 13.766801631971123, 13.468510072675373, 12.5359551511083, 10.65792309054148, 9.767711352513551, 8.790306572681768, 7.78042906971586, 6.808872594733253, 7.858867624349121, 8.838172121011588, 9.779444549341724, 10.759330975996964, 11.590952010047236, 12.49790258688003, 13.521230616323574, 14.397911770000524, 14.572396145179294, 13.612294952474645, 13.196693267635494, 13.902719640681958, 13.635920043800622, 12.58486582864344, 11.598868921233755, 9.688503949904606, 8.747114558065652, 7.753413874906215, 6.825376283728191, 5.878111966234221, 6.868897866355134, 7.805178963585774, 8.775396527334134, 9.73996716335364, 10.552737509997154, 11.485859395168259, 12.49886778370558, 13.434025508764782, 14.328647302553664, 14.53816875755897, 14.225114689620735, 13.537778016248167, 12.60203159426914, 11.664837418895214, 10.631430317748674, 8.75042424714438, 7.775812098968258, 6.85339347363998, 5.872268397140786, 4.91437951454691, 5.925259402061135, 6.856582126661705, 7.798716920266122, 8.676322097264617, 9.6069770326841, 10.584184571592905, 11.509358030329947, 12.448318265408815, 13.394926805739347, 14.381913397972275, 13.474466106489976, 12.535082671188064, 11.607743683094077, 10.665509540576082, 9.650741792565645, 7.704202270353474, 6.766612881402535, 5.963138661714718, 4.921809007790807, 3.980636867254498, 4.946577599913245, 5.808162927318704, 6.781478848103567, 7.747358299987518, 8.744491512766027, 9.676114538644871, 10.654940710064839, 11.60115648023039, 12.67283999895779, 13.506155025377678, 12.555346478682573, 11.57103307796005, 10.577034061310515, 9.612089213456528, 8.634037059893286, 6.748144433706869, 5.820191321761226, 4.982794790870452, 3.9441750333522543, 2.941067204006411, 3.9905439243653005, 4.846325360388194, 5.7917711481601, 6.819774272226815, 7.744895602478821, 8.724764980347343, 9.635478008175546, 10.706472584032873, 11.712082339406138, 12.622781041627727, 11.673588776243077, 10.632234318221654, 9.705420489708311, 8.731167177283284, 7.703749812099784, 5.856592295742756, 4.850627738838873, 3.930453295065896, 2.9108681398740783, 1.9236455761654994, 2.9315300047899355, 3.8990633935657746, 4.825560414871866, 5.794577130915151, 6.8143877776629065, 7.782414415891192, 8.707940746030822, 9.69501807755533, 10.737760200820627, 11.732496607612783, 10.776169385256877, 9.823570110673572, 8.834869727378893, 7.785150604429481, 6.899503731244352, 4.88242493799003, 3.910360169265023, 2.889777825974849, 1.9216583262159963, 0.9708260140751462, 1.9854881326471188, 2.934139856246798, 3.8718142523451284, 4.92398868157654, 5.9531794153249376, 6.837396114657754, 7.880837480248371, 8.91670646389164, 9.931491384597871, 10.796553726719218, 9.772288782659905, 8.788581275721237, 7.799893898636657, 6.806470828020698, 5.859901387486744, 3.9095429870887917, 2.9680176062432313, 1.9215563252239618, 0.9253614959850323, 0.0, 0.9960462579237662, 1.9589693907878, 2.9834643500780023, 3.938754241176614, 4.907432063970039, 5.866077063041197, 6.917683655246864, 7.9404111934279005, 9.008322097598999, 9.926988846768232, 8.866322070096503, 7.852169359470844, 6.837628633024188, 5.893722853735064, 4.856562199961493, 4.968787619431975, 3.968684138593159, 2.9162074916563094, 1.8562318111978575, 1.0259283745332977, 1.928072627643354, 2.933033310854708, 3.9324512064219017, 4.98984754969517, 5.912587868718116, 6.869492919591884, 7.901257063940781, 8.87770904595843, 9.917537798760598, 10.816149753423936, 9.823576606082531, 8.843952293045364, 7.884995660811844, 6.850928489572629, 5.8644794914114495, 5.867550805984893, 4.921729976887447, 3.8741038595334434, 2.8288977141049845, 2.029675816468666, 3.002876265207115, 3.937413146320986, 4.895797822398579, 5.868241673282299, 6.868643917902541, 7.823057554878561, 8.845190368923415, 9.805714842265349, 10.818135748998758, 11.75883129966779, 10.796512968530376, 9.837218395545575, 8.807324519860483, 7.822008979990723, 6.889249027894762, 6.833657454254172, 5.85294931123823, 4.8498606561842275, 3.902840131558758, 3.0110350003178263, 3.976090604816396, 4.920378803146766, 5.9421955859234235, 6.930287872399632, 7.8607093046215635, 8.83890645407533, 9.801639194444272, 10.737196605394901, 11.697853839938936, 12.668978213456, 11.743562664121248, 10.792400303080798, 9.778191972774414, 8.72960811066448, 7.783654762808847, 7.846515358859513, 6.831931563154548, 5.870324646920121, 4.9068610556288785, 4.074627582358705, 4.903222801993462, 5.893946297655453, 6.93826017171366, 7.983223297380254, 8.896659543671639, 9.853651162808893, 10.760776853242028, 11.70578697629461, 12.685029758828193, 13.62894808471328, 12.60953212066336, 11.59030513668933, 10.649452807245936, 9.704885890911576, 8.738887686536698, 8.85279906185164, 7.841114076116463, 6.880462111450547, 5.907831461059892, 5.036124906679325, 5.845538703255638, 6.828866117801569, 7.848765253941628, 8.790520659427129, 9.835926147602336, 10.873134536056432, 11.747760707975637, 12.63376179524106, 13.563180631712806, 14.571243278566413, 13.57807447751697, 12.664924133022646, 11.661439690856996, 10.724345638210357, 9.66572612725854], [11.623951197400277, 12.582926452673208, 13.56226346611042, 14.553138607583001, 14.745391159793492, 14.168932923805558, 13.591683412446956, 12.680362610335164, 11.813862930803122, 10.878041639195853, 9.82472896301485, 8.834311608663594, 7.769258884213416, 6.760866451277606, 5.7903929106545915, 6.778870530775487, 7.736256009749078, 8.760628606977354, 9.7366501537662, 10.763387750116308, 12.642856975046854, 13.638230798663232, 14.552776344414422, 14.775212124392166, 13.715361730614333, 13.189731005488303, 14.10517955294737, 13.730010566197155, 12.73128834833649, 11.658902043953134, 10.705506355523255, 9.745464281818105, 8.686654342091083, 7.670227169673813, 6.717520906225246, 7.784751335324124, 8.661703687238383, 9.59002553190256, 10.645276456149077, 11.690401703302326, 13.567953290487653, 14.509108430310544, 14.677583649932128, 13.786548896778239, 12.787708463970908, 12.150131276588755, 13.10244945361185, 13.959973382684053, 13.64661830216121, 12.639363581630215, 11.619150311877945, 10.688357323088775, 9.636087093517533, 8.640112259079839, 7.665813485818076, 8.604446521344201, 9.554305254548947, 10.603427376927828, 11.570674607232244, 12.522503936904076, 14.443248791888088, 14.673675930867649, 13.693739728622049, 12.765130709117399, 11.725871197568024, 11.166802129897379, 12.095860172101437, 12.892905222694498, 13.734098971365206, 13.622926655469879, 12.622475609772971, 11.554300279748471, 10.590396998652345, 9.627848558296595, 8.68571944175967, 9.61552278993058, 10.483339165051605, 11.418457240858315, 12.412036394019854, 13.420619077941934, 14.61733355794091, 13.73466200889, 12.706356952860357, 11.75311172206378, 10.743609275807684, 10.110843436733376, 11.041890101041684, 11.82903764999184, 12.741972861240834, 13.590384829289471, 13.560789304492403, 12.493669980161021, 11.57873279481002, 10.600001758631787, 9.664548687989251, 10.676667652036368, 11.482435026805419, 12.411298376582621, 13.357899175882773, 14.390837893887966, 13.609231464544887, 12.70959474831547, 11.760356851880443, 10.834969934236604, 9.801046439187306, 9.060038910389016, 9.99721436418008, 10.866730782857376, 11.810019503605648, 12.541443441361556, 13.48759033301703, 13.454599604014604, 12.497179621266987, 11.568220672931863, 10.590410303006733, 11.569647825704537, 12.496980826589528, 13.409723362990235, 14.305581203340335, 14.461431738794909, 12.665200721749839, 11.72984638434909, 10.768663907756972, 9.80755227322111, 8.830274701536416, 8.089725468309897, 8.949873116485383, 9.828090020056592, 10.789514227663988, 11.599689533439594, 12.526471778635852, 13.4555794017069, 13.562883392221545, 12.57266418014103, 11.542890226435771, 12.497069373692486, 13.459234471224587, 14.38558530039013, 14.464556330599141, 13.532001409032068, 11.653969348465248, 10.763757610437317, 9.786352830605535, 8.776475327639627, 7.8049188526570195, 7.063574641372901, 7.973581669594504, 8.846708036123427, 9.826594462778667, 10.658215496828937, 11.565166073661732, 12.588494103105276, 13.465175256782226, 13.576349887255526, 12.616248694550878, 13.55112855874826, 14.480715158848898, 14.63196630172439, 13.580912086567208, 12.594915179157523, 10.684550207828373, 9.74316081598942, 8.749460132829983, 7.821422541651957, 6.874158224157988, 6.021243531897815, 6.907052777584518, 7.842660014115839, 8.807230650135343, 9.620000996778856, 10.55312288194996, 11.566131270487281, 12.501288995546483, 13.395910789335366, 13.542122499635203, 14.529799726094327, 14.533824274171934, 13.598077852192908, 12.660883676818981, 11.627476575672441, 9.746470505068148, 8.771858356892025, 7.849439731563748, 6.8683146550645535, 5.910425772470677, 5.077605067603816, 5.923845613443408, 6.865980407047825, 7.74358558404632, 8.674240519465801, 9.651448058374607, 10.576621517111649, 11.515581752190517, 12.462190292521049, 13.449176884753976, 14.44500332245784, 13.531128929111832, 12.603789941017844, 11.66155579849985, 10.646788050489413, 8.70024852827724, 7.762659139326302, 6.959184919638483, 5.917855265714572, 4.976683125178265, 4.013841086694949, 4.875426414100408, 5.84874233488527, 6.814621786769221, 7.81175499954773, 8.743378025426574, 9.722204196846542, 10.668419967012094, 11.740103485739493, 12.77495111737435, 13.55139273660634, 12.567079335883818, 11.573080319234283, 10.608135471380296, 9.630083317817054, 7.744190691630635, 6.8162375796849926, 5.978841048794217, 4.9402212912760195, 3.9371134619301777, 3.057807411147005, 3.913588847169898, 4.859034634941803, 5.887037759008519, 6.812159089260525, 7.792028467129047, 8.702741494957248, 9.773736070814575, 10.77934582618784, 11.814289685567612, 12.669635034166845, 11.628280576145421, 10.701466747632079, 9.727213435207052, 8.69979607002355, 6.852638553666522, 5.8466739967626395, 4.926499552989662, 3.906914397797844, 2.9196918340892655, 1.9987934915716403, 2.966326880347479, 3.89282390165357, 4.8618406176968545, 5.88165126444461, 6.849677902672895, 7.775204232812524, 8.762281564337034, 9.805023687602331, 10.839184265066189, 11.772215643180644, 10.81961636859734, 9.83091598530266, 8.781196862353248, 7.895549989168119, 5.8784711959137965, 4.90640642718879, 3.885824083898615, 2.9177045841397624, 1.9668722719989125, 1.0527516194288233, 2.0014033430285023, 2.939077739126833, 3.991252168358244, 4.973501493387891, 5.841349856733987, 6.884791222324604, 7.920660205967872, 8.935445126674104, 9.903241384172624, 10.768335040583668, 9.784627533645, 8.795940156560421, 7.802517085944466, 6.85594764541051, 4.905589245012558, 3.9640638641669974, 2.917602583147728, 1.9214077539087984, 0.9960462579237662, 0.0, 0.962923132864034, 1.9874180921542361, 2.9427079832528475, 3.911385806046272, 4.8700308051174295, 5.921637397323097, 6.944364935504133, 8.012275839675231, 8.939075287327487, 9.862368328020269, 8.84821561739461, 7.833674890947954, 6.88976911165883, 5.852608457885259, 5.9648338773557406, 4.964730396516925, 3.9122537495800755, 2.8522780691216236, 1.9979320193195813, 0.9320263697195876, 1.936987052930942, 2.9364049484981356, 3.9938012917714047, 4.916541610794349, 5.873446661668116, 6.905210806017013, 7.881662788034661, 8.921491540836831, 9.890514181267513, 10.819622864006297, 9.83999855096913, 8.88104191873561, 7.846974747496395, 6.860525749335215, 6.86359706390866, 5.917776234811214, 4.87015011745721, 3.8249439720287506, 3.0016794612549496, 2.006830007283349, 2.9413668883972197, 3.8997515644748137, 4.872195415358533, 5.8725976599787755, 6.827011296954794, 7.849144110999648, 8.809668584341582, 9.82208949107499, 10.822123431679197, 11.784441762816611, 10.83326465346934, 9.803370777784249, 8.818055237914487, 7.885295285818529, 7.829703712177939, 6.848995569161996, 5.845906914107993, 4.898886389482524, 3.975279499987613, 2.98004434689263, 3.924332545223, 4.946149327999657, 5.934241614475867, 6.864663046697798, 7.842860196151562, 8.805592936520503, 9.741150347471134, 10.701807582015169, 11.672931955532233, 12.64856760433833, 11.788446561004564, 10.774238230698181, 9.725654368588247, 8.779701020732613, 8.84256161678328, 7.827977821078314, 6.866370904843887, 5.902907313552644, 4.881661271779493, 3.907176544069696, 4.897900039731686, 5.942213913789892, 6.987177039456489, 7.900613285747873, 8.857604904885125, 9.764730595318259, 10.70974071837084, 11.688983500904424, 12.65255616073975, 13.604037720844266, 12.586351394613098, 11.645499065169703, 10.700932148835344, 9.734933944460465, 9.810798700125268, 8.799113714390092, 7.838461749724177, 6.791453778204131, 5.843158596100114, 4.8494924453318715, 5.832819859877802, 6.8527189960178605, 7.794474401503361, 8.839879889678569, 9.877088278132664, 10.751714450051868, 11.637715537317291, 12.567134373789036, 13.594851354592883, 14.572580077697877, 13.660970390946414, 12.657485948780764, 11.720391896134124, 10.661772385182308], [12.586874330264312, 13.545849585537242, 14.525186598974454, 15.516061740447036, 14.605770947080856, 13.650657136033997, 12.628760279582925, 11.717439477471133, 10.850939797939091, 9.984329290635932, 8.937935597807716, 7.947518243456458, 6.897557546774191, 5.889165113838382, 6.696874440733108, 7.6853520608540045, 8.642737539827596, 9.667110137055872, 10.643131683844716, 11.669869280194824, 13.605780107910888, 14.601153931527266, 15.515699477278456, 15.612574571973713, 14.55272417819588, 14.016307621917042, 13.158181027342383, 12.767087433333124, 11.90648560433218, 10.834399139000233, 9.881003450570354, 8.926865816310045, 7.868055876583024, 6.851628704165754, 7.624002436303763, 8.691232865402641, 9.5681852173169, 10.496507061981077, 11.551757986227594, 12.596883233380844, 14.47443482056617, 15.415589960389061, 15.514946097513675, 14.623911344359787, 13.625070911552456, 12.976707893017494, 12.155450928006864, 12.998105428558825, 12.864251037706815, 11.85699631717582, 10.857444115039074, 9.926651126249904, 8.883271502258557, 7.907504625813639, 8.572295015896593, 9.510928051422717, 10.460786784627462, 11.509908907006345, 12.477156137310761, 13.428985466982594, 15.349730321966604, 15.511038378449197, 14.531102176203596, 13.602493156698946, 12.563233645149571, 11.993378746326117, 11.148861646496451, 11.93103726856927, 12.772231017239978, 12.8753240490041, 11.874873003307192, 10.806697673282692, 9.842794392186565, 8.895240925030397, 9.592200971838187, 10.522004320009096, 11.38982069513012, 12.32493877093683, 13.31851792409837, 14.32710060802045, 15.520986076335072, 14.572024456471548, 13.543719400441905, 12.590474169645328, 11.580971723389231, 10.937420053162114, 10.094891575436698, 10.867169695866611, 11.780104907115605, 12.628516875164243, 12.813186698026623, 11.746067373695242, 10.83113018834424, 9.867394125365589, 10.571030218067769, 11.583149182114884, 12.388916556883935, 13.317779906661137, 14.264380705961289, 15.297319423966481, 14.525405847244649, 13.546957195897017, 12.59771929946199, 11.672332381818151, 10.638408886768854, 9.886615526817755, 9.050215838575093, 9.904862828732147, 10.84815154948042, 11.579575487236328, 12.525722378891802, 12.706996997548824, 11.814492588948891, 10.885533640613767, 11.49689183308525, 12.476129355783055, 13.403462356668046, 14.31620489306875, 15.21206273341885, 15.424354871658943, 13.5813751044496, 12.567208831930637, 11.60602635533852, 10.644914720802657, 9.667637149117963, 8.916302084738636, 7.988005162360154, 8.866222065931364, 9.82764627353876, 10.637821579314366, 11.564603824510623, 12.493711447581672, 12.880196359903449, 11.899202809088552, 12.449371756514289, 13.403550903771006, 14.365716001303104, 15.292066830468645, 15.427479463463175, 14.494924541896102, 12.57014373116501, 11.601120058018864, 10.623715278187083, 9.613837775221175, 8.642281300238567, 7.890151257801639, 7.011713715469275, 7.8848400819982, 8.864726508653439, 9.696347542703709, 10.603298119536504, 11.626626148980048, 12.503307302656998, 12.902888516203047, 13.522730224629395, 14.45761008882678, 15.387196688927418, 15.594889434588424, 14.543835219431243, 13.557838312021557, 11.600724590528134, 10.580523263570967, 9.58682258041153, 8.658784989233505, 7.711520671739534, 6.847820148326553, 5.9451848234592894, 6.88079205999061, 7.845362696010115, 8.658133042653628, 9.591254927824732, 10.604263316362053, 11.539421041421255, 12.434042835210137, 13.463354004117113, 14.44525307279702, 15.372970655492583, 14.561000985056943, 13.623806809683016, 12.590399708536475, 10.66264488776791, 9.657505812505718, 8.686802179145293, 7.705677102646099, 6.7477882200522235, 5.9041816840325545, 4.96197765931818, 5.904112452922597, 6.781717629921092, 7.712372565340574, 8.689580104249378, 9.61475356298642, 10.553713798065289, 11.50032233839582, 12.487308930628748, 13.483135368332611, 14.422518803634523, 13.566713073881878, 12.624478931363884, 11.609711183353447, 9.663171661141275, 8.725582272190335, 7.8840792728659155, 6.8147136116746845, 5.814045572759811, 4.840417703123688, 3.91355845997518, 4.886874380760042, 5.852753832643993, 6.849887045422501, 7.781510071301346, 8.760336242721314, 9.706552012886865, 10.778235531614264, 11.813083163249122, 12.763891709944227, 13.530002468747853, 12.536003452098317, 11.57105860424433, 10.593006450681088, 8.70711382449467, 7.779160712549026, 6.941764181658251, 5.903144424140054, 4.900036594794211, 3.884384027575743, 2.95172089304467, 3.8971666808165755, 4.92516980488329, 5.850291135135296, 6.830160513003818, 7.74087354083202, 8.811868116689347, 9.81747787206261, 10.852421731442384, 11.801613996827033, 12.591203709009456, 11.664389880496113, 10.690136568071086, 9.662719202887585, 7.815561686530556, 6.809597129626673, 5.889422685853696, 4.869837530661878, 3.882614966953299, 2.9342289846457703, 2.004458926222251, 2.9309559475283415, 3.899972663571626, 4.9197833103193815, 5.887809948547667, 6.813336278687296, 7.8004136102118045, 8.8431557334771, 9.876261132202156, 10.919664078514884, 11.782539501461372, 10.793839118166693, 9.74411999521728, 8.858473122032153, 6.84139432877783, 5.869329560052823, 4.848747216762649, 3.8806277170037964, 2.929795404862946, 1.9881871125029533, 1.0395353889032741, 1.9772097850016044, 3.0293842142330156, 4.010578360523857, 4.8784267238699535, 5.92186808946057, 6.957737073103838, 7.97252199381007, 8.940318251308591, 9.962726884247573, 10.747550666509035, 9.758863289424456, 8.765440218808498, 7.818870778274544, 5.868512377876591, 4.926986997031031, 3.880525716011762, 2.8843308867728323, 1.9589693907878, 0.962923132864034, 0.0, 1.0244949592902022, 1.9797848503888138, 2.9484626731822385, 3.9071076722533964, 4.958714264459064, 5.9814418026401, 7.049352706811199, 7.976152154463454, 9.036818931135183, 9.811138750258644, 8.796598023811988, 7.8526922445228635, 6.815531590749292, 6.927757010219774, 5.927653529380959, 4.8751768824441095, 3.8152012019856576, 2.9608551521836155, 1.8949495025836216, 0.9740639200669081, 1.9734818156341016, 3.0308781589073703, 3.9536184779303154, 4.910523528804083, 5.942287673152981, 6.918739655170628, 7.958568407972798, 8.92759104840348, 9.920164195744885, 10.802921683833164, 9.843965051599644, 8.80989788036043, 7.823448882199249, 7.826520196772693, 6.8806993676752475, 5.8330732503212435, 4.7878671048927846, 3.9321120999703956, 2.913311537361865, 1.9787746562479942, 2.9368284316107793, 3.909272282494499, 4.909674527114742, 5.864088164090761, 6.886220978135615, 7.846745451477549, 8.859166358210958, 9.859200298815164, 10.821518629952578, 11.796187786333375, 10.766293910648283, 9.780978370778522, 8.848218418682562, 8.792626845041973, 7.81191870202603, 6.8088300469720275, 5.861809522346558, 4.881761030066129, 3.886525876971146, 3.052631207783774, 3.9992614122415553, 4.971318481611833, 5.901739913833764, 6.879937063287529, 7.842669803656471, 8.778227214607101, 9.738884449151136, 10.7100088226682, 11.685644471474298, 12.636806832514747, 11.737161363562215, 10.688577501452281, 9.742624153596648, 9.805484749647313, 8.790900953942348, 7.795790307759932, 6.813171820272521, 5.788142801858009, 4.813658074148212, 4.026198702292461, 4.995325998031792, 6.024253906592455, 6.937690152883839, 7.894681772021092, 8.801807462454228, 9.74681758550681, 10.726060368040393, 11.689633027875717, 12.641114587980233, 13.549274527477133, 12.608422198033738, 11.663855281699378, 10.6978570773245, 10.717280230203784, 9.705595244468608, 8.744943279802692, 7.697935308282647, 6.74964012617863, 5.755973975410388, 4.961118522438577, 5.965925630810727, 6.907681036296227, 7.953086524471434, 8.91416514526863, 9.788791317187837, 10.67479240445326, 11.604211240925006, 12.63192822172885, 13.609656944833844, 14.598922283920084, 13.620409081644798, 12.683315028998159, 11.624695518046343], [13.611369289554515, 14.570344544827446, 15.549681558264657, 14.609510627421702, 13.581275987790654, 12.626162176743795, 11.604265320292724, 10.692944518180932, 9.82644483864889, 8.95983433134573, 7.924616326782031, 6.9341989724307735, 5.904790417520842, 6.844292830047135, 7.66451979987235, 8.652997419993246, 9.610382898966838, 10.634755496195114, 11.610777042983958, 12.637514639334064, 14.610308936780411, 15.62564889081747, 16.54019443656866, 15.651312028401248, 14.594598721570861, 13.60536409506105, 12.554392023912913, 11.742592474042922, 10.881990645041979, 9.821079867974548, 8.86768417954467, 7.996478761243836, 6.941864541631245, 7.806756420374508, 8.591647795443004, 9.658878224541883, 10.535830576456142, 11.46415242112032, 12.519403345366836, 13.564528592520086, 15.442080179705412, 16.383235319528303, 16.393485626863175, 15.502450873709284, 14.503610440901953, 13.855247422366993, 12.982399305544153, 12.112072286384326, 11.850931766681132, 10.843677046150137, 9.888529873009114, 8.996264071183695, 7.957080167306778, 8.862632342022394, 9.539940375035833, 10.478573410561957, 11.428432143766702, 12.477554266145587, 13.444801496450003, 14.396630826121836, 16.317375681105844, 16.389577907798696, 15.409641705553094, 14.481032686048444, 13.441773174499069, 12.871918275675617, 11.97581002403374, 11.04500412639477, 11.803762465648205, 11.902352765794953, 10.947588685762488, 9.880506338330912, 8.916603057234786, 9.85036864123915, 10.559846330977427, 11.489649679148336, 12.357466054269361, 13.29258413007607, 14.28616328323761, 15.29474596715969, 16.39952560568457, 15.450563985821047, 14.422258929791404, 13.469013698994825, 12.459511252738729, 11.815959582511613, 10.921839952973986, 9.981136553692112, 10.811636355523833, 11.65488759018638, 11.886995363074845, 10.819876038743462, 9.90493885339246, 10.822521841574343, 11.538675577207009, 12.550794541254124, 13.356561916023175, 14.285425265800377, 15.232026065100529, 16.26496478310572, 15.403945376594148, 14.425496725246516, 13.47625882881149, 12.55087191116765, 11.516948416118352, 10.765155056167254, 9.928755367924595, 9.018829686557648, 9.879682997888647, 10.605946202258465, 11.552093093913939, 11.780805662597045, 10.931711822115622, 11.84066135682252, 12.46453719222449, 13.443774714922295, 14.371107715807286, 15.28385025220799, 16.17970809255809, 16.34316338045913, 14.4599146337991, 13.445748361280135, 12.484565884688017, 11.523454250152154, 10.54617667846746, 9.794841614088135, 8.866544691709654, 7.980188923756865, 8.859177721946986, 9.664192294336504, 10.590974539532763, 11.520082162603812, 11.99741559307018, 12.854330525297305, 13.417017115653529, 14.371196262910246, 15.333361360442344, 16.259712189607885, 16.34628797226336, 15.413733050696289, 13.448683260514509, 12.479659587368364, 11.50225480753658, 10.492377304570672, 9.520820829588065, 8.768690787151138, 7.8902532448187745, 6.9988069398237, 7.896257957061666, 8.722718257725846, 9.629668834558643, 10.652996864002187, 11.529678017679137, 12.488481702897834, 13.415598524223578, 14.386595689131719, 15.316182289232357, 16.25513761358438, 15.462643728231429, 14.476646820821744, 12.479264119877634, 11.459062792920465, 10.465362109761028, 9.537324518583002, 8.590060201089033, 7.726359677676053, 6.823724352808789, 5.99475891781611, 6.876894144418342, 7.684503757675766, 8.617625642846871, 9.630634031384192, 10.565791756443394, 11.460413550232277, 12.489724719139252, 13.471623787819158, 14.399341370514723, 15.472916408848695, 14.562034757985684, 13.528627656839143, 11.541184417117409, 10.536045341855218, 9.565341708494792, 8.584216631995599, 7.626327749401722, 6.782721213382054, 5.840517188667679, 5.018079310748097, 5.80808834494323, 6.738743280362712, 7.715950819271518, 8.64112427800856, 9.580084513087428, 10.52669305341796, 11.513679645650887, 12.50950608335475, 13.448889518656662, 14.523148147006182, 13.616643869760045, 12.601876121749608, 10.687666620431477, 9.70673846829834, 8.762618802215414, 7.693253141024183, 6.69258510210931, 5.718957232473186, 4.792097989324678, 3.966270258306247, 4.879124547666131, 5.875477552756089, 6.784700808454184, 7.763526979874152, 8.709742750039704, 9.781426268767103, 10.810507712787441, 11.761316259482546, 12.745629660205068, 13.560498411388519, 12.595553563534532, 11.61750140997129, 9.731608783784871, 8.803655671839229, 7.9186788079984, 6.880059050480202, 5.832671324606467, 4.762923556925242, 3.8302604223941685, 2.9765625583627804, 3.928360542036128, 4.8534818722881345, 5.833351250156657, 6.73829809037034, 7.809292666227666, 8.81490242160093, 9.849846280980703, 10.799038546365352, 11.840393004386776, 12.688884839786315, 11.714631527361288, 10.687214162177787, 8.84005664582076, 7.834092088916876, 6.913917645143899, 5.887828857529748, 4.822520069371972, 3.8127685139952687, 2.8829984555717494, 1.9341466846811795, 2.903163400724464, 3.917207859857702, 4.885234498085987, 5.810760828225616, 6.797838159750125, 7.840580283015421, 8.851766172911955, 9.895169119224683, 10.847768393807987, 11.818334077456894, 10.768614954507482, 9.882968081322357, 7.865889288068032, 6.893824519343026, 5.873242176052852, 4.905122676293999, 3.8813887604244246, 2.866726641852452, 1.9180749182527725, 0.9804005221544423, 2.0194187905502354, 2.986083401233655, 3.8539317645797513, 4.897373130170369, 5.933242113813637, 6.9480270345198685, 7.9158232920183895, 8.938231924957371, 9.921939431896039, 10.783358248714658, 9.7899351780987, 8.843365737564746, 6.893007337166793, 5.951481956321233, 4.905020675301964, 3.9088258460630345, 2.9834643500780023, 1.9874180921542361, 1.0244949592902022, 0.0, 0.9552898910986116, 1.9239677138920364, 2.882612712963194, 3.9342193051688614, 4.956946843349899, 6.024857747520997, 6.951657195173253, 8.012323971844982, 9.02647668247064, 9.82109298310219, 8.877187203813065, 7.840026550039494, 7.952251969509976, 6.9521484886711615, 5.899671841734312, 4.839696161275859, 3.9853501114738177, 2.919444461873824, 1.9595804401756112, 0.9601625446084175, 2.0153347065065796, 2.9291235186401137, 3.886028569513881, 4.917792713862778, 5.894244695880427, 6.934073448682597, 7.903096089113278, 8.895669236454683, 9.87529354949185, 10.83425018172537, 9.83439283965063, 8.84794384148945, 8.851015156062896, 7.90519432696545, 6.857568209611446, 5.812362064182986, 4.899757459109638, 3.880956896501107, 2.946420015387236, 1.9235091605850956, 2.8959530114688152, 3.896355256089058, 4.839593204800559, 5.861726018845413, 6.822250492187347, 7.834671398920756, 8.834705339524962, 9.797023670662377, 10.833584491623794, 11.790788869938483, 10.805473330068722, 9.872713377972765, 9.817121804332176, 8.836413661316232, 7.833325006262229, 6.88630448163676, 5.849406389205371, 4.854171236110388, 4.007758923992529, 2.9859421412158715, 3.957999210586149, 4.88842064280808, 5.855442103997327, 6.818174844366269, 7.7537322553169, 8.714389489860935, 9.685513863377999, 10.661149512184096, 11.612311873224545, 12.668014984287538, 11.713072460742485, 10.767119112886851, 10.829979708937518, 9.786823869528313, 8.763435666899174, 7.780817179411763, 6.755788160997251, 5.781303433287454, 4.981326418501215, 3.9820067270061075, 5.010934635566771, 5.924370881858154, 6.87018681273089, 7.777312503164026, 8.722322626216608, 9.701565408750191, 10.665138068585515, 11.616619628690032, 12.63433373866073, 13.575186068104125, 12.688350240989582, 11.722352036614703, 11.684925589343026, 10.67324060360785, 9.712588638941934, 8.665580667421889, 7.717285485317872, 6.72361933454963, 5.9162462386473305, 4.952606359785042, 5.894361765270542, 6.9397672534457495, 7.889670185978428, 8.764296357897635, 9.650297445163059, 10.579716281634804, 11.607433262438649, 12.585161985543643, 13.574427324629882, 14.587172951715186, 13.707809988288362, 12.649190477336546], [14.566659180653126, 15.525634435926056, 14.62536039849795, 13.65422073632309, 12.625986096692042, 11.670872285645183, 10.648975429194113, 9.737654627082321, 8.871154947550277, 8.004544440247118, 7.15729147571987, 6.2395478115436545, 6.860080308619454, 7.799582721145748, 8.61980969097096, 9.608287311091857, 10.565672790065449, 11.590045387293724, 12.566066934082569, 13.592804530432677, 15.565598827879022, 16.58093878191608, 15.615873276801953, 14.696022137302636, 13.639308830472249, 12.650074203962438, 11.599102132814302, 10.787302582944312, 9.926700753943367, 9.041352037434944, 8.100359328482508, 7.301827600356717, 7.897154432729857, 8.76204631147312, 9.546937686541614, 10.614168115640494, 11.491120467554753, 12.41944231221893, 13.474693236465447, 14.519818483618696, 16.397370070804023, 17.338525210626916, 16.53196825008666, 15.565802529923005, 14.566962097115674, 13.633034834647543, 12.601832232149821, 11.846595466419053, 10.943137945649472, 10.063949215610531, 9.121205021946952, 8.301612910296576, 8.91237005840539, 9.817922233121006, 10.495230266134444, 11.433863301660567, 12.383722034865313, 13.432844157244197, 14.400091387548613, 15.351920717220446, 17.272665572204453, 17.344867798897308, 16.364931596651708, 15.436322577147056, 14.397063065597681, 13.827208166774227, 12.928358558903035, 11.937250024500813, 10.951699674342532, 11.122624935255347, 10.180263834700327, 9.289977776117224, 9.871892948333398, 10.805658532337763, 11.515136222076038, 12.444939570246946, 13.312755945367972, 14.247874021174681, 15.24145317433622, 16.2500358582583, 17.354815496783182, 16.405853876919657, 15.377548820890016, 14.424303590093437, 13.414801143837341, 12.771249473610224, 11.877129844072599, 10.936426444790724, 9.959573564218159, 10.802824798880708, 11.23547956203238, 10.229347476529774, 10.860228744491073, 11.777811732672955, 12.49396546830562, 13.506084432352734, 14.311851807121787, 15.24071515689899, 16.18731595619914, 17.220254674204334, 16.35923526769276, 15.380786616345128, 14.431548719910102, 13.506161802266263, 12.472238307216964, 11.720444947265864, 10.884045259023205, 9.97411957765626, 9.027620206582974, 9.753883410952794, 10.700030302608267, 11.190277100383357, 11.887001713214234, 12.795951247921133, 13.419827083323101, 14.399064606020906, 15.326397606905896, 16.239140143306603, 17.134997983656703, 17.29845327155774, 15.415204524897712, 14.401038252378747, 13.43985577578663, 12.478744141250766, 11.501466569566073, 10.750131505186745, 9.821834582808265, 8.935478814855477, 8.007114930641313, 8.812129503030832, 9.738911748227089, 10.668019371298138, 11.650187212469703, 12.640104618706658, 13.636894201033012, 14.58859208288182, 15.520693762695027, 16.465120359392348, 17.301577863361974, 16.3690229417949, 14.40397315161312, 13.434949478466976, 12.457544698635193, 11.447667195669284, 10.476110720686677, 9.723980678249749, 8.845543135917385, 7.954096830922313, 7.044195165755993, 7.870655466420174, 8.77760604325297, 9.800934072696515, 10.677615226373465, 11.636418911592163, 12.563535732917906, 13.534532897826047, 14.464119497926685, 15.403074822278708, 16.41793361933004, 15.431936711920356, 13.434554010976246, 12.414352684019077, 11.42065200085964, 10.492614409681615, 9.545350092187645, 8.681649568774663, 7.779014243907399, 6.950048808914723, 6.02483135311267, 6.832440966370093, 7.7655628515411985, 8.77857124007852, 9.713728965137722, 10.608350758926605, 11.63766192783358, 12.619560996513487, 13.54727857920905, 14.620853617543023, 15.517324649084296, 14.483917547937756, 12.49647430821602, 11.49133523295383, 10.520631599593404, 9.539506523094209, 8.581617640500333, 7.738011104480664, 6.7958070797662895, 5.97336920184671, 4.9560255536375575, 5.8866804890570394, 6.863888027965845, 7.789061486702888, 8.728021721781756, 9.674630262112288, 10.661616854345215, 11.657443292049079, 12.59682672735099, 13.671085355700509, 14.571933760858657, 13.55716601284822, 11.642956511530087, 10.662028359396952, 9.717908693314026, 8.648543032122795, 7.647874993207921, 6.6742471235717975, 5.74738788042329, 4.9215601494048595, 4.0270617563604585, 4.9862615370295025, 5.895484792727598, 6.837977238021013, 7.7841930081865645, 8.855876526913963, 9.85521782168883, 10.806026368383936, 11.790339769106458, 12.80196184523351, 13.55084345463314, 12.572791301069898, 10.686898674883482, 9.75894556293784, 8.873968699097011, 7.835348941578814, 6.787961215705079, 5.718213448023853, 4.78555031349278, 3.9318524494613927, 3.076297750730456, 3.964265856561548, 4.94413523443007, 5.783008199271729, 6.854002775129055, 7.85961253050232, 8.894556389882093, 9.843748655266742, 10.885103113288165, 11.811916941801508, 12.669921418459898, 11.642504053276397, 9.79534653691937, 8.789381980015486, 7.869207536242509, 6.843118748628361, 5.777809960470584, 4.76805840509388, 3.838288346670361, 2.8894365757797913, 2.051100609418792, 2.96191796875909, 3.9299446069873754, 4.855470937127005, 5.842548268651513, 6.88529039191681, 7.896476281813342, 8.93987922812607, 9.892478502709375, 10.881178886004054, 11.723904845606091, 10.838257972420967, 8.821179179166641, 7.849114410441636, 6.828532067151462, 5.8604125673926095, 4.8366786515230356, 3.8220165329510634, 2.873364809351384, 1.935690413253054, 1.0641288994516238, 2.030793510135043, 2.8986418734811394, 3.9420832390717564, 4.977952222715024, 5.992737143421256, 6.960533400919777, 7.982942033858758, 8.966649540797427, 9.955336917882006, 10.745225069197309, 9.798655628663354, 7.8482972282654035, 6.906771847419844, 5.860310566400575, 4.8641157371616455, 3.9387542411766137, 2.9427079832528475, 1.9797848503888138, 0.9552898910986116, 0.0, 0.9686778227934246, 1.9273228218645824, 2.97892941407025, 4.001656952251286, 5.069567856422385, 5.99636730407464, 7.057034080746369, 8.071186791372028, 9.085727517818684, 9.832477094911676, 8.795316441138105, 8.907541860608587, 7.907438379769772, 6.854961732832923, 5.794986052374471, 4.9406400025724295, 3.8747343529724354, 2.914870331274223, 1.9154524357070293, 1.0600448154079682, 1.9738336275415018, 2.9307386784152687, 3.9625028227641668, 4.938954804781814, 5.978783557583984, 6.947806198014666, 7.940379345356071, 8.920003658393238, 9.878960290626758, 10.789682730749242, 9.803233732588062, 9.806305047161507, 8.86048421806406, 7.812858100710057, 6.767651955281598, 5.855047350208249, 4.836246787599718, 3.9017099064858476, 2.878799051683707, 2.0544355503184333, 2.972907363504652, 3.8843033137019467, 4.9064361277468, 5.866960601088734, 6.879381507822142, 7.879415448426349, 8.841733779563762, 9.87829460052518, 10.898136055957213, 11.760763221167334, 10.828003269071376, 10.772411695430787, 9.791703552414843, 8.78861489736084, 7.841594372735371, 6.8046962803039825, 5.8094611272089995, 4.96304881509114, 3.941232032314483, 3.116481749435767, 4.039235229009575, 4.900152212898715, 5.862884953267657, 6.798442364218287, 7.759099598762322, 8.730223972279386, 9.705859621085484, 10.657021982125933, 11.712725093188926, 12.668362351841095, 11.722409003985462, 11.785269600036127, 10.742113760626923, 9.718725557997784, 8.736107070510373, 7.711078052095862, 6.736593324386066, 5.936616309599827, 4.937296618104719, 4.169417174416389, 5.075185468059651, 5.914896921632278, 6.822022612065414, 7.767032735117996, 8.746275517651581, 9.709848177486903, 10.66132973759142, 11.679043847562118, 12.619896177005513, 13.564463093339873, 12.677641927713314, 12.640215480441636, 11.62853049470646, 10.667878530040545, 9.6208705585205, 8.672575376416482, 7.678909225648241, 6.871536129745943, 5.907896250883654, 5.199710604383423, 6.1481041255425835, 6.934380294879816, 7.809006466799022, 8.695007554064448, 9.624426390536193, 10.652143371340037, 11.62987209444503, 12.61913743353127, 13.631883060616573, 14.630887690857213, 13.604480368435157], [15.45080072786114, 14.632177224429089, 13.656682575704526, 12.685542913529666, 11.657308273898618, 10.70219446285176, 9.680297606400687, 8.768976804288895, 7.902477124756851, 7.035866617453694, 6.1886136529264455, 7.124044900545969, 7.8287581314128785, 8.768260543939173, 9.588487513764386, 10.576965133885283, 11.534350612858875, 12.55872321008715, 13.534744756875996, 14.561482353226104, 16.469706505507716, 15.666694516667492, 14.647195454008529, 13.727344314509212, 12.670631007678825, 11.681396381169014, 10.630424310020876, 9.818624760150886, 8.95802293114994, 8.07267421464152, 7.131681505689084, 8.091723579394234, 8.86583225552328, 9.730724134266545, 10.51561550933504, 11.58284593843392, 12.459798290348179, 13.388120135012356, 14.443371059258872, 15.488496306412122, 17.366047893597447, 16.520050019121825, 15.563290427293234, 14.59712470712958, 13.59828427432225, 12.664357011854118, 11.633154409356395, 10.877917643625628, 9.974460122856046, 9.095271392817107, 8.152527199153528, 9.083320187942698, 9.881047881198812, 10.78660005591443, 11.46390808892787, 12.402541124453993, 13.352399857658739, 14.401521980037623, 15.36876921034204, 16.320598540013872, 18.241343394997877, 17.531139958243028, 16.547134348603315, 15.652925938791462, 14.613666427242087, 13.58822446831938, 12.639743690866808, 11.944985803615182, 10.99037857664734, 10.153947112461923, 9.211586011906903, 10.071685053763346, 10.84057077112682, 11.774336355131187, 12.483814044869463, 13.413617393040372, 14.281433768161397, 15.216551843968107, 16.210130997129646, 17.218713681051725, 18.323493319576606, 17.37453169971308, 16.34622664368344, 15.392981412886861, 14.383478966630765, 13.731316125753493, 12.68601862872938, 11.745315229447506, 10.704982167148104, 9.894436385811119, 10.266801739238955, 11.011054754175897, 11.828906567284495, 12.746489555466379, 13.462643291099045, 14.47476225514616, 15.280529629915211, 16.209392979692414, 17.155993778992567, 18.188932496997758, 17.327913090486188, 16.34946443913855, 15.400226542703527, 14.474839625059687, 13.440916130010388, 12.688713577300927, 11.751538123509864, 10.783008362313042, 9.773028809512919, 8.845494997883204, 9.791641889538678, 10.744043290796322, 11.734562262334483, 12.663521210669607, 13.627682867489664, 14.606920390187469, 15.521256150357699, 16.479291039819856, 17.531376821672744, 18.267131094351164, 16.383882347691138, 15.369716075172171, 14.408533598580053, 13.44742196404419, 12.470144392359497, 11.718809327980171, 10.79051240560169, 9.806024667943213, 8.846285461153226, 7.903741089961242, 8.8305233351575, 9.759630958228549, 10.741798799400113, 11.678413361734272, 12.675202944060626, 13.626900825909434, 14.55900250572264, 15.503429102419961, 16.51182139597635, 17.337700764588323, 15.372650974406545, 14.4036273012604, 13.426222521428617, 12.416345018462708, 11.4447885434801, 10.692658501043175, 9.814220958710811, 8.824642684010048, 7.883365696267905, 6.962267053350584, 7.869217630183381, 8.839242815724129, 9.715923969401079, 10.674727654619776, 11.60184447594552, 12.57284164085366, 13.502428240954298, 14.441383565306321, 15.492437780463503, 16.400614534713778, 14.40323183376967, 13.383030506812501, 12.389329823653064, 11.461292232475039, 10.51402791498107, 9.650327391568089, 8.747692066700825, 7.820594662002459, 6.8640018836245815, 5.924052553300504, 6.857174438471609, 7.816879983106134, 8.752037708165336, 9.646659501954218, 10.675970670861194, 11.6578697395411, 12.585587322236664, 13.659162360570637, 14.72597997738785, 15.45259537073118, 13.465152131009445, 12.460013055747254, 11.489309422386828, 10.508184345887633, 9.550295463293757, 8.70668892727409, 7.764484902559715, 6.843915054934445, 5.800437166927232, 4.97829207598745, 5.902196770993459, 6.827370229730502, 7.76633046480937, 8.712939005139901, 9.699925597372829, 10.695752035076692, 11.635135470378604, 12.709394098728122, 13.734087265570855, 14.525843835641645, 12.611634334323513, 11.630706182190377, 10.68658651610745, 9.61722085491622, 8.616552816001345, 7.6429249463652225, 6.716065703216715, 5.8373528215340835, 4.871473369650133, 4.017583714236078, 4.926806969934174, 5.869299415227588, 6.8155151853931395, 7.8871987041205385, 8.886539998895405, 9.83734854559051, 10.821661946313032, 11.833284022440084, 12.75284535454124, 13.541469123863326, 11.655576497676908, 10.727623385731265, 9.842646521890437, 8.804026764372239, 7.756639038498504, 6.686891270817278, 5.754228136286205, 4.900530272254817, 3.92070936402013, 2.995588033768124, 3.9754574116366466, 4.814330376478304, 5.88532495233563, 6.890934707708895, 7.925878567088668, 8.875070832473316, 9.91642529049474, 10.843239119008082, 11.81749243143311, 12.611181876069823, 10.764024359712796, 9.758059802808912, 8.837885359035935, 7.811796571421785, 6.746487783264008, 5.736736227887305, 4.806966169463785, 3.858114398573216, 3.013050792713421, 1.9932401459656655, 2.961266784193951, 3.88679311433358, 4.873870445858088, 5.916612569123385, 6.927798459019918, 7.971201405332646, 8.923800679915951, 9.91250106321063, 10.962220186160042, 11.806935795214393, 9.789857001960067, 8.817792233235062, 7.797209889944888, 6.829090390186035, 5.805356474316461, 4.790694355744488, 3.8420426321448087, 2.9043682360464786, 2.0328067222450485, 1.0621156873416187, 1.929964050687715, 2.973405416278332, 4.0092743999216, 5.024059320627832, 5.991855578126353, 7.014264211065333, 7.997971718004001, 8.98665909508858, 10.027203713831314, 10.76733345145678, 8.81697505105883, 7.8754496702132695, 6.828988389194, 5.832793559955071, 4.907432063970039, 3.9113858060462725, 2.9484626731822385, 1.9239677138920364, 0.9686778227934246, 0.0, 0.9586449990711577, 2.010251591276825, 3.032979129457862, 4.10089003362896, 5.027689481281215, 6.088356257952944, 7.1025089685786025, 8.117049695025258, 9.060955474314383, 9.763994263931531, 9.876219683402013, 8.876116202563198, 7.8236395556263485, 6.763663875167897, 5.909317825365854, 4.84341217576586, 3.8835481540676473, 2.884130258500454, 2.0287226382013928, 1.005155804748077, 1.9620608556218442, 2.993824999970742, 3.97027698198839, 5.010105734790559, 5.979128375221242, 6.971701522562647, 7.951325835599814, 8.910282467833333, 9.981542297590806, 10.771911555381488, 10.774982869954933, 9.829162040857486, 8.781535923503483, 7.7363297780750235, 6.823725173001675, 5.804924610393144, 4.8703877292792725, 3.847476874477132, 3.00463178533147, 2.0042295407112274, 2.915625490908522, 3.937758304953376, 4.89828277829531, 5.910703685028718, 6.910737625632925, 7.873055956770338, 8.909616777731756, 9.929458233163789, 10.91477377303355, 11.796681091864802, 11.741089518224213, 10.760381375208269, 9.757292720154265, 8.810272195528796, 7.773374103097408, 6.778138950002425, 5.931726637884565, 4.909909855107908, 4.000978838438082, 3.0705574062161514, 3.93147439010529, 4.894207130474232, 5.829764541424863, 6.790421775968898, 7.761546149485962, 8.73718179829206, 9.688344159332509, 10.744047270395502, 11.792631132505436, 12.691086826778887, 12.753947422829555, 11.710791583420349, 10.68740338079121, 9.704784893303799, 8.679755874889288, 7.7052711471794915, 6.9052941323932515, 5.905974440898143, 5.053914263418704, 4.106507645266227, 4.946219098838853, 5.853344789271989, 6.798354912324571, 7.777597694858155, 8.741170354693478, 9.692651914797995, 10.710366024768694, 11.651218354212089, 12.595785270546449, 13.561783474921327, 13.608893303235064, 12.597208317499888, 11.636556352833972, 10.589548381313927, 9.64125319920991, 8.647587048441666, 7.840213952539367, 6.876574073677078, 6.084207693385737, 5.179426302749159, 5.965702472086391, 6.840328644005597, 7.726329731271022, 8.655748567742767, 9.683465548546613, 10.661194271651606, 11.650459610737846, 12.66320523782315, 13.662209868063789, 14.48862191564317], [14.492155728789983, 13.673532225357933, 12.69803757663337, 11.726897914458508, 10.69866327482746, 9.743549463780601, 8.72165260732953, 7.8103318052177375, 6.943832125685693, 6.077221618382537, 7.087811973057794, 8.073266482809617, 8.787403130484037, 9.72690554301033, 10.547132512835544, 11.53561013295644, 12.492995611930032, 13.517368209158308, 14.493389755947154, 15.502333360750024, 15.51106150643656, 14.708049517596338, 13.688550454937374, 12.768699315438054, 11.711986008607667, 10.722751382097856, 9.671779310949718, 8.859979761079728, 7.999377932078783, 7.114029215570364, 8.030879825820433, 8.990921899525585, 9.82447725459444, 10.689369133337703, 11.474260508406198, 12.541490937505078, 13.418443289419336, 14.346765134083514, 15.40201605833003, 16.447141305483278, 16.50256015987356, 15.561405020050668, 14.604645428222076, 13.638479708058423, 12.639639275251092, 11.70571201278296, 10.674509410285237, 9.91927264455447, 9.015815123784888, 8.136626393745953, 9.051725519284878, 9.982518508074048, 10.839692880269972, 11.745245054985588, 12.422553087999027, 13.361186123525151, 14.311044856729897, 15.360166979108781, 16.327414209413195, 17.27924353908503, 17.50990902419217, 16.57249495917187, 15.588489349532155, 14.694280939720304, 13.65502142817093, 12.629579469248222, 11.68109869179565, 10.986340804544025, 10.031733577576182, 9.195302113390769, 10.110784332038252, 10.970883373894695, 11.79921577019798, 12.732981354202344, 13.442459043940621, 14.37226239211153, 15.240078767232555, 16.175196843039263, 17.168775996200804, 18.177358680122882, 18.435484675615783, 17.51150888114952, 16.64447098907709, 15.646785796187366, 14.63728334993127, 13.685538162412225, 12.735068762855404, 12.050208377246683, 11.023859687700554, 10.261840749235464, 9.94234665580697, 10.860768465251923, 11.895386601268271, 12.815003058219316, 13.658325495269228, 14.680587871717961, 15.642297293925697, 16.5711606437029, 17.583839861892386, 18.51040376032622, 18.286558089557342, 17.308109438209712, 16.358871541774686, 15.433484624130845, 14.399561129081548, 13.625371067742737, 12.688195613951674, 11.719665852754853, 10.709686299954729, 9.782152488325014, 8.970381763221537, 9.89983884139834, 10.890357812936502, 11.796863542971138, 12.732463880251746, 13.71170140294955, 14.626037163119781, 15.584072052581938, 16.636157834434826, 17.449732260272654, 17.342527346762292, 16.328361074243332, 15.367178597651213, 14.40606696311535, 13.428789391430657, 12.67745432705133, 11.748734842022648, 10.742682158385023, 9.782942951595036, 8.840398580403052, 7.948917677254063, 8.875953234451826, 9.853865952876003, 10.783194374496354, 11.779983956822708, 12.731681838671516, 13.663783518484722, 14.608210115182043, 15.616602408738435, 16.520301930509813, 16.3312959734777, 15.362272300331558, 14.384867520499776, 13.374990017533868, 12.40343354255126, 11.651303500114333, 10.772443395131768, 9.761300174451858, 8.820023186709715, 7.898924543792394, 6.987611972279945, 7.944023828486211, 8.82070498216316, 9.779508667381858, 10.706625488707601, 11.677622653615742, 12.60720925371638, 13.546164578068403, 14.597218793225585, 15.58321570063527, 15.361876832840828, 14.34167550588366, 13.347974822724224, 12.419937231546198, 11.472672914052229, 10.608972390639247, 9.705914503121782, 8.757252152444268, 7.800659374066392, 6.860710043742314, 5.975568780568173, 6.9216609958682165, 7.856818720927418, 8.7514405147163, 9.780751683623276, 10.762650752303182, 11.690368334998746, 12.763943373332719, 13.830760990149932, 14.797794955098553, 14.423797130080603, 13.418658054818412, 12.447954421457986, 11.466829344958793, 10.508940462364917, 9.665333926345248, 8.722707338980673, 7.7805725453762555, 6.737094657369042, 5.91494956642926, 5.006977783755541, 5.932151242492584, 6.871111477571452, 7.8177200179019835, 8.804706610134911, 9.800533047838774, 10.739916483140686, 11.814175111490204, 12.838868278332937, 13.817106429915524, 13.570279333394671, 12.589351181261534, 11.645231515178608, 10.575865853987377, 9.575197815072505, 8.601569945436381, 7.674710702287872, 6.774010311975894, 5.808130860091943, 4.9542412046778885, 4.031587982696256, 4.93880360436627, 5.885019374531821, 6.95670289325922, 7.956044188034086, 8.906852734729192, 9.891166135451714, 10.902788211578766, 11.822349543679923, 12.800401697243165, 12.614221496748065, 11.686268384802423, 10.801291520961595, 9.762671763443397, 8.715284037569662, 7.645536269888436, 6.712873135357363, 5.859175271325975, 4.85736685446194, 3.932245524209934, 3.080238424398728, 3.8838345656169855, 4.9548291414743115, 5.9604388968475766, 6.995382756227349, 7.944575021611998, 8.985929479633421, 9.912743308146764, 10.886996620571791, 11.914413985755292, 11.722669358783953, 10.71670480188007, 9.796530358107093, 8.770441570492942, 7.705132782335166, 6.695381226958463, 5.765611168534943, 4.816759397644374, 3.949708283155231, 2.9298976364074756, 2.0307709733326327, 2.9562973034722617, 3.9433746349967707, 4.986116758262067, 5.96915345994876, 7.0125564062614885, 7.965155680844792, 8.95385606413947, 10.003575187088883, 10.973144542336449, 10.748502001031225, 9.77643723230622, 8.755854889016046, 7.787735389257193, 6.764001473387619, 5.749339354815646, 4.8006876312159665, 3.8630132351176365, 2.9914517213162064, 1.9987731777834288, 0.9713190516165572, 2.014760417207174, 3.0506294008504424, 4.065414321556674, 5.033210579055195, 6.055619211994175, 7.039326718932843, 8.028014096017422, 9.068558714760156, 10.01512815529411, 9.775620050129987, 8.834094669284427, 7.787633388265158, 6.791438559026229, 5.866077063041197, 4.87003080511743, 3.9071076722533964, 2.882612712963194, 1.9273228218645824, 0.9586449990711577, 0.0, 1.0516065922056674, 2.0743341303867044, 3.1422450345578024, 4.0690444822100575, 5.129711258881787, 6.143863969507445, 7.158404695954101, 8.102310475243225, 9.139471129016796, 10.834864682473171, 9.834761201634356, 8.782284554697506, 7.722308874239054, 6.8679628244370114, 5.802057174837018, 4.842193153138806, 3.8427752575716116, 2.9873676372725506, 1.9638008038192347, 1.0034158565506865, 2.035180000899584, 3.0116319829172324, 4.051460735719402, 5.020483376150084, 6.013056523491489, 6.992680836528656, 7.951637468762175, 9.022897298519649, 10.009346296680828, 11.73362786902609, 10.787807039928644, 9.740180922574641, 8.69497477714618, 7.782370172072833, 6.763569609464302, 5.82903272835043, 4.80612187354829, 3.9632767844026278, 2.962874539782385, 1.9569804918373646, 2.979113305882218, 3.9396377792241526, 4.952058685957561, 5.952092626561768, 6.9144109576991815, 7.9509717786606, 8.970813234092631, 9.956128773962392, 10.931352188219282, 12.69973451729537, 11.719026374279427, 10.715937719225423, 9.768917194599954, 8.732019102168566, 7.736783949073583, 6.890371636955723, 5.868554854179066, 4.950200420701729, 4.019778988479798, 2.9728293910341326, 3.935562131403074, 4.871119542353705, 5.83177677689774, 6.8029011504148045, 7.778536799220903, 8.729699160261353, 9.785402271324346, 10.83398613343428, 11.779939481289913, 13.597938693433372, 12.669436582491507, 11.646048379862368, 10.663429892374957, 9.638400873960446, 8.66391614625065, 7.863939131464409, 6.864619439969301, 6.003135845682351, 5.0557292275298735, 3.987574099767696, 4.894699790200831, 5.839709913253413, 6.818952695786997, 7.782525355622321, 8.734006915726837, 9.751721025697538, 10.692573355140933, 11.637140271475293, 12.603138475850171, 14.567538302306222, 13.555853316571046, 12.59520135190513, 11.548193380385085, 10.599898198281068, 9.606232047512824, 8.798858951610525, 7.835219072748236, 7.033429275649384, 6.078624622880508, 5.007057473015234, 5.881683644934439, 6.767684732199864, 7.69710356867161, 8.724820549475455, 9.702549272580448, 10.691814611666688, 11.704560238751993, 12.703564868992633, 13.529976916572014], [13.471084277151219, 12.652460773719168, 11.676966124994605, 10.705826462819745, 9.677591823188697, 8.722478012141838, 7.744821056846131, 6.83350025473434, 6.0474580119487635, 7.071884289694369, 8.090809983850612, 9.081227338201868, 9.839009722689704, 10.778512135215998, 11.598739105041211, 12.587216725162108, 13.5446022041357, 14.568974801363975, 15.507999505461367, 14.481261909111259, 14.489990054797795, 13.686978065957573, 12.66747900329861, 11.747627863799291, 10.690914556968902, 9.701679930459093, 8.69494776046632, 7.883148210596331, 7.103003818341853, 8.108691886882195, 9.03387783661325, 9.9939199103184, 10.876083846800107, 11.74097572554337, 12.525867100611865, 13.593097529710745, 14.470049881625004, 15.39837172628918, 16.453622650535696, 15.535770399058121, 15.481488708234794, 14.540333568411903, 13.583573976583311, 12.617408256419658, 11.618567823612327, 10.72888046229956, 9.69767785980184, 8.942441094071071, 8.119441010047957, 9.126695730578952, 10.054723530077695, 10.985516518866865, 11.89129947247564, 12.796851647191255, 13.474159680204695, 14.412792715730818, 15.362651448935564, 16.41177357131445, 17.37902080161886, 16.52693806181837, 16.4888375725534, 15.551423507533105, 14.56741789789339, 13.681962623525383, 12.678189877687531, 11.652747918764824, 10.704267141312252, 10.009509254060626, 9.13535946383925, 10.112084854673714, 11.11253590037062, 10.917410003535437, 11.881313284631563, 12.843861724987313, 13.717721977866074, 14.761752306834952, 15.690270933275084, 16.625389009081793, 17.610269880122573, 17.511467286499553, 17.414413223977014, 16.490437429510756, 15.623399537438324, 14.669954245703968, 13.660451799447872, 12.708706611928827, 11.758237212372006, 11.073376826763285, 10.127485573963623, 11.071730047077592, 10.802937882262421, 9.978040303122887, 11.012658439139237, 11.90517731470162, 12.738892731636492, 13.761155108085225, 14.722864530292961, 15.651727880070164, 16.66440709825965, 17.590970996693486, 17.480642555900594, 17.516468911180972, 16.567231014745946, 15.641844097102105, 14.603014636068249, 13.740088403024673, 12.80291294923361, 12.035683693897749, 11.059438931598809, 10.688032196627528, 9.830972989676988, 9.017110679269305, 10.007629650807466, 10.887037799453442, 11.81303111661901, 12.792268639316815, 13.706604399487045, 14.6646392889492, 15.716725070802088, 16.53029949663992, 16.600010558144557, 17.379967666448998, 16.41878518985688, 15.457673555321016, 14.480395983636322, 13.647949323792098, 12.706327762596741, 11.659231864479066, 10.69151480004745, 9.746278288705566, 8.809508903709514, 7.993225072322791, 8.944040209358308, 9.873368630978657, 10.860551193189972, 11.81224907503878, 12.744350754851986, 13.688777351549305, 14.697169645105697, 15.600869166877079, 15.64625698925938, 16.413878892537223, 15.436474112705442, 14.426596609739534, 13.455040134756926, 12.654019254398335, 11.74464180555624, 10.677849880545901, 9.72859503516213, 8.80480425209491, 7.848203198735394, 7.061295666357177, 7.910879238645466, 8.869682923864161, 9.787192725074865, 10.758189889983006, 11.687776490083644, 12.626731814435667, 13.677786029592848, 14.663782937002534, 14.676837848622505, 15.393282098089326, 14.399581414929889, 13.471543823751864, 12.524279506257894, 11.61168814492325, 10.678112913546254, 9.673801858538312, 8.709231222518806, 7.769281892194727, 6.836160007023622, 6.038932833739182, 6.946992977409722, 7.8416147711986035, 8.86131891999054, 9.824531158033489, 10.752248740729053, 11.825823779063025, 12.875278958040916, 13.747544625938982, 13.73875814586228, 14.470264647024077, 13.499561013663651, 12.518435937164458, 11.560547054570582, 10.66804968062925, 9.694905749405144, 8.752770955800727, 7.7092930677935145, 6.844776549119796, 5.867569010210991, 5.04942308036355, 5.961285734053756, 6.9078942743842875, 7.866587015865217, 8.862413453569081, 9.801796888870992, 10.876055517220511, 11.838382214236727, 12.766856100755954, 12.692536169071372, 13.6409577734672, 12.696838107384274, 11.627472446193043, 10.62680440727817, 9.653176537642047, 8.72631729449354, 7.746208722400366, 6.7803292705164155, 5.8936442114216625, 4.892179209151705, 3.991049379358042, 4.9372651495235935, 6.0089486682509925, 6.909353786575079, 7.860162333270184, 8.844475733992706, 9.856097810119758, 10.772099214520352, 11.750151368083595, 11.819769034988639, 12.73787497700809, 11.85289811316726, 10.814278355649062, 9.766890629775327, 8.697142862094102, 7.76447972756303, 6.860666034224939, 5.829565264886413, 4.904443934634407, 3.9408296508541776, 2.9360803406087577, 4.007074916466084, 5.012684671839349, 5.948692354768342, 6.897884620152991, 7.935679150473852, 8.862492978987195, 9.836746291412222, 10.864163656595723, 10.940340475700113, 11.768311394085737, 10.84813695031276, 9.82204816269861, 8.756739374540834, 7.74698781916413, 6.81721776074061, 5.868365989850041, 4.921906693579704, 3.9020960468319483, 2.934069408603663, 2.008543078464034, 2.983006667411221, 4.025748790676517, 4.917546867743093, 5.960949814055821, 6.913549088639125, 7.9022494719338034, 8.951968594883216, 9.921537950130782, 9.940998012585156, 10.828043824511887, 9.807461481221713, 8.83934198146286, 7.8156080655932865, 6.800945947021313, 5.852294223421634, 4.914619827323303, 4.043058313521874, 3.0503797699890964, 2.0229256438222247, 1.0279686190866943, 2.046820941455598, 3.06160586216183, 3.9816039868495277, 5.004012619788508, 5.987720126727176, 6.976407503811755, 8.016952122554489, 8.963521563088444, 9.03488374968383, 9.885701261490095, 8.839239980470825, 7.843045151231896, 6.917683655246864, 5.921637397323098, 4.958714264459063, 3.9342193051688614, 2.9789294140702496, 2.010251591276825, 1.0516065922056674, 0.0, 1.0227275381810368, 2.0906384423521347, 3.0174378900043903, 4.078104666676119, 5.092257377301777, 6.106798103748433, 7.050703883037558, 8.087864536811129, 10.003583401051017, 10.886367793840023, 9.833891146903174, 8.773915466444722, 7.919569416642679, 6.853663767042685, 5.893799745344473, 4.894381849777279, 4.038974229478217, 3.0154073960249024, 2.0319743164112274, 0.9835734086939167, 1.9600253907115648, 2.9998541435137343, 3.9688767839444163, 4.961449931285822, 5.941074244322989, 6.9000308765565075, 7.971290706313981, 8.957739704475161, 10.901443817923482, 11.839413632134313, 10.791787514780308, 9.746581369351848, 8.8339767642785, 7.815176201669969, 6.880639320556098, 5.857728465753957, 5.014883376608295, 4.0144811319880525, 2.9855389516979054, 2.027227080520002, 2.918566327585388, 3.9309872343187964, 4.9310211749230035, 5.893339506060417, 6.929900327021835, 7.919206641886963, 8.904522181756723, 9.879745596013613, 11.708865338205824, 12.769518588433085, 11.76754431143109, 10.820523786805621, 9.783625694374233, 8.78839054127925, 7.94197822916139, 6.920161446384733, 5.97875888056227, 5.048337448340339, 4.001387850894673, 3.0391880176661443, 3.8500480907149406, 4.810705325258976, 5.78182969877604, 6.757465347582138, 7.708627708622587, 8.764330819685581, 9.812914681795515, 10.758868029651149, 12.576867241794607, 13.63498071257117, 12.697654972068035, 11.715036484580624, 10.690007466166113, 9.715522738456317, 8.915545723670077, 7.9162260321749685, 7.031694305542892, 6.063318158283989, 4.991721899640046, 3.9983256764639012, 4.862878362770016, 5.8421211453036, 6.761453903983556, 7.712935464088073, 8.730649574058774, 9.671501903502168, 10.616068819836528, 11.582067024211407, 13.567752444980869, 14.579437430716045, 13.646807944110796, 12.59979997259075, 11.651504790486733, 10.657838639718491, 9.850465543816192, 8.886825664953903, 8.061987735509925, 7.081622633673327, 6.010055483808053, 4.985309531197509, 5.790853181716467, 6.720272018188212, 7.703749097836691, 8.681477820941684, 9.670743160027923, 10.683488787113228, 11.682493417353868, 12.50890546493325], [12.448356738970183, 11.629733235538133, 10.65423858681357, 9.68309892463871, 8.654864285007662, 7.699750473960803, 6.722093518665095, 5.810772716553304, 6.750429853752404, 7.77485613149801, 8.828168807679013, 9.81858616203027, 10.732307986232671, 11.671810398758963, 12.589913254796686, 13.578390874917583, 14.535776353891174, 15.471333662174217, 14.48527196728033, 13.458534370930224, 13.46726251661676, 12.664250527776536, 11.644751465117572, 10.724900325618256, 9.668187018787869, 8.678952392278058, 7.672220222285284, 6.8604206724152945, 7.805975660145494, 8.811663728685836, 9.765059417115715, 10.725101490820865, 11.769382110343074, 12.634273989086335, 13.51704125036734, 14.58427167946622, 15.461224031380478, 16.389545876044657, 15.533361963112858, 14.513042860877086, 14.45876117005376, 13.51760603023087, 12.560846438402278, 11.594680718238624, 10.595840285431294, 9.706152924118527, 8.674950321620804, 7.919713555890036, 8.822412851851599, 9.829667572382593, 10.78590511058016, 11.71669809936933, 12.123314922688479, 13.004006101820337, 13.71490039562663, 14.653533431152754, 15.596577305596705, 16.630369504693984, 16.45603985330917, 15.504210523637337, 15.466110034372369, 14.528695969352071, 13.544690359712357, 12.65923508534435, 11.655462339506496, 10.630020380583789, 9.681539603131217, 8.98678171587959, 9.838331305642892, 10.815056696477356, 11.815507742174262, 11.856223385826098, 11.16379203276047, 12.016269802603581, 12.694994439685036, 13.739024768653914, 14.667543395094047, 15.602661470900756, 16.587542341941532, 16.488739748318523, 16.39168568579598, 15.467709891329722, 14.60067199925729, 13.647226707522933, 12.637724261266836, 11.685979073747792, 10.73550967419097, 10.05064928858225, 10.830457415767265, 11.774701888881234, 11.74175126455308, 10.916853685413548, 10.175456236602797, 11.044116602268389, 11.716165193455454, 12.738427569904188, 13.700136992111924, 14.629000341889126, 15.641679560078613, 16.56824345851245, 16.457915017719557, 16.493741372999935, 15.544503476564909, 14.61911655892107, 13.580287097887213, 12.717360864843638, 11.780185411052575, 11.012956155716713, 11.76241077340245, 11.626845578918187, 10.769786371967648, 9.955924061559966, 9.148683267879635, 10.02597708702021, 10.790303578437973, 11.769541101135777, 12.683876861306008, 13.641911750768163, 14.69399753262105, 15.507571958458882, 15.57728301996352, 16.591455068919338, 16.61832355747751, 15.61995190118737, 14.551058835538104, 13.687674306922757, 12.842396087267515, 12.051596918517497, 11.630328182338108, 10.685091670996226, 9.748322286000173, 8.932038454613451, 8.082979496925077, 9.012307918545426, 9.837823655008934, 10.789521536857743, 11.721623216670949, 12.666049813368268, 13.67444210692466, 14.578141628696041, 14.623529451078346, 15.623988450494881, 16.416919589429916, 15.407042086464006, 14.435485611481399, 13.592832636688994, 12.6834551878469, 11.616663262836559, 10.667408417452787, 9.743617634385568, 8.787016581026053, 8.000109048647836, 7.049818526212235, 8.00862221143093, 8.764465186893828, 9.735462351801969, 10.665048951902607, 11.60400427625463, 12.655058491411811, 13.641055398821496, 13.654110310441471, 14.667377952224676, 15.380026891654362, 14.451989300476336, 13.504724982982367, 12.550501527213909, 11.616926295836913, 10.61261524082897, 9.648044604809463, 8.708095274485386, 7.774973389314281, 6.977746216029841, 6.085932264976491, 6.980554058765373, 7.838591381809503, 8.801803619852452, 9.729521202548016, 10.803096240881988, 11.852551419859882, 12.724817087757948, 12.716030607681246, 13.680615385960277, 14.480006490388124, 13.498881413888931, 12.540992531295055, 11.60686306291991, 10.633719131695804, 9.691584338091387, 8.648106450084173, 7.7835899314104555, 6.80638239250165, 5.988236462654209, 5.100225021620525, 6.046833561951057, 6.84385947768418, 7.839685915388045, 8.779069350689957, 9.853327979039477, 10.815654676055694, 11.74412856257492, 11.669808630890339, 12.671416168394554, 13.61553583447748, 12.607917922917515, 11.607249884002643, 10.63362201436652, 9.676564905378589, 8.685022104691026, 7.719142652807075, 6.832457593712322, 5.830992591442365, 4.929862761648701, 4.076204437090363, 5.066435621926874, 5.886626248394043, 6.837434795089147, 7.821748195811669, 8.83337027193872, 9.749371676339319, 10.72742382990256, 10.797041496807603, 11.724994608753246, 12.74288748322819, 11.794723832373535, 10.7473361064998, 9.677588338818575, 8.744925204287503, 7.799479416515598, 6.768378647177072, 5.843257316925066, 4.879643033144837, 3.874893722899417, 3.006520400940702, 4.012130156313967, 4.925964816587306, 5.875157081971954, 6.912951612292817, 7.8397654408061594, 8.814018753231187, 9.841436118414688, 9.917612937519076, 10.904700521604935, 11.870864488493797, 10.844775700879648, 9.779466912721873, 8.769715357345168, 7.839945298921648, 6.829736791913648, 5.860720075870363, 4.840909429122608, 3.872882790894322, 2.947356460754693, 1.9602791292301844, 3.003021252495481, 3.8948193295620563, 4.938222275874785, 5.890821550458089, 6.879521933752767, 7.929241056702178, 8.898810411949745, 8.91827047440412, 9.964432952031085, 10.83018901940275, 9.862069519643898, 8.838335603774324, 7.823673485202351, 6.875021761602671, 5.9373473655043405, 5.065785851702911, 4.073107308170133, 3.0456531820032615, 2.050696157267731, 1.024093403274561, 2.038878323980793, 2.958876448668491, 3.9812850816074707, 4.964992588546139, 5.953679965630718, 6.994224584373452, 7.940794024907406, 8.012156211502793, 8.953681592348353, 9.861967518651863, 8.865772689412934, 7.940411193427901, 6.944364935504135, 5.9814418026401, 4.956946843349899, 4.001656952251287, 3.0329791294578623, 2.0743341303867044, 1.0227275381810368, 0.0, 1.067910904171098, 1.9947103518233533, 3.055377128495082, 4.06952983912074, 5.084070565567396, 6.027976344856521, 7.065136998630092, 8.98085586286998, 9.987904113591027, 10.85661868508421, 9.796643004625759, 8.942296954823716, 7.876391305223723, 6.91652728352551, 5.917109387958316, 5.0617017676592555, 4.03813493420594, 3.0165190059070346, 1.968118098189724, 0.937297852530528, 1.9771266053326977, 2.9461492457633796, 3.9387223931047846, 4.918346706141952, 5.87730333837547, 6.948563168132944, 7.935012166294124, 9.878716279742445, 10.824537108839891, 11.814515052961346, 10.769308907532885, 9.856704302459537, 8.837903739851006, 7.903366858737135, 6.880456003934994, 5.947026544624353, 4.94662430000411, 3.878496076791139, 2.8563632627462856, 1.8958387894043511, 2.9082596961377596, 3.9082936367419663, 4.8706119678793796, 5.907172788840798, 6.896479103705926, 7.881794643575686, 8.857018057832576, 10.686137800024788, 11.74679105025205, 12.765652662276064, 11.818632137650596, 10.774799844129708, 9.779564691034725, 8.835276492704356, 7.813459709927699, 6.8084279699289665, 5.878006537707035, 4.8310569402613694, 3.868324199892428, 2.8273205525339042, 3.7879777870779394, 4.759102160595004, 5.734737809401103, 6.685900170441552, 7.741603281504545, 8.79018714361448, 9.736140491470113, 11.554139703613572, 12.612253174390135, 13.635641377019274, 12.706210634336099, 11.681181615921588, 10.706696888211791, 9.808843987213042, 8.809524295717935, 7.857718322389316, 6.850153429461649, 5.778557170817707, 4.785160947641562, 3.8401508245889797, 4.819393607122564, 5.7387263658025205, 6.690207925907037, 7.707922035877738, 8.648774365321133, 9.593341281655492, 10.559339486030371, 12.545024906799833, 13.55670989253501, 14.517361857200925, 13.590974122346227, 12.64267894024221, 11.649012789473966, 10.743763807359157, 9.78012392849687, 8.88413725697626, 7.838731768801052, 6.7671646189357775, 5.742418666325234, 4.768125643535431, 5.697544480007176, 6.6810215596556555, 7.658750282760647, 8.648015621846886, 9.660761248932193, 10.659765879172832, 11.486177926752214], [11.51023248361373, 10.69160898018168, 9.716114331457117, 8.769443337279428, 7.753188574401037, 6.873231899006836, 6.078240782477218, 6.878683620724401, 7.818340757923502, 8.842767035669107, 9.89607971185011, 10.886497066201366, 11.80021889040377, 12.73972130293006, 13.657824158967784, 14.646301779088681, 15.55758200404604, 14.533209406817765, 13.547147711923877, 12.520410115573771, 12.529138261260307, 11.726126272420084, 10.70662720976112, 9.811244738258974, 8.783218003580195, 7.852433817324091, 7.028367486097407, 7.928331576586392, 8.87388656431659, 9.879574632856933, 10.832970321286812, 11.793012394991962, 12.837293014514172, 13.277211034417428, 13.595282071048363, 14.56811505626415, 15.581944366977579, 15.563534243282044, 14.595237707756405, 13.574918605520633, 13.572860914294033, 12.632637015023196, 11.675877423194605, 10.709711703030951, 9.71087127022362, 8.892033546223638, 8.031097585432926, 8.987624460061134, 9.890323756022696, 10.89757847655369, 11.853816014751256, 12.784609003540426, 13.138026923719286, 12.221335112769543, 12.646989491455534, 13.585622526981657, 14.528666401425609, 15.562458600522888, 15.520635858839572, 14.6129511157759, 14.581141019164695, 13.643726954144398, 12.659721344504684, 11.774266070136676, 10.772708536626505, 9.875362692915015, 9.03768686694334, 10.028795401345562, 10.906242209813989, 11.882967600648453, 12.883418646345358, 12.870935386856905, 12.178504033791278, 11.233598813552787, 11.62708353551394, 12.671113864482818, 13.59963249092295, 14.53475056672966, 15.519631437770435, 15.60377073311085, 15.50671667058831, 14.582740876122049, 13.715702984049617, 12.764472904642941, 11.754970458386845, 10.931321386079018, 10.091656938003092, 11.032360337284967, 11.898368319938362, 12.84261279305233, 12.756463265583887, 11.931565686444355, 11.190168237633603, 10.261445613217594, 10.648254289284358, 11.670516665733091, 12.632226087940827, 13.56108943771803, 14.573768655907516, 15.500332554341352, 15.390004113548462, 15.610940981464557, 14.661703085029531, 13.736362756041078, 12.697533295007222, 11.982125912423378, 11.136332674864697, 11.99466720441943, 12.830321677573547, 12.641557579948994, 11.784498372998454, 10.970636062590772, 10.163395268910442, 9.243306097969416, 9.722392674266876, 10.70163019696468, 11.615965957134911, 12.574000846597066, 13.626086628449954, 14.439661054287786, 14.509372115792424, 15.523544164748243, 15.735523165942134, 14.73719809830738, 13.668305032658113, 12.952439354502497, 12.198543351079637, 13.033307967220214, 12.645040183368915, 11.699803672027032, 10.76303428703098, 9.946750455644258, 9.097691497955884, 8.229636929494632, 8.769912750837838, 9.721610632686646, 10.653712312499852, 11.598138909197171, 12.606531202753564, 13.510230724524945, 13.555618546907246, 14.556077546323781, 15.552329640201807, 15.665217356520117, 14.69366088153751, 13.978590181439493, 13.174834797970517, 12.631375263867366, 11.682120418483594, 10.758329635416375, 9.80172858205686, 9.014821049678643, 8.064530527243042, 7.225951222380136, 7.696554282722731, 8.667551447630872, 9.59713804773151, 10.536093372083533, 11.587147587240715, 12.5731444946504, 12.58619940627037, 13.599467048053576, 14.562565741588294, 15.466701301507143, 14.519436984013174, 13.565213528244717, 12.631638296867722, 11.627327241859776, 10.66275660584027, 9.722807275516193, 8.789685390345088, 7.992458217060648, 7.100644266007298, 6.197883069714579, 6.770680477638406, 7.733892715681355, 8.66161029837692, 9.735185336710892, 10.784640515688782, 11.656906183586848, 11.648119703510146, 12.612704481789176, 13.529590775603, 14.510715852102194, 13.555704532325862, 12.621575063950718, 11.648431132726612, 10.706296339122195, 9.662818451114981, 8.798301932441262, 7.821094393532457, 7.002948463685016, 6.114937022651332, 5.264162572900263, 5.775948573513083, 6.771775011216947, 7.7111584465188585, 8.785417074868377, 9.747743771884593, 10.67621765840382, 10.601897726719239, 11.603505264223454, 12.54762493030638, 13.616990591497611, 12.62196188503345, 11.648334015397326, 10.691276906409396, 9.699734105721832, 8.733854653837883, 7.847169594743129, 6.845704592473171, 5.944574762679508, 5.09091643812117, 4.1925052488332195, 4.818715344222945, 5.76952389091805, 6.753837291640571, 7.765459367767623, 8.681460772168219, 9.65951292573146, 9.729130592636503, 10.657083704582146, 11.67497657905709, 12.713596336575286, 11.762048107530607, 10.692300339849382, 9.75963720531831, 8.814191417546404, 7.783090648207879, 6.857969317955873, 5.894355034175644, 4.889605723930224, 4.021232401971508, 3.1381997832203132, 3.858053912416208, 4.807246177800857, 5.845040708121719, 6.771854536635061, 7.746107849060087, 8.773525214243588, 8.849702033347981, 9.836789617433837, 10.89017461191057, 11.874433704567096, 10.84737781689297, 9.837626261516267, 8.871599235732315, 7.844448792944455, 6.87543207690117, 5.855621430153414, 4.887594791925129, 3.9620684617854995, 2.9749911302609906, 2.072486437599091, 2.8269084253909584, 3.8703113717036866, 4.82291064628699, 5.811611029581669, 6.86133015253108, 7.830899507778646, 7.8503595702330236, 8.896522047859987, 9.917104391150161, 10.885223890909014, 9.906246507945422, 8.891584389373449, 7.942932665773769, 7.005258269675439, 6.133696755874008, 5.141018212341232, 4.113564086174359, 3.074674387948635, 2.038805404305367, 1.0240204835991351, 1.8909655444973927, 2.9133741774363733, 3.897081684375041, 4.88576906145962, 5.926313680202354, 6.87288312073631, 6.944245307331695, 7.885770688177255, 8.932231969196524, 9.928426798435453, 9.008322097598999, 8.012275839675233, 7.049352706811199, 6.024857747520996, 5.069567856422385, 4.10089003362896, 3.142245034557802, 2.0906384423521347, 1.067910904171098, 0.0, 0.9267994476522554, 1.9874662243239842, 3.0016189349496427, 4.016159661396299, 4.9600654406854225, 5.997226094458994, 7.912944958698883, 8.919993209419928, 9.926883135628872, 10.859297113648278, 10.010207858994814, 8.94430220939482, 7.9844381876966075, 6.9850202921294136, 6.129612671830353, 5.106045838377037, 4.084429910078132, 3.036029002360822, 2.005208756701626, 1.074880246937971, 1.8782383415922814, 2.8708114889336867, 3.850435801970854, 4.809392434204373, 5.880652263961847, 6.867101262123026, 8.810805375571347, 9.756626204668793, 10.804252322022798, 11.831963016555404, 10.924615206630635, 9.905814644022104, 8.971277762908233, 7.948366908106092, 7.014937448795451, 6.014535204175209, 4.946406980962237, 3.9242741669173835, 2.963749693575449, 2.018898377644341, 2.893041116399368, 3.8437478513815315, 4.849734722385486, 5.828568199534828, 6.813883739404589, 7.789107153661478, 9.637079703575763, 10.687845539019575, 11.715729504551948, 12.662750029177417, 11.842710748300807, 10.847475595205823, 9.903187396875454, 8.881370614098797, 7.876338874100065, 6.945917441878134, 5.898967844432468, 4.936235104063526, 3.8952314567050017, 3.027048617385965, 3.932583585641037, 4.796613554044651, 5.7477759150851, 6.803479026148093, 7.741129047165455, 8.687082395021088, 10.61601544825712, 11.666827790935894, 12.690215993565033, 13.666770953247537, 12.749092520092686, 11.77460779238289, 10.87675489138414, 9.877435199889034, 8.925629226560414, 7.918064333632747, 6.846468074988804, 5.853071851812659, 4.908061728760077, 4.078275089694319, 4.912207790848553, 5.752083670550586, 6.769797780521286, 7.710650109964681, 8.65521702629904, 9.621215230673918, 11.60690065144338, 12.618585637178557, 13.579237601844472, 14.626245573364518, 13.710589844413306, 12.716923693645064, 11.811674711530255, 10.848034832667969, 9.952048161147356, 8.906642672972149, 7.835075523106875, 6.810329570496331, 5.836036547706528, 5.053691743819299, 5.854502984701688, 6.720626027404196, 7.709891366490435, 8.72263699357574, 9.72164162381638, 10.548053671395762], [10.583433035961475, 9.764809532529425, 8.789314883804861, 7.842643889627173, 6.826389126748781, 5.94643245135458, 6.9529445436000605, 7.805483068376657, 8.745140205575758, 9.769566483321363, 10.822879159502365, 11.813296513853622, 12.727018338056023, 13.666520750582315, 13.595610618966761, 14.584088239087658, 14.630782556393784, 13.606409959165509, 12.620348264271623, 11.593610667921515, 11.602338813608052, 10.79932682476783, 9.779827762108866, 8.884445290606719, 7.85641855592794, 6.925634369671835, 7.903071247220249, 8.855131024238649, 9.800686011968848, 10.80637408050919, 11.75976976893907, 12.71981184264422, 13.764092462166426, 13.621188886844674, 12.668482623396107, 13.641315608611894, 14.655144919325323, 14.636734795629788, 13.668438260104152, 12.648119157868377, 12.646061466641779, 11.705837567370939, 10.749077975542349, 9.782912255378696, 8.784071822571365, 7.965234098571383, 8.90580134655577, 9.91442390771339, 10.817123203674953, 11.824377924205947, 12.780615462403514, 13.711408451192684, 13.636014730021854, 12.69448881706504, 11.720190043803278, 12.658823079329402, 13.601866953773353, 14.635659152870632, 14.593836411187318, 13.686151668123644, 13.654341571512438, 12.71692750649214, 11.732921896852428, 10.84746662248442, 9.845909088974249, 8.94856324526276, 9.897044022715331, 10.888152557117554, 11.833041657466246, 12.80976704830071, 13.810218093997616, 13.483160024532392, 12.676491840093846, 11.713943399738096, 10.700284087861684, 11.744314416830562, 12.672833043270694, 13.607951119077404, 14.592831990118182, 14.676971285458592, 14.579917222936052, 13.655941428469792, 12.788903536397363, 11.837673456990686, 10.82817101073459, 10.004521938426763, 10.951014093775084, 11.891717493056959, 12.825167767590619, 13.769412240704588, 13.481511694943702, 12.543790324119842, 11.729135513598036, 10.741790199402903, 9.721454841632102, 10.743717218080835, 11.705426640288572, 12.634289990065774, 13.646969208255262, 14.573533106689096, 14.463204665896207, 14.684141533812303, 13.734903637377277, 12.809563308388823, 11.770733847354967, 11.055326464771122, 11.992501918562185, 12.854024360191422, 13.757121125225805, 13.455693694013743, 12.509546802358269, 11.58286070026626, 10.702362544874875, 9.773403596539751, 8.79559322661462, 9.774830749312425, 10.689166509482655, 11.647201398944812, 12.6992871807977, 13.51286160663553, 13.582572668140168, 14.596744717095987, 14.80872371828988, 13.810398650655124, 12.741505585005857, 12.025639906850241, 12.967261468045598, 13.892665122992206, 13.470823742076654, 12.525587230734772, 11.488082716390794, 10.558975093319745, 9.706302051914388, 8.801610074688123, 7.843113303185582, 8.794811185034389, 9.726912864847597, 10.671339461544918, 11.67973175510131, 12.58343127687269, 12.62881909925499, 13.629278098671525, 14.625530192549551, 14.738417908867861, 13.766861433885254, 13.051790733787238, 13.943552914936477, 13.457158822575105, 12.507903977191333, 11.584113194124114, 10.6275121407646, 9.62704568735413, 8.673141081201546, 7.797924367573627, 6.769754835070476, 7.740751999978616, 8.670338600079255, 9.609293924431277, 10.660348139588459, 11.646345046998144, 11.659399958618115, 12.672667600401322, 13.63576629393604, 14.563803885114066, 14.697622062384285, 14.094121843262323, 13.48036898995223, 12.453110800567515, 11.48854016454801, 10.548590834223932, 9.615468949052827, 8.647901655498533, 7.709254819965803, 6.76985621490807, 5.84388102998615, 6.807093268029099, 7.734810850724664, 8.808385889058636, 9.857841068036528, 10.730106735934593, 10.72132025585789, 11.685905034136923, 12.602791327950746, 13.58391640444994, 14.482503979978118, 13.51349703940422, 12.540353108180113, 11.598218314575696, 10.554740426568483, 9.624085491149001, 8.646877952240196, 7.721704493503153, 6.782744258424286, 5.836135718093754, 4.849149125860827, 5.844975563564692, 6.784358998866603, 7.858617627216122, 8.82094432423234, 9.749418210751564, 9.675098279066983, 10.6767058165712, 11.620825482654126, 12.690191143845357, 13.548761332685705, 12.575133463049582, 11.61807635406165, 10.626533553374086, 9.660654101490136, 8.773969042395384, 7.772504040125426, 6.871374210331763, 6.017715885773425, 4.957627459012496, 3.8919158965706897, 4.842724443265794, 5.8270378439883155, 6.838659920115368, 7.754661324515963, 8.732713478079205, 8.80233114498425, 9.730284256929892, 10.748177131404836, 11.786796888923032, 12.688847555182862, 11.619099787501638, 10.686436652970565, 9.74099086519866, 8.709890095860134, 7.784768765608128, 6.821154481827898, 5.8164051715824785, 4.948031849623764, 3.966198324143725, 2.9312544647639522, 3.8804467301486008, 4.918241260469463, 5.8450550889828055, 6.819308401407832, 7.846725766591333, 7.9229025856957245, 8.909990169781581, 9.963375164258315, 10.94763425691484, 11.774177264545227, 10.764425709168522, 9.798398683384569, 8.771248240596709, 7.802231524553425, 6.782420877805669, 5.814394239577384, 4.888867909437755, 3.9017905779132462, 2.970539991496957, 1.9001089777387028, 2.943511924051431, 3.8961111986347348, 4.884811581929413, 5.934530704878824, 6.904100060126391, 6.923560122580768, 7.9697226002077315, 8.990304943497906, 9.958424443256758, 10.833045955597678, 9.818383837025705, 8.869732113426025, 7.9320577173276945, 7.060496203526264, 6.067817659993487, 5.040363533826615, 4.0014738356008905, 2.9656048519576226, 1.9508199312513905, 0.9641660968451373, 1.9865747297841176, 2.9702822367227855, 3.9589696138073647, 4.999514232550099, 5.946083673084054, 6.017445859679439, 6.958971240524999, 8.005432521544268, 9.001627350783197, 9.926988846768229, 8.939075287327489, 7.976152154463454, 6.951657195173252, 5.99636730407464, 5.027689481281215, 4.0690444822100575, 3.0174378900043903, 1.9947103518233533, 0.9267994476522554, 0.0, 1.0606667766717288, 2.074819487297387, 3.089360213744043, 4.033265993033167, 5.070426646806738, 6.986145511046628, 7.993193761767673, 9.000083687976616, 9.932497665996022, 10.93700730664707, 9.871101657047076, 8.911237635348863, 7.911819739781669, 7.056412119482609, 6.032845286029293, 5.011229357730388, 3.962828450013077, 2.932008204353881, 1.9495840080608131, 0.951438893940026, 1.9440120412814312, 2.9236363543185986, 3.8825929865521176, 4.953852816309591, 5.940301814470771, 7.884005927919093, 8.829826757016539, 9.877452874370544, 10.905163568903149, 11.837025560816175, 10.83261409167436, 9.898077210560489, 8.875166355758347, 7.941736896447707, 6.941334651827464, 5.873206428614492, 4.851073614569638, 3.8905491412277042, 2.893602138767183, 1.9662416687471127, 2.916948403729276, 3.9229352747332302, 4.901768751882574, 5.887084291752334, 6.862307706009224, 8.710280255923507, 9.761046091367321, 10.788930056899694, 11.735950581525163, 12.76951019595306, 11.774275042858077, 10.829986844527708, 9.808170061751051, 8.80313832175232, 7.8727168895303885, 6.8257672920847225, 5.8630345517157805, 4.822030904357257, 3.9017523785088075, 3.005784137988782, 3.869814106392395, 4.820976467432844, 5.876679578495837, 6.8143295995132, 7.760282947368833, 9.689216000604864, 10.74002834328364, 11.76341654591278, 12.739971505595284, 13.67589196774494, 12.701407240035143, 11.803554339036394, 10.804234647541287, 9.852428674212671, 8.844863781285003, 7.77326752264106, 6.779871299464915, 5.834861176412333, 4.9529788508171615, 3.9854083431962977, 4.82528422289833, 5.842998332869031, 6.7838506623124255, 7.728417578646784, 8.694415783021663, 10.680101203791125, 11.6917861895263, 12.652438154192216, 13.699446125712262, 14.63738929206556, 13.643723141297318, 12.738474159182509, 11.774834280320222, 10.878847608799612, 9.833442120624404, 8.76187497075913, 7.737129018148587, 6.762835995358784, 5.9283955049421415, 4.927703537049433, 5.79382657975194, 6.7830919188381795, 7.795837545923485, 8.794842176164124, 9.621254223743506], [9.666757200018985, 8.848133696586935, 7.872639047862372, 6.925968053684683, 5.909713290806291, 6.864827101853151, 7.892170915471128, 8.844007691336502, 9.783664828535603, 10.808091106281207, 11.86140378246221, 12.851821136813466, 13.78387113778564, 14.723373550311932, 14.581617419293325, 14.184978230423848, 13.714106720451294, 12.689734123223019, 11.703672428329131, 10.676934831979025, 10.685662977665562, 9.88265098882534, 8.863151926166376, 7.967769454664229, 6.93974271998545, 7.844029020170406, 8.842297619091317, 9.834293432884964, 10.839210634928692, 11.844898703469035, 12.798294391898914, 13.758336465604064, 14.817146405331084, 14.607195687171238, 13.654489423722671, 13.179097425875211, 13.9121014553939, 13.720058959687298, 12.75176242416166, 11.731443321925887, 11.729385630699287, 10.789161731428447, 9.832402139599857, 8.866236419436204, 7.867395986628874, 8.880209630972288, 9.845027718426836, 10.86691622785378, 11.855647826634797, 12.862902547165792, 13.819140085363358, 14.749933074152528, 14.622021530348418, 13.680495617391603, 12.706196844129842, 12.196604896592719, 12.839167188874116, 13.872959387971395, 13.677160575244827, 12.769475832181154, 12.737665735569946, 11.800251670549649, 10.816246060909936, 9.930790786541928, 8.929233253031757, 9.863538777663665, 10.812019555116237, 11.80312808951846, 12.78867843967674, 13.765403830511204, 14.76585487620811, 14.469166824858956, 13.66249864042041, 12.69995020006466, 11.686290888188248, 11.18552862800634, 11.910133278371458, 12.845251354178167, 13.794462524361023, 13.7602954495161, 13.66324138699356, 12.7392655925273, 11.872227700454872, 10.920997621048194, 9.911495174792098, 10.919497470827668, 11.86598962617599, 12.806693025457864, 13.780804549801113, 14.725049022915082, 14.467518495270266, 13.529797124446405, 12.7151423139246, 11.727796999729467, 10.707461641958666, 10.124383765900552, 10.911037416617642, 11.839900766394845, 12.848599742498104, 13.614767900379098, 13.504439459586209, 13.767465697869811, 12.818227801434785, 11.892887472446331, 10.854058011412475, 11.88163779858776, 12.818813252378824, 13.768999892592328, 14.712757907436298, 14.441700494340306, 13.495553602684833, 12.568867500592823, 11.688369345201439, 10.759410396866315, 9.781600026941184, 9.155497297132142, 9.890797043725497, 10.848831933187654, 11.900917715040542, 12.554096400325532, 12.62380746183017, 13.601595273860399, 13.892047882347388, 12.893722814712632, 11.824829749063365, 12.85195124066688, 13.793572801862236, 14.807640655393111, 14.456830542403218, 13.511594031061335, 12.474089516717358, 11.544981893646309, 10.692308852240952, 9.787616875014686, 8.829120103512146, 8.088283490413374, 8.928543399090438, 9.87296999578776, 10.881362289344152, 11.624666070562691, 11.618853600523462, 12.619312599939997, 13.615564693818023, 13.82174207292537, 12.850185597942762, 13.878102067603876, 14.769864248753116, 14.443165622901668, 13.493910777517897, 12.570119994450678, 11.613518941091163, 10.613052487680694, 9.65914788152811, 8.78393116790019, 7.7557616353970396, 7.034224305357601, 7.8719691343220966, 8.810924458674119, 9.83629040294999, 10.687579840688146, 10.649434459886587, 11.662702101669794, 12.625800795204512, 13.553838386382537, 13.780946226441793, 14.785490758936609, 14.466375790278795, 13.439117600894079, 12.474546964874573, 11.534597634550495, 10.601475749379391, 9.633908455825097, 8.695261620292367, 7.755863015234634, 6.829887830312714, 6.00580288337236, 6.813819459764447, 7.879670654228929, 8.847875569305, 9.720141237203064, 9.711354757126362, 10.675939535405394, 11.592825829219217, 12.573950905718412, 13.531839788312288, 14.499503839730783, 13.526359908506677, 12.58422511490226, 11.540747226895046, 10.610092291475565, 9.63288475256676, 8.707711293829718, 7.7687510587508495, 6.822142518420318, 5.835155926187391, 5.043685178907952, 5.811124114704345, 6.8853827430538646, 7.81097882550081, 8.739452712020036, 8.665132780335455, 9.666740317839672, 10.610859983922598, 11.680225645113829, 12.680893684028703, 13.598419983067041, 12.641362874079109, 11.649820073391545, 10.683940621507595, 9.797255562412843, 8.795790560142885, 7.894660730349223, 7.015317778066459, 5.94363425933906, 4.8779226968972536, 3.9809755337667854, 4.8470745214763316, 5.858696597603384, 6.744695825784435, 7.722747979347676, 7.79236564625272, 8.720318758198363, 9.738211632673307, 10.776831390191504, 11.807389274102913, 12.642386307519097, 11.709723172988024, 10.764277385216118, 9.733176615877593, 8.808055285625587, 7.844441001845358, 6.839691691599938, 5.957814879843554, 4.952205124470289, 3.917261265090516, 3.0046272538646286, 3.9082757617379347, 4.835089590251277, 5.8093429026763035, 6.8367602678598045, 6.862235809023995, 7.849323393109854, 8.902708387586587, 9.886967480243113, 10.789967646262001, 11.797852074886439, 10.82168520340203, 9.79453476061417, 8.825518044570885, 7.805707397823129, 6.837680759594844, 5.912154429455215, 4.925077097930706, 3.956546791823521, 2.8861157780652666, 1.9335464253199028, 2.886145699903207, 3.8748460831978857, 4.917527232287154, 5.88709658753472, 5.862893345909039, 6.909055823536004, 7.929638166826178, 8.897757666585031, 9.837148084171648, 10.851810202743621, 9.930398890097752, 8.992724493999422, 8.121162980197992, 7.0956558473758395, 6.068201721208967, 5.02476035561835, 3.9888913719750825, 2.9741064512688506, 1.9501728971717012, 0.9259079531123888, 1.9096154600510569, 2.898302837135636, 3.9388474558783706, 4.885416896412325, 4.956779083007711, 5.898304463853272, 6.944765744872541, 7.94096057411147, 8.866322070096501, 9.862368328020267, 9.036818931135182, 8.01232397184498, 7.0570340807463685, 6.0883562579529436, 5.129711258881786, 4.0781046666761185, 3.055377128495082, 1.9874662243239842, 1.0606667766717288, 0.0, 1.0141527106256583, 2.0286934370723144, 2.9725992163614388, 4.00975987013501, 6.016023715350894, 6.9325269850959454, 7.939416911304889, 8.871830889324295, 9.884913177753363, 10.794394697739854, 9.97190441202059, 8.972486516453397, 8.117078896154336, 7.093512062701021, 6.071896134402117, 5.0234952266848065, 3.99267498102561, 3.0102507847325417, 2.0121056706117546, 1.0273362053389414, 2.006960518376109, 2.965917150609628, 3.9916988902255603, 4.97814788838674, 6.959701016810412, 7.905521845907858, 8.897313279182024, 9.844496792231421, 10.776358784144447, 11.795159346752978, 10.958743987232216, 9.935833132430075, 9.002403673119437, 8.002001428499193, 6.933873205286221, 5.911740391241367, 4.951215917899433, 3.954268915438912, 2.9625908989242, 2.0002725677867863, 3.0062594387907406, 3.9850929159400836, 4.962779380643654, 5.938002794900543, 7.785975344814828, 8.83674118025864, 9.864625145791013, 10.811645670416482, 11.757717967993608, 12.752953121088591, 11.886839644257325, 10.865022861480668, 9.859991121481936, 8.929569689260006, 7.88262009181434, 6.919887351445398, 5.8605555273171035, 4.899898292773068, 3.9287739192560034, 2.953138270449905, 3.904300631490355, 4.960003742553348, 5.8900246884045195, 6.835978036260153, 8.772540164662374, 9.81572343217496, 10.839111634804098, 11.815666594486602, 12.821310550034488, 13.680085318265657, 12.86040713876601, 11.861087447270904, 10.890953297172516, 9.88338840424485, 8.811792145600906, 7.818395922424761, 6.873385799372179, 5.914227572498341, 4.9083981244635195, 3.90860838695584, 4.926322496926541, 5.8671748263699355, 6.811741742704294, 7.777739947079173, 9.763425367848635, 10.77511035358381, 11.735762318249726, 12.782770289769772, 13.731065471873789, 14.622401219527832, 13.795326958912126, 12.83168708004984, 11.917372231759458, 10.87196674358425, 9.800399593718977, 8.775653641108432, 7.80136061831863, 6.889644226623321, 5.8506933183166545, 4.87715074380945, 5.8664160828956895, 6.879161709980995, 7.878166340221634, 8.704578387801016], [8.666075502302158, 7.899536517551241, 6.924041868826679, 6.111896285013157, 6.863224023009323, 7.818337834056183, 8.84568164767416, 9.797518423539536, 10.737175560738637, 11.761601838484241, 12.814914514665244, 13.8053318690165, 14.737381869988672, 15.519622514847908, 14.549148974224893, 13.67081050170806, 12.713425022734468, 11.689052425506192, 10.702990730612306, 9.676253134262199, 9.684981279948735, 8.934053809789646, 7.9145547471306825, 7.153697685992704, 7.893253452188482, 8.797539752373439, 9.79580835129435, 10.787804165087996, 11.792721367131726, 12.798409435672067, 13.751805124101946, 14.711847197807096, 15.770657137534116, 15.621348397796895, 14.668642134348328, 13.956391937384963, 13.096974941417509, 12.719377261970472, 11.751080726444835, 10.73076162420906, 10.728703932982462, 9.850688800289937, 8.893929208461346, 8.143484764337195, 8.820906718831907, 9.83372036317532, 10.798538450629868, 11.820426960056812, 12.809158558837831, 13.816413279368826, 14.77265081756639, 15.70344380635556, 15.636174240974075, 14.69464832801726, 13.720349554755499, 12.97389940810247, 12.024040674897725, 13.057832873995004, 12.676478877528002, 11.768794134464327, 11.747051977979748, 10.86177873941114, 9.877773129771425, 9.20803913144292, 9.882743985234791, 10.817049509866697, 11.765530287319269, 12.756638821721491, 13.742189171879772, 14.718914562714236, 15.719365608411142, 15.483319535484611, 14.676651351046067, 13.714102910690317, 12.700443598813905, 12.023525390835198, 11.095006764395066, 12.030124840201776, 12.972972232060364, 12.769681691925902, 12.672627629403362, 11.80079266138879, 10.933754769316359, 10.272557567140494, 10.865005906995131, 11.8730082030307, 12.819500358379022, 13.760203757660896, 14.734315282004145, 15.678559755118114, 15.481671205895921, 14.54394983507206, 13.729295024550257, 12.741949710355124, 11.721614352584323, 10.971889999402508, 10.095910902641252, 11.024774252418455, 12.027109450197445, 12.787787795035113, 12.677459354242224, 12.828992766731298, 11.879754870296273, 11.327604305131564, 11.807568743615509, 12.835148530790796, 13.77232398458186, 14.72251062479536, 15.66626863963933, 15.455853204965962, 14.509706313310488, 13.583020211218479, 12.702522055827096, 11.773563107491972, 10.795752737566842, 10.003003530634098, 9.075670529749107, 10.033705419211262, 11.079427422739883, 11.727116294981547, 11.796827356486185, 12.749997077246277, 12.953574951208875, 12.35502196614706, 12.7783404812664, 13.805461972869915, 14.747083534065272, 15.761151387596144, 15.470983253028875, 14.525746741686993, 13.488242227343013, 12.559134604271964, 11.70646156286661, 10.801769585640345, 9.843272814137803, 8.97997934753529, 8.113416885114049, 9.057843481811368, 10.05987199704349, 10.797685965218706, 10.791873495179477, 11.767714403325876, 12.747365982656511, 13.386098911728542, 13.803696330145796, 14.831612799806912, 15.723374980956152, 15.457318333527326, 14.508063488143554, 13.584272705076335, 12.62767165171682, 11.62720519830635, 10.673300592153767, 9.79808387852585, 8.769914346022697, 7.925920162479516, 7.056842620345707, 7.995797944697729, 9.009310297606005, 9.860599735344161, 9.822454354542602, 10.747117608877979, 11.710216302412697, 12.638253893590722, 13.579987747207785, 14.570773647328696, 15.480528500904452, 14.453270311519736, 13.48869967550023, 12.548750345176153, 11.615628460005048, 10.648061166450756, 9.709414330918024, 8.770015725860292, 7.844040540938372, 6.8974987404942745, 5.998692945788057, 7.064544140252539, 8.020895463961015, 8.89316113185908, 8.884374651782377, 9.760355042613579, 10.677241336427402, 11.658366412926597, 12.616255295520473, 13.627135183034698, 14.540512619132336, 13.598377825527919, 12.554899937520705, 11.624245002101222, 10.647037463192417, 9.721864004455375, 8.782903769376507, 7.836295229045976, 6.849308636813049, 5.935381036029867, 4.995997600727955, 6.070256229077475, 6.983998720156826, 7.912472606676051, 7.838152674991471, 8.751155825047856, 9.695275491130783, 10.764641152322014, 11.765309191236888, 12.738937060873011, 13.655515584704768, 12.663972784017204, 11.698093332133254, 10.811408273038504, 9.809943270768546, 8.908813440974882, 8.029470488692118, 6.957786969964718, 5.892075407522912, 4.995128244392443, 4.031948007499942, 5.043570083626994, 5.917715720440451, 6.895767874003692, 6.908507766966598, 7.804734265406548, 8.822627139881492, 9.861246897399688, 10.793236563477254, 11.842713283836146, 12.698494719859038, 11.778430095841777, 10.747329326503252, 9.822207996251246, 8.858593712471018, 7.853844402225597, 6.971967590469212, 5.966357835095947, 4.931413975716175, 4.018779964490287, 3.0931492477615445, 4.0199630762748875, 4.9823627973323195, 5.968479061451737, 5.914850786398248, 6.835170682484195, 7.888555676960928, 8.872814769617454, 9.775814935636342, 10.78369936426078, 11.75123275303662, 10.808687471239828, 9.839670755196543, 8.819860108448788, 7.851833470220503, 6.926307140080874, 5.939229808556365, 4.970699502449179, 3.900268488690925, 2.947699135945561, 2.0710191859268168, 3.0277027943113257, 3.9960303872106415, 4.965599742458208, 4.915508323283292, 5.894903112910345, 6.9154854562005195, 7.883604955959372, 8.82299537354599, 9.837657492117962, 10.786309215717642, 10.00687720462508, 9.135315690823651, 8.109808558001498, 7.082354431834626, 6.038913066244009, 5.003044082600741, 3.9882591618945096, 2.9643256077973597, 1.940060663738047, 1.016763236469365, 1.9768059920591243, 3.0173506108018584, 3.9639200513358133, 3.942626372382053, 4.884151753227613, 5.930613034246882, 6.926807863485811, 7.852169359470843, 8.84821561739461, 9.811138750258644, 9.026476682470639, 8.071186791372027, 7.1025089685786025, 6.143863969507445, 5.092257377301777, 4.06952983912074, 3.0016189349496427, 2.074819487297387, 1.0141527106256583, 0.0, 1.0145407264466562, 1.9584465057357805, 2.9956071595093516, 5.001871004725236, 5.9183742744702865, 6.92526420067923, 7.857678178698636, 8.870760467127704, 9.780241987114197, 10.785202670325553, 9.986639227079056, 9.131231606779995, 8.107664773326679, 7.086048845027774, 6.037647937310464, 5.006827691651268, 3.9715651990041656, 2.9734200848833785, 1.980846937541973, 1.0012226245048055, 1.9601792567383245, 2.977546179599902, 3.963995177761082, 5.945548306184753, 6.891369135282199, 7.883160568556364, 8.830344081605762, 9.762206073518788, 10.78100663612732, 11.71554351724119, 10.949985843055734, 9.979191991663948, 8.978789747043704, 7.910661523830733, 6.888528709785879, 5.928004236443945, 4.915583329710536, 3.9161016311272316, 2.953783299989818, 2.000521544919437, 2.9793550220687806, 3.948626670017995, 4.923850084274884, 6.771822634189169, 7.822588469632981, 8.850472435165354, 9.797492959790823, 10.74356525736795, 11.738800410462932, 12.683088608793302, 11.8185335936837, 10.813501853684969, 9.883080421463038, 8.836130824017372, 7.87339808364843, 6.814066259520136, 5.8534090249761, 4.8822846514590355, 3.9066490026529372, 2.955703452454661, 4.00448956139569, 4.875871977778861, 5.821825325634494, 7.771858466945547, 8.8015707215493, 9.82495892417844, 10.801513883860943, 11.807157839408829, 12.665932607639999, 13.656656103301987, 12.814598179473936, 11.844464029375548, 10.836899136447881, 9.765302877803938, 8.771906654627793, 7.826896531575211, 6.867738304701373, 5.861908856666552, 4.862119119158872, 3.9777253178908474, 4.918577647334242, 5.863144563668601, 6.777058249362346, 8.762743670131808, 9.774428655866984, 10.7350806205329, 11.782088592052945, 12.730383774156962, 13.608248508902173, 14.591575923448103, 13.785197812252871, 12.870882963962492, 11.825477475787284, 10.75391032592201, 9.729164373311466, 8.754871350521663, 7.843154958826353, 6.804204050519687, 5.830661476012482, 5.052344314224164, 5.9305645309453014, 6.92956916118594, 7.703896690084189], [7.651534775855502, 6.91699488875692, 6.167021206135328, 7.116997320529527, 7.868325058525693, 8.823438869572552, 9.85078268319053, 10.802619459055904, 11.742276596255005, 12.76670287400061, 13.820015550181612, 14.810432904532869, 15.513474221337061, 14.505081788401252, 13.534608247778237, 12.656269775261405, 11.698884296287813, 10.674511699059538, 9.688450004165649, 8.661712407815543, 8.670440553502079, 7.972299234746944, 7.157534084439331, 8.106071305643022, 8.898354487704852, 9.802640787889807, 10.80090938681072, 11.792905200604366, 12.797822402648094, 13.803510471188435, 14.756906159618314, 15.716948233323464, 16.43086967921473, 15.414442506797458, 14.461736243348891, 13.638161284490547, 12.624331973777117, 11.704836535523818, 10.736539999998177, 9.716220897762405, 9.714163206535805, 9.006150687984833, 8.136908545769995, 9.095858383987514, 9.826007754348277, 10.838821398691692, 11.803639486146238, 12.825527995573182, 13.8142595943542, 14.821514314885194, 15.777751853082759, 16.70854484187193, 16.529739050835673, 15.588213137878856, 14.613914364617095, 13.82632879194904, 12.876470058744294, 12.26147116480594, 11.661938151081344, 10.754253408017671, 10.73251125153309, 10.017240627106036, 9.120752467080074, 10.049361486584724, 10.887845020751161, 11.822150545383069, 12.77063132283564, 13.761739857237863, 14.747290207396144, 15.724015598230608, 16.724466643927514, 16.41074346672584, 15.570216160907663, 14.607667720551913, 13.594008408675501, 12.875954774681768, 11.947436148241636, 11.233763131012712, 11.958431505613706, 11.755140965479244, 11.658086902956704, 10.956254549083685, 10.176734106625009, 11.113879922282297, 11.870106942511502, 12.878109238547072, 13.824601393895394, 14.765304793177268, 15.739416317520517, 16.683660790634484, 16.40909513713715, 15.47137376631329, 14.622859834411853, 13.63551452021672, 12.61517916244592, 11.824319383249078, 10.948340286487822, 10.184111504890389, 11.012568723750787, 11.773247068588457, 11.662918627795568, 11.997221663328105, 11.122734207604923, 12.048121125248763, 12.812669779131879, 13.840249566307165, 14.777425020098228, 15.727611660311732, 16.671369675155702, 16.38327713620719, 15.437130244551717, 14.510444142459708, 13.596086865688692, 12.667127917353568, 11.689317547428438, 10.855432914480668, 9.928099913595677, 9.185686518482775, 10.064886696293225, 10.712575568534891, 10.782286630039529, 11.735456350799623, 12.196554288517525, 13.075538786264257, 13.78344151678277, 14.810563008386284, 15.75218456958164, 16.766252423112515, 16.398407184270102, 15.45317067292822, 14.415666158584242, 13.486558535513193, 12.633885494107837, 11.717410584762629, 10.7368376239994, 9.83240873138186, 8.965846268960618, 8.20982458108288, 9.045331270596835, 9.78314523877205, 9.77733276873282, 10.753173676879221, 11.732825256209855, 12.677354271267848, 13.496207649260159, 14.546202678876027, 15.525507175538493, 16.38474226476855, 15.435487419384781, 14.511696636317563, 13.555095582958048, 12.554629129547578, 11.600724523394994, 10.713724877648133, 9.663479155884293, 8.778349546326085, 7.909272004192276, 7.147779043969241, 7.994769571159349, 8.846059008897505, 8.807913628095946, 9.732576882431324, 10.69567557596604, 11.623713167144066, 12.565447020761127, 13.556232920882039, 14.492514018112677, 15.380694242760963, 14.416123606741458, 13.47617427641738, 12.543052391246276, 11.575485097691981, 10.636838262159252, 9.69743965710152, 8.737605350799967, 7.749928124340844, 6.851122329634626, 6.076413732970209, 7.00635473751436, 7.878620405412423, 7.869833925335721, 8.745814316166925, 9.662700609980746, 10.64382568647994, 11.601714569073815, 12.61259445658804, 13.585738387812146, 14.525801756769145, 13.482323868761931, 12.55166893334245, 11.574461394433644, 10.649287935696602, 9.710327700617734, 8.763719160287202, 7.776732568054275, 6.787810419876436, 5.848426984574525, 5.082125821795144, 5.96945799371017, 6.897931880229395, 6.823611948544815, 7.7366150986012014, 8.680734764684127, 9.750100425875358, 10.75076846479023, 11.724396334426354, 12.645791560342893, 13.619107481127754, 12.692692818030922, 11.806007758936172, 10.804542756666214, 9.903110190098895, 8.956894419933343, 7.8852109012059435, 6.819499338764137, 5.8686907920690325, 4.884377391346511, 4.051416200011582, 4.903174993993795, 5.881227147557036, 5.893967040519941, 6.790193538959892, 7.808086413434835, 8.846706170953032, 9.778695837030599, 10.82817255738949, 11.683953993412382, 12.629399781184288, 11.74192881240092, 10.816807482148914, 9.853193198368686, 8.848443888123265, 7.966567076366879, 6.960957320993614, 5.926013461613842, 4.986933089629538, 3.945578631608115, 3.018764803094772, 3.9678220708856635, 4.953938335005081, 4.900310059951591, 5.820629956037539, 6.8740149505142725, 7.858274043170798, 8.761274209189686, 9.769158637814124, 10.736692026589964, 11.663189047896054, 10.834270241094211, 9.814459594346456, 8.846432956118171, 7.9209066259785414, 6.933829294454033, 5.965298988346847, 4.894867974588593, 3.9422986218432294, 3.001862451159348, 2.01316206786467, 2.9814896607639856, 3.951059016011552, 3.900967596836635, 4.880362386463689, 5.9009447297538635, 6.869064229512716, 7.8084546470993335, 8.823116765671307, 9.771768489270986, 10.709442885369317, 10.133598777647562, 9.104408043899165, 8.076953917732293, 7.033512552141677, 5.997643568498409, 4.9828586477921775, 3.9589250936950275, 2.9346601496357154, 1.9509526426970476, 0.9622652656124682, 2.0028098843552025, 2.9493793248891573, 2.9280856459353966, 3.869611026780957, 4.916072307800226, 5.912267137039155, 6.837628633024187, 7.833674890947954, 8.796598023811988, 9.82109298310219, 9.085727517818682, 8.117049695025258, 7.158404695954101, 6.106798103748433, 5.084070565567396, 4.016159661396299, 3.089360213744043, 2.0286934370723144, 1.0145407264466562, 0.0, 0.9439057792891243, 1.9810664330626955, 3.9873302782785798, 4.903833548023631, 5.910723474232574, 6.84313745225198, 7.856219740681048, 8.76570126066754, 9.770661943878896, 10.770079839446089, 10.14577233322665, 9.122205499773335, 8.095716140699212, 7.0473152329819015, 6.016494987322705, 4.976666234520535, 3.9785211203997486, 2.985947973058343, 2.0063236600211756, 1.0473670277876566, 1.9630054531532457, 2.9494544513144256, 4.931007579738097, 5.876828408835543, 6.868619842109708, 7.815803355159107, 8.747665347072132, 9.766465909680663, 10.701002790794535, 11.723913645596676, 10.984293027180316, 9.983890782560072, 8.915762559347101, 7.893629745302247, 6.933105271960313, 5.920684365226905, 4.921202666643602, 3.958884335506188, 3.005622580435807, 2.0665427931181126, 2.934085943571339, 3.9093093578282283, 5.757281907742513, 6.808047743186325, 7.835931708718698, 8.782952233344167, 9.729024530921293, 10.724259684016276, 11.668547882346646, 12.690364665123303, 11.818602889201339, 10.888181456979408, 9.841231859533742, 8.8784991191648, 7.819167295036506, 6.8585100604924705, 5.8873856869754055, 4.911750038169307, 3.960804487971031, 3.0916773324450224, 3.8613312513322047, 4.807284599187838, 6.757317740498891, 7.787029995102643, 8.810418197731781, 9.786973157414288, 10.792617112962173, 11.651391881193343, 12.642115376855331, 13.68642925091354, 12.849565064891916, 11.84200017196425, 10.770403913320306, 9.777007690144162, 8.83199756709158, 7.872839340217743, 6.867009892182922, 5.867220154675242, 4.9828263534072175, 4.161556984642891, 4.880602934874279, 5.76251752291569, 7.748202943685153, 8.75988792942033, 9.720539894086246, 10.767547865606291, 11.715843047710308, 12.593707782455517, 13.577035197001447, 14.596934333141506, 13.87598399947886, 12.830578511303653, 11.759011361438379, 10.734265408827834, 9.759972386038031, 8.848255994342724, 7.809305086036057, 6.835762511528852, 6.057445349740534, 5.17354386825395, 5.947027532391619, 6.689355963637533], [6.707628996566378, 5.973089109467796, 6.88672829341195, 7.877603434884531, 8.812230837814816, 9.767344648861675, 10.794688462479652, 11.746525238345027, 12.686182375544128, 13.710608653289732, 14.763921329470735, 15.634621166498116, 14.569568442047938, 13.56117600911213, 12.590702468489114, 11.71236399597228, 10.754978516998689, 9.730605919770413, 8.744544224876524, 7.717806628526418, 7.726534774212954, 7.028393455457819, 7.877241171715953, 8.825778392919645, 9.842260266993975, 10.74654656717893, 11.74481516609984, 12.736810979893487, 13.741728181937217, 14.74741625047756, 15.700811938907439, 16.545773839652625, 15.486963899925605, 14.470536727508335, 13.517830464059768, 12.694255505201422, 11.680426194487993, 10.760930756234693, 9.792634220709052, 8.77231511847328, 8.77025742724668, 8.062244908695709, 8.856615633046617, 9.815565471264136, 10.7699135336374, 11.782727177980814, 12.74754526543536, 13.769433774862303, 14.758165373643322, 15.765420094174317, 16.721657632371883, 17.488666880923297, 16.436396651352055, 15.440421816914359, 14.466123043652598, 13.676748034483914, 12.753360461007777, 11.733235341280643, 10.71803237179222, 9.810347628728547, 9.788605472243965, 9.073334847816911, 9.840459554356697, 10.769068573861347, 11.808328085410722, 12.76605632467219, 13.714537102124762, 14.705645636526985, 15.691195986685265, 16.66792137751973, 17.668372423216635, 17.35464924601496, 16.514121940196787, 15.551573499841037, 14.537914187964626, 13.819860553970893, 12.89134192753076, 12.01636911324533, 11.022789960083792, 10.81123518619012, 10.71418112366758, 10.01234876979456, 10.89644119390163, 11.83358700955892, 12.790590007171062, 13.822015017836193, 14.768507173184515, 15.70921057246639, 16.68332209680964, 17.62756656992361, 17.353000916426275, 16.415279545602413, 15.566765613700978, 14.579420299505845, 13.559084941735044, 12.768225162538203, 11.892246065776947, 11.065173601196673, 10.076927178220872, 10.83760552305854, 10.727277082265651, 11.05331588403898, 11.842441294881544, 12.767828212525384, 13.733152843791439, 14.760732630966725, 15.697908084757788, 16.666437845954608, 17.615275454444827, 17.327182915496316, 16.381036023840842, 15.454349921748832, 14.539992644977817, 13.611033696642693, 12.633223326717562, 11.799338693769792, 10.872005692884802, 10.06674861478906, 9.12924515076331, 9.776934023004975, 9.846645084509612, 10.791550571510498, 11.752733048102616, 12.759727526010192, 13.57765771885043, 14.628447726523898, 15.557892843140248, 16.546077015136206, 17.342312963559227, 16.397076452217345, 15.359571937873367, 14.430464314802318, 13.577791273396961, 12.661316364051753, 11.680743403288524, 10.776314510670984, 9.909752048249743, 9.090886677389165, 8.109689725066918, 8.847503693242134, 8.841691223202904, 9.809267897590097, 10.78891947692073, 11.733448491978724, 12.552301869971034, 13.602296899586902, 14.581601396249368, 15.56469503120304, 16.379393198673906, 15.455602415606688, 14.499001362247173, 13.498534908836703, 12.54463030268412, 11.657630656937258, 10.607384935173418, 9.72225532561521, 8.853177783481401, 8.028841140275524, 7.059128025629432, 7.9104174633675886, 7.872272082566029, 8.7886711031422, 9.751769796676916, 10.679807387854941, 11.621541241472002, 12.612327141592914, 13.548608238823553, 14.560647009195451, 15.360029386030583, 14.420080055706505, 13.4869581705354, 12.519390876981106, 11.580744041448376, 10.641345436390644, 9.681511130089092, 8.693833903629969, 7.795028108923751, 6.957475829276492, 6.070713191984443, 6.942978859882507, 6.934192379805804, 7.801908536877799, 8.718794830691621, 9.699919907190814, 10.65780878978469, 11.668688677298915, 12.641832608523021, 13.583967402127438, 14.426229648051056, 13.495574712631575, 12.518367173722769, 11.593193714985727, 10.654233479906859, 9.707624939576327, 8.7206383473434, 7.731716199165561, 6.79233276386365, 5.963187918101428, 5.033816448180254, 5.962290334699478, 5.887970403014898, 6.792709319312077, 7.736828985395002, 8.806194646586233, 9.806862685501105, 10.780490555137229, 11.701885781053768, 12.675201701838631, 13.636598597320047, 12.749913538225298, 11.74844853595534, 10.84701596938802, 9.900800199222468, 8.82911668049507, 7.763405118053262, 6.812596571358157, 5.828283170635636, 4.932478296317866, 3.967533448463878, 4.945585602027119, 4.950061261230817, 5.846287759670767, 6.86418063414571, 7.902800391663908, 8.834790057741476, 9.884266778100367, 10.74004821412326, 11.685494001895165, 12.685834591690044, 11.760713261438038, 10.797098977657813, 9.792349667412392, 8.910472855656003, 7.904863100282739, 6.869919240902966, 5.930838868918663, 4.889484410897239, 3.9626705823838964, 3.032180525355747, 4.018296789475165, 3.9564042806624675, 4.876724176748414, 5.930109171225148, 6.9143682638816735, 7.817368429900563, 8.825252858525001, 9.79278624730084, 10.719283268606931, 11.688299984650216, 10.75836537363558, 9.790338735407296, 8.864812405267667, 7.877735073743158, 6.909204767635972, 5.838773753877717, 4.886204401132353, 3.945768230448473, 2.957067847153794, 2.045848115234069, 3.015417470481635, 2.9570618175475105, 3.9364566071745646, 4.957038950464739, 5.9251584502235914, 6.8645488678102105, 7.8792109863821835, 8.827862709981863, 9.765537106080194, 10.817711535311606, 10.04831382318829, 9.020859697021418, 7.977418331430802, 6.941549347787534, 5.926764427081302, 4.902830872984152, 3.8785659289248398, 2.894858421986172, 1.9061710449015925, 1.0671683388252857, 2.0137377793592406, 1.9841798666462722, 2.9257052474918326, 3.972166528511102, 4.968361357750032, 5.893722853735064, 6.889769111658831, 7.852692244522865, 8.877187203813067, 9.83247709491168, 9.060955474314383, 8.102310475243225, 7.050703883037558, 6.027976344856521, 4.960065440685423, 4.033265993033168, 2.9725992163614388, 1.9584465057357805, 0.9439057792891243, 0.0, 1.0371606537735711, 3.043424498989455, 3.9599277687345067, 4.96681769494345, 5.899231672962857, 6.912313961391925, 7.821795481378419, 8.826756164589774, 9.826174060156967, 10.883570403430236, 10.06611127906246, 9.039621919988335, 7.9912210122710245, 6.960400766611829, 5.920572013809659, 4.9224268996888725, 3.9298537523474675, 2.9502294393103, 1.991272807076781, 1.0190996738641214, 2.0055486720253013, 3.987101800448973, 4.932922629546418, 5.924714062820584, 6.871897575869984, 7.80375956778301, 8.82256013039154, 9.757097011505412, 10.780007866307553, 11.752451717191272, 10.927796561849197, 9.859668338636226, 8.837535524591372, 7.877011051249438, 6.864590144516029, 5.865108445932726, 4.902790114795312, 3.9495283597249315, 2.975495704151975, 1.9901801642822146, 2.965403578539104, 4.813376128453388, 5.8641419638972, 6.892025929429574, 7.839046454055043, 8.78511875163217, 9.780353904727153, 10.724642103057523, 11.74645888583418, 12.751490625832911, 11.832087236268531, 10.785137638822865, 9.822404898453923, 8.763073074325629, 7.8024158397815935, 6.831291466264529, 5.855655817458431, 4.904710267260155, 3.966009334153015, 2.9174254720430803, 3.8633788198987133, 5.813411961209766, 6.843124215813519, 7.866512418442657, 8.843067378125165, 9.84871133367305, 10.70748610190422, 11.698209597566208, 12.742523471624416, 13.79347084418104, 12.785905951253373, 11.71430969260943, 10.720913469433285, 9.775903346380703, 8.816745119506866, 7.810915671472046, 6.811125933964366, 5.822116401362908, 4.881264071919513, 3.936697155585154, 4.818611743626565, 6.804297164396028, 7.815982150131205, 8.77663411479712, 9.823642086317166, 10.771937268421183, 11.649802003166394, 12.633129417712324, 13.653028553852383, 14.594783959337883, 13.774484290592776, 12.702917140727502, 11.678171188116957, 10.703878165327154, 9.792161773631847, 8.75321086532518, 7.779668290817976, 6.896735397696224, 5.893250955530572, 5.003121753102494, 5.7454501843484085], [5.9397600567241975, 6.898735311997128, 7.861994909158964, 8.852870050631545, 9.817714904934403, 10.772828715981262, 11.80017252959924, 12.777869885046352, 13.717527022245452, 14.741953299991057, 15.5878778670758, 14.597460512724544, 13.532407788274366, 12.524015355338557, 11.553541814715542, 10.782822451400445, 9.854021014467467, 8.844542922134833, 7.867455591871735, 6.949937688684238, 6.958665834370773, 7.954039657987152, 8.852507787462969, 9.80104500866666, 10.847744334113562, 11.752030634298517, 12.75029923321943, 13.742295047013076, 14.773072828638542, 15.778760897178884, 16.468655259584203, 15.508613185879053, 14.449803246152033, 13.433376073734763, 12.480669810286196, 11.788703255949082, 10.77946869195677, 9.874867758599112, 8.915545587704264, 8.004446178631099, 8.002388487404499, 8.94354362722739, 9.831882248793633, 10.790832087011152, 11.775397600756987, 12.788211245100403, 13.753029332554949, 14.774917841981893, 15.789510020344647, 16.79676474087564, 17.382299215938893, 16.45150622714972, 15.399235997578481, 14.403261163140787, 13.428962389879025, 12.771195785231575, 11.852402958476555, 10.856146708275855, 9.84094373878743, 9.042478688886366, 9.020736532401784, 9.954633566348592, 10.815726170103712, 11.744335189608362, 12.783594701157737, 13.77154039179178, 14.720021169244351, 15.711129703646574, 16.696680053804855, 17.673405444639318, 18.38562451383392, 17.31744918380942, 16.353545902713293, 15.390997462357543, 14.44886834582062, 13.683993782540256, 12.755475156100124, 11.820357080293414, 10.826777927131875, 10.043366246347938, 9.946312183825398, 10.893647488326241, 11.871707809648647, 12.808853625305936, 13.765856622918077, 14.827499084955782, 15.773991240304104, 16.71469463958598, 17.68880616392923, 18.633050637043198, 18.33127342410977, 17.39355205328591, 16.545038121384472, 15.55769280718934, 14.53735744941854, 13.69460702540055, 12.732897603192814, 11.804034253415612, 10.785624619188724, 9.93587081236416, 9.777941380371496, 10.7532252538229, 11.702463150257925, 12.627850067901765, 13.511268802727749, 14.538848589903036, 15.4760240436941, 16.44455380489092, 17.45453335769104, 18.30545542317981, 17.359308531524338, 16.432622429432328, 15.518265152661312, 14.589306204326189, 13.611495834401058, 12.77761120145329, 11.8502782005683, 10.862578135071113, 9.837942591731162, 8.875199312310594, 8.833910637576448, 9.754389917736926, 10.715572394329044, 11.72256687223662, 12.540497065076858, 13.591287072750326, 14.520732189366676, 15.508916361362633, 16.470340568970027, 17.37534895990084, 16.337844445556865, 15.408736822485814, 14.556063781080457, 13.63958887173525, 12.65901591097202, 11.75458701835448, 10.88802455593324, 9.886716197671218, 8.878323904114826, 7.945768982547752, 7.822679264291857, 8.772107243816524, 9.751758823147158, 10.696287838205151, 11.515141216197462, 12.56513624581333, 13.544440742475796, 14.527534377429468, 15.507420804084708, 16.433874923290183, 15.477273869930668, 14.476807416520199, 13.522902810367615, 12.635903164620753, 11.585657442856913, 10.700527833298706, 9.831450291164899, 8.963350392562145, 7.993637277916052, 7.008682752673207, 6.853260123654983, 7.751510449368627, 8.714609142903344, 9.642646734081369, 10.58438058769843, 11.575166487819342, 12.51144758504998, 13.523486355421879, 14.488056991441384, 15.39835256339, 14.465230678218896, 13.497663384664602, 12.559016549131872, 11.61961794407414, 10.659783637772588, 9.672106411313464, 8.773300616607248, 7.891985081563112, 7.005222444271062, 6.041244149188125, 5.915180420894758, 6.764747883104227, 7.681634176918049, 8.662759253417242, 9.620648136011118, 10.631528023525343, 11.604671954749449, 12.546806748353866, 13.532884297226108, 14.46353923264559, 13.496639681406265, 12.571466222669223, 11.632505987590354, 10.685897447259823, 9.698910855026895, 8.709988706849057, 7.770605271547145, 6.897697170388048, 5.968325700466873, 5.060555624005096, 4.868958444103852, 5.755548665538504, 6.69966833162143, 7.769033992812661, 8.769702031727533, 9.743329901363657, 10.664725127280196, 11.638041048065059, 12.603920499949009, 13.601053712727518, 12.785609189728909, 11.825288477071515, 10.879072706905964, 9.807389188178565, 8.741677625736758, 7.790869079041653, 6.806555678319132, 5.866987548604485, 4.902042700750497, 4.043850891332737, 3.912900607457246, 4.809127105897195, 5.827019980372138, 6.865639737890335, 7.797629403967904, 8.847106124326793, 9.702887560349687, 10.648333348121593, 11.676336472188307, 12.601457802440313, 11.834259631431381, 10.82951032118596, 9.898857256739845, 8.89324750136658, 7.858303641986807, 6.909111376602159, 5.867756918580735, 4.9409430900673925, 3.966689777642366, 3.1135636435392353, 2.919243626888896, 3.8395635229748426, 4.892948517451576, 5.877207610108102, 6.780207776126992, 7.788092204751428, 8.755625593527268, 9.682122614833359, 10.651139330876644, 11.6709499776244, 10.827499389180865, 9.901973059041236, 8.914895727516727, 7.946365421409542, 6.875934407651288, 5.923365054905925, 4.982928884222043, 3.994228500927365, 2.9803573675206882, 2.110684324545706, 1.9199011637739396, 2.899295953400993, 3.9198782966911674, 4.88799779645002, 5.827388214036639, 6.842050332608611, 7.790702056208291, 8.728376452306621, 9.780550881538034, 10.80974161528643, 10.05802035079499, 9.014578985204373, 7.9787100015611045, 6.963925080854873, 5.939991526757723, 4.915726582698411, 3.932019075759743, 2.9433316986751636, 2.0016775911119056, 1.0551081505779507, 0.9470192128727011, 1.8885445937182614, 2.9350058747375307, 3.9312007039764603, 4.856562199961493, 5.8526084578852595, 6.815531590749293, 7.840026550039495, 8.795316441138107, 9.763994263931531, 9.139471129016798, 8.08786453681113, 7.065136998630093, 5.997226094458995, 5.070426646806739, 4.00975987013501, 2.9956071595093516, 1.9810664330626955, 1.0371606537735711, 0.0, 2.006263845215884, 2.9227671149609353, 3.9296570411698784, 4.862071019189285, 5.875153307618353, 6.784634827604847, 7.789595510816201, 8.789013406383395, 9.846409749656663, 10.769150068679608, 10.076782573761907, 9.028381666044597, 7.9975614203854, 6.9577326675832305, 5.959587553462444, 4.967014406121039, 3.9873900930838713, 3.0284334608503523, 1.9943662896111363, 1.0079172914499563, 3.006598515268977, 3.952419344366423, 4.887553409047013, 5.834736922096412, 6.766598914009438, 7.785399476617968, 8.71993635773184, 9.742847212533981, 10.7152910634177, 11.715693308037944, 10.896828992409796, 9.874696178364943, 8.914171705023008, 7.9017507982896005, 6.902269099706297, 5.939950768568884, 4.980656195584082, 3.9507623198989896, 2.9654467800292292, 2.0567289761779954, 3.972705163538256, 4.8836386787172055, 5.872700979279903, 6.819721503905373, 7.747958097858598, 8.743193250953581, 9.68748144928395, 10.709298232060608, 11.714329972059339, 12.64475140428127, 11.81648228552419, 10.853749545155248, 9.794417721026953, 8.833760486482918, 7.862636112965853, 6.887000464159755, 5.9358381031193055, 4.94127594990003, 3.892692087790095, 3.0955098800565333, 4.985563068143597, 5.862620930633524, 6.886009133262663, 7.8237424279754935, 8.811550679899478, 9.670325448130647, 10.661048943792636, 11.705362817850844, 12.756468544510096, 13.680701643331345, 12.745654339310754, 11.752258116134609, 10.807247993082028, 9.841855413168691, 8.83602596513387, 7.816610001083951, 6.797383017109922, 5.8565306876665275, 4.911963771332169, 4.050742803784385, 5.996789966036813, 6.929919152495626, 7.890571117161541, 8.824712833406508, 9.773008015510525, 10.612641349392822, 11.595968763938751, 12.615867900078811, 13.557623305564311, 14.603028793739519, 13.734261787428826, 12.709515834818282, 11.735222812028479, 10.817272067293672, 9.778321158987005, 8.785152357937562, 7.872002013443239, 6.868517571277587, 5.978388368849508, 4.977581244506228], [5.760688803544712, 6.719664058817642, 7.6990010722548545, 8.689876213727436, 9.718110853358484, 10.673224664405343, 11.700568478023321, 12.7150439604309, 13.654701097630001, 14.679127375375606, 13.736031386397254, 12.745614032045998, 11.68056130759582, 10.672168874660011, 9.701695334036994, 8.815380271154236, 7.862651674147225, 6.838279076918949, 5.861191746655851, 4.992300669524651, 6.779594581191288, 7.774968404807666, 8.689513950558858, 9.63805117176255, 10.697901565540382, 11.652426582722597, 12.65069518164351, 13.642690995437157, 14.694453621230565, 15.570204467335536, 14.616808778905657, 13.656766705200507, 12.597956765473485, 11.581529593056215, 10.628823329607648, 9.801928662349958, 8.788099351636529, 7.86860391338323, 6.90928174248838, 6.051062277411896, 7.823317234225015, 8.764472374047907, 9.668888411889522, 10.627838250107041, 11.625554832183807, 12.638368476527223, 13.653425280979029, 14.675313790405973, 15.690976779188352, 16.550666005012616, 15.530452735260345, 14.599659746471175, 13.547389516899933, 12.551414682462239, 11.577115909200478, 10.78442119163245, 9.861033618156313, 8.849882863059971, 7.834679893571547, 7.089094787667163, 8.8416652792223, 9.77556231316911, 10.652732333199602, 11.581341352704252, 12.620600864253626, 13.6216976232186, 14.570178400671171, 15.561286935073394, 16.546837285231675, 17.52356267606614, 16.53377803315537, 15.465602703130871, 14.501699422034745, 13.539150981678995, 12.597021865142072, 11.677729937324372, 10.74921131088424, 9.81409323507753, 8.820514081915992, 8.149634395600097, 9.767240930645913, 10.714576235146758, 11.708713972744537, 12.645859788401825, 13.602862786013967, 14.66867095592917, 15.624148471730924, 16.5648518710128, 17.53896339535605, 18.42173169726297, 17.472091727874805, 16.40497240354342, 15.49003521819242, 14.511304182014188, 13.575851111371653, 12.675359269990736, 11.713649847783, 10.784786498005797, 9.76637686377891, 9.119853211546129, 9.890166799841978, 10.865450673293383, 11.814688569728409, 12.740075487372248, 13.623494222198232, 14.65107400937352, 15.588249463164583, 16.556779224361403, 17.566758777161525, 18.442967574011828, 18.318303428654644, 17.365902027397002, 16.40848204464939, 15.479523096314265, 14.501712726389135, 13.644245738759146, 12.733890220675145, 11.767055461976216, 10.714058891236473, 10.180524711599695, 8.94613605704693, 9.86661533720741, 10.827797813799528, 11.834792291707103, 12.652722484547342, 13.70351249222081, 14.63295760883716, 15.621141780833117, 16.58256598844051, 17.501213666089864, 18.29233932772005, 17.363231704649, 16.510558663243646, 15.594083753898435, 14.613510793135205, 13.709081900517665, 12.794954572563098, 11.753883959452626, 10.745491665896234, 9.81293674432916, 7.934904683762339, 8.884332663287008, 9.86398424261764, 10.808513257675633, 11.627366635667945, 12.677361665283813, 13.65666616194628, 14.639759796899952, 15.619646223555192, 16.559739629479207, 17.431768752093856, 16.431302298683384, 15.477397692530802, 14.590398046783939, 13.540152325020099, 12.655022715461891, 11.785945173328084, 10.912901637021482, 9.8618474218643, 8.875850514454616, 6.965485543125465, 7.863735868839109, 8.826834562373826, 9.754872153551851, 10.696606007168914, 11.687391907289825, 12.623673004520464, 13.635711774892362, 14.600282410911868, 15.521525129429126, 16.419725560382084, 15.45215826682779, 14.51351143129506, 13.574112826237327, 12.614278519935773, 11.62660129347665, 10.727795498770433, 9.846479963726296, 8.941819012116074, 7.908411910969533, 6.0274058403652395, 6.87697330257471, 7.793859596388532, 8.774984672887726, 9.732873555481602, 10.743753442995827, 11.716897374219933, 12.65903216782435, 13.64510971669659, 14.57576465211607, 15.451134563569452, 14.52596110483241, 13.587000869753542, 12.64039232942301, 11.653405737190083, 10.664483589012242, 9.725100153710331, 8.852192052551231, 7.922820582630058, 6.927723385786504, 4.9811838635743335, 5.867774085008987, 6.811893751091913, 7.881259412283144, 8.881927451198017, 9.85555532083414, 10.77695054675068, 11.75026646753554, 12.71614591941949, 13.713279132198, 14.644902158076848, 13.7797833592347, 12.83356758906915, 11.76188407034175, 10.696172507899945, 9.74536396120484, 8.761050560482317, 7.82148243076767, 6.856537582913682, 5.911018653114145, 4.025126026927728, 4.921352525367678, 5.939245399842621, 6.977865157360818, 7.909854823438386, 8.959331543797274, 9.815112979820169, 10.760558767592075, 11.78856189165879, 12.713683221910797, 13.69355259977932, 12.802550682629105, 11.85335213890303, 10.847742383529765, 9.812798524149992, 8.863606258765342, 7.82225180074392, 6.895437972230577, 5.921184659805551, 4.980731405320643, 3.031469046359378, 3.951788942445325, 5.005173936922059, 5.989433029578585, 6.892433195597474, 7.90031762422191, 8.86785101299775, 9.794348034303841, 10.763364750347126, 11.783175397094881, 12.751202035323168, 11.87501342048438, 10.887936088959872, 9.952629266625426, 8.882198252867171, 7.925871030511267, 6.973271755927963, 5.984571372633285, 4.934852249683873, 4.0651792067088905, 2.0321265832444215, 3.0115213728714756, 4.03210371616165, 5.000223215920503, 5.939613633507121, 6.954275752079093, 7.902927475678773, 8.840601871777103, 9.892776301008515, 10.921967034756912, 11.806183734089728, 10.987619346647518, 9.95175036300425, 8.936965442298018, 7.946255371973606, 6.921990427914294, 5.9382829209756265, 4.949595543891047, 3.95617247327509, 3.009603032741135, 1.059244632343183, 2.0007700131887436, 3.047231294208013, 4.043426123446943, 4.968787619431975, 5.964833877355741, 6.927757010219775, 7.952251969509977, 8.907541860608589, 9.876219683402013, 10.834864682473171, 10.003583401051019, 8.980855862869982, 7.912944958698883, 6.986145511046628, 6.016023715350894, 5.001871004725236, 3.9873302782785793, 3.043424498989455, 2.006263845215884, 0.0, 1.0289685488110878, 2.0814451957479374, 3.1444550781677263, 4.157537366596793, 5.2234430161967875, 6.251271234636673, 7.250689130203867, 8.308085473477135, 9.371665814767503, 10.151901637406064, 9.103500729688754, 8.072680484029558, 7.032851731227389, 6.034706617106602, 5.042133469765197, 4.062509156728029, 3.1035525244945106, 2.0322926947370368, 1.0458436965758569, 1.000334670053093, 1.9461554991505388, 2.9937816165045428, 4.052609683339949, 4.984471675252975, 6.0032722378615055, 6.937809118975377, 7.960719973777517, 8.933163824661237, 9.933566069281481, 10.971948056053956, 9.949815242009102, 8.989290768667168, 7.976869861933759, 6.977388163350455, 6.015069832213042, 5.012465721774704, 3.9825718460896113, 2.997256306219851, 2.0220328919629615, 1.9664413183223723, 2.877374833501321, 3.905258799033694, 4.852279323659164, 5.8961116171800505, 6.8913467702750335, 7.835634968605404, 8.857451751382062, 9.862483491380793, 10.792904923602723, 11.83985452104839, 10.88459038994155, 9.825258565813256, 8.86460133126922, 7.893476957752156, 6.917841308946058, 5.966678947905609, 4.910975836842616, 3.862391974732681, 2.9164386268770475, 2.9792992229277138, 3.856357085417639, 4.879745288046777, 5.856300247729284, 6.881329266143796, 7.8184789674521, 8.80920246311409, 9.853516337172298, 10.90462206383155, 11.828855162652799, 12.685210525578611, 11.691814302402467, 10.746804179349885, 9.767561396816301, 8.761731948781481, 7.742315984731562, 6.723089000757532, 5.782236671314137, 4.837669754979778, 3.8716715506048995, 3.9905261208209293, 4.923655307279741, 5.884307271945657, 6.857270653160298, 7.805565835264315, 8.760794868714274, 9.744122283260205, 10.764021419400265, 11.705776824885765, 12.751182313060973, 13.671435862813375, 12.64668991020283, 11.672396887413027, 10.742978050941282, 9.704027142634615, 8.710858341585173, 7.797707997090848, 6.794223554925196, 5.857129502278559, 4.798509991326743], [6.751337967950883, 7.710313223223814, 8.689650236661025, 9.680525378133606, 10.708760017764654, 11.663873828811512, 12.69121764242949, 13.705693124837072, 14.645350262036173, 13.875654702809785, 12.822342026628782, 11.831924672277525, 10.766871947827347, 9.758479514891539, 8.788005974268522, 7.905642057167417, 6.961659180358506, 5.937286583130231, 4.960199252867132, 5.982949833930823, 7.77024374559746, 8.765617569213838, 9.68016311496503, 10.628700336168722, 11.688550729946554, 12.643075747128767, 13.641344346049678, 14.633340159843325, 15.685102785636733, 14.656515107567063, 13.703119419137185, 12.743077345432035, 11.684267405705013, 10.667840233287743, 9.715133969839176, 8.90093616856124, 7.88710685784781, 6.967611419594511, 6.008289248699661, 7.041711441818068, 8.813966398631187, 9.755121538454079, 10.659537576295694, 11.618487414513213, 12.616203996589979, 13.629017640933395, 14.644074445385197, 15.66596295481214, 16.644231365775138, 15.636976645244143, 14.616763375491873, 13.685970386702703, 12.63370015713146, 11.637725322693766, 10.663426549432005, 9.883428697843732, 8.960041124367594, 7.948890369271252, 6.933687399782828, 7.885516729454662, 9.832314443628473, 10.76621147757528, 11.643381497605773, 12.571990517110423, 13.611250028659798, 14.612346787624771, 15.560827565077343, 16.551936099479565, 17.537486449637846, 16.620539719083805, 15.620088673386899, 14.551913343362399, 13.588010062266273, 12.625461621910523, 11.683332505373599, 10.776737443535653, 9.848218817095521, 8.913100741288812, 7.919521588127273, 8.928104272049353, 10.757890095052087, 10.939870295591732, 11.794141178762251, 12.823197007902374, 13.59950956687254, 14.665317736787742, 15.666377708080118, 16.5525385995498, 17.532164642850645, 17.508042337494498, 16.558402368106332, 15.49128304377495, 14.576345858423947, 13.597614822245715, 12.66216175160318, 11.774366776202019, 10.812657353994283, 9.88379400421708, 8.865384369990192, 9.898323087995385, 10.747798918281502, 9.898903181347311, 10.848141077782337, 11.773527995426177, 12.656946730252162, 13.68452651742745, 14.621701971218513, 15.590231732415335, 16.600211285215458, 17.442864093173014, 17.404614068886172, 16.45221266762853, 15.494792684880917, 14.565833736545793, 13.588023366620662, 12.743253244970429, 11.832897726886427, 10.866062968187498, 9.813066397447754, 10.775809676868322, 9.803768175486454, 8.900067845261338, 9.861250321853456, 10.868244799761031, 11.686174992601272, 12.73696500027474, 13.66641011689109, 14.654594288887047, 15.616018496494442, 16.50111018525105, 17.427892430447308, 17.476098274575044, 16.560496455835477, 15.57027724375496, 14.5405032900497, 13.810467051689196, 12.795151371521486, 11.841014116700537, 10.832621823144144, 10.670568862768683, 8.792536802201862, 7.917785171340937, 8.897436750671572, 9.841965765729563, 10.660819143721875, 11.710814173337743, 12.69011867000021, 13.673212304953882, 14.653098731609122, 15.559636148640394, 16.46658672547319, 17.347805568428438, 16.393900962275854, 15.506901316528989, 14.456655594765149, 13.571525985206941, 12.702448443073134, 11.770533755461004, 10.719479540303823, 9.733482632894138, 7.823117661564988, 6.897188376893039, 7.8602870704277565, 8.788324661605781, 9.730058515222844, 10.720844415343755, 11.657125512574394, 12.669164282946292, 13.633734918965798, 14.521421648590312, 15.454543533761417, 16.36866153657284, 15.43001470104011, 14.490616095982377, 13.530781789680823, 12.5431045632217, 11.644298768515483, 10.736645305929523, 9.799451130555596, 8.766044029409056, 6.885037958804762, 5.91042581062864, 6.827312104442462, 7.808437180941656, 8.766326063535532, 9.777205951049757, 10.750349882273863, 11.69248467587828, 12.645006235857775, 13.575661171277257, 14.552868710186063, 15.44246437457746, 14.503504139498592, 13.55689559916806, 12.569909006935132, 11.580986858757292, 10.641603423455381, 9.742357394754459, 8.800123252236464, 7.785355504226027, 5.838815982013856, 4.901226593062917, 5.845346259145843, 6.914711920337074, 7.915379959251947, 8.88900782888807, 9.776847065911863, 10.750162986696726, 11.716042438580676, 12.713175651359185, 13.64479867723803, 14.623624848657998, 13.7500708588142, 12.6783873400868, 11.612675777644995, 10.66186723094989, 9.677553830227367, 8.711647772970897, 7.746702925116909, 6.768650771553668, 4.882758145367251, 3.954805033421608, 4.972697907896551, 6.011317665414748, 6.909751342599571, 7.959228062958459, 8.815009498981354, 9.76045528675326, 10.788458410819974, 11.71357974107198, 12.693449118940503, 13.604162146768704, 12.76985540864808, 11.764245653274816, 10.729301793895043, 9.780109528510394, 8.73875507048897, 7.811941241975628, 6.837687929550602, 5.838363523760166, 3.94797231610443, 2.9852414504992555, 4.038626444975989, 5.007411450256203, 5.892329714758659, 6.900214143383095, 7.867747532158934, 8.794244553465026, 9.76326126950831, 10.783071916256066, 11.75109855448435, 12.67662488462398, 11.837662842477663, 10.869132536370477, 9.798701522612223, 8.842374300256317, 7.889775025673013, 6.901074642378335, 5.851355519428924, 4.981682476453941, 2.9486298529894728, 2.044973880925406, 3.0500821368392685, 4.018201636598121, 4.939510152668306, 5.954172271240278, 6.902823994839958, 7.840498390938288, 8.8926728201697, 9.921863553918097, 10.806080253250913, 11.84952161884153, 10.90147711652204, 9.886692195815808, 8.862758641718658, 7.838493697659346, 6.854786190720678, 5.866098813636099, 4.872675743020141, 3.926106302486186, 1.9757479020882345, 1.034222521242674, 2.0471278133691975, 3.043322642608127, 3.9686841385931593, 4.964730396516925, 5.92765352938096, 6.9521484886711615, 7.907438379769773, 8.876116202563198, 9.834761201634356, 10.886367793840023, 9.987904113591027, 8.919993209419928, 7.993193761767674, 6.932526985095945, 5.9183742744702865, 4.903833548023631, 3.9599277687345067, 2.9227671149609353, 1.0289685488110878, 0.0, 1.0524766469368496, 2.1154865293566383, 3.128568817785706, 4.1944744673856995, 5.222302685825585, 6.221720581392779, 7.279116924666048, 8.342697265956417, 9.38327274351243, 10.132469278499842, 9.101649032840646, 8.061820280038477, 7.06367516591769, 6.071102018576285, 5.091477705539117, 4.132521073305599, 3.061261243548125, 2.0748122453869446, 1.9909838344592652, 1.0451630053618195, 2.010373014813984, 3.069201081649391, 4.001063073562417, 5.019863636170948, 5.954400517284819, 6.97731137208696, 7.949755222970679, 8.950157467590921, 10.018285690803893, 10.974973358959259, 10.014448885617325, 9.002027978883916, 8.00199403827971, 7.039675707142296, 6.003114886180877, 4.973221010495784, 3.9879054706260235, 3.012682056369134, 2.9570904827285442, 1.976382339712602, 2.995520585046875, 3.942541109672344, 4.982422257411577, 5.97765741050656, 6.92194560883693, 7.943762391613587, 8.948794131612319, 9.879215563834249, 10.926165161279915, 11.875239554347722, 10.815907730219427, 9.855250495675392, 8.884126122158328, 7.90849047335223, 6.957328112311781, 5.901625001248788, 4.853041139138853, 3.907087791283219, 3.9699483873338854, 2.9553645916289204, 3.978752794258059, 4.946562033742465, 5.971591052156976, 6.904789607683626, 7.895513103345617, 8.939826977403824, 9.990932704063075, 10.915165802884324, 11.940909870013478, 12.682463466808638, 11.737453343756057, 10.758210561222473, 9.752381113187653, 8.732965149137733, 7.713738165163703, 6.772885835720309, 5.82831891938595, 4.862320715011071, 4.981175285227101, 4.0226628134910225, 4.983314778156938, 5.947532439173479, 6.895827621277496, 7.847105508945802, 8.830432923491733, 9.850332059631793, 10.792087465117293, 11.8374929532925, 12.909060103157774, 13.637339074609002, 12.6630460518192, 11.733627215347454, 10.694676307040787, 9.701507505991344, 8.78835716149702, 7.784872719331368, 6.8477786666847305, 5.789159155732914], [7.711697447820202, 8.670672703093132, 9.650009716530343, 10.640884858002924, 11.669119497633972, 12.62423330868083, 13.651577122298807, 14.66605260470639, 13.844691248994629, 12.823178055872935, 11.769865379691932, 10.779448025340676, 9.714395300890498, 8.70600286795469, 7.7355293273316725, 6.853165410230567, 5.924363973297586, 4.927617198349637, 5.871833797418369, 6.898571393768476, 8.730603225466778, 9.725977049083156, 10.640522594834348, 11.58905981603804, 12.648910209815872, 13.603435226998085, 14.601703825918996, 15.593699639712643, 14.67642476501357, 13.604038460630214, 12.650642772200335, 11.690600698495185, 10.631790758768163, 9.615363586350893, 8.662657322902326, 7.8590462147792035, 6.84981165078689, 5.957942034813917, 6.919923793250899, 7.957333001655721, 9.774325878500505, 10.715481018323397, 11.619897056165012, 12.578846894382531, 13.576563476459297, 14.589377120802713, 15.604433925254515, 16.607417707620666, 15.591754718838288, 14.584499998307294, 13.564286728555023, 12.633493739765854, 11.581223510194611, 10.585248675756917, 9.610949902495156, 8.841538744061696, 7.922745917306674, 6.971343879839186, 7.845321944334065, 8.797151274005898, 10.79267392349779, 11.726570957444599, 12.18755390352295, 13.1161629230276, 13.646032431300567, 14.671474390223274, 15.619955167675846, 16.611063702078066, 16.54478846298142, 15.568063072146956, 14.56761202645005, 13.49943669642555, 12.535533415329423, 11.572984974973673, 10.63085585843675, 9.780298454249465, 8.851779827809333, 7.999051913632414, 8.83115613267851, 9.83973881660059, 11.718249574921405, 11.91308424785892, 11.131572263978015, 12.15639807674221, 12.663770509540226, 13.729578679455429, 14.730638650747805, 15.616799542217485, 16.59091686611544, 16.45556569055765, 15.505925721169483, 14.4388063968381, 13.523869211487098, 12.545138175308866, 11.609685104666331, 10.812585111770883, 9.850875689563146, 9.048703539754737, 9.77701891454143, 10.809957632546622, 11.72101287054869, 10.8721171336145, 10.1855721629981, 11.10135133875114, 11.72120767291985, 12.748787460095137, 13.6859629138862, 14.654492675083022, 15.658963508480253, 16.390387446236165, 16.352137421949326, 15.399736020691682, 14.442316037944067, 13.513357089608943, 12.535546719683813, 11.781471580539293, 10.871116062455291, 10.04712852616235, 10.724700941998991, 11.68744422141956, 10.77698212775364, 9.873281797528527, 9.111752082085498, 10.073933677735646, 10.750435935268959, 11.801225942942427, 12.730671059558777, 13.677034024931197, 14.638458232538593, 15.448633538314201, 16.37541578351046, 16.423621627638195, 15.508019808898625, 14.51780059681811, 13.488026643112851, 12.84868538725806, 11.83336970709035, 11.022990463562245, 11.744256367695382, 11.64378281503587, 9.76575075446905, 8.890999123608125, 8.129441004934062, 9.042856732154164, 9.725080086389562, 10.77507511600543, 11.754379612667897, 12.695652040998032, 13.675538467653272, 14.507159501703544, 15.41411007853634, 16.437438107979883, 16.54118077961147, 15.521486303932607, 14.561385111227958, 13.81953057195933, 12.889943971858692, 12.085036000675885, 11.69269349257101, 10.706696585161325, 8.796331613832175, 7.8704023291602265, 7.092291324690247, 7.98921562803038, 8.79431945789053, 9.785105358011442, 10.721386455242081, 11.691604018990443, 12.656174655009949, 13.468945001653463, 14.402066886824567, 15.415075275361888, 16.35023300042109, 15.49192300764263, 14.532088701341076, 13.544411474881953, 12.645605680175736, 11.70985925819671, 10.772665082822783, 9.739257981676243, 7.8582519110719495, 6.883639762895827, 6.059316358704952, 6.993620525957355, 7.83058700620322, 8.841466893717444, 9.772789618318013, 10.71492441192243, 11.592529588920925, 12.523184524340408, 13.500392063249214, 14.425565521986256, 15.364525757065124, 14.558202510828313, 13.571215918595385, 12.582293770417545, 11.642910335115634, 10.715571347021646, 9.773337204503651, 8.758569456493214, 6.8120299342810435, 5.8744405453301045, 5.077350513408333, 5.965875671236081, 6.8968443589108075, 7.862785091569554, 8.724370418975013, 9.697686339759876, 10.663565791643826, 11.660699004422336, 12.592322030301181, 13.571148201721149, 14.5173639718867, 13.679694251747055, 12.613982689305248, 11.663174142610142, 10.67886074188762, 9.684861725238084, 8.719916877384097, 7.741864723820855, 5.855972097634438, 4.928018985688795, 4.097006642564066, 4.9882416967975285, 5.857274695662721, 6.90675141602161, 7.7625328520445045, 8.70797863981641, 9.735981763883125, 10.66110309413513, 11.640972472003654, 12.551685499831855, 13.622680075689182, 12.765552564935069, 11.730608705555296, 10.781416440170647, 9.740061982149223, 8.81324815363588, 7.838994841210854, 6.811577476027353, 4.954862242313372, 3.9584554027664423, 3.0382809589934654, 3.954934803319353, 4.839853067821808, 5.847737496446245, 6.815270885222085, 7.741767906528176, 8.710784622571461, 9.730595269319217, 10.698621907547501, 11.62414823768713, 12.611225569211639, 11.876022462579423, 10.805591448821168, 9.849264226465262, 8.896664951881958, 7.907964568587278, 6.858245445637867, 5.988572402662885, 3.955519779198416, 3.018187833192593, 1.9976054899024187, 2.9657249896612714, 3.8870335057314556, 4.901695624303429, 5.850347347903108, 6.788021744001439, 7.84019617323285, 8.869386906981248, 9.753603606314064, 10.79704497190468, 11.83291395554795, 10.893582122024753, 9.869648567927603, 8.84538362386829, 7.861676116929622, 6.872988739845042, 5.879565669229084, 4.93299622869513, 2.9826378282971775, 2.041112447451617, 0.9946511664323477, 1.9908459956712772, 2.9162074916563094, 3.9122537495800755, 4.8751768824441095, 5.899671841734312, 6.8549617328329235, 7.8236395556263485, 8.782284554697506, 9.833891146903174, 10.85661868508421, 9.926883135628872, 9.000083687976616, 7.939416911304888, 6.92526420067923, 5.910723474232574, 4.96681769494345, 3.929657041169879, 2.0814451957479374, 1.0524766469368496, 0.0, 1.0630098824197889, 2.0760921708488564, 3.14199782044885, 4.169826038888735, 5.169243934455929, 6.2266402777291985, 7.290220619019568, 8.33079609657558, 9.379197004292891, 10.154125679777495, 9.114296926975326, 8.11615181285454, 7.123578665513135, 6.1439543524759666, 5.184997720242448, 4.113737890484974, 3.1272888923237945, 2.9513433143285837, 2.005522485231138, 0.9578963678771342, 2.016724434712541, 2.948586426625567, 3.9673869892340976, 4.901923870347968, 5.924834725150109, 6.897278576033828, 7.89768082065407, 8.965809043867042, 9.987941857911895, 10.94846633125383, 9.962387458753232, 8.962353518149026, 8.000035187011612, 6.963474366050194, 5.9335804903651015, 4.948264950495341, 3.973041536238452, 3.917449962597863, 2.93674181958192, 1.943043938110025, 2.890064462735494, 3.9299456104747277, 4.925180763569711, 5.869468961900081, 6.891285744676738, 7.896317484675469, 8.8267389168974, 9.873688514343065, 10.836421254712008, 11.776267210088745, 10.81560997554471, 9.844485602027646, 8.868849953221549, 7.9176875921811, 6.861984481118107, 5.8134006190081715, 4.867447271152538, 4.930307867203204, 3.9157240714982384, 2.9635079288459183, 3.8940853868056147, 4.919114405220126, 5.852312960746777, 6.843036456408767, 7.887350330466974, 8.938456057126226, 9.862689155947475, 10.888433223076628, 11.795558913509765, 12.697812823625375, 11.718570041091791, 10.71274059305697, 9.693324629007051, 8.674097645033022, 7.7332453155896275, 6.788678399255269, 5.82268019488039, 5.94153476509642, 4.93429735804226, 3.9736453933763443, 4.8950557922366285, 5.8433509743406455, 6.7946288620089526, 7.7779562765548835, 8.797855412694943, 9.739610818180443, 10.78501630635565, 11.856583456220925, 12.782542768243374, 13.623405531688517, 12.693986695216772, 11.655035786910105, 10.661866985860662, 9.748716641366338, 8.745232199200688, 7.8081381465540485, 6.749518635602233], [8.774707330239991, 9.733682585512922, 10.713019598950133, 11.703894740422715, 12.732129380053763, 13.687243191100622, 14.578453198833047, 13.667132396721255, 12.800632717189213, 11.77911952406752, 10.725806847886517, 9.73538949353526, 8.670336769085083, 7.661944336149273, 6.691470795526258, 5.920791420920733, 5.0809078309229925, 5.978202105225981, 6.922418704294714, 7.9491563006448205, 9.793613107886568, 10.788986931502945, 11.703532477254136, 12.652069698457828, 13.71192009223566, 14.666445109417877, 15.528579902453236, 14.684128859001564, 13.632366233208154, 12.559979928824799, 11.60658424039492, 10.64654216668977, 9.58773222696275, 8.57130505454548, 7.618598791096913, 6.926672225469369, 6.006355508412296, 6.9346773530764745, 7.970508700127243, 9.007917908532066, 10.837335760920293, 11.778490900743185, 12.6829069385848, 13.246913035328026, 13.647894017245, 14.594827856456199, 15.566568768727807, 15.563359175815254, 14.547696187032875, 13.54044146650188, 12.52022819674961, 11.58943520796044, 10.537164978389198, 9.541190143951503, 8.566891370689742, 7.9091647547518615, 7.0792897749320804, 7.948079198101743, 8.895906851210409, 9.847736180882242, 11.855683805917579, 12.789580839864387, 12.973957953823625, 12.182358668222301, 12.586056750842115, 13.611498709764822, 14.559979487217394, 15.551088021619616, 15.500729931176007, 14.524004540341544, 13.523553494644636, 12.455378164620136, 11.49147488352401, 10.52892644316826, 9.586797326631336, 8.92024102333824, 8.008323685434739, 8.943441761241449, 9.881741039554854, 10.890323723476934, 12.781259457341193, 12.810765403159143, 11.917976314278691, 11.117840232524728, 11.603794829081775, 12.669602998996979, 13.670662970289351, 14.556823861759032, 15.530941185656987, 15.411507158752235, 14.461867189364067, 13.394747865032686, 12.479810679681684, 11.501079643503452, 10.565626572860918, 9.96912896939629, 9.007419547188555, 9.936282896965757, 10.827603821417773, 11.860542539422966, 12.618694025848914, 11.769798288914723, 10.971976213298777, 10.062793494533658, 10.661231992461397, 11.688811779636683, 12.625987233427747, 13.594516994624568, 14.598987828021802, 15.33041176577771, 15.308078890143912, 14.355677488886268, 13.398257506138654, 12.46929855780353, 11.4914881878784, 10.938015438164701, 10.0276599200807, 10.93470788337337, 11.775285848875335, 12.738029128295903, 11.674663283053865, 10.77096295282875, 9.898156132386175, 9.035375833518163, 9.690460254810507, 10.741250262483975, 11.670695379100325, 12.617058344472746, 13.57848255208014, 14.388657857855748, 15.315440103052005, 15.379563095832783, 14.463961277093212, 13.473742065012697, 12.443968111307438, 12.005229244883468, 10.989913564715758, 11.910569820773265, 12.794841274571727, 12.541463970336094, 10.663431909769274, 9.788680278908348, 8.915845055234739, 8.004298887936681, 8.66510440593111, 9.715099435546978, 10.694403932209445, 11.63567636053958, 12.61556278719482, 13.44718382124509, 14.354134398077885, 15.37746242752143, 15.497122247806054, 14.477427772127193, 13.517326579422544, 12.976074429584738, 12.0464878294841, 12.972615357886905, 12.590374647871235, 11.60437774046155, 9.6940127691324, 8.768083484460451, 7.878695374990924, 6.950657783812899, 7.734343777432079, 8.72512967755299, 9.66141077478363, 10.631628338531991, 11.596198974551497, 12.40896932119501, 13.342091206366113, 14.355099594903434, 15.290257319962636, 15.472511553413845, 14.44320038450687, 14.00449585156998, 13.10463750404175, 12.607540413496935, 11.670346238123008, 10.636939136976467, 8.755933066372174, 7.781320918196051, 6.936187758239067, 5.955062681739873, 6.770611325744768, 7.781491213258992, 8.712813937859561, 9.654948731463978, 10.532553908462472, 11.463208843881954, 12.44041638279076, 13.365589841527802, 14.30455007660667, 15.251158616937202, 14.46889707389561, 13.47997492571777, 12.540591490415858, 11.61325250232187, 10.671018359803876, 9.656250611793439, 7.709711089581267, 6.772121700630328, 5.9686474809425105, 4.9273178270186, 5.836868678452356, 6.802809411111102, 7.664394738516561, 8.637710659301423, 9.603590111185373, 10.600723323963882, 11.53234634984273, 12.511172521262697, 13.457388291428249, 14.529071810155648, 13.511663844605472, 12.560855297910367, 11.576541897187845, 10.582542880538309, 9.617598032684322, 8.63954587912108, 6.753653252934662, 5.825700140989019, 4.988303610098244, 3.9496838525800473, 4.797299015204269, 5.846775735563158, 6.702557171586052, 7.648002959357957, 8.676006083424673, 9.601127413676679, 10.580996791545202, 11.491709819373401, 12.562704395230728, 13.568314150603992, 12.62828986085552, 11.679097595470871, 10.637743137449448, 9.710929308936105, 8.736675996511078, 7.709258631327577, 5.862101114970549, 4.856136558066666, 3.935962114293689, 2.9163769591018713, 3.7798773873633564, 4.7877618159877935, 5.755295204763632, 6.681792226069724, 7.6508089421130085, 8.670619588860763, 9.638646227089048, 10.564172557228677, 11.551249888753185, 12.593992012018482, 11.738005426840576, 10.78167820448467, 9.829078929901366, 8.840378546606686, 7.790659423657275, 6.905012550472145, 4.887933757217823, 3.915868988492816, 2.895286645202642, 1.9271671454437893, 2.8270578252730036, 3.8417199438449763, 4.7903716674446555, 5.728046063542986, 6.780220492774397, 7.809411226522795, 8.693627925855612, 9.737069291446229, 10.772938275089498, 11.78772319579573, 10.802062545947011, 9.777797601887698, 8.79409009494903, 7.8054027178644505, 6.811979647248492, 5.865410206714537, 3.9150518063165847, 2.9735264254710243, 1.9270651444517548, 0.9308703152128252, 1.8562318111978575, 2.8522780691216236, 3.8152012019856576, 4.83969616127586, 5.794986052374472, 6.763663875167897, 7.722308874239054, 8.773915466444722, 9.796643004625759, 10.859297113648282, 9.932497665996026, 8.871830889324297, 7.857678178698638, 6.843137452251982, 5.899231672962857, 4.862071019189286, 3.1444550781677263, 2.1154865293566383, 1.0630098824197889, 0.0, 1.0130822884290676, 2.0789879380290612, 3.1068161564689465, 4.1062340520361404, 5.16363039530941, 6.227210736599778, 7.267786214155791, 8.316187121873101, 9.347007367532298, 10.177306809395114, 9.179161695274328, 8.186588547932923, 7.206964234895755, 6.248007602662237, 5.176747772904763, 4.190298774743583, 4.014353196748372, 3.068532367650927, 2.020906250296923, 0.9726659029071268, 1.9045278948201527, 2.923328457428683, 3.857865338542554, 4.880776193344695, 5.853220044228414, 6.853622288848657, 7.921750512061628, 8.943883326106482, 9.904407799448416, 10.916828706181825, 10.025363400568816, 9.063045069431402, 8.026484248469984, 6.996590372784891, 6.011274832915131, 5.036051418658241, 4.980459845017651, 3.999751702001709, 2.993628844986369, 2.0466083203609, 2.885887078669313, 3.881122231764296, 4.825410430094666, 5.847227212871323, 6.852258952870056, 7.782680385091987, 8.829629982537652, 9.792362722906594, 10.835889562577968, 11.796546797122003, 10.907495484447434, 9.931859835641337, 8.980697474600888, 7.924994363537895, 6.8764105014279595, 5.930457153572326, 5.993317749622992, 4.978733953918027, 4.014092835722263, 3.050629244431021, 3.949479660710192, 4.808254428941362, 5.798977924603353, 6.843291798661559, 7.8943975253208105, 8.818630624142061, 9.844374691271215, 10.75150038170435, 11.696510504756931, 12.675753287290515, 11.775750475476759, 10.75633451142684, 9.73710752745281, 8.796255198009415, 7.851688281675057, 6.885690077300178, 6.996567250653781, 5.984882264918604, 5.024230300252689, 4.051599649862035, 4.910976985030812, 5.750570330203538, 6.733897744749468, 7.753796880889527, 8.695552286375028, 9.740957774550235, 10.81252492441551, 11.738484236437959, 12.624485323703382, 13.553904160175128, 12.718045669329893, 11.72487686828045, 10.811726523786126, 9.808242081620476, 8.871148028973836, 7.812528518022021], [9.74823858062687, 10.7072138358998, 11.686550849337012, 12.677425990809592, 13.70566063044064, 14.660774441487499, 13.677672745948263, 12.76635194383647, 11.899852264304428, 10.878339071182735, 9.825026395001732, 8.834609040650475, 7.769556316200298, 6.761163883264488, 5.790690342641473, 5.020010968035949, 5.97739644700954, 6.941145636167248, 7.885362235235981, 8.912099831586087, 10.767144358273447, 11.762518181889824, 12.677063727641016, 13.625600948844708, 13.745243847223865, 14.734478473733674, 14.627799449568451, 13.78334840611678, 12.73158578032337, 11.659199475940014, 10.705803787510135, 9.745761713804985, 8.686951774077965, 7.670524601660695, 6.717818338212128, 6.025891772584586, 6.902844124498844, 7.831165969163022, 8.886416893409539, 9.931542140562788, 11.809093727748115, 12.750248867571006, 13.65643818897168, 13.81643101338777, 12.81759058058044, 13.76452441979164, 14.736265332063248, 14.662578722930471, 13.646915734148092, 12.639661013617097, 11.619447743864827, 10.688654755075657, 9.636384525504415, 8.64040969106672, 7.666110917804958, 7.008384301867078, 7.958243035071824, 8.84456781418829, 9.811815044492706, 10.763644374164539, 12.8274417727454, 13.761338806692208, 13.72362184523158, 12.79501282572693, 11.755753314177555, 12.781195273100263, 13.729676050552834, 14.720784584955057, 14.599949478291222, 13.623224087456759, 12.622773041759853, 11.554597711735353, 10.590694430639227, 9.628145990283477, 8.686016873746551, 8.019460570453457, 8.887276945574483, 9.822395021381192, 10.79764923283715, 11.80623191675923, 13.753017424169014, 13.764544125499532, 12.736239069469889, 11.782993838673312, 10.773491392417215, 11.839299562332418, 12.840359533624794, 13.726520425094474, 14.700637748992428, 14.510726705867453, 13.561086736479286, 12.493967412147903, 11.5790302267969, 10.600299190618669, 9.664846119976133, 9.080605432559246, 9.886372807328296, 10.815236157105499, 11.74351201470007, 12.776450732705262, 13.631776314277982, 12.739476864925, 11.790238968489975, 10.864852050846135, 9.830928555796838, 10.858508342972126, 11.79568379676319, 12.76421355796001, 13.768684391357242, 14.500108329113152, 14.40729843725913, 13.454897036001485, 12.497477053253869, 11.568518104918745, 10.590707734993615, 10.049491901327656, 10.906613180220441, 11.813661143513112, 12.691194042157631, 13.6539373215782, 12.687745571482933, 11.759728500958621, 10.798546024366503, 9.83743438983064, 8.860156818145947, 9.910946825819416, 10.840391942435765, 11.786754907808186, 12.748179115415581, 13.55835442119119, 14.485136666387447, 14.478782642948, 13.563180824208427, 12.572961612127912, 11.543187658422653, 11.116705708046423, 11.8688668248555, 12.789523080913007, 13.710749467854022, 13.554546258765162, 11.676514198198342, 10.793639727046848, 9.816234947215067, 8.806357444249159, 7.834800969266551, 8.884795998882419, 9.864100495544886, 10.805372923875021, 11.78525935053026, 12.616880384580533, 13.523830961413328, 14.547158990856872, 14.596341794921269, 13.576647319242408, 12.61654612653776, 12.170764893102197, 12.925441089623842, 13.851568618026647, 13.603456936300303, 12.617460028890617, 10.707095057561467, 9.773042932598951, 8.779342249439514, 7.851304658261489, 6.904040340767519, 7.894826240888431, 8.83110733811907, 9.801324901867432, 10.765895537886937, 11.578665884530452, 12.511787769701556, 13.524796158238876, 14.459953883298079, 14.57173110052906, 13.542419931622085, 13.199186315087438, 13.983590764181493, 13.620622701926003, 12.683428526552076, 11.650021425405535, 9.769015354801242, 8.79440320662512, 7.879321848173279, 6.898196771674085, 5.940307889080208, 6.951187776594432, 7.882510501195002, 8.824645294799419, 9.702250471797914, 10.632905407217397, 11.610112946126202, 12.535286404863244, 13.474246639942113, 14.420855180272644, 14.537151835747407, 14.161304019551846, 13.553673778844926, 12.626334790750938, 11.684100648232944, 10.669332900222507, 8.722793378010335, 7.785203989059396, 6.981729769371578, 5.940400115447667, 5.006565241787796, 5.972505974446542, 6.834091301852002, 7.807407222636864, 8.773286674520815, 9.770419887299324, 10.70204291317817, 11.680869084598138, 12.62708485476369, 13.698768373491088, 14.52474613303454, 13.573937586339435, 12.589624185616913, 11.595625168967377, 10.63068032111339, 9.652628167550148, 7.76673554136373, 6.838782429418087, 6.001385898527311, 4.962766141009114, 3.9669955785397093, 5.016472298898598, 5.872253734921492, 6.817699522693397, 7.845702646760112, 8.77082397701212, 9.750693354880642, 10.661406382708844, 11.73240095856617, 12.738010713939435, 13.641372149284589, 12.69217988389994, 11.650825425878516, 10.724011597365173, 9.749758284940146, 8.722340919756645, 6.875183403399617, 5.869218846495734, 4.949044402722756, 3.9294592475309384, 2.949573950698797, 3.957458379323233, 4.924991768099073, 5.851488789405163, 6.820505505448448, 7.840316152196204, 8.80834279042449, 9.733869120564119, 10.720946452088628, 11.763688575353925, 12.751087715269641, 11.794760492913738, 10.842161218330434, 9.853460835035754, 8.803741712086342, 7.918094838901213, 5.901016045646891, 4.928951276921884, 3.9083689336317096, 2.940249433872857, 1.9967543886084438, 3.0114165071804164, 3.9600682307800956, 4.897742626878426, 5.949917056109837, 6.971433512707473, 7.83928187605357, 8.882723241644186, 9.918592225287455, 10.933377145993687, 11.815144834376076, 10.790879890316763, 9.807172383378095, 8.818485006293516, 7.82506193567756, 6.878492495143605, 4.928134094745652, 3.986608713900092, 2.9401474328808224, 1.9439526036418928, 1.0259283745332977, 1.9979320193195813, 2.9608551521836155, 3.9853501114738177, 4.9406400025724295, 5.9093178253658545, 6.867962824437012, 7.9195694166426795, 8.942296954823716, 10.010207858994814, 10.93700730664707, 9.884913177753363, 8.870760467127704, 7.856219740681048, 6.912313961391924, 5.875153307618353, 4.157537366596794, 3.1285688177857063, 2.0760921708488564, 1.0130822884290676, 0.0, 1.0659056495999937, 2.093733868039879, 3.0931517636070724, 4.150548106880342, 5.21412844817071, 6.254703925726723, 7.303104833444033, 8.33392507910323, 9.373753831905399, 10.192243983703396, 9.19967083636199, 8.220046523324823, 7.261089891091305, 6.189830061333831, 5.203381063172651, 4.987884447135251, 4.042063618037805, 2.9944375006838007, 1.935609433848394, 1.0037474419353682, 2.022548004543899, 2.95708488565777, 3.979995740459911, 4.95243959134363, 5.952841835963873, 7.020970059176845, 8.043102873221699, 9.003627346563633, 10.016048253297042, 10.998894650955695, 10.03657631981828, 9.000015498856863, 7.97012162317177, 6.98480608330201, 6.00958266904512, 5.95399109540453, 4.973282952388587, 3.9565723759276366, 3.0095518513021675, 1.9851066257845287, 2.9803417788795117, 3.9246299772098814, 4.9464467599865385, 5.951478499985271, 6.881899932207202, 7.928849529652868, 8.891582270021809, 9.935109109693185, 10.89576634423722, 11.866890717754284, 10.905391086028215, 9.954228724987766, 8.898525613924773, 7.849941751814838, 6.903988403959205, 6.966849000009871, 5.952265204304905, 4.97703636666353, 4.013572775372288, 3.0486992078254076, 3.9074739760565778, 4.898197471718568, 5.942511345776774, 6.993617072436026, 7.917850171257276, 8.943594238386432, 9.850719928819565, 10.795730051872146, 11.77497283440573, 12.74928172586364, 11.72986576181372, 10.71063877783969, 9.769786448396296, 8.825219532061936, 7.859221327687057, 7.959510781595048, 6.947825795859871, 5.987173831193956, 4.958491714250045, 4.010196532146028, 4.849789877318753, 5.833117291864683, 6.853016428004742, 7.794771833490243, 8.84017732166545, 9.911744471530724, 10.837703783553174, 11.723704870818597, 12.653123707290343, 13.691576919716773, 12.69840811866733, 11.785257774173006, 10.781773332007356, 9.844679279360717, 8.7860597684089], [10.814144230226862, 11.773119485499793, 12.752456498937004, 13.743331640409586, 14.727806568906631, 13.772692757859772, 12.745348944241794, 11.834028142130002, 10.967528462597958, 9.946015269476266, 8.892702593295263, 7.902285238944006, 6.837232514493829, 5.8288400815580195, 4.858366540935004, 5.8468441610559, 6.804229640029491, 7.828602237257767, 8.804623784046614, 9.831361380396721, 11.804155677843065, 12.828423831489816, 13.742969377241007, 14.691506598444699, 14.647388100333922, 14.121757375207892, 13.695475647861983, 12.851024604410313, 11.799261978616903, 10.726875674233547, 9.773479985803668, 8.813437912098516, 7.7546279723714955, 6.7382007999542255, 5.7854945365056585, 6.852724965604537, 7.729677317518795, 8.657999162182973, 9.71325008642949, 10.75837533358274, 12.635926920768066, 13.577082060590957, 14.533841652419547, 14.718575266497828, 13.719734833690497, 13.082157646308344, 14.034475823331439, 13.730254921224002, 12.714591932441623, 11.707337211910628, 10.687123942158358, 9.756330953369188, 8.704060723797946, 7.708085889360251, 6.733787116098489, 7.672420151624612, 8.622278884829358, 9.67140100720824, 10.638648237512657, 11.59047756718449, 13.5112224221685, 14.448636487188796, 14.625766098341638, 13.697157078836987, 12.657897567287613, 12.098828499616967, 13.027886541821026, 13.824931592414087, 13.667625676584755, 12.690900285750292, 11.690449240053384, 10.622273910028884, 9.658370628932758, 8.695822188577008, 7.7536930720400825, 8.683496420210991, 9.551312795332016, 10.486430871138726, 11.480010024300265, 12.488592708222345, 14.436798073592113, 14.66668837860959, 13.638383322579948, 12.685138091783369, 11.675635645527272, 11.042869806452964, 11.973916470761273, 12.761064019711428, 13.673999230960423, 13.578402904160983, 12.628762934772816, 11.561643610441434, 10.646706425090432, 9.6679753889122, 8.732522318269664, 9.74464128231678, 10.550408657085832, 11.479272006863035, 12.425872806163184, 13.458811524168377, 14.541257834264474, 13.64162111803506, 12.692383221600034, 11.766996303956194, 10.733072808906895, 9.992065280108605, 10.929240733899668, 11.798757152576965, 12.742045873325237, 13.473469811081147, 13.47497463555266, 12.522573234295017, 11.5651532515474, 10.636194303212276, 9.658383933287146, 10.63762145598495, 11.564954456869941, 12.477696993270648, 13.373554833620746, 14.336298113041314, 13.597227091469426, 12.661872754068678, 11.70069027747656, 10.739578642940698, 9.762301071256005, 9.021751838029486, 9.881899486204972, 10.760116389776181, 11.721540597383576, 12.531715903159185, 13.458498148355442, 13.546458841241531, 12.630857022501958, 11.640637810421444, 10.610863856716184, 11.5650430039729, 12.527208101505, 13.453558930670543, 14.393110259317137, 14.464027778751655, 12.585995718184835, 11.695783980156907, 10.718379200325124, 9.708501697359216, 8.736945222376608, 7.995601011092489, 8.905608039314092, 9.778734405843016, 10.758620832498256, 11.590241866548528, 12.497192443381323, 13.520520472824867, 13.6640179932148, 12.64432351753594, 11.68422232483129, 12.619102189028673, 13.548688789129312, 14.487644113481334, 14.512938456286795, 13.52694154887711, 11.61657657754796, 10.675187185709008, 9.681486502549571, 8.753448911371546, 7.806184593877576, 6.9532699016174035, 7.839079147304107, 8.774686383835427, 9.739257019854932, 10.552027366498447, 11.48514925166955, 12.498157640206871, 13.433315365266074, 13.639407298822592, 12.610096129915616, 13.59777335637474, 14.525490939070304, 14.530104221912495, 13.592910046538568, 12.559502945392028, 10.678496874787735, 9.703884726611612, 8.781466101283335, 7.8003410247841405, 6.842452142190265, 6.009631437323405, 6.855871983162997, 7.798006776767414, 8.675611953765909, 9.606266889185392, 10.583474428094197, 11.50864788683124, 12.447608121910108, 13.39421666224064, 13.604828034040938, 14.559891060839147, 14.463155298831419, 13.535816310737431, 12.593582168219436, 11.578814420209, 9.632274897996828, 8.69468550904589, 7.891211289358072, 6.849881635434161, 5.9087094948978525, 4.945867456414537, 5.807452783819996, 6.780768704604859, 7.74664815648881, 8.74378136926732, 9.675404395146163, 10.654230566566131, 11.600446336731682, 12.672129855459081, 13.70697748709394, 14.483419106325927, 13.499105705603405, 12.50510668895387, 11.540161841099883, 10.56210968753664, 8.676217061350222, 7.74826394940458, 6.9108674185138055, 5.872247660995608, 4.869139831649766, 3.9898337808665927, 4.845615216889486, 5.791061004661392, 6.819064128728107, 7.744185458980113, 8.724054836848635, 9.634767864676839, 10.705762440534166, 11.71137219590743, 12.746316055287203, 13.601661403886432, 12.560306945865008, 11.633493117351666, 10.659239804926639, 9.631822439743138, 7.78466492338611, 6.778700366482227, 5.8585259227092505, 4.838940767517432, 3.8517182038088533, 2.9308198612912277, 3.898353250067067, 4.824850271373158, 5.793866987416443, 6.813677634164199, 7.781704272392484, 8.707230602532114, 9.694307934056622, 10.73705005732192, 11.771210634785778, 12.704242012900231, 11.751642738316926, 10.762942355022247, 9.713223232072835, 8.827576358887708, 6.810497565633384, 5.838432796908378, 4.817850453618203, 3.8497309538593503, 2.8988986417185, 1.984777989148411, 2.93342971274809, 3.8711041088464206, 4.923278538077832, 5.905527863107479, 6.773376226453576, 7.816817592044193, 8.85268657568746, 9.867471496393692, 10.835267753892213, 11.700361410303257, 10.71665390336459, 9.72796652628001, 8.734543455664053, 7.787974015130098, 5.837615614732146, 4.896090233886586, 3.8496289528673158, 2.853434123628386, 1.928072627643354, 0.9320263697195876, 1.8949495025836216, 2.919444461873824, 3.8747343529724354, 4.84341217576586, 5.802057174837018, 6.853663767042685, 7.876391305223722, 8.94430220939482, 9.871101657047076, 10.794394697739857, 9.780241987114199, 8.765701260667543, 7.821795481378418, 6.7846348276048465, 5.2234430161967875, 4.1944744673856995, 3.14199782044885, 2.0789879380290612, 1.0659056495999937, 0.0, 1.0278282184398853, 2.0272461140070788, 3.0846424572803475, 4.148222798570716, 5.188798276126729, 6.237199183844039, 7.268019429503235, 8.307848182305404, 9.305993296426191, 10.265576485961985, 9.285952172924818, 8.326995540691298, 7.255735710933824, 6.269286712772645, 6.053790096735245, 5.107969267637799, 4.060343150283795, 3.001515083448388, 2.069653091535362, 1.074803637563761, 2.009340518677632, 2.9905927299837565, 3.963036580867476, 4.963438825487719, 6.0315670487006905, 7.053699862745544, 8.014224336087478, 9.026645242820887, 10.026679183425093, 10.988997514562508, 10.065921148456857, 9.036027272771765, 8.050711732902004, 7.075488318645114, 7.019896745004524, 6.039188601988581, 5.022478025527631, 4.075457500902162, 3.0432531302680252, 2.0480179771730422, 2.992306175503412, 4.014122958280069, 5.0191546982788005, 5.9495761305007315, 6.9965257279463975, 7.95925846831534, 8.94570609921703, 9.906363333761066, 10.87748770727813, 11.853123356084227, 11.020134374587759, 9.964431263524766, 8.915847401414831, 7.969894053559199, 8.032754649609865, 6.980670610590966, 5.957282407961828, 4.974663920474416, 3.9496349020599055, 2.9751501743501083, 3.9658736700120985, 5.010187544070305, 6.061293270729557, 6.985526369550806, 8.011270436679961, 8.918396127113096, 9.863406250165678, 10.842649032699262, 11.848478480734082, 12.795771411413712, 11.776544427439683, 10.835692097996288, 9.891125181661929, 8.92512697728705, 8.878772330405681, 7.867087344670504, 6.906435380004589, 5.859427408484543, 4.911132226380526, 3.917466075612284, 4.900793490158215, 5.9206926262982735, 6.862448031783774, 7.907853519958982, 8.979420669824256, 9.905379981846703, 10.791381069112129, 11.720799905583874, 12.788837987804856, 13.764313768267323, 12.851163423772999, 11.847678981607348, 10.91058492896071, 9.851965418008893], [11.702539318594987, 12.661514573867917, 13.640851587305129, 14.63172672877771, 13.705906432172755, 12.750792621125896, 11.72344880750792, 10.812128005396128, 9.945628325864083, 9.017184353921811, 7.9638716777408085, 6.973454323389551, 5.923493626707283, 4.9151011937714735, 5.7228105206662, 6.7112881407870955, 7.668673619760686, 8.693046216988963, 9.669067763777809, 10.695805360127917, 12.66859965757426, 13.71681891985794, 14.631364465609131, 15.579901686812823, 14.71922916595296, 13.729994539443151, 12.673575511128108, 11.861775961258118, 10.932721523316681, 9.860335218933326, 8.906939530503447, 7.952801896243137, 6.893991956516116, 5.877564784098846, 6.649938516236855, 7.717168945335732, 8.594121297249991, 9.522443141914168, 10.577694066160685, 11.622819313313935, 13.500370900499261, 14.441526040322152, 15.398285632150742, 15.597975264426694, 14.599134831619363, 13.950771813084401, 13.129514848073773, 12.905850106422287, 11.890187117639908, 10.882932397108913, 9.883380194972165, 8.952587206182995, 7.909207582191648, 6.933440705746731, 7.598231095829685, 8.53686413135581, 9.486722864560555, 10.535844986939436, 11.503092217243852, 12.454921546915685, 14.375666401899696, 15.313080466919994, 15.505166096270504, 14.576557076765853, 13.537297565216479, 12.967442666393024, 12.12292556656336, 12.905101188636177, 12.877985519771652, 11.901260128937189, 10.900809083240283, 9.832633753215783, 8.868730472119656, 7.9211770049634875, 8.618137051771278, 9.547940399942188, 10.415756775063214, 11.350874850869923, 12.344454004031462, 13.353036687953542, 15.30124205332331, 15.546088376538455, 14.517783320508812, 13.564538089712235, 12.555035643456138, 11.911483973229021, 11.068955495503607, 11.841233615933518, 12.754168827182513, 12.788762747347883, 11.839122777959716, 10.772003453628333, 9.85706626827733, 8.89333020529868, 9.59696629800086, 10.609085262047977, 11.414852636817027, 12.34371598659423, 13.290316785894381, 14.323255503899574, 15.499469767311556, 14.521021115963924, 13.571783219528898, 12.646396301885058, 11.612472806835761, 10.860679446884662, 10.024279758642002, 10.878926748799055, 11.822215469547327, 12.553639407303235, 12.68533447873956, 11.732933077481915, 10.840428668881982, 9.911469720546858, 10.522827913018341, 11.502065435716146, 12.429398436601137, 13.342140973001843, 14.237998813351943, 15.200742092772511, 14.555439024516508, 13.541272751997544, 12.580090275405427, 11.618978640869564, 10.64170106918487, 9.890366004805543, 8.962069082427062, 9.840285985998271, 10.801710193605667, 11.611885499381273, 12.538667744577532, 12.75681868442843, 11.90613243983654, 10.925138889021643, 11.47530783644738, 12.429486983704095, 13.391652081236195, 14.318002910401738, 15.257554239048336, 15.46898846196301, 13.544207651231917, 12.575183978085771, 11.59777919825399, 10.587901695288082, 9.616345220305474, 8.864215177868546, 7.9857776355361825, 8.858904002065106, 9.838790428720346, 10.670411462770616, 11.577362039603413, 12.600690069046957, 12.939293410549382, 11.928824596136138, 12.548666304562486, 13.483546168759869, 14.413132768860507, 15.35208809321253, 15.51789913949815, 14.531902232088465, 12.574788510595042, 11.554587183637874, 10.560886500478437, 9.632848909300412, 8.685584591806442, 7.8218840683934605, 6.919248743526197, 7.8548559800575175, 8.819426616077022, 9.632196962720537, 10.56531884789164, 11.578327236428962, 12.513484961488164, 12.956892748801696, 13.474540109646812, 14.462217336105935, 15.389934918801499, 15.53506490512385, 14.597870729749923, 13.564463628603383, 11.636708807834816, 10.631569732572625, 9.6608660992122, 8.679741022713007, 7.721852140119131, 6.878245604099462, 5.936041579385087, 6.878176372989504, 7.755781549988, 8.686436485407482, 9.663644024316287, 10.58881748305333, 11.527777718132198, 12.47438625846273, 13.461372850695657, 14.45719928839952, 15.396582723701432, 14.540776993948786, 13.598542851430791, 12.583775103420354, 10.637235581208182, 9.699646192257243, 8.858143192932824, 7.788777531741592, 6.7881094928267185, 5.814481623190595, 4.887622380042087, 5.86093830082695, 6.826817752710901, 7.823950965489409, 8.744281248629795, 9.723107420049763, 10.669323190215314, 11.741006708942713, 12.770088152963055, 13.72089669965816, 14.50406638881476, 13.510067372165224, 12.545122524311237, 11.567070370747995, 9.681177744561577, 8.753224632615934, 7.91582810172516, 6.877208344206963, 5.874100514861119, 4.8584479476426505, 3.925784813111578, 4.871230600883483, 5.887940982211739, 6.813062312463745, 7.792931690332267, 8.697878530545951, 9.768873106403278, 10.774482861776544, 11.809426721156317, 12.758618986540966, 13.565267629076363, 12.63845380056302, 11.664200488137993, 10.636783122954492, 8.789625606597465, 7.783661049693581, 6.863486605920604, 5.8439014507287865, 4.856678887020207, 3.908292904712678, 2.9785228462891586, 3.8937271248567904, 4.862743840900075, 5.876788300033312, 6.844814938261598, 7.770341268401227, 8.757418599925735, 9.800160723191032, 10.811346613087565, 11.854749559400293, 12.756603421528279, 11.7679030382336, 10.718183915284188, 9.832537042099062, 7.815458248844737, 6.843393480119731, 5.822811136829557, 4.8546916370707045, 3.9038593249298543, 2.962251032569861, 2.013599308970182, 2.9399809623300532, 3.9789992307258464, 4.9456638414092655, 5.813512204755362, 6.856953570345979, 7.892822553989247, 8.90760747469548, 9.875403732194, 10.897812365132982, 11.721614586575942, 10.732927209491363, 9.739504138875406, 8.792934698341451, 6.8425762979434985, 5.901050917097939, 4.85458963607867, 3.8583948068397405, 2.933033310854708, 1.936987052930942, 0.9740639200669081, 1.9595804401756112, 2.914870331274223, 3.8835481540676473, 4.842193153138805, 5.893799745344472, 6.916527283525509, 7.9844381876966075, 8.911237635348863, 9.971904412020592, 10.785202670325551, 9.770661943878896, 8.82675616458977, 7.789595510816199, 6.251271234636673, 5.222302685825585, 4.169826038888735, 3.1068161564689465, 2.093733868039879, 1.0278282184398853, 0.0, 0.9994178955671936, 2.0568142388404627, 3.1203945801308315, 4.1609700576868445, 5.209370965404155, 6.240191211063351, 7.280019963865521, 8.278165077986309, 9.270738225327714, 10.25036253836488, 9.354823759131182, 8.28356392937371, 7.29711493121253, 6.942185185103369, 5.996364356005924, 4.94873823865192, 3.8899101718165134, 2.9580481799034875, 1.9392476172949569, 1.004710736181086, 1.9627645115438717, 2.9352083624275913, 3.935610607047834, 5.003738830260806, 6.02587164430566, 6.986396117647594, 7.998817024381003, 8.998850964985209, 9.961169296122623, 10.954316236824981, 9.92442236113989, 8.939106821270128, 7.963883407013238, 7.908291833372648, 6.9264338936779515, 5.898549928145578, 4.951529403520109, 3.907697109999221, 2.912461956904238, 2.078567287716866, 3.025197492174648, 3.997254561544925, 4.927675993766856, 5.974625591212522, 6.937358331581464, 7.917877880777147, 8.878535115321181, 9.849659488838245, 10.825295137644343, 11.776457498684792, 10.85282635189289, 9.804242489782956, 8.858289141927322, 8.903228061098725, 7.8451145903221615, 6.821726387693023, 5.839107900205612, 4.814078881791101, 3.839594154081304, 3.0521347822255525, 4.021262077964884, 5.050189986525547, 5.963626232816932, 6.989370299946085, 7.896495990379221, 8.841506113431803, 9.820748895965387, 10.826578344000207, 11.780765254150278, 12.664939515807808, 11.724087186364413, 10.779520270030053, 9.813522065655174, 9.743216310136877, 8.7315313244017, 7.770879359735784, 6.723871388215739, 5.7755762061117215, 4.78191005534348, 3.987054602371668, 4.9918617107438195, 5.933617116229319, 6.979022604404527, 8.008853673193624, 8.883479845112829, 9.769480932378254, 10.69889976885, 11.766937851070981, 12.74930761100389, 13.738572950090129, 12.736074069975473, 11.798980017328834, 10.740360506377018], [12.684086053192722, 13.643061308465652, 14.622398321902864, 13.734723176236612, 12.706488536605564, 11.751374725558705, 10.724030911940726, 9.812710109828934, 8.94621043029689, 8.017766458354616, 6.964453782173614, 5.974036427822356, 4.944627872912425, 5.884130285438718, 6.704357255263933, 7.692834875384829, 8.65022035435842, 9.674592951586696, 10.65061449837554, 11.677352094725649, 13.650146392171994, 14.698365654455676, 15.612911200206867, 14.776524577216158, 13.719811270385769, 12.73057664387596, 11.674157615560915, 10.862358065690925, 9.933303627749487, 8.860917323366131, 7.907521634936252, 7.036316216635418, 5.981701997022827, 6.84659387576609, 7.631485250834587, 8.698715679933466, 9.575668031847725, 10.503989876511902, 11.559240800758419, 12.604366047911668, 14.481917635096995, 15.423072774919886, 16.379832366748477, 15.646304969836525, 14.647464537029194, 13.708090317394156, 12.676887714896434, 11.906432210855092, 10.890769222072713, 9.883514501541718, 8.928367328400697, 8.036101526575278, 6.99691762269836, 7.902469797413976, 8.579777830427417, 9.518410865953541, 10.468269599158287, 11.51739172153717, 12.484638951841585, 13.436468281513418, 15.357213136497428, 16.294627201517727, 16.369804250161515, 15.441195230656863, 14.401935719107488, 13.832080820284034, 12.935972568642157, 12.005166671003188, 11.906687675864006, 10.942190221186534, 9.98742614115407, 8.920343793722495, 7.956440512626369, 8.890206096630733, 9.599683786369011, 10.52948713453992, 11.397303509660945, 12.332421585467655, 13.326000738629194, 14.334583422551274, 16.282788787921042, 16.410726530429464, 15.382421474399823, 14.429176243603244, 13.419673797347148, 12.776122127120031, 11.882002497582404, 10.94129909830053, 11.77179890013225, 11.876472787854594, 10.926832818466426, 9.859713494135045, 8.944776308784043, 9.862359296965925, 10.578513032598593, 11.590631996645708, 12.39639937141476, 13.325262721191962, 14.271863520492113, 15.304802238497306, 16.364107921202567, 15.385659269854935, 14.43642137341991, 13.51103445577607, 12.47711096072677, 11.725317600775671, 10.888917912533012, 9.978992231166066, 10.839845542497065, 11.566108746866883, 11.773044519246271, 10.820643117988627, 9.971549277507204, 10.880498812214103, 11.504374647616075, 12.48361217031388, 13.41094517119887, 14.323687707599575, 15.219545547949675, 16.182288827370243, 15.420077178407519, 14.405910905888554, 13.444728429296436, 12.483616794760573, 11.50633922307588, 10.755004158696552, 9.826707236318072, 8.940351468365282, 9.819340266555404, 10.624354838944921, 11.551137084141178, 11.844528724935142, 11.037253048461762, 11.894167980688888, 12.456854571045113, 13.41103371830183, 14.373198815833929, 15.29954964499947, 16.239100973646067, 16.373895595304706, 14.408845805122928, 13.439822131976783, 12.462417352145, 11.452539849179091, 10.480983374196484, 9.728853331759556, 8.850415789427192, 7.958969484432118, 8.856420501670083, 9.682880802334264, 10.589831379167059, 11.613159408610603, 12.070414019174605, 12.897853687803384, 13.53021303916022, 14.465092903357604, 15.394679503458242, 16.333634827810265, 16.422806272839846, 15.436809365430163, 13.439426664486053, 12.419225337528884, 11.425524654369447, 10.497487063191421, 9.550222745697452, 8.68652222228447, 7.783886897417206, 6.954921462424529, 7.837056689026759, 8.644666302284183, 9.577788187455287, 10.590796575992607, 11.52595430105181, 12.420576094840692, 13.449887263747668, 14.431786332427574, 15.359503915123138, 16.433078953457112, 15.522197302594103, 14.488790201447562, 12.501346961725828, 11.496207886463637, 10.525504253103211, 9.544379176604016, 8.58649029401014, 7.742883757990471, 6.800679733276096, 5.978241855356515, 6.768250889551647, 7.698905824971129, 8.676113363879933, 9.601286822616975, 10.540247057695844, 11.486855598026375, 12.473842190259303, 13.469668627963166, 14.409052063265078, 15.483310691614598, 14.576806414368464, 13.562038666358028, 11.636653476775376, 10.666901012906756, 9.722781346823831, 8.6534156856326, 7.652747646717727, 6.6791197770816035, 5.752260533933096, 4.926432802914665, 5.839287092274548, 6.8356400973645055, 7.744863353062601, 8.72368952448257, 9.669905294648121, 10.74158881337552, 11.77067025739586, 12.721478804090966, 13.705792204813488, 14.509485267732416, 13.544540419878428, 12.566488266315186, 10.68059564012877, 9.752642528183127, 8.878841352606816, 7.84022159508862, 6.792833869214885, 5.723086101533659, 4.790422967002586, 3.936725102971198, 4.888523086644545, 5.813644416896551, 6.793513794765073, 7.698460634978757, 8.769455210836083, 9.77506496620935, 10.810008825589122, 11.759201090973772, 12.800555548995195, 13.637871696130214, 12.663618383705186, 11.636201018521685, 9.789043502164658, 8.783078945260774, 7.862904501487797, 6.84331934629598, 5.7826826139803895, 4.772931058603686, 3.8431610001801664, 2.894309229289597, 3.8633259453328814, 4.877370404466119, 5.845397042694405, 6.770923372834034, 7.758000704358542, 8.80074282762384, 9.811928717520372, 10.8553316638331, 11.807930938416405, 12.767320933800791, 11.717601810851379, 10.831954937666255, 8.81487614441193, 7.842811375686924, 6.82222903239675, 5.854109532637898, 4.841551305032842, 3.826889186460869, 2.8782374628611898, 1.9405630667628597, 2.9795813351586533, 3.9462459458420724, 4.814094309188169, 5.857535674778786, 6.893404658422054, 7.908189579128286, 8.875985836626807, 9.898394469565789, 10.882101976504456, 11.732345105058556, 10.738922034442597, 9.792352593908642, 7.841994193510692, 6.900468812665132, 5.854007531645863, 4.8578127024069335, 3.9324512064219017, 2.9364049484981356, 1.9734818156341016, 0.9601625446084175, 1.9154524357070293, 2.884130258500454, 3.8427752575716116, 4.894381849777279, 5.917109387958316, 6.985020292129414, 7.91181973978167, 8.9724865164534, 9.986639227079058, 10.770079839446089, 9.826174060156964, 8.789013406383393, 7.250689130203866, 6.221720581392778, 5.1692439344559284, 4.10623405203614, 3.0931517636070724, 2.0272461140070788, 0.9994178955671936, 0.0, 1.057396343273269, 2.1209766845636375, 3.1615521621196505, 4.209953069836962, 5.240773315496158, 6.280602068298328, 7.278747182419115, 8.27132032976052, 9.250944642797688, 10.209901275031207, 9.282981824940903, 8.296532826779723, 7.923731919701103, 6.977911090603657, 5.930284973249653, 4.871456906414246, 3.93959491450122, 2.9207943518926895, 1.9862574707788188, 0.9633466159766779, 1.9357904668603974, 2.93619271148064, 4.004320934693611, 5.026453748738465, 5.986978222080399, 6.999399128813808, 7.999433069418015, 8.961751400555428, 9.998312221516846, 10.905969095737623, 9.920653555867862, 8.945430141610972, 8.889838567970383, 7.907980628275683, 6.88009666274331, 5.9330761381178405, 4.889243844596954, 3.8940086915019707, 3.047596379384111, 2.025779596607454, 2.997836665977731, 3.928258098199662, 4.975207695645328, 5.93794043601427, 6.918459985209952, 7.879117219753987, 8.850241593271052, 9.82587724207715, 10.777039603117599, 11.832742714180592, 10.785789224380691, 9.839835876525058, 9.884774795696458, 8.826661324919895, 7.803273122290757, 6.820654634803345, 5.795625616388834, 4.821140888679037, 4.021163873892798, 3.02184418239769, 4.050772090958353, 4.964208337249737, 5.989952404378891, 6.897078094812027, 7.842088217864609, 8.821331000398194, 9.827160448433014, 10.781347358583085, 11.799061468553784, 12.705633920962148, 11.761067004627789, 10.79506880025291, 10.724763044734608, 9.713078058999432, 8.752426094333517, 7.705418122813471, 6.757122940709454, 5.763456789941213, 4.956083694038913, 3.9924438151766246, 4.934199220662125, 5.979604708837332, 7.009435777626429, 7.884061949545635, 8.770063036811061, 9.699481873282807, 10.767519955503788, 11.749889715436696, 12.739155054522936, 13.717620804573208, 12.780526751926569, 11.721907240974753], [13.687574023010228, 14.646549278283159, 13.78419858575926, 12.79332344428668, 11.765088804655631, 10.809974993608773, 9.782631179990794, 8.871310377879, 8.004810698346958, 7.1382001910438, 6.104914612960023, 5.179502996135686, 5.948115842729931, 6.887618255256226, 7.7078452250814395, 8.696322845202335, 9.653708324175927, 10.678080921404202, 11.654102468193049, 12.680840064543155, 14.6536343619895, 15.701853624273182, 14.774711464063262, 13.835124845266225, 12.778411538435837, 11.789176911926027, 10.732757883610983, 9.920958333740991, 9.060356504740048, 8.00137815415254, 7.0479824657226615, 6.241782784948748, 6.985189966840333, 7.850081845583598, 8.634973220652094, 9.702203649750972, 10.57915600166523, 11.507477846329408, 12.562728770575925, 13.607854017729174, 15.4854056049145, 16.426560744737394, 15.671070958050246, 14.704905237886592, 13.706064805079262, 12.766690585444223, 11.735487982946502, 10.980251217215732, 10.031230052859122, 9.023975332328128, 8.068828159187106, 7.241568094888607, 8.000405592515866, 8.905957767231484, 9.583265800244924, 10.521898835771047, 11.471757568975793, 12.520879691354676, 13.488126921659092, 14.439956251330925, 16.360701106314934, 17.298115171335233, 16.654914879360327, 15.755259512381569, 14.716000000832194, 13.690558041909487, 12.742077264456915, 12.032698856808697, 11.047148506650416, 10.082651051972944, 9.12788697194048, 8.229932960709254, 8.959928482443875, 9.89369406644824, 10.603171756186518, 11.532975104357426, 12.400791479478452, 13.335909555285161, 14.3294887084467, 15.33807139236878, 17.28627675773855, 17.465898692327624, 16.437593636297983, 15.484348405501406, 14.47484595924531, 13.831294289018192, 12.937174659480565, 11.99647126019869, 11.019618379626127, 11.1327426686607, 10.183102699272533, 9.169302661121804, 9.948264278601549, 10.865847266783433, 11.5820010024161, 12.594119966463214, 13.399887341232265, 14.328750691009468, 15.27535149030962, 16.308290208314812, 17.41928008310073, 16.440831431753093, 15.491593535318069, 14.56620661767423, 13.532283122624932, 12.780489762673833, 11.944090074431173, 11.034164393064227, 10.087665021990942, 10.81392822636076, 11.08263368623303, 10.130232284975387, 10.97503724732471, 11.883986782031611, 12.507862617433581, 13.487100140131385, 14.414433141016376, 15.327175677417081, 16.22303351776718, 17.18577679718775, 16.47524934030568, 15.461083067786715, 14.499900591194598, 13.538788956658735, 12.561511384974041, 11.810176320594714, 10.881879398216233, 9.995523630263444, 9.067159746049281, 9.872174318438798, 10.798956563635057, 11.154117891921901, 12.040741018279268, 12.897655950506396, 13.46034254086262, 14.414521688119336, 15.376686785651435, 16.303037614816976, 17.242588943463574, 17.429067757202866, 15.464017967021087, 14.494994293874942, 13.517589514043161, 12.507712011077253, 11.536155536094645, 10.784025493657717, 9.905587951325353, 9.014141646330279, 8.10423998116396, 8.930700281828141, 9.837650858660938, 10.860978888104484, 11.737660041781433, 12.69646372700013, 13.623580548325874, 14.594577713234015, 15.524164313334653, 16.463119637686678, 17.477978434738006, 16.49198152732832, 14.494598826384212, 13.474397499427045, 12.480696816267608, 11.552659225089583, 10.605394907595613, 9.741694384182631, 8.839059059315368, 8.010093624322689, 7.084876168520638, 7.892485781778062, 8.825607666949166, 9.838616055486488, 10.77377378054569, 11.668395574334573, 12.697706743241548, 13.679605811921455, 14.60732339461702, 15.680898432950992, 16.577369464492264, 15.543962363345722, 13.556519123623987, 12.551380048361796, 11.58067641500137, 10.599551338502177, 9.641662455908302, 8.798055919888633, 7.855851895174258, 7.033414017254676, 6.016070369045526, 6.946725304465008, 7.923932843373813, 8.849106302110856, 9.788066537189724, 10.734675077520256, 11.721661669753184, 12.717488107457047, 13.656871542758958, 14.731130171108479, 15.631978576266624, 14.617210828256187, 12.694049820048646, 11.722073174804919, 10.777953508721993, 9.708587847530762, 8.70791980861589, 7.734291938979766, 6.807432695831258, 5.981604964812827, 5.087106571768427, 6.046306352437472, 6.955529608135567, 7.898022053428981, 8.844237823594533, 9.915921342321932, 10.915262637096799, 11.866071183791904, 12.850384584514426, 13.862006660641478, 14.6019367631517, 13.623884609588458, 11.73799198340204, 10.810038871456397, 9.93401351450498, 8.895393756986781, 7.848006031113047, 6.778258263431821, 5.845595128900748, 4.99189726486936, 4.136342566138424, 5.024310671969517, 6.004180049838039, 6.843053014679697, 7.914047590537023, 8.919657345910288, 9.95460120529006, 10.90379347067471, 11.945147928696134, 12.871961757209476, 13.721014726978456, 12.693597361794955, 10.846439845437928, 9.840475288534044, 8.920300844761067, 7.90071568956925, 6.837854775878551, 5.8281032205018475, 4.898333162078329, 3.949481391187759, 3.1111454248267596, 4.021962784167059, 4.989989422395344, 5.915515752534973, 6.902593084059482, 7.945335207324778, 8.95652109722131, 9.999924043534039, 10.952523318117343, 11.941223701412023, 12.77499815412465, 11.889351280939525, 9.8722724876852, 8.900207718960194, 7.87962537567002, 6.911505875911168, 5.896723466931004, 4.882061348359031, 3.933409624759352, 2.995735228661022, 2.124173714859592, 3.0908383255430114, 3.9586866888891077, 5.002128054479725, 6.037997038122993, 7.052781958829224, 8.020578216327745, 9.042986849266727, 10.026694356205395, 11.015381733289974, 11.796318377715867, 10.849748937181912, 8.899390536783962, 7.957865155938402, 6.911403874919133, 5.915209045680204, 4.989847549695171, 3.9938012917714047, 3.030878158907371, 2.0153347065065796, 1.0600448154079682, 2.0287226382013928, 2.9873676372725506, 4.038974229478218, 5.061701767659255, 6.129612671830353, 7.056412119482609, 8.117078896154338, 9.131231606779997, 10.145772333226653, 10.883570403430234, 9.846409749656663, 8.308085473477135, 7.279116924666048, 6.2266402777291985, 5.16363039530941, 4.150548106880342, 3.084642457280348, 2.0568142388404627, 1.057396343273269, 0.0, 1.0635803412903688, 2.104155818846382, 3.1525567265636925, 4.183376972222888, 5.223205725025058, 6.2213508391458445, 7.2139239864872495, 8.193548299524418, 9.152504931757937, 10.22376476151541, 9.353929170052991, 8.927219889518609, 7.981399060421164, 6.93377294306716, 5.874944876231753, 4.943082884318727, 3.924282321710196, 2.9897454405963253, 1.9668345857941845, 0.9943907349104649, 1.9947929795307076, 3.05772045413306, 4.079853268177914, 5.040377741519848, 6.0527986482532565, 7.052832588857464, 8.015150919994877, 9.051711740956295, 10.081605616641387, 10.924141525685368, 9.948918111428478, 9.893326537787889, 8.91146859809319, 7.883584632560818, 6.936564107935348, 5.892731814414461, 4.897496661319478, 4.051084349201618, 3.0292675664249606, 2.056436934027799, 2.98685836624973, 4.033807963695396, 4.996540704064338, 5.971859504649401, 6.932516739193436, 7.903641112710501, 8.879276761516598, 9.830439122557047, 10.88614223362004, 11.789277194198197, 10.843323846342564, 10.888262765513964, 9.830149294737401, 8.806761092108262, 7.824142604620851, 6.7991135862063405, 5.824628858496544, 5.024651843710305, 4.025332152215197, 3.109372359008421, 4.022808605299804, 5.048552672428959, 5.955678362862095, 6.900688485914677, 7.879931268448261, 8.883265317918017, 9.834746878022534, 10.852460987993233, 11.793313317436628, 12.737880233770987, 11.798556770070416, 11.728251014552116, 10.71656602881694, 9.755914064151025, 8.70890609263098, 7.760610910526961, 6.76694475975872, 5.959571663856421, 4.995931784994131, 4.139665788975455, 5.095727262782737, 6.068036045676497, 6.942662217595703, 7.828663304861128, 8.758082141332874, 9.825560511771151, 10.803289234876145, 11.792554573962384, 12.805300201047688, 13.784014721744075, 12.725395210792259], [14.52931534979531, 13.71069184636326, 12.735197197638696, 11.764057535463834, 10.735822895832786, 9.780709084785927, 8.758812228334856, 7.847491426223065, 6.9809917466910205, 6.114381239387863, 5.183457848178368, 6.1188890957978925, 6.919703049993708, 7.859205462520001, 8.712930470754369, 9.701408090875265, 10.658793569848857, 11.683166167077133, 12.659187713865977, 13.685925310216085, 15.548221127441886, 14.745209138601664, 13.7257100759427, 12.80585893644338, 11.749145629612993, 10.759911003103182, 9.708938931955045, 8.897139382085056, 8.03653755308411, 7.079921389370886, 6.126525700941007, 7.0865677746461575, 7.9567771741041105, 8.821669052847374, 9.640058466325023, 10.707288895423902, 11.584241247338161, 12.512563092002338, 13.567814016248855, 14.612939263402104, 16.49049085058743, 15.598564641055994, 14.641805049227402, 13.675639329063749, 12.676798896256418, 11.742871633788287, 10.711669031290564, 9.956432265559798, 9.052974744790214, 8.102518567546475, 7.147371394405451, 8.078164383194622, 8.971992799779644, 9.87754497449526, 10.588351045917852, 11.526984081443976, 12.476842814648721, 13.525964937027606, 14.493212167332022, 15.445041497003855, 17.36578635198786, 16.609654580177196, 15.625648970537481, 14.73144056072563, 13.692181049176256, 12.666739090253548, 11.718258312800977, 11.023500425549352, 10.068893198581508, 9.161194287191291, 8.206430207158826, 9.06652924901527, 9.931515689707652, 10.865281273712016, 11.608257001859446, 12.538060350030355, 13.40587672515138, 14.34099480095809, 15.334573954119628, 16.34315663804171, 18.291362003411475, 17.548668502154847, 16.681630610082415, 15.683945417192692, 14.674442970936596, 13.722697783417551, 12.77222838386073, 12.087367998252011, 11.06101930870588, 10.211285903879046, 9.261645934490879, 10.00589894942782, 10.919851485865326, 11.837434474047209, 12.587086248089028, 13.599205212136143, 14.404972586905195, 15.333835936682398, 16.280436735982548, 17.313375453987742, 18.333068895234263, 17.354620243886632, 16.405382347451607, 15.479995429807765, 14.446071934758466, 13.693869382049003, 12.75669392825794, 11.788164167061119, 10.778184614260995, 9.85065080263128, 10.233610827076312, 10.966828573281402, 11.946624454588488, 12.855573989295387, 13.51294786310651, 14.492185385804314, 15.419518386689305, 16.33226092309001, 17.228118763440108, 18.190862042860676, 17.389038152439213, 16.37487187992025, 15.413689403328132, 14.452577768792269, 13.475300197107575, 12.723965132728248, 11.795668210349767, 10.81118047269129, 9.851441265901304, 8.908896894709319, 9.835679139905578, 10.764786762976627, 11.746954604148192, 12.68356916648235, 13.680358748808704, 14.632056630657512, 15.564158310470718, 16.50858490716804, 17.51697720072443, 18.3428565693364, 16.37780677915462, 15.408783106008478, 14.431378326176695, 13.421500823210787, 12.449944348228179, 11.697814305791251, 10.819376763458887, 9.829798488758126, 8.888521501015983, 7.9674228580986615, 8.874373434931458, 9.844398620472207, 10.721079774149157, 11.679883459367854, 12.607000280693597, 13.577997445601738, 14.507584045702377, 15.4465393700544, 16.497593585211582, 17.405770339461856, 15.408387638517748, 14.38818631156058, 13.394485628401142, 12.466448037223117, 11.519183719729147, 10.655483196316165, 9.752847871448902, 8.825750466750536, 7.869157688372659, 6.929208358048581, 7.862330243219686, 8.822035787854212, 9.757193512913414, 10.651815306702296, 11.681126475609272, 12.663025544289178, 13.590743126984743, 14.664318165318715, 15.731135782135928, 16.457751175479256, 14.470307935757523, 13.465168860495332, 12.494465227134906, 11.513340150635711, 10.555451268041836, 9.711844732022167, 8.769640707307792, 7.849070859682523, 6.805592971675309, 5.983447880735527, 6.907352575741537, 7.83252603447858, 8.771486269557448, 9.71809480988798, 10.705081402120907, 11.70090783982477, 12.640291275126682, 13.7145499034762, 14.739243070318933, 15.530999640389723, 13.616790139071592, 12.635861986938455, 11.691742320855528, 10.622376659664297, 9.621708620749423, 8.6480807511133, 7.721221507964792, 6.842508626282161, 5.87662917439821, 5.022739518984156, 5.931962774682251, 6.874455219975665, 7.820670990141217, 8.892354508868616, 9.891695803643483, 10.842504350338588, 11.82681775106111, 12.838439827188163, 13.758001159289318, 14.546624928611404, 12.660732302424986, 11.732779190479343, 10.847802326638512, 9.809182569120315, 8.76179484324658, 7.692047075565355, 6.759383941034282, 5.905686077002894, 4.925865168768207, 4.000743838516201, 4.980613216384723, 5.819486181226381, 6.890480757083707, 7.896090512456972, 8.931034371836745, 9.880226637221394, 10.921581095242818, 11.84839492375616, 12.822648236181188, 13.616337680817901, 11.769180164460874, 10.76321560755699, 9.843041163784013, 8.816952376169862, 7.751643588012085, 6.7418920326353815, 5.812121974211863, 4.863270203321293, 4.018206597461498, 2.9983959507137428, 3.966422588942028, 4.891948919081657, 5.879026250606166, 6.921768373871462, 7.932954263767995, 8.976357210080723, 9.928956484664027, 10.917656867958707, 11.967375990908119, 12.812091599962471, 10.795012806708145, 9.82294803798314, 8.802365694692966, 7.834246194934113, 6.810512279064538, 5.795850160492565, 4.847198436892886, 3.909524040794556, 3.037962526993126, 2.067271492089696, 2.935119855435792, 3.9785612210264087, 5.014430204669677, 6.0292151253759085, 6.99701138287443, 8.019420015813411, 9.003127522752079, 9.991814899836658, 11.032359518579392, 11.772489256204858, 9.822130855806908, 8.880605474961348, 7.834144193942079, 6.837949364703149, 5.912587868718116, 4.91654161079435, 3.953618477930316, 2.9291235186401137, 1.9738336275415018, 1.005155804748077, 1.9638008038192347, 3.0154073960249024, 4.038134934205939, 5.106045838377037, 6.032845286029293, 7.093512062701022, 8.10766477332668, 9.122205499773337, 10.066111279062461, 10.76915006867961, 9.371665814767505, 8.342697265956417, 7.290220619019567, 6.227210736599778, 5.21412844817071, 4.148222798570716, 3.120394580130831, 2.1209766845636375, 1.0635803412903688, 0.0, 1.040575477556013, 2.0889763852733236, 3.1197966309325196, 4.1596253837346895, 5.157770497855476, 6.150343645196881, 7.129967958234049, 8.088924590467569, 9.160184420225042, 10.146633418386221, 9.932305135191537, 8.986484306094091, 7.938858188740088, 6.8800301219046816, 5.948168129991656, 4.9293675673831245, 3.9948306862692533, 2.9719198314671122, 1.9994759805833928, 0.9990737359631501, 1.994140112842691, 3.0162729268875443, 3.976797400229479, 4.989218306962887, 5.989252247567094, 6.951570578704508, 7.988131399665926, 9.018025275351018, 10.00334081522078, 10.954003357101406, 10.898411783460817, 9.916553843766119, 8.888669878233745, 7.941649353608277, 6.897817060087389, 5.902581906992406, 5.022671556465394, 4.0008547736887365, 2.995823033690005, 2.065401601468074, 3.0099890120394592, 3.9727217524084013, 4.9082791633590315, 5.868936397903067, 6.840060771420131, 7.815696420226229, 8.766858781266679, 9.822561892329672, 10.871145754439606, 11.81709910229524, 11.893348011186893, 10.83523454041033, 9.81184633778119, 8.82922785029378, 7.804198831879269, 6.829714104169472, 5.99623905097408, 4.996919359478973, 4.048758458670627, 3.101351840518149, 4.024733720773022, 4.931859411206158, 5.8768695342587405, 6.856112316792324, 7.819684976627647, 8.771166536732164, 9.788880646702864, 10.72973297614626, 11.674299892480619, 12.640298096855497, 12.733336260225045, 11.721651274489869, 10.760999309823953, 9.713991338303908, 8.76569615619989, 7.772030005431648, 6.931158871120196, 5.967518992257908, 5.079051888637661, 4.174270498001082, 5.04421709402056, 5.918843265939766, 6.804844353205191, 7.734263189676937, 8.761980170480781, 9.739708893585775, 10.728974232672014, 11.74171985975732, 12.740724489997959, 13.56713653757734], [13.488739872239297, 12.670116368807246, 11.694621720082683, 10.723482057907823, 9.695247418276775, 8.740133607229916, 7.718236750778842, 6.806915948667051, 5.940416269135007, 5.07380576183185, 6.084396116507107, 7.069850626258929, 7.870664580454746, 8.81016699298104, 9.728269849018764, 10.71674746913966, 11.674132948113252, 12.698505545341527, 13.674527092130374, 14.498917504199337, 14.507645649885873, 13.70463366104565, 12.685134598386686, 11.76528345888737, 10.708570152056982, 9.719335525547171, 8.668363454399032, 7.856563904529041, 6.995962075528096, 6.110613359019677, 7.027463969269745, 7.987506042974896, 8.907738704565148, 9.772630583308413, 10.655397844589418, 11.722628273688297, 12.599580625602556, 13.527902470266733, 14.58315339451325, 15.553425994146199, 15.499144303322874, 14.557989163499983, 13.601229571671391, 12.635063851507738, 11.636223418700407, 10.702296156232272, 9.67109355373455, 8.915856788003783, 8.012399267234201, 7.133210537195265, 8.04830966273419, 8.97910265152336, 9.92295433024068, 10.828506504956298, 11.603690424182247, 12.54232345970837, 13.492182192913116, 14.541304315292, 15.508551545596417, 16.46038087526825, 16.50649316764148, 15.569079102621185, 14.58507349298147, 13.690865083169617, 12.651605571620243, 11.626163612697535, 10.677682835244964, 9.982924947993338, 9.028317721025495, 8.19188625684008, 9.107368475487565, 9.967467517344009, 10.882477220168688, 11.816242804173054, 12.62359638012384, 13.55339972829475, 14.421216103415775, 15.356334179222484, 16.349913332384023, 17.358496016306102, 17.432068819065094, 16.508093024598836, 15.641055132526404, 14.64336993963668, 13.633867493380583, 12.682122305861538, 11.731652906304717, 11.046792520695996, 10.020443831149867, 9.258424892684776, 10.162584202819618, 10.906837217756559, 11.870813016326363, 12.788396004508247, 13.602425626353423, 14.614544590400538, 15.420311965169589, 16.34917531494679, 17.295776114246944, 18.328714832252135, 18.440170912461117, 17.489884605113684, 16.540646708678658, 15.615259791034816, 14.57643033000096, 13.713504096957385, 12.776328643166321, 11.962376741585176, 10.952397188785053, 10.30736628061269, 9.973797619772226, 10.903254697949027, 11.893773669487189, 12.800279399521825, 13.735879736802433, 14.715117259500238, 15.629453019670468, 16.587487909132623, 17.63957369098551, 18.453148116823343, 18.345943203312977, 17.331776930794017, 16.3705944542019, 15.409482819666035, 14.432205247981342, 13.680870183602014, 12.752150698573335, 11.74609801493571, 10.786358808145723, 9.843814436953739, 8.952333533804751, 9.879369091002513, 10.85728180942669, 11.78661023104704, 12.783399813373395, 13.735097695222203, 14.667199375035409, 15.611625971732728, 16.62001826528912, 17.5237177870605, 17.334711830028386, 16.365688156882243, 15.388283377050461, 14.378405874084553, 13.406849399101946, 12.654719356665018, 11.775859251682455, 10.764716031002544, 9.823439043260402, 8.902340400343082, 7.991027828830632, 8.947439685036898, 9.824120838713847, 10.782924523932545, 11.710041345258288, 12.68103851016643, 13.610625110267067, 14.54958043461909, 15.600634649776271, 16.586631557185957, 16.365292689391513, 15.345091362434346, 14.351390679274909, 13.423353088096883, 12.476088770602914, 11.612388247189932, 10.70933035967247, 9.760668008994955, 8.804075230617078, 7.864125900293001, 6.9789846371188595, 7.925076852418903, 8.860234577478105, 9.754856371266987, 10.784167540173963, 11.766066608853869, 12.693784191549433, 13.767359229883406, 14.834176846700618, 15.74133609366498, 15.427212986631288, 14.422073911369097, 13.451370278008671, 12.470245201509478, 11.512356318915602, 10.668749782895933, 9.72612319553136, 8.783988401926942, 7.7405105139197286, 6.918365422979947, 6.010393640306228, 6.935567099043271, 7.8745273341221385, 8.82113587445267, 9.808122466685598, 10.803948904389461, 11.743332339691372, 12.817590968040893, 13.832173681962725, 14.760647568481952, 14.573695189945358, 13.59276703781222, 12.648647371729293, 11.579281710538062, 10.57861367162319, 9.604985801987066, 8.67812655883856, 7.77742616852658, 6.81154671664263, 5.957657061228575, 5.035003839246943, 5.942219460916957, 6.888435231082508, 7.960118749809907, 8.903145254301077, 9.853953800996182, 10.838267201718704, 11.849889277845756, 12.76589068224635, 13.743942835809593, 13.617637353298752, 12.68968424135311, 11.80470737751228, 10.766087619994082, 9.718699894120347, 8.648952126439122, 7.7162889919080495, 6.862591127876661, 5.860782711012627, 4.935661380760621, 4.083654280949415, 4.887250422167672, 5.958244998024998, 6.963854753398263, 7.942483822494339, 8.891676087878988, 9.92947061819985, 10.856284446713193, 11.83053775913822, 12.857955124321721, 12.72608521533464, 11.720120658430757, 10.79994621465778, 9.77385742704363, 8.708548638885853, 7.69879708350915, 6.76902702508563, 5.82017525419506, 4.953124139705918, 3.9333134929581623, 3.0341868298833194, 3.9597131600229485, 4.946790491547457, 5.989532614812753, 6.91133833546909, 7.954741281781818, 8.907340556365122, 9.896040939659802, 10.945760062609214, 11.91532941785678, 11.751917857581912, 10.779853088856907, 9.759270745566733, 8.79115124580788, 7.767417329938306, 6.752755211366333, 5.804103487766653, 4.866429091668323, 3.9948675778668923, 3.0021890343341155, 1.9747349081672438, 3.018176273757861, 4.040612409181596, 5.055397329887827, 5.975395454575525, 6.997804087514505, 7.981511594453173, 8.970198971537753, 10.010743590280487, 10.957313030814442, 10.779035906680674, 9.837510525835114, 8.791049244815845, 7.794854415576916, 6.869492919591884, 5.873446661668117, 4.910523528804083, 3.88602856951388, 2.9307386784152687, 1.9620608556218442, 1.0034158565506865, 2.0319743164112274, 3.0165190059070346, 4.084429910078132, 5.011229357730388, 6.071896134402117, 7.086048845027775, 8.095716140699212, 9.039621919988337, 10.076782573761907, 10.151901637406064, 9.383272743512428, 8.330796096575579, 7.267786214155791, 6.254703925726723, 5.18879827612673, 4.1609700576868445, 3.1615521621196505, 2.104155818846382, 1.040575477556013, 0.0, 1.0484009077173106, 2.0792211533765066, 3.1190499061786765, 4.117195020299463, 5.109768167640868, 6.089392480678036, 7.048349112911555, 8.119608942669029, 9.106057940830208, 10.954924257728038, 10.009103428630592, 8.961477311276587, 7.90264924444118, 6.9707872525281545, 5.951986689919623, 5.017449808805753, 3.994538954003612, 3.0220951031198924, 2.02169285849965, 0.953564635286678, 1.9756974493315316, 2.936221922673466, 3.9486428294068743, 4.948676770011081, 5.910995101148495, 6.947555922109913, 7.977449797795006, 8.962765337664766, 9.937988751921656, 11.726520933293902, 10.931893222030514, 9.90400925649814, 8.956988731872672, 7.913156438351785, 6.917921285256802, 5.973633086926432, 4.951816304149775, 3.9467845641510424, 3.0163631319291118, 1.969413534483446, 2.932146274852388, 3.8677036858030185, 4.828360920347054, 5.799485293864118, 6.775120942670216, 7.726283303710665, 8.781986414773659, 9.830570276883593, 10.776523624739227, 12.594522836882685, 11.850573918674726, 10.827185716045587, 9.844567228558176, 8.819538210143666, 7.845053482433868, 6.947200581435118, 5.947880889940011, 4.999719989131664, 4.052313370979187, 2.984158243217009, 3.891283933650145, 4.836294056702727, 5.8155368392363105, 6.779109499071634, 7.730591059176151, 8.748305169146851, 9.689157498590246, 10.633724414924606, 11.599722619299484, 13.585408040068947, 12.736990652754265, 11.77633868808835, 10.729330716568304, 9.781035534464287, 8.787369383696044, 7.8821204015812345, 6.918480522718946, 6.030013419098697, 5.075208766329821, 4.003641616464547, 4.878267788383752, 5.764268875649178, 6.693687712120923, 7.721404692924769, 8.699133416029762, 9.688398755116001, 10.701144382201306, 11.700149012441946, 12.526561060021328], [12.54187913209885, 11.7232556286668, 10.747760979942237, 9.776621317767377, 8.74838667813633, 7.79327286708947, 6.8156159117937625, 5.904295109681971, 5.063884603254847, 6.088310881000452, 7.107236575156697, 8.097653929507954, 8.919065488172057, 9.85856790069835, 10.776670756736072, 11.765148376856969, 12.72253385583056, 13.746906453058836, 14.578794360408999, 13.552056764058891, 13.560784909745427, 12.757772920905206, 11.738273858246242, 10.818422718746923, 9.761709411916534, 8.772474785406725, 7.765742615413951, 6.953943065543962, 6.119430409647936, 7.125118478188279, 8.050304427919336, 9.010346501624486, 9.95613961228246, 10.821031491025723, 11.703798752306726, 12.771029181405606, 13.647981533319864, 14.576303377984042, 15.626884356241527, 14.606565254005753, 14.552283563182426, 13.611128423359535, 12.654368831530943, 11.68820311136729, 10.68936267855996, 9.799675317247193, 8.768472714749471, 8.013235949018704, 7.135867601354041, 8.143122321885036, 9.07115012138378, 10.00194311017295, 10.971355237957992, 11.876907412673608, 12.652091331899555, 13.590724367425679, 14.540583100630425, 15.58970522300931, 16.549562246437837, 15.597732916766002, 15.559632427501034, 14.622218362480737, 13.638212752841023, 12.752757478473015, 11.748984732635163, 10.723542773712456, 9.775061996259884, 9.080304109008258, 8.151786055145335, 9.1285114459798, 10.128962491676706, 10.990307975993598, 11.930878127886, 12.864643711890364, 13.67199728784115, 14.601800636012058, 15.469617011133083, 16.40473508693979, 17.39831424010133, 16.58226214144719, 16.485208078924646, 15.561232284458388, 14.694194392385956, 13.7407491006516, 12.731246654395504, 11.779501466876459, 10.829032067319638, 10.144171681710917, 9.143912165269708, 10.088156638383676, 11.037796607771844, 10.961613711816804, 11.996231847833155, 12.888750723395537, 13.684283291645176, 14.70654566809391, 15.668255090301646, 16.597118440078848, 17.609797658268334, 17.53895089851662, 17.49331017232067, 16.5872637661286, 15.638025869693577, 14.712638952049737, 13.67380949101588, 12.810883257972305, 11.873707804181242, 11.085845075705016, 10.075865522904893, 11.003399334534608, 10.814546398370906, 10.000684087963222, 10.991203059501384, 11.87061120814736, 12.758421676627695, 13.737659199325499, 14.65199495949573, 15.610029848957886, 16.662115630810774, 17.475690056648602, 17.54540111815324, 17.586099102214572, 16.71184595060618, 15.713474294316038, 14.644581228666771, 13.781196700051424, 12.935918480396182, 12.10633646456988, 11.096370798846554, 10.729851697399484, 9.793082312403431, 8.976798481016708, 9.927613618052224, 10.856942039672575, 11.805941753198656, 12.757639635047465, 13.68974131486067, 14.634167911557991, 15.642560205114384, 16.54625972688576, 16.591647549268064, 17.39745230123114, 16.42004752139936, 15.410170018433451, 14.438613543450844, 13.637592663092253, 12.728215214250158, 11.661423289239817, 10.712168443856045, 9.788377660788827, 8.831776607429312, 8.044869075051093, 8.894452647339381, 9.853256332558079, 10.73258328508355, 11.70358044999169, 12.633167050092329, 13.572122374444351, 14.623176589601533, 15.609173497011218, 15.62222840863119, 16.376855506783244, 15.383154823623807, 14.455117232445781, 13.507852914951812, 12.595261553617167, 11.661686322240172, 10.657375267232228, 9.692804631212722, 8.752855300888644, 7.81973341571754, 7.0225062424330975, 7.930566386103639, 8.825188179892521, 9.806709479999224, 10.769921718042173, 11.697639300737737, 12.77121433907171, 13.820669518049602, 14.692935185947668, 14.684148705870966, 15.453838055717995, 14.483134422357569, 13.502009345858376, 12.5441204632645, 11.651623089323168, 10.678479158099062, 9.736344364494645, 8.692866476487431, 7.828349957813713, 6.8511424189049075, 6.032996489057465, 6.9448591427476725, 7.891467683078204, 8.811977575873902, 9.807804013577766, 10.747187448879677, 11.821446077229197, 12.783772774245413, 13.71224666076464, 13.637926729080059, 14.624531182161117, 13.680411516078191, 12.61104585488696, 11.610377815972088, 10.636749946335964, 9.709890703187458, 8.729782131094282, 7.763902679210332, 6.877217620115579, 5.875752617845622, 4.974622788051959, 5.92083855821751, 6.992522076944909, 7.854744346583765, 8.80555289327887, 9.789866294001392, 10.801488370128444, 11.717489774529039, 12.69554192809228, 12.765159594997325, 13.693112706942967, 12.836471521861178, 11.79785176434298, 10.750464038469245, 9.68071627078802, 8.748053136256948, 7.844239442918855, 6.81313867358033, 5.888017343328324, 4.924403059548094, 3.9196537493026744, 4.974638499130426, 5.9802482545036915, 6.894082914777028, 7.843275180161677, 8.881069710482539, 9.807883538995881, 10.782136851420908, 11.80955421660441, 11.885731035708801, 12.751884802779655, 11.831710359006678, 10.805621571392528, 9.740312783234753, 8.730561227858049, 7.800791169434528, 6.8519393985439585, 5.9054801022736205, 4.885669455525865, 3.9176428172975797, 2.9921164871579506, 3.928397227419908, 4.971139350685204, 5.862937427751779, 6.9063403740645075, 7.858939648647811, 8.84764003194249, 9.897359154891902, 10.866928510139468, 10.886388572593845, 11.811617233205805, 10.79103488991563, 9.822915390156778, 8.799181474287204, 7.784519355715231, 6.835867632115551, 5.898193236017221, 5.02663172221579, 4.033953178683013, 3.006499052516141, 2.011542027780611, 2.992211501464285, 4.006996422170517, 4.926994546858214, 5.949403179797195, 6.933110686735863, 7.921798063820442, 8.962342682563177, 9.908912123097132, 9.975400878917299, 10.869274670184012, 9.822813389164743, 8.826618559925814, 7.901257063940782, 6.905210806017015, 5.942287673152981, 4.917792713862778, 3.9625028227641663, 2.993824999970742, 2.035180000899584, 0.9835734086939167, 1.968118098189724, 3.036029002360822, 3.9628284500130775, 5.0234952266848065, 6.037647937310465, 7.0473152329819015, 7.991221012271026, 9.028381666044597, 9.103500729688754, 10.132469278499842, 9.379197004292891, 8.316187121873103, 7.303104833444035, 6.237199183844041, 5.209370965404156, 4.209953069836962, 3.1525567265636925, 2.0889763852733236, 1.0484009077173106, 0.0, 1.030820245659196, 2.0706489984613654, 3.0687941125821525, 4.061367259923558, 5.040991572960726, 5.9999482051942445, 7.071208034951718, 8.057657033112898, 10.00136114656122, 10.947181975658665, 10.009878218993897, 8.95105015215849, 8.019188160245465, 7.000387597636934, 6.065850716523063, 5.042939861720923, 4.0704960108372035, 3.0700937662169605, 2.0019655430039887, 1.0436536718260856, 1.989361182533019, 3.0017820892664275, 4.001816029870635, 4.964134361008048, 6.000695181969466, 7.0191239705247, 8.00443951039446, 8.97966292465135, 10.779660193153456, 11.840313443380717, 10.95241016421545, 10.005389639589982, 8.961557346069094, 7.966322192974112, 7.022033994643742, 6.000217211867085, 4.9951854718683535, 4.064764039646422, 3.0178144422007565, 2.0556146089722276, 2.9208429456625717, 3.881500180206607, 4.852624553723672, 5.82826020252977, 6.779422563570219, 7.835125674633212, 8.883709536743147, 9.82966288459878, 11.64766209674224, 12.705775567518803, 11.875586623762896, 10.892968136275485, 9.867939117860974, 8.893454390151177, 7.9956014891524285, 6.996281797657321, 6.0481208968489755, 5.079744749590072, 4.008148490946129, 3.0147522677699845, 3.933673217717647, 4.912916000251231, 5.832248758931188, 6.783730319035705, 7.801444429006406, 8.7422967584498, 9.68686367478416, 10.652861879159039, 12.6385472999285, 13.650232285663677, 12.824739595805658, 11.777731624285613, 10.829436442181596, 9.835770291413352, 8.930521309298545, 7.966881430436256, 7.078414326816009, 6.098049224979411, 5.026482075114136, 4.001736122503592, 4.861648036664098, 5.7910668731358435, 6.774543952784323, 7.752272675889315, 8.741538014975553, 9.75428364206086, 10.7532882723015, 11.579700319880882], [11.511058886439653, 10.692435383007602, 9.716940734283039, 8.745801072108181, 7.717566432477132, 6.762452621430272, 5.784795666134566, 4.873474864022775, 5.8131320012218755, 6.837558278967481, 7.890870955148484, 8.881288309499741, 9.795010133702142, 10.734512546228434, 11.652615402266157, 12.641093022387054, 13.598478501360646, 14.534035809643687, 13.547974114749799, 12.521236518399693, 12.52996466408623, 11.726952675246006, 10.707453612587042, 9.787602473087727, 8.730889166257338, 7.741654539747527, 6.734922369754755, 5.923122819884766, 6.868677807614965, 7.8743658761553075, 8.827761564585186, 9.787803638290338, 10.832084257812545, 11.696976136555806, 12.579743397836811, 13.64697382693569, 14.52392617884995, 15.452248023514127, 14.596064110582327, 13.575745008346555, 13.52146331752323, 12.580308177700338, 11.623548585871747, 10.657382865708094, 9.658542432900763, 8.768855071587996, 7.737652469090275, 6.982415703359507, 7.88511499932107, 8.892369719852065, 9.84860725804963, 10.7794002468388, 11.831670476410043, 12.752852058203691, 13.52803597742964, 14.466669012955764, 15.41652774616051, 16.465649868539394, 15.518742000778639, 14.566912671106806, 14.528812181841838, 13.59139811682154, 12.607392507181826, 11.721937232813818, 10.718164486975967, 9.69272252805326, 8.744241750600688, 8.049483863349062, 8.901033453112364, 9.877758843946829, 10.878209889643735, 11.767765112659449, 12.101089885291, 12.95356765513411, 13.632292292215565, 14.676322621184443, 15.604841247624575, 16.539959323431283, 16.504576189123085, 15.551441895787992, 15.454387833265452, 14.530412038799192, 13.66337414672676, 12.709928854992404, 11.700426408736307, 10.748681221217263, 9.798211821660441, 9.11335143605172, 9.893159563236736, 10.837404036350705, 11.787044005738872, 11.854151537944077, 11.112754089133325, 11.981414454798918, 12.653463045985983, 13.675725422434716, 14.637434844642453, 15.566298194419655, 16.57897741260914, 16.508130652857428, 16.462489926661476, 15.556443520469406, 14.60720562403438, 13.68181870639054, 12.642989245356684, 11.780063012313109, 10.842887558522046, 10.075658303186184, 10.825112920871922, 11.752646732501637, 11.707084224498177, 10.893221914090494, 10.085981120410164, 10.96327493955074, 11.727601430968502, 12.706838953666306, 13.621174713836536, 14.579209603298693, 15.631295385151581, 16.444869810989413, 16.514580872494047, 16.55527885655538, 15.681025704946983, 14.682654048656842, 13.613760983007575, 12.750376454392228, 11.905098234736986, 11.114299065986968, 11.845618196813582, 11.622389523526754, 10.685620138530702, 9.86933630714398, 9.020277349455606, 9.949605771075955, 10.775121507539463, 11.726819389388272, 12.658921069201478, 13.603347665898799, 14.61173995945519, 15.51543948122657, 15.560827303608873, 16.56128630302541, 16.62055080983549, 15.610673306869579, 14.639116831886971, 13.776527281329225, 12.881389681627866, 12.095681049920133, 11.604706269983316, 10.680915486916097, 9.724314433556582, 8.937406901178365, 7.987116378742764, 8.94592006396146, 9.701763039424357, 10.672760204332498, 11.602346804433136, 12.541302128785158, 13.59235634394234, 14.578353251352025, 14.591408162971998, 15.604675804755203, 16.31732474418489, 15.389287153006865, 14.442022835512896, 13.48779937974444, 12.554224148367444, 11.549913093359498, 10.585342457339992, 9.645393127015915, 8.71227124184481, 7.91504406856037, 7.02323011750702, 7.917851911295902, 8.775889234340031, 9.73910147238298, 10.666819055078545, 11.740394093412517, 12.78984927239041, 13.662114940288475, 13.653328460211773, 14.617913238490804, 15.417304342918655, 14.43617926641946, 13.478290383825584, 12.54416091545044, 11.571016984226334, 10.628882190621917, 9.585404302614704, 8.720887783940984, 7.743680245032179, 6.925534315184738, 6.037522874151054, 6.984131414481586, 7.781157330214708, 8.776983767918573, 9.716367203220484, 10.790625831570004, 11.75295252858622, 12.681426415105447, 12.607106483420866, 13.608714020925081, 14.552833687008008, 13.545215775448046, 12.544547736533172, 11.570919866897048, 10.613862757909118, 9.622319957221555, 8.656440505337605, 7.769755446242851, 6.7682904439728935, 5.86716061417923, 5.013502289620892, 6.003733474457403, 6.823924100924571, 7.774732647619675, 8.759046048342197, 9.77066812446925, 10.686669528869846, 11.664721682433088, 11.73433934933813, 12.662292461283773, 13.680185335758717, 12.732021684904064, 11.684633959030329, 10.614886191349104, 9.682223056818032, 8.736777269046126, 7.705676499707601, 6.780555169455595, 5.816940885675366, 4.812191575429946, 3.9438182534712305, 4.949428008844496, 5.863262669117834, 6.812454934502482, 7.850249464823344, 8.777063293336687, 9.751316605761714, 10.778733970945215, 10.854910790049605, 11.837124943360244, 12.808162341024326, 11.782073553410179, 10.716764765252401, 9.707013209875697, 8.777243151452177, 7.767034644444177, 6.798017928400892, 5.7782072816531365, 4.810180643424851, 3.8846543132852216, 2.8975769817607127, 3.940319105026009, 4.832117182092584, 5.875520128405312, 6.828119402988616, 7.816819786283294, 8.866538909232705, 9.836108264480272, 9.855568326934648, 10.896857373786395, 11.76748687193328, 10.799367372174427, 9.775633456304853, 8.76097133773288, 7.8123196141332, 6.874645218034869, 6.003083704233439, 5.010405160700661, 3.9829510345337895, 2.987994009798259, 1.961391255805089, 2.976176176511321, 3.8961743011990184, 4.918582934137999, 5.902290441076667, 6.890977818161246, 7.93152243690398, 8.878091877437935, 8.944580633258102, 9.886106014103662, 10.799265371182392, 9.803070541943463, 8.87770904595843, 7.881662788034664, 6.918739655170629, 5.894244695880427, 4.938954804781815, 3.9702769819883903, 3.0116319829172324, 1.9600253907115648, 0.937297852530528, 2.005208756701626, 2.932008204353881, 3.99267498102561, 5.006827691651268, 6.016494987322705, 6.96040076661183, 7.997561420385401, 8.072680484029558, 9.101649032840646, 10.154125679777495, 9.347007367532298, 8.33392507910323, 7.268019429503236, 6.240191211063351, 5.240773315496157, 4.183376972222888, 3.1197966309325196, 2.0792211533765066, 1.030820245659196, 0.0, 1.0398287528021697, 2.0379738669229566, 3.0305470142643616, 4.01017132730153, 4.969127959535048, 6.040387789292522, 7.026836787453702, 8.970540900902023, 9.916361729999469, 10.94911090025052, 9.890282833415114, 8.958420841502088, 7.939620278893557, 7.005083397779686, 5.982172542977545, 5.009728692093826, 4.009326447473583, 2.941198224260611, 1.9190654102157574, 0.958540936873823, 1.9709618436072316, 2.9709957842114383, 3.933314115348852, 4.96987493631027, 5.988303724865504, 6.973619264735264, 7.948842678992154, 9.748839947494258, 10.809493197721519, 11.828354809745536, 10.881334285120067, 9.83750199159918, 8.842266838504196, 7.897978640173827, 6.87616185739717, 5.8711301173984385, 4.940708685176507, 3.8937590877308415, 2.9310263473618994, 1.8900227000033758, 2.8506799345474105, 3.821804308064475, 4.797439956870573, 5.748602317911022, 6.804305428974015, 7.85288929108395, 8.798842638939583, 10.616841851083041, 11.674955321859604, 12.698343524488743, 11.76891278180557, 10.743883763391059, 9.769399035681262, 8.871546134682513, 7.872226443187406, 6.9204204698587874, 5.91285557693112, 4.841259318287177, 3.8478630951110326, 2.902852972058451, 3.8820957545920347, 4.801428513271991, 5.7529100733765075, 6.770624183347208, 7.711476512790603, 8.656043429124962, 9.62204163349984, 11.607727054269303, 12.619412040004478, 13.580064004670394, 12.653676269815696, 11.705381087711679, 10.711714936943437, 9.806465954828628, 8.842826075966341, 7.946839404445731, 6.901433916270523, 5.829866766405249, 4.805120813794705, 3.830827791004902, 4.760246627476647, 5.743723707125126, 6.7214524302301175, 7.710717769316357, 8.723463396401662, 9.722468026642302, 10.548880074221684], [10.57285503468019, 9.75423153124814, 8.778736882523576, 7.832065888345888, 6.815811125467496, 5.863941057330857, 5.003360535539247, 5.871372964588731, 6.811030101787831, 7.835456379533436, 8.88876905571444, 9.879186410065696, 10.792908234268099, 11.73241064679439, 12.650513502832114, 13.63899112295301, 14.596376601926602, 13.595831957884224, 12.609770262990338, 11.58303266664023, 11.591760812326767, 10.788748823486545, 9.76924976082758, 8.873867289325434, 7.832377602157922, 6.843142975648112, 5.953487239159436, 6.921020920450721, 7.866575908180921, 8.872263976721264, 9.825659665151143, 10.785701738856293, 11.829982358378501, 12.694874237121763, 13.577641498402768, 14.644871927501647, 15.521824279415906, 14.626156794348503, 13.657860258822867, 12.637541156587092, 12.622951753423811, 11.68179661360092, 10.72503702177233, 9.758871301608677, 8.760030868801346, 7.88274270454766, 6.956217338494956, 7.9781058479219, 8.883013099887027, 9.890267820418021, 10.846505358615588, 11.777298347404757, 12.829568576976, 13.296215359707515, 13.66977405186409, 14.608407087390214, 15.551450961834165, 15.598461379394458, 14.583258409906033, 13.668401107007387, 13.630300617742419, 12.692886552722122, 11.70888094308241, 10.823425668714401, 9.82186813520423, 8.866071851239036, 7.962806620005368, 8.953915154407591, 9.89893155367832, 10.875656944512784, 11.87610799020969, 12.765663213225405, 13.140918638093169, 12.30847906049076, 12.649868095922496, 13.693898424891374, 14.622417051331507, 15.557535127138216, 15.569092598250478, 14.652930331688573, 14.555876269166033, 13.631900474699773, 12.764862582627345, 11.813632503220667, 10.80413005696457, 9.92203054440304, 9.016776691065122, 9.957480090346996, 10.891057663802693, 11.835302136916662, 12.784942106304829, 12.893980290746246, 12.152582841935494, 11.336325860155567, 11.671038849692914, 12.693301226141648, 13.655010648349384, 14.583873998126586, 15.596553216316073, 15.609619088758008, 15.563978362562056, 14.660100580042284, 13.710862683607258, 12.785522354618804, 11.746692893584948, 10.972835070747399, 10.061452427926726, 10.91978695748146, 11.823011021437878, 12.750544833067593, 12.746912977300346, 11.933050666892663, 11.125809873212333, 10.318186344907389, 10.745177234675433, 11.724414757373237, 12.638750517543468, 13.596785407005623, 14.64887118885851, 15.462445614696342, 15.53215667620098, 15.658935916128257, 14.78468276451986, 13.786357696885105, 12.717464631235838, 11.943148512826518, 11.123663104141666, 11.958427720282243, 12.843516297379539, 12.662218276328923, 11.72544889133287, 10.90916505994615, 10.060106102257775, 9.304517176432604, 9.792697311246394, 10.744395193095203, 11.676496872908409, 12.620923469605728, 13.62931576316212, 14.533015284933501, 14.578403107315802, 15.578862106732338, 15.72425445806375, 14.714376955097842, 13.742820480115235, 12.969299339763515, 12.099954551032546, 12.939809704215408, 12.644535022785485, 11.720744239718266, 10.764143186358751, 9.977235653980534, 9.026945131544933, 8.300831469318108, 8.719338843131288, 9.690336008039429, 10.619922608140067, 11.55887793249209, 12.609932147649271, 13.595929055058956, 13.608983966678927, 14.622251608462134, 15.58535030199685, 15.620845426108236, 14.673581108614266, 14.0116304492386, 13.166483443042532, 12.589741846161667, 11.625171210142161, 10.685221879818084, 9.75209999464698, 8.954872821362539, 8.06305887030919, 7.272763316652552, 7.793465038046962, 8.756677276089912, 9.684394858785476, 10.757969897119448, 11.807425076097338, 12.679690743995405, 12.670904263918702, 13.635489042197735, 14.552375336011556, 15.47600801922163, 14.518119136627755, 13.58398966825261, 12.610845737028503, 11.668710943424086, 10.625233055416873, 9.760716536743153, 8.783508997834348, 7.965363067986907, 7.077351626953225, 6.339042819838236, 6.7987331339216395, 7.794559571625504, 8.733943006927415, 9.808201635276934, 10.77052833229315, 11.699002218812376, 11.624682287127795, 12.626289824632012, 13.570409490714937, 14.585044528250215, 13.584376489335343, 12.61074861969922, 11.653691510711287, 10.662148710023724, 9.696269258139774, 8.80958419904502, 7.8081191967750625, 6.906989366981399, 6.053331042423062, 5.267385495771191, 5.841499904631502, 6.7923084513266065, 7.776621852049128, 8.78824392817618, 9.704245332576775, 10.682297486140017, 10.751915153045061, 11.679868264990704, 12.697761139465648, 13.736380896983846, 12.7244627118325, 11.654714944151275, 10.722051809620202, 9.776606021848297, 8.745505252509771, 7.820383922257764, 6.856769638477535, 5.852020328232115, 4.983647006273401, 4.2130800301582845, 4.880838472824765, 5.830030738209413, 6.867825268530275, 7.794639097043618, 8.768892409468645, 9.796309774652146, 9.872486593756536, 10.797296190558074, 11.850681185034807, 12.821902306212348, 11.75659351805457, 10.746841962677866, 9.817071904254346, 8.806863397246346, 7.837846681203061, 6.8180360344553055, 5.85000939622702, 4.924483066087391, 3.9374057345628826, 3.1473666845370616, 3.849692985799516, 4.893095932112244, 5.845695206695548, 6.834395589990226, 7.884114712939638, 8.853684068187205, 8.87314413064158, 9.857028620984224, 10.877610964274398, 11.839196124976596, 10.815462209107022, 9.800800090535049, 8.852148366935369, 7.914473970837038, 7.042912457035608, 6.050233913502831, 5.022779787335959, 4.027822762600429, 3.001220008607259, 2.098900730537106, 2.9137501049059504, 3.9361587378449308, 4.919866244783599, 5.908553621868178, 6.949098240610912, 7.895667681144866, 7.904751880455931, 8.846277261301491, 9.89273854232076, 10.842899294745632, 9.917537798760598, 8.921491540836833, 7.958568407972798, 6.934073448682596, 5.978783557583984, 5.010105734790559, 4.0514607357194015, 2.9998541435137343, 1.9771266053326977, 1.074880246937971, 1.9495840080608131, 3.010250784732542, 3.971565199004165, 4.976666234520535, 5.920572013809659, 6.9577326675832305, 7.032851731227389, 8.061820280038477, 9.114296926975326, 10.177306809395116, 9.3737538319054, 8.307848182305406, 7.28001996386552, 6.280602068298326, 5.223205725025057, 4.159625383734689, 3.119049906178676, 2.0706489984613654, 1.0398287528021697, 0.0, 0.998145114120787, 1.990718261462192, 2.9703425744993597, 3.9292992067328787, 5.000559036490352, 5.987008034651532, 7.930712148099854, 8.8765329771973, 9.924159094551303, 10.888180933981069, 9.956318942068043, 8.937518379459512, 8.00298149834564, 6.9800706435435, 6.007626792659781, 5.007224548039538, 3.9390963248265667, 2.916963510781713, 1.9564390374397786, 0.9440181307063702, 1.9440520713105771, 2.906370402447991, 3.942931223409409, 4.948474972063335, 5.933790511933095, 6.909013926189985, 8.75698647610427, 9.807752311548082, 10.835636277080456, 11.782656801705924, 10.835400092165136, 9.840164939070153, 8.895876740739784, 7.8740599579631265, 6.869028217964394, 5.938606785742463, 4.891657188296797, 3.928924447927855, 2.8879208005693315, 1.9521683704479944, 2.923292743965059, 3.85923610511111, 4.810398466151559, 5.866101577214552, 6.861035819693961, 7.806989167549594, 9.678637999323579, 10.736751470100142, 11.76013967272928, 12.742758160216692, 11.741781863957016, 10.767297136247219, 9.86944423524847, 8.870124543753363, 7.918318570424744, 6.910753677497077, 5.839157418853134, 4.845761195676989, 3.9007510726244066, 3.0033948427563484, 3.9029169491725746, 4.814706221617045, 5.832420331587746, 6.7732726610311405, 7.717839577365499, 8.683837781740378, 10.66952320250984, 11.681208188245016, 12.641860152910931, 13.651574370381654, 12.703279188277637, 11.709613037509394, 10.804364055394585, 9.840724176532298, 8.944737505011686, 7.899332016836478, 6.827764866971204, 5.803018914360661, 4.8287258915708575, 3.9788114968813284, 4.84521214302571, 5.783248578470655, 6.7725139175568945, 7.7852595446422, 8.78426417488284, 9.61067622246222], [9.63199414202145, 8.813370638589397, 7.837875989864836, 6.891204995687145, 5.874950232808755, 4.9949935574145545, 6.001505649660034, 6.869518078709518, 7.809175215908619, 8.833601493654223, 9.886914169835226, 10.877331524186483, 11.791053348388886, 12.730555760915177, 13.6486586169529, 14.63672914142735, 13.679343662453759, 12.654971065225483, 11.668909370331598, 10.64217177398149, 10.650899919668026, 9.847887930827804, 8.82838886816884, 7.933006396666691, 6.904979661987913, 5.974195475731809, 6.951632353280223, 7.919166034571509, 8.864721022301708, 9.870409090842049, 10.823804779271928, 11.783846852977078, 12.828127472499288, 13.69301935124255, 13.619921517336133, 14.59275450255192, 14.604791339943063, 13.685295901689763, 12.716999366164126, 11.696680263928352, 11.694622572701753, 10.754398673430913, 9.797639081602322, 8.831473361438668, 7.832632928631337, 7.013795204631357, 7.954362452615743, 8.976250962042688, 9.881158214007813, 10.888412934538808, 11.844650472736372, 12.775443461525542, 13.827713691096784, 13.645927711005065, 12.671628937743304, 13.610261973269427, 14.553305847713379, 14.657600486735717, 13.642397517247293, 12.734712774183619, 12.702902677572412, 11.765488612552115, 10.7814830029124, 9.896027728544393, 8.894470195034222, 7.997124351322733, 8.945605128775306, 9.936713663177528, 10.897076667799107, 11.873802058633572, 12.874253104330478, 13.76380832734619, 13.627930734033871, 12.665382293678121, 11.65172298180171, 12.695753310770588, 13.62427193721072, 14.55939001301743, 14.628231705591737, 13.725532391518566, 13.628478328996026, 12.704502534529766, 11.837464642457334, 10.886234563050659, 9.876732116794562, 9.053083044486735, 9.999575199835059, 10.940278599116933, 11.88920277792348, 12.833447251037448, 13.783087220425616, 13.495229218059867, 12.680574407538062, 11.693229093342929, 10.672893735572128, 11.695156112020861, 12.656865534228597, 13.5857288840058, 14.598408102195288, 14.682221148588, 14.636580422392049, 13.732702639872274, 12.783464743437248, 11.858124414448795, 10.81929495341494, 10.103887570831095, 11.041063024622158, 11.902585466251397, 12.821156135558665, 13.74868994718838, 13.460985696298295, 12.534299594206285, 11.6538014388149, 10.724842490479777, 9.747032120554646, 10.72626964325245, 11.640605403422681, 12.598640292884838, 13.650726074737726, 14.464300500575556, 14.534011562080194, 14.731537975958247, 13.85728482434985, 12.858959756715096, 11.79006669106583, 11.074201012910214, 12.01582257410557, 12.94122622905218, 13.841661411500326, 13.477026124674797, 12.43952161033082, 11.51041398725977, 10.657740945854414, 9.753048968628148, 8.794552197125608, 9.746250078974416, 10.678351758787622, 11.622778355484943, 12.631170649041335, 13.534870170812715, 13.580257993195016, 14.580716992611551, 14.796856517893742, 13.786979014927834, 12.815422539945226, 12.10035183984721, 12.99211402099645, 13.922608212985345, 13.459342871131359, 12.53555208806414, 11.578951034704625, 10.578484581294155, 9.624579975141572, 8.749363261513652, 7.721193729010501, 8.692190893918642, 9.62177749401928, 10.560732818371303, 11.611787033528485, 12.59778394093817, 12.61083885255814, 13.624106494341346, 14.587205187876062, 14.693447485938227, 13.746183168444258, 13.142682949322296, 14.058642913006436, 13.40454969450754, 12.439979058488035, 11.500029728163957, 10.566907842992853, 9.599340549438558, 8.660693713905829, 7.7212951088480954, 6.795319923926176, 7.758532161969125, 8.68624974466469, 9.759824782998662, 10.809279961976554, 11.681545629874618, 11.672759149797916, 12.637343928076946, 13.554230221890768, 14.535355298389963, 14.70991562013157, 14.086321413616295, 13.491792002120139, 12.549657208515722, 11.506179320508508, 10.575524385089027, 9.598316846180222, 8.67314338744318, 7.734183152364311, 6.787574612033779, 5.800588019800853, 6.796414457504717, 7.735797892806628, 8.810056521156149, 9.772383218172365, 10.70085710469159, 10.626537173007009, 11.628144710511224, 12.572264376594148, 13.64163003778538, 14.500200226625731, 13.526572356989607, 12.569515248001675, 11.577972447314112, 10.612092995430162, 9.72540793633541, 8.723942934065452, 7.8228131042717886, 6.969154779713451, 5.909066352952522, 4.843354790510715, 5.79416333720582, 6.778476737928341, 7.790098814055393, 8.706100218455989, 9.68415237201923, 9.753770038924273, 10.681723150869916, 11.69961602534486, 12.738235782863057, 13.640286449122888, 12.570538681441663, 11.63787554691059, 10.692429759138685, 9.66132898980016, 8.736207659548153, 7.772593375767924, 6.767844065522504, 5.899470743563789, 4.917637218083751, 3.8826933587039782, 4.831885624088627, 5.8696801544094885, 6.796493982922831, 7.770747295347857, 8.798164660531357, 8.874341479635751, 9.799151076437287, 10.85253607091402, 11.836795163570546, 12.725616158485252, 11.715864603108548, 10.749837577324595, 9.722687134536734, 8.75367041849345, 7.733859771745695, 6.765833133517409, 5.84030680337778, 4.853229471853272, 3.921978885436983, 2.851547871678729, 3.8949508179914574, 4.847550092574761, 5.83625047586944, 6.885969598818852, 7.855538954066418, 7.8749990165207935, 8.858883506863437, 9.879465850153611, 10.847585349912464, 11.784484849537703, 10.76982273096573, 9.82117100736605, 8.88349661126772, 8.01193509746629, 7.019256553933513, 5.9918024277666415, 4.952912729540916, 3.917043745897648, 2.9022588251914163, 1.9156049907851633, 2.938013623724143, 3.921721130662811, 4.91040850774739, 5.950953126490124, 6.89752256702408, 6.906606766335145, 7.848132147180705, 8.894593428199974, 9.890788257438903, 10.816149753423936, 9.890514181267514, 8.92759104840348, 7.903096089113278, 6.947806198014667, 5.979128375221242, 5.020483376150084, 3.9688767839444163, 2.9461492457633796, 1.8782383415922814, 0.951438893940026, 2.0121056706117546, 2.9734200848833785, 3.978521120399748, 4.9224268996888725, 5.959587553462444, 6.034706617106602, 7.06367516591769, 8.11615181285454, 9.179161695274328, 10.192243983703396, 9.305993296426195, 8.278165077986309, 7.278747182419115, 6.221350839145845, 5.157770497855476, 4.117195020299463, 3.0687941125821525, 2.0379738669229566, 0.998145114120787, 0.0, 0.9925731473414052, 1.9721974603785728, 2.9311540926120916, 4.002413922369565, 4.988862920530745, 6.9325670339790655, 7.878387863076512, 8.926013980430515, 9.984842047265921, 10.916704039178947, 9.935663493580298, 9.001126612466427, 7.9782157576642865, 7.005771906780567, 6.005369662160325, 4.937241438947353, 3.9151086249025, 2.9545841515605655, 1.942163244827157, 1.0148027748070867, 1.9655095097892499, 2.9714963807932047, 3.950329857942547, 4.935645397812308, 5.910868812069197, 7.758841361983482, 8.809607197427294, 9.837491162959667, 10.784511687585136, 11.828343981106023, 10.83831005319094, 9.89402185486057, 8.872205072083913, 7.867173332085181, 6.93675189986325, 5.889802302417584, 4.927069562048642, 3.8860659146901186, 2.950313484568781, 2.054345244048756, 2.9183752124523687, 3.8695375734928183, 4.925240684555812, 5.862890705573173, 6.808844053428807, 8.737777106664836, 9.788589449343613, 10.811977651972752, 11.788532611655256, 12.739926978077802, 11.765442250368006, 10.867589349369256, 9.86826965787415, 8.91646368454553, 7.9088987916178635, 6.837302532973921, 5.843906309797776, 4.898896186745194, 4.001539956877135, 3.033969449256272, 3.8738453289583035, 4.891559438929004, 5.832411768372399, 6.776978684706758, 7.742976889081636, 9.7286623098511, 10.740347295586275, 11.70099926025219, 12.748007231772236, 13.696302413876253, 12.70775815163018, 11.802509169515371, 10.838869290653085, 9.942882619132474, 8.897477130957267, 7.825909981091992, 6.801164028481448, 5.826871005691645, 4.976956611002115, 3.976264643109407, 4.8423876858119135, 5.831653024898152, 6.844398651983458, 7.843403282224097, 8.66981532980348], [8.639420994680044, 7.820797491247993, 6.845302842523431, 5.89863184834574, 4.88237708546735, 5.837490896514209, 6.864834710132187, 7.816671485997561, 8.756328623196662, 9.780754900942267, 10.83406757712327, 11.824484931474526, 12.756534932446698, 13.69603734497299, 14.614140201010713, 13.644155994085946, 12.686770515112354, 11.662397917884078, 10.67633622299019, 9.649598626640085, 9.658326772326621, 8.855314783486397, 7.835815720827434, 6.940433249325286, 5.912406514646508, 6.816692814831464, 7.814961413752376, 8.806957227546022, 9.811874429589752, 10.817562498130094, 11.770958186559973, 12.731000260265123, 13.789810199992143, 14.658500935300362, 14.612494664677538, 14.206433631214152, 13.612218192601658, 12.692722754348358, 11.72442621882272, 10.704107116586947, 10.702049425360347, 9.761825526089506, 8.805065934260917, 7.838900214097263, 6.840059781289932, 7.852873425633347, 8.817691513087896, 9.83958002251484, 10.828311621295857, 11.835566341826851, 12.791803880024418, 13.722596868813588, 14.77486709838483, 14.63850085834647, 13.664202085084709, 13.22394110193166, 13.866503394213057, 13.66502733939431, 12.649824369905886, 11.742139626842214, 11.710329530231006, 10.772915465210708, 9.788909855570996, 8.903454581202988, 7.901897047692816, 8.836202572324723, 9.784683349777294, 10.775791884179517, 11.761342234337798, 12.738067625172263, 13.73851867086917, 14.710961734634235, 14.620503881375276, 13.657955441019526, 12.644296129143115, 12.21286483334528, 12.937469483710398, 13.872587559517108, 13.63565855825033, 12.73295924417716, 12.63590518165462, 11.71192938718836, 10.844891495115931, 9.893661415709252, 8.884158969453155, 9.892161265488726, 10.838653420837048, 11.779356820118922, 12.75346834446217, 13.69771281757614, 14.647352786964307, 14.48780236540127, 13.673147554879467, 12.685802240684334, 11.665466882913533, 11.151719971239492, 11.938373621956583, 12.867236971733785, 13.875935947837045, 13.689648001246594, 13.644007275050642, 12.74012949253087, 11.790891596095845, 10.865551267107389, 9.826721806073532, 10.85430159324882, 11.791477047039884, 12.741663687253386, 13.685421702097356, 14.612955513727071, 14.453558843639698, 13.526872741547688, 12.646374586156305, 11.717415637821182, 10.739605267896051, 10.182833502471082, 10.918133249064438, 11.876168138526594, 12.928253920379483, 13.581432605664473, 13.65114366716911, 13.738964828616844, 12.864711677008447, 11.86638660937369, 10.797493543724423, 11.82461503532794, 12.766236596523296, 13.78030445005417, 14.705926978039017, 14.469599272016202, 13.432094757672223, 12.502987134601174, 11.650314093195819, 10.745622115969555, 9.787125344467013, 9.115619695752315, 9.955879604429379, 10.9003062011267, 11.908698494683092, 12.652002275901632, 12.646189805862402, 13.646648805278938, 13.804283370552335, 12.794405867586427, 11.82284939260382, 12.850765862264936, 13.742528043414175, 14.761686433987334, 14.451916018472764, 13.528125235405545, 12.57152418204603, 11.571057728635559, 10.617153122482977, 9.741936408855059, 8.713766876351906, 8.061560510696541, 8.899305339661037, 9.83826066401306, 10.86362660828893, 11.714916046027087, 11.676770665225527, 12.690038307008734, 13.653137000543452, 13.70087433859682, 12.753610021102851, 13.758154553597667, 14.694435650828305, 14.397122841848946, 13.43255220582944, 12.492602875505362, 11.559480990334258, 10.591913696779965, 9.653266861247234, 8.713868256189501, 7.787893071267581, 7.033139088711301, 7.841155665103387, 8.90700685956787, 9.87521177464394, 10.747477442542005, 10.738690962465302, 11.703275740744335, 12.620162034558158, 13.601287111057353, 13.717342472790163, 14.701793017891665, 14.484365149461546, 13.542230355857129, 12.498752467849915, 11.568097532430432, 10.590889993521627, 9.665716534784584, 8.726756299705716, 7.780147759375184, 6.793161167142258, 6.071021384246893, 6.838460320043286, 7.912718948392805, 8.838315030839752, 9.766788917358976, 9.692468985674395, 10.694076523178612, 11.638196189261539, 12.70756185045277, 13.708229889367644, 14.519145504331012, 13.56208839534308, 12.570545594655517, 11.604666142771567, 10.717981083676817, 9.716516081406859, 8.815386251613194, 7.9617279270548575, 6.901639500293927, 5.83592793785212, 5.008311739105726, 5.874410726815272, 6.886032802942324, 7.772032031123375, 8.750084184686617, 8.819701851591661, 9.747654963537304, 10.765547838012248, 11.804167595530444, 12.764643810088941, 13.563111828783068, 12.630448694251996, 11.68500290648009, 10.653902137141564, 9.728780806889558, 8.76516652310933, 7.76041721286391, 6.892043890905196, 5.910210365425156, 4.875266506045383, 4.03196345920357, 4.935611967076875, 5.862425795590218, 6.836679108015244, 7.864096473198745, 7.886258033009935, 8.806577929095882, 9.859962923572615, 10.844222016229141, 11.747222182248029, 12.708437750449953, 11.742410724666001, 10.715260281878141, 9.746243565834856, 8.7264329190871, 7.758406280858815, 6.832879950719186, 5.845802619194678, 4.9145520327783885, 3.844121019020134, 2.960882630658844, 3.913481905242148, 4.902182288536826, 5.944863437626095, 6.9144327928736615, 6.886915569894978, 7.866310359522032, 8.886892702812206, 9.855012202571059, 10.794402620157676, 11.762395878307135, 10.813744154707456, 9.876069758609125, 9.004508244807695, 8.011829701274918, 6.9843755751080465, 5.945485876882322, 4.909616893239054, 3.8948319725328218, 2.9081781381265683, 1.9532441584513303, 2.9369516653899983, 3.9256390424745775, 4.966183661217312, 5.912753101751267, 5.91403361899374, 6.8555589998393, 7.902020280858569, 8.898215110097498, 9.82357660608253, 10.819622864006295, 9.920164195744885, 8.895669236454683, 7.940379345356072, 6.971701522562647, 6.013056523491489, 4.961449931285822, 3.9387223931047846, 2.8708114889336867, 1.9440120412814312, 1.0273362053389414, 1.980846937541973, 2.985947973058343, 3.9298537523474675, 4.967014406121039, 5.042133469765197, 6.071102018576285, 7.123578665513135, 8.186588547932924, 9.199670836361992, 10.265576485961986, 9.27073822532771, 8.271320329760517, 7.213923986487249, 6.15034364519688, 5.109768167640867, 4.061367259923557, 3.0305470142643616, 1.990718261462192, 0.9925731473414052, 0.0, 0.9796243130371676, 1.9385809452706866, 3.0098407750281604, 3.99628977318934, 5.9399938866376605, 6.885814715735107, 7.933440833089111, 8.992268899924518, 9.924130891837544, 10.928236640921707, 9.993699759807836, 8.970788905005694, 7.998345054121974, 6.9979428095017315, 5.929814586288759, 4.9076817722439054, 3.947157298901971, 2.9347363921685625, 1.9352546935852584, 0.9729363624478448, 1.9789232334517992, 2.957756710601142, 3.9430722504709026, 4.918295664727792, 6.766268214642077, 7.817034050085889, 8.844918015618262, 9.79193854024373, 10.835770833764618, 11.803791637248752, 10.859503438918383, 9.837686656141726, 8.832654916142994, 7.902233483921064, 6.855283886475398, 5.892551146106456, 4.833219321978161, 3.8725620874341264, 2.901437713917062, 1.9258020651109637, 2.8769644261514133, 3.9326675372144067, 4.870317558231768, 5.816270906087402, 7.745203959323432, 8.796016302002208, 9.819404504631347, 10.795959464313851, 11.820988482728362, 12.730923834425818, 11.833070933427068, 10.833751241931962, 9.863617091833575, 8.856052198905907, 7.784455940261964, 6.791059717085819, 5.846049594033237, 4.886891367159399, 3.881061919124578, 2.8812721816168985, 3.8989862915875992, 4.839838621030994, 5.784405537365353, 6.750403741740231, 8.736089162509694, 9.74777414824487, 10.708426112910786, 11.755434084430831, 12.703729266534848, 13.673239735687993, 12.767990753573184, 11.804350874710897, 10.890036026420516, 9.844630538245308, 8.773063388380034, 7.748317435769491, 6.774024412979688, 5.862308021284379, 4.823357112977713, 3.8498145384705085, 4.839079877556747, 5.851825504642053, 6.850830134882692, 7.6772421824620745], [7.680896769717898, 6.898313893046436, 5.9228192443218735, 5.110673660508351, 5.862001398504518, 6.817115209551377, 7.844459023169355, 8.796295799034729, 9.73595293623383, 10.760379213979434, 11.813691890160436, 12.804109244511693, 13.736159245483867, 14.63220377820741, 13.661730237584395, 12.6856317691238, 11.728246290150208, 10.703873692921933, 9.717811998028044, 8.691074401677938, 8.699802547364474, 7.93283118528484, 6.913332122625877, 6.152475061487898, 6.892030827683676, 7.796317127868632, 8.794585726789544, 9.78658154058319, 10.791498742626919, 11.797186811167261, 12.75058249959714, 13.71062457330229, 14.76943451302931, 15.541564496603616, 14.58885823315505, 13.667523278352942, 12.653693967639512, 11.734198529386212, 10.765901993860572, 9.7455828916248, 9.7435252003982, 8.849466175785132, 7.892706583956541, 7.142262139832391, 7.8196840943271, 8.832497738670515, 9.797315826125063, 10.819204335552007, 11.807935934333024, 12.815190654864018, 13.771428193061585, 14.702221181850755, 15.754491411421997, 15.618125171383637, 14.643826398121876, 13.975122032607276, 13.02526329940253, 12.706503114432163, 11.691300144943739, 10.783615401880066, 10.761873245395485, 9.860556114906334, 8.876550505266621, 8.206816506938116, 8.881521360729984, 9.815826885361892, 10.764307662814463, 11.755416197216686, 12.740966547374967, 13.71769193820943, 14.718142983906336, 15.690586047671403, 15.600128194412443, 14.637579754056693, 13.623920442180282, 13.024748015340004, 12.096229388899872, 13.031347464706581, 12.677134333288183, 11.784502959341639, 11.687448896819099, 10.799570036883985, 9.932532144811557, 9.27133494263569, 9.863783282490324, 10.871785578525895, 11.818277733874217, 12.758981133156091, 13.73309265749934, 14.677337130613308, 15.626977100001476, 15.467426678438438, 14.652771867916634, 13.6654265537215, 12.6450911959507, 11.973112623907314, 11.097133527146058, 12.02599687692326, 13.018892383771965, 12.741191716411073, 12.695550990215121, 11.827770142226496, 10.87853224579147, 10.32638168062676, 10.806346119110701, 11.833925906285987, 12.77110136007705, 13.721288000290555, 14.665046015134525, 15.59257982676424, 15.433183156676865, 14.506497054584855, 13.625998899193473, 12.697039950858349, 11.719229580933218, 11.004226155138904, 10.076893154253913, 11.034928043716068, 12.071210356314403, 12.718899228556067, 12.788610290060705, 12.82660547831247, 11.952352326704073, 11.353799341642254, 11.777117856761592, 12.804239348365106, 13.745860909560463, 14.759928763091338, 15.685551291076186, 15.44922358505337, 14.41171907070939, 13.482611447638341, 12.629938406232986, 11.725246429006722, 10.76674965750418, 9.981201972040095, 9.114639509618854, 10.059066106316173, 11.05165493061801, 11.789468898793226, 11.783656428753996, 12.759497336900395, 12.93466340385551, 12.384876287223737, 12.802473705640988, 13.830390175302103, 14.722152356451343, 15.741310747024503, 15.43154033150993, 14.507749548442712, 13.551148495083197, 12.550682041672726, 11.596777435520144, 10.721560721892226, 9.693391189389073, 8.927142786984321, 8.058065244850512, 8.997020569202535, 10.001093231180525, 10.85238266891868, 10.814237288117122, 11.738900542452498, 12.701999235987216, 13.438517391347519, 13.73323433414002, 14.737778866634835, 15.674059963865474, 15.376747154886113, 14.412176518866607, 13.47222718854253, 12.539105303371425, 11.571538009817132, 10.632891174284401, 9.693492569226668, 8.767517384304748, 7.89872136499908, 6.999915570292862, 8.065766764757345, 9.012678397535534, 9.884944065433599, 9.876157585356896, 10.752137976188099, 11.669024270001922, 12.650149346501117, 13.608038229094992, 14.618918116609217, 15.463989462498713, 14.521854668894296, 13.478376780887082, 12.5477218454676, 11.570514306558794, 10.645340847821751, 9.706380612742883, 8.759772072412352, 7.772785480179425, 6.936603660534672, 5.997220225232761, 7.07147885358228, 7.975781653731346, 8.90425554025057, 8.82993560856599, 9.742938758622376, 10.687058424705302, 11.756424085896533, 12.757092124811408, 13.730719994447531, 14.541712708380249, 13.550169907692686, 12.584290455808736, 11.697605396713984, 10.696140394444026, 9.795010564650362, 8.941352240092025, 7.881263813331094, 6.815552250889287, 5.987936052142894, 5.033170632004747, 6.0447927081318, 6.90949865401497, 7.8875508075782115, 7.900290700541117, 8.796517198981068, 9.814410073456012, 10.853029830974208, 11.785019497051774, 12.834496217410665, 13.610073007289165, 12.664627219517259, 11.633526450178733, 10.708405119926727, 9.744790836146498, 8.740041525901077, 7.871668203942363, 6.889834678462323, 5.85489081908255, 5.011587772240738, 4.0943718722663505, 5.021185700779693, 5.974145730906839, 6.960261995026257, 6.906633719972767, 7.826953616058715, 8.880338610535448, 9.864597703191974, 10.767597869210862, 11.7754822978353, 12.72203503770317, 11.69488459491531, 10.725867878872025, 9.70605723212427, 8.738030593895983, 7.812504263756353, 6.825426932231845, 5.894176345815556, 4.823745332057301, 3.940506943696012, 3.0722418104316223, 4.019485727885845, 4.987813320785161, 5.9573826760327275, 5.90729125685781, 6.886686046484865, 7.907268389775039, 8.875387889533892, 9.814778307120509, 10.829440425692482, 11.778092149292162, 10.855694071646292, 9.984132557844863, 8.991454014312085, 7.963999888145214, 6.925110189919489, 5.889241206276221, 4.874456285569989, 3.887802451163736, 2.932868471488498, 2.0179858609741705, 2.968588925633644, 4.009133544376378, 4.955702984910333, 4.934409305956572, 5.8759346868021325, 6.9223959678214015, 7.918590797060331, 8.843952293045362, 9.839998550969128, 10.802921683833162, 9.87529354949185, 8.920003658393238, 7.951325835599814, 6.992680836528656, 5.941074244322989, 4.918346706141952, 3.850435801970854, 2.9236363543185986, 2.006960518376109, 1.0012226245048055, 2.0063236600211756, 2.9502294393103, 3.987390093083871, 4.062509156728029, 5.091477705539117, 6.1439543524759666, 7.206964234895755, 8.220046523324823, 9.285952172924818, 10.250362538364879, 9.250944642797686, 8.193548299524418, 7.129967958234049, 6.089392480678036, 5.040991572960726, 4.01017132730153, 2.9703425744993597, 1.9721974603785728, 0.9796243130371676, 0.0, 0.9589566322335189, 2.0302164619909924, 3.016665460152172, 4.960369573600493, 5.9061904026979395, 6.9538165200519435, 8.012644586887351, 8.944506578800377, 9.963307141408908, 10.89784402252278, 9.95041321804286, 8.97796936715914, 7.977567122538897, 6.9094388993259255, 5.887306085281072, 4.926781611939138, 3.9143607052057297, 2.914879006622426, 1.9525606754850124, 0.9992989204146318, 1.9781323975639746, 2.963447937433735, 3.9386713516906244, 5.786643901604909, 6.837409737048722, 7.865293702581095, 8.812314227206564, 9.856146520727451, 10.851381673822434, 11.795669872152803, 10.817310969178894, 9.812279229180163, 8.881857796958233, 7.834908199512567, 6.872175459143625, 5.81284363501533, 4.852186400471295, 3.88106202695423, 2.9054263781481318, 1.9544808279498556, 3.0032669368908844, 3.890693245194601, 4.836646593050234, 6.786679734361287, 7.81639198896504, 8.839780191594178, 9.816335151276684, 10.841364169691195, 11.7785138709995, 12.76923736666149, 11.81337555496913, 10.843241404870742, 9.835676511943076, 8.764080253299133, 7.770684030122988, 6.8256739070704056, 5.866515680196567, 4.860686232161746, 3.8608964946540665, 2.976502693386042, 3.9173550228294367, 4.861921939163795, 5.791879516778086, 7.777564937547549, 8.789249923282725, 9.74990188794864, 10.796909859468686, 11.745205041572703, 12.720829772261675, 13.704157186807604, 12.783975187748066, 11.869660339457685, 10.824254851282477, 9.752687701417203, 8.727941748806659, 7.7536487260168565, 6.841932334321547, 5.802981426014881, 4.8294388515076765, 4.051121689719358, 4.929341906440496, 5.9283465366811345, 6.718717957499929], [6.7219401374843795, 5.9874002503857975, 5.1196541783476714, 6.06963029274187, 6.820958030738036, 7.776071841784896, 8.803415655402873, 9.755252431268248, 10.694909568467349, 11.719335846212953, 12.772648522393956, 13.763065876745213, 14.6816395789097, 13.67324714597389, 12.702773605350876, 11.726675136890282, 10.76928965791669, 9.744917060688415, 8.758855365794528, 7.73211776944442, 7.740845915130956, 7.042704596375821, 6.110167056651675, 7.058704277855366, 7.850987459917195, 8.75527376010215, 9.753542359023061, 10.745538172816708, 11.750455374860438, 12.75614344340078, 13.70953913183066, 14.66958120553581, 15.599035036787367, 14.582607864370097, 13.62990160092153, 12.708566646119424, 11.694737335405994, 10.775241897152695, 9.806945361627056, 8.786626259391282, 8.784568568164683, 8.04630110981093, 7.089541517982339, 8.048491356199857, 8.778640726560619, 9.791454370904034, 10.75627245835858, 11.778160967785524, 12.766892566566543, 13.774147287097538, 14.730384825295104, 15.661177814084274, 16.548467788213816, 15.55249295377612, 14.578194180514359, 13.691059175401916, 12.767671601925779, 11.747546482198647, 10.732343512710223, 9.824658769646549, 9.802916613161969, 9.057391048932132, 8.07338543929242, 9.00199445879707, 9.840477992963503, 10.774783517595411, 11.723264295047983, 12.714372829450205, 13.699923179608486, 14.67664857044295, 15.677099616139856, 16.649542679904922, 16.55908482664596, 15.59653638629021, 14.5828770744138, 13.923321802469426, 12.994803176029293, 12.281130158800366, 11.718177701054667, 10.825546327108123, 10.728492264585583, 9.996404970909783, 9.129367078837355, 10.066512894494643, 10.822739914723844, 11.830742210759414, 12.777234366107736, 13.71793776538961, 14.692049289732859, 15.636293762846828, 16.585933732234995, 16.426383310671955, 15.611728500150152, 14.624383185955018, 13.604047828184218, 12.871686411036734, 11.995707314275478, 11.231478532678043, 12.059935751538445, 11.782235084177557, 11.736594357981605, 11.024605076252294, 10.075367179817269, 11.000754097461108, 11.76530275134422, 12.792882538519507, 13.73005799231057, 14.680244632524074, 15.624002647368044, 16.55153645899776, 16.392139788910384, 15.465453686818375, 14.58495553142699, 13.655996583091866, 12.678186213166736, 11.902799942268324, 10.975466941383333, 10.23305354627043, 11.112253724080883, 11.759942596322547, 11.829653657827185, 12.023440412338267, 11.149187260729871, 12.028171758476603, 12.736074488995111, 13.763195980598626, 14.704817541793982, 15.718885395324858, 16.644507923309707, 16.40818021728689, 15.37067570294291, 14.44156807987186, 13.588895038466505, 12.684203061240241, 11.725706289737698, 10.879775759169515, 10.013213296748274, 9.257191608870535, 10.09269829838449, 10.830512266559706, 10.824699796520477, 11.800540704666876, 12.131498337881307, 13.059248704058085, 13.761430337874508, 14.789346807535622, 15.681108988684862, 16.700267379258023, 16.390496963743452, 15.466706180676232, 14.510105127316717, 13.509638673906245, 12.555734067753663, 11.680517354125746, 10.652347821622591, 9.825716574113741, 8.956639031979932, 8.195146071756897, 9.042136598947005, 9.893426036685161, 9.855280655883602, 10.779943910218979, 11.743042603753697, 12.671080194931722, 13.612814048548785, 14.603599948669697, 15.539881045900335, 16.33570378711963, 15.371133151100127, 14.431183820776049, 13.498061935604944, 12.530494642050652, 11.59184780651792, 10.652449201460188, 9.726474016538265, 8.7972951521285, 7.8984893574222825, 7.123780760757865, 8.053721765302015, 8.92598743320008, 8.917200953123377, 9.79318134395458, 10.710067637768402, 11.691192714267597, 12.649081596861473, 13.659961484375698, 14.633105415599804, 15.480811301127815, 14.437333413120601, 13.506678477701119, 12.529470938792313, 11.604297480055271, 10.665337244976403, 9.718728704645871, 8.731742112412944, 7.835177447664092, 6.895794012362181, 6.1294928495828005, 7.0168250214978265, 7.945298908017051, 7.870978976332471, 8.783982126388857, 9.728101792471783, 10.797467453663014, 11.798135492577888, 12.771763362214012, 13.693158588130547, 14.509126539926202, 13.543247088042252, 12.656562028947503, 11.655097026677545, 10.753967196883881, 9.900308872325542, 8.840220445564613, 7.774508883122807, 6.916057819856689, 5.9317444191341675, 5.098783227799238, 5.950542021781451, 6.928594175344692, 6.941334068307598, 7.837560566747548, 8.855453441222492, 9.894073198740688, 10.826062864818255, 11.875539585177146, 12.731321021200039, 13.623583851750775, 12.59248308241225, 11.667361752160243, 10.703747468380017, 9.698998158134597, 8.83062483617588, 7.848791310695843, 6.81384745131607, 5.970544404474256, 4.992945659395771, 4.066131830882428, 5.01518909867332, 6.0013053627927375, 5.947677087739248, 6.867996983825195, 7.921381978301929, 8.905641070958454, 9.808641236977342, 10.81652566560178, 11.78405905437762, 12.653841227148826, 11.68482451110554, 10.665013864357785, 9.696987226129501, 8.771460895989872, 7.784383564465363, 6.853132978049075, 5.782701964290821, 4.899463575929531, 4.031198442665141, 3.060529095652326, 4.028856688551642, 4.998426043799208, 4.948334624624292, 5.9277294142513455, 6.94831175754152, 7.916431257300372, 8.85582167488699, 9.870483793458963, 10.819135517058642, 11.756809913156973, 10.943089190078382, 9.950410646545604, 8.922956520378733, 7.884066822153008, 6.84819783850974, 5.833412917803508, 4.846759083397255, 3.8918251037220166, 2.9769424932076896, 2.0096322934001245, 3.0501769121428586, 3.9967463526768134, 3.975452673723053, 4.916978054568613, 5.963439335587882, 6.959634164826811, 7.884995660811843, 8.88104191873561, 9.843965051599644, 10.83425018172537, 9.878960290626758, 8.910282467833333, 7.951637468762176, 6.900030876556508, 5.877303338375471, 4.809392434204373, 3.8825929865521176, 2.965917150609628, 1.9601792567383245, 1.0473670277876566, 1.991272807076781, 3.0284334608503523, 3.1035525244945106, 4.132521073305599, 5.184997720242448, 6.248007602662237, 7.261089891091304, 8.326995540691298, 9.354823759131182, 10.209901275031203, 9.152504931757935, 8.088924590467567, 7.048349112911554, 5.999948205194244, 4.969127959535048, 3.9292992067328787, 2.9311540926120916, 1.9385809452706866, 0.9589566322335189, 0.0, 1.0712598297574736, 2.0577088279186535, 4.001412941366975, 4.94723377046442, 5.994859887818424, 7.053687954653831, 7.985549946566857, 9.004350509175387, 9.938887390289258, 10.909369850276379, 9.93692599939266, 8.936523754772416, 7.868395531559445, 6.846262717514591, 5.885738244172657, 4.873317337439249, 3.873835638855945, 2.9115173077185315, 1.9582555526481507, 1.0191757653304558, 2.0044913052002165, 2.979714719457106, 4.82768726937139, 5.878453104815202, 6.9063370703475755, 7.853357594973045, 8.897189888493932, 9.892425041588915, 10.836713239919284, 11.776267601412412, 10.77123586141368, 9.84081442919175, 8.793864831746085, 7.8311320913771425, 6.771800267248848, 5.811143032704813, 4.8400186591877485, 3.8643830103816503, 2.9134374601833746, 2.0443103046573654, 2.9317366129610822, 3.8776899608167152, 5.827723102127768, 6.8574353567315205, 7.880823559360659, 8.857378519043166, 9.882407537457677, 10.81955723876598, 11.81028073442797, 12.772332187202649, 11.802198037104262, 10.794633144176593, 9.72303688553265, 8.729640662356505, 7.784630539303923, 6.825472312430086, 5.819642864395265, 4.819853126887585, 3.9354593256195605, 3.1141899568552343, 3.951008296503156, 4.832922884544567, 6.81860830531403, 7.830293291049207, 8.790945255715123, 9.837953227235168, 10.786248409339185, 11.761873140028156, 12.745200554574085, 13.742931819981584, 12.828616971691204, 11.783211483515997, 10.711644333650723, 9.686898381040178, 8.712605358250375, 7.800888966555066, 6.7619380582484, 5.788395483741195, 5.010078321952877, 4.126176840466294, 5.017432894020496, 5.75976132526641], [5.688529322702256, 4.953989435603673, 5.867628619547828, 6.858503761020409, 7.823348615323266, 8.778462426370126, 9.805806239988105, 10.783503595435215, 11.723160732634316, 12.74758701037992, 13.800899686560923, 14.713281488577755, 13.648228764127577, 12.639836331191768, 11.669362790568753, 10.693264322108158, 9.735878843134566, 8.71150624590629, 7.725444551012403, 6.698706954662296, 6.707435100348832, 6.009293781593697, 6.858141497851832, 7.8066787190555225, 8.853378044502424, 9.757664344687381, 10.755932943608293, 11.74792875740194, 12.778706539027405, 13.784394607567748, 14.737790295997627, 15.624434161732264, 14.565624222005244, 13.549197049587974, 12.596490786139407, 11.6751558313373, 10.66132652062387, 9.74183108237057, 8.773534546844932, 7.7532154446091575, 7.751157753382558, 7.043145234831586, 7.837515959182496, 8.796465797400014, 9.78103131114585, 10.793844955489263, 11.758663042943812, 12.780551552370756, 13.79514373073351, 14.802398451264505, 15.758635989462071, 16.567327203002932, 15.515056973431692, 14.519082138993998, 13.544783365732236, 12.657648360619792, 11.734260787143654, 10.714135667416523, 9.698932697928099, 8.791247954864424, 8.769505798379843, 8.054235173952788, 8.821359880492576, 9.749968899997226, 10.7892284115466, 11.77717410218064, 12.725654879633211, 13.716763414035434, 14.702313764193715, 15.679039155028178, 16.679490200725084, 17.43327015966263, 16.469366878566504, 15.506818438210754, 14.56468932167383, 13.541982741680924, 12.613464115240792, 11.678346039434082, 10.684766886272543, 9.792135512325997, 9.695081449803457, 8.993249095930437, 9.877341520037511, 10.8144873356948, 11.771490333306941, 12.833132795344643, 13.779624950692964, 14.720328349974839, 15.694439874318087, 16.638684347432054, 17.58832431682022, 17.434379219466532, 16.5858652875651, 15.598519973369966, 14.578184615599165, 13.787324836402323, 12.911345739641067, 12.084273275060795, 11.096026852084995, 10.748824269395431, 10.70318354319948, 10.034216210174858, 10.823341621017425, 11.748728538661265, 12.714053169927318, 13.741632957102606, 14.67880841089367, 15.64733817209049, 16.626393231953273, 17.553927043582988, 17.40013569770496, 16.47344959561295, 15.559092318841937, 14.630133370506814, 13.652323000581683, 12.818438367633913, 11.891105366748922, 11.085848288653182, 10.148344824627433, 10.796033696869095, 10.828276927187586, 11.03305154626083, 11.897161701930028, 12.77614619967676, 13.684824907578209, 14.711946399181725, 15.653567960377082, 16.685978934891274, 17.646898507894935, 17.416176126081464, 16.378671611737488, 15.449563988666437, 14.596890947261082, 13.680416037915874, 12.699843077152645, 11.795414184535105, 10.928851722113864, 10.109986351253287, 9.12878939893104, 9.866603367106254, 9.817045553902995, 10.76647353342766, 11.746125112758296, 12.69065412781629, 13.509507505808601, 14.55950253542447, 15.538807032086936, 16.521900667040608, 17.39849287253803, 16.474702089470806, 15.518101036111293, 14.517634582700822, 13.56372997654824, 12.676730330801378, 11.626484609037538, 10.74135499947933, 9.872277457345522, 9.047940814139647, 8.078227699493555, 8.92951713723171, 8.84762641326612, 9.745876738979764, 10.708975432514482, 11.637013023692507, 12.57874687730957, 13.569532777430481, 14.50581387466112, 15.517852645033019, 16.379129059894705, 15.439179729570625, 14.506057844399521, 13.538490550845228, 12.599843715312497, 11.660445110254765, 10.700610803953213, 9.71293357749409, 8.814127782787873, 7.976575503140614, 7.089812865848565, 7.962078533746628, 7.909546710505894, 8.759114172715364, 9.676000466529187, 10.657125543028382, 11.615014425622258, 12.625894313136483, 13.599038244360589, 14.541173037965006, 15.445329321915178, 14.514674386495695, 13.53746684758689, 12.612293388849848, 11.67333315377098, 10.726724613440448, 9.73973802120752, 8.750815873029682, 7.81143243772777, 6.98228759196555, 6.052916122044375, 6.9813900085636, 6.863324733714988, 7.749914955149642, 8.694034621232568, 9.763400282423799, 10.764068321338673, 11.737696190974797, 12.659091416891332, 13.632407337676195, 14.598286789560145, 13.727821858704978, 12.72635685643502, 11.825227026641356, 10.919899873086587, 9.848216354359188, 8.782504791917383, 7.831696245222278, 6.847382844499757, 5.9515779701819875, 4.986633122328, 5.964685275891241, 5.907266897068382, 6.803493395508332, 7.821386269983275, 8.860006027501473, 9.79199569357904, 10.84147241393793, 11.697253849960823, 12.64269963773273, 13.663742912169726, 12.73862158191772, 11.775007298137492, 10.770257987892071, 9.901884665933355, 8.920051140453316, 7.885107281073543, 6.949938542782784, 5.90858408476136, 4.9817702562480175, 4.051280199219868, 5.037396463339286, 4.913609916500032, 5.833929812585979, 6.8873148070627135, 7.871573899719238, 8.774574065738127, 9.782458494362565, 10.749991883138405, 11.676488904444495, 12.64550562048778, 11.736273694115262, 10.768247055886976, 9.842720725747347, 8.855643394222838, 7.924392807806548, 6.853961794048294, 5.905304074996475, 4.964867904312594, 3.9761675210179153, 3.0649477890981904, 4.034517144345757, 3.9142674533850754, 4.8936622430121295, 5.914244586302304, 6.882364086061156, 7.8217545036477745, 8.836416622219748, 9.785068345819427, 10.722742741917758, 11.77491717114917, 11.021670476303079, 9.994216350136208, 8.955326651910482, 7.919457668267214, 6.904672747560983, 5.918018913154729, 4.897665602788961, 3.913958095850293, 2.925270718765714, 2.0862680126894073, 3.032837453223362, 2.941385502483837, 3.8829108833293975, 4.929372164348667, 5.925566993587596, 6.850928489572628, 7.846974747496395, 8.80989788036043, 9.834392839650631, 10.789682730749243, 9.981542297590808, 9.02289729851965, 7.971290706313983, 6.948563168132946, 5.8806522639618475, 4.953852816309592, 3.9916988902255603, 2.977546179599902, 1.9630054531532457, 1.0190996738641214, 1.9943662896111363, 2.0322926947370368, 3.061261243548125, 4.113737890484974, 5.176747772904763, 6.189830061333831, 7.255735710933825, 8.28356392937371, 9.282981824940903, 10.22376476151541, 9.160184420225042, 8.119608942669029, 7.071208034951718, 6.040387789292522, 5.000559036490352, 4.002413922369565, 3.00984077502816, 2.0302164619909924, 1.0712598297574736, 0.0, 0.9864489981611799, 2.9680021265848513, 3.913822955682297, 4.961449073036301, 6.020277139871707, 6.952139131784733, 7.970939694393264, 8.905476575507135, 9.928387430309277, 10.900831281192996, 10.00778358452989, 8.939655361316918, 7.917522547272064, 6.95699807393013, 5.944577167196722, 4.9450954686134185, 3.982777137476005, 2.986289905972946, 1.9563960302878536, 0.9710804904180931, 1.9463039046749824, 3.794276454589267, 4.84504229003308, 5.872926255565453, 6.819946780190922, 7.863779073711809, 8.859014226806792, 9.803302425137161, 10.825119207913819, 11.79948702558065, 10.86906559335872, 9.822115995913054, 8.859383255544111, 7.800051431415817, 6.8393941968717815, 5.8682698233547175, 4.892634174548619, 3.94147181350817, 2.946909660288894, 1.898325798178959, 2.844279146034592, 4.794312287345645, 5.824024541949398, 6.847412744578536, 7.823967704261043, 8.848996722675555, 9.786146423983858, 10.776869919645847, 11.821183793704055, 12.830449201271229, 11.82288430834356, 10.751288049699617, 9.757891826523473, 8.812881703470891, 7.847489123557555, 6.841659675522734, 5.822243711472815, 4.803016727498786, 3.8621643980553912, 2.9175974817210326, 3.799512069762444, 5.785197490531907, 6.796882476267083, 7.757534440932998, 8.804542412453044, 9.752837594557061, 10.728462325246033, 11.711789739791962, 12.731688875932022, 13.673444281417522, 12.811462647682964, 11.73989549781769, 10.715149545207145, 9.740856522417342, 8.822905777682536, 7.783954869375869, 6.790786068326425, 5.877635723832102, 4.8741512816664505, 3.9840220792383723, 4.726350510484287], [4.931842765274241, 5.890818020547171, 6.854077617709009, 7.84495275918159, 8.809797613484449, 9.764911424531308, 10.792255238149284, 11.769952593596397, 12.709609730795497, 13.734036008541102, 14.78187508297311, 13.791457728621854, 12.726405004171676, 11.718012571235867, 10.747539030612852, 9.861223967730094, 8.908495370723083, 7.8841227734948065, 6.907035443231708, 5.942020397234281, 5.950748542920817, 6.946122366537195, 7.844590496013012, 8.793127717216704, 9.839827042663607, 10.744113342848562, 11.742381941769473, 12.73437775556312, 13.765155537188587, 14.770843605728928, 15.662652475481515, 14.702610401776365, 13.643800462049343, 12.627373289632073, 11.674667026183506, 10.847772358925816, 9.833943048212387, 8.914447609959087, 7.955125439064237, 6.996528887181142, 6.994471195954543, 7.935626335777434, 8.823964957343676, 9.782914795561195, 10.767480309307032, 11.780293953650446, 12.745112041104992, 13.767000550531936, 14.781592728894692, 15.788847449425687, 16.576296431836205, 15.645503443047033, 14.593233213475791, 13.597258379038097, 12.622959605776336, 11.830264888208308, 10.90687731473217, 9.895726559635827, 8.880523590147403, 8.03456139743641, 8.012819240951828, 8.946716274898638, 9.807808878653756, 10.736417898158406, 11.77567740970778, 12.763623100341823, 13.712103877794394, 14.703212412196617, 15.688762762354898, 16.66548815318936, 17.57962172973123, 16.511446399706728, 15.547543118610603, 14.584994678254853, 13.64286556171793, 12.723573633900228, 11.795055007460096, 10.859936931653387, 9.866357778491848, 9.035448954897982, 8.938394892375442, 9.885730196876288, 10.863790518198691, 11.80093633385598, 12.75793933146812, 13.819581793505826, 14.766073948854148, 15.706777348136022, 16.680888872479272, 17.62513334559324, 18.51793542445066, 17.450816100119276, 16.535878914768276, 15.557147878590046, 14.621694807947511, 13.721202966566594, 12.759493544358858, 11.830630194581655, 10.812220560354767, 9.992137711967416, 9.946496985771464, 10.926697311120709, 11.809790619178605, 12.735177536822444, 13.700502168088498, 14.728081955263786, 15.665257409054849, 16.63378717025167, 17.61284223011446, 18.540376041744175, 18.367225822974294, 17.440539720882285, 16.52618244411127, 15.597223495776145, 14.619413125851015, 13.785528492903246, 12.858195492018256, 11.870495426521067, 10.845859883181117, 9.883116603760548, 9.841827929026405, 10.762307209186883, 11.723489685779, 12.730484163686576, 13.548414356526818, 14.599204364200286, 15.528649480816636, 16.516833652812593, 17.478257860419987, 18.383266251350797, 17.34576173700682, 16.41665411393577, 15.563981072530416, 14.647506163185206, 13.666933202421976, 12.762504309804436, 11.895941847383197, 10.894633489121173, 9.88624119556478, 8.953686273997707, 8.830596555741813, 9.780024535266481, 10.759676114597116, 11.70420512965511, 12.523058507647422, 13.57305353726329, 14.552358033925756, 15.535451668879428, 16.515338095534666, 17.44179221474014, 16.485191161380627, 15.484724707970155, 14.530820101817573, 13.64382045607071, 12.59357473430687, 11.708445124748662, 10.839367582614855, 9.971267684012101, 9.001554569366009, 8.016600044123162, 7.861177415104939, 8.759427740818584, 9.722526434353302, 10.650564025531327, 11.59229787914839, 12.583083779269302, 13.51936487649994, 14.531403646871839, 15.495974282891344, 16.40626985483996, 15.473147969668855, 14.505580676114562, 13.56693384058183, 12.627535235524098, 11.667700929222544, 10.680023702763421, 9.781217908057204, 8.899902373013068, 8.013139735721019, 7.049161440638081, 6.923097712344714, 7.772665174554184, 8.689551468368007, 9.670676544867202, 10.628565427461078, 11.639445314975303, 12.61258924619941, 13.554724039803826, 14.540801588676064, 15.471456524095547, 14.504556972856223, 13.579383514119181, 12.640423279040313, 11.693814738709781, 10.706828146476854, 9.717905998299013, 8.778522562997102, 7.905614461838004, 6.97624299191683, 6.068472915455053, 5.876875735553808, 6.763465956988462, 7.707585623071387, 8.77695128426262, 9.777619323177493, 10.751247192813617, 11.672642418730153, 12.645958339515015, 13.611837791398965, 14.608971004177475, 13.7128058545962, 12.811676024802535, 11.88698999835592, 10.815306479628521, 9.749594917186716, 8.79878637049161, 7.8144729697690885, 6.874904840054442, 5.909959992200454, 5.051768182782694, 4.9208178989072024, 5.817044397347153, 6.8349372718220955, 7.873557029340293, 8.80554669541786, 9.855023415776751, 10.710804851799644, 11.65625063957155, 12.684253763638264, 13.60937509389027, 12.761456296298672, 11.756706986053251, 10.888333664094535, 9.901164792816537, 8.866220933436765, 7.917028668052115, 6.875674210030692, 5.948860381517349, 4.974607069092323, 4.121480934989192, 3.9271609183388527, 4.8474808144248, 5.900865808901534, 6.885124901558059, 7.788125067576948, 8.796009496201386, 9.763542884977225, 10.690039906283316, 11.6590566223266, 12.678867269074356, 11.754696054048155, 10.829169723908526, 9.842092392384018, 8.910841805967728, 7.8404107922094735, 6.891753073157655, 5.951316902473773, 4.962616519179095, 3.988274658970645, 3.1186016159956624, 2.9278184552238957, 3.90721324485095, 4.927795588141124, 5.895915087899977, 6.835305505486595, 7.849967624058568, 8.798619347658247, 9.736293743756578, 10.78846817298799, 11.817658906736387, 10.980665348297387, 9.941775650071664, 8.905906666428395, 7.891121745722162, 6.904467911315908, 5.884114600950141, 4.900407094011473, 3.9117197169268936, 3.009594882561862, 2.0630254420279073, 1.9549365043226574, 2.896461885168218, 3.9429231661874873, 4.939117995426416, 5.864479491411449, 6.860525749335215, 7.82344888219925, 8.847943841489451, 9.803233732588064, 10.771911555381488, 10.00934629668083, 8.957739704475163, 7.9350121662941255, 6.867101262123027, 5.9403018144707715, 4.97814788838674, 3.963995177761082, 2.9494544513144256, 2.0055486720253013, 1.0079172914499563, 1.0458436965758569, 2.0748122453869446, 3.1272888923237945, 4.190298774743583, 5.203381063172651, 6.2692867127726455, 7.297114931212531, 8.296532826779725, 9.353929170052993, 10.146633418386221, 9.106057940830208, 8.057657033112898, 7.026836787453702, 5.987008034651532, 4.988862920530745, 3.99628977318934, 3.0166654601521725, 2.0577088279186535, 0.9864489981611799, 0.0, 2.0461783666289497, 2.9919991957263954, 4.0396253130804, 5.0984533799158065, 6.0303153718288325, 7.0491159344373635, 7.983652815551235, 9.006563670353376, 9.979007521237095, 10.979409765857339, 9.926104359478098, 8.903971545433244, 7.94344707209131, 6.931026165357902, 5.931544466774598, 4.969226135637185, 3.9727389041341263, 2.9428450284490335, 1.9575294885792731, 1.048811684728039, 3.0122850148982288, 3.923218530077178, 4.951102495609551, 5.898123020235021, 6.9419553137559085, 7.9371904668508915, 8.88147866518126, 9.903295447957918, 10.90832718795665, 11.83874862017858, 10.808564994074235, 9.845832253705293, 8.786500429576998, 7.825843195032963, 6.854718821515898, 5.8790831727098, 4.927920811669351, 3.933358658450074, 2.884774796340139, 2.087592588606577, 4.02514291950357, 4.902200781993496, 5.925588984622635, 6.902143944305141, 7.927172962719652, 8.864322664027958, 9.855046159689946, 10.899360033748154, 11.950465760407406, 12.809333306504742, 11.737737047860799, 10.744340824684654, 9.799330701632073, 8.833938121718736, 7.828108673683915, 6.808692709633997, 5.789465725659967, 4.848613396216572, 3.9040464798822128, 3.0428255123344288, 5.028510933103892, 5.969499003855598, 6.930150968521514, 7.903114349736155, 8.851409531840172, 9.806638565290132, 10.789965979836062, 11.809865115976121, 12.751620521461621, 13.797026009636829, 12.726344495978871, 11.701598543368327, 10.727305520578524, 9.809354775843717, 8.77040386753705, 7.777235066487607, 6.864084721993283, 5.860600279827631, 4.970471077399552, 3.969663953056272], [4.760354133491618, 5.719329388764549, 6.698666402201761, 7.689541543674342, 8.717776183305391, 9.67288999435225, 10.700233807970228, 11.714709290377806, 12.654366427576907, 13.678792705322511, 12.735696716344162, 11.745279361992905, 10.680226637542727, 9.671834204606919, 8.701360663983902, 7.8150456011011435, 6.862317004094132, 5.837944406865857, 4.860857076602758, 3.9919659994715575, 5.779259911138194, 6.774633734754572, 7.689179280505765, 8.637716501709455, 9.697566895487288, 10.652091912669505, 11.650360511590417, 12.642356325384064, 13.694118951177472, 14.569869797282443, 13.616474108852564, 12.656432035147414, 11.597622095420393, 10.581194923003123, 9.628488659554556, 8.801593992296866, 7.787764681583436, 6.868269243330137, 5.9089470724352875, 5.0507276073588026, 6.82298256417192, 7.764137703994812, 8.668553741836428, 9.627503580053947, 10.625220162130713, 11.638033806474127, 12.653090610925936, 13.67497912035288, 14.69064210913526, 15.550331334959523, 14.530118065207253, 13.599325076418083, 12.54705484684684, 11.551080012409146, 10.576781239147385, 9.784086521579358, 8.86069894810322, 7.8495481930068784, 6.834345223518454, 6.088760117614069, 7.841330609169206, 8.775227643116015, 9.652397663146507, 10.581006682651157, 11.620266194200532, 12.621362953165503, 13.569843730618075, 14.560952265020298, 15.546502615178579, 16.523228006013042, 15.533443363102279, 14.465268033077779, 13.501364751981653, 12.538816311625903, 11.596687195088979, 10.67739526727128, 9.748876640831147, 8.813758565024438, 7.820179411862899, 7.149299725547003, 8.766906260592819, 9.714241565093666, 10.70837930269144, 11.645525118348731, 12.602528115960872, 13.668336285876077, 14.623813801677828, 15.564517200959703, 16.538628725302953, 17.421397027209878, 16.471757057821712, 15.404637733490329, 14.489700548139327, 13.510969511961095, 12.57551644131856, 11.675024599937643, 10.713315177729907, 9.784451827952704, 8.766042193725818, 8.119518541493035, 9.775008353988841, 10.755208679338086, 11.654379403671355, 12.579766321315194, 13.54509095258125, 14.572670739756536, 15.509846193547599, 16.47837595474442, 17.47058208293814, 18.264115650257025, 17.317968758601552, 16.36556735734391, 15.408147374596297, 14.479188426261173, 13.501378056336042, 12.643911068706053, 11.733555550622052, 10.766720791923124, 9.71372422118338, 9.1801900415466, 9.946470727100024, 10.866950007260503, 11.82813248385262, 12.835126961760196, 13.653057154600434, 14.703847162273902, 15.633292278890252, 16.62147645088621, 17.582900658493607, 18.399976852642784, 18.318560587361475, 17.389452964290424, 16.473851145550857, 15.48363193347034, 14.45385797976508, 13.71112487542482, 12.69580919525711, 11.741671940436165, 10.733279646879772, 10.109620371309441, 8.935239353815433, 9.8846673333401, 10.864318912670734, 11.808847927728728, 12.627701305721038, 13.677696335336906, 14.657000831999373, 15.640094466953045, 16.619980893608286, 17.458502816032127, 18.36545339286492, 17.43163696873648, 16.477732362583897, 15.590732716837032, 14.540486995073191, 13.655357385514984, 12.786279843381177, 11.913236307074575, 10.862182091917393, 9.876185184507708, 7.965820213178558, 8.864070538892204, 9.82716923242692, 10.755206823604945, 11.696940677222006, 12.687726577342918, 13.624007674573557, 14.636046444945455, 15.60061708096496, 16.420288315982045, 17.35341020115315, 16.452492936880883, 15.513846101348152, 14.57444749629042, 13.614613189988866, 12.626935963529743, 11.728130168823526, 10.846814633779388, 9.942153682169167, 8.908746581022626, 7.027740510418333, 7.877307972627803, 8.794194266441625, 9.775319342940819, 10.733208225534694, 11.74408811304892, 12.717232044273025, 13.659366837877442, 14.54387290324951, 15.47452783866899, 16.451469233622547, 15.526295774885503, 14.587335539806634, 13.640726999476103, 12.653740407243175, 11.664818259065335, 10.725434823763424, 9.852526722604324, 8.923155252683152, 7.928058055839598, 5.981518533627427, 6.868108755062081, 7.812228421145006, 8.881594082336237, 9.84818767323939, 10.81412840589814, 11.6757137333036, 12.64902965408846, 13.61490910597241, 14.61204231875092, 15.543665344629767, 14.755380138250855, 13.833902259122242, 12.762218740394843, 11.696507177953038, 10.745698631257932, 9.76138523053541, 8.821817100820763, 7.856872252966776, 6.911353323167239, 5.025460696980821, 5.9216871954207715, 6.939580069895714, 7.939585011126113, 8.808618009991305, 9.858094730350196, 10.713876166373089, 11.659321954144994, 12.68732507821171, 13.612446408463716, 14.59231578633224, 13.70041109950157, 12.832037777542855, 11.848077053582859, 10.813133194203086, 9.863940928818437, 8.822586470797013, 7.895772642283671, 6.921519329858644, 5.981066075373737, 4.031803716412472, 4.9521236124984185, 5.9896242733220495, 6.906278117647937, 7.7911963821503925, 8.79908081077483, 9.76661419955067, 10.69311122085676, 11.662127936900045, 12.681938583647801, 13.649965221876087, 12.772873837356846, 11.785796505832337, 10.854545919416047, 9.784114905657793, 8.873306201581325, 7.932870030897445, 6.944169647602767, 5.935186919736966, 5.065513876761983, 3.0324612532975146, 4.011856042924569, 4.948948804231002, 5.917068303989855, 6.83837682006004, 7.853038938632013, 8.801690662231692, 9.739365058330023, 10.791539487561435, 11.820730221309832, 12.704946920642648, 11.885479763519983, 10.849610779876715, 9.834825859170483, 8.848172024764228, 7.865667729373812, 6.881960222435144, 5.893272845350565, 4.956507143328183, 4.009937702794228, 2.0595793023962763, 3.0011046832418367, 3.9459944807609317, 4.942189309999861, 5.8675508059848935, 6.86359706390866, 7.8265201967726945, 8.851015156062896, 9.806305047161509, 10.774982869954933, 11.73362786902609, 10.901443817923482, 9.878716279742445, 8.810805375571347, 7.884005927919091, 6.959701016810411, 5.945548306184753, 4.931007579738097, 3.987101800448973, 3.006598515268977, 1.000334670053093, 1.9909838344592652, 2.951343314328584, 4.014353196748373, 4.987884447135251, 6.053790096735245, 6.94218518510337, 7.923731919701103, 8.927219889518609, 9.932305135191537, 10.954924257728036, 10.001361146561218, 8.970540900902021, 7.930712148099852, 6.9325670339790655, 5.9399938866376605, 4.960369573600493, 4.001412941366975, 2.9680021265848513, 2.0461783666289497, 0.0, 0.9458208290974457, 1.9934469464514497, 3.052275013286857, 3.984137005199883, 5.002937567808413, 5.937474448922284, 6.960385303724425, 7.932829154608144, 8.933231399228386, 10.001359622441358, 8.983989524499993, 8.023465051158059, 7.01104414442465, 6.011010203820443, 5.04869187268303, 4.012131051721611, 2.9822371760365187, 1.996921636166758, 1.0216982219098687, 0.9661066482692793, 1.877040163448228, 2.9049241289806016, 3.8519446536060706, 4.895776947126958, 5.891012100221941, 6.835300298552311, 7.857117081328968, 8.8621488213277, 9.79257025354963, 10.839519850995297, 9.884255719888458, 8.824923895760163, 7.864266661216128, 6.893142287699063, 5.917506638892965, 4.9663442778525155, 3.9106411667895227, 2.8620573046795874, 1.9161039568239542, 1.9789645528746205, 2.8560224153645466, 3.879410617993685, 4.855965577676192, 5.880994596090703, 6.818144297399007, 7.8088677930609975, 8.853181667119204, 9.904287393778455, 10.828520492599706, 11.684875855525517, 10.691479632349372, 9.74646950929679, 8.767226726763207, 7.761397278728386, 6.741981314678467, 5.722754330704438, 4.781902001261043, 3.8373350849266847, 2.871336880551806, 2.9901914507678358, 3.9233206372266487, 4.883972601892564, 5.856935983107205, 6.8052311652112225, 7.760460198661183, 8.743787613207113, 9.763686749347173, 10.705442154832673, 11.75084764300788, 12.67110119276028, 11.646355240149736, 10.672062217359933, 9.742643380888188, 8.70369247258152, 7.710523671532077, 6.7973733270377545, 5.793888884872103, 4.856794832225464, 3.798175321273649], [5.706174962589064, 6.665150217861995, 7.644487231299207, 8.635362372771787, 9.663597012402835, 10.618710823449694, 11.646054637067671, 12.660530119475252, 13.600187256674353, 12.843188563427718, 11.789875887246716, 10.799458532895459, 9.734405808445281, 8.726013375509472, 7.755539834886457, 6.869224772003697, 5.916496174996686, 4.892123577768411, 3.915036247505312, 4.937786828569004, 6.72508074023564, 7.720454563852019, 8.635000109603212, 9.583537330806903, 10.643387724584736, 11.59791274176695, 12.59618134068786, 13.588177154481507, 14.639939780274915, 13.624048968184997, 12.670653279755118, 11.710611206049968, 10.651801266322948, 9.635374093905678, 8.682667830457111, 7.85577316319942, 6.84194385248599, 5.922448414232691, 4.963126243337841, 5.996548436456249, 7.7688033932693665, 8.709958533092259, 9.614374570933876, 10.573324409151395, 11.57104099122816, 12.583854635571576, 13.598911440023379, 14.620799949450323, 15.611765226393073, 14.604510505862079, 13.584297236109808, 12.653504247320638, 11.601234017749396, 10.605259183311702, 9.63096041004994, 8.838265692481912, 7.914878119005774, 6.903727363909432, 5.888524394421008, 6.840353724092842, 8.787151438266651, 9.721048472213461, 10.598218492243955, 11.526827511748605, 12.56608702329798, 13.567183782262953, 14.515664559715525, 15.506773094117747, 16.49232344427603, 15.588073579701742, 14.587622534004835, 13.519447203980334, 12.555543922884208, 11.592995482528458, 10.650866365991535, 9.731574438173833, 8.803055811733701, 7.867937735926992, 6.874358582765453, 7.882941266687533, 9.712727089690265, 10.660062394191112, 11.65420013178889, 12.591345947446179, 13.54834894505832, 14.614157114973523, 15.569634630775278, 16.510338030057152, 17.4198206712264, 16.47557619811243, 15.525936228724266, 14.458816904392885, 13.543879719041882, 12.56514868286365, 11.629695612221116, 10.729203770840197, 9.76749434863246, 8.838630998855258, 7.820221364628372, 8.853160082633565, 10.680989730767179, 10.944066186709131, 11.893304083144157, 12.818691000787997, 13.702109735613982, 14.729689522789268, 15.666864976580332, 16.63539473777715, 17.645374290577273, 17.318294821159583, 16.37214792950411, 15.419746528246467, 14.462326545498852, 13.533367597163728, 12.555557227238598, 11.698090239608607, 10.787734721524606, 9.820899962825678, 8.767903392085934, 9.730646671506502, 10.848931180848274, 9.945230850623158, 10.906413327215276, 11.913407805122851, 12.731337997963092, 13.78212800563656, 14.71157312225291, 15.682556510162337, 16.643980717769733, 17.454156023545337, 17.372739758264032, 16.44363213519298, 15.52803031645341, 14.537811104372896, 13.508037150667636, 12.765304046327374, 11.749988366159664, 10.795851111338719, 9.787458817782326, 10.660077001269343, 9.837699807563682, 8.962948176702756, 9.942599756033392, 10.887128771091385, 11.705982149083695, 12.755977178699563, 13.73528167536203, 14.701174526229172, 15.681060952884412, 16.51268198693468, 17.419632563767475, 17.375561541158596, 16.561191287166253, 15.541496811487391, 14.581395618782743, 13.726438572905018, 12.79685197280438, 11.857896648452357, 10.838020517219812, 10.778645638255957, 8.868280666926807, 7.942351382254859, 8.905450075789577, 9.833487666967603, 10.775221520584664, 11.766007420705575, 12.702288517936214, 13.697126504221583, 14.661697140241088, 15.474467486884599, 16.407589372055703, 17.398313765978326, 16.459666930445596, 15.520268325387864, 14.56043401908631, 13.572756792627187, 12.67395099792097, 11.781808311291343, 10.844614135917416, 9.811207034770876, 7.930200964166582, 6.95558881599046, 7.872475109804282, 8.853600186303476, 9.811489068897352, 10.822368956411577, 11.778312103549153, 12.72044689715357, 13.598052074152063, 14.528707009571544, 15.50591454848035, 16.431088007217394, 15.533156368904079, 14.586547828573547, 13.59956123634062, 12.61063908816278, 11.671255652860868, 10.787520400116279, 9.845286257598284, 8.830518509587847, 6.883978987375676, 5.946389598424737, 6.890509264507663, 7.959874925698894, 8.902366844141945, 9.868307576800692, 10.729892904206153, 11.703208824991014, 12.669088276874964, 13.666221489653473, 14.597844515532321, 15.576670686952289, 14.779723088219688, 13.70803956949229, 12.642328007050482, 11.691519460355376, 10.707206059632854, 9.756810778332717, 8.79186593047873, 7.813813776915488, 5.9279211507290706, 4.999968038783428, 6.017860913258371, 6.9937641820286665, 7.862797180893859, 8.912273901252748, 9.768055337275642, 10.713501125047548, 11.741504249114264, 12.66662557936627, 13.646494957234793, 14.557207985062995, 13.7778586066403, 12.793897882680303, 11.75895402330053, 10.809761757915881, 9.768407299894458, 8.841593471381115, 7.867340158956089, 6.883526529121986, 4.977624545509917, 4.030404455861075, 5.043803444224603, 5.960457288550491, 6.845375553052946, 7.853259981677383, 8.820793370453224, 9.747290391759314, 10.7163071078026, 11.736117754550355, 12.704144392778641, 13.62967072291827, 12.731617334929783, 11.800366748513493, 10.729935734755239, 9.819127030678773, 8.878690859994892, 7.889990476700213, 6.881007748834411, 6.011334705859428, 3.97828208239496, 3.0901368862872256, 4.003127975133556, 4.971247474892409, 5.8925559909625935, 6.907218109534567, 7.855869833134246, 8.793544229232577, 9.845718658463989, 10.874909392212386, 11.759126091545202, 12.802567457135819, 11.79543160897416, 10.780646688267929, 9.793992853861674, 8.81148855847126, 7.8277810515325905, 6.839093674448011, 5.902327972425628, 4.955758531891673, 3.0054001314937215, 2.0793855266044936, 3.0001736516634856, 3.996368480902415, 4.921729976887447, 5.917776234811214, 6.880699367675248, 7.90519432696545, 8.860484218064062, 9.829162040857486, 10.787807039928644, 11.839413632134312, 10.824537108839891, 9.756626204668793, 8.829826757016537, 7.905521845907857, 6.891369135282199, 5.876828408835543, 4.932922629546418, 3.9524193443664224, 1.9461554991505388, 1.0451630053618195, 2.005522485231138, 3.068532367650927, 4.042063618037805, 5.107969267637799, 5.996364356005924, 6.977911090603657, 7.981399060421163, 8.986484306094091, 10.00910342863059, 10.947181975658664, 9.916361729999467, 8.876532977197298, 7.878387863076512, 6.885814715735107, 5.906190402697939, 4.94723377046442, 3.913822955682297, 2.991999195726396, 0.9458208290974457, 0.0, 1.047626117354004, 2.1064541841894107, 3.0383161761024366, 4.057116738710967, 4.991653619824838, 6.014564474626979, 6.987008325510698, 7.98741057013094, 9.055538793343912, 9.92981035359744, 8.969285880255505, 7.956864973522096, 6.956831032917889, 5.994512701780476, 4.957951880819057, 3.9280580051339644, 2.942742465264204, 1.9675190510073144, 1.911927477366725, 0.9312193343507824, 1.9591032998831557, 2.906123824508625, 3.949956118029512, 4.945191271124495, 5.889479469454865, 6.911296252231522, 7.916327992230254, 8.846749424452184, 9.89369902189785, 10.830076548985904, 9.77074472485761, 8.810087490313574, 7.838963116796509, 6.863327467990411, 5.912165106949962, 4.856461995886969, 3.8078781337770335, 2.8619247859214, 2.9247853819720664, 1.910201586267101, 2.9335897888962394, 3.9101447485787455, 4.935173766993257, 5.872323468301561, 6.863046963963551, 7.9073608380217575, 8.958466564681009, 9.88269966350226, 10.908443730631413, 11.637300461446818, 10.692290338394237, 9.713047555860653, 8.707218107825833, 7.687802143775913, 6.668575159801884, 5.7277228303584895, 4.783155914024131, 3.817157709649252, 3.936012279865282, 2.977499808129203, 3.9381517727951185, 4.911115154009759, 5.859410336113776, 6.814639369563737, 7.797966784109667, 8.817865920249726, 9.759621325735226, 10.805026813910434, 11.876593963775708, 12.592176069247182, 11.61788304645738, 10.688464209985634, 9.649513301678967, 8.656344500629524, 7.743194156135201, 6.739709713969549, 5.8026156613229105, 4.743996150371095], [6.753801079943068, 7.712776335215999, 8.69211334865321, 9.68298849012579, 10.711223129756839, 11.666336940803697, 12.693680754421674, 13.708156236829257, 12.886794881117492, 11.8652816879958, 10.811969011814798, 9.82155165746354, 8.756498933013363, 7.7481065000775535, 6.777632959454538, 5.895269042353433, 4.966467605420452, 3.969720830472503, 4.913937429541235, 5.940675025891342, 7.772706857589645, 8.768080681206023, 9.682626226957215, 10.631163448160907, 11.691013841938739, 12.645538859120952, 13.643807458041863, 14.63580327183551, 13.718528397136437, 12.646142092753081, 11.692746404323202, 10.732704330618052, 9.67389439089103, 8.65746721847376, 7.7047609550251925, 6.901149846902069, 5.891915282909756, 5.000045666936783, 5.962027425373765, 6.999436633778587, 8.816429510623372, 9.757584650446264, 10.662000688287879, 11.620950526505398, 12.618667108582164, 13.63148075292558, 14.646537557377382, 15.649521339743535, 14.633858350961155, 13.62660363043016, 12.60639036067789, 11.67559737188872, 10.623327142317478, 9.627352307879784, 8.653053534618023, 7.883642376184561, 6.96484954942954, 6.013447511962052, 6.887425576456931, 7.839254906128765, 9.834777555620658, 10.768674589567466, 11.645844609597958, 12.574453629102608, 13.613713140651983, 14.614809899616956, 15.563290677069528, 16.55439921147175, 15.586892095104286, 14.610166704269822, 13.609715658572917, 12.541540328548416, 11.57763704745229, 10.61508860709654, 9.672959490559617, 8.822402086372332, 7.8938834599322, 7.041155545755279, 7.873259764801376, 8.881842448723456, 10.760353207044272, 11.707688511545115, 12.089468631855148, 13.114294444619343, 13.621666877417361, 14.687475047332565, 15.688535018624938, 16.57469591009462, 16.441913795794484, 15.497669322680517, 14.54802935329235, 13.480910028960967, 12.565972843609964, 11.587241807431733, 10.651788736789198, 9.85468874389375, 8.892979321686013, 8.090807171877602, 8.819122546664296, 9.852061264669487, 11.679890912803103, 11.830013501491633, 11.143468530875234, 12.059247706628273, 12.679104040796984, 13.70668382797227, 14.643859281763334, 15.612389042960155, 16.616859876357392, 16.340387945727667, 15.394241054072193, 14.441839652814549, 13.484419670066934, 12.55546072173181, 11.57765035180668, 10.82357521266216, 9.913219694578158, 9.089232158285215, 9.766804574121858, 10.729547853542426, 11.734878495630776, 10.83117816540566, 10.069648449962632, 11.031830045612779, 11.708332303146094, 12.759122310819562, 13.688567427435911, 14.634930392808334, 15.59635460041573, 16.406529906191334, 16.394832882832112, 15.465725259761063, 14.550123441021492, 13.559904228940978, 12.530130275235718, 11.890789019380927, 10.875473339213217, 10.06509409568511, 10.786359999818249, 11.658978183305267, 10.723647122346184, 9.848895491485258, 9.087337372811195, 10.000753100031297, 10.682976454266697, 11.732971483882565, 12.712275980545032, 13.653548408875169, 14.633434835530409, 15.465055869580677, 16.372006446413472, 16.397654665726677, 15.583284411734335, 14.563589936055473, 13.603488743350825, 12.861634204082197, 11.932047603981559, 11.127139632798748, 11.836921699255734, 11.66459295303846, 9.75422798170931, 8.828298697037361, 8.05018769256738, 8.947111995907514, 9.752215825767665, 10.743001725888577, 11.679282823119216, 12.64950038686758, 13.614071022887085, 14.426841369530596, 15.3599632547017, 16.372971643239023, 16.49807232239986, 15.558673717342126, 14.52936254843515, 13.890055626067438, 12.99019727853921, 12.198504943797781, 11.730561450699918, 10.697154349553378, 8.816148278949084, 7.841536130772962, 7.017212726582087, 7.95151689383449, 8.788483374080354, 9.799363261594578, 10.73068598619515, 11.672820779799567, 12.55042595679806, 13.481080892217541, 14.458288431126347, 15.383461889863389, 16.322422124942257, 15.516098878705447, 14.52911228647252, 13.54019013829468, 12.600806702992768, 11.67346771489878, 10.731233572380786, 9.71646582437035, 7.769926302158178, 6.832336913207239, 6.035246881285468, 6.923772039113216, 7.854740726787942, 8.82068145944669, 9.68226678685215, 10.655582707637011, 11.621462159520961, 12.61859537229947, 13.550218398178318, 14.529044569598286, 15.475260339763837, 14.637590619624188, 13.571879057182382, 12.621070510487277, 11.636757109764755, 10.64275809311522, 9.677813245261232, 8.69976109169799, 6.813868465511573, 5.88591535356593, 5.054903010441201, 5.946138064674663, 6.8151710635398555, 7.864647783898745, 8.72042921992164, 9.665875007693545, 10.693878131760261, 11.618999462012267, 12.59886883988079, 13.509581867708992, 14.580576443566319, 13.723448932812204, 12.688505073432431, 11.739312808047782, 10.697958350026358, 9.771144521513015, 8.796891209087988, 7.769473843904488, 5.912758610190507, 4.916351770643577, 3.9961773268706002, 4.912831171196488, 5.797749435698943, 6.80563386432338, 7.77316725309922, 8.699664274405311, 9.668680990448596, 10.688491637196352, 11.656518275424638, 12.582044605564267, 13.569121937088775, 12.833918830456557, 11.763487816698303, 10.807160594342397, 9.854561319759092, 8.865860936464413, 7.816141813515002, 6.94646877054002, 4.913416147075551, 3.9760842010697273, 2.955501857779553, 3.923621357538406, 4.84492987360859, 5.8595919921805635, 6.808243715780243, 7.745918111878574, 8.798092541109986, 9.827283274858383, 10.711499974191197, 11.754941339781814, 12.790810323425083, 11.828272805621932, 10.827544935804738, 9.803279991745425, 8.819572484806757, 7.830885107722177, 6.837462037106219, 5.8908925965722645, 3.940534196174312, 2.9990088153287515, 1.952547534309482, 2.9487423635484116, 3.874103859533444, 4.87015011745721, 5.8330732503212435, 6.857568209611445, 7.812858100710057, 8.781535923503482, 9.74018092257464, 10.791787514780307, 11.814515052961344, 10.804252322022796, 9.87745287437054, 8.897313279182024, 7.883160568556365, 6.868619842109709, 5.924714062820584, 4.887553409047013, 2.9937816165045428, 2.010373014813984, 0.9578963678771342, 2.020906250296923, 2.9944375006838007, 4.060343150283794, 4.94873823865192, 5.930284973249653, 6.933772943067159, 7.938858188740086, 8.961477311276587, 10.009878218993897, 10.949110900250519, 9.924159094551301, 8.926013980430515, 7.93344083308911, 6.953816520051943, 5.994859887818424, 4.961449073036301, 4.0396253130804, 1.9934469464514497, 1.047626117354004, 0.0, 1.0588280668354069, 1.9906900587484326, 3.009490621356963, 3.944027502470834, 4.966938357272975, 5.939382208156694, 6.939784452776936, 8.007912675989909, 9.030045490034762, 9.990569963376696, 9.0044910908761, 8.004457150271893, 7.042138819134479, 6.005577998173061, 4.975684122487968, 3.9903685826182076, 3.015145168361318, 2.959553594720729, 1.9788454517047864, 0.9851475702328909, 1.9321680948583602, 2.972049242597593, 3.967284395692576, 4.911572594022946, 5.933389376799603, 6.9384211167983345, 7.868842549020266, 8.91579214646593, 9.878524886834873, 10.818370842211612, 9.857713607667577, 8.886589234150513, 7.910953585344415, 6.959791224303966, 5.904088113240973, 4.855504251131038, 3.909550903275404, 3.9724114993260704, 2.957827703621105, 2.0056115609687843, 2.9361890189284807, 3.961218037342992, 4.894416592869642, 5.8851400885316325, 6.9294539625898395, 7.980559689249091, 8.90479278807034, 9.930536855199493, 10.837662545632629, 11.739916455748242, 10.760673673214658, 9.754844225179838, 8.735428261129918, 7.716201277155888, 6.7753489477124935, 5.830782031378135, 4.864783827003256, 4.983638397219286, 3.976400990165126, 3.0157490254992103, 3.9371594243594945, 4.885454606463512, 5.836732494131818, 6.820059908677749, 7.839959044817808, 8.781714450303308, 9.827119938478516, 10.89868708834379, 11.824646400366237, 12.665509163811384, 11.736090327339639, 10.697139419032972, 9.70397061798353, 8.790820273489205, 7.787335831323553, 6.850241778676915, 5.791622267725099], [7.812629146778475, 8.771604402051405, 9.750941415488617, 10.741816556961197, 11.770051196592245, 12.725165007639104, 13.60578729592592, 12.694466493814128, 11.827966814282085, 10.806453621160392, 9.753140944979389, 8.762723590628132, 7.697670866177955, 6.689278433242145, 5.718804892619131, 4.948125518013606, 4.1082419280158655, 5.005536202318854, 5.949752801387587, 6.9764903977376935, 8.831534924425052, 9.82690874804143, 10.741454293792621, 11.689991514996313, 12.749841908774146, 13.704366925956359, 14.555913999546108, 13.711462956094437, 12.659700330301026, 11.58731402591767, 10.633918337487792, 9.673876263782642, 8.615066324055622, 7.598639151638353, 6.645932888189786, 5.954006322562243, 5.033689605505169, 5.9620114501693475, 6.997842797220116, 8.035252005624939, 9.875257577458779, 10.81641271728167, 11.720828755123286, 12.679778593340805, 13.67749517541757, 14.690308819760986, 15.558644098881627, 14.590693272908128, 13.575030284125749, 12.567775563594754, 11.547562293842484, 10.616769305053314, 9.564499075482072, 8.568524241044377, 7.594225467782616, 6.9364988518447355, 6.1066238720249535, 6.975413295194616, 7.923240948303283, 8.875070277975116, 10.893605622456064, 11.827502656402872, 12.704672676433365, 13.15502457112943, 13.558722653749243, 14.58416461267195, 15.532645390124522, 15.51361437842716, 14.52806402826888, 13.551338637434416, 12.55088759173751, 11.48271226171301, 10.518808980616884, 9.556260540261134, 8.61413142372421, 7.9475751204311145, 7.035657782527613, 7.9707758583343225, 8.909075136647727, 9.917657820569808, 11.819181273879678, 12.766516578380521, 12.890642217185817, 12.090506135431855, 12.576460731988902, 13.642268901904107, 14.643328873196479, 15.52948976466616, 15.38308572895908, 14.43884125584511, 13.489201286456943, 12.42208196212556, 11.507144776774558, 10.528413740596326, 9.592960669953792, 8.996463066489163, 8.034753644281427, 8.96361699405863, 9.854937918510647, 10.88787663651584, 12.715706284649453, 12.74246419182185, 11.944642116205904, 11.035459397440786, 11.633897895368525, 12.661477682543811, 13.598653136334875, 14.567182897531696, 15.571653730928928, 15.28155987889226, 14.335412987236786, 13.383011585979142, 12.425591603231528, 11.496632654896404, 10.518822284971273, 9.965349535257573, 9.054994017173572, 9.962041980466243, 10.802619945968209, 11.765363225388777, 12.647329185960992, 11.743628855735878, 10.870822035293301, 10.008041736425291, 10.663126157717635, 11.713916165391103, 12.643361282007453, 13.589724247379872, 14.551148454987267, 15.361323760762875, 15.336004815996706, 14.406897192925657, 13.491295374186086, 12.501076162105571, 11.471302208400312, 11.03256334197634, 10.01724766180863, 10.937903917866137, 11.8221753716646, 12.694793555151618, 11.6360978126764, 10.761346181815476, 9.888510958141865, 8.976964790843809, 9.637770308838238, 10.687765338454106, 11.667069835116573, 12.608342263446707, 13.588228690101946, 14.419849724152218, 15.326800300985013, 15.338826598891272, 14.524456344898928, 13.504761869220067, 12.544660676515418, 12.00340852667761, 11.073821926576972, 11.999949454979777, 12.872737071102085, 12.577043643368677, 10.666678672039525, 9.740749387367577, 8.85136127789805, 7.923323686720026, 8.707009680339207, 9.697795580460118, 10.634076677690757, 11.604294241439117, 12.568864877458623, 13.381635224102137, 14.314757109273241, 15.327765497810562, 15.439244255564452, 14.49984565050672, 13.470534481599744, 13.031829948662851, 12.131971601134623, 13.07131476597881, 12.643012141030136, 11.609605039883595, 9.7285989692793, 8.753986821103178, 7.908853661146194, 6.927728584647, 7.743277228651895, 8.75415711616612, 9.685479840766687, 10.627614634371104, 11.5052198113696, 12.435874746789082, 13.413082285697888, 14.33825574443493, 15.277215979513798, 15.433566147321036, 14.465266385725066, 13.99394765312726, 13.134666946194725, 12.585918405228998, 11.643684262711004, 10.628916514700567, 8.682376992488393, 7.744787603537455, 6.9413133838496375, 5.899983729925727, 6.8095345813594825, 7.7754753140182284, 8.637060641423687, 9.61037656220855, 10.5762560140925, 11.57338922687101, 12.505012252749856, 13.483838424169823, 14.430054194335375, 15.501737713062774, 14.4843297475126, 13.533521200817495, 12.549207800094972, 11.555208783445437, 10.59026393559145, 9.612211782028208, 7.7263191558417885, 6.798366043896146, 5.960969513005371, 4.922349755487174, 5.769964918111396, 6.819441638470284, 7.675223074493179, 8.620668862265084, 9.648671986331799, 10.573793316583805, 11.553662694452328, 12.46437572228053, 13.535370298137856, 14.54098005351112, 13.600955763762649, 12.651763498378, 11.610409040356576, 10.683595211843233, 9.709341899418206, 8.681924534234705, 6.834767017877676, 5.828802460973793, 4.908628017200816, 3.8890428620089983, 4.752543290270483, 5.76042771889492, 6.727961107670759, 7.6544581289768505, 8.623474845020136, 9.643285491767891, 10.611312129996175, 11.536838460135804, 12.523915791660313, 13.56665791492561, 12.7106713297477, 11.754344107391796, 10.801744832808492, 9.813044449513812, 8.7633253265644, 7.877678453379272, 5.86059966012495, 4.888534891399943, 3.867952548109769, 2.8998330483509163, 3.7997237281801306, 4.814385846752103, 5.763037570351782, 6.700711966450113, 7.752886395681524, 8.782077129429922, 9.666293828762738, 10.709735194353355, 11.745604177996624, 12.760389098702856, 11.774728448854136, 10.750463504794823, 9.766755997856155, 8.778068620771576, 7.784645550155618, 6.838076109621664, 4.887717709223711, 3.946192328378151, 2.8997310473588813, 1.903536218119952, 2.8288977141049845, 3.8249439720287506, 4.7878671048927846, 5.812362064182986, 6.767651955281598, 7.736329778075023, 8.69497477714618, 9.746581369351848, 10.769308907532885, 11.831963016555408, 10.905163568903152, 9.844496792231423, 8.830344081605764, 7.815803355159108, 6.871897575869983, 5.834736922096412, 4.052609683339949, 3.069201081649391, 2.016724434712541, 0.9726659029071268, 1.935609433848394, 3.0015150834483877, 3.8899101718165134, 4.871456906414246, 5.874944876231752, 6.88003012190468, 7.90264924444118, 8.95105015215849, 9.890282833415112, 10.888180933981069, 9.984842047265921, 8.992268899924516, 8.01264458688735, 7.053687954653831, 6.020277139871708, 5.0984533799158065, 3.0522750132868564, 2.1064541841894107, 1.0588280668354069, 0.0, 0.9318619919130259, 1.9506625545215566, 2.8851994356354274, 3.908110290437568, 4.880554141321287, 5.88095638594153, 6.949084609154502, 7.971217423199356, 8.93174189654129, 9.944162803274699, 9.0632852171073, 8.100966885969886, 7.064406065008468, 6.034512189323375, 5.049196649453615, 4.073973235196725, 4.018381661556136, 3.037673518540193, 2.0209629420792425, 1.0739424174537733, 1.9132211757621862, 2.908456328857169, 3.852744527187539, 4.8745613099641965, 5.879593049962928, 6.810014482184859, 7.856964079630525, 8.819696819999466, 9.863223659670842, 10.823880894214877, 9.94541730098592, 8.969781652179822, 8.018619291139373, 6.9629161800763795, 5.914332317966444, 4.968378970110811, 5.031239566161477, 4.016655770456511, 3.0414269328151358, 2.077963341523894, 2.976813757803065, 3.8355885260342353, 4.826312021696225, 5.870625895754433, 6.9217316224136844, 7.8459647212349335, 8.871708788364089, 9.778834478797222, 10.723844601849803, 11.703087384383387, 10.813672292015244, 9.794256327965325, 8.775029343991296, 7.8341770145479, 6.8896100982135415, 5.923611893838663, 6.023901347746653, 5.012216362011477, 4.051564397345562, 3.078933746954908, 3.9383110821236857, 4.777904427296411, 5.76123184184234, 6.781130977982399, 7.7228863834679, 8.768291871643108, 9.839859021508381, 10.76581833353083, 11.651819420796254, 12.581238257268, 11.755967485868378, 10.762798684818936, 9.849648340324611, 8.84616389815896, 7.909069845512322, 6.850450334560506], [8.744491138691501, 9.703466393964431, 10.682803407401643, 11.673678548874225, 12.701913188505273, 13.657026999552132, 12.673925304012895, 11.762604501901103, 10.896104822369061, 9.874591629247366, 8.821278953066363, 7.830861598715106, 6.76580887426493, 5.75741644132912, 4.786942900706105, 4.016263526100581, 4.973649005074172, 5.93739819423188, 6.881614793300613, 7.9083523896507195, 9.763396916338078, 10.758770739954455, 11.673316285705646, 12.621853506909337, 13.68170390068717, 14.636228917869387, 13.624052007633084, 12.779600964181412, 11.727838338388002, 10.655452034004647, 9.702056345574768, 8.742014271869618, 7.683204332142597, 6.666777159725327, 5.71407089627676, 5.022144330649217, 5.899096682563476, 6.827418527227654, 7.88266945147417, 8.92779469862742, 10.805346285812746, 11.746501425635637, 12.65269074703631, 13.611640585253829, 13.821338022515809, 14.768271861727008, 14.626782106968603, 13.658831280995104, 12.643168292212724, 11.63591357168173, 10.61570030192946, 9.68490731314029, 8.632637083569048, 7.636662249131352, 6.66236347586959, 6.0046368599317095, 6.954495593136455, 7.840820372252923, 8.808067602557337, 9.75989693222917, 11.823694330810032, 12.75759136475684, 13.636534668346389, 13.7987602676623, 12.759500756112924, 13.784942715035632, 14.733423492488203, 14.581752386514136, 13.596202036355855, 12.619476645521392, 11.619025599824486, 10.550850269799986, 9.58694698870386, 8.62439854834811, 7.682269431811184, 7.0157131285180885, 7.883529503639114, 8.818647579445823, 9.793901790901781, 10.802484474823862, 12.749269982233645, 13.696605286734489, 13.73998651140526, 12.78674128060868, 11.777238834352584, 12.843047004267788, 13.84410697556016, 14.730267867029841, 14.451223737046055, 13.506979263932086, 12.557339294543919, 11.490219970212536, 10.575282784861534, 9.596551748683302, 8.661098678040766, 8.076857990623877, 8.88262536539293, 9.811488715170132, 10.7397645727647, 11.772703290769893, 13.600532938903507, 13.674326183734875, 12.793986410425346, 11.868599492781506, 10.834675997732207, 11.862255784907493, 12.799431238698556, 13.767960999895378, 14.772431833292611, 14.349697886979236, 13.403550995323762, 12.451149594066118, 11.493729611318502, 10.564770662983378, 9.586960293058247, 9.045744459392287, 9.902865738285074, 10.809913701577745, 11.687446600222263, 12.65018987964283, 13.579191177874018, 12.675490847648902, 11.802293466301872, 10.84118183176601, 9.863904260081316, 10.914694267754784, 11.844139384371134, 12.790502349743555, 13.75192655735095, 14.562101863126557, 14.404142824083682, 13.475035201012632, 12.55943338227306, 11.569214170192545, 10.539440216487286, 10.112958266111054, 10.865119382920133, 11.78577563897764, 12.707002025918655, 13.579620209405672, 12.567959804589426, 11.6932081737285, 10.819982389150436, 9.810104886184527, 8.83854841120192, 9.888543440817788, 10.867847937480255, 11.80912036581039, 12.78900679246563, 13.6206278265159, 14.527578403348695, 14.406964606978248, 13.592594352985902, 12.57289987730704, 11.612798684602392, 11.167017451166828, 11.921693647688475, 12.84782117609128, 13.75756372535614, 13.508905635281701, 11.598540663952551, 10.672611379280603, 9.783089691374883, 8.855052100196858, 7.907787782702887, 8.8985736828238, 9.834854780054439, 10.8050723438028, 11.769642979822306, 12.582413326465819, 13.515535211636923, 14.528543600174244, 14.507382263651426, 13.567983658593693, 12.538672489686718, 12.195438873152069, 12.979843322246126, 13.919186487090313, 13.57487413294316, 12.54146703179662, 10.660460961192326, 9.685848813016204, 8.84071565305922, 7.859590576560026, 6.944055331015576, 7.954935218529801, 8.88625794313037, 9.828392736734788, 10.705997913733281, 11.636652849152764, 12.61386038806157, 13.539033846798612, 14.47799408187748, 14.50170415540801, 13.53340439381204, 13.157556577616477, 13.982538667306228, 13.517780397142023, 12.575546254624028, 11.560778506613591, 9.61423898440142, 8.676649595450481, 7.8731753757626635, 6.831845721838753, 6.010312683723164, 6.97625341638191, 7.83783874378737, 8.811154664572232, 9.777034116456182, 10.774167329234691, 11.684458267563825, 12.663284438983792, 13.609500209149344, 14.681183727876743, 14.490637623102177, 14.220266222757644, 13.481069792007997, 12.487070775358461, 11.522125927504474, 10.544073773941232, 8.658181147754814, 7.730228035809172, 6.892831504918397, 5.8542117474002, 4.970743020475077, 6.020219740833966, 6.87600117685686, 7.821446964628766, 8.828118001145768, 9.753239331397774, 10.733108709266297, 11.63805554947998, 12.709050125337306, 13.71465988071057, 14.532817755675673, 13.583625490291023, 12.5422710322696, 11.615457203756257, 10.64120389133123, 9.613786526147729, 7.766629009790702, 6.760664452886819, 5.840490009113842, 4.820904853922023, 3.953321392634165, 4.961205821258601, 5.928739210034441, 6.833904143790818, 7.802920859834103, 8.81696531896734, 9.784991957195626, 10.710518287335255, 11.697595618859763, 12.74033774212506, 13.642533321660727, 12.686206099304822, 11.733606824721518, 10.744906441426838, 9.695187318477426, 8.8095404452923, 6.792461652037976, 5.820396883312969, 4.799814540022795, 3.831695040263942, 3.0005018305438123, 4.0151639491157844, 4.963815672715464, 5.88015798126408, 6.9191762496598725, 7.885840860343293, 8.753689223689388, 9.797130589280005, 10.832999572923274, 11.847784493629506, 12.706590440767162, 11.682325496707849, 10.69861798976918, 9.709930612684602, 8.716507542068644, 7.76993810153469, 5.819579701136737, 4.878054320291177, 3.8315930392719073, 2.8353982100329778, 2.029675816468666, 3.00167946125495, 3.9321120999703956, 4.899757459109638, 5.855047350208249, 6.823725173001674, 7.782370172072832, 8.8339767642785, 9.856704302459537, 10.924615206630635, 11.837025560816178, 10.776358784144449, 9.76220607351879, 8.747665347072134, 7.803759567783009, 6.766598914009438, 4.984471675252975, 4.001063073562416, 2.9485864266255666, 1.9045278948201527, 1.0037474419353682, 2.069653091535362, 2.9580481799034875, 3.93959491450122, 4.943082884318726, 5.948168129991655, 6.9707872525281545, 8.019188160245465, 8.958420841502086, 9.956318942068043, 10.916704039178947, 9.924130891837542, 8.944506578800375, 7.985549946566857, 6.952139131784734, 6.0303153718288325, 3.9841370051998823, 3.0383161761024366, 1.9906900587484326, 0.9318619919130259, 0.0, 1.0188005626085306, 1.9533374437224014, 2.976248298524542, 3.9486921494082616, 4.949094394028505, 6.017222617241476, 7.03935543128633, 7.999879904628264, 9.012300811361673, 9.995147209020326, 9.032828877882912, 7.996268056921494, 6.966374181236401, 5.981058641366641, 5.005835227109751, 4.950243653469162, 3.969535510453219, 2.952824933992268, 2.005804409366799, 0.9813591838491604, 1.9765943369441432, 2.920882535274513, 3.94269931805117, 4.947731058049902, 5.878152490271833, 6.925102087717499, 7.887834828086441, 8.931361667757816, 9.892018902301851, 10.863143275818915, 9.901643644092848, 8.9504812830524, 7.8947781719894055, 6.84619430987947, 5.900240962023837, 5.963101558074503, 4.948517762369537, 3.9732889247281618, 3.00982533343692, 2.0449517658900396, 2.9037265341212093, 3.8944500297831994, 4.938763903841406, 5.989869630500658, 6.9141027293219075, 7.939846796451062, 8.846972486884198, 9.79198260993678, 10.771225392470363, 11.74553428392827, 10.726118319878351, 9.706891335904322, 8.766039006460927, 7.8214720901265675, 6.855473885751689, 6.955763339659679, 5.944078353924503, 4.983426389258588, 3.9547442723146773, 3.00644909021066, 3.846042435383385, 4.829369849929315, 5.849268986069374, 6.791024391554874, 7.8364298797300815, 8.907997029595355, 9.833956341617807, 10.71995742888323, 11.649376265354976, 12.687829477781404, 11.694660676731962, 10.781510332237637, 9.778025890071987, 8.840931837425348, 7.782312326473532], [9.763291701300032, 10.722266956572962, 11.701603970010174, 12.692479111482754, 13.65300293134287, 12.697889120296011, 11.670545306678033, 10.759224504566241, 9.892724825034197, 8.871211631912505, 7.817898955731502, 6.827481601380245, 5.762428876930068, 4.754036443994258, 3.783562903371243, 4.772040523492139, 5.72942600246573, 6.753798599694006, 7.729820146482853, 8.75655774283296, 10.729352040279304, 11.777571302562986, 12.692116848314178, 13.64065406951787, 14.666325665123075, 13.677091038613266, 12.620672010298222, 11.776220966846552, 10.724458341053142, 9.652072036669786, 8.698676348239907, 7.738634274534755, 6.679824334807734, 5.663397162390464, 4.710690898941897, 5.777921328040776, 6.654873679955034, 7.583195524619212, 8.638446448865729, 9.683571696018978, 11.561123283204305, 12.502278423027196, 13.459038014855786, 14.425203735019439, 14.794538471254258, 14.156961283872105, 13.62340210963374, 12.65545128366024, 11.63978829487786, 10.632533574346866, 9.612320304594595, 8.681527315805425, 7.629257086234184, 6.63328225179649, 5.6589834785347275, 6.597616514060851, 7.547475247265597, 8.59659736964448, 9.563844599948895, 10.515673929620728, 12.436418784604738, 13.373832849625035, 14.396690195526816, 14.771960716400748, 13.732701204851374, 13.173632137180729, 14.062173183858318, 13.578372389179275, 12.592822039020994, 11.61609664818653, 10.615645602489623, 9.547470272465123, 8.583566991368997, 7.621018551013246, 6.678889434476321, 7.60869278264723, 8.476509157768255, 9.411627233574965, 10.405206386736504, 11.413789070658584, 13.361994436028352, 14.310956055891877, 14.713186960143709, 13.75994172934713, 12.750439283091033, 12.117673444016726, 13.008203112798565, 13.780481233228477, 13.44784373971119, 12.503599266597222, 11.553959297209055, 10.486839972877673, 9.571902787526671, 8.593171751348438, 7.657718680705904, 8.669837644753018, 9.475605019522071, 10.404468369299273, 11.351069168599423, 12.384007886604616, 14.21183753473823, 14.693126746343404, 13.767186859163795, 12.841799941519955, 11.807876446470656, 11.066868917672366, 11.96352737593696, 12.818174366094013, 13.760639894389755, 13.346317889644373, 12.4001709979889, 11.447769596731256, 10.490349613983641, 9.561390665648517, 8.583580295723387, 9.562817818421191, 10.490150819306182, 11.402893355706887, 12.298751196056985, 13.261494475477553, 14.597991740482549, 13.694291410257431, 12.775493915040322, 11.814382280504459, 10.837104708819766, 10.096555475593247, 10.90131669972202, 11.77953360329323, 12.740134618448094, 13.545149190837613, 13.400762826748819, 12.47165520367777, 11.556053384938199, 10.565834172857684, 9.536060219152425, 10.490239366409142, 11.45240446394124, 12.378755293106781, 13.318306621753376, 14.190924805240394, 13.586760367197957, 12.71200873633703, 11.793182837888885, 10.783305334922977, 9.81174885994037, 9.07040464865625, 9.92502525283114, 10.798151619360064, 11.777214853562773, 12.603675154226956, 13.51062573105975, 13.403584609643385, 12.589214355651041, 11.56951987997218, 10.609418687267532, 11.544298551464916, 12.473885151565554, 13.412840475917577, 14.368868321190861, 14.52770619789023, 12.617341226561082, 11.691411941889132, 10.756290140113332, 9.828252548935307, 8.880988231441338, 8.028073539181165, 8.858496360821155, 9.794103597352475, 10.75785104091945, 11.565460654176874, 12.498582539347979, 13.5115909278853, 13.504002266316565, 12.564603661258833, 11.535292492351857, 12.52296971881098, 13.450687301506544, 14.48420578691661, 14.59367469555169, 13.560267594405149, 11.679261523800857, 10.704649375624733, 9.856269738847097, 8.875144662347902, 7.917255779754026, 7.084435074887166, 7.875289196680045, 8.817423990284462, 9.689045241444338, 10.61970017686382, 11.596907715772625, 12.522081174509667, 13.461041409588535, 13.49832415807315, 12.53002439647718, 13.485087423275388, 14.4244708585773, 14.536580959750552, 13.594346817232557, 12.57957906922212, 10.63303954700995, 9.69545015805901, 8.891975938371194, 7.850646284447284, 6.9835131324616135, 6.020671093978298, 6.826869997337045, 7.800185918121907, 8.76008144416724, 9.756434449257197, 10.665657704955294, 11.644483876375261, 12.590699646540813, 13.662383165268212, 13.487257625767317, 14.438066172462422, 14.499870354616528, 13.50587133796699, 12.540926490113003, 11.562874336549761, 9.676981710363345, 8.749028598417702, 7.911632067526928, 6.873012310008731, 5.943943469213527, 5.064637418430354, 5.8650324304065355, 6.8104782181784405, 7.809317438537236, 8.734438768789243, 9.714308146657766, 10.619254986871448, 11.690249562728775, 12.695859318102041, 13.730803177481814, 14.602426052899554, 13.56107159487813, 12.634257766364788, 11.660004453939761, 10.63258708875626, 8.785429572399233, 7.77946501549535, 6.859290571722373, 5.839705416530555, 4.926521841372614, 4.005623498854989, 4.917770463584116, 5.815103581182287, 6.784120297225572, 7.798164756358809, 8.766191394587095, 9.691717724726724, 10.678795056251232, 11.72153717951653, 12.732723069413062, 13.705006661913353, 12.752407387330049, 11.76370700403537, 10.713987881085957, 9.82834100790083, 7.811262214646507, 6.8391974459215, 5.818615102631326, 4.850495602872473, 3.973702279282261, 3.0595816267121725, 3.9528469262651393, 4.861357418655549, 5.900375687051342, 6.867040297734762, 7.734888661080859, 8.778330026671476, 9.814199010314745, 10.828983931020977, 11.796780188519497, 12.70112605931638, 11.717418552377712, 10.728731175293133, 9.735308104677175, 8.78873866414322, 6.838380263745268, 5.896854882899708, 4.850393601880438, 3.854198772641509, 3.002876265207115, 2.006830007283349, 2.913311537361865, 3.880956896501107, 4.836246787599719, 5.804924610393144, 6.763569609464302, 7.815176201669969, 8.837903739851006, 9.905814644022104, 10.83261409167436, 11.79515934675298, 10.781006636127321, 9.766465909680665, 8.82256013039154, 7.785399476617969, 6.0032722378615055, 5.019863636170947, 3.9673869892340976, 2.9233284574286835, 2.022548004543899, 1.074803637563761, 1.9392476172949569, 2.9207943518926895, 3.924282321710196, 4.929367567383124, 5.951986689919623, 7.000387597636934, 7.939620278893556, 8.937518379459512, 9.935663493580298, 10.928236640921703, 9.963307141408908, 9.004350509175389, 7.970939694393265, 7.049115934437363, 5.002937567808413, 4.057116738710968, 3.0094906213569637, 1.9506625545215566, 1.0188005626085306, 0.0, 0.9345368811138708, 1.9574477359160116, 2.929891586799731, 3.9302938314199736, 4.998422054632945, 6.020554868677799, 6.981079342019733, 7.993500248753142, 8.993534189357348, 9.955852520494762, 9.015068619530025, 7.985174743844932, 6.999859203975172, 6.024635789718282, 5.969044216077692, 4.987186276382994, 3.9593023108506205, 3.0122817862251514, 1.9684494927042642, 0.9732143396092813, 1.917502537939651, 2.939319320716308, 3.94435106071504, 4.8747724929369705, 5.921722090382636, 6.8844548307515785, 7.912561105149286, 8.87321833969332, 9.844342713210384, 10.819978362016482, 9.969281845660928, 8.913578734597936, 7.864994872488, 6.919041524632367, 6.963980443803768, 5.905866973027205, 4.882478770398067, 3.8998602829106557, 2.8748312644961445, 1.9003465367863472, 2.8910700324483374, 3.935383906506544, 4.986489633165796, 5.910722731987045, 6.936466799116199, 7.843592489549335, 8.788602612601917, 9.7678453951355, 10.77367484317032, 11.744918882486882, 10.725691898512853, 9.784839569069458, 8.840272652735099, 7.874274448360219, 7.80396869284192, 6.792283707106743, 5.831631742440828, 4.784623770920782, 3.836328588816765, 2.842662438048523, 3.825989852594453, 4.8458889887345125, 5.787644394220013, 6.833049882395221, 7.904617032260495, 8.830576344282942, 9.716577431548368, 10.645996268020113, 11.714034350241095, 12.713461239340493, 11.800310894846168, 10.796826452680518, 9.859732400033879, 8.801112889082063], [10.697828582413901, 11.656803837686832, 12.636140851124043, 13.627015992596625, 12.766052775431026, 11.810938964384167, 10.783595150766189, 9.872274348654397, 9.005774669122353, 8.027565645508634, 6.974252969327631, 5.983835614976374, 4.918782890526197, 3.9103904575903874, 4.718099784485114, 5.70657740460601, 6.663962883579601, 7.688335480807877, 8.664357027596722, 9.691094623946828, 11.663888921393175, 12.712108183676856, 13.626653729428046, 14.575190950631738, 13.779375509211231, 12.790140882701422, 11.733721854386378, 10.921922304516388, 9.933915226580437, 8.861528922197081, 7.9081332337672015, 6.9480911600620505, 5.88928122033503, 4.87285404791776, 5.645227780055769, 6.712458209154647, 7.589410561068905, 8.517732405733083, 9.5729833299796, 10.61810857713285, 12.495660164318176, 13.436815304141067, 14.393574895969657, 15.35974061613331, 14.707028775854656, 13.767654556219618, 12.736451953721897, 11.907043809686042, 10.891380820903663, 9.884126100372669, 8.87866945879108, 7.947876470001909, 6.904496846010563, 5.928729969565645, 6.593520359648599, 7.532153395174722, 8.482012128379468, 9.53113425075835, 10.498381481062767, 11.4502108107346, 13.37095566571861, 14.308369730738907, 15.331227076640687, 15.58126781294694, 14.542008301397566, 13.972153402574111, 13.127636302744447, 12.858825133748848, 11.873274783590567, 10.896549392756103, 9.896098347059198, 8.827923017034697, 7.864019735938571, 6.9164662687824014, 7.613426315590193, 8.543229663761101, 9.411046038882127, 10.346164114688836, 11.339743267850375, 12.348325951772456, 14.296531317142223, 15.245492937005748, 15.5224940566899, 14.569248825893322, 13.559746379637225, 12.916194709410108, 12.073666231684694, 12.845944352114605, 12.728296484280767, 11.784052011166798, 10.83441204177863, 9.767292717447248, 8.852355532096245, 7.888619469117593, 8.592255561819774, 9.60437452586689, 10.410141900635942, 11.339005250413145, 12.285606049713294, 13.318544767718487, 15.146374415852101, 15.525731852145013, 14.576493955709987, 13.651107038066147, 12.617183543016848, 11.865390183065749, 11.02899049482309, 11.883637484980142, 12.826103013275882, 12.626770634213948, 11.680623742558474, 10.72822234130083, 9.835717932700895, 8.906758984365771, 9.518117176837256, 10.49735469953506, 11.424687700420051, 12.337430236820758, 13.233288077170856, 14.196031356591424, 15.53252862159642, 14.545983488178631, 13.584801011586514, 12.62368937705065, 11.646411805365958, 10.89507674098663, 9.966779818608149, 10.844996722179358, 11.805597737334221, 12.610612309723741, 12.681215571318393, 11.752107948247344, 10.901421703655453, 9.920428152840556, 10.470597100266295, 11.42477624752301, 12.38694134505511, 13.313292174220653, 14.252843502867247, 15.125461686354265, 14.521297248311829, 13.57989471426686, 12.602489934435077, 11.592612431469169, 10.621055956486561, 9.868925914049633, 8.99048837171727, 9.863614738246193, 10.8426779724489, 11.669138273113084, 12.57608884994588, 12.68403735421296, 11.934582674368295, 10.924113859955051, 11.543955568381401, 12.478835432578784, 13.408422032679422, 14.347377357031444, 15.303405202304733, 15.462243079004102, 13.551878107674954, 12.559297919818961, 11.565597236659524, 10.637559645481499, 9.69029532798753, 8.826594804574547, 7.923959479707284, 8.859566716238604, 9.823314159805577, 10.630923773063003, 11.564045658234107, 12.577054046771428, 12.891580617678342, 11.952182012620609, 12.469829373465727, 13.45750659992485, 14.385224182620414, 15.418742668030477, 15.52821157666556, 14.49480447551902, 12.613798404914728, 11.636280468753714, 10.665576835393288, 9.684451758894093, 8.726562876300218, 7.882956340280549, 6.940752315566174, 7.882887109170591, 8.754508360330465, 9.685163295749948, 10.662370834658754, 11.587544293395796, 12.526504528474664, 12.885902509434926, 13.464561277591049, 14.419624304389258, 15.359007739691169, 15.471117840864423, 14.528883698346428, 13.514115950335992, 11.567576428123822, 10.629987039172882, 9.826512819485066, 8.785183165561154, 7.7928202290078055, 6.819192359371682, 5.892333116223174, 6.865649037008036, 7.825544563053367, 8.821897568143324, 9.73112082384142, 10.709946995261388, 11.65616276542694, 12.727846284154339, 13.75692772817468, 14.707736274869786, 15.434407235730399, 14.440408219080862, 13.475463371226875, 12.497411217663632, 10.611518591477216, 9.683565479531573, 8.846168948640798, 7.807549191122602, 6.878480350327397, 5.8631586838237375, 4.930495549292664, 5.875941337064569, 6.874780557423365, 7.799901887675371, 8.779771265543893, 9.684718105757577, 10.755712681614904, 11.76132243698817, 12.796266296367943, 13.745458561752592, 14.495608475992002, 13.56879464747866, 12.594541335053632, 11.567123969870131, 9.719966453513104, 8.71400189660922, 7.7938274528362435, 6.774242297644426, 5.861058722486485, 4.9130036408937645, 3.9832335824702447, 4.880566700068416, 5.849583416111701, 6.863627875244938, 7.831654513473223, 8.757180843612852, 9.744258175137361, 10.787000298402658, 11.79818618829919, 12.841589134611919, 13.686944268443916, 12.698243885149237, 11.648524762199825, 10.762877889014701, 8.745799095760376, 7.7737343270353705, 6.753151983745196, 5.785032483986344, 4.908239160396132, 3.9669617687509473, 3.018310045151268, 3.9268205375416785, 4.965838805937471, 5.932503416620891, 6.800351779966988, 7.843793145557605, 8.879662129200874, 9.894447049907106, 10.862243307405626, 11.884651940344607, 12.651955433491581, 11.663268056407002, 10.669844985791043, 9.723275545257088, 7.772917144859138, 6.831391764013578, 5.784930482994309, 4.78873565375538, 3.9374131463209854, 2.9413668883972193, 1.9787746562479942, 2.946420015387236, 3.9017099064858476, 4.8703877292792725, 5.82903272835043, 6.880639320556098, 7.903366858737135, 8.971277762908233, 9.898077210560489, 10.958743987232218, 11.71554351724119, 10.701002790794535, 9.75709701150541, 8.71993635773184, 6.937809118975377, 5.954400517284817, 4.901923870347968, 3.8578653385425543, 2.9570848856577694, 2.009340518677632, 1.004710736181086, 1.9862574707788188, 2.9897454405963253, 3.9948306862692533, 5.017449808805754, 6.065850716523064, 7.0050833977796865, 8.002981498345642, 9.001126612466429, 9.993699759807834, 10.89784402252278, 9.93888739028926, 8.905476575507135, 7.983652815551234, 5.937474448922284, 4.991653619824838, 3.944027502470834, 2.8851994356354274, 1.9533374437224014, 0.9345368811138708, 0.0, 1.0229108548021408, 1.9953547056858603, 2.9957569503061032, 4.0638851735190755, 5.086017987563929, 6.046542460905863, 7.058963367639272, 8.058997308243478, 9.021315639380893, 9.949605500643896, 8.919711624958804, 7.934396085089043, 6.959172670832153, 6.903581097191563, 5.9217231574968645, 4.893839191964491, 3.946818667339022, 2.902986373818135, 1.907751220723152, 1.0738565515357799, 2.085343835432917, 3.057400904803194, 3.9878223370251247, 5.034771934470791, 5.997504674839733, 6.9780242240354164, 7.938681458579452, 8.909805832096517, 9.885441480902614, 10.836603841943063, 9.848115615711805, 8.79953175360187, 7.853578405746238, 7.8985173249176395, 6.840403854141076, 5.817015651511938, 4.8343971640245265, 3.809368145610015, 2.834883417900218, 2.0474240460444664, 3.081408421223153, 4.1103363297838165, 5.023772576075199, 6.0495166432043534, 6.95664233363749, 7.901652456690072, 8.880895239223657, 9.886724687258477, 10.84091159740855, 11.660228779626722, 10.719376450183328, 9.774809533848968, 8.80881132947409, 8.73850557395579, 7.726820588220614, 6.766168623554698, 5.7191606520346525, 4.770865469930635, 3.777199319162394, 2.982343866190582, 4.0022430023306415, 4.943998407816142, 5.98940389599135, 7.060971045856624, 7.9436261883710975, 8.829627275636524, 9.759046112108269, 10.82708419432925, 11.80945395426216, 12.734847775960038, 11.731363333794388, 10.794269281147749, 9.735649770195932], [11.720739437216043, 12.679714692488973, 13.659051705926185, 12.771376560259933, 11.743141920628885, 10.788028109582026, 9.760684295964047, 8.849363493852255, 7.982863814320211, 7.05441984237794, 6.001107166196936, 5.010689811845679, 3.9812812569357474, 4.920783669462041, 5.741010639287254, 6.72948825940815, 7.686873738381741, 8.711246335610017, 9.687267882398864, 10.71400547874897, 12.686799776195313, 13.735019038478997, 14.649564584230188, 13.813177961239479, 12.75646465440909, 11.76723002789928, 10.710810999584236, 9.899011449714246, 8.96995701177281, 7.897570707389454, 6.944175018959575, 6.072969600658741, 5.01835538104615, 5.883247259789413, 6.668138634857909, 7.735369063956787, 8.612321415871044, 9.540643260535221, 10.595894184781738, 11.641019431934987, 13.518571019120314, 14.459726158943205, 15.416485750771795, 14.682958353859846, 13.684117921052515, 12.744743701417477, 11.713541098919755, 10.943085594878417, 9.927422606096037, 8.920167885565043, 7.965020712424019, 7.0727549105986, 6.033571006721683, 6.9391231814372984, 7.616431214450739, 8.555064249976862, 9.504922983181608, 10.554045105560489, 11.521292335864905, 12.473121665536738, 14.39386652052075, 15.331280585541046, 16.354137931442825, 15.733312628354822, 14.694053116805447, 13.66861115788274, 12.720130380430168, 11.928891410045612, 10.94334105988733, 9.978843605209859, 9.024079525177394, 7.9569971777458175, 6.993093896649691, 7.926859480654055, 8.636337170392332, 9.566140518563241, 10.433956893684266, 11.369074969490976, 12.362654122652515, 13.371236806574595, 15.319442171944363, 16.268403791807888, 16.3457680903765, 15.392522859579922, 14.383020413323825, 13.739468743096708, 12.845349113559081, 11.904645714277207, 11.857370644991887, 10.913126171877918, 9.96348620248975, 8.896366878158368, 7.981429692807365, 8.899012680989246, 9.615166416621914, 10.62728538066903, 11.43305275543808, 12.361916105215283, 13.308516904515434, 14.341455622520627, 16.16928527065424, 16.34900588583161, 15.399767989396585, 14.474381071752745, 13.440457576703448, 12.688664216752349, 11.85226452850969, 10.942338847142743, 11.803192158473742, 11.755844794925068, 10.809697903269594, 9.85729650201195, 9.008202661530525, 9.917152196237424, 10.541028031639396, 11.5202655543372, 12.447598555222191, 13.360341091622896, 14.256198931972996, 15.218942211393564, 16.383423794384196, 15.369257521865231, 14.408075045273113, 13.44696341073725, 12.469685839052557, 11.71835077467323, 10.790053852294749, 9.90369808434196, 10.782686882532081, 11.5877014549216, 11.810289732029513, 10.881182108958464, 10.073906432485083, 10.930821364712209, 11.493507955068434, 12.447687102325151, 13.40985219985725, 14.33620302902279, 15.275754357669388, 16.148372541156405, 15.372192421099603, 14.403168747953458, 13.425763968121677, 12.415886465155769, 11.444329990173161, 10.692199947736233, 9.81376240540387, 8.922316100408795, 9.81976711764676, 10.646227418310943, 11.553177995143738, 11.81311151492408, 11.107067403197926, 11.934507071826705, 12.56686642318354, 13.501746287380925, 14.431332887481563, 15.370288211833586, 16.326316057106872, 16.400155981406837, 14.402773280462728, 13.382571953505561, 12.388871270346124, 11.460833679168099, 10.51356936167413, 9.649868838261147, 8.747233513393883, 7.918268078401206, 8.800403305003437, 9.608012918260862, 10.541134803431966, 11.554143191969287, 12.070953664433668, 12.962575224492262, 13.492740228267866, 14.48041745472699, 15.408135037422554, 16.441653522832617, 16.48554391857078, 15.452136817424238, 13.464693577702503, 12.459554502440312, 11.488850869079887, 10.507725792580693, 9.549836909986817, 8.706230373967148, 7.764026349252774, 6.941588471333192, 7.731597505528326, 8.662252440947807, 9.639459979856612, 10.564633438593654, 11.503593673672523, 12.450202214003054, 13.437188806235982, 14.433015243939845, 15.372398679241757, 16.446657307591277, 15.54015303034514, 14.525385282334703, 12.590487282925963, 11.630247628883435, 10.686127962800509, 9.616762301609278, 8.616094262694405, 7.642466393058282, 6.715607149909774, 5.889779418891343, 6.802633708251227, 7.7989867133411845, 8.70820996903928, 9.687036140459247, 10.633251910624798, 11.704935429352197, 12.73401687337254, 13.684825420067645, 14.669138820790167, 15.463319073883003, 14.498374226029016, 13.520322072465774, 11.634429446279357, 10.706476334333715, 9.842187968583495, 8.803568211065297, 7.756180485191563, 6.686432717510337, 5.753769582979264, 4.900071718947876, 5.851869702621224, 6.77699103287323, 7.756860410741752, 8.661807250955436, 9.732801826812763, 10.738411582186028, 11.773355441565801, 12.72254770695045, 13.763902164971874, 14.591705502280801, 13.617452189855774, 12.590034824672273, 10.742877308315245, 9.736912751411362, 8.816738307638383, 7.797153152446566, 6.746029229957067, 5.736277674580363, 4.8065076161568445, 3.857655845266275, 4.82667256130956, 5.8407170204427965, 6.808743658671082, 7.734269988810711, 8.72134732033522, 9.764089443600517, 10.77527533349705, 11.818678279809777, 12.771277554393082, 13.721154739951379, 12.671435617001967, 11.785788743816843, 9.768709950562517, 8.796645181837512, 7.776062838547337, 6.807943338788484, 5.80489792100952, 4.790235802437547, 3.841584078837868, 2.903909682739538, 3.9429279511353306, 4.90959256181875, 5.777440925164846, 6.820882290755463, 7.856751274398731, 8.871536195104964, 9.839332452603484, 10.861741085542466, 11.845448592481134, 12.686178911209144, 11.692755840593184, 10.74618640005923, 8.79582799966128, 7.854302618815719, 6.80784133779645, 5.81164650855752, 4.89579782239858, 3.8997515644748137, 2.9368284316107798, 1.9235091605850956, 2.878799051683707, 3.8474768744771315, 4.806121873548289, 5.857728465753956, 6.880456003934993, 7.948366908106092, 8.875166355758347, 9.935833132430076, 10.949985843055735, 11.723913645596676, 10.780007866307551, 9.742847212533981, 7.9607199737775165, 6.977311372086958, 5.924834725150109, 4.880776193344695, 3.97999574045991, 2.990592729983757, 1.9627645115438717, 0.9633466159766779, 1.9668345857941845, 2.9719198314671122, 3.994538954003612, 5.042939861720923, 5.982172542977545, 6.980070643543501, 7.978215757664287, 8.970788905005692, 9.95041321804286, 10.909369850276379, 9.928387430309275, 9.006563670353373, 6.960385303724424, 6.014564474626979, 4.966938357272975, 3.908110290437568, 2.976248298524542, 1.9574477359160116, 1.0229108548021408, 0.0, 0.9724438508837195, 1.9728460955039622, 3.040974318716934, 4.063107132761788, 5.023631606103722, 6.036052512837131, 7.036086453441338, 7.998404784578751, 9.034965605540169, 9.942622479760944, 8.957306939891183, 7.982083525634293, 7.926491951993703, 6.944634012299006, 5.916750046766633, 4.969729522141163, 3.925897228620276, 2.930662075525293, 2.084249763407433, 1.0624329806307762, 2.0344900500010534, 2.964911482222984, 4.01186107966865, 4.974593820037592, 5.955113369233275, 6.91577060377731, 7.886894977294375, 8.862530626100472, 9.813692987140922, 10.869396098203914, 9.822442608404012, 8.876489260548379, 8.921428179719781, 7.863314708943218, 6.83992650631408, 5.857308018826668, 4.832279000412156, 3.857794272702359, 3.0578172579161196, 2.0584975664210123, 3.0874254749816754, 4.0008617212730595, 5.026605788402213, 5.933731478835349, 6.878741601887931, 7.857984384421515, 8.863813832456335, 9.818000742606408, 10.835714852577107, 11.742287304985469, 10.79772038865111, 9.83172218427623, 9.761416428757931, 8.749731443022755, 7.78907947835684, 6.742071506836794, 5.793776324732777, 4.800110173964534, 3.9927370780622353, 3.029097199199947, 3.9708526046854473, 5.016258092860655, 6.046089161649751, 6.920715333568957, 7.806716420834382, 8.736135257306127, 9.80417333952711, 10.786543099460019, 11.775808438546258, 12.75427418859653, 11.81718013594989, 10.758560624998074], [12.693183288099762, 13.652158543372693, 12.789807850848792, 11.798932709376212, 10.770698069745164, 9.815584258698305, 8.788240445080326, 7.876919642968535, 7.010419963436491, 6.143809456133335, 5.110523878049558, 4.185112261225221, 4.953725107819467, 5.89322752034576, 6.713454490170974, 7.701932110291869, 8.659317589265461, 9.683690186493736, 10.659711733282583, 11.68644932963269, 13.659243627079034, 14.707462889362716, 13.780320729152795, 12.840734110355758, 11.784020803525369, 10.79478617701556, 9.738367148700515, 8.926567598830527, 8.06596576982958, 7.006987419242076, 6.0535917308121965, 5.247392050038283, 5.990799231929869, 6.855691110673132, 7.6405824857416285, 8.707812914840506, 9.584765266754765, 10.513087111418942, 11.568338035665459, 12.613463282818708, 14.491014870004035, 15.432170009826926, 14.676680223139778, 13.710514502976125, 12.711674070168794, 11.772299850533756, 10.741097248036034, 9.985860482305268, 9.036839317948658, 8.029584597417664, 7.074437424276641, 6.247177359978142, 7.006014857605402, 7.911567032321018, 8.588875065334458, 9.527508100860581, 10.477366834065327, 11.52648895644421, 12.493736186748626, 13.445565516420459, 15.366310371404468, 16.303724436424766, 15.660524144449857, 14.760868777471101, 13.721609265921726, 12.696167306999019, 11.747686529546447, 11.038308121898233, 10.052757771739952, 9.08826031706248, 8.133496237030016, 7.23554222579879, 7.965537747533411, 8.899303331537775, 9.608781021276052, 10.53858436944696, 11.406400744567986, 12.341518820374695, 13.335097973536234, 14.343680657458314, 16.29188602282808, 17.240847642691605, 16.71650578399479, 15.713373633938163, 14.703871187682067, 13.752126000163022, 12.8016566006062, 12.102175694600891, 11.044883881864324, 10.138351933750236, 9.188711964362069, 8.17491192621134, 8.953873543691085, 9.871456531872967, 10.587610267505633, 11.599729231552748, 12.405496606321801, 13.334359956099004, 14.280960755399153, 15.313899473404346, 17.141729121537956, 17.321449736715334, 16.372211840280308, 15.446824922636466, 14.412901427587167, 13.661108067636068, 12.824708379393408, 11.914782698026462, 11.082055756901408, 11.03438984297804, 10.088242951322567, 9.135841550064923, 9.980646512414246, 10.889596047121145, 11.513471882523115, 12.49270940522092, 13.42004240610591, 14.332784942506617, 15.228642782856715, 16.19138606227728, 17.355867645267914, 16.34170137274895, 15.380518896156833, 14.41940726162097, 13.442129689936277, 12.690794625556949, 11.762497703178468, 10.876141935225679, 10.061550480959747, 10.866565053349266, 11.088834780082486, 10.159727157011437, 11.046350283368804, 11.90326521559593, 12.465951805952153, 13.420130953208869, 14.382296050740969, 15.308646879906512, 16.248198208553106, 17.120816392040123, 16.344636271983322, 15.37561259883718, 14.398207819005396, 13.388330316039488, 12.41677384105688, 11.664643798619952, 10.786206256287588, 9.894759951292514, 9.098630716074426, 9.925091016738609, 10.832041593571404, 11.091656562977052, 12.045561169129634, 12.906950922710426, 13.53931027406726, 14.474190138264643, 15.40377673836528, 16.342732062717303, 17.298759907990593, 17.372599832290557, 15.37521713134645, 14.35501580438928, 13.361315121229843, 12.433277530051818, 11.486013212557848, 10.622312689144866, 9.719677364277603, 8.890711929284924, 8.079266903431103, 8.886876516688528, 9.819998401859632, 10.821511768437603, 11.756669493496805, 12.651291287285687, 13.680602456192663, 14.66250152487257, 15.590219107568133, 16.663794145902106, 17.457987769454498, 16.424580668307957, 14.437137428586224, 13.431998353324033, 12.461294719963607, 11.480169643464412, 10.522280760870537, 9.678674224850868, 8.736470200136493, 7.9140323222169116, 7.010461103955991, 7.941116039375473, 8.906828556324928, 9.83200201506197, 10.770962250140839, 11.71757079047137, 12.704557382704298, 13.700383820408161, 14.639767255710073, 15.714025884059591, 16.512596881228863, 15.497829133218424, 13.562931133809682, 12.602691479767156, 11.65857181368423, 10.589206152492999, 9.588538113578124, 8.614910243942001, 7.688051000793493, 6.862223269775062, 6.081497306678892, 7.022215499567548, 7.931438755265644, 8.873931200559058, 9.82014697072461, 10.891830489452008, 11.833652793018397, 12.784461339713502, 13.768774740436024, 14.780396816563076, 15.470818076912737, 14.492765923349495, 12.606873297163077, 11.678920185217434, 10.814631819467213, 9.776012061949016, 8.728624336075281, 7.6588765683940565, 6.726213433862983, 5.872515569831595, 5.130733301048889, 6.000219819099594, 6.980089196968116, 7.8189621618097735, 8.8899567376671, 9.895566493040366, 10.872991361211659, 11.822183626596308, 12.85997815691717, 13.786791985430513, 14.589896040739493, 13.562478675555992, 11.715321159198965, 10.709356602295081, 9.789182158522104, 8.769597003330285, 7.718473080840786, 6.708721525464083, 5.778951467040564, 4.830099696149994, 4.105536159737225, 4.997871931297135, 5.965898569525421, 6.89142489966505, 7.878502231189558, 8.921244354454855, 9.84184587418641, 10.885248820499138, 11.837848095082443, 12.826548478377122, 13.643879467885686, 12.758232594700562, 10.741153801446236, 9.769089032721231, 8.748506689431057, 7.780387189672203, 6.777341771893239, 5.762679653321266, 4.814027929721587, 3.876353533623257, 3.118564449770057, 4.066747472673089, 4.934595836019185, 5.978037201609802, 6.971119947898915, 7.985904868605147, 8.905902993292845, 9.928311626231826, 10.912019133170494, 11.900706510255073, 12.665199691476904, 11.71863025094295, 9.768271850544998, 8.826746469699438, 7.780285188680169, 6.784090359441239, 5.8682416732822995, 4.872195415358533, 3.909272282494499, 2.895953011468815, 2.0544355503184333, 3.00463178533147, 3.9632767844026278, 5.014883376608295, 5.947026544624354, 7.014937448795452, 7.941736896447708, 9.002403673119437, 9.979191991663946, 10.984293027180316, 11.75245171719127, 10.7152910634177, 8.933163824661236, 7.949755222970677, 6.897278576033828, 5.853220044228414, 4.95243959134363, 3.963036580867476, 2.935208362427591, 1.9357904668603974, 0.9943907349104649, 1.9994759805833928, 3.022095103119893, 4.0704960108372035, 5.009728692093826, 6.0076267926597815, 7.005771906780568, 7.998345054121973, 8.97796936715914, 9.93692599939266, 10.900831281192994, 9.979007521237092, 7.932829154608143, 6.987008325510698, 5.939382208156694, 4.880554141321287, 3.9486921494082616, 2.929891586799731, 1.9953547056858603, 0.9724438508837195, 0.0, 1.0004022446202427, 2.068530467833215, 3.0906632818780686, 4.051187755220003, 5.0636086619534115, 6.063642602557619, 7.025960933695032, 8.06252175465645, 9.092415630341542, 9.929750790774902, 8.954527376518012, 8.898935802877423, 7.917077863182725, 6.889193897650352, 5.9421733730248825, 4.898341079503995, 3.903105926409012, 3.0566936142911527, 2.0348768315144956, 1.0620461991173338, 1.9924676313392646, 3.0394172287849304, 4.002149969153872, 4.982669518349556, 5.943326752893591, 6.914451126410656, 7.890086775216754, 8.841249136257204, 9.896952247320197, 10.794886459287731, 9.848933111432098, 9.893872030603498, 8.835758559826935, 7.812370357197797, 6.829751869710385, 5.804722851295875, 4.830238123586078, 4.030261108799839, 3.0309414173047315, 2.1149816240979558, 3.0284178703893394, 4.054161937518494, 4.961287627951629, 5.906297751004211, 6.885540533537795, 7.891369981572616, 8.845556891722689, 9.86327100169339, 10.804123331136784, 11.748690247471144, 10.80416603515995, 10.73386027964165, 9.722175293906474, 8.761523329240559, 7.714515357720512, 6.766220175616495, 5.772554024848254, 4.965180928945955, 4.001541050083667, 3.145275054064989, 4.101336527872272, 5.0736453107660315, 5.948271482685237, 6.834272569950662, 7.763691406422407, 8.83172948864339, 9.8140992485763, 10.80336458766254, 11.816110214747845, 12.78962398683361, 11.731004475881793], [13.603303460165591, 12.784679956733541, 11.809185308008978, 10.838045645834118, 9.80981100620307, 8.854697195156211, 7.832800338705137, 6.9214795365933455, 6.054979857061301, 5.188369349758144, 4.184384112215218, 5.119815359834742, 5.920629314030557, 6.86013172655685, 7.713856734791217, 8.702334354912113, 9.659719833885704, 10.68409243111398, 11.660113977902826, 12.686851574252934, 14.622209237812168, 13.819197248971944, 12.79969818631298, 11.879847046813664, 10.823133739983277, 9.833899113473466, 8.782927042325326, 7.971127492455336, 7.110525663454391, 6.080847653407735, 5.1274519649778565, 6.087494038683007, 6.9577034381409595, 7.822595316884223, 8.640984730361872, 9.70821515946075, 10.585167511375008, 11.513489356039186, 12.568740280285702, 13.613865527438952, 15.491417114624278, 14.672552751426277, 13.715793159597686, 12.749627439434033, 11.750787006626702, 10.816859744158567, 9.785657141660845, 9.030420375930078, 8.110699552114319, 7.103444831583324, 6.148297658442301, 7.079090647231471, 7.972919063816493, 8.878471238532109, 9.589277309954701, 10.527910345480825, 11.47776907868557, 12.526891201064453, 13.494138431368869, 14.445967761040702, 16.36671261602471, 15.68364269054748, 14.699637080907765, 13.805428671095912, 12.766169159546537, 11.74072720062383, 10.792246423171258, 10.097488535919632, 9.126618005905613, 8.162120551228139, 7.207356471195675, 8.067455513052119, 8.932441953744501, 9.866207537748865, 10.609183265896295, 11.538986614067204, 12.406802989188229, 13.341921064994938, 14.335500218156477, 15.344082902078558, 17.292288267448324, 16.62265661252513, 15.755618720452699, 14.757933527562974, 13.748431081306878, 12.796685893787833, 11.846216494231012, 11.161356108622291, 10.118744116029985, 9.212212167915895, 8.262572198527728, 9.00682521346467, 9.920777749902175, 10.838360738084058, 11.588012512125877, 12.600131476172992, 13.405898850942044, 14.334762200719247, 15.281363000019397, 16.31430171802459, 18.1421313661582, 17.60444819303998, 16.655210296604952, 15.729823378961111, 14.690993917927255, 13.82806768488368, 12.890892231092616, 12.060677026465294, 11.05069747366517, 10.180683982768635, 9.234537091113161, 9.967754837318251, 10.947550718625337, 11.856500253332236, 12.513874127143358, 13.493111649841163, 14.420444650726154, 15.33318718712686, 16.229045027476957, 17.191788306897525, 18.356269889888154, 17.342103617369194, 16.380921140777076, 15.419809506241211, 14.442531934556518, 13.69119687017719, 12.762899947798712, 11.81025420865444, 10.850515001864453, 9.90797063067247, 10.256001177080636, 10.991640444264766, 11.97380828543633, 12.87016942180702, 13.466354050572397, 14.420533197829112, 15.382698295361212, 16.309049124526755, 17.24860045317335, 18.121218636660366, 17.345038516603562, 16.37601484345742, 15.398610063625638, 14.38873256065973, 13.417176085677122, 12.665046043240194, 11.786608500907832, 10.828872224721275, 9.887595236979132, 8.966496594061812, 9.873447170894607, 10.843472356435356, 11.720153510112306, 12.678957195331003, 13.606074016656747, 14.577071181564888, 15.506657781665526, 16.44561310601755, 17.496667321174733, 18.373002076910797, 16.37561937596669, 15.355418049009522, 14.361717365850085, 13.43367977467206, 12.48641545717809, 11.622714933765108, 10.720079608897846, 9.824824202713685, 8.868231424335809, 7.928282094011731, 8.861403979182835, 9.821109523817361, 10.756267248876563, 11.650889042665446, 12.680200211572421, 13.662099280252328, 14.589816862947892, 15.663391901281864, 16.730209518099077, 17.424982912928197, 15.437539673206464, 14.432400597944273, 13.461696964583847, 12.480571888084654, 11.522683005490778, 10.67907646947111, 9.736872444756736, 8.848144595645673, 7.804666707638459, 6.982521616698677, 7.906426311704687, 8.831599770441729, 9.770560005520597, 10.717168545851129, 11.704155138084056, 12.69998157578792, 13.639365011089831, 14.713623639439351, 15.738316806282084, 16.498231377838664, 14.563333378429926, 13.603093724387396, 12.65897405830447, 11.589608397113238, 10.588940358198366, 9.615312488562243, 8.688453245413736, 7.841582362245311, 6.87570291036136, 6.021813254947306, 6.931036510645401, 7.8735289559388155, 8.819744726104368, 9.891428244831767, 10.833250548398153, 11.784059095093259, 12.76837249581578, 13.779994571942833, 14.69599597634343, 15.493168167969738, 13.60727554178332, 12.679322429837677, 11.815034064087456, 10.776414306569258, 9.729026580695523, 8.659278813014298, 7.726615678483226, 6.872917814451838, 5.924938904731357, 4.999817574479351, 5.9796869523478735, 6.818559917189531, 7.889554493046857, 8.895164248420123, 9.872589116591415, 10.821781381976065, 11.859575912296927, 12.78638974081027, 13.760643053235297, 14.562880920176235, 12.715723403819208, 11.709758846915324, 10.789584403142348, 9.76999924795053, 8.71887532546103, 7.709123770084326, 6.779353711660806, 5.830501940770237, 5.017280333424648, 3.997469686676893, 4.965496324905178, 5.891022655044807, 6.878099986569316, 7.920842109834612, 8.841443629566166, 9.884846575878894, 10.837445850462199, 11.826146233756878, 12.87586535670629, 13.758634839320806, 11.74155604606648, 10.769491277341475, 9.7489089340513, 8.780789434292448, 7.777744016513482, 6.763081897941509, 5.81443017434183, 4.876755778243499, 4.037036262956276, 3.066345228052846, 3.9341935913989423, 4.97763495698956, 5.970717703278671, 6.985502623984903, 7.905500748672601, 8.927909381611583, 9.91161688855025, 10.90030426563483, 11.940848884377564, 12.719032495563193, 10.768674095165242, 9.827148714319682, 8.780687433300413, 7.784492604061483, 6.868643917902543, 5.872597659978776, 4.909674527114742, 3.8963552560890573, 2.972907363504652, 2.0042295407112274, 2.9628745397823852, 4.0144811319880525, 4.94662430000411, 6.014535204175209, 6.941334651827464, 8.002001428499193, 8.978789747043702, 9.983890782560072, 10.927796561849197, 11.715693308037944, 9.93356606928148, 8.950157467590921, 7.897680820654071, 6.8536222888486575, 5.952841835963873, 4.963438825487719, 3.9356106070478334, 2.93619271148064, 1.9947929795307076, 0.9990737359631501, 2.02169285849965, 3.0700937662169605, 4.009326447473582, 5.007224548039538, 6.005369662160325, 6.99794280950173, 7.977567122538897, 8.936523754772416, 10.00778358452989, 10.979409765857335, 8.933231399228386, 7.987410570130941, 6.939784452776937, 5.880956385941531, 4.949094394028505, 3.930293831419974, 2.9957569503061032, 1.9728460955039622, 1.0004022446202427, 0.0, 1.0681282232129719, 2.090261037257825, 3.0507855105997597, 4.063206417333168, 5.063240357937375, 6.0255586890747885, 7.062119510036206, 8.092013385721298, 9.07732892559106, 9.954929621138255, 9.899338047497666, 8.91748010780297, 7.889596142270595, 6.942575617645126, 5.898743324124238, 4.903508171029255, 4.023597820502244, 3.0017810377255865, 1.9967492977268548, 1.066327865504924, 2.08397712240974, 3.046709862778682, 3.9822672737293123, 4.9429245082733475, 5.914048881790412, 6.889684530596511, 7.84084689163696, 8.896550002699954, 9.945133864809888, 10.849335356052341, 10.894274275223742, 9.836160804447179, 8.81277260181804, 7.830154114330629, 6.805125095916118, 5.830640368206321, 4.99716531501093, 3.9978456235158224, 3.049684722707477, 2.102278104554999, 3.098721831143303, 4.005847521576439, 4.950857644629021, 5.930100427162605, 6.893673086997929, 7.845154647102445, 8.862868757073146, 9.803721086516541, 10.7482880028509, 11.71428620722578, 11.734262524261894, 10.722577538526718, 9.761925573860802, 8.714917602340757, 7.766622420236739, 6.772956269468497, 5.932085135157045, 4.968445256294757, 4.07997815267451, 3.1751967620379316, 4.118205204390841, 4.992831376310047, 5.878832463575472, 6.808251300047218, 7.835968280851064, 8.813697003956056, 9.802962343042296, 10.815707970127601, 11.81471260036824, 12.641124647947622], [12.53517523695262, 11.71655173352057, 10.741057084796006, 9.769917422621146, 8.741682782990098, 7.78656897194324, 6.764672115492164, 5.853351313380373, 4.986851633848329, 4.120241126545173, 5.13083148122043, 6.116285990972252, 6.917099945168068, 7.856602357694361, 8.774705213732085, 9.763182833852982, 10.720568312826574, 11.744940910054849, 12.720962456843694, 13.54535286891266, 13.554081014599197, 12.751069025758975, 11.73156996310001, 10.811718823600692, 9.755005516770304, 8.765770890260494, 7.714798819112353, 6.902999269242364, 6.042397440241419, 5.157048723732999, 6.073899333983069, 7.03394140768822, 7.95417406927847, 8.819065948021734, 9.70183320930274, 10.769063638401619, 11.646015990315878, 12.574337834980055, 13.629588759226571, 14.599861358859522, 14.545579668036195, 13.604424528213304, 12.647664936384713, 11.68149921622106, 10.682658783413729, 9.748731520945594, 8.717528918447872, 7.962292152717105, 7.058834631947524, 6.179645901908588, 7.094745027447513, 8.025538016236684, 8.969389694954003, 9.87494186966962, 10.650125788895568, 11.588758824421692, 12.538617557626438, 13.587739680005322, 14.554986910309738, 15.506816239981571, 15.552928532354803, 14.615514467334506, 13.631508857694792, 12.737300447882939, 11.698040936333564, 10.672598977410857, 9.724118199958285, 9.029360312706661, 8.074753085738818, 7.2383216215534025, 8.153803840200888, 9.013902882057332, 9.928912584882012, 10.862678168886376, 11.670031744837162, 12.599835093008071, 13.467651468129096, 14.402769543935806, 15.396348697097345, 16.404931381019423, 16.478504183778416, 15.554528389312157, 14.687490497239725, 13.689805304350001, 12.680302858093905, 11.72855767057486, 10.778088271018039, 10.09322788540932, 9.06687919586319, 8.304860257398097, 9.209019567532941, 9.953272582469882, 10.917248381039686, 11.834831369221568, 12.648860991066744, 13.66097995511386, 14.46674732988291, 15.395610679660113, 16.342211478960266, 17.375150196965457, 17.486606277174438, 16.536319969827, 15.587082073391977, 14.661695155748138, 13.622865694714282, 12.759939461670706, 11.822764007879643, 11.0088121062985, 9.998832553498376, 9.353801645326012, 10.180984460118374, 10.914202206323464, 11.904721177861626, 12.83368012619675, 13.574722606084226, 14.55396012878203, 15.481293129667021, 16.394035666067726, 17.289893506417826, 18.252636785838394, 18.430637019969488, 17.535155305912973, 16.66090215430458, 15.662530498014439, 14.593637432365172, 13.730252903749825, 12.884974684094583, 12.029303495163363, 11.019337829440037, 10.295555553247974, 9.90589816909143, 10.832933726289191, 11.810846444713368, 12.740174866333719, 13.716319731800073, 14.668017613648882, 15.600119293462088, 16.54454589015941, 17.5529381837158, 18.456637705487182, 18.288276465315068, 17.31925279216892, 16.34184801233714, 15.331970509371232, 14.360414034388624, 13.608283991951696, 12.729423886969132, 11.718280666289221, 10.77700367854708, 9.85590503562976, 8.94459246411731, 9.901004320323576, 10.777685474000526, 11.736489159219223, 12.642961263684967, 13.613958428593108, 14.543545028693746, 15.482500353045769, 16.533554568202952, 17.519551475612637, 17.318857324678195, 16.298655997721024, 15.304955314561587, 14.376917723383562, 13.429653405889592, 12.56595288247661, 11.662894994959146, 10.714232644281632, 9.757639865903757, 8.817690535579679, 7.932549272405538, 8.87864148770558, 9.813799212764783, 10.708421006553666, 11.717087458600641, 12.68029969664359, 13.608017279339155, 14.681592317673127, 15.73104749665102, 16.603313164549085, 16.380777621917968, 15.375638546655775, 14.40493491329535, 13.423809836796156, 12.46592095420228, 11.622314418182611, 10.679687830818036, 9.737553037213619, 8.694075149206405, 7.871930058266624, 6.963958275592906, 7.889131734329949, 8.828091969408817, 9.774700509739349, 10.72235555447532, 11.718181992179183, 12.657565427481094, 13.731824055830614, 14.69415075284683, 15.622624639366057, 15.527259825232036, 14.546331673098898, 13.602212007015972, 12.53284634582474, 11.532178306909868, 10.558550437273745, 9.631691194125239, 8.730990803813258, 7.765111351929307, 6.911221696515253, 5.98856847453362, 6.895784096203634, 7.841999866369186, 8.913683385096585, 9.765122325185182, 10.715930871880287, 11.70024427260281, 12.711866348729862, 13.627867753130456, 14.605919906693698, 14.57120198858543, 13.643248876639788, 12.758272012798958, 11.71965225528076, 10.672264529407025, 9.6025167617258, 8.669853627194728, 7.81615576316334, 6.8143473462993045, 5.8892260160472985, 5.0372189162360925, 5.84081505745435, 6.885016477731842, 7.890626233105107, 8.804460893378444, 9.753653158763093, 10.791447689083956, 11.718261517597298, 12.692514830022326, 13.719932195205827, 13.679649850621319, 12.673685293717435, 11.753510849944458, 10.727422062330309, 9.662113274172533, 8.652361718795829, 7.722591660372308, 6.773739889481739, 5.906688774992595, 4.88687812824484, 3.987751465169997, 4.913277795309626, 5.838775206021324, 6.88151732928662, 7.773315406353195, 8.816718352665923, 9.769317627249228, 10.758018010543907, 11.807737133493319, 12.777306488740885, 12.70548249286859, 11.733417724143585, 10.712835380853411, 9.744715881094558, 8.720981965224984, 7.706319846653011, 6.757668123053332, 5.819993726955001, 4.948432213153571, 3.9557536696207936, 2.928299543453922, 3.971740909044539, 4.9025894800657, 5.917374400771932, 6.83737252545963, 7.859781158398611, 8.84348866533728, 9.832176042421858, 10.872720661164593, 11.819290101698547, 11.732600541967352, 10.791075161121793, 9.744613880102523, 8.748419050863594, 7.823057554878562, 6.827011296954796, 5.864088164090761, 4.8395932048005585, 3.8843033137019467, 2.915625490908522, 1.9569804918373646, 2.9855389516979054, 3.878496076791139, 4.946406980962237, 5.873206428614493, 6.933873205286222, 7.910661523830731, 8.915762559347101, 9.859668338636226, 10.896828992409796, 10.971948056053954, 10.018285690803895, 8.965809043867045, 7.921750512061631, 7.020970059176846, 6.031567048700691, 5.003738830260806, 4.004320934693612, 3.05772045413306, 1.994140112842691, 0.953564635286678, 2.0019655430039887, 2.941198224260611, 3.9390963248265667, 4.937241438947353, 5.929814586288758, 6.9094388993259255, 7.868395531559444, 8.939655361316918, 9.926104359478098, 10.00135962244136, 9.055538793343914, 8.00791267598991, 6.949084609154504, 6.017222617241478, 4.998422054632947, 4.0638851735190755, 3.0409743187169345, 2.068530467833215, 1.0681282232129719, 0.0, 1.0221328140448536, 1.9826572873867878, 2.9950781941201963, 3.995112134724403, 4.957430465861816, 5.993991286823235, 7.023885162508328, 8.009200702378088, 8.984424116634978, 10.772956298007225, 9.978328586743835, 8.950444621211462, 8.003424096585993, 6.9595918030651065, 5.9643566499701235, 5.020068451639753, 3.9982516688630967, 2.993219928864365, 2.0627984966424338, 1.015848899196768, 1.9785816395657099, 2.914139050516341, 3.874796285060376, 4.845920658577441, 5.821556307383539, 6.772718668423988, 7.828421779486981, 8.877005641596917, 9.82295898945255, 11.640958201596009, 10.897009283388048, 9.873621080758909, 8.891002593271498, 7.865973574856986, 6.89148884714719, 5.99363594614844, 4.994316254653333, 4.046155353844987, 3.0987487356925087, 2.030593607930331, 2.937719298363467, 3.8827294214160486, 4.861972203949633, 5.825544863784957, 6.777026423889474, 7.794740533860175, 8.73559286330357, 9.680159779637929, 10.646157984012808, 12.63184340478227, 11.783426017467585, 10.82277405280167, 9.775766081281624, 8.827470899177607, 7.833804748409365, 6.928555766294556, 5.964915887432268, 5.076448783812021, 4.121644131043144, 3.0500769811778694, 3.9247031530970746, 4.8107042403625, 5.740123076834245, 6.767840057638092, 7.745568780743084, 8.734834119829323, 9.74757974691463, 10.74658437715527, 11.57299642473465], [11.513042422907764, 10.694418919475714, 9.71892427075115, 8.747784608576293, 7.719549968945244, 6.764436157898384, 5.786779202602678, 4.875458400490887, 4.020230931428761, 5.044657209174367, 6.0635829033306115, 7.054000257681869, 7.875944723486383, 8.815447136012677, 9.733549992050401, 10.722027612171297, 11.67941309114489, 12.703785688373165, 13.549957651217913, 12.523220054867805, 12.531948200554341, 11.72893621171412, 10.709437149055155, 9.789586009555839, 8.732872702725448, 7.743638076215639, 6.736905906222867, 5.925106356352877, 5.075776737821851, 6.081464806362193, 7.00665075609325, 7.966692829798401, 8.913018847596785, 9.77791072634005, 10.660677987621055, 11.727908416719934, 12.604860768634193, 13.53318261329837, 14.588433537544887, 13.577728544814667, 13.52344685399134, 12.582291714168448, 11.625532122339857, 10.659366402176204, 9.660525969368873, 8.77083860805611, 7.739636005558387, 6.984399239827619, 6.092213929527956, 7.099468650058951, 8.027496449557695, 8.958289438346865, 9.928234473272317, 10.833786647987935, 11.608970567213884, 12.547603602740008, 13.497462335944753, 14.546584458323638, 15.513831688628054, 14.568896207574916, 14.530795718309948, 13.59338165328965, 12.609376043649936, 11.723920769281929, 10.720148023444079, 9.694706064521371, 8.7462252870688, 8.051467399817174, 7.10813238331925, 8.084857774153715, 9.08530881985062, 9.946654304167513, 10.887757363200325, 11.821522947204691, 12.628876523155478, 13.558679871326387, 14.426496246447412, 15.361614322254121, 16.35519347541566, 15.553425432256102, 15.456371369733562, 14.532395575267302, 13.66535768319487, 12.711912391460515, 11.702409945204419, 10.750664757685374, 9.800195358128553, 9.115334972519832, 8.100258493443622, 9.044502966557591, 9.994142935945758, 10.886024004580063, 11.876093159358, 12.793676147539884, 13.60770576938506, 14.619824733432175, 15.425592108201226, 16.35445545797843, 17.30105625727858, 16.510114189325538, 16.464473463129586, 15.558427056937518, 14.609189160502492, 13.683802242858652, 12.644972781824796, 11.78204654878122, 10.844871094990157, 10.042191403878931, 9.032211851078808, 9.959745662708523, 10.905892554363996, 11.044337759789308, 12.00504653062592, 12.882340349766498, 13.646666841184258, 14.625904363882062, 15.540240124052293, 16.498275013514448, 17.550360795367336, 17.41481652239026, 17.408504205924636, 16.55726239302349, 15.683009241415094, 14.684637585124953, 13.615744519475687, 12.75235999086034, 11.907081771205098, 11.062682792743795, 10.052717127020468, 10.901499570630484, 10.836735984229517, 10.020452152842793, 10.939342759671362, 11.868671181291713, 12.69418691775522, 13.645884799604028, 14.577986479417234, 15.522413076114553, 16.530805369670944, 17.434504891442327, 17.47989271382463, 17.53954506694389, 16.6225343463036, 15.61265684333769, 14.641100368355083, 13.778510817797336, 12.883373218095977, 12.04406477667696, 11.015636891905789, 10.832031332614912, 9.875430279255397, 9.088522746877178, 9.90618178895852, 10.864985474177217, 11.620828449640113, 12.591825614548254, 13.521412214648892, 14.460367539000915, 15.511421754158096, 16.49741866156778, 16.510473573187756, 17.320788811765876, 16.32708812860644, 15.399050537428415, 14.451786219934446, 13.588085696521464, 12.685027809004001, 11.701028939058313, 10.736458303038807, 9.79650897271473, 8.863387087543625, 8.066159914259183, 8.942295527722777, 9.83691732151166, 10.694954644555787, 11.658166882598737, 12.585884465294301, 13.659459503628273, 14.708914682606167, 15.581180350504233, 15.57239387042753, 16.39777136070063, 15.427067727340205, 14.44594265084101, 13.488053768247134, 12.644447232227465, 11.701820644862892, 10.759685851258475, 9.71620796325126, 8.872003629639797, 7.894796090730993, 7.076650160883551, 7.956588284366812, 8.903196824697343, 9.700222740430466, 10.696049178134329, 11.63543261343624, 12.709691241785759, 13.672017938801979, 14.600491825321205, 14.526171893636624, 15.52777943114084, 14.624344821060827, 13.554979159869596, 12.554311120954722, 11.580683251318598, 10.65382400817009, 9.753123617858112, 8.787244165974162, 7.920871291941665, 6.9194062896717075, 6.018276459878044, 6.93256769983665, 7.92279888467316, 8.742989511140328, 9.693798057835433, 10.678111458557956, 11.689733534685008, 12.605734939085604, 13.583787092648846, 13.653404759553888, 14.58135787149953, 13.78040482684381, 12.741785069325614, 11.694397343451879, 10.624649575770654, 9.691986441239582, 8.838288577208194, 7.836480160344158, 6.911358830092152, 5.96805673137418, 4.96330742112876, 5.862883663686988, 6.868493419060253, 7.78232807933359, 8.73152034471824, 9.769314875039102, 10.696128703552445, 11.670382015977472, 12.697799381160973, 12.773976200265361, 13.695818107762289, 12.775643663989312, 11.749554876375164, 10.684246088217387, 9.674494532840683, 8.744724474417163, 7.795872703526593, 6.928821589037449, 5.909010942289694, 4.961296489123665, 4.035770158984036, 4.81664239197647, 5.859384515241766, 6.751182592308341, 7.794585538621069, 8.747184813204374, 9.735885196499053, 10.785604319448465, 11.755173674696032, 11.774633737150404, 12.755550538188439, 11.734968194898265, 10.766848695139412, 9.743114779269838, 8.728452660697865, 7.7798009370981855, 6.842126540999855, 5.9705650271984245, 4.977886483665647, 3.950432357498775, 3.0551956996066965, 3.880456666020846, 4.895241586727078, 5.815239711414776, 6.837648344353756, 7.821355851292424, 8.810043228377003, 9.850587847119737, 10.797157287653691, 10.821715391237646, 11.763240772083206, 10.766746694147377, 9.770551864908448, 8.845190368923415, 7.849144110999649, 6.886220978135615, 5.861726018845412, 4.906436127746801, 3.937758304953376, 2.979113305882218, 2.027227080520002, 2.856363262746285, 3.924274166917383, 4.851073614569638, 5.911740391241367, 6.888528709785879, 7.893629745302249, 8.837535524591374, 9.874696178364944, 9.949815242009102, 10.974973358959259, 9.987941857911897, 8.943883326106482, 8.043102873221699, 7.053699862745544, 6.025871644305659, 5.026453748738465, 4.079853268177914, 3.0162729268875443, 1.9756974493315316, 1.0436536718260856, 1.9190654102157574, 2.916963510781713, 3.9151086249025, 4.9076817722439054, 5.8873060852810735, 6.846262717514592, 7.917522547272066, 8.903971545433246, 8.983989524499993, 9.92981035359744, 9.030045490034762, 7.971217423199356, 7.03935543128633, 6.020554868677799, 5.0860179875639275, 4.063107132761787, 3.0906632818780677, 2.090261037257825, 1.0221328140448536, 0.0, 0.9605244733419344, 1.972945380075343, 2.97297932067955, 3.935297651816964, 4.971858472778382, 6.001752348463475, 6.987067888333235, 7.962291302590124, 9.75082348396237, 10.81147673418963, 9.909289399529777, 8.962268874904309, 7.918436581383422, 6.923201428288439, 5.978913229958069, 4.957096447181412, 3.9520647071826804, 3.02164327496075, 1.974693677515084, 1.0119609371461422, 1.8920062364714871, 2.8526634710155223, 3.823787844532587, 4.799423493338685, 5.750585854379134, 6.806288965442127, 7.854872827552062, 8.800826175407694, 10.618825387551153, 11.676938858327716, 10.832465859077224, 9.849847371589814, 8.824818353175303, 7.850333625465505, 6.9524807244667555, 5.953161032971648, 5.005000132163302, 4.036091077763986, 2.964494819120044, 1.9710985959438991, 2.9048365085265626, 3.8840792910601465, 4.8034120497401025, 5.754893609844619, 6.77260771981532, 7.713460049258715, 8.658026965593073, 9.624025169967952, 11.609710590737414, 12.62139557647259, 11.781618831119987, 10.734610859599941, 9.786315677495924, 8.792649526727681, 7.887400544612872, 6.923760665750583, 6.035293562130336, 5.054395553153325, 3.9828284032880505, 2.958082450677507, 3.8328113274730136, 4.762230163944759, 5.7457072435932375, 6.723435966698229, 7.712701305784469, 8.725446932869774, 9.724451563110414, 10.550863610689795], [10.55251794956583, 9.73389444613378, 8.758399797409217, 7.787260135234359, 6.75902549560331, 5.80391168455645, 4.826254729260744, 3.9149339271489527, 4.854591064348053, 5.8790173420936584, 6.932330018274662, 7.92274737262592, 8.83646919682832, 9.775971609354613, 10.694074465392335, 11.682552085513231, 12.639937564486823, 13.575494872769864, 12.589433177875978, 11.56269558152587, 11.571423727212407, 10.768411738372185, 9.748912675713221, 8.829061536213905, 7.772348229383515, 6.783113602873705, 5.776381432880933, 4.964581883010943, 5.910136870741143, 6.915824939281485, 7.869220627711364, 8.829262701416514, 9.873543320938722, 10.738435199681986, 11.621202460962989, 12.688432890061868, 13.565385241976127, 14.493707086640304, 13.637523173708507, 12.617204071472733, 12.562922380649406, 11.621767240826514, 10.665007648997923, 9.69884192883427, 8.700001496026939, 7.810314134714175, 6.779111532216453, 6.023874766485685, 6.926574062447248, 7.933828782978242, 8.890066321175809, 9.820859309964979, 10.87312953953622, 11.794311121329871, 12.569495040555818, 13.508128076081942, 14.457986809286687, 15.507108931665572, 14.560201063904815, 13.608371734232982, 13.570271244968014, 12.632857179947717, 11.648851570308002, 10.763396295939994, 9.759623550102145, 8.734181591179437, 7.785700813726865, 7.09094292647524, 7.942492516238541, 8.919217907073005, 9.91966895276991, 10.809224175785626, 11.773127456881753, 12.735675897237503, 13.589400996497412, 14.51920434466832, 15.387020719789346, 16.322138795596054, 15.54603525224926, 14.592900958914168, 14.495846896391628, 13.571871101925367, 12.704833209852936, 11.751387918118581, 10.741885471862485, 9.79014028434344, 8.839670884786619, 8.154810499177898, 8.934618626362914, 9.878863099476883, 10.82850306886505, 11.748593876198177, 12.07129502600715, 12.939955391672742, 13.612003982859804, 14.634266359308537, 15.595975781516273, 16.524839131293476, 16.49189803411218, 15.549589715983602, 15.50394898978765, 14.597902583595584, 13.648664687160558, 12.723277769516718, 11.684448308482862, 10.821522075439287, 9.884346621648223, 9.117117366312362, 9.8665719839981, 10.794105795627814, 11.740252687283288, 11.851762850964317, 11.044522057283988, 11.921815876424564, 12.686142367842322, 13.665379890540127, 14.579715650710357, 15.537750540172514, 16.589836322025402, 16.454292049048327, 16.4479797325827, 15.596737919681557, 14.72248476807316, 13.72411311178302, 12.655220046133753, 11.791835517518406, 10.946557297863164, 10.155758129113146, 10.88707725993976, 11.735859703549776, 11.644161075404524, 10.827877244017802, 9.97881828632943, 10.90814670794978, 11.733662444413284, 12.685360326262092, 13.617462006075298, 14.561888602772619, 15.570280896329011, 16.47398041810039, 16.51936824048269, 16.579020593601957, 15.662009872961665, 14.652132369995757, 13.680575895013149, 12.817986344455402, 11.922848744754043, 11.13714011304631, 11.84999702482508, 11.63945642378992, 10.682855370430405, 9.895947838052187, 8.945657315616588, 9.904461000835283, 10.660303976298177, 11.631301141206318, 12.560887741306956, 13.499843065658979, 14.55089728081616, 15.536894188225846, 15.549949099845819, 16.563216741629027, 16.486638432184176, 15.55860084100615, 14.61133652351218, 13.860317453930488, 12.98937763676403, 12.1411881350539, 11.543883394213815, 10.603934063889737, 9.670812178718633, 8.873585005434192, 7.981771054380844, 8.876392848169726, 9.734430171213852, 10.697642409256801, 11.625359991952365, 12.698935030286338, 13.74839020926423, 14.620655877162296, 14.611869397085593, 15.576454175364626, 16.37584527979248, 15.394720203293284, 14.436831320699408, 13.502701852324263, 12.529557921100157, 11.58742312749574, 10.543945239488526, 9.679428720814807, 8.702221181906001, 7.88407525205856, 6.996063811024878, 7.94267235135541, 8.73969826708853, 9.735524704792393, 10.674908140094304, 11.749166768443825, 12.711493465460041, 13.639967351979267, 13.565647420294686, 14.567254957798903, 15.511374623881828, 14.50375671232187, 13.503088673406996, 12.529460803770872, 11.57240369478294, 10.580860894095377, 9.614981442211427, 8.728296383116673, 7.726831380846716, 6.8257015510530525, 5.972043226494716, 6.962274411331226, 7.782465037798393, 8.733273584493498, 9.71758698521602, 10.729209061343072, 11.645210465743666, 12.623262619306908, 12.692880286211953, 13.620833398157595, 14.638726272632539, 13.690562621777888, 12.643174895904153, 11.573427128222928, 10.640763993691856, 9.69531820591995, 8.664217436581424, 7.739096106329417, 6.775481822549188, 5.770732512303768, 4.902359190345054, 5.907968945718319, 6.821803605991656, 7.7709958713763045, 8.808790401697166, 9.735604230210509, 10.709857542635536, 11.737274907819037, 11.813451726923427, 12.753735227997852, 13.736168137331246, 12.710079349717098, 11.644770561559321, 10.635019006182617, 9.705248947759097, 8.725575581318, 7.756558865274714, 6.736748218526959, 5.768721580298673, 4.843195250159044, 3.856117918634536, 4.898860041899832, 5.790658118966407, 6.834061065279135, 7.786660339862439, 8.775360723157117, 9.82507984610653, 10.794649201354096, 10.81410926380847, 11.813467658424003, 12.695492668240199, 11.727373168481346, 10.703639252611772, 9.6889771340398, 8.74032541044012, 7.802651014341789, 6.9310895005403586, 5.938410957007582, 4.91095683084071, 3.9465349466720823, 2.919932192678912, 3.934717113385144, 4.854715238072842, 5.877123871011822, 6.86083137795049, 7.849518755035069, 8.890063373777803, 9.836632814311757, 9.86119091789571, 10.80271629874127, 11.727271167489311, 10.731076338250382, 9.805714842265349, 8.809668584341583, 7.846745451477549, 6.822250492187346, 5.866960601088735, 4.89828277829531, 3.939637779224152, 2.918566327585388, 1.8958387894043511, 2.963749693575449, 3.8905491412277042, 4.951215917899433, 5.928004236443943, 6.933105271960313, 7.877011051249438, 8.914171705023008, 8.989290768667166, 10.014448885617325, 10.948466331253831, 9.904407799448416, 9.003627346563633, 8.01422433608748, 6.986396117647594, 5.9869782220804, 5.040377741519848, 3.976797400229479, 2.936221922673466, 1.989361182533019, 0.958540936873823, 1.9564390374397786, 2.9545841515605655, 3.9471572989019705, 4.926781611939138, 5.885738244172656, 6.95699807393013, 7.94344707209131, 8.023465051158059, 8.969285880255505, 9.990569963376696, 8.93174189654129, 7.999879904628264, 6.981079342019733, 6.0465424609058624, 5.023631606103722, 4.051187755220003, 3.0507855105997597, 1.9826572873867878, 0.9605244733419344, 0.0, 1.0124209067334085, 2.012454847337615, 2.974773178475029, 4.011333999436447, 5.04122787512154, 6.0265434149913, 7.00176682924819, 8.790299010620437, 9.850952260847698, 10.869813872871713, 9.922793348246245, 8.878961054725357, 7.883725901630375, 6.939437703300005, 5.917620920523348, 4.912589180524615, 3.9821677483026843, 2.9352181508570183, 1.9724854104880767, 0.9314817631295529, 1.8921389976735878, 2.8632633711906523, 3.8388990199967505, 4.7900613810372, 5.8457644921001926, 6.894348354210128, 7.840301702065761, 9.658300914209219, 10.716414384985782, 11.739802587614921, 10.810371844931748, 9.785342826517237, 8.81085809880744, 7.913005197808691, 6.913685506313584, 5.961879532984965, 4.954314640057298, 3.882718381413355, 2.88932215823721, 1.9443120351846281, 2.923554817718212, 3.8428875763981685, 4.794369136502685, 5.812083246473386, 6.752935575916781, 7.6975024922511395, 8.663500696626018, 10.64918611739548, 11.660871103130656, 12.621523067796572, 11.695135332941875, 10.746840150837858, 9.753174000069615, 8.847925017954807, 7.884285139092519, 6.988298467571909, 5.942892979396701, 4.871325829531426, 3.8465798769208828, 2.8722868541310795, 3.801705690602825, 4.7851827702513035, 5.762911493356295, 6.752176832442535, 7.76492245952784, 8.76392708976848, 9.590339137347861], [9.628836903973818, 8.810213400541768, 7.834718751817206, 6.888047757639516, 5.871792994761125, 4.919922926624487, 4.0593424048328774, 4.927354833882361, 5.867011971081461, 6.8914382488270665, 7.94475092500807, 8.935168279359328, 9.848890103561729, 10.78839251608802, 11.706495372125744, 12.69497299224664, 13.652358471220232, 12.651813827177852, 11.665752132283966, 10.639014535933859, 10.647742681620395, 9.844730692780173, 8.825231630121209, 7.929849158619062, 6.888359471451552, 5.899124844941742, 5.009469108453066, 5.977002789744351, 6.922557777474551, 7.928245846014893, 8.881641534444773, 9.841683608149925, 10.885964227672131, 11.750856106415393, 12.633623367696398, 13.700853796795277, 14.577806148709536, 13.682138663642132, 12.713842128116495, 11.69352302588072, 11.678933622717443, 10.737778482894552, 9.78101889106596, 8.814853170902307, 7.816012738094976, 6.93872457384129, 6.012199207788586, 7.03408771721553, 7.938994969180656, 8.94624968971165, 9.902487227909218, 10.833280216698387, 11.88555044626963, 12.806732028063278, 13.581915947289227, 14.52054898281535, 15.470407716020096, 14.654443248688086, 13.639240279199662, 12.724382976301019, 12.68628248703605, 11.748868422015754, 10.76486281237604, 9.879407538008032, 8.87785000449786, 7.9220537205326655, 7.0187884892989985, 8.009897023701221, 8.95491342297195, 9.931638813806416, 10.932089859503321, 11.821645082519035, 12.785548363615161, 13.252497191197131, 13.593886226628866, 14.637916555597744, 15.566435182037877, 15.618653620705645, 14.625074467544106, 13.708912200982205, 13.611858138459665, 12.687882343993405, 11.820844451920973, 10.869614372514297, 9.8601119262582, 8.978012413696668, 8.072758560358752, 9.013461959640626, 9.947039533096323, 10.891284006210292, 11.840923975598459, 12.761014782931586, 13.083715932740557, 12.280343990861939, 12.615056980399284, 13.637319356848018, 14.599028779055754, 15.527892128832956, 15.570937249407026, 14.66560095805164, 14.619960231855687, 13.716082449335913, 12.766844552900887, 11.841504223912434, 10.802674762878578, 10.028816940041027, 9.117434297220356, 9.97576882677509, 10.878992890731508, 11.806526702361223, 12.752673594016697, 12.864183757697724, 12.056942964017395, 11.26220447561376, 11.689195365381803, 12.668432888079607, 13.582768648249838, 14.540803537711994, 15.592889319564883, 15.570303291116364, 15.563990974650736, 14.714917785421886, 13.840664633813489, 12.842339566178735, 11.773446500529468, 10.999130382120146, 10.179644973435297, 11.014409589575873, 11.899498166673169, 12.748280610283185, 12.656581982137931, 11.84029815075121, 10.991239193062837, 10.248535307138976, 10.736715441952764, 11.688413323801573, 12.620515003614779, 13.5649416003121, 14.573333893868492, 15.477033415639871, 15.522421238022174, 15.697200459342287, 14.78023632735738, 13.770358824391472, 12.798802349408865, 12.025281209057143, 11.155936420326176, 11.995791573509038, 12.86241793155849, 12.651877330523327, 11.695276277163812, 10.908368744785594, 9.958078222349995, 9.24484960002448, 9.663356973837658, 10.634354138745799, 11.563940738846437, 12.50289606319846, 13.553950278355641, 14.539947185765326, 14.5530020973853, 15.566269739168504, 15.604864886579891, 14.676827295401866, 13.729562977907896, 13.067612318532229, 12.222465312336162, 12.999839595516628, 12.556304300947222, 11.616354970623144, 10.68323308545204, 9.8860059121676, 8.994191961114252, 8.216781447358922, 8.737483168753332, 9.700695406796282, 10.628412989491846, 11.701988027825818, 12.75144320680371, 13.623708874701776, 13.614922394625074, 14.579507172904105, 15.496393466717928, 15.651184312189084, 14.693295429595208, 14.011250782826227, 13.205672476477272, 12.599844034229147, 11.556366146221933, 10.691849627548214, 9.714642088639408, 8.896496158791967, 8.008484717758286, 7.283060950544606, 7.7427512646280094, 8.738577702331874, 9.677961137633785, 10.752219765983305, 11.714546462999522, 12.643020349518748, 12.568700417834167, 13.570307955338382, 14.514427621421309, 15.516177619055277, 14.515509580140403, 13.54188171050428, 12.584824601516347, 11.593281800828784, 10.627402348944834, 9.740717289850082, 8.739252287580124, 7.8381224577864606, 6.984464133228123, 6.211403626477561, 6.785518035337872, 7.7363265820329765, 8.720639982755499, 9.73226205888255, 10.648263463283147, 11.626315616846389, 11.695933283751431, 12.623886395697074, 13.641779270172018, 14.680399027690214, 13.65559580263756, 12.585848034956335, 11.653184900425263, 10.707739112653357, 9.676638343314831, 8.751517013062825, 7.787902729282596, 6.783153419037176, 5.914780097078461, 5.1570981608646544, 5.824856603531135, 6.774048868915783, 7.811843399236645, 8.738657227749988, 9.712910540175015, 10.740327905358516, 10.816504724462906, 11.741314321264445, 12.794699315741179, 13.722500256450505, 12.65719146829273, 11.647439912916026, 10.717669854492506, 9.737996488051406, 8.768979772008121, 7.749169125260367, 6.781142487032081, 5.855616156892452, 4.868538825367944, 4.091384815243432, 4.793711116505886, 5.837114062818614, 6.789713337401918, 7.778413720696596, 8.828132843646008, 9.797702198893575, 9.81716226134795, 10.801046751690595, 11.82162909498077, 12.739794075214753, 11.716060159345181, 10.701398040773208, 9.752746317173528, 8.815071921075198, 7.9435104072737674, 6.950831863740991, 5.923377737574119, 4.958955853405491, 3.9323530994123206, 3.0429188612434763, 3.8577682356123204, 4.880176868551301, 5.8638843754899685, 6.852571752574548, 7.893116371317282, 8.839685811851236, 8.848770011162303, 9.790295392007863, 10.836756673027132, 11.74349724498379, 10.818135748998758, 9.822089491074992, 8.859166358210958, 7.834671398920755, 6.879381507822144, 5.910703685028719, 4.952058685957561, 3.9309872343187964, 2.9082596961377596, 2.018898377644341, 2.893602138767183, 3.954268915438912, 4.915583329710536, 5.920684365226906, 6.864590144516031, 7.901750798289602, 7.97686986193376, 9.002027978883916, 9.962387458753236, 10.916828706181825, 10.016048253297042, 9.026645242820887, 7.998817024381002, 6.999399128813808, 6.0527986482532565, 4.989218306962888, 3.9486428294068747, 3.0017820892664275, 1.9709618436072316, 0.9440181307063702, 1.942163244827157, 2.9347363921685625, 3.91436070520573, 4.873317337439249, 5.944577167196723, 6.931026165357903, 7.01104414442465, 7.956864973522096, 9.004491090876101, 9.944162803274699, 9.012300811361673, 7.993500248753142, 7.0589633676392705, 6.03605251283713, 5.063608661953411, 4.063206417333168, 2.9950781941201967, 1.972945380075343, 1.0124209067334085, 0.0, 1.000033940604207, 1.9623522717416204, 2.9989130927030385, 4.028806968388131, 5.014122508257891, 5.989345922514781, 7.837318472429065, 8.888084307872878, 9.915968273405252, 10.86298879803072, 9.891381961458766, 8.896146808363783, 7.951858610033414, 6.9300418272567565, 5.925010087258024, 4.994588655036093, 3.947639057590427, 2.984906317221485, 1.9439026698629613, 1.0081502397416242, 1.9792746132586887, 2.9152179744047393, 3.866380335445189, 4.922083446508182, 5.941367816018757, 6.8873211638743905, 8.734619868617207, 9.79273333939377, 10.816121542022909, 11.79874002951032, 10.797763733250646, 9.823279005540849, 8.9254261045421, 7.926106413046993, 6.974300439718372, 5.966735546790705, 4.895139288146763, 3.9017430649706184, 2.9567329419180366, 2.059376712049978, 2.9588988184662046, 3.870688090910674, 4.888402200881375, 5.82925453032477, 6.773821446659128, 7.739819651034007, 9.725505071803468, 10.737190057538644, 11.69784202220456, 12.707556239675283, 11.759261057571265, 10.765594906803024, 9.860345924688215, 8.896706045825928, 8.000719374305316, 6.955313886130108, 5.883746736264834, 4.859000783654291, 3.8847077608644875, 3.034793366174958, 3.9011940123193396, 4.839230447764284, 5.828495786850523, 6.841241413935829, 7.840246044176467, 8.66665809175585], [8.628802963369614, 7.8101794599375625, 6.834684811213, 5.88801381703531, 4.871759054156919, 3.9801907826074667, 5.007534596225444, 5.927388774486568, 6.867045911685668, 7.891472189431274, 8.944784865612277, 9.935202219963534, 10.848924044165935, 11.788426456692227, 12.70652931272995, 13.633537962775515, 12.676152483801923, 11.651779886573648, 10.665718191679762, 9.638980595329654, 9.64770874101619, 8.844696752175967, 7.825197689517004, 6.929815218014856, 5.901788483336078, 4.959392700924722, 5.957661299845633, 6.949657113639279, 7.922591718078758, 8.9282797866191, 9.88167547504898, 10.84171754875413, 11.885998168276338, 12.750890047019599, 13.633657308300604, 14.615429472004656, 13.601600161291227, 12.682104723037927, 11.71380818751229, 10.693489085276516, 10.691431394049918, 9.751207494779077, 8.794447902950486, 7.8282821827868325, 6.829441749979502, 5.99899242982427, 6.960391399181153, 7.982279908608096, 8.939028909784863, 9.946283630315857, 10.902521168513424, 11.833314157302594, 12.885584386873836, 13.806765968667484, 13.68643171255039, 14.625064748076513, 14.674534427811011, 13.654409308083881, 12.639206338595457, 11.731521595531783, 11.699711498920577, 10.76229743390028, 9.778291824260565, 8.892836549892557, 7.891279016382385, 6.982321576515646, 7.930802353968217, 8.921910888370439, 9.90746123852872, 10.884186629363185, 11.884637675060091, 12.821679023123242, 13.785582304219368, 13.680185068485207, 12.666525756608795, 13.710556085577673, 14.639074712017806, 14.61861968010144, 13.625040526939902, 12.72234121286673, 12.62528715034419, 11.70131135587793, 10.834273463805498, 9.883043384398821, 8.873540938142725, 8.038280269679648, 8.984772425027971, 9.925475824309846, 10.899587348653093, 11.843831821767061, 12.793471791155229, 13.761048723535792, 13.695377182345148, 12.708031868150014, 11.687696510379213, 12.709958886827947, 13.671668309035683, 14.600531658812885, 14.570903308802821, 13.679029969936165, 13.633389243740213, 12.729511461220438, 11.780273564785412, 10.854933235796958, 9.816103774763102, 9.089084796024007, 10.02626024981507, 10.88778269144431, 11.831540706288278, 12.759074517917993, 13.705221409573467, 13.549102369013369, 12.668604213621986, 11.739645265286862, 10.761834895361732, 11.741072418059536, 12.655408178229766, 13.613443067691922, 14.66552884954481, 14.58373230300089, 14.577419986535261, 13.728346797306411, 12.854093645698015, 11.855768578063259, 10.786875512413992, 10.059398238103126, 11.001019799298483, 11.926423454245093, 12.852045982229939, 13.700828425839955, 13.454324385137904, 12.525216762066854, 11.6725437206615, 10.767851743435235, 9.809354971932693, 10.761052853781502, 11.693154533594708, 12.637581130292027, 13.64597342384842, 14.5496729456198, 14.581444499447661, 14.710629471226813, 13.793665339241905, 12.783787836275996, 11.812231361293389, 11.085549065040123, 11.977311246189362, 12.907805438178258, 13.81496574711526, 13.550354862871226, 12.59375380951171, 11.59328735610124, 10.639382749948657, 9.76416603632074, 8.735996503817587, 9.706993668725728, 10.636580268826366, 11.575535593178389, 12.62658980833557, 13.612586715745255, 13.612025358810786, 14.625293000593993, 14.618293898464415, 13.69025630728639, 12.74299198979242, 12.127880174515209, 13.043840138199348, 13.911853460185847, 13.45478183329512, 12.514832502971043, 11.581710617799938, 10.614143324245646, 9.675496488712914, 8.736097883655182, 7.810122698733262, 8.77333493677621, 9.701052519471775, 10.774627557805747, 11.810466468229198, 12.682732136127264, 12.673945656050561, 13.638530434329594, 14.555416728143415, 14.664613324073608, 13.706724441479732, 13.071518638809208, 14.027047302340458, 13.56445998332281, 12.520982095315595, 11.590327159896113, 10.613119620987307, 9.687946162250265, 8.748985927171397, 7.802377386840866, 6.815390794607939, 7.811217232311804, 8.750600667613716, 9.824859295963236, 10.773569724425009, 11.702043610944235, 11.627723679259654, 12.629331216763871, 13.573450882846796, 14.642816544038027, 14.640467088772144, 14.135282619718074, 13.584318022808763, 12.5927752221212, 11.62689577023725, 10.740210711142497, 9.738745708872539, 8.837615879078877, 7.983957554520538, 6.923869127759608, 5.858157565317802, 6.808966112012906, 7.7932795127354275, 8.80490158886248, 9.707286724708634, 10.685338878271876, 10.75495654517692, 11.682909657122563, 12.700802531597507, 13.739422289115705, 14.655089223929975, 13.58534145624875, 12.652678321717678, 11.707232533945772, 10.676131764607247, 9.75101043435524, 8.787396150575011, 7.782646840329591, 6.914273518370877, 5.932439992890838, 4.897496133511065, 5.846688398895713, 6.870866660662134, 7.797680489175477, 8.771933801600504, 9.799351166784005, 9.821512726595193, 10.741832622681141, 11.795217617157874, 12.7794767098144, 13.657225408896936, 12.647473853520232, 11.717703795096712, 10.737489909343823, 9.768473193300538, 8.748662546552783, 7.780635908324497, 6.855109578184868, 5.868032246660359, 4.936781660244069, 3.8663506464858153, 4.896137324244102, 5.848736598827406, 6.837436982122084, 7.880118131211352, 8.849687486458919, 8.822170263480237, 9.801565053107291, 10.822147396397465, 11.790266896156318, 12.716094099949387, 11.701431981377414, 10.752780257777735, 9.815105861679404, 8.943544347877975, 7.950865804345197, 6.923411678178326, 5.958989794009698, 4.9318465207047355, 3.9170615999985032, 2.93040776559225, 3.888498852036588, 4.872206358975256, 5.860893736059835, 6.901438354802569, 7.848007795336525, 7.849288312578999, 8.790813693424559, 9.837274974443828, 10.833469803682757, 11.75883129966779, 10.822123431679199, 9.859200298815164, 8.834705339524962, 7.879415448426351, 6.910737625632926, 5.952092626561768, 4.9310211749230035, 3.9082936367419663, 2.893041116399368, 1.9662416687471127, 2.9625908989241996, 3.9161016311272316, 4.921202666643602, 5.8651084459327265, 6.902269099706298, 6.977388163350455, 8.00199403827971, 8.962353518149028, 10.025363400568818, 10.998894650955695, 10.026679183425092, 8.998850964985207, 7.999433069418014, 7.052832588857463, 5.989252247567094, 4.948676770011081, 4.001816029870634, 2.9709957842114383, 1.9440520713105771, 1.0148027748070867, 1.9352546935852584, 2.914879006622426, 3.873835638855945, 4.9450954686134185, 5.931544466774598, 6.011010203820444, 6.95683103291789, 8.004457150271893, 9.0632852171073, 9.995147209020326, 8.993534189357348, 8.058997308243477, 7.036086453441336, 6.063642602557617, 5.063240357937374, 3.995112134724403, 2.9729793206795496, 2.012454847337615, 1.000033940604207, 0.0, 0.9623183311374136, 1.9988791520988318, 3.0287730277839247, 4.014088567653685, 4.989311981910575, 6.837284531824859, 7.888050367268672, 8.915934332801045, 9.862954857426514, 10.891415902062972, 9.89618074896799, 8.95189255063762, 7.930075767860963, 6.9250440278622305, 5.994622595640299, 4.9476729981946335, 3.984940257825692, 2.9439366104671683, 2.008184180345831, 1.0395424692416693, 1.9151840338005326, 2.866346394840982, 3.922049505903975, 4.941333875414551, 5.887287223270184, 7.734585928013002, 8.792699398789566, 9.816087601418705, 10.798706088906115, 11.797797673854852, 10.823312946145055, 9.925460045146306, 8.9261403536512, 7.97433438032258, 6.966769487394913, 5.895173228750971, 4.901777005574826, 3.9567668825222437, 3.024996122484006, 2.019166674449185, 2.8706541503064673, 3.8883682602771685, 4.829220589720563, 5.773787506054922, 6.739785710429801, 8.725471131199264, 9.73715611693444, 10.697808081600355, 11.7448160531204, 12.693111235224418, 11.76562884740723, 10.86037986529242, 9.896739986430134, 9.000753314909524, 7.955347826734316, 6.8837806768690415, 5.859034724258498, 4.884741701468695, 4.000412776608986, 2.9614618683023197, 3.8391965071600778, 4.8284618462463165, 5.841207473331623, 6.840212103572261, 7.666624151151644], [7.666484632232199, 6.847861128800148, 5.872366480075586, 4.925695485897897, 3.9094407230195056, 4.864554534066365, 5.891898347684343, 6.843735123549716, 7.783392260748816, 8.807818538494422, 9.861131214675424, 10.851548569026681, 11.783598569998855, 12.723100982525146, 13.64120383856287, 12.6712196316381, 11.713834152664509, 10.689461555436234, 9.703399860542344, 8.676662264192238, 8.685390409878774, 7.882378421038553, 6.8628793583795895, 5.967496886877443, 4.939470152198664, 5.84375645238362, 6.842025051304532, 7.834020865098178, 8.838938067141905, 9.844626135682248, 10.798021824112126, 11.758063897817276, 12.816873837544296, 13.685564572852519, 14.568331834133524, 13.653111140867242, 12.639281830153813, 11.719786391900513, 10.751489856374873, 9.7311707541391, 9.7291130629125, 8.788889163641663, 7.832129571813072, 6.865963851649418, 5.867123418842088, 6.879937063185503, 7.844755150640052, 8.866643660066996, 9.85537525884801, 10.862629979379005, 11.818867517576571, 12.74966050636574, 13.801930735936983, 14.741440494500404, 14.637138447532553, 14.196877464379504, 13.712216096673597, 12.692090976946464, 11.67688800745804, 10.769203264394367, 10.737393167783162, 9.799979102762865, 8.81597349312315, 7.930518218755143, 6.928960685244972, 7.863266209876879, 8.811746987329451, 9.802855521731674, 10.788405871889955, 11.76513126272442, 12.765582308421326, 13.738025372186389, 14.701928653282515, 14.630891803467371, 13.61723249159096, 13.185801195793125, 13.910405846158245, 13.656301348964023, 12.662722195802484, 11.760022881729316, 11.662968819206776, 10.738993024740516, 9.871955132668084, 8.920725053261409, 7.911222607005312, 8.919224903040881, 9.865717058389205, 10.806420457671079, 11.780531982014327, 12.724776455128296, 13.674416424516464, 14.677395072598939, 14.646083917327312, 13.658738603132178, 12.638403245361378, 12.124656333687337, 12.91130998440443, 13.840173334181632, 13.608584977665403, 12.71671163879875, 12.671070912602799, 11.767193130083024, 10.817955233647998, 9.892614904659546, 8.85378544362569, 9.881365230800977, 10.81854068459204, 11.768727324805543, 12.712485339649513, 13.640019151279228, 14.586166042934702, 14.499809103995535, 13.61931094860415, 12.690352000269026, 11.712541630343896, 11.155769864918927, 11.891069611512284, 12.849104500974441, 13.90119028282733, 13.621413971863475, 13.615101655397847, 12.766028466168997, 11.8917753145606, 10.893450246925847, 9.82455718127658, 10.851678672880096, 11.793300234075453, 12.807368087606326, 13.732990615591174, 14.58177305920119, 14.40503112012007, 13.47592349704902, 12.623250455643664, 11.7185584784174, 10.760061706914858, 10.08855605820016, 10.928815966877226, 11.873242563574546, 12.881634857130939, 13.624938638349477, 13.619126168310247, 13.748311140089399, 12.831347008104492, 11.821469505138584, 10.849913030155976, 11.877829499817093, 12.769591680966332, 13.788750071539491, 14.695910380476494, 14.50106159785339, 13.544460544493875, 12.543994091083405, 11.590089484930822, 10.714872771302904, 9.686703238799751, 9.034496873144386, 9.872241702108884, 10.811197026460906, 11.836562970736773, 12.687852408474932, 12.649707027673372, 13.662974669456577, 13.655975567327003, 12.727937976148977, 11.780673658655008, 12.785218191149823, 13.721499288380462, 14.748757477765178, 14.405488568277285, 13.465539237953207, 12.532417352782103, 11.564850059227808, 10.626203223695079, 9.686804618637346, 8.760829433715426, 8.006075451159145, 8.814092027551233, 9.879943222015715, 10.848148137091783, 11.72041380498985, 11.711627324913147, 12.676212103192178, 13.593098397006, 13.702294992936196, 12.74440611034232, 13.728856655443822, 14.702000586667928, 14.515166718304972, 13.471688830297758, 12.541033894878277, 11.563826355969471, 10.63865289723243, 9.699692662153561, 8.75308412182303, 7.766097529590103, 7.043957746694738, 7.8113966824911305, 8.88565531084065, 9.811251393287595, 10.739725279806821, 10.66540534812224, 11.667012885626455, 12.611132551709382, 13.680498212900613, 13.678148757634732, 14.651776627270856, 14.535024757790925, 13.543481957103362, 12.577602505219412, 11.690917446124661, 10.689452443854703, 9.78832261406104, 8.9346642895027, 7.8745758627417715, 6.808864300299965, 5.981248101553571, 6.847347089263117, 7.858969165390169, 8.74496839357122, 9.723020547134462, 9.792638214039505, 10.720591325985147, 11.738484200460091, 12.777103957978287, 13.737580172536788, 14.536048191230913, 13.60338505669984, 12.657939268927935, 11.62683849958941, 10.701717169337403, 9.738102885557176, 8.733353575311755, 7.864980253353039, 6.883146727873001, 5.848202868493228, 5.0048998216514144, 5.90854832952472, 6.835362158038063, 7.809615470463089, 8.837032835646589, 8.85919439545778, 9.779514291543727, 10.83289928602046, 11.817158378676986, 12.720158544695876, 13.609792184657646, 12.680022126234126, 11.688196644325986, 10.719179928282701, 9.699369281534945, 8.73134264330666, 7.80581631316703, 6.818738981642522, 5.887488395226233, 4.817057381467979, 3.933818993106689, 4.886418267689993, 5.875118650984671, 6.917799800073939, 7.8873691553215055, 7.859851932342823, 8.839246721969877, 9.859829065260051, 10.827948565018904, 11.767338982605523, 12.663750312514829, 11.715098588915149, 10.777424192816818, 9.905862679015389, 8.913184135482611, 7.88573000931574, 6.918422239330166, 5.882553255686898, 4.867768334980666, 3.881114500574413, 2.926180520899175, 3.9098880278378427, 4.898575404922422, 5.939120023665156, 6.88568946419911, 6.886969981441585, 7.8284953622871445, 8.874956643306414, 9.871151472545343, 10.796512968530376, 11.784441762816613, 10.821518629952578, 9.797023670662377, 8.841733779563764, 7.87305595677034, 6.914410957699182, 5.893339506060418, 4.87061196787938, 3.843747851381531, 2.916948403729276, 2.0002725677867863, 2.953783299989818, 3.958884335506188, 4.902790114795312, 5.939950768568884, 6.015069832213042, 7.039675707142296, 8.000035187011614, 9.063045069431404, 10.036576319818282, 10.988997514562506, 9.961169296122621, 8.961751400555428, 8.015150919994877, 6.951570578704509, 5.910995101148496, 4.964134361008048, 3.933314115348852, 2.9063704024479904, 1.9655095097892499, 0.9729363624478448, 1.9525606754850124, 2.9115173077185315, 3.9827771374760053, 4.969226135637185, 5.04869187268303, 5.994512701780476, 7.04213881913448, 8.100966885969887, 9.032828877882913, 9.955852520494762, 9.02131563938089, 7.99840478457875, 7.025960933695031, 6.0255586890747885, 4.957430465861817, 3.9352976518169633, 2.974773178475029, 1.9623522717416204, 0.9623183311374136, 0.0, 1.036560820961418, 2.0664546966465105, 3.051770236516271, 4.026993650773161, 5.874966200687445, 6.925732036131258, 7.953616001663631, 8.9006365262891, 9.944468819809988, 10.830855274800909, 9.88656707647054, 8.864750293693882, 7.85971855369515, 6.929297121473219, 5.882347524027553, 4.919614783658611, 3.8602829595303163, 2.8996257249862816, 1.928501351469217, 0.9528657026631191, 1.9040280637035685, 2.959731174766562, 3.9790155442771367, 4.92496889213277, 6.772267596875587, 7.830381067652151, 8.853769270281289, 9.8363877577687, 10.86141677618321, 11.757987471977975, 10.860134570979225, 9.860814879484119, 8.890680729385728, 7.883115836458062, 6.811519577814119, 5.818123354637974, 4.873113231585392, 3.9139550047115543, 2.9081255566767332, 1.908335819169054, 2.9260499291397544, 3.866902258583149, 4.811469174917508, 5.7774673792923865, 7.7631528000618495, 8.774837785797025, 9.735489750462941, 10.782497721982987, 11.730792904087004, 12.70030337324015, 11.79505439112534, 10.831414512263054, 9.917099663972671, 8.871694175797463, 7.8001270259321895, 6.775381073321646, 5.801088050531843, 4.889371658836534, 3.850420750529868, 2.8768781760226645, 3.8661435151089036, 4.878889142194208, 5.877893772434847, 6.70430582001423], [6.717638476063854, 5.899014972631805, 4.923520323907241, 4.111374740093719, 4.862919288932059, 5.818033099978919, 6.845376913596897, 7.797213689462271, 8.73687082666137, 9.761297104406975, 10.814609780587977, 11.805027134939234, 12.737077135911408, 13.676579548437699, 12.710851095590654, 11.722373475469757, 10.764987996496165, 9.74061539926789, 8.754553704374, 7.7278161080238945, 7.736544253710431, 6.933532264870209, 5.914033202211245, 5.153176141073265, 5.892948718111218, 6.797235018296174, 7.7955036172170855, 8.787499431010731, 9.79241663305446, 10.798104701594802, 11.751500390024681, 12.711542463729831, 13.770352403456851, 14.590685354609874, 13.637979091161307, 12.704264984698899, 11.69043567398547, 10.77094023573217, 9.802643700206529, 8.782324597970756, 8.780266906744156, 7.8501672553705, 6.893407663541909, 6.142963219417758, 6.820601984754642, 7.833415629098057, 8.798233716552605, 9.82012222597955, 10.808853824760565, 11.81610854529156, 12.772346083489126, 13.703139072278296, 14.755409301849538, 15.560570444015898, 14.586271670754137, 13.68675751398139, 12.763369940505253, 11.74324482077812, 10.728041851289696, 9.820357108226023, 9.798614951741442, 8.861257194491703, 7.877251584851988, 7.207517586523483, 7.882439251157526, 8.816744775789433, 9.765225553242004, 10.756334087644227, 11.741884437802508, 12.718609828636971, 13.719060874333877, 14.691503938098943, 15.65540721919507, 15.636878674471323, 14.623219362594911, 14.024046935754635, 13.095528309314503, 12.70745519279568, 11.71387603963414, 10.821244665687596, 10.724190603165056, 9.800271116469354, 8.933233224396922, 8.272036022221057, 8.864701172917865, 9.872703468953436, 10.819195624301758, 11.759899023583632, 12.73401054792688, 13.67825502104085, 14.627894990429017, 15.630873638511494, 15.652070788331264, 14.66472547413613, 13.64439011636533, 12.972411544321945, 12.096432447560689, 13.025295797337892, 12.65973882149706, 11.77793342275703, 11.732292696561078, 10.828471221811862, 9.879233325376836, 9.327082760212127, 9.807264009538242, 10.834843796713528, 11.772019250504592, 12.722205890718095, 13.665963905562066, 14.59349771719178, 15.539644608847254, 15.505795974999486, 14.625297819608102, 13.696338871272978, 12.718528501347848, 12.003525075553535, 11.076192074668544, 12.0342269641307, 13.070509276729034, 12.682635755821755, 12.676323439356127, 11.827306557897835, 10.953053406289438, 10.354500421227623, 10.778035747189133, 11.805157238792647, 12.746778799988004, 13.760846653518879, 14.686469181503726, 15.535251625113743, 15.411017991124021, 14.481910368052972, 13.629237326647617, 12.724545349421353, 11.76604857791881, 10.980500892454726, 10.113938430033485, 11.058365026730804, 12.050953851032641, 12.788767819207857, 12.782955349168628, 12.809589231818236, 11.935364483440875, 11.385577366809105, 11.80339159606853, 12.831308065729644, 13.723070246878883, 14.742228637452044, 15.649388946389047, 15.507048468857343, 14.550447415497828, 13.549980962087357, 12.596076355934775, 11.720859642306857, 10.692690109803703, 9.926441707398952, 9.057364165265144, 9.996319489617166, 11.000392151595156, 11.851681589333312, 11.813536208531753, 12.73216664495271, 12.97251416368469, 12.439218470932888, 12.734152224567561, 13.738696757062376, 14.674977854293015, 15.70223604367773, 15.411475439281238, 14.47152610895716, 13.538404223786056, 12.570836930231764, 11.632190094699032, 10.6927914896413, 9.766816304719377, 8.898020285413711, 7.999214490707494, 9.065065685171977, 10.011977317950166, 10.88424298584823, 10.875456505771528, 11.74540407868831, 12.662290372502133, 13.434813573005913, 13.697884676254873, 14.682335221356375, 15.655479152580481, 15.521153589308927, 14.477675701301713, 13.54702076588223, 12.569813226973425, 11.644639768236383, 10.705679533157515, 9.759070992826983, 8.772084400594055, 7.935902580949303, 6.996519145647392, 8.070777773996912, 8.975080574145977, 9.903554460665202, 9.82923452898062, 10.736204861122587, 11.680324527205514, 12.749690188396745, 13.750358227311619, 14.723986096947742, 15.54101162879488, 14.549468828107317, 13.583589376223367, 12.696904317128617, 11.695439314858659, 10.794309485064995, 9.940651160506656, 8.880562733745725, 7.814851171303919, 6.987234972557525, 6.0324695524193785, 7.044091628546431, 7.9087975744296015, 8.886849727992843, 8.893556803041328, 9.789783301481279, 10.807676175956223, 11.84629593347442, 12.778285599551985, 13.827762319910876, 14.609371927703796, 13.66392613993189, 12.632825370593364, 11.707704040341358, 10.74408975656113, 9.73934044631571, 8.870967124356994, 7.889133598876954, 6.854189739497182, 6.010886692655369, 5.093670792680982, 6.020484621194324, 6.97344465132147, 7.959560915440888, 7.899899822472979, 8.820219718558926, 9.87360471303566, 10.857863805692185, 11.760863971711073, 12.768748400335511, 13.716582947195544, 12.694183515329941, 11.725166799286656, 10.7053561525389, 9.737329514310614, 8.811803184170985, 7.824725852646476, 6.893475266230187, 5.823044252471933, 4.939805864110643, 4.0715407308462535, 5.0187846483004765, 5.987112241199792, 6.956681596447359, 6.9005573593580225, 7.879952148985076, 8.90053449227525, 9.868653992034103, 10.80804440962072, 11.822706528192693, 12.751659409876567, 11.813985013778236, 10.942423499976806, 9.949744956444029, 8.922290830277158, 7.92440911033412, 6.888540126690852, 5.8737552059846205, 4.8871013715783675, 3.9321673919031292, 3.017284781388802, 3.967887846048275, 5.008432464791009, 5.9550019053249645, 5.927675408456784, 6.869200789302344, 7.915662070321613, 8.911856899560542, 9.837218395545573, 10.833264653469339, 11.796187786333373, 10.833584491623794, 9.878294600525182, 8.909616777731758, 7.9509717786606, 6.929900327021835, 5.907172788840798, 4.849734722385485, 3.9229352747332302, 3.0062594387907406, 2.000521544919437, 3.005622580435807, 3.9495283597249315, 4.980656195584083, 5.012465721774705, 6.003114886180876, 6.963474366050194, 8.026484248469984, 9.000015498856861, 10.065921148456855, 10.95431623682498, 9.998312221516846, 9.051711740956295, 7.988131399665926, 6.947555922109913, 6.000695181969466, 4.96987493631027, 3.942931223409409, 2.971496380793204, 1.9789232334517992, 0.9992989204146318, 1.9582555526481507, 2.986289905972946, 3.9727389041341263, 4.012131051721611, 4.957951880819056, 6.00557799817306, 7.064406065008467, 7.996268056921493, 9.015068619530023, 9.949605500643894, 9.034965605540169, 8.06252175465645, 7.062119510036206, 5.993991286823235, 4.971858472778381, 4.011333999436447, 2.998913092703039, 1.9988791520988318, 1.036560820961418, 0.0, 1.0298938756850926, 2.0152094155548532, 2.9904328298117426, 4.838405379726027, 5.8891712151698385, 6.917055180702212, 7.864075705327681, 8.907907998848568, 9.903143151943551, 10.840045642383092, 9.818228859606435, 8.813197119607704, 7.882775687385774, 6.835826089940108, 5.873093349571166, 4.813761525442871, 3.853104290898836, 2.8819799173817717, 1.9063442685756735, 0.9551819075352239, 2.0108850185982172, 2.942454723315719, 3.8884080711713525, 5.823421440707243, 6.868153467086157, 7.891541669715295, 8.868096629397803, 9.893125647812314, 10.830275349120617, 11.813613136891778, 10.814293445396672, 9.844159295298283, 8.836594402370617, 7.7649981437266735, 6.771601920550529, 5.826591797497946, 4.867433570624109, 3.861604122589288, 2.8618143850816082, 1.97720377297141, 2.9180561024148046, 3.8626230187491633, 4.828621223124042, 6.814306643893505, 7.825991629628682, 8.786643594294597, 9.833651565814643, 10.78194674791866, 11.772591250382792, 12.748532957037893, 11.784893078175607, 10.870578229885226, 9.825172741710018, 8.753605591844744, 7.728859639234201, 6.754566616444397, 5.842850224749089, 4.803899316442423, 3.8303567419352182, 3.051822769304726, 3.930042986025864, 4.929047616266503, 5.755459663845885], [5.702764372153924, 4.968224485055341, 4.100478413017216, 5.091353554489797, 5.892813164617152, 6.847926975664012, 7.8752707892819895, 8.827107565147363, 9.766764702346464, 10.791190980092068, 11.844503656273071, 12.834921010624328, 13.662463813579244, 12.654071380643435, 11.68359784002042, 10.707499371559827, 9.750113892586235, 8.72574129535796, 7.739679600464071, 6.712942004113964, 6.7216701498005005, 6.023528831045365, 5.090991291321219, 6.03952851252491, 6.922842593796311, 7.827128893981267, 8.825397492902178, 9.817393306695825, 10.822310508739553, 11.827998577279896, 12.781394265709775, 13.741436339414925, 14.579859271456911, 13.563432099039641, 12.610725835591074, 11.689390880788968, 10.675561570075539, 9.756066131822239, 8.7877695962966, 7.767450494060826, 7.765392802834227, 7.027125344480474, 6.070365752651884, 7.029315590869403, 7.850495860439735, 8.86330950478315, 9.828127592237697, 10.850016101664641, 11.838747700445658, 12.846002420976653, 13.80223995917422, 14.73303294796339, 15.529292022883359, 14.533317188445665, 13.559018415183903, 12.67188341007146, 11.748495836595323, 10.728370716868191, 9.713167747379767, 8.805483004316093, 8.783740847831512, 8.038215283601676, 7.054209673961963, 7.982818693466613, 8.912333126842618, 9.846638651474526, 10.795119428927098, 11.78622796332932, 12.771778313487602, 13.748503704322065, 14.74895475001897, 15.721397813784037, 16.48360192801817, 15.52105348766242, 14.578924371125497, 13.556217791132593, 12.62769916469246, 11.69258108888575, 10.699001935724212, 9.806370561777666, 9.709316499255126, 8.977229205579327, 8.110191313506897, 9.047337129164188, 9.894595048602959, 10.90259734463853, 11.849089499986851, 12.789792899268726, 13.763904423611974, 14.708148896725943, 15.65778886611411, 16.660767514196586, 16.630904265480606, 15.643558951285474, 14.623223593514673, 13.89086217636719, 13.014883079605934, 12.250654298008502, 11.644864717587131, 10.7630593188471, 10.717418592651148, 10.005429310921837, 9.056191414486811, 9.98157833213065, 10.837157885223336, 11.864737672398622, 12.801913126189685, 13.75209976640319, 14.69585778124716, 15.623391592876875, 16.569538484532348, 16.48462945214883, 15.604131296757446, 14.675172348422322, 13.697361978497192, 12.92197570759878, 11.994642706713789, 11.252229311600889, 12.104740854915285, 11.667761651911825, 11.661449335446196, 11.00426464700781, 10.130011495399414, 11.008995993146147, 11.807929622874227, 12.835051114477741, 13.776672675673098, 14.790740529203973, 15.71636305718882, 16.565145500798838, 16.389851468273367, 15.460743845202316, 14.608070803796961, 13.703378826570697, 12.744882055068153, 11.898951524499973, 11.03238906207873, 10.276367374200994, 11.085185429218892, 11.822999397394108, 11.773441584190849, 11.986547320928212, 11.11232257255085, 12.04007293872763, 12.833285471753623, 13.861201941414738, 14.752964122563977, 15.772122513137138, 16.67928282207414, 16.485881946006685, 15.529280892647172, 14.528814439236701, 13.574909833084119, 12.699693119456201, 11.671523586953047, 10.844892339444199, 9.975814797310388, 9.214321837087354, 10.034623729781407, 10.885913167519563, 10.804022443553974, 11.702272769267617, 12.149472252794665, 13.07750984397269, 13.764046100252655, 14.76859063274747, 15.704871729978109, 16.732129919362826, 16.390308916430584, 15.450359586106504, 14.5172377009354, 13.549670407381107, 12.611023571848376, 11.671624966790644, 10.745649781868721, 9.816470917458958, 8.917665122752739, 8.142956526088321, 9.046208896136417, 9.918474564034481, 9.865942740793749, 10.715510203003218, 11.632396496817039, 12.613521573316234, 13.57141045591011, 14.582290343424335, 15.55543427464844, 16.497569068252858, 15.456509178451057, 14.525854243031574, 13.548646704122769, 12.623473245385727, 11.684513010306858, 10.737904469976327, 9.7509178777434, 8.85435321299455, 7.9149697776926375, 7.148668614913257, 8.009312152332228, 8.937786038851453, 8.819720764002842, 9.706310985437495, 10.65043065152042, 11.719796312711651, 12.720464351626525, 13.694092221262649, 14.615487447179188, 15.528302305256657, 14.562422853372707, 13.675737794277959, 12.674272792008, 11.773142962214337, 10.919484637655998, 9.859396210895067, 8.793684648453262, 7.935233585187145, 6.950920184464624, 6.117958993129695, 6.943029152615853, 7.921081306179095, 7.863662927356236, 8.759889425796187, 9.77778230027113, 10.816402057789329, 11.748391723866895, 12.797868444225786, 13.653649880248679, 14.599095668020585, 13.611658847742705, 12.686537517490699, 11.722923233710473, 10.718173923465052, 9.849800601506336, 8.867967076026297, 7.833023216646524, 6.989720169804712, 6.012121424726227, 5.085307596212885, 6.007676229507722, 6.99379249362714, 6.870005946787886, 7.790325842873834, 8.843710837350567, 9.827969930007093, 10.730970096025983, 11.73885452465042, 12.70638791342626, 13.63288493473235, 12.704000276435996, 11.684189629688241, 10.716162991459957, 9.790636661320328, 8.803559329795819, 7.872308743379529, 6.801877729621275, 5.918639341259986, 5.050374207995596, 4.079704860982782, 5.021343819386044, 5.990913174633611, 5.87066348367293, 6.850058273299984, 7.870640616590158, 8.838760116349011, 9.77815053393563, 10.792812652507603, 11.741464376107283, 12.679138772205613, 11.962264955408838, 10.96958641187606, 9.942132285709189, 8.903242587483463, 7.867373603840195, 6.8525886831339635, 5.86593484872771, 4.911000869052472, 3.996118258538145, 3.028808058730581, 4.042664042977261, 4.9892334835112155, 4.897781532771691, 5.839306913617252, 6.885768194636521, 7.88196302387545, 8.807324519860483, 9.803370777784249, 10.766293910648283, 11.790788869938485, 10.898136055957213, 9.929458233163789, 8.970813234092631, 7.919206641886964, 6.896479103705927, 5.828568199534828, 4.901768751882573, 3.9850929159400836, 2.97935502206878, 2.0665427931181126, 2.975495704151975, 3.95076231989899, 3.9825718460896113, 4.9732210104957835, 5.9335804903651015, 6.99659037278489, 7.970121623171768, 9.036027272771761, 9.92442236113989, 10.905969095737621, 10.081605616641387, 9.018025275351018, 7.977449797795005, 7.019123970524699, 5.988303724865504, 4.948474972063334, 3.950329857942547, 2.957756710601142, 1.9781323975639746, 1.0191757653304558, 1.9563960302878536, 2.9428450284490335, 2.9822371760365183, 3.928058005133964, 4.9756841224879675, 6.034512189323374, 6.9663741812364, 7.985174743844931, 8.919711624958802, 9.942622479760944, 9.092415630341542, 8.092013385721298, 7.023885162508327, 6.001752348463473, 5.041227875121539, 4.028806968388131, 3.028773027783924, 2.0664546966465105, 1.0298938756850926, 0.0, 0.9853155398697605, 1.9605389541266498, 3.8085115040409345, 4.859277339484747, 5.88716130501712, 6.834181829642589, 7.878014123163476, 8.87324927625846, 9.817537474588828, 10.839354257365486, 9.843090995292796, 8.912669563070866, 7.8657199656252, 6.902987225256258, 5.843655401127964, 4.882998166583929, 3.911873793066864, 2.936238144260766, 1.9850757832203165, 1.0251345393269098, 1.9125608476306264, 2.8585141954862596, 4.808547336797313, 5.838259591401065, 6.861647794030203, 7.83820275371271, 8.863231772127222, 9.800381473435525, 10.791104969097514, 11.835418843155722, 10.874053170983377, 9.866488278055709, 8.794892019411765, 7.8014957962356215, 6.856485673183039, 5.897327446309201, 4.89149799827438, 3.8917082607667006, 3.0070976486565026, 2.0950141915247786, 2.9318325311727005, 3.8137471192141117, 5.799432539983575, 6.8111175257187515, 7.771769490384667, 8.818777461904713, 9.76707264400873, 10.7426973746977, 11.72602478924363, 12.74592392538369, 11.90047210557032, 10.855066617395112, 9.783499467529838, 8.758753514919293, 7.78446049212949, 6.872744100434181, 5.833793192127515, 4.860250617620311, 4.081716644989819, 3.1070010751358383, 3.99825712869004, 4.740585559935955], [4.7174488322841635, 3.98290894518558, 4.8965481291297355, 5.887423270602317, 6.852268124905174, 7.807381935952034, 8.834725749570012, 9.812423105017125, 10.752080242216225, 11.77650651996183, 12.829819196142832, 13.742200998159662, 12.677148273709484, 11.668755840773676, 10.69828230015066, 9.722183831690066, 8.764798352716474, 7.740425755488198, 6.754364060594311, 5.727626464244204, 5.736354609930739, 5.0382132911756035, 5.887061007433739, 6.83559822863743, 7.8822975540843325, 8.786583854269288, 9.7848524531902, 10.776848266983848, 11.807626048609315, 12.813314117149655, 13.766709805579534, 14.653353671314171, 13.594543731587152, 12.578116559169882, 11.625410295721315, 10.704075340919207, 9.690246030205778, 8.770750591952478, 7.80245405642684, 6.782134954191065, 6.780077262964466, 6.072064744413493, 6.866435468764403, 7.825385306981922, 8.809950820727757, 9.82276446507117, 10.78758255252572, 11.809471061952664, 12.82406324031542, 13.831317960846414, 14.787555499043979, 15.596246712584842, 14.5439764830136, 13.548001648575905, 12.573702875314144, 11.6865678702017, 10.763180296725562, 9.74305517699843, 8.727852207510006, 7.820167464446332, 7.798425307961751, 7.083154683534696, 7.8502793900744825, 8.778888409579132, 9.818147921128507, 10.806093611762547, 11.754574389215119, 12.745682923617341, 13.731233273775622, 14.707958664610086, 15.708409710306992, 16.462189669244538, 15.498286388148411, 14.535737947792661, 13.593608831255738, 12.570902251262831, 11.642383624822699, 10.70726554901599, 9.71368639585445, 8.821055021907904, 8.724000959385364, 8.022168605512345, 8.906261029619417, 9.843406845276705, 10.800409842888847, 11.86205230492655, 12.808544460274872, 13.749247859556746, 14.723359383899995, 15.667603857013964, 16.61724382640213, 17.401559369657086, 16.486622184306086, 15.507891148127854, 14.57243807748532, 13.568531583929197, 12.60682216172146, 11.677958811944258, 10.65954917771737, 9.777743778977339, 9.732103052781387, 9.063135719756765, 9.85226113059933, 10.77764804824317, 11.742972679509224, 12.77055246668451, 13.707727920475573, 14.676257681672395, 15.65531274153518, 16.582846553164895, 17.52899344482037, 17.444530086031047, 16.53017280926003, 15.601213860924906, 14.623403490999776, 13.789518858052006, 12.862185857167015, 12.056928779071274, 11.119425315045525, 10.682446112042063, 10.676133795576435, 10.061971055842738, 10.926081211511933, 11.805065709258667, 12.713744417160115, 13.74086590876363, 14.682487469958986, 15.714898444473178, 16.675818017476843, 17.52460046108686, 17.349752102155584, 16.420644479084533, 15.567971437679176, 14.651496528333967, 13.670923567570737, 12.766494674953197, 11.899932212531956, 11.08106684167138, 10.099869889349133, 10.837683857524349, 10.788126044321087, 11.04425372976314, 11.90839228866337, 12.836142654840149, 13.739100266039511, 14.767016735700626, 15.658778916849865, 16.696280428406343, 17.638737782362163, 17.4457825798889, 16.489181526529386, 15.488715073118918, 14.534810466966334, 13.64781082121947, 12.59756509945563, 11.712435489897423, 10.843357947763614, 10.01902130455774, 9.049308189911647, 9.900597627649804, 9.818706903684213, 10.716957229397856, 11.680055922932574, 12.6080935141106, 13.549827367727662, 14.540613267848574, 15.476894365079213, 16.488933135451113, 17.3502095503128, 16.41026021998872, 15.477138334817615, 14.509571041263321, 13.570924205730591, 12.631525600672859, 11.671691294371305, 10.684014067912182, 9.785208273205965, 8.947655993558707, 8.060893356266657, 8.933159024164722, 8.880627200923987, 9.730194663133457, 10.64708095694728, 11.628206033446475, 12.58609491604035, 13.596974803554575, 14.570118734778681, 15.512253528383098, 16.41640981233327, 15.48575487691379, 14.508547338004984, 13.583373879267942, 12.644413644189074, 11.697805103858542, 10.710818511625614, 9.721896363447774, 8.782512928145863, 7.953368082383642, 7.023996612462468, 7.952470498981692, 7.834405224133081, 8.720995445567734, 9.66511511165066, 10.734480772841891, 11.735148811756765, 12.708776681392889, 13.630171907309425, 14.603487828094288, 15.54773839324247, 14.66105333414772, 13.659588331877762, 12.758458502084098, 11.890980363504683, 10.819296844777284, 9.753585282335477, 8.802776735640371, 7.81846333491785, 6.92265846060008, 5.957713612746092, 6.935765766309333, 6.878347387486476, 7.774573885926426, 8.79246676040137, 9.831086517919566, 10.763076183997132, 11.812552904356023, 12.668334340378916, 13.613780128150822, 14.596974387612468, 13.671853057360462, 12.708238773580234, 11.703489463334813, 10.835116141376098, 9.853282615896058, 8.818338756516285, 7.921019033200876, 6.879664575179453, 5.952850746666111, 5.022360689637961, 6.008476953757379, 5.884690406918126, 6.805010303004073, 7.858395297480806, 8.842654390137332, 9.74565455615622, 10.753538984780658, 11.721072373556497, 12.647569394862588, 13.616586110905873, 12.669505169558004, 11.701478531329718, 10.775952201190089, 9.78887486966558, 8.85762428324929, 7.787193269491036, 6.876384565414568, 5.935948394730687, 4.947248011436009, 4.036028279516283, 5.005597634763849, 4.885347943803169, 5.864742733430223, 6.885325076720397, 7.85344457647925, 8.792834994065867, 9.80749711263784, 10.75614883623752, 11.69382323233585, 12.745997661567262, 11.954901951745821, 10.92744782557895, 9.888558127353226, 8.852689143709958, 7.837904223003725, 6.851250388597471, 5.868746093207054, 4.8850385862683865, 3.8963512091838073, 3.0573485031075003, 4.003917943641455, 3.9124659929019305, 4.8539913737474905, 5.9004526547667595, 6.896647484005689, 7.822008979990721, 8.818055237914487, 9.780978370778522, 10.805473330068724, 11.760763221167336, 10.91477377303355, 9.956128773962392, 8.904522181756725, 7.881794643575688, 6.81388373940459, 5.887084291752334, 4.962779380643653, 3.948626670017995, 2.934085943571339, 1.9901801642822146, 2.9654467800292297, 2.9972563062198514, 3.9879054706260235, 4.948264950495342, 6.011274832915131, 6.984806083302009, 8.050711732902002, 8.93910682127013, 9.920653555867862, 10.924141525685368, 10.00334081522078, 8.962765337664766, 8.00443951039446, 6.973619264735265, 5.933790511933095, 4.9356453978123085, 3.943072250470903, 2.9634479374337355, 2.0044913052002165, 0.9710804904180931, 1.9575294885792731, 1.996921636166758, 2.942742465264204, 3.990368582618208, 5.049196649453615, 5.981058641366641, 6.999859203975172, 7.934396085089043, 8.957306939891184, 9.929750790774904, 9.07732892559106, 8.009200702378088, 6.987067888333234, 6.0265434149913, 5.014122508257892, 4.014088567653685, 3.0517702365162713, 2.0152094155548532, 0.9853155398697605, 0.0, 0.9752234142568894, 2.823195964171174, 3.873961799614986, 4.9018457651473595, 5.848866289772829, 6.892698583293717, 7.8879337363887, 8.832221934719069, 9.854038717495726, 10.828406535162557, 9.897985102940627, 8.851035505494961, 7.888302765126019, 6.828970940997724, 5.868313706453689, 4.897189332936625, 3.9215536841305267, 2.970391323090077, 1.975829169870801, 0.9272453077608659, 1.8731986556164992, 3.8232317969275518, 4.8529440515313045, 5.8763322541604435, 6.8528872138429495, 7.87791623225746, 8.815065933565766, 9.805789429227755, 10.850103303285962, 11.859368710853136, 10.85180381792547, 9.780207559281527, 8.786811336105382, 7.8418012130528, 6.876408633139462, 5.870579185104641, 4.851163221054723, 3.831936237080693, 2.8910839076372983, 1.9465169913029396, 2.8284315793443513, 4.814117000113814, 5.82580198584899, 6.786453950514906, 7.833461922034951, 8.781757104138968, 9.75738183482794, 10.74070924937387, 11.76060838551393, 12.70236379099943, 11.840382157264873, 10.7688150073996, 9.744069054789055, 8.769776031999251, 7.851825287264442, 6.812874378957776, 5.819705577908333, 4.906555233414009, 3.903070791248358, 3.0129415888202793, 3.7552700200661944], [3.8830310805462025, 4.842006335819133, 5.821343349256345, 6.8122184907289265, 7.827491539162064, 8.782605350208923, 9.8099491638269, 10.787646519274013, 11.727303656473113, 12.751729934218718, 13.75739493825403, 12.766977583902774, 11.701924859452596, 10.693532426516787, 9.72305888589377, 8.836743823011012, 7.884015226004001, 6.859642628775726, 5.882555298512627, 4.893208712506243, 4.901936858192778, 5.897310681809157, 6.811856227560349, 7.76039344876404, 8.820243842541872, 9.761807268526178, 10.760075867447089, 11.752071681240736, 12.782849462866203, 13.788537531406543, 14.638172330762433, 13.678130257057283, 12.619320317330262, 11.602893144912992, 10.650186881464425, 9.823292214206734, 8.809462903493305, 7.889967465240006, 6.930645294345156, 5.947717202453104, 5.945659511226505, 6.886814651049396, 7.791230688891013, 8.750180527108531, 9.747897109185297, 10.760710753528713, 11.762805966782608, 12.784694476209552, 13.799286654572308, 14.806541375103302, 15.551816287117122, 14.621023298327952, 13.56875306875671, 12.572778234319015, 11.598479461057254, 10.805784743489227, 9.882397170013089, 8.871246414916747, 7.856043445428323, 6.985749712708371, 6.96400755622379, 7.897904590170599, 8.775074610201093, 9.703683629705743, 10.742943141255118, 11.74403990022009, 12.692520677672661, 13.683629212074884, 14.669179562233165, 15.645904953067628, 16.555141585012148, 15.486966254987648, 14.523062973891522, 13.560514533535772, 12.618385416998848, 11.699093489181148, 10.770574862741016, 9.835456786934307, 8.841877633772768, 7.986637270169943, 7.889583207647404, 8.836918512148248, 9.831056249746027, 10.768202065403317, 11.725205063015459, 12.791013232930663, 13.746490748732414, 14.687194148014289, 15.661305672357537, 16.605550145471504, 17.49345527973158, 16.426335955400198, 15.511398770049196, 14.532667733870964, 13.59721466322843, 12.696722821847512, 11.735013399639776, 10.806150049862573, 9.787740415635687, 8.94332602723938, 8.897685301043428, 9.877885626392668, 10.77705635072594, 11.70244326836978, 12.667767899635836, 13.695347686811122, 14.632523140602185, 15.601052901799006, 16.593259029992723, 17.520792841622438, 18.33966698051142, 17.38726557925378, 16.429845596506166, 15.500886648171042, 14.523076278245911, 13.665609290615922, 12.75525377253192, 11.788419013832993, 10.735422443093249, 9.848028360304104, 9.841716043838476, 10.855888092794295, 11.817070569386413, 12.729860929385275, 13.638539637286726, 14.66566112889024, 15.607282690085597, 16.63969366459979, 17.613764305934385, 18.4625467495444, 18.324975516412472, 17.39586789334142, 16.543194851936068, 15.626719942590857, 14.646146981827627, 13.741718089210087, 12.875155626788848, 11.943445173849213, 10.93505288029282, 10.002497958725748, 9.879408240469854, 10.828836219994521, 11.808487799325155, 12.753016814383148, 13.571870192375458, 14.621865221991326, 15.601169718653793, 16.584263353607465, 17.564149780262703, 18.42100599414579, 17.464404940786277, 16.463938487375806, 15.510033881223224, 14.62303423547636, 13.57278851371252, 12.687658904154313, 11.818581362020506, 10.99424471881463, 10.024531604168537, 9.065411728851203, 8.909989099832979, 9.808239425546624, 10.77133811908134, 11.699375710259366, 12.641109563876427, 13.631895463997338, 14.568176561227977, 15.580215331599875, 16.54478596761938, 17.38548363424561, 16.452361749074505, 15.484794455520213, 14.546147619987481, 13.606749014929749, 12.646914708628195, 11.659237482169072, 10.760431687462855, 9.922879407815596, 9.036116770523547, 8.09797312536612, 7.9719093970727535, 8.821476859282225, 9.738363153096046, 10.719488229595239, 11.677377112189115, 12.68825699970334, 13.661400930927446, 14.603535724531863, 15.565571125159378, 16.46097829117068, 15.483770752261874, 14.558597293524832, 13.619637058445964, 12.673028518115432, 11.686041925882504, 10.697119777704664, 9.757736342402753, 8.928591496640532, 7.999220026719358, 7.117284600183092, 6.9256874202818475, 7.812277641716501, 8.756397307799427, 9.825762968990658, 10.82643100790553, 11.800058877541654, 12.697411955213468, 13.67072787599833, 14.63660732788228, 15.633740540660789, 14.63481174613465, 13.733681916340986, 12.866203777761571, 11.794520259034172, 10.728808696592367, 9.778000149897261, 8.79368674917474, 7.89788187485697, 6.932937027002982, 6.100579867510733, 5.969629583635242, 6.865856082075192, 7.883748956550135, 8.922368714068332, 9.830316231901174, 10.879792952260065, 11.735574388282958, 12.681020176054863, 13.70902330012158, 14.634144630373585, 13.683462187837122, 12.678712877591702, 11.810339555632986, 10.828506030152948, 9.793562170773175, 8.896242447457766, 7.854887989436342, 6.928074160923, 5.997584103894851, 5.170292619717231, 4.975972603066892, 5.896292499152839, 6.949677493629572, 7.927976339557806, 8.812894604060261, 9.8207790326847, 10.788312421460539, 11.71480944276663, 12.683826158809914, 13.644728583814892, 12.676701945586606, 11.751175615446977, 10.764098283922468, 9.83284769750618, 8.762416683747926, 7.851607979671457, 6.911171808987576, 5.922471425692898, 5.011251693773173, 4.167413300723702, 3.976630139951935, 4.956024929578989, 5.970647026140871, 6.938766525899724, 7.860075041969909, 8.874737160541882, 9.823388884141561, 10.761063280239892, 11.813237709471304, 12.842428443219701, 11.90267123983584, 10.863781541610114, 9.827912557966846, 8.813127637260614, 7.826473802854361, 6.843969507463943, 5.8602620005252755, 4.871574623440696, 4.03257191736439, 3.111837126755946, 3.0037481890506967, 3.945273569896257, 4.9676927026708, 5.96388753190973, 6.8892490278947625, 7.885295285818529, 8.848218418682563, 9.872713377972765, 10.828003269071377, 11.796681091864802, 10.931352188219282, 9.879745596013615, 8.857018057832578, 7.7891071536614795, 6.862307706009224, 5.938002794900543, 4.923850084274885, 3.9093093578282283, 2.965403578539104, 2.0567289761779954, 2.0220328919629615, 3.012682056369134, 3.973041536238452, 5.036051418658241, 6.009582669045119, 7.075488318645112, 7.963883407013239, 8.945430141610972, 9.948918111428478, 10.954003357101406, 9.937988751921656, 8.97966292465135, 7.948842678992154, 6.909013926189984, 5.9108688120691975, 4.9182956647277924, 3.938671351690625, 2.979714719457106, 1.9463039046749824, 1.048811684728039, 1.0216982219098687, 1.9675190510073144, 3.015145168361318, 4.073973235196725, 5.005835227109751, 6.024635789718282, 6.959172670832153, 7.982083525634294, 8.954527376518014, 9.954929621138257, 8.984424116634978, 7.962291302590124, 7.00176682924819, 5.989345922514781, 4.989311981910574, 4.026993650773161, 2.990432829811742, 1.9605389541266498, 0.9752234142568894, 0.0, 1.987804870179148, 2.898738385358097, 3.92662235089047, 4.873642875515939, 5.917475169036827, 6.91271032213181, 7.85699852046218, 8.878815303238838, 9.88384704323757, 10.8142684754595, 9.82625891975185, 8.863526179382909, 7.804194355254614, 6.843537120710579, 5.872412747193514, 4.896777098387416, 3.945614737346966, 2.95105258412769, 1.9024687220177552, 1.038780903878538, 2.9888140451895904, 3.877720637274415, 4.901108839903554, 5.87766379958606, 6.90269281800057, 7.839842519308876, 8.830566014970866, 9.874879889029074, 10.925985615688326, 11.827027232182358, 10.755430973538415, 9.76203475036227, 8.817024627309689, 7.851632047396352, 6.845802599361531, 5.8263866353116125, 4.8071596513375825, 3.8663073218941877, 2.921740405559829, 1.99401382760639, 3.9796992483758524, 4.945018859136518, 5.905670823802433, 6.8786342050170735, 7.8269293871210905, 8.78215842057105, 9.765485835116982, 10.785384971257042, 11.727140376742542, 12.772545864917749, 11.744038421656487, 10.719292469045943, 9.74499944625614, 8.827048701521333, 7.788097793214666, 6.7949289921652225, 5.881778647670899, 4.878294205505247, 3.9794717792800487, 2.920852268328233], [3.794247485222339, 4.75322274049527, 5.732559753932482, 6.723434895405063, 7.751669535036111, 8.70678334608297, 9.734127159700947, 10.748602642108528, 11.688259779307629, 12.712686057053233, 11.919309803123197, 10.92889244877194, 9.863839724321762, 8.855447291385953, 7.884973750762937, 6.932151634074807, 5.974766155101216, 4.950393557872941, 3.973306227609842, 3.0258593512022784, 4.813153262868916, 5.808527086485293, 6.7230726322364855, 7.671609853440176, 8.73146024721801, 9.685985264400225, 10.684253863321135, 11.676249677114782, 12.72801230290819, 13.74949365424106, 12.800087195631598, 11.840045121926448, 10.781235182199428, 9.764808009782158, 8.81210174633359, 7.91404314330395, 6.90021383259052, 5.980718394337221, 5.0213962234423715, 4.0846209590895235, 5.856875915902642, 6.7980310557255335, 7.70244709356715, 8.661396931784669, 9.659113513861435, 10.671927158204848, 11.686983962656655, 12.708872472083598, 13.724535460865978, 14.731790181396972, 13.713731151986288, 12.782938163197118, 11.730667933625876, 10.734693099188181, 9.76039432592642, 8.896535672586442, 7.973148099110304, 6.961997344013962, 5.946794374525538, 5.12265346934479, 6.875223960899928, 7.809120994846737, 8.686291014877229, 9.61490003438188, 10.654159545931254, 11.655256304896225, 12.603737082348797, 13.59484561675102, 14.5803959669093, 15.557121357743764, 14.717056449881314, 13.648881119856814, 12.684977838760688, 11.722429398404937, 10.780300281868014, 9.789844418278363, 8.861325791838231, 7.926207716031522, 6.932628562869983, 6.183193077277724, 7.800799612323542, 8.748134916824387, 9.742272654422163, 10.679418470079453, 11.636421467691594, 12.702229637606798, 13.65770715340855, 14.598410552690424, 15.572522077033673, 16.51676655014764, 15.655370144600745, 14.588250820269364, 13.673313634918362, 12.69458259874013, 11.759129528097596, 10.787473750944727, 9.825764328736991, 8.896900978959788, 7.878491344732902, 7.153411893223756, 8.808901705719565, 9.789102031068808, 10.688272755402076, 11.613659673045916, 12.578984304311971, 13.606564091487257, 14.54373954527832, 15.512269306475142, 16.50447543466886, 17.432009246298573, 16.50158184538059, 15.549180444122946, 14.591760461375332, 13.662801513040208, 12.684991143115077, 11.756360219713137, 10.846004701629136, 9.879169942930208, 8.826173372190464, 8.214083393277322, 9.752932448514613, 10.767104497470433, 11.72828697406255, 12.64107733406141, 13.549756041962862, 14.576877533566376, 15.518499094761733, 16.550910069275925, 17.52498071061052, 18.373763154220537, 17.50217367414051, 16.57306605106946, 15.65746423232989, 14.667245020249375, 13.637471066544116, 12.823574026431904, 11.808258346264195, 10.854121091443249, 9.845728797886856, 9.143513723040163, 9.901346002084713, 10.850773981609379, 11.830425560940014, 12.774954575998008, 13.59380795399032, 14.643802983606188, 15.623107480268654, 16.606201115222326, 17.586087541877564, 18.42460946430141, 18.46347937911463, 17.504995457035076, 16.690625203042732, 15.67093072736387, 14.710829534659222, 13.784708553009548, 12.85512195290891, 11.916166628556887, 10.896290497324342, 10.080599952914708, 8.931926861447838, 9.830177187161482, 10.7932758806962, 11.721313471874225, 12.663047325491288, 13.6538332256122, 14.590114322842838, 15.602153093214737, 16.56672372923424, 17.386394964251327, 18.30033429898879, 17.332767005434498, 16.39412016990177, 15.454721564844034, 14.49488725854248, 13.507210032083357, 12.60840423737714, 11.77085195772988, 10.88408932043783, 9.874853229291906, 7.993847158687612, 8.843414620897082, 9.760300914710905, 10.7414259912101, 11.699314873803976, 12.710194761318201, 13.683338692542307, 14.625473486146724, 15.50997955151879, 16.440634486938272, 17.331743302176157, 16.406569843439115, 15.467609608360249, 14.521001068029717, 13.53401447579679, 12.54509232761895, 11.605708892317038, 10.776564046554816, 9.847192576633642, 8.894164704108878, 6.947625181896706, 7.83421540333136, 8.778335069414286, 9.847700730605517, 10.814294321508672, 11.78023505416742, 12.641820381572877, 13.61513630235774, 14.58101575424169, 15.5781489670202, 16.482784296048933, 15.581654466255271, 14.714176327675856, 13.642492808948457, 12.576781246506652, 11.625972699811546, 10.641659299089024, 9.745854424771254, 8.780909576917267, 7.877459971436518, 5.9915673452501, 6.8877938436900505, 7.9056867181649935, 8.905691659395393, 9.774724658260585, 10.824201378619476, 11.679982814642369, 12.625428602414274, 13.653431726480989, 14.578553056732995, 15.531434737751407, 14.526685427505987, 13.658312105547271, 12.676478580067231, 11.641534720687458, 10.744214997372051, 9.702860539350628, 8.776046710837285, 7.845556653809135, 6.947172723643016, 4.997910364681751, 5.9182302607676975, 6.955730921591329, 7.872384765917217, 8.757303030419672, 9.76518745904411, 10.73272084781995, 11.65921786912604, 12.628234585169325, 13.64804523191708, 14.524674495500891, 13.599148165361262, 12.612070833836754, 11.680820247420463, 10.61038923366221, 9.699580529585743, 8.759144358901862, 7.770443975607183, 6.859224243687457, 6.031620525031262, 3.9985679015667936, 4.977962691193848, 5.915055452500282, 6.883174952259135, 7.80448346832932, 8.819145586901293, 9.767797310500972, 10.705471706599303, 11.757646135830715, 12.786836869579112, 13.671053568911928, 12.7117540915244, 11.67588510788113, 10.661100187174899, 9.674446352768644, 8.69194205737823, 7.708234550439561, 6.719547173354981, 5.880544467278674, 4.976044351063507, 3.0256859506655553, 3.9672113315111157, 4.912101129030211, 5.908295958269141, 6.8336574542541735, 7.82970371217794, 8.792626845041974, 9.817121804332176, 10.772411695430788, 11.741089518224213, 12.69973451729537, 11.708865338205822, 10.686137800024785, 9.637079703575763, 8.710280255923507, 7.785975344814827, 6.771822634189169, 5.757281907742513, 4.813376128453388, 3.972705163538256, 1.9664413183223723, 2.9570904827285442, 3.917449962597863, 4.980459845017652, 5.95399109540453, 7.019896745004523, 7.90829183337265, 8.889838567970383, 9.893326537787889, 10.89841178346082, 11.726520933293902, 10.779660193153454, 9.748839947494258, 8.756986476104268, 7.758841361983482, 6.766268214642077, 5.786643901604909, 4.82768726937139, 3.794276454589267, 3.012285014898229, 0.9661066482692793, 1.911927477366725, 2.959553594720729, 4.018381661556136, 4.950243653469162, 5.969044216077693, 6.903581097191564, 7.926491951993705, 8.898935802877425, 9.899338047497668, 10.772956298007223, 9.75082348396237, 8.790299010620435, 7.837318472429066, 6.837284531824859, 5.874966200687446, 4.838405379726027, 3.8085115040409345, 2.823195964171174, 1.987804870179148, 0.0, 1.060653250227262, 2.0885372157596356, 3.0355577403851046, 4.079390033905992, 5.074625187000975, 6.018913385331345, 7.040730168108002, 8.045761908106734, 8.976183340328664, 9.88088181198812, 8.918149071619178, 7.858817247490883, 6.898160012946848, 5.927035639429784, 4.951399990623686, 4.0002376295832365, 2.944534518520243, 1.8959506564103081, 0.9499973085546749, 1.0128579046053412, 2.0396355021435806, 3.063023704772719, 4.039578664455226, 5.064607682869736, 6.001757384178041, 6.9924808798400315, 8.036794753898238, 9.08790048055749, 10.01213357937874, 10.718769207256239, 9.725372984080094, 8.780362861027513, 7.801120078493929, 6.795290630459108, 5.775874666409189, 4.756647682435159, 3.8157953529917643, 2.8712284366574057, 1.9052302322825267, 2.0240848024985567, 3.035769788233733, 3.9964217528996486, 5.040549069886239, 5.9888442519902565, 6.944073285440217, 7.927400699986148, 8.947299836126207, 9.889055241611707, 10.934460729786915, 11.704994544491003, 10.680248591880458, 9.705955569090655, 8.77653673261891, 7.737585824312243, 6.744417023262799, 5.8312666787684755, 4.827782236602824, 3.8906881839561858, 2.83206867300437], [4.854900735449601, 5.813875990722532, 6.793213004159744, 7.784088145632325, 8.812322785263374, 9.767436596310233, 10.794780409928212, 11.80925589233579, 12.74891302953489, 11.911969229076936, 10.858656552895933, 9.868239198544677, 8.803186474094499, 7.794794041158689, 6.824320500535674, 5.938005437652915, 4.985276840645904, 3.9609042434176285, 2.98381691315453, 4.010554509504637, 5.873806513096177, 6.869180336712556, 7.783725882463748, 8.732263103667439, 9.792113497445271, 10.746638514627488, 11.7449071135484, 12.736902927342047, 13.76521593821757, 12.692829633834215, 11.739433945404336, 10.779391871699186, 9.720581931972166, 8.704154759554896, 7.751448496106329, 6.924553828848638, 5.910724518135208, 4.991229079881909, 4.031906908987059, 5.069316117391882, 6.917529166129904, 7.858684305952795, 8.763100343794411, 9.72205018201193, 10.719766764088696, 11.73258040843211, 12.74763721288392, 13.769525722310863, 14.680545892042291, 13.673291171511297, 12.653077901759026, 11.722284912969856, 10.670014683398614, 9.67403984896092, 8.699741075699158, 7.907046358131129, 6.983658784654992, 5.97250802955865, 4.957305060070226, 5.90913438974206, 7.935877211127189, 8.869774245073998, 9.74694426510449, 10.67555328460914, 11.714812796158515, 12.715909555123487, 13.664390332576058, 14.65549886697828, 15.633579636185424, 14.65685424535096, 13.656403199654052, 12.588227869629552, 11.624324588533426, 10.661776148177676, 9.719647031640752, 8.800355103823051, 7.871836477382919, 6.93671840157621, 5.943139248414671, 6.951721932336751, 8.861452862550802, 9.808788167051649, 10.802925904649424, 11.740071720306714, 12.697074717918856, 13.76288288783406, 14.718360403635812, 15.659063802917686, 16.488601336875618, 15.544356863761651, 14.594716894373484, 13.527597570042103, 12.6126603846911, 11.633929348512869, 10.698476277870334, 9.797984436489415, 8.836275014281679, 7.907411664504477, 6.88900203027759, 7.921940748282783, 9.749770396416396, 10.811510086895552, 11.748926005629338, 12.674312923273177, 13.639637554539233, 14.667217341714519, 15.604392795505582, 16.5729225567024, 17.314609298438516, 16.3870754868088, 15.440928595153329, 14.488527193895685, 13.53110721114807, 12.602148262812946, 11.624337892887816, 10.766870905257825, 9.856515387173824, 8.889680628474895, 7.836684057735152, 8.79942733715572, 10.693801139211445, 10.876450184973944, 11.837632661566062, 12.844627139473637, 13.662557332313876, 14.713347339987344, 15.642792456603694, 16.613775844513118, 17.575200052120515, 17.328829394730764, 16.44152042391325, 15.512412800842199, 14.596810982102628, 13.606591770022114, 12.576817816316854, 11.834084711976592, 10.818769031808882, 9.864631776987936, 8.856239483431544, 9.728857666918561, 10.768919141914466, 9.894167511053542, 10.873819090384174, 11.818348105442167, 12.63720148343448, 13.687196513050347, 14.666501009712814, 15.632393860579954, 16.612280287235194, 17.443901321285463, 17.40282612888737, 16.444342206807814, 15.62997195281547, 14.61027747713661, 13.65017628443196, 12.795219238554235, 11.865632638453597, 10.926677314101575, 9.90680118286903, 10.665943896793106, 9.799500001277591, 8.873570716605643, 9.83666941014036, 10.764707001318385, 11.706440854935448, 12.69722675505636, 13.633507852286998, 14.628345838572365, 15.59291647459187, 16.40568682123538, 17.338808706406486, 17.466705039425808, 16.544759863480994, 15.605361258423262, 14.576050089516286, 13.823640660539477, 12.923782313011248, 11.962033633331233, 10.89521601651402, 10.742426369121658, 8.861420298517366, 7.886808150341243, 8.803694444155065, 9.78481952065426, 10.742708403248136, 11.75358829076236, 12.709531437899935, 13.651666231504352, 14.529271408502845, 15.459926343922326, 16.43713388283113, 17.362307341568172, 16.464375703254863, 15.517767162924333, 14.530780570691405, 13.541858422513565, 12.602474987211654, 11.71873973446706, 10.776505591949066, 9.76173784393863, 7.815198321726459, 6.87760893277552, 7.821728598858446, 8.891094260049677, 9.833586178492727, 10.799526911151476, 11.661112238556935, 12.634428159341796, 13.600307611225746, 14.597440824004256, 15.529063849883103, 16.507890021303073, 15.710942422570474, 14.639258903843075, 13.573547341401268, 12.622738794706162, 11.63842539398364, 10.6880301126835, 9.723085264829512, 8.74503311126627, 6.859140485079854, 5.931187373134211, 6.949080247609154, 7.92498351637945, 8.79401651524464, 9.843493235603532, 10.699274671626425, 11.64472045939833, 12.672723583465046, 13.597844913717053, 14.577714291585576, 15.488427319413777, 14.709077940991083, 13.72511721703109, 12.690173357651316, 11.740981092266667, 10.699626634245243, 9.7728128057319, 8.798559493306874, 7.814745863472769, 5.908843879860699, 4.961623790211858, 5.975022778575386, 6.891676622901274, 7.7765948874037285, 8.784479316028166, 9.752012704804006, 10.678509726110097, 11.647526442153382, 12.667337088901137, 13.635363727129423, 14.560890057269052, 13.662836669280566, 12.731586082864276, 11.661155069106021, 10.750346365029555, 9.809910194345674, 8.821209811050995, 7.812227083185195, 6.9425540402102115, 4.9095014167457425, 4.021356220638008, 4.934347309484339, 5.902466809243192, 6.823775325313376, 7.838437443885349, 8.787089167485028, 9.724763563583359, 10.776937992814771, 11.806128726563168, 12.690345425895984, 13.733786791486601, 12.726650943324943, 11.711866022618711, 10.725212188212456, 9.742707892822041, 8.759000385883374, 7.7703130087987935, 6.833547306776412, 5.886977866242456, 3.9366194658445037, 3.010604860955276, 3.9313929860142682, 4.927587815253197, 5.85294931123823, 6.848995569161996, 7.811918702026031, 8.836413661316232, 9.791703552414845, 10.760381375208269, 11.719026374279427, 12.769518588433087, 11.74679105025205, 10.687845539019575, 9.76104609136732, 8.83674118025864, 7.822588469632981, 6.808047743186325, 5.864141963897201, 4.883638678717205, 2.877374833501321, 1.976382339712602, 2.9367418195819206, 3.9997517020017095, 4.973282952388588, 6.039188601988581, 6.9264338936779515, 7.907980628275684, 8.91146859809319, 9.916553843766117, 10.931893222030515, 11.840313443380717, 10.80949319772152, 9.80775231154808, 8.809607197427294, 7.817034050085889, 6.837409737048721, 5.878453104815202, 4.84504229003308, 3.923218530077178, 1.877040163448228, 0.9312193343507824, 1.9788454517047864, 3.0376735185401933, 3.9695355104532193, 4.987186276382994, 5.921723157496865, 6.944634012299006, 7.917077863182725, 8.917480107802968, 9.978328586743837, 10.811476734189633, 9.850952260847698, 8.888084307872878, 7.888050367268671, 6.925732036131258, 5.889171215169839, 4.859277339484747, 3.873961799614986, 2.898738385358097, 1.060653250227262, 0.0, 1.0278839655323733, 1.9749044901578423, 3.0187367836787296, 4.013971936773713, 4.958260135104083, 5.98007691788074, 6.985108657879472, 7.915530090101403, 8.962479687547068, 9.92521242791601, 8.919470497718146, 7.958813263174111, 6.987688889657046, 6.012053240850948, 5.060890879810499, 4.005187768747506, 2.9566039066375707, 2.010650558781937, 2.037095722692882, 0.9789822519163184, 2.002370454545457, 2.9789254142279633, 4.003954432642475, 4.941104133950779, 5.931827629612769, 6.976141503670975, 8.027247230330227, 8.951480329151478, 9.977224396280631, 10.786026234307355, 9.841016111254774, 8.86177332872119, 7.855943880686369, 6.8365279166364505, 5.817300932662421, 4.876448603219027, 3.931881686884668, 2.9658834825097893, 3.048322620586097, 2.0462804737784204, 3.006932438444336, 3.979895819658977, 4.928191001762994, 5.883420035212954, 6.8667474497588845, 7.886646585898943, 8.828401991384444, 9.873807479559652, 10.945374629424926, 11.74090184210772, 10.766608819317916, 9.837189982846171, 8.798239074539504, 7.8050702734900606, 6.891919928995738, 5.888435486830086, 4.951341434183448, 3.8927219232316324], [5.882784700981975, 6.841759956254905, 7.8210969696921175, 8.8119721111647, 9.840206750795748, 10.795320561842606, 11.822664375460583, 12.772098136198297, 11.905598456666254, 10.884085263544563, 9.83077258736356, 8.840355233012303, 7.775302508562126, 6.766910075626316, 5.796436535003301, 4.910121472120542, 3.9813200351875615, 2.9845732602396122, 3.9287898593083446, 4.955527455658451, 6.9016904786285505, 7.897064302244929, 8.81160984799612, 9.760147069199812, 10.819997462977645, 11.774522480159861, 12.772791079080772, 13.764786892874419, 12.7373319726852, 11.664945668301844, 10.711549979871965, 9.751507906166815, 8.692697966439793, 7.676270794022523, 6.723564530573956, 5.916002276669179, 4.906767712676865, 4.0148980967038925, 4.976879855140874, 6.0142890635456965, 7.89955668947945, 8.840711829302341, 9.790984309326785, 10.749934147544304, 11.74765072962107, 12.760464373964485, 13.775521178416291, 14.668324915292299, 13.65266192650992, 12.645407205978925, 11.625193936226655, 10.694400947437485, 9.642130717866243, 8.646155883428548, 7.671857110166786, 6.898494805951671, 5.9797019791966495, 5.028299941729161, 5.902278006224041, 6.854107335895875, 8.917904734476735, 9.851801768423543, 10.774828230636864, 11.703437250141514, 12.742696761690889, 13.743793520655862, 14.692274298108433, 15.591246020811333, 14.605695670653052, 13.628970279818589, 12.628519234121681, 11.56034390409718, 10.596440623001055, 9.633892182645305, 8.69176306610838, 7.83725451613944, 6.908735889699308, 6.056007975522389, 6.888112194568485, 7.896694878490566, 9.84348038590035, 10.790815690401192, 11.819120746430835, 12.767955685839087, 13.724958683451229, 14.790766853366431, 15.746244369168187, 16.531724568721668, 15.460717371343248, 14.51647289822928, 13.566832928841112, 12.499713604509731, 11.584776419158729, 10.606045382980497, 9.670592312337961, 8.86954117366086, 7.907831751453123, 7.105659601644712, 7.833974976431405, 8.866913694436597, 10.694743342570211, 11.756483033049367, 12.128616101108125, 13.044395276861167, 13.654860837447767, 14.682440624623055, 15.619616078414118, 16.588145839610938, 16.286725332906148, 15.359191521276431, 14.413044629620957, 13.460643228363313, 12.503223245615697, 11.574264297280573, 10.596453927355443, 9.83842764242927, 8.928072124345267, 8.104084588052325, 8.781657003888967, 9.744400283309535, 11.63877408536526, 11.816325735638554, 11.054796020195523, 12.016977615845672, 12.684089099796877, 13.734879107470345, 14.664324224086695, 15.610687189459115, 16.57211139706651, 16.300945429198393, 15.413636458380877, 14.484528835309828, 13.568927016570255, 12.57870780448974, 11.548933850784481, 10.905641449148037, 9.890325768980325, 9.07994652545222, 9.801212429585359, 10.673830613072376, 11.708794692579076, 10.834043061718152, 10.072484943044087, 10.98590067026419, 11.65873325091748, 12.708728280533348, 13.688032777195815, 14.62930520552595, 15.60919163218119, 16.44081266623146, 16.374942163354994, 15.416458241275443, 14.602087987283097, 13.582393511604236, 12.622292318899587, 11.876486633849305, 10.946900033748667, 10.141992062565858, 10.851774129022845, 11.61091684294692, 10.739375551942201, 9.813446267270253, 9.035335262800272, 9.932259566140408, 10.727972622418449, 11.71875852253936, 12.65503961977, 13.625257183518361, 14.589827819537867, 15.402598166181377, 16.33572005135248, 16.438821073893436, 15.516875897948621, 14.577477292890888, 13.548166123983913, 12.904908055834547, 12.005049708306316, 11.213357373564891, 11.840188962667835, 11.682301919786267, 9.801295849181976, 8.826683701005853, 8.002360296814977, 8.936664464067382, 9.764240170731137, 10.775120058245362, 11.706442782845931, 12.648577576450348, 13.526182753448841, 14.456837688868323, 15.434045227777128, 16.359218686514172, 16.457806330035737, 15.511197789705205, 14.542898028109235, 13.867025760298954, 13.007745053366419, 12.207645284739955, 11.716381142613676, 10.701613394603239, 8.755073872391069, 7.81748448344013, 7.020394451518358, 7.908919609346108, 8.830497523438725, 9.79643825609747, 10.658023583502931, 11.631339504287793, 12.597218956171742, 13.594352168950252, 14.5259751948291, 15.504801366249067, 16.45101713641462, 15.622738189857081, 14.557026627415274, 13.606218080720168, 12.621904679997646, 11.627905663348109, 10.662960815494122, 9.68490866193088, 7.799016035744463, 6.871062923798821, 6.040050580674092, 6.931285634907555, 7.790927860190638, 8.840404580549526, 9.69618601657242, 10.641631804344327, 11.669634928411043, 12.594756258663049, 13.574625636531572, 14.485338664359773, 15.5563332402171, 14.708596503045095, 13.673652643665323, 12.724460378280673, 11.68310592025925, 10.756292091745907, 9.78203877932088, 8.754621414137379, 6.897906180423398, 5.901499340876468, 4.981324897103491, 5.8979787414293785, 6.7735062323497255, 7.781390660974162, 8.748924049750002, 9.675421071056093, 10.644437787099378, 11.664248433847133, 12.63227507207542, 13.557801402215048, 14.544878733739557, 13.759470048396649, 12.689039034638395, 11.778230330561929, 10.83779415987805, 9.84909377658337, 8.801289383747893, 7.93161634077291, 5.898563717308441, 4.961231771302618, 3.9406494280124438, 4.9087689277712965, 5.820686670259373, 6.835348788831345, 7.7840005124310245, 8.721674908529355, 9.773849337760767, 10.803040071509164, 11.68725677084198, 12.730698136432597, 13.754534908857314, 12.739749988151083, 11.75309615374483, 10.770591858354415, 9.786884351415747, 8.798196974331168, 7.8226096073391105, 6.876040166805155, 4.925681766407203, 3.984156385561642, 2.9376951045423727, 3.9244991601991948, 4.849860656184227, 5.845906914107993, 6.808830046972027, 7.833325006262228, 8.78861489736084, 9.757292720154265, 10.715937719225423, 11.76754431143109, 12.76565266227606, 11.715729504551948, 10.788930056899693, 9.864625145791015, 8.850472435165356, 7.8359317087187, 6.892025929429575, 5.872700979279903, 3.9052587990336947, 2.995520585046875, 1.943043938110025, 2.9936288449863695, 3.956572375927637, 5.022478025527631, 5.898549928145577, 6.88009666274331, 7.883584632560816, 8.888669878233744, 9.90400925649814, 10.95241016421545, 11.828354809745534, 10.835636277080454, 9.837491162959667, 8.844918015618262, 7.865293702581095, 6.906337070347576, 5.872926255565454, 4.951102495609551, 2.9049241289806016, 1.9591032998831557, 0.9851475702328909, 2.0209629420792425, 2.9528249339922685, 3.9593023108506205, 4.893839191964491, 5.916750046766632, 6.889193897650351, 7.889596142270594, 8.950444621211462, 9.909289399529777, 10.869813872871712, 9.915968273405252, 8.915934332801045, 7.953616001663631, 6.917055180702214, 5.887161305017121, 4.90184576514736, 3.9266223508904705, 2.0885372157596356, 1.0278839655323733, 0.0, 0.9470205246254692, 1.9908528181463563, 2.9860879712413393, 3.930376169571709, 4.952192952348366, 5.957224692347097, 6.887646124569028, 7.934595722014694, 8.897328462383635, 9.947354463250518, 8.986697228706483, 8.015572855189419, 7.039937206383321, 6.088774845342872, 5.033071734279879, 3.984487872169944, 3.0385345243143105, 3.0649796882252547, 2.0068662174486915, 1.0204639907358934, 1.95104144869559, 2.9760704671101013, 3.9132201684184054, 4.903943664080395, 5.948257538138602, 6.999363264797854, 7.923596363619103, 8.949340430748258, 9.856466121181391, 10.801476244233973, 9.889657294253563, 8.883827846218743, 7.864411882168824, 6.845184898194795, 5.9043325687514, 4.959765652417041, 3.9937674480421625, 4.002938405667411, 2.991253419932235, 2.0306014552663196, 2.952011854126604, 3.900307036230621, 4.855536069680581, 5.838863484226511, 6.85876262036657, 7.800518025852071, 8.845923514027279, 9.917490663892552, 10.843449975915, 11.729451063180424, 10.865073948378544, 9.826123040071877, 8.832954239022435, 7.919803894528111, 6.916319452362459, 5.979225399715821, 4.920605888764006], [6.829805225607443, 7.788780480880374, 8.768117494317586, 9.758992635790168, 10.787227275421216, 11.742341086468075, 12.736398413684622, 11.82507761157283, 10.958577932040786, 9.937064738919094, 8.883752062738091, 7.893334708386834, 6.828281983936657, 5.8198895510008475, 4.849416010377832, 3.9631009474950725, 3.034299510562092, 3.931593784865081, 4.875810383933813, 5.90254798028392, 7.848711003254019, 8.844084826870397, 9.758630372621589, 10.70716759382528, 11.767017987603113, 12.72154300478533, 13.68652511730481, 12.84207407385314, 11.79031144805973, 10.717925143676375, 9.764529455246496, 8.804487381541344, 7.7456774418143235, 6.7292502693970535, 5.7765440059484865, 4.9689817520437085, 3.959747188051396, 4.888069032715574, 5.9239003797663425, 6.961309588171165, 8.846577214104919, 9.78773235392781, 10.738004833952253, 11.696954672169772, 12.694671254246538, 13.707484898589954, 14.68925521664033, 13.72130439066683, 12.705641401884451, 11.698386681353456, 10.678173411601186, 9.747380422812016, 8.695110193240774, 7.699135358803079, 6.724836585541317, 5.951474281326201, 5.03268145457118, 5.9014708777408424, 6.849298530849509, 7.801127860521343, 9.864925259102204, 10.798822293049012, 11.721848755262332, 12.650457774766982, 13.689717286316357, 14.69081404528133, 15.635334030588087, 14.644225496185864, 13.658675146027583, 12.68194975519312, 11.681498709496212, 10.613323379471712, 9.649420098375586, 8.686871658019836, 7.7447425414829105, 6.890233991513972, 5.9617153650738395, 6.896833440880549, 7.835132719193954, 8.843715403116034, 10.790500910525818, 11.737836215026661, 12.766141271056304, 13.16444855288563, 13.650403149442676, 14.716211319357878, 15.717271290650254, 15.584704044096199, 14.51369684671778, 13.569452373603811, 12.619812404215644, 11.552693079884262, 10.63775589453326, 9.659024858355028, 8.723571787712492, 7.92252064903539, 6.960811226827654, 7.889674576604856, 8.780995501056873, 9.813934219062066, 11.64176386719568, 12.703503557674836, 13.018584533659679, 12.10940181489456, 12.707840312822299, 13.735420099997587, 14.67259555378865, 15.641125314985471, 15.339704808280677, 14.412170996650962, 13.466024104995489, 12.513622703737845, 11.556202720990228, 10.627243772655104, 9.649433402729974, 8.891407117803801, 7.981051599719798, 8.888099563012469, 9.728677528514435, 10.691420807935003, 12.585794609990728, 12.763346260264019, 11.944764452747076, 11.081984153879064, 11.737068575171408, 12.787858582844876, 13.717303699461226, 14.663666664833647, 15.625090872441042, 15.353924904572924, 14.466615933755408, 13.537508310684359, 12.621906491944786, 11.631687279864272, 10.601913326159012, 9.958620924522569, 8.943305244354857, 9.863961500412364, 10.748232954210827, 11.620851137697844, 12.655815217204545, 11.781063586343617, 10.96245337559564, 10.050907208297582, 10.711712726292012, 11.76170775590788, 12.741012252570346, 13.682284680900482, 14.662171107555722, 15.49379214160599, 15.427921638729527, 14.469437716649974, 13.655067462657628, 12.635372986978767, 11.675271794274119, 10.929466109223837, 9.999879509123199, 10.926007037526002, 11.798794653648313, 12.55793736757239, 11.68639607656767, 10.76046679189572, 9.925303695351825, 8.9972661041738, 9.78095209779298, 10.771737997913892, 11.70801909514453, 12.678236658892892, 13.642807294912398, 14.455577641555909, 15.388699526727013, 15.49180054926797, 14.569855373323152, 13.63045676826542, 12.601145599358444, 11.957887531209078, 11.058029183680848, 11.997372348525035, 12.787209487293303, 12.629322444411736, 10.748316373807445, 9.77370422563132, 8.949380821440446, 8.001671002100775, 8.817219646105668, 9.828099533619893, 10.759422258220463, 11.70155705182488, 12.579162228823373, 13.509817164242854, 14.48702470315166, 15.412198161888702, 15.510785805410269, 14.564177265079737, 13.595877503483766, 12.920005235673486, 12.06072452874095, 12.9916602597001, 12.663401667239144, 11.648633919228708, 9.702094397016538, 8.764505008065598, 7.967414976143827, 6.9739261473795, 7.883476998813256, 8.849417731472002, 9.711003058877463, 10.684318979662324, 11.650198431546274, 12.647331644324783, 13.57895467020363, 14.557780841623599, 15.50399661178915, 15.618822295215711, 14.553110732773904, 13.982714880814653, 13.024774121968964, 12.574926187973578, 11.60998134011959, 10.631929186556349, 8.746036560369932, 7.818083448424289, 6.98707110529956, 5.996292172940947, 6.843907335565169, 7.893384055924058, 8.749165491946952, 9.694611279718858, 10.722614403785574, 11.64773573403758, 12.627605111906103, 13.538318139734304, 14.609312715591631, 15.614922470964895, 14.620673168290791, 13.671480902906142, 12.630126444884718, 11.703312616371376, 10.729059303946348, 9.701641938762847, 7.844926705048867, 6.848519865501936, 5.9283454217289595, 4.962985279462771, 5.826485707724257, 6.834370136348693, 7.801903525124533, 8.728400546430624, 9.697417262473909, 10.717227909221664, 11.68525454744995, 12.61078087758958, 13.597858209114088, 14.640600332379385, 13.636059559263863, 12.725250855187397, 11.784814684503518, 10.796114301208839, 9.748309908373361, 8.87863686539838, 6.845584241933911, 5.9082522959280865, 4.887669952637912, 3.9737754658046893, 4.873666145633904, 5.888328264205876, 6.836979987805556, 7.774654383903886, 8.826828813135299, 9.856019546883696, 10.740236246216512, 11.783677611807128, 12.819546595450397, 13.686770512776551, 12.700116678370298, 11.717612382979883, 10.733904876041215, 9.745217498956636, 8.769630131964579, 7.823060691430625, 5.872702291032672, 4.931176910187111, 3.8847156291678417, 2.9774786355737253, 3.9028401315587575, 4.898886389482524, 5.861809522346558, 6.88630448163676, 7.841594372735371, 8.810272195528796, 9.768917194599954, 10.820523786805621, 11.818632137650596, 12.662750029177417, 11.735950581525161, 10.811645670416484, 9.797492959790825, 8.782952233344169, 7.839046454055044, 6.819721503905373, 4.852279323659164, 3.9425411096723435, 2.890064462735494, 2.0466083203609, 3.0095518513021675, 4.075457500902161, 4.951529403520109, 5.933076138117841, 6.9365641079353475, 7.941649353608275, 8.956988731872672, 10.005389639589982, 10.881334285120067, 11.782656801705922, 10.784511687585136, 9.79193854024373, 8.812314227206564, 7.853357594973045, 6.819946780190922, 5.898123020235021, 3.8519446536060706, 2.906123824508625, 1.9321680948583602, 1.0739424174537733, 2.005804409366799, 3.0122817862251514, 3.946818667339022, 4.969729522141163, 5.9421733730248825, 6.942575617645125, 8.003424096585993, 8.96226887490431, 9.922793348246245, 10.86298879803072, 9.862954857426514, 8.9006365262891, 7.864075705327682, 6.834181829642589, 5.848866289772829, 4.873642875515939, 3.035557740385104, 1.9749044901578423, 0.9470205246254692, 0.0, 1.0438322935208872, 2.0390674466158702, 2.98335564494624, 4.005172427722897, 5.0102041677216285, 5.9406255999435595, 6.9875751973892255, 7.950307937758168, 9.009639761886461, 9.933717753331951, 8.962593379814887, 7.98695773100879, 7.035795369968341, 5.980092258905348, 4.9315083967954125, 3.985555048939779, 4.012000212850724, 2.9538867420741606, 1.9674845153613627, 1.0040209240701208, 2.029049942484632, 2.9661996437929363, 3.9569231394549265, 5.001237013513133, 6.052342740172385, 6.976575838993634, 8.00231990612279, 8.909445596555924, 9.854455719608506, 10.83369850214209, 9.830848370844212, 8.811432406794292, 7.792205422820263, 6.8513530933768685, 5.90678617704251, 4.940787972667631, 4.949958930292881, 3.938273944557704, 2.9776219798917887, 2.0049913295011343, 2.9532865116051514, 3.908515545055112, 4.891842959601043, 5.9117420957411015, 6.853497501226602, 7.89890298940181, 8.970470139267084, 9.896429451289531, 10.782430538554957, 11.711849375026702, 10.773143564697346, 9.779974763647903, 8.866824419153579, 7.863339976987928, 6.9262459243412895, 5.867626413389474], [7.873637519128331, 8.832612774401262, 9.811949787838474, 10.802824929311054, 11.831059568942102, 12.719909933781715, 11.692566120163736, 10.781245318051944, 9.9147456385199, 8.893232445398207, 7.839919769217204, 6.849502414865946, 5.784449690415769, 4.77605725747996, 3.805583716856945, 3.0349043422514206, 3.992289821225012, 4.974364864958855, 5.918581464027588, 6.945319060377694, 8.892543296774907, 9.887917120391286, 10.802462666142478, 11.75099988734617, 12.810850281124003, 13.69911185209897, 12.642692823783925, 11.798241780332251, 10.746479154538843, 9.674092850155487, 8.720697161725608, 7.7606550880204574, 6.701845148293437, 5.685417975876167, 4.7327117124276, 4.040785146800057, 4.917737498714316, 5.846059343378494, 6.90131026762501, 7.946435514778259, 9.823987101963587, 10.765142241786478, 11.721901833615068, 12.68806755377872, 13.686907986586052, 14.676625525617165, 13.645422923119444, 12.677472097145943, 11.661809108363563, 10.654554387832569, 9.634341118080298, 8.703548129291129, 7.6512778997198865, 6.655303065282192, 5.68100429202043, 5.023277676082548, 5.973136409287294, 6.859461188403762, 7.826708418708177, 8.77853774838001, 10.842335146960872, 11.77623218090768, 12.705745754925147, 13.634354774429797, 13.740859939962084, 14.766301898884791, 14.591501737067198, 13.600393202664975, 12.614842852506694, 11.63811746167223, 10.637666415975325, 9.569491085950824, 8.605587804854698, 7.643039364498948, 6.700910247962023, 6.034353944668927, 6.902170319789953, 7.837288395596662, 8.812542607052622, 9.821125290974702, 11.767910798384486, 12.715246102885331, 13.743551158914974, 13.76810046445784, 12.758598018201743, 13.824406188116946, 14.825466159409322, 14.540871750575313, 13.469864553196894, 12.525620080082925, 11.575980110694758, 10.508860786363375, 9.593923601012373, 8.61519256483414, 7.6797394941916055, 7.095498806774715, 7.901266181543767, 8.830129531320969, 9.758405388915541, 10.791344106920734, 12.619173755054348, 13.680913445533504, 13.775345594274503, 12.849958676630663, 11.816035181581366, 12.843614968756654, 13.780790422547717, 14.749320183744539, 14.29587251475979, 13.368338703130075, 12.422191811474601, 11.469790410216957, 10.512370427469342, 9.583411479134218, 8.605601109209088, 8.064385275543126, 8.921506554435911, 9.828554517728582, 10.706087416373103, 11.668830695793671, 13.563204497849396, 13.656850031498063, 12.783652650151032, 11.822541015615169, 10.845263443930476, 11.896053451603944, 12.825498568220294, 13.747983095997492, 14.708584111152359, 14.310092611052037, 13.42278364023452, 12.493676017163471, 11.5780741984239, 10.587854986343386, 9.558081032638126, 9.131599082261893, 9.88376019907097, 10.804416455128477, 11.725642842069494, 12.598261025556512, 13.549318988438587, 12.674567357577661, 11.801341572999595, 10.791464070033687, 9.81990759505108, 10.869902624666947, 11.849207121329414, 12.766601112064327, 13.745664346267038, 14.572124646931222, 14.38408934520864, 13.425605423129086, 12.611235169136743, 11.591540693457882, 10.631439500753233, 10.185658267317667, 10.940334463839312, 11.866461992242115, 12.77620454150698, 13.535347255431057, 12.579899847801713, 11.653970563129763, 10.764448875224042, 9.836411284046017, 8.889146966552048, 9.87993286667296, 10.816213963903598, 11.762553090056738, 12.726300533623714, 13.53391014688114, 14.467032032052245, 14.447968255747082, 13.526023079802266, 12.586624474744534, 11.557313305837559, 11.214079689302908, 11.998484138396961, 12.937827303241148, 13.76461937515197, 13.52282621564578, 11.641820145041487, 10.667207996865363, 9.822074836908381, 8.840949760409188, 7.925414514864737, 8.93629440237896, 9.843738689384308, 10.785873482988725, 11.657494734148603, 12.588149669568086, 13.565357208476891, 14.490530667213934, 14.466953511889383, 13.52034497155885, 12.55204520996288, 12.176197393767316, 13.001179483457063, 13.932115214416212, 13.556905438473189, 12.542137690462752, 10.59559816825058, 9.65800877929964, 8.854534559611825, 7.813204905687914, 6.991671867572324, 7.957612600231071, 8.795319490041308, 9.768635410826171, 10.728530936871504, 11.724883941961462, 12.634107197659558, 13.612933369079526, 14.559149139245077, 14.574990001694825, 13.509278439253018, 13.238907038908483, 13.965229076685077, 13.468429959207622, 12.503485111353635, 11.525432957790393, 9.639540331603975, 8.711587219658332, 7.874190688767558, 6.835570931249361, 5.9521022043242375, 7.001578924683127, 7.833481923110799, 8.778927710882705, 9.777766931241501, 10.702888261493507, 11.68275763936203, 12.587704479575713, 13.65869905543304, 14.664308810806304, 14.469939871059756, 14.21525531881064, 13.523630216118761, 12.596816387605418, 11.622563075180391, 10.59514570999689, 8.747988193639863, 7.742023636735979, 6.821849192963002, 5.8022640377711845, 4.934680576483325, 5.942565005107762, 6.88621995628838, 7.7835530738865515, 8.752569789929836, 9.766614249063075, 10.73464088729136, 11.660167217430988, 12.647244548955497, 13.689986672220794, 14.623892505509886, 13.667565283153982, 12.714966008570677, 11.726265625275998, 10.676546502326586, 9.79089962914146, 7.773820835887135, 6.801756067162129, 5.781173723871955, 4.8130542241131025, 3.9818610143929725, 4.9965231329649455, 5.921296418969403, 6.829806911359814, 7.868825179755606, 8.835489790439027, 9.703338153785122, 10.746779519375739, 11.782648503019008, 12.79743342372524, 13.687949624616321, 12.663684680557008, 11.67997717361834, 10.691289796533761, 9.697866725917804, 8.751297285383849, 6.8009388849858965, 5.859413504140337, 4.8129522231210675, 3.8167573938821384, 3.0110350003178263, 3.9752794999876127, 4.881761030066129, 5.849406389205371, 6.8046962803039825, 7.7733741030974075, 8.732019102168564, 9.783625694374232, 10.774799844129706, 11.842710748300805, 12.76951019595306, 11.757717967993608, 10.74356525736795, 9.729024530921293, 8.785118751632169, 7.747958097858597, 5.8961116171800505, 4.982422257411576, 3.929945610474727, 2.885887078669313, 1.9851066257845287, 3.0432531302680252, 3.907697109999221, 4.889243844596954, 5.89273181441446, 6.897817060087387, 7.913156438351784, 8.961557346069094, 9.83750199159918, 10.835400092165136, 11.828343981106025, 10.83577083376462, 9.856146520727453, 8.897189888493934, 7.86377907371181, 6.941955313755908, 4.895776947126958, 3.9499561180295117, 2.972049242597593, 1.9132211757621862, 0.9813591838491604, 1.9684494927042642, 2.902986373818135, 3.9258972286202756, 4.898341079503995, 5.898743324124237, 6.9595918030651065, 7.918436581383423, 8.878961054725357, 9.891381961458766, 10.891415902062972, 9.944468819809988, 8.90790799884857, 7.878014123163477, 6.892698583293717, 5.917475169036827, 4.079390033905992, 3.0187367836787296, 1.9908528181463563, 1.0438322935208872, 0.0, 0.9952351530949829, 1.9395233514253527, 2.96134013420201, 3.9663718742007417, 4.896793306422673, 5.943742903868339, 6.906475644237281, 7.9658074683655755, 8.92646470290961, 9.897589076426675, 9.030790024529677, 8.079627663489228, 7.0239245524262355, 5.9753406903163, 5.029387342460667, 5.055832506371611, 3.997719035595048, 3.01131680888225, 2.0478532175910082, 1.063592582040879, 1.922367350272049, 2.913090845934039, 3.9574047199922457, 5.008510446651497, 5.932743545472748, 6.9584876126019015, 7.865613303035038, 8.81062342608762, 9.789866208621204, 10.795695656656024, 9.85526470031518, 8.836037716341151, 7.895185386897756, 6.9506184705633975, 5.984620266188519, 5.992730010386655, 4.981045024651478, 4.020393059985563, 2.973385088465517, 2.0250899063614995, 2.864683251534225, 3.848010666080155, 4.867909802220214, 5.809665207705715, 6.855070695880922, 7.926637845746196, 8.852597157768646, 9.738598245034071, 10.668017081505816, 11.736055163726798, 10.823807057168791, 9.910656712674466, 8.907172270508816, 7.970078217862177, 6.911458706910362], [8.79352103518372, 9.75249629045665, 10.731833303893861, 11.722708445366443, 12.679788591733589, 11.72467478068673, 10.697330967068753, 9.786010164956961, 8.919510485424917, 7.8979972923032244, 6.844684616122221, 5.854267261770963, 4.789214537320786, 3.780822104384977, 2.810348563761962, 3.798826183882858, 4.756211662856449, 5.780584260084725, 6.756605806873571, 7.783343403223678, 9.756137700670022, 10.807800636446673, 11.722346182197864, 12.670883403401556, 13.693111325513794, 12.703876699003985, 11.647457670688942, 10.80300662723727, 9.75124400144386, 8.678857697060504, 7.725462008630625, 6.765419934925474, 5.706609995198454, 4.690182822781184, 3.7374765593326167, 4.804706988431494, 5.681659340345753, 6.609981185009931, 7.665232109256447, 8.710357356409697, 10.587908943595023, 11.529064083417914, 12.485823675246504, 13.451989395410157, 14.450829828217488, 13.681390372522184, 12.650187770024461, 11.68223694405096, 10.66657395526858, 9.659319234737586, 8.639105964985315, 7.708312976196145, 6.6560427466249035, 5.660067912187209, 4.685769138925447, 5.62440217445157, 6.574260907656316, 7.6233830300352, 8.590630260339614, 9.542459590011447, 11.463204444995458, 12.400618510015756, 13.423475855917536, 14.352084875422186, 14.705915544460655, 14.146846476790008, 13.596266583972216, 12.605158049569994, 11.619607699411713, 10.64288230857725, 9.642431262880342, 8.574255932855841, 7.610352651759715, 6.647804211403965, 5.70567509486704, 6.63547844303795, 7.503294818158976, 8.438412893965685, 9.431992047127224, 10.440574731049304, 12.388780096419072, 13.337741716282597, 14.36604677231224, 14.733156068956411, 13.723653622700315, 13.090887783626005, 13.981417452407847, 13.545636597480328, 12.47462940010191, 11.53038492698794, 10.580744957599773, 9.513625633268392, 8.59868844791739, 7.619957411739158, 6.6845043410966225, 7.696623305143738, 8.50239067991279, 9.431254029689992, 10.377854828990143, 11.410793546995336, 13.23862319512895, 14.300362885608106, 14.740401198773077, 13.815014281129237, 12.781090786079938, 12.040083257281646, 12.936741715546242, 13.791388705703294, 13.300637361664807, 12.373103550035092, 11.426956658379618, 10.474555257121974, 9.51713527437436, 8.588176326039235, 7.610365956114105, 8.58960347881191, 9.5169364796969, 10.429679016097605, 11.325536856447705, 12.288280135868273, 14.182653937923998, 14.652085184593044, 13.748708254649603, 12.78759662011374, 11.810319048429047, 11.069769815202527, 11.874531039331302, 12.752747942902511, 13.713348958057374, 13.314857457957054, 12.427548487139537, 11.498440864068488, 10.582839045328917, 9.592619833248403, 8.562845879543143, 9.51702502679986, 10.479190124331959, 11.4055409534975, 12.345092282144098, 13.217710465631114, 14.54455414153357, 13.669802510672643, 12.766397177498167, 11.756519674532258, 10.78496319954965, 10.04361898826553, 10.898239592440422, 11.771365958969346, 12.750429193172053, 13.576889493836237, 13.388854192113657, 12.430370270034103, 11.61600001604176, 10.596305540362899, 9.63620434765825, 10.571084211855634, 11.500670811956272, 12.439626136308295, 13.395653981581583, 14.15479669550566, 13.575135000896696, 12.649205716224746, 11.729504479722614, 10.801466888544589, 9.85420257105062, 9.001287878790444, 9.831710700430436, 10.767317936961756, 11.73106538052873, 12.538674993786156, 13.47179687895726, 13.452733102652099, 12.530787926707283, 11.591389321649551, 10.562078152742576, 11.549755379201699, 12.477472961897263, 13.510991447307328, 14.384068815226573, 14.518061368740762, 12.63705529813647, 11.662443149960346, 10.817309990003363, 9.83618491350417, 8.890470119363307, 8.057649414496446, 8.848503536289327, 9.790638329893744, 10.662259581053618, 11.592914516473101, 12.570122055381907, 13.495295514118949, 13.4717183587944, 12.525109818463868, 11.556810056867898, 12.511873083666107, 13.451256518968018, 14.505279358482392, 14.55214059156817, 13.537372843557733, 11.590833321345563, 10.653243932394624, 9.849769712706808, 8.808440058782896, 7.956727472070894, 6.993885433587579, 7.800084336946326, 8.773400257731188, 9.73329578377652, 10.729648788866477, 11.638872044564573, 12.617698215984541, 13.563913986150093, 13.57975484859984, 12.514043286158035, 13.46485183285314, 14.415306112196031, 14.463665112302603, 13.498720264448616, 12.520668110885374, 10.634775484698958, 9.706822372753315, 8.86942584186254, 7.830806084344344, 6.917157808822807, 6.0378517580396345, 6.838246770015816, 7.783692557787722, 8.782531778146517, 9.707653108398523, 10.687522486267046, 11.592469326480728, 12.663463902338055, 13.66907365771132, 13.474704717964773, 14.423896983349422, 14.518865369213744, 13.592051540700401, 12.617798228275374, 11.590380863091873, 9.743223346734846, 8.737258789830962, 7.817084346057985, 6.7974991908661675, 5.899736180981895, 4.97883783846427, 5.890984803193397, 6.7883179207915685, 7.7573346368348535, 8.77137909596809, 9.739405734196374, 10.664932064336003, 11.652009395860512, 12.69475151912581, 13.674384020596781, 14.662800436248963, 13.710201161665658, 12.721500778370979, 11.671781655421567, 10.786134782236443, 8.769055988982117, 7.796991220257112, 6.776408876966938, 5.8082893772080855, 4.946916618891542, 4.032795966321453, 4.92606126587442, 5.834571758264831, 6.873590026660623, 7.840254637344043, 8.708103000690139, 9.751544366280756, 10.787413349924025, 11.802198270630257, 12.738441139703216, 13.658919833651991, 12.675212326713323, 11.686524949628744, 10.693101879012785, 9.74653243847883, 7.7961740380808795, 6.85464865723532, 5.8081873762160505, 4.811992546977121, 3.9760906048163958, 2.9800443468926296, 3.886525876971146, 4.854171236110388, 5.8094611272089995, 6.7781389500024245, 7.736783949073582, 8.78839054127925, 9.779564691034725, 10.847475595205823, 11.77427504285808, 12.752953121088591, 11.738800410462932, 10.724259684016276, 9.780353904727152, 8.743193250953581, 6.8913467702750335, 5.977657410506559, 4.92518076356971, 3.881122231764296, 2.9803417788795112, 2.0480179771730422, 2.912461956904238, 3.8940086915019707, 4.897496661319477, 5.902581906992405, 6.917921285256801, 7.966322192974111, 8.842266838504196, 9.840164939070153, 10.83831005319094, 11.803791637248754, 10.851381673822436, 9.892425041588917, 8.859014226806792, 7.937190466850891, 5.891012100221941, 4.945191271124495, 3.967284395692576, 2.908456328857169, 1.9765943369441432, 0.9732143396092813, 1.907751220723152, 2.9306620755252926, 3.903105926409012, 4.903508171029255, 5.9643566499701235, 6.92320142828844, 7.883725901630374, 8.896146808363783, 9.89618074896799, 10.830855274800909, 9.903143151943553, 8.873249276258461, 7.8879337363887, 6.91271032213181, 5.074625187000975, 4.013971936773713, 2.9860879712413393, 2.0390674466158702, 0.9952351530949829, 0.0, 0.9442881983303698, 1.9661049811070268, 2.9711367211057587, 3.9015581533276897, 4.948507750773356, 5.911240491142298, 6.9705723152705925, 7.931229549814628, 8.902353923331692, 9.877989572137789, 9.074862816584211, 8.019159705521218, 6.970575843411283, 6.02462249555565, 5.990766104194488, 4.932652633417925, 3.9092644307887863, 2.9266459433013745, 1.901616924886863, 0.9271321971770661, 1.9178556928390562, 2.9621695668972627, 4.013275293556514, 4.937508392377765, 5.9632524595069185, 6.870378149940055, 7.815388272992637, 8.79463105552622, 9.800460503561041, 10.81987646761096, 9.831272869436134, 8.89042053999274, 7.9458536236583805, 6.979855419283502, 6.8307543532326385, 5.819069367497462, 4.858417402831546, 3.8114094313115006, 2.8631142492074835, 1.8694480984392419, 2.852775512985172, 3.872674649125231, 4.814430054610732, 5.859835542785939, 6.931402692651213, 7.8573620046736625, 8.743363091939088, 9.672781928410833, 10.740820010631815, 11.788418824464571, 10.90589186576945, 9.9024074236038, 8.948220844232074, 7.889601333280258], [9.737809233514088, 10.696784488787019, 11.67612150222423, 12.666996643696812, 11.73550039340322, 10.78038658235636, 9.753042768738382, 8.84172196662659, 7.975222287094547, 6.953709093972855, 5.9003964177918515, 4.909979063440594, 3.844926338990417, 2.8365339060546075, 3.7546367620923315, 4.743114382213228, 5.7004998611868185, 6.724872458415094, 7.700894005203941, 8.727631601554048, 10.700425899000392, 11.752088834777043, 12.666634380528233, 13.615171601731925, 12.748823127183424, 11.759588500673615, 10.70316947235857, 9.89136992248858, 8.860058675044657, 7.787672370661301, 6.8342766822314225, 5.8742346085262716, 4.815424668799251, 3.7989974963819804, 4.681764757662986, 5.748995186761864, 6.625947538676122, 7.5542693833403005, 8.609520307586816, 9.654645554740066, 11.532197141925392, 12.473352281748284, 13.430111873576873, 14.396277593740527, 13.67647639382685, 12.737102174191811, 11.70589957169409, 10.833187258150263, 9.817524269367883, 8.810269548836889, 7.8048129072553, 6.87401991846613, 5.830640294474783, 4.854873418029866, 5.630057337255816, 6.56869037278194, 7.518549105986685, 8.567671228365569, 9.534918458669983, 10.486747788341816, 12.407492643325828, 13.344906708346125, 14.367764054247905, 15.296373073752555, 14.686411589579782, 13.660969630657075, 12.712488853204503, 11.784968582213068, 10.799418232054787, 9.822692841220324, 8.822241795523418, 7.7540664654989175, 6.790163184402791, 5.8426097172466225, 6.649963293197409, 7.57976664136832, 8.447583016489345, 9.382701092296054, 10.376280245457593, 11.384862929379674, 13.333068294749442, 14.282029914612966, 15.310334970642609, 15.643105377429102, 14.633602931173005, 13.990051260945888, 13.147522783220474, 12.725447130123406, 11.654439932744987, 10.710195459631018, 9.76055549024285, 8.693436165911468, 7.778498980560465, 6.814762917581815, 7.628792539426992, 8.640911503474108, 9.446678878243159, 10.375542228020361, 11.322143027320513, 12.355081745325705, 14.18291139345932, 15.244651083938475, 15.650350507245767, 14.724963589601927, 13.691040094552628, 12.939246734601529, 12.10284704635887, 12.957494036515921, 12.480447894307883, 11.552914082678168, 10.606767191022694, 9.65436578976505, 8.761861381165119, 7.832902432829994, 8.554654154444474, 9.533891677142279, 10.46122467802727, 11.373967214427974, 12.269825054778075, 13.232568334198643, 15.126942136254367, 15.596373382923414, 14.658657563122294, 13.69754592858643, 12.720268356901737, 11.96893329252241, 11.040636370143929, 11.918853273715138, 12.866936645939516, 12.49466799060013, 11.607359019782614, 10.678251396711564, 9.827565152119677, 8.846571601304777, 9.507134077873513, 10.46131322513023, 11.423478322662328, 12.349829151827869, 13.289380480474467, 14.161998663961484, 15.48884233986394, 14.614090709003012, 13.676346485970857, 12.666468983004949, 11.694912508022341, 10.942782465585413, 10.06434492325305, 10.937471289781973, 11.904016881054195, 12.730477181718378, 12.568664724756733, 11.61018080267718, 10.860726122832519, 9.850257308419273, 10.58049254598862, 11.515372410186004, 12.444959010286642, 13.383914334638664, 14.339942179911953, 15.099084893836029, 14.519423199227065, 13.593493914555115, 12.639453788195304, 11.711416197017279, 10.76415187952331, 9.900451356110327, 8.997816031243064, 9.933423267774383, 10.884653068410872, 11.692262681668296, 12.6253845668394, 12.632543635295175, 11.817724066142564, 10.878325461084831, 11.506366351072945, 12.494043577532068, 13.421761160227632, 14.455279645637697, 15.328357013556943, 15.462349567071131, 13.58134349646684, 12.606731348290715, 11.739433386929068, 10.758308310429873, 9.800419427835998, 8.956812891816329, 8.014608867101954, 8.95674366070637, 9.81584726893576, 10.746502204355242, 11.723709743264047, 12.64888320200109, 12.75865449822968, 11.812045957899148, 12.501098255198267, 13.456161281996476, 14.395544717298387, 15.449567556812761, 15.49642878989854, 14.481661041888103, 12.535121519675933, 11.597532130724993, 10.794057911037177, 9.752728257113265, 8.866676780543585, 7.893048910907462, 6.966189667758954, 7.939505588543816, 8.886883471658662, 9.88323647674862, 10.792459732446716, 11.771285903866683, 12.717501674032235, 12.883703281966191, 13.458331484488404, 14.40914003118351, 15.3595943105264, 15.407953310632973, 14.443008462778986, 13.464956309215744, 11.579063683029327, 10.651110571083684, 9.81371404019291, 8.775094282674713, 7.8614460071531775, 6.937015235359517, 6.004352100828444, 6.949797888600349, 7.936119466028658, 8.861240796280665, 9.841110174149188, 10.746057014362869, 11.817051590220196, 12.82266134559346, 13.76124130929166, 14.71043357467631, 15.463153567544113, 14.53633973903077, 13.562086426605743, 12.534669061422242, 10.687511545065215, 9.681546988161331, 8.761372544388355, 7.741787389196538, 6.844024379312265, 5.92312603679464, 5.057090134006025, 5.941905608673709, 6.910922324716994, 7.9249667838502305, 8.892993422078515, 9.818519752218144, 10.79555562193454, 11.838297745199837, 12.730095822266412, 13.77349876857914, 14.65448935999603, 13.66578897670135, 12.616069853751938, 11.730422980566813, 9.713344187312488, 8.741279418587482, 7.720697075297308, 6.752577575538456, 5.8912048172219125, 4.977084164651823, 4.092166596687048, 4.988159446146971, 6.027177714542764, 6.993842325226184, 7.86169068857228, 8.905132054162898, 9.859369895978917, 10.874154816685149, 11.794152941372847, 12.812747597369714, 13.619500525043694, 12.630813147959115, 11.637390077343156, 10.690820636809201, 8.74046223641125, 7.798936855565691, 6.7524755745464216, 5.756280745307492, 4.920378803146766, 3.924332545223, 3.052631207783774, 4.007758923992529, 4.96304881509114, 5.931726637884565, 6.890371636955723, 7.94197822916139, 8.835276492704356, 9.903187396875454, 10.82998684452771, 11.886839644257325, 12.683088608793303, 11.668547882346648, 10.724642103057523, 9.687481449283952, 7.835634968605403, 6.921945608836929, 5.86946896190008, 4.825410430094666, 3.9246299772098814, 2.992306175503412, 2.078567287716866, 3.047596379384111, 4.051084349201617, 5.022671556465394, 5.973633086926432, 7.022033994643742, 7.897978640173827, 8.895876740739782, 9.894021854860569, 10.859503438918383, 11.795669872152805, 10.836713239919286, 9.803302425137161, 8.881478665181259, 6.83530029855231, 5.889479469454864, 4.911572594022946, 3.8527445271875393, 2.9208825352745134, 1.917502537939651, 1.0738565515357799, 2.084249763407433, 3.0566936142911527, 4.023597820502244, 5.020068451639753, 5.97891322995807, 6.939437703300004, 7.951858610033412, 8.951892550637618, 9.886567076470538, 10.84004564238309, 9.81753747458883, 8.832221934719069, 7.856998520462179, 6.018913385331344, 4.958260135104082, 3.930376169571709, 2.98335564494624, 1.9395233514253527, 0.9442881983303698, 0.0, 1.021816782776657, 2.026848522775389, 2.9572699549973196, 4.0042195524429856, 4.966952292811928, 6.0262841169402215, 6.986941351484257, 7.958065725001321, 8.933701373807418, 9.884863734847867, 8.963447903851588, 7.9148640417416525, 6.968910693886019, 6.935054302524858, 5.8769408317482945, 4.8535526291191555, 3.870934141631744, 2.845905123217233, 1.8714203955074358, 0.9735674945086864, 2.017881368566893, 3.068987095226145, 3.9932201940473946, 5.018964261176548, 5.9260899516096845, 6.871100074662267, 7.850342857195851, 8.856172305230672, 9.875588269280591, 10.775561067766505, 9.83470873832311, 8.89014182198875, 7.924143617613871, 7.775042551563008, 6.763357565827832, 5.802705601161916, 4.755697629641871, 3.8074024475378536, 2.8137362967696116, 1.9084873146548023, 2.9283864507948616, 3.870141856280362, 4.91554734445557, 5.987114494320844, 6.913073806343292, 7.799074893608718, 8.728493730080462, 9.796531812301444, 10.844130626134202, 11.833395965220442, 10.84669562193417, 9.892509042562443, 8.833889531610627], [10.759626016290746, 11.718601271563676, 12.697938285000888, 11.74191825025761, 10.713683610626562, 9.758569799579703, 8.731225985961725, 7.819905183849934, 6.95340550431789, 5.991986861747164, 4.9386741855661604, 3.948256831214903, 2.918848276304971, 3.8583506888312646, 4.776453544868989, 5.764931164989886, 6.7223166439634765, 7.746689241191753, 8.722710787980597, 9.749448384330705, 11.72224268177705, 12.7739056175537, 13.68845116330489, 12.783719651237156, 11.727006344406767, 10.737771717896958, 9.681352689581914, 8.869553139711925, 7.907524031142033, 6.835137726758678, 5.881742038328799, 5.010536620027965, 3.9559224004153735, 4.820814279158637, 5.703581540439644, 6.7708119695385225, 7.64776432145278, 8.576086166116959, 9.631337090363475, 10.676462337516725, 12.554013924702051, 13.495169064524942, 14.451928656353534, 13.653500043857523, 12.654659611050192, 11.715285391415154, 10.684082788917433, 9.880652614247639, 8.86498962546526, 7.857734904934266, 6.902587731793243, 6.010321929967824, 4.971138026090906, 5.8766902008065225, 6.651874120032474, 7.590507155558598, 8.540365888763343, 9.589488011142226, 10.556735241446642, 11.508564571118475, 13.429309426102485, 14.366723491122782, 15.389580837024562, 14.7038543183525, 13.664594806803125, 12.639152847880418, 11.690672070427846, 10.866458429414834, 9.880908079256553, 8.91641062457908, 7.961646544546618, 6.894564197115041, 5.9306609160189145, 6.864426500023279, 7.671780075974068, 8.601583424144977, 9.469399799266002, 10.404517875072711, 11.39809702823425, 12.40667971215633, 14.354885077526099, 15.303846697389623, 16.332151753419264, 15.656359174819562, 14.646856728563465, 13.69511154104442, 12.7446421414876, 11.865944861739528, 10.79493766436111, 9.85069319124714, 8.901053221858973, 7.83393389752759, 6.918996712176588, 7.83657970035847, 8.65060932220365, 9.662728286250765, 10.468495661019816, 11.397359010797018, 12.34395981009717, 13.376898528102362, 15.204728176235976, 16.266467866715132, 16.462200970027364, 15.536814052383523, 14.502890557334224, 13.751097197383125, 12.914697509140465, 12.004771827773519, 11.620945625924005, 10.69341181429429, 9.747264922638816, 8.794863521381172, 7.945769680899749, 8.854719215606648, 9.576470937221131, 10.555708459918936, 11.483041460803927, 12.395783997204632, 13.291641837554732, 14.2543851169753, 16.148758919031025, 16.431690502496007, 15.47050802590389, 14.509396391368027, 13.532118819683333, 12.780783755304006, 11.852486832925525, 10.966131064972735, 11.845119863162857, 11.635165722216252, 10.747856751398736, 9.818749128327687, 9.011473451854307, 9.868388384081433, 10.52895086065017, 11.483130007906887, 12.445295105438985, 13.371645934604526, 14.311197263251124, 15.18381544673814, 16.43462540173038, 15.465601728584236, 14.488196948752453, 13.478319445786545, 12.506762970803937, 11.754632928367009, 10.876195386034645, 9.98474908103957, 10.882200098277536, 11.70866039894172, 11.709162456372855, 10.750678534293302, 10.04463442256715, 10.872074091195929, 11.602309328765276, 12.53718919296266, 13.466775793063299, 14.405731117415321, 15.36175896268861, 16.120901676612686, 15.465206261093506, 14.445004934136337, 13.4513042509769, 12.523266659798875, 11.576002342304905, 10.712301818891923, 9.80966649402466, 8.980701059031981, 9.862836285634213, 10.67044589889164, 11.603567784062744, 11.773041366911297, 11.008520683802892, 11.900142243861486, 12.528183133849602, 13.515860360308725, 14.44357794300429, 15.477096428414354, 16.3501737963336, 16.484166349847793, 14.527126558333281, 13.52198748307109, 12.551283849710664, 11.57015877321147, 10.612269890617593, 9.768663354597924, 8.82645932988355, 8.004021451963968, 8.794030486159102, 9.724685421578585, 10.70189296048739, 11.627066419224432, 11.994227927158859, 12.833862740675803, 13.522915037974924, 14.477978064773133, 15.417361500075044, 16.47138433958942, 16.5182455726752, 15.503477824664763, 13.556938302452592, 12.619348913501652, 11.748560943431286, 10.679195282240055, 9.678527243325181, 8.704899373689058, 7.77804013054055, 6.952212399522119, 7.865066688882003, 8.86141969397196, 9.770642949670057, 10.749469121090025, 11.695684891255576, 12.767368409982975, 13.70008595832174, 14.650894505016845, 15.635207905739367, 16.429770093409633, 15.464825245555646, 14.486773091992404, 12.600880465805986, 11.672927353860343, 10.835530822969567, 9.79691106545137, 8.818613465822338, 7.748865698141113, 6.81620256361004, 5.962504699578652, 6.914302683252, 7.839424013504006, 8.819293391372529, 9.724240231586213, 10.79523480744354, 11.800844562816806, 12.739424526515002, 13.688616791899651, 14.726411322220514, 15.55815652180743, 14.583903209382402, 13.556485844198901, 11.709328327841874, 10.70336377093799, 9.783189327165013, 8.763604171973194, 7.808462210587843, 6.798710655211139, 5.8689405967876205, 4.920088825897051, 5.889105541940336, 6.903150001073573, 7.871176639301859, 8.796702969441489, 9.77373883915788, 10.816480962423178, 11.708279039489753, 12.751681985802481, 13.704281260385786, 14.687605759478007, 13.637886636528595, 12.752239763343471, 10.735160970089145, 9.76309620136414, 8.742513858073966, 7.774394358315113, 6.867330901640296, 5.852668783068323, 4.904017059468644, 3.966342663370314, 5.0053609317661065, 5.9720255424495265, 6.839873905795623, 7.88331527138624, 8.837553113202258, 9.85233803390849, 10.772336158596188, 11.790930814593057, 12.774638321531725, 13.652629930735772, 12.659206860119813, 11.712637419585858, 9.762279019187908, 8.820753638342348, 7.774292357323079, 6.778097528084149, 5.9421955859234235, 4.946149327999657, 3.9992614122415557, 2.9859421412158715, 3.941232032314483, 4.909909855107908, 5.868554854179066, 6.920161446384733, 7.813459709927698, 8.881370614098795, 9.808170061751051, 10.865022861480668, 11.818533593683698, 12.690364665123305, 11.74645888583418, 10.70929823206061, 8.85745175138206, 7.943762391613586, 6.891285744676737, 5.847227212871323, 4.9464467599865385, 4.014122958280069, 3.0251974921746476, 2.025779596607454, 3.0292675664249606, 4.0008547736887365, 4.951816304149775, 6.000217211867085, 6.87616185739717, 7.874059957963125, 8.872205072083911, 9.837686656141726, 10.817310969178893, 11.776267601412412, 10.825119207913819, 9.903295447957916, 7.857117081328967, 6.911296252231522, 5.933389376799603, 4.8745613099641965, 3.9426993180511705, 2.939319320716308, 2.085343835432917, 1.0624329806307762, 2.0348768315144956, 3.0017810377255865, 3.9982516688630962, 4.957096447181413, 5.917620920523347, 6.930041827256755, 7.930075767860962, 8.86475029369388, 9.818228859606435, 10.839354257365487, 9.854038717495726, 8.878815303238836, 7.040730168108002, 5.98007691788074, 4.9521929523483665, 4.005172427722897, 2.96134013420201, 1.9661049811070268, 1.021816782776657, 0.0, 1.0050317399987319, 1.9354531722206627, 2.9824027696663284, 3.9451355100352705, 5.004467334163564, 5.9651245687075996, 6.936248942224664, 7.911884591030762, 8.863046952071212, 9.918750063134205, 8.93668082451831, 7.990727476662677, 7.956871085301515, 6.898757614524952, 5.8753694118958135, 4.892750924408402, 3.86772190599389, 2.893237178284093, 1.9953842772853436, 0.9960645857902359, 2.047170312449488, 2.971403411270738, 3.9971474783998913, 4.904273168833027, 5.84928329188561, 6.828526074419194, 7.834355522454015, 8.853771486503934, 9.872998470477963, 10.813850799921358, 9.911958604765408, 8.945960400390529, 8.796859334339665, 7.785174348604489, 6.824522383938573, 5.777514412418528, 4.829219230314511, 3.8355530795462687, 2.9303040974314594, 1.9666642185691705, 2.908419624054671, 3.953825112229879, 5.016630851647429, 5.891257023566635, 6.777258110832061, 7.706676947303806, 8.774715029524788, 9.822313843357545, 10.811579182443785, 11.825837683532418, 10.9143258253391, 9.855706314387284], [11.764657756289477, 12.70709866516867, 11.72776165173146, 10.736886510258877, 9.708651870627829, 8.75353805958097, 7.726194245962993, 6.8148734438512015, 5.948373764319157, 5.081763257016001, 4.048477678932224, 3.1230660621078874, 3.923880016303703, 4.863382428829996, 5.7814852848677205, 6.769962904988617, 7.727348383962208, 8.751720981190484, 9.727742527979329, 10.754480124329437, 12.72727442177578, 13.737773592694426, 12.718274530035462, 11.778687911238423, 10.721974604408036, 9.732739977898225, 8.676320949583182, 7.864521399713192, 7.003919570712247, 5.944941220124742, 4.991545531694863, 4.18534585092095, 4.960954140414105, 5.825846019157368, 6.708613280438375, 7.775843709537254, 8.652796061451511, 9.581117906115688, 10.636368830362205, 11.681494077515454, 13.55904566470078, 14.500200804523672, 13.614634024022445, 12.648468303858792, 11.649627871051461, 10.710253651416423, 9.679051048918701, 8.923814283187934, 7.974793118831324, 6.96753839830033, 6.012391225159307, 5.185131160860808, 5.9761697660896385, 6.881721940805254, 7.656905860031205, 8.595538895557329, 9.545397628762075, 10.594519751140956, 11.561766981445372, 12.513596311117205, 14.434341166101216, 15.371755231121513, 14.598477945332524, 13.698822578353768, 12.659563066804393, 11.634121107881686, 10.685640330429115, 9.9762619227809, 8.990711572622619, 8.026214117945145, 7.0714500379126815, 6.173496026681456, 6.935692656017647, 7.86945824002201, 8.6768118159728, 9.606615164143708, 10.474431539264733, 11.409549615071443, 12.403128768232982, 13.411711452155062, 15.35991681752483, 16.308878437388355, 15.654459584877458, 14.65132743482083, 13.641824988564734, 12.69007980104569, 11.739610401488868, 11.040129495483558, 9.982837682746991, 9.076305734632902, 8.126665765244734, 7.112865727094006, 7.92402845217532, 8.841611440357202, 9.655641062202381, 10.667760026249496, 11.473527401018547, 12.40239075079575, 13.348991550095901, 14.381930268101094, 16.209759916234706, 17.271499606713864, 16.54860420386281, 15.623217286218967, 14.584387825185111, 13.721461592141535, 12.784286138350472, 11.909857008290544, 10.89987745549042, 9.972343643860706, 9.026196752205232, 8.073795350947588, 8.95080142089848, 9.85975095560538, 10.581502677219863, 11.560740199917667, 12.488073200802658, 13.400815737203363, 14.296673577553463, 15.259416856974031, 17.153790659029756, 17.403747571866283, 16.442565095274166, 15.481453460738303, 14.50417588905361, 13.752840824674282, 12.824543902295801, 11.938188134343013, 11.12359668007708, 10.914097551782667, 10.026788580965151, 9.097680957894102, 10.016505191853039, 10.873420124080164, 11.533982600648901, 12.488161747905618, 13.450326845437717, 14.376677674603258, 15.316229003249855, 16.188847186736872, 17.406682471100655, 16.437658797954512, 15.460254018122729, 14.45037651515682, 13.478820040174213, 12.726689997737285, 11.848252455404921, 10.956806150409848, 10.16067691519176, 10.96324589178867, 10.98809428593927, 10.029610363859717, 10.983514970012301, 11.87710583119466, 12.607341068764008, 13.542220932961392, 14.47180753306203, 15.410762857414053, 16.36679070268734, 17.125933416611417, 16.437263330463782, 15.417062003506613, 14.423361320347176, 13.49532372916915, 12.548059411675181, 11.6843588882622, 10.781723563394936, 9.952758128402259, 9.141313102548436, 9.925031391738589, 10.858153276909693, 11.051973196477713, 11.947401231248044, 12.886799836305777, 13.533214873848333, 14.520892100307456, 15.44860968300302, 16.482128168413084, 17.355205536332328, 17.48662686742529, 15.499183627703557, 14.494044552441366, 13.52334091908094, 12.542215842581745, 11.58432695998787, 10.7407204239682, 9.798516399253826, 8.976078521334246, 8.072507303073325, 8.979270914425534, 9.90317560943154, 10.828349068168583, 11.767309303247451, 12.713917843577983, 13.652287447613146, 14.64811388531701, 15.58749732061892, 16.66175594896844, 17.523277312673933, 16.508509564663495, 14.561970042451323, 13.624380653500383, 12.720618012801562, 11.651252351610331, 10.650584312695457, 9.676956443059334, 8.750097199910826, 7.924269468892396, 7.1435435057962255, 8.018562552674162, 8.927785808372256, 9.87027825366567, 10.816494023831222, 11.874863591855839, 12.695054218323008, 13.645862765018114, 14.630176165740636, 15.641798241867688, 16.469856985554376, 15.491804831991136, 13.605912205804717, 12.677959093859075, 11.840562562968302, 10.801942805450103, 9.790670535192614, 8.72092276751139, 7.788259632980317, 6.934561768948929, 6.192779500166223, 6.996566872206206, 7.976436250074729, 8.815309214916386, 9.814948370869667, 10.820558126242933, 11.73439278651627, 12.68358505190092, 13.721379582221783, 14.648193410735125, 15.588934949381134, 14.561517584197633, 12.714360067840605, 11.708395510936722, 10.788221067163745, 9.768635911971927, 8.78051927995812, 7.770767724581417, 6.8409976661578975, 5.892145895267328, 5.167582358854559, 5.994218984403748, 6.962245622632033, 7.887771952771662, 8.76870709915915, 9.811449222424447, 10.703247299491021, 11.74665024580375, 12.699249520387054, 13.687949903681734, 14.642918376527327, 13.757271503342203, 11.740192710087877, 10.768127941362872, 9.747545598072698, 8.779426098313845, 7.839387971010574, 6.8247258524386005, 5.876074128838921, 4.93839973274059, 4.180610648887391, 5.063094525779701, 5.921519472318287, 6.964960837908904, 7.832521373203527, 8.847306293909758, 9.767304418597456, 10.785899074594326, 11.769606581532994, 12.758293958617573, 13.664238600118544, 12.71766915958459, 10.767310759186639, 9.82578537834108, 8.77932409732181, 7.78312926808288, 6.930287872399634, 5.934241614475868, 4.971318481611833, 3.9579992105861486, 3.116481749435767, 4.000978838438082, 4.950200420701729, 5.97875888056227, 6.808427969928966, 7.876338874100064, 8.80313832175232, 9.859991121481936, 10.813501853684967, 11.818602889201337, 12.751490625832911, 11.71432997205934, 9.862483491380791, 8.948794131612319, 7.8963174846754685, 6.852258952870055, 5.95147849998527, 5.0191546982788005, 3.9972545615449246, 2.997836665977731, 2.056436934027799, 2.995823033690005, 3.946784564151043, 4.9951854718683535, 5.871130117398438, 6.869028217964393, 7.86717333208518, 8.832654916142994, 9.812279229180161, 10.77123586141368, 11.79948702558065, 10.908327187956647, 8.862148821327699, 7.916327992230253, 6.9384211167983345, 5.879593049962928, 4.947731058049902, 3.94435106071504, 3.0574009048031945, 2.0344900500010534, 1.0620461991173338, 1.9967492977268548, 2.993219928864365, 3.9520647071826804, 4.9125891805246145, 5.925010087258023, 6.9250440278622305, 7.859718553695149, 8.813197119607704, 9.843090995292796, 10.828406535162557, 9.883847043237568, 8.045761908106734, 6.985108657879471, 5.957224692347098, 5.0102041677216285, 3.9663718742007417, 2.9711367211057587, 2.026848522775389, 1.0050317399987319, 0.0, 0.9304214322219309, 1.9773710296675966, 2.9401037700365382, 3.9994355941648325, 4.960092828708867, 5.931217202225932, 6.90685285103203, 7.8580152120724795, 8.913718323135473, 9.941712564517042, 8.995759216661408, 8.961902825300246, 7.903789354523683, 6.880401151894545, 5.897782664407133, 4.8727536459926215, 3.8982689182828247, 3.0004160172840755, 2.001096325788968, 1.052935424980622, 1.9663716712720058, 2.99211573840116, 3.899241428834295, 4.844251551886877, 5.823494334420461, 6.829323782455282, 7.848739746505201, 8.86796673047923, 9.808819059922625, 10.753385976256984, 9.95099214038926, 9.801891074338396, 8.79020608860322, 7.829554123937305, 6.782546152417259, 5.834250970313242, 4.8405848195450005, 3.935335837430191, 2.9716959585679024, 2.0832288549476554, 3.039290328754938, 4.011599111648698, 4.886225283567903, 5.772226370833328, 6.701645207305074, 7.769683289526055, 8.817282103358812, 9.806547442445051, 10.820805943533685, 11.819810573774324, 10.860738054386015], [12.677980001349745, 11.77667723294674, 10.797340219509529, 9.806465078036947, 8.778230438405899, 7.823116627359039, 6.795772813741062, 5.8844520116292705, 5.017952332097227, 4.15134182479407, 3.1180562467102937, 4.053487494329818, 4.854301448525634, 5.793803861051926, 6.711906717089652, 7.700384337210547, 8.657769816184139, 9.682142413412414, 10.65816396020126, 11.684901556551367, 13.657695853997712, 12.807352160472496, 11.787853097813532, 10.848266479016493, 9.791553172186106, 8.802318545676295, 7.74589951736125, 6.934099967491261, 6.073498138490317, 5.014519787902811, 4.0611240994729325, 5.0211661731780834, 5.891375572636036, 6.756267451379299, 7.639034712660306, 8.706265141759184, 9.583217493673443, 10.51153933833762, 11.566790262584137, 12.611915509737386, 14.489467096922713, 13.640972183629106, 12.684212591800515, 11.718046871636862, 10.71920643882953, 9.779832219194493, 8.74862961669677, 7.993392850966003, 7.044371686609394, 6.0371169660784, 5.081969792937377, 6.012762781726547, 6.906591198311569, 7.812143373027184, 8.587327292253136, 9.52596032777926, 10.475819060984005, 11.524941183362888, 12.492188413667304, 13.444017743339137, 15.364762598323146, 14.652062122750309, 13.668056513110594, 12.768401146131836, 11.729141634582462, 10.703699675659754, 9.755218898207183, 9.04584049055897, 8.060290140400689, 7.0957926857232145, 6.141028605690751, 7.001127647547195, 7.866114088239577, 8.799879672243941, 9.60723324819473, 10.537036596365638, 11.404852971486664, 12.339971047293373, 13.333550200454912, 14.342132884376992, 16.29033824974676, 15.59107604472796, 14.724038152655528, 13.720906002598898, 12.711403556342802, 11.759658368823757, 10.809188969266936, 10.109708063261628, 9.052416250525061, 8.14588430241097, 7.196244333022803, 7.940497347959745, 8.854449884397251, 9.772032872579134, 10.586062494424311, 11.598181458471426, 12.403948833240477, 13.33281218301768, 14.279412982317831, 15.312351700323024, 17.140181348456636, 16.5674206680759, 15.618182771640875, 14.692795853997035, 13.653966392963179, 12.791040159919604, 11.85386470612854, 10.99434916096037, 9.984369608160247, 9.11435611726371, 8.168209225608237, 8.901426971813327, 9.881222853120413, 10.790172387827312, 11.511924109441793, 12.491161632139598, 13.418494633024588, 14.331237169425293, 15.227095009775393, 16.18983828919596, 18.084212091251686, 17.566256004161872, 16.692002852553475, 15.693631196263336, 14.62473813061407, 13.761353601998723, 12.91607538234348, 12.014840549825234, 11.004874884101907, 10.056110025185673, 9.189673311575712, 9.925312578759842, 10.907480419931407, 11.803841556302096, 12.464404032870831, 13.418583180127548, 14.380748277659647, 15.307099106825188, 16.246650435471786, 17.119268618958802, 18.33710390332259, 17.368080230176442, 16.390675450344663, 15.380797947378753, 14.409241472396145, 13.657111429959217, 12.778673887626855, 11.88722758263178, 10.953923102484058, 10.032824459566736, 10.150979016549831, 10.857241984725457, 11.811146590878039, 12.807527263416592, 13.537762500985938, 14.472642365183322, 15.40222896528396, 16.341184289635983, 17.297212134909273, 18.056354848833347, 17.367684762685716, 16.347483435728545, 15.353782752569108, 14.425745161391083, 13.478480843897113, 12.614780320484131, 11.71214499561687, 10.88317956062419, 9.934559289840735, 8.994609959516657, 9.927731844687761, 10.887437389322285, 11.822595114381487, 12.71721690817037, 13.716597919516538, 14.679810157559487, 15.607527740255051, 16.681102778589022, 17.730557957566916, 18.417048299647224, 16.42960505992549, 15.424465984663296, 14.45376235130287, 13.472637274803677, 12.514748392209802, 11.671141856190133, 10.72893783147576, 9.906499953556178, 8.870994573143383, 8.048849482203602, 8.97275417720961, 9.897927635946653, 10.836887871025521, 11.783496411356053, 12.721866015391216, 13.71769245309508, 14.65707588839699, 15.73133451674651, 16.693661213762727, 17.43893099688542, 15.492391474673251, 14.554802085722311, 13.651039445023493, 12.581673783832262, 11.58100574491739, 10.607377875281266, 9.68051863213276, 8.854690901114328, 7.942030775866284, 7.08814112045223, 7.997364376150325, 8.93985682144374, 9.886072591609292, 10.944442159633908, 11.764632786101078, 12.715441332796184, 13.699754733518706, 14.711376809645758, 15.627378214046352, 16.422226264213062, 14.536333638026646, 13.608380526081003, 12.770983995190228, 11.732364237672032, 10.721091967414546, 9.651344199733321, 8.718681065202249, 7.864983201170861, 6.991266770236281, 6.066145439984275, 7.0460148178527975, 7.884887782694455, 8.884526938647738, 9.890136694021002, 10.80397135429434, 11.75316361967899, 12.790958149999852, 13.717771978513195, 14.692025290938222, 15.491939016419561, 13.644781500062534, 12.63881694315865, 11.718642499385673, 10.699057344193855, 9.710940712180054, 8.70118915680335, 7.7714190983798295, 6.82256732748926, 6.083608198929572, 5.063797552181817, 6.031824190410102, 6.957350520549731, 7.83828566693722, 8.881027790202516, 9.772825867269091, 10.81622881358182, 11.768828088165124, 12.757528471459803, 13.807247594409215, 14.687692935564131, 12.670614142309805, 11.6985493735848, 10.677967030294626, 9.709847530535773, 8.769809403232506, 7.7551472846605325, 6.806495561060853, 5.868821164962522, 5.1033641284612, 4.13267309355777, 4.991098040096356, 6.034539405686973, 6.902099940981596, 7.916884861687828, 8.836882986375526, 9.855477642372396, 10.839185149311064, 11.827872526395643, 12.868417145138377, 13.648090591806518, 11.697732191408567, 10.756206810563008, 9.709745529543738, 8.71355070030481, 7.860709304621564, 6.864663046697798, 5.901739913833764, 4.88842064280808, 4.039235229009576, 3.0705574062161514, 4.019778988479798, 5.048337448340339, 5.878006537707035, 6.945917441878134, 7.872716889530389, 8.929569689260006, 9.883080421463037, 10.888181456979407, 11.832087236268531, 12.64475140428127, 10.792904923602723, 9.879215563834249, 8.8267389168974, 7.782680385091985, 6.8818999322072, 5.9495761305007315, 4.927675993766856, 3.928258098199662, 2.9868583662497294, 2.065401601468074, 3.0163631319291118, 4.064764039646422, 4.940708685176507, 5.938606785742463, 6.93675189986325, 7.902233483921064, 8.881857796958231, 9.84081442919175, 10.86906559335872, 11.83874862017858, 9.79257025354963, 8.846749424452184, 7.868842549020265, 6.810014482184858, 5.878152490271832, 4.8747724929369705, 3.9878223370251247, 2.964911482222984, 1.9924676313392646, 1.066327865504924, 2.0627984966424338, 3.02164327496075, 3.9821677483026843, 4.994588655036093, 5.9946225956403, 6.929297121473219, 7.882775687385774, 8.912669563070866, 9.897985102940627, 10.8142684754595, 8.976183340328664, 7.915530090101401, 6.887646124569028, 5.940625599943559, 4.896793306422672, 3.9015581533276893, 2.9572699549973196, 1.9354531722206627, 0.9304214322219309, 0.0, 1.0469495974456657, 2.0096823378146076, 3.069014161942902, 4.029671396486937, 5.000795770004002, 5.9764314188101, 6.927593779850549, 7.983296890913542, 9.031880753023477, 9.926180648883339, 9.892324257522176, 8.834210786745613, 7.810822584116475, 6.828204096629063, 5.803175078214553, 4.828690350504756, 3.930837449506006, 2.931517758010899, 1.9833568572025528, 1.035950239050075, 2.0616943061792288, 2.9688199966123645, 3.9138301196649463, 4.89307290219853, 5.898902350233351, 6.91831831428327, 7.9375452982573, 8.878397627700695, 9.822964544035054, 10.788962748409933, 10.732312506560328, 9.720627520825152, 8.759975556159237, 7.71296758463919, 6.764672402535173, 5.771006251766932, 4.865757269652121, 3.9021173907898334, 3.013650287169586, 2.1088688965330076, 3.0811776794267667, 3.9558038513459723, 4.841804938611397, 5.7712237750831425, 6.839261857304124, 7.88686067113688, 8.87612601022312, 9.890384511311755, 10.889389141552394, 11.715801189131776], [11.631030403904079, 10.729727635501076, 9.750390622063865, 8.759515480591283, 7.731280840960234, 6.776167029913374, 5.7488232162953965, 4.837502414183605, 3.9710027346515613, 3.104392227348404, 4.114982582023662, 5.1004370917754835, 5.901251045971299, 6.840753458497592, 7.7588563145353175, 8.747333934656213, 9.704719413629805, 10.72909201085808, 11.705113557646927, 12.64120803586412, 12.649936181550656, 11.760402563026831, 10.740903500367867, 9.801316881570829, 8.744603574740438, 7.755368948230629, 6.698949919915585, 5.887150370045596, 5.026548541044651, 4.141199824536231, 5.0580504347863, 6.018092508491451, 6.9383251700817015, 7.803217048824965, 8.685984310105972, 9.75321473920485, 10.630167091119109, 11.558488935783286, 12.613739860029803, 13.658865107183052, 13.53517772600633, 12.594022586183439, 11.637262994354847, 10.671097274191194, 9.672256841383863, 8.732882621748828, 7.701680019251105, 6.9464432535203375, 6.042985732750756, 5.163797002711819, 6.0788961282507445, 7.0096891170399145, 7.953540795757235, 8.859092970472851, 9.634276889698802, 10.572909925224925, 11.522768658429671, 12.571890780808554, 13.53913801111297, 14.490967340784803, 14.542526590324938, 13.60511252530464, 12.621106915664926, 11.721451548686172, 10.682192037136797, 9.65675007821409, 8.708269300761518, 8.013511413509892, 7.058904186542049, 6.222472722356634, 7.13795494100412, 7.998053982860562, 8.913063685685243, 9.846829269689607, 10.654182845640396, 11.583986193811304, 12.45180256893233, 13.386920644739039, 14.380499797900578, 15.389082481822658, 15.468102241748552, 14.544126447282292, 13.67708855520986, 12.673956405153234, 11.664453958897138, 10.712708771378093, 9.762239371821272, 9.077378986212551, 8.051030296666422, 7.2890113582013285, 8.193170668336172, 8.937423683273112, 9.901399481842917, 10.8189824700248, 11.633012091869977, 12.645131055917092, 13.450898430686145, 14.379761780463348, 15.326362579763497, 16.359301297768692, 16.476204335144576, 15.520471070630236, 14.57123317419521, 13.645846256551371, 12.607016795517515, 11.74409056247394, 10.806915108682876, 9.992963207101731, 8.982983654301608, 8.337952746129243, 9.165135560921605, 9.898353307126694, 10.888872278664856, 11.81783122699998, 12.558873706887459, 13.538111229585263, 14.465444230470254, 15.37818676687096, 16.274044607221057, 17.236787886641626, 17.420235077939626, 16.519306406716208, 15.645053255107813, 14.646681598817672, 13.577788533168405, 12.714404004553058, 11.869125784897816, 11.013454595966595, 10.003488930243268, 9.279706654051205, 10.18659964688908, 10.922238914073208, 11.904406755244773, 12.831500395474764, 13.511353630316497, 14.465532777573213, 15.427697875105313, 16.354048704270856, 17.29360003291745, 18.166218216404467, 18.431466451224217, 17.50158908063661, 16.584578359996318, 15.57470085703041, 14.603144382047802, 13.740554831490055, 12.845417231788696, 11.99483657989976, 10.966408695128589, 10.221180690661862, 9.960441363314077, 10.916853219520343, 11.793534373197293, 12.75233805841599, 13.595522127155197, 14.566519292063338, 15.496105892163976, 16.435061216516, 17.486115431673184, 18.47211233908287, 18.334706223874964, 17.31450489691779, 16.320804213758354, 15.392766622580329, 14.44550230508636, 13.581801781673377, 12.678743894155915, 11.7300815434784, 10.773488765100526, 9.833539434776448, 8.948398171602305, 9.894490386902348, 10.82964811196155, 11.724269905750432, 12.669648322070872, 13.632860560113821, 14.560578142809385, 15.634153181143358, 16.68360836012125, 17.55587402801932, 17.396626521114737, 16.391487445852544, 15.420783812492118, 14.439658735992923, 13.481769853399047, 12.638163317379378, 11.695536730014805, 10.753401936410388, 9.709924048403174, 8.887778957463393, 7.9798071747896735, 8.904980633526716, 9.843940868605584, 10.790549408936116, 11.67491641794555, 12.670742855649413, 13.610126290951325, 14.684384919300843, 15.646711616317063, 16.57518550283629, 16.50086557115171, 15.562180572295667, 14.61806090621274, 13.54869524502151, 12.548027206106635, 11.574399336470512, 10.647540093322004, 9.746839703010025, 8.780960251126075, 7.927070595712021, 7.004417373730388, 7.911632995400402, 8.857848765565954, 9.897492562188244, 10.717683188655412, 11.668491735350518, 12.65280513607304, 13.664427212200092, 14.580428616600688, 15.55848077016393, 15.583283235472313, 14.65533012352667, 13.774120911995723, 12.735501154477527, 11.688113428603792, 10.618365660922567, 9.685702526391495, 8.832004662360108, 7.830196245496072, 6.905074915244066, 6.05306781543286, 6.856663956651118, 7.837577341202072, 8.843187096575338, 9.757021756848674, 10.706214022233324, 11.744008552554186, 12.670822381067529, 13.645075693492556, 14.672493058676057, 14.691731097508201, 13.685766540604318, 12.765592096831341, 11.743270961527077, 10.6779621733693, 9.668210617992596, 8.738440559569076, 7.789588788678506, 6.922537674189363, 5.902727027441608, 5.003600364366765, 5.929126694506394, 6.791336069491554, 7.83407819275685, 8.725876269823425, 9.769279216136153, 10.721878490719458, 11.710578874014137, 12.76029799696355, 13.729867352211116, 13.717563739755473, 12.745498971030468, 11.724916627740294, 10.756797127981441, 9.736830864421751, 8.722168745849778, 7.773517022250099, 6.835842626151768, 5.9642811123503385, 4.971602568817561, 3.9441484426506896, 4.987589808241307, 5.8551503435359304, 6.869935264242162, 7.78993338892986, 8.808528044926728, 9.792235551865396, 10.780922928949975, 11.82146754769271, 12.768036988226664, 12.744681788854235, 11.803156408008675, 10.756695126989406, 9.760500297750477, 8.838906454075328, 7.8428601961515625, 6.879937063287528, 5.855442103997326, 4.900152212898715, 3.9314743901052904, 2.9728293910341326, 4.001387850894673, 4.8310569402613694, 5.898967844432468, 6.825767292084723, 7.8826200918143385, 8.83613082401737, 9.84123185953374, 10.785137638822865, 11.816482285524188, 11.839854521048391, 10.926165161279917, 9.873688514343067, 8.829629982537652, 7.928849529652867, 6.996525727946398, 5.974625591212522, 4.975207695645328, 4.033807963695395, 3.0099890120394592, 1.969413534483446, 3.0178144422007565, 3.8937590877308415, 4.891657188296797, 5.889802302417584, 6.855283886475397, 7.834908199512565, 8.793864831746085, 9.822115995913052, 10.808564994074231, 10.839519850995298, 9.893699021897852, 8.915792146465932, 7.856964079630525, 6.925102087717499, 5.921722090382637, 5.034771934470791, 4.01186107966865, 3.0394172287849304, 2.08397712240974, 1.015848899196768, 1.974693677515084, 2.9352181508570183, 3.9476390575904268, 4.9476729981946335, 5.882347524027552, 6.835826089940106, 7.865719965625199, 8.85103550549496, 9.826258919751849, 9.880881811988118, 8.96247968754707, 7.934595722014696, 6.987575197389226, 5.943742903868339, 4.948507750773356, 4.0042195524429856, 2.9824027696663284, 1.9773710296675966, 1.0469495974456657, 0.0, 0.9627327403689419, 2.022064564497236, 2.982721799041271, 3.9538461725583356, 4.929481821364433, 5.8806441824048825, 6.936347293467875, 7.984931155577811, 8.930884503433443, 10.736813368547468, 9.88116038419128, 8.85777218156214, 7.875153694074729, 6.8501246756602185, 5.875639947950422, 4.977787046951672, 3.9784673554565644, 3.0303064546482186, 2.0828998364957405, 1.014744708733563, 1.9218703991666988, 2.866880522219281, 3.8461233047528647, 4.851952752787685, 5.871368716837604, 6.890595700811634, 7.831448030255029, 8.776014946589388, 9.742013150964267, 11.727698571733729, 10.767577118270818, 9.806925153604903, 8.759917182084857, 7.811621999980839, 6.817955849212598, 5.912706867097787, 4.949066988235499, 4.060599884615252, 3.1057952318463755, 2.034228081981101, 2.908854253900307, 3.794855341165732, 4.7242741776374775, 5.792312259858459, 6.839911073691214, 7.8291764127774535, 8.843434913866089, 9.842439544106728, 10.66885159168611], [10.668297663535137, 9.766994895132134, 8.787657881694923, 7.796782740222341, 6.768548100591292, 5.813434289544432, 4.786090475926454, 3.8747696738146633, 3.008269994282619, 4.0326962720282244, 5.051621966184469, 6.042039320535727, 6.863983786340241, 7.803486198866534, 8.721589054904259, 9.710066675025155, 10.667452153998747, 11.691824751227022, 12.667846298015867, 11.678475295495177, 11.687203441181714, 10.79766982265789, 9.778170759998925, 8.838584141201887, 7.781870834371497, 6.792636207861687, 5.736217179546643, 4.924417629676654, 4.063815800675709, 5.069503869216051, 5.994689818947108, 6.9547318926522586, 7.9010579104506435, 8.765949789193908, 9.648717050474913, 10.715947479573792, 11.592899831488051, 12.521221676152228, 13.576472600398745, 12.73298378544204, 12.572444985637388, 11.631289845814496, 10.674530253985905, 9.708364533822252, 8.709524101014921, 7.7701498813798855, 6.738947278882163, 5.9837105131513955, 5.080252992381814, 6.087507712912808, 7.015535512411552, 7.946328501200722, 8.916273536126177, 9.821825710841793, 10.597009630067742, 11.535642665593866, 12.485501398798611, 13.534623521177496, 14.501870751481912, 13.617894339220964, 13.579793849955996, 12.642379784935699, 11.658374175295984, 10.75871880831723, 9.719459296767855, 8.694017337845148, 7.745536560392575, 7.05077867314095, 6.096171446173107, 7.072896837007572, 8.073347882704478, 8.934693367021369, 9.875796426054185, 10.80956201005855, 11.616915586009336, 12.546718934180245, 13.41453530930127, 14.34965338510798, 15.343232538269518, 14.60242356390215, 14.50536950137961, 13.58139370691335, 12.714355814840918, 11.711223664784292, 10.701721218528196, 9.749976031009151, 8.79950663145233, 8.114646245843609, 7.08829755629748, 8.032542029411449, 8.982181998799616, 9.87406306743392, 10.86413222221186, 11.781715210393742, 12.595744832238918, 13.607863796286033, 14.413631171055084, 15.342494520832286, 16.28909532013244, 15.559112320971584, 15.513471594775632, 14.557738330261294, 13.608500433826269, 12.683113516182429, 11.644284055148573, 10.781357822104997, 9.844182368313934, 9.030230466732789, 8.020250913932665, 8.94778472556238, 9.893931617217854, 10.834992691287502, 11.825511662825663, 12.754470611160787, 13.5216064472564, 14.500843969954204, 15.428176970839194, 16.3409195072399, 17.23677734759, 16.46381465403631, 16.45750233757068, 15.556573666347267, 14.682320514738871, 13.68394885844873, 12.615055792799463, 11.751671264184116, 10.906393044528874, 10.050721855597653, 9.040756189874326, 9.889538633484342, 10.915395703185329, 11.032413089988935, 11.951303696817506, 12.880632118437857, 13.706147854901362, 14.65784573675017, 15.589947416563376, 16.534374013260695, 17.542766306817086, 17.39324498379915, 17.468733710855272, 16.538856340267667, 15.621845619627376, 14.611968116661467, 13.64041164167886, 12.777822091121113, 11.882684491419754, 11.032103839530818, 10.003675954759647, 10.831012670095, 10.887391216401538, 10.10048368402332, 10.918142726104664, 11.876946411323361, 12.632789386786255, 13.603786551694396, 14.533373151795034, 15.472328476147057, 16.52338269130424, 17.509379598713924, 17.5224345103339, 17.44017486200932, 16.446474178849886, 15.51843658767186, 14.571172270177891, 13.820153200596199, 12.94921338342974, 11.987610403422476, 11.02303976740297, 10.79627217514539, 9.875348024689766, 9.078120851405325, 9.954256464868921, 10.848878258657804, 11.70691558170193, 12.670127819744879, 13.597845402440443, 14.671420440774416, 15.72087561975231, 16.593141287650376, 16.58435480757367, 17.354220186221486, 16.38351655286106, 15.402391476361865, 14.44450259376799, 13.60089605774832, 12.658269470383747, 11.71613467677933, 10.672656788772116, 9.850511697832335, 8.906757027877134, 8.088611098029693, 8.968549221512955, 9.915157761843487, 10.712183677576608, 11.708010115280471, 12.647393550582382, 13.721652178931901, 14.683978875948121, 15.612452762467347, 15.538132830782766, 16.52491331266461, 15.580793646581682, 14.511427985390451, 13.510759946475577, 12.537132076839454, 11.610272833690946, 10.709572443378967, 9.743692991495017, 8.889803336080963, 7.93136722681785, 7.0302373970241865, 7.944528636982792, 8.934759821819302, 9.75495044828647, 10.705758994981576, 11.690072395704098, 12.70169447183115, 13.617695876231746, 14.595748029794988, 14.66536569670003, 15.593318808645673, 14.736853652364665, 13.698233894846469, 12.650846168972734, 11.58109840129151, 10.648435266760437, 9.79473740272905, 8.792928985865014, 7.867807655613008, 6.980017668520322, 5.975268358274902, 6.87484460083313, 7.880454356206395, 8.794289016479732, 9.743481281864382, 10.781275812185244, 11.708089640698587, 12.682342953123614, 13.709760318307115, 13.772993172044144, 14.648499280973258, 13.728324837200281, 12.70600370189602, 11.640694913738242, 10.630943358361538, 9.701173299938018, 8.752321529047448, 7.885270414558305, 6.86545976781055, 5.966333104735707, 5.047731096130178, 5.828603329122612, 6.871345452387908, 7.763143529454483, 8.806546475767211, 9.759145750350516, 10.747846133645195, 11.797565256594607, 12.767134611842174, 12.773650708929187, 13.708231711399408, 12.687649368109234, 11.719529868350381, 10.699563604790693, 9.68490148621872, 8.73624976261904, 7.79857536652071, 6.927013852719281, 5.934335309186503, 4.906881183019632, 4.067156636752839, 4.892417603166988, 5.90720252387322, 6.827200648560918, 7.845795304557786, 8.829502811496454, 9.818190188581033, 10.858734807323767, 11.805304247857721, 11.80076875802795, 12.74229413887351, 11.719427867358347, 10.723233038119417, 9.80163919444427, 8.805592936520505, 7.84266980365647, 6.818174844366268, 5.862884953267657, 4.894207130474232, 3.935562131403074, 3.0391880176661443, 3.868324199892428, 4.936235104063526, 5.863034551715781, 6.919887351445397, 7.8733980836484285, 8.878499119164799, 9.822404898453923, 10.853749545155248, 10.88459038994155, 11.875239554347724, 10.836421254712008, 9.792362722906592, 8.891582270021809, 7.95925846831534, 6.937358331581463, 5.937940436014269, 4.996540704064337, 3.972721752408401, 2.932146274852388, 2.0556146089722276, 2.9310263473619, 3.928924447927855, 4.927069562048642, 5.892551146106456, 6.872175459143623, 7.831132091377142, 8.859383255544111, 9.845832253705291, 9.884255719888458, 10.830076548985904, 9.878524886834873, 8.819696819999466, 7.88783482808644, 6.8844548307515785, 5.997504674839732, 4.974593820037591, 4.002149969153872, 3.0467098627786817, 1.9785816395657099, 1.0119609371461422, 1.9724854104880767, 2.984906317221485, 3.9849402578256923, 4.919614783658611, 5.873093349571166, 6.9029872252562585, 7.888302765126019, 8.863526179382909, 8.918149071619178, 9.925212427916009, 8.897328462383635, 7.950307937758167, 6.90647564423728, 5.911240491142297, 4.966952292811927, 3.94513551003527, 2.9401037700365382, 2.0096823378146076, 0.9627327403689419, 0.0, 1.0593318241282943, 2.019989058672329, 2.9911134321893935, 3.9667490809954917, 4.917911442035941, 5.973614553098934, 7.0221984152088694, 7.968151763064503, 9.774080628178526, 10.832194098955089, 9.820504921931082, 8.837886434443671, 7.81285741602916, 6.838372688319363, 5.940519787320613, 4.941200095825506, 3.99303919501716, 3.024130140617844, 1.9525338819739015, 0.9591376587977569, 1.9041477818503387, 2.8833905643839226, 3.8892200124187433, 4.908635976468662, 5.927862960442692, 6.868715289886087, 7.813282206220445, 8.779280410595325, 10.764965831364787, 11.730309858639759, 10.769657893973843, 9.722649922453797, 8.77435474034978, 7.780688589581539, 6.875439607466729, 5.911799728604441, 5.023332624984194, 4.042434616007183, 2.9708674661419083, 1.9461215135313648, 2.83212260079679, 3.7615414372685354, 4.829579519489517, 5.877178333322272, 6.866443672408511, 7.880702173497146, 8.879706803737784, 9.706118851317168], [9.621036186436276, 8.802412683004226, 7.8269180342796645, 6.8557783721048065, 5.827543732473758, 4.872429921426898, 3.8947729661311907, 2.9834521640193996, 3.9231093012185, 4.947535578964105, 6.000848255145109, 6.9912656094963666, 7.923315610468536, 8.86281802299483, 9.780920879032553, 10.76939849915345, 11.726783978127042, 12.64401310964031, 11.657951414746424, 10.631213818396317, 10.639941964082853, 9.836929975242631, 8.817430912583667, 7.897579773084352, 6.840866466253963, 5.851631839744153, 4.8448996697513795, 4.03310011988139, 4.97865510761159, 5.984343176151932, 6.937738864581812, 7.897780938286963, 8.956590878013984, 9.825281613322202, 10.708048874603207, 11.775279303702087, 12.652231655616346, 13.580553500280523, 12.706041410578953, 11.685722308343179, 11.631440617519852, 10.69028547769696, 9.73352588586837, 8.767360165704718, 7.768519732897387, 6.878832371584622, 5.8476297690868995, 5.092393003356132, 5.995092299317695, 7.002347019848689, 7.958584558046256, 8.889377546835426, 9.941647776406668, 10.881157534970088, 11.656341454196037, 12.59497448972216, 13.544833222926906, 14.59395534530579, 13.628719300775261, 12.676889971103428, 12.63878948183846, 11.701375416818163, 10.71736980717845, 9.831914532810442, 8.82814178697259, 7.802699828049883, 6.854219050597312, 6.159461163345687, 7.011010753108988, 7.987736143943453, 8.98818718964036, 9.877742412656074, 10.8416456937522, 11.80419413410795, 12.67624741013763, 13.60605075830854, 14.473867133429565, 15.408985209236274, 14.614553489119706, 13.661419195784614, 13.564365133262074, 12.640389338795814, 11.773351446723385, 10.819906154989027, 9.810403708732931, 8.858658521213886, 7.908189121657065, 7.2233287360483445, 8.003136863233362, 8.94738133634733, 9.897021305735498, 10.817112113068625, 11.829981489909875, 12.776347334443143, 13.655076656367212, 14.667195620414327, 15.47296299518338, 16.401826344960583, 15.560416270982625, 14.618107952854048, 14.572467226658096, 13.66642082046603, 12.717182924031004, 11.791796006387164, 10.752966545353308, 9.890040312309733, 8.95286485851867, 8.185635603182808, 8.935090220868547, 9.862624032498262, 10.808770924153736, 11.76117232541138, 11.976003820413538, 12.853297639554116, 13.617624130971876, 14.59686165366968, 15.511197413839911, 16.469232303302068, 16.48555356533934, 15.522810285918773, 15.516497969453145, 14.665256156552003, 13.791003004943606, 12.792631348653465, 11.723738283004199, 10.860353754388852, 10.01507553473361, 9.224276365983592, 9.955595496810208, 10.804377940420224, 11.83023501012121, 11.759359007147355, 10.91030004945898, 11.839628471079331, 12.665144207542838, 13.616842089391646, 14.548943769204852, 15.493370365902173, 16.501762659458564, 16.452240615681614, 16.527729342737736, 15.647538830472405, 14.730528109832111, 13.720650606866203, 12.749094131883595, 11.886504581325848, 10.99136698162449, 10.205658349916757, 10.918515261695529, 11.745851977030881, 11.614337133559955, 10.82742960118174, 9.877139078746138, 10.835942763964836, 11.591785739427731, 12.562782904335872, 13.49236950443651, 14.431324828788533, 15.482379043945715, 16.468375951355398, 16.481430862975373, 16.548857352214057, 15.555156669054622, 14.627119077876596, 13.679854760382627, 12.928835690800934, 12.057895873634475, 11.209706371924346, 11.937879074338852, 11.535415827019287, 10.602293941848183, 9.805066768563744, 8.913252817510395, 9.807874611299278, 10.665911934343406, 11.629124172386355, 12.55684175508192, 13.630416793415892, 14.679871972393784, 15.55213764029185, 15.543351160215147, 16.50793593849418, 16.58260117116301, 15.601476094663814, 14.643587212069939, 13.872474155094933, 13.041103037775585, 12.186385978992359, 11.475427002618076, 10.610910483944357, 9.633702945035552, 8.815557015188112, 7.92754557415443, 8.874154114484961, 9.671180030218084, 10.667006467921947, 11.606389903223858, 12.680648531573379, 13.642975228589595, 14.571449115108821, 14.49712918342424, 15.498736720928457, 16.442856387011382, 15.43523847545142, 14.434570436536546, 13.460942566900423, 12.50388545791249, 11.512342657224927, 10.546463205340977, 9.659778146246225, 8.658313143976267, 7.757183314182605, 6.903524989624268, 7.893756174460778, 8.713946800927946, 9.664755347623052, 10.649068748345574, 11.660690824472626, 12.57669222887322, 13.554744382436462, 13.624362049341507, 14.552315161287149, 15.570208035762093, 14.622044384907438, 13.574656659033703, 12.504908891352478, 11.572245756821406, 10.6267999690495, 9.595699199710975, 8.670577869458969, 7.70696358567874, 6.70221427543332, 5.833840953474606, 6.839450708847871, 7.753285369121208, 8.702477634505858, 9.74027216482672, 10.667085993340063, 11.64133930576509, 12.668756670948591, 12.713661347915851, 13.633981244001799, 14.667649900460797, 13.641561112846649, 12.576252324688873, 11.566500769312169, 10.63673071088865, 9.657057344447551, 8.688040628404266, 7.668229981656511, 6.7002033434282255, 5.7746770132885965, 4.787599681764088, 5.830341805029384, 6.722139882095959, 7.765542828408687, 8.718142102991992, 9.706842486286671, 10.756561609236083, 11.72613096448365, 11.714318884800894, 12.693713674427949, 13.62697443136975, 12.658854931610897, 11.635121015741325, 10.620458897169351, 9.671807173569672, 8.734132777471341, 7.862571263669912, 6.869892720137134, 5.842438593970263, 4.878016709801635, 3.851413955808465, 4.866198876514697, 5.786197001202394, 6.786463480429491, 7.770170987368159, 8.758858364452738, 9.799402983195472, 10.745972423729427, 10.741436933899656, 11.682962314745216, 12.658752930618862, 11.662558101379933, 10.737196605394901, 9.741150347471136, 8.778227214607101, 7.7537322553168995, 6.798442364218288, 5.829764541424863, 4.871119542353705, 3.8500480907149406, 2.827320552533904, 3.8952314567050017, 4.822030904357257, 5.860555527317103, 6.814066259520134, 7.819167295036504, 8.763073074325629, 9.794417721026955, 9.825258565813256, 10.815907730219429, 11.776267210088749, 10.83588956257797, 9.935109109693187, 8.945706099217032, 7.917877880777147, 6.918459985209953, 5.9718595046494, 4.9082791633590315, 3.867703685803019, 2.9208429456625717, 1.8900227000033758, 2.8879208005693315, 3.8860659146901186, 4.833219321978161, 5.812843635015328, 6.771800267248847, 7.800051431415818, 8.786500429576998, 8.824923895760163, 9.77074472485761, 10.818370842211614, 9.863223659670844, 8.931361667757818, 7.912561105149287, 6.978024224035416, 5.955113369233275, 4.982669518349556, 3.9822672737293128, 2.914139050516341, 1.8920062364714871, 0.9314817631295529, 1.9439026698629613, 2.9439366104671683, 3.8602829595303163, 4.813761525442871, 5.843655401127964, 6.828970940997724, 7.804194355254614, 7.858817247490884, 8.919470497718146, 9.94735446325052, 9.009639761886461, 7.965807468365575, 6.970572315270592, 6.0262841169402215, 5.004467334163564, 3.999435594164833, 3.069014161942902, 2.022064564497236, 1.0593318241282943, 0.0, 0.960657234544035, 1.9317816080610994, 2.9074172568671974, 3.858579617907647, 4.91428272897064, 5.962866591080576, 6.908819938936209, 8.726819151079665, 9.784932621856228, 10.808320824485367, 9.897218258571966, 8.872189240157455, 7.897704512447658, 6.999851611448908, 6.000531919953801, 5.030397769855411, 4.022832876927744, 2.9512366182838017, 1.9578403951076573, 1.0128302720550753, 1.9920730545886594, 2.9114058132686154, 3.862887373373132, 4.880601483343833, 5.821453812787228, 6.766020729121586, 7.732018933496465, 9.717704354265926, 10.729389340001102, 11.690041304667018, 10.781981746582092, 9.833686564478075, 8.840020413709833, 7.934771431595024, 6.971131552732736, 6.056816704442355, 5.011411216267147, 3.9398440664018732, 2.9150981137913297, 1.9408050910015264, 2.8702239274732717, 3.8537010071217503, 4.831429730226742, 5.820695069312981, 6.833440696398287, 7.832445326638926, 8.658857374218307], [8.660378951892243, 7.8417554484601935, 6.86626079973563, 5.8951211375607695, 4.8668864979297215, 3.911772686882862, 3.051192165091253, 3.944109398563435, 4.883766535762535, 5.9081928135081405, 6.961505489689144, 7.951922844040402, 8.883972845012572, 9.823475257538865, 10.741578113576589, 11.730055733697485, 12.687441212671077, 11.683355875096277, 10.697294180202391, 9.670556583852283, 9.67928472953882, 8.876272740698598, 7.856773678039634, 6.9369225385403155, 5.8802092317099275, 4.8909746052001175, 4.001318868711442, 4.993314682505088, 5.939312342155625, 6.945000410695967, 7.898396099125847, 8.858438172830997, 9.917248112558017, 10.785938847866237, 11.668706109147243, 12.735936538246122, 13.61288889016038, 12.713680711560556, 11.74538417603492, 10.725065073799145, 10.670783382975818, 9.729628243152927, 8.772868651324336, 7.806702931160682, 6.8078624983533516, 5.930574334099665, 5.004048968046962, 6.025937477473906, 6.95574953386173, 7.963004254392724, 8.919241792590292, 9.850034781379462, 10.902305010950704, 11.841814769514123, 12.616998688740072, 13.555631724266195, 14.505490457470941, 13.683265035719652, 12.668062066231228, 11.716232736559395, 11.678132247294426, 10.74071818227413, 9.756712572634415, 8.871257298266407, 7.869699764756235, 6.913903480791041, 6.010638249557374, 7.001746783959596, 7.971667987653023, 8.948393378487488, 9.948844424184394, 10.83839964720011, 11.802302928296236, 12.764851368651986, 13.636904644681666, 14.566707992852574, 15.4345243679736, 14.647475407737211, 13.653896254575672, 12.70076196124058, 12.60370789871804, 11.67973210425178, 10.812694212179348, 9.86146413277267, 8.851961686516574, 7.969862173955043, 7.064608320617127, 8.005311719899002, 8.963794097777397, 9.908038570891366, 10.857678540279533, 11.77776934761266, 12.79063872445391, 13.288494230603563, 13.623207220140907, 14.64546959658964, 15.607179018797376, 15.61816867066548, 14.599759036438591, 13.657450718310015, 13.611809992114063, 12.707932209594288, 11.758694313159262, 10.833353984170808, 9.794524523136952, 9.020666700299403, 8.109284057478732, 8.967618587033465, 9.895747455412582, 10.823281267042297, 11.769428158697771, 12.721829559955415, 12.936661054957575, 12.270354715355385, 12.697345605123425, 13.67658312782123, 14.59091888799146, 15.548953777453615, 15.524896330795308, 14.56215305137474, 14.555840734909111, 13.706767545680261, 12.832514394071865, 11.834189326437109, 10.765296260787842, 9.990980142378522, 9.171494733693672, 10.006259349834249, 10.916252731354243, 11.76503517496426, 12.790892244665246, 12.72001624169139, 11.870957284003017, 11.2566855468806, 11.744865681694387, 12.696563563543195, 13.628665243356402, 14.57309184005372, 15.581484133610113, 15.49158338113758, 15.567072108193702, 14.689050219600663, 13.772086087615754, 12.762208584649846, 11.790652109667239, 11.017130969315518, 10.147786180584552, 10.987641333767414, 11.879172496239564, 12.706509211574916, 12.574994368103992, 11.788086835725775, 10.837796313290175, 10.252999839766105, 10.67150721357928, 11.642504378487422, 12.57209097858806, 13.511046302940082, 14.562100518097264, 15.548097425506949, 15.549332752659655, 15.590415329997702, 14.596714646838265, 13.66867705566024, 12.72141273816627, 12.059462078790604, 11.214315072594538, 11.991689355775003, 12.898536308882887, 12.496073061563324, 11.56295117639222, 10.76572400310778, 9.873910052054432, 9.224931687100547, 9.745633408494955, 10.708845646537904, 11.636563229233468, 12.71013826756744, 13.747773862078066, 14.620039529976133, 14.61125304989943, 15.575837828178463, 15.624159148946653, 14.643034072447458, 13.685145189853582, 13.003100543084603, 12.197522236735647, 12.968368962843016, 12.436084237162111, 11.571567718488394, 10.594360179579589, 9.776214249732147, 8.888202808698466, 8.29121119028623, 8.750901504369633, 9.746727942073496, 10.686111377375408, 11.760370005724926, 12.710877118273878, 13.639351004793104, 13.565031073108523, 14.56663861061274, 15.510758276695665, 15.619555876060868, 14.618887837145994, 14.06686452399347, 13.245941436078647, 12.472999891768962, 11.507120439885012, 10.620435380790262, 9.618970378520304, 8.71784054872664, 7.864182224168303, 7.219553866219186, 7.793668275079496, 8.744476821774601, 9.728790222497123, 10.740412298624175, 11.644594118557503, 12.622646272120745, 12.69226393902579, 13.620217050971432, 14.638109925446376, 15.582701619451473, 14.535313893577738, 13.465566125896514, 12.532902991365441, 11.587457203593535, 10.55635643425501, 9.631235104003004, 8.667620820222776, 7.6628715099773554, 6.7944981880186415, 6.165248400606279, 6.833006843272759, 7.782199108657408, 8.808174054511003, 9.734987883024345, 10.709241195449373, 11.736658560632874, 11.753004113371814, 12.673324009457762, 13.726709003934495, 14.602218347390686, 13.536909559232909, 12.527158003856204, 11.597387945432684, 10.617714578991587, 9.648697862948302, 8.628887216200546, 7.660860577972261, 6.735334247832632, 5.748256916308123, 5.099535054985056, 5.80186135624751, 6.833444718092971, 7.786043992676275, 8.774744375970954, 9.817425525060221, 10.786994880307788, 10.753661650256857, 11.733056439883912, 12.753638783174086, 13.619512166154934, 12.59577825028536, 11.581116131713387, 10.632464408113707, 9.694790012015376, 8.823228498213947, 7.830549954681169, 6.803095828514298, 5.83867394434567, 4.8120711903524995, 4.0510691009851, 4.865918475353945, 5.825806245885457, 6.809513752824125, 7.798201129908704, 8.838745748651439, 9.785315189185393, 9.78077969935562, 10.72230508020118, 11.768766361220449, 12.62321533592397, 11.697853839938936, 10.70180758201517, 9.738884449151136, 8.714389489860935, 7.759099598762323, 6.790421775968898, 5.83177677689774, 4.810705325258976, 3.787977787077939, 3.027048617385965, 3.9017523785088075, 4.899898292773068, 5.8534090249761, 6.8585100604924705, 7.802415839781595, 8.833760486482918, 8.86460133126922, 9.855250495675394, 10.815609975544712, 11.796546797122005, 10.895766344237222, 9.906363333761067, 8.878535115321181, 7.879117219753988, 6.932516739193435, 5.868936397903067, 4.828360920347054, 3.881500180206607, 2.850679934547411, 1.9521683704479944, 2.9503134845687815, 3.872562087434127, 4.852186400471295, 5.8111430327048135, 6.839394196871782, 7.825843195032962, 7.864266661216128, 8.810087490313574, 9.857713607667577, 10.823880894214879, 9.892018902301853, 8.873218339693322, 7.938681458579451, 6.91577060377731, 5.943326752893591, 4.942924508273348, 3.874796285060376, 2.8526634710155223, 1.8921389976735878, 1.0081502397416242, 2.008184180345831, 2.899625724986282, 3.853104290898836, 4.882998166583929, 5.868313706453689, 6.843537120710579, 6.898160012946849, 7.958813263174111, 8.986697228706484, 9.933717753331953, 8.926464702909609, 7.931229549814627, 6.986941351484257, 5.9651245687075996, 4.960092828708868, 4.029671396486937, 2.982721799041271, 2.019989058672329, 0.960657234544035, 0.0, 0.9711243735170645, 1.9467600223231627, 2.8979223833636123, 3.953625494426605, 5.00220935653654, 5.948162704392174, 7.766161916535632, 8.824275387312195, 9.847663589941334, 10.830282077428745, 9.83284647470149, 8.858361746991694, 7.960508845992943, 6.961189154497836, 5.991055004399446, 4.983490111471779, 3.911893852827837, 2.918497629651692, 1.9734875065991102, 1.0512264723083538, 1.9507485787245804, 2.9022301388290974, 3.9199442487997986, 4.8607965782431934, 5.805363494577552, 6.771361698952431, 8.757047119721893, 9.768732105457069, 10.729384070122984, 11.74263898112613, 10.794343799022112, 9.800677648253869, 8.89542866613906, 7.931788787276771, 7.01747393898639, 5.972068450811182, 4.900501300945908, 3.875755348335365, 2.9014623255455616, 2.026643126433334, 2.893043772577715, 3.870772495682708, 4.8600378347689475, 5.872783461854253, 6.871788092094892, 7.698200139674274], [7.689254578375178, 6.870631074943128, 5.895136426218565, 4.9239967640437055, 3.8957621244126575, 2.9406483133657977, 3.9679921269837752, 4.915233772080499, 5.854890909279599, 6.879317187025205, 7.932629863206208, 8.923047217557466, 9.855097218529638, 10.79459963105593, 11.712702487093653, 12.69398957778108, 11.736604098807488, 10.712231501579213, 9.726169806685323, 8.699432210335218, 8.708160356021754, 7.905148367181532, 6.885649304522569, 5.965798165023251, 4.9090848581928626, 3.9198502316830526, 4.918118830603964, 5.91011464439761, 6.910436715672689, 7.916124784213031, 8.869520472642911, 9.829562546348061, 10.888372486075081, 11.757063221383302, 12.639830482664307, 13.675881087010222, 12.662051776296792, 11.742556338043492, 10.774259802517852, 9.75394070028208, 9.69965900945875, 8.75850386963586, 7.80174427780727, 6.8355785576436165, 5.836738124836287, 4.9594499605826, 5.920848929939484, 6.942737439366428, 7.926873907378794, 8.93412862790979, 9.890366166107356, 10.821159154896526, 11.873429384467768, 12.812939143031187, 13.588123062257136, 14.52675609778326, 13.734986042816576, 12.712140662202584, 11.69693769271416, 10.745108363042327, 10.707007873777359, 9.769593808757062, 8.785588199117349, 7.900132924749341, 6.89857539123917, 5.942779107273976, 6.891259884726548, 7.8823684191287695, 8.86791876928705, 9.844644160121515, 10.84509520581842, 11.809524020717173, 12.7734273018133, 13.73597574216905, 13.706068225850466, 14.750098554819344, 14.611469110026853, 13.676351034220144, 12.682771881058605, 11.729637587723513, 11.632583525200973, 10.708607730734713, 9.841569838662284, 8.890339759255607, 7.88083731299951, 6.998737800437978, 7.945229955786301, 8.885933355068175, 9.860044879411422, 10.804289352525391, 11.753929321913558, 12.748893721129724, 13.761763097970974, 13.747574337391685, 12.727238979620884, 13.749501356069617, 14.711210778277353, 14.647044297148412, 13.628634662921524, 12.686326344792947, 12.640685618596995, 11.736807836077224, 10.787569939642198, 9.862229610653744, 8.823400149619888, 8.049542326782337, 8.9867177805734, 9.848240222202639, 10.791998237046608, 11.719532048676323, 12.665678940331796, 13.61808034158944, 13.708146682863656, 12.779187734528533, 11.801377364603402, 12.780614887301207, 13.694950647471437, 14.652985536933592, 14.55377195727824, 13.591028677857672, 13.584716361392044, 12.735643172163197, 11.8613900205548, 10.863064952920045, 9.794171887270778, 9.019855768861456, 9.961477330056812, 10.886880985003422, 11.812503512988268, 12.661285956598284, 13.687143026299271, 13.564759231308525, 12.71208618990317, 11.807394212676906, 10.848897441174364, 11.800595323023172, 12.732697002836378, 13.677123599533697, 14.68551589309009, 14.520459007620513, 14.595947734676635, 13.717925846083599, 12.80096171409869, 11.791084211132782, 10.819527736150174, 10.046006595798453, 10.937768776947692, 11.868262968936587, 12.775423277873589, 13.602759993208942, 13.546118741621058, 12.63282982534291, 11.678925219190328, 10.80370850556241, 9.775538973059257, 10.746536137967398, 11.676122738068036, 12.615078062420059, 13.66613227757724, 14.61635375994415, 14.578208379142591, 14.619290956480638, 13.625590273321201, 12.697552682143176, 11.750288364649206, 11.088337705273538, 12.004297668957678, 12.872310990944177, 13.794787090516913, 13.46719743508039, 12.534075549909286, 11.653685793487316, 10.715038957954585, 9.775640352896852, 8.849665167974932, 9.812877406017881, 10.740594988713445, 11.80844457348493, 12.776649488561002, 13.648915156459068, 13.640128676382366, 14.604713454661397, 14.653034775429589, 13.671909698930394, 12.714020816336518, 12.031976169567537, 12.987504833098788, 13.84899059801219, 13.407208610679175, 12.54269209200546, 11.565484553096654, 10.727488631491935, 9.788528396413067, 8.841919856082535, 7.854933263849609, 8.850759701553473, 9.739898033960348, 10.814156662309866, 11.739752744756814, 12.66822663127604, 12.593906699591459, 13.595514237095674, 14.5396339031786, 14.648431502543804, 13.64776346362893, 13.095740150476404, 14.035924032441788, 13.444124265286026, 12.478244813402076, 11.591559754307328, 10.59009475203737, 9.688964922243706, 8.835306597685367, 7.9634115970012775, 6.897700034559471, 7.848508581254576, 8.775848440732334, 9.787470516859386, 10.673469745040439, 11.651521898603681, 11.721139565508723, 12.649092677454366, 13.66698555192931, 14.705605309447506, 14.687333126877018, 14.051773826024348, 13.504027364882505, 12.5585815771106, 11.527480807772074, 10.602359477520068, 9.638745193739842, 8.633995883494421, 7.7656225615357055, 6.971982462132507, 5.937038602752734, 6.886230868137383, 7.837049680993937, 8.76386350950728, 9.738116821932307, 10.765534187115808, 10.78187973985475, 11.702199635940698, 12.755584630417431, 13.739843723073957, 14.508033932749973, 13.498282377373268, 12.568512318949749, 11.58883895250865, 10.619822236465366, 9.60001158971761, 8.631984951489326, 7.706458621349697, 6.719381289825188, 5.976324129485739, 4.905893115727485, 5.862320344575906, 6.81491961915921, 7.803620002453888, 8.846301151543155, 9.815870506790722, 9.782537276739793, 10.761932066366848, 11.782514409657022, 12.750633909415875, 13.566902623802424, 12.55224050523045, 11.603588781630771, 10.66591438553244, 9.79435287173101, 8.801674328198233, 7.774220202031362, 6.809798317862734, 5.7831955638695645, 4.956604069240172, 3.9699502348339193, 4.854681872368392, 5.83838937930706, 6.827076756391639, 7.867621375134373, 8.814190815668328, 8.809655325838555, 9.751180706684115, 10.797641987703384, 11.793836816942314, 12.668978213456, 11.672931955532235, 10.7100088226682, 9.685513863377999, 8.730223972279386, 7.761546149485962, 6.8029011504148045, 5.78182969877604, 4.7591021605950035, 3.932583585641037, 3.005784137988782, 3.9287739192560034, 4.882284651459035, 5.887385686975405, 6.831291466264529, 7.862636112965855, 7.893476957752156, 8.884126122158328, 9.844485602027648, 10.907495484447438, 11.866890717754286, 10.877487707278132, 9.849659488838245, 8.850241593271052, 7.903641112710499, 6.840060771420131, 5.799485293864118, 4.852624553723672, 3.8218043080644755, 2.923292743965059, 2.054345244048756, 2.901437713917062, 3.8810620269542295, 4.8400186591877485, 5.868269823354718, 6.854718821515898, 6.893142287699063, 7.838963116796508, 8.886589234150513, 9.94541730098592, 10.863143275818917, 9.844342713210386, 8.909805832096515, 7.886894977294374, 6.914451126410655, 5.914048881790412, 4.84592065857744, 3.823787844532587, 2.8632633711906523, 1.9792746132586887, 1.0395424692416693, 1.928501351469217, 2.8819799173817717, 3.9118737930668646, 4.897189332936625, 5.872412747193515, 5.927035639429784, 6.987688889657046, 8.015572855189419, 8.962593379814887, 9.897589076426675, 8.902353923331692, 7.9580657250013225, 6.936248942224665, 5.931217202225933, 5.000795770004002, 3.953846172558336, 2.991113432189394, 1.9317816080610994, 0.9711243735170645, 0.0, 0.9756356488060981, 1.9267980098465476, 2.9825011209095407, 4.0310849830194755, 4.977038330875109, 6.795037543018567, 7.85315101379513, 8.876539216424268, 9.859157703911679, 10.803970848218555, 9.829486120508758, 8.931633219510008, 7.932313528014902, 6.96217937791651, 5.954614484988843, 4.883018226344901, 3.8896220031687565, 2.9446118801161747, 1.9854536532423368, 0.9796242052075159, 1.931105765312033, 2.9488198752827337, 3.8896722047261285, 4.834239121060487, 5.800237325435366, 7.785922746204829, 8.797607731940005, 9.75825969660592, 10.805267668125966, 11.753562850229983, 10.771802021770933, 9.866553039656123, 8.902913160793837, 7.988598312503454, 6.943192824328246, 5.8716256744629725, 4.846879721852429, 3.8725866990626256, 2.960870307367317, 1.9219193990606507, 2.899648122165643, 3.888913461251882, 4.901659088337188, 5.900663718577826, 6.727075766157209], [6.71361892956908, 5.89499542613703, 4.919500777412467, 3.9728297832347774, 2.9565750203563863, 3.911688831403246, 4.939032645021223, 5.890869420886597, 6.8305265580856975, 7.854952835831303, 8.908265512012306, 9.898682866363563, 10.830732867335735, 11.770235279862026, 12.68833813589975, 11.718353928974983, 10.760968450001391, 9.736595852773116, 8.750534157879226, 7.72379656152912, 7.732524707215656, 6.929512718375435, 5.910013655716471, 5.014631184214323, 3.986604449535545, 4.890890749720501, 5.889159348641412, 6.881155162435058, 7.886072364478787, 8.89176043301913, 9.845156121449008, 10.805198195154158, 11.864008134881178, 12.732698870189399, 13.615466131470404, 12.700245438204124, 11.686416127490695, 10.766920689237395, 9.798624153711755, 8.778305051475982, 8.776247360249382, 7.836023460978544, 6.879263869149954, 5.9130981489863, 4.91425771617897, 5.927071360522384, 6.891889447976932, 7.913777957403876, 8.902509556184892, 9.909764276715887, 10.866001814913453, 11.796794803702623, 12.849065033273865, 13.788574791837284, 14.563758711063233, 13.682737967486617, 12.759350394010479, 11.739225274283346, 10.724022304794921, 9.816337561731249, 9.784527465120044, 8.847113400099747, 7.863107790460033, 6.977652516092025, 5.976094982581853, 6.91040050721376, 7.858881284666332, 8.849989819068554, 9.835540169226835, 10.812265560061299, 11.812716605758204, 12.78515966952327, 13.749062950619397, 14.711611390975147, 14.570098194254076, 14.138666898456245, 13.638553722107615, 12.703435646300905, 11.709856493139366, 10.807157179066198, 10.710103116543658, 9.786127322077398, 8.919089430004966, 7.96785935059829, 6.958356904342193, 7.966359200377762, 8.912851355726085, 9.85355475500796, 10.827666279351208, 11.771910752465176, 12.721550721853344, 13.724529369935821, 14.737398746777071, 14.611604305795295, 13.591268948024494, 13.077522036350457, 13.864175687067547, 13.674128909229172, 12.655719275002285, 11.763845936135633, 11.718205209939681, 10.814327427419906, 9.86508953098488, 8.939749201996428, 7.90091974096257, 8.928499528137857, 9.86567498192892, 10.815861622142423, 11.759619636986393, 12.687153448616108, 13.633300340271582, 14.585701741529226, 14.572176651267267, 13.643217702932143, 12.665407333007012, 12.108635567582047, 12.843935314175402, 13.801970203637559, 13.603401302459847, 12.668548269200357, 12.66223595273473, 11.81316276350588, 10.938909611897483, 9.940584544262729, 8.871691478613462, 9.898812970216976, 10.840434531412333, 11.854502384943206, 12.780124912928054, 13.62890735653807, 14.654764426239057, 14.428789199712138, 13.576116158306782, 12.671424181080518, 11.712927409577974, 11.04142176086328, 11.881681669540344, 12.826108266237664, 13.834500559794057, 13.597978598963198, 13.67346732601932, 12.795445437426281, 11.878481305441374, 10.868603802475466, 9.897047327492858, 10.924963797153973, 11.816725978303213, 12.835884368876371, 13.743044677813375, 14.570381393148727, 14.497326247156993, 13.496859793746523, 12.54295518759394, 11.667738473966022, 10.639568941462867, 9.987362575807506, 10.825107404772002, 11.764062729124024, 12.789428673399895, 13.640718111138053, 13.602572730336494, 13.696810547823322, 12.703109864663885, 11.77507227348586, 10.82780795599189, 11.832352488486706, 12.768633585717344, 13.79589177510206, 14.760462411121566, 14.418404940616325, 13.48528305544522, 12.517715761890926, 11.579068926358197, 10.639670321300464, 9.713695136378542, 8.958941153822265, 9.766957730214353, 10.832808924678833, 11.801013839754905, 12.673279507652971, 12.664493027576269, 13.6290778058553, 13.730554366772271, 12.749429290273078, 11.791540407679202, 12.775990952780704, 13.74913488400481, 14.691269677609228, 14.382844259485276, 13.493899597541395, 12.51669205863259, 11.591518599895547, 10.652558364816679, 9.705949824486147, 8.71896323225322, 7.996823449357857, 8.76426238515425, 9.838521013503769, 10.764117095950716, 11.692590982469943, 11.618271050785362, 12.619878588289577, 13.563998254372503, 13.725951093886486, 12.725283054971614, 13.698910924607738, 14.767370956323456, 14.419759914092127, 13.453880462208177, 12.567195403113427, 11.565730400843469, 10.664600571049805, 9.810942246491466, 8.82744156540489, 7.761730002963083, 6.93411380421669, 7.800212791926237, 8.811834868053289, 9.697834096234342, 10.675886249797584, 10.745503916702626, 11.673457028648269, 12.691349903123212, 13.729969660641409, 13.7648527182197, 14.654944600155682, 14.479663013688606, 13.5342172259167, 12.503116456578175, 11.577995126326169, 10.614380842545941, 9.60963153230052, 8.741258210341805, 7.836012430536119, 6.801068571156346, 5.957765524314533, 6.86141403218784, 7.788227860701182, 8.76248117312621, 9.78989853830971, 9.806244091048653, 10.7265639871346, 11.779948981611334, 12.76420807426786, 13.66720824028675, 14.473918026179367, 13.544147967755848, 12.564474601314751, 11.595457885271466, 10.575647238523711, 9.607620600295425, 8.682094270155796, 7.695016938631286, 6.840354097889351, 5.769923084131097, 4.886684695769808, 5.839283970353112, 6.82798435364779, 7.870665502737058, 8.840234857984624, 8.806901627933696, 9.78629641756075, 10.806878760850925, 11.774998260609777, 12.714388678196396, 13.52787615403655, 12.57922443043687, 11.64155003433854, 10.76998852053711, 9.777309977004332, 8.749855850837461, 7.785433966668833, 6.758831212675663, 5.820634037643785, 4.833980203237532, 3.879046223562294, 4.862753730500962, 5.851441107585541, 6.891985726328275, 7.83855516686223, 7.834019677032457, 8.775545057878018, 9.822006338897287, 10.818201168136216, 11.74356266412125, 12.648567604338334, 11.6856444714743, 10.661149512184098, 9.705859621085486, 8.737181798292061, 7.778536799220904, 6.757465347582139, 5.734737809401102, 4.79661355404465, 3.8698141063923948, 2.953138270449905, 3.906649002652937, 4.911750038169307, 5.855655817458432, 6.887000464159756, 6.917841308946057, 7.908490473352231, 8.868849953221549, 9.931859835641337, 10.905391086028217, 11.853123356084229, 10.825295137644343, 9.82587724207715, 8.879276761516598, 7.81569642022623, 6.775120942670217, 5.828260202529769, 4.797439956870574, 3.8592361051111093, 2.9183752124523687, 1.9258020651109637, 2.9054263781481313, 3.8643830103816503, 4.89263417454862, 5.8790831727098, 5.917506638892965, 6.863327467990411, 7.910953585344415, 8.969781652179822, 9.901643644092848, 10.819978362016485, 9.885441480902614, 8.862530626100472, 7.890086775216752, 6.88968453059651, 5.821556307383538, 4.799423493338685, 3.8388990199967505, 2.9152179744047393, 1.9151840338005326, 0.9528657026631191, 1.9063442685756735, 2.9362381442607663, 3.9215536841305267, 4.896777098387416, 4.951399990623686, 6.012053240850948, 7.039937206383321, 7.986957731008791, 9.030790024529677, 9.877989572137789, 8.93370137380742, 7.911884591030763, 6.90685285103203, 5.976431418810099, 4.929481821364433, 3.9667490809954917, 2.9074172568671974, 1.9467600223231627, 0.9756356488060981, 0.0, 0.9511623610404495, 2.0068654721034425, 3.0554493342133773, 4.001402682069011, 5.819401894212469, 6.877515364989032, 7.900903567618171, 8.883522055105582, 9.908551073520092, 10.805121769314855, 9.907268868316105, 8.907949176820999, 7.9378150267226095, 6.930250133794942, 5.858653875151, 4.865257651974855, 3.920247528922273, 2.9610893020484346, 1.955259854013614, 0.9554701165059348, 1.9731842264766355, 2.9140365559200303, 3.858603472254389, 4.824601676629268, 6.810287097398731, 7.8219720831339075, 8.782624047799823, 9.829632019319869, 10.777927201423886, 11.74743767057703, 10.84218868846222, 9.878548809599934, 8.964233961309553, 7.9188284731343455, 6.847261323269071, 5.822515370658527, 4.848222347868724, 3.9365059561734146, 2.8975550478667484, 1.9240124733595452, 2.9132778124457843, 3.9260234395310896, 4.925028069771729, 5.751440117351111], [5.762456568528631, 4.94383306509658, 3.9683384163720175, 3.156192832558496, 3.907737381396836, 4.862851192443696, 5.890195006061673, 6.842031781927047, 7.781688919126148, 8.806115196871753, 9.859427873052756, 10.849845227404012, 11.781895228376186, 12.721397640902477, 11.75566918805543, 10.767191567934534, 9.809806088960942, 8.785433491732666, 7.799371796838778, 6.772634200488671, 6.781362346175207, 5.978350357334985, 4.9588512946760215, 4.197994233538042, 4.937766810575995, 5.842053110760951, 6.840321709681862, 7.832317523475508, 8.837234725519236, 9.842922794059579, 10.796318482489458, 11.756360556194608, 12.815170495921627, 13.635503447074651, 12.682797183626084, 11.749083077163675, 10.735253766450246, 9.815758328196946, 8.847461792671307, 7.827142690435533, 7.825084999208934, 6.894985347835276, 5.938225756006686, 5.187781311882534, 5.865420077219419, 6.878233721562833, 7.843051809017382, 8.864940318444326, 9.853671917225341, 10.860926637756336, 11.817164175953902, 12.747957164743072, 13.800227394314314, 14.605388536480675, 13.631089763218913, 12.731575606446167, 11.80818803297003, 10.788062913242898, 9.772859943754474, 8.8651752006908, 8.843433044206218, 7.906075286956479, 6.922069677316765, 6.25233567898826, 6.927257343622302, 7.861562868254209, 8.81004364570678, 9.801152180109003, 10.786702530267284, 11.763427921101748, 12.763878966798654, 13.73632203056372, 14.700225311659846, 15.59312483569743, 14.650995719160507, 13.6159099875073, 12.687391361067167, 11.752273285260458, 10.758694132098919, 9.866062758152372, 9.769008695629832, 8.84508920893413, 7.978051316861699, 7.3168541146858335, 7.9095192653826425, 8.917521561418212, 9.864013716766534, 10.804717116048408, 11.778828640391657, 12.723073113505626, 13.672713082893793, 14.67569173097627, 15.68856110781752, 15.562766666835746, 14.542431309064945, 13.92759345185717, 13.051614355095914, 12.722966548188726, 11.704556913961838, 10.822751515221807, 10.777110789025855, 9.873289314276638, 8.924051417841612, 8.371900852676903, 8.85208210200302, 9.879661889178308, 10.816837342969372, 11.767023983182872, 12.710781998026842, 13.638315809656557, 14.584462701312031, 15.536864102569675, 15.523339012307718, 14.594380063972594, 13.616569694047463, 12.95870698308876, 12.03137398220377, 12.989408871665926, 12.6522389414194, 11.727453848286531, 11.721141531820903, 10.872124650362611, 9.997871498754215, 9.3993185136924, 9.822853839653911, 10.849975331257427, 11.791596892452784, 12.805664745983655, 13.731287273968503, 14.58006971757852, 15.605926787279506, 15.379951560752588, 14.527278519347233, 13.622586542120969, 12.664089770618425, 11.93568279998995, 11.06912033756871, 12.013546934266031, 13.006135758567865, 12.656884178049372, 12.732372905105494, 11.854407324283013, 10.980182575905651, 10.430395459273882, 10.848209688533307, 11.876126158194424, 12.767888339343664, 13.78704672991682, 14.694207038853824, 15.521543754189176, 15.448488608197444, 14.448022154786972, 13.49411754863439, 12.618900835006473, 11.590731302503318, 10.881623614934176, 10.012546072800369, 10.951501397152391, 11.95557405913038, 12.806863496868537, 12.768718116066978, 12.87500411873091, 12.017332256149466, 11.484036563397664, 11.77897031703234, 12.783514849527155, 13.719795946757793, 14.74705413614251, 15.711624772162015, 15.369567301656776, 14.436445416485672, 13.468878122931379, 12.530231287398648, 11.590832682340915, 10.664857497418993, 9.853202192948935, 8.954396398242718, 10.0202475927072, 10.96715922548539, 11.839424893383455, 11.830638413306753, 12.700585986223533, 13.05030722213476, 12.47963166547069, 12.742702768719651, 13.727153313821153, 14.70029724504526, 15.642432038649677, 15.334006620525725, 14.445061958581846, 13.46785441967304, 12.542680960935998, 11.60372072585713, 10.657112185526598, 9.67012559329367, 8.891084488484527, 7.9517010531826156, 9.025959681532136, 9.9302624816812, 10.858736368200427, 10.784416436515846, 11.69138676865781, 12.635506434740737, 13.507376520191963, 13.676445416012063, 14.650073285648187, 15.718533317363905, 15.370922275132576, 14.405042823248627, 13.518357764153876, 12.516892761883918, 11.615762932090254, 10.762104607531915, 9.778603926445339, 8.712892364003533, 7.88527616525714, 6.987651459954602, 7.999273536081654, 8.863979481964826, 9.842031635528068, 9.848738710576553, 10.744965209016502, 11.762858083491446, 12.801477841009643, 13.733467507087209, 14.7829442274461, 15.430825374729055, 14.48537958695715, 13.454278817618624, 12.529157487366618, 11.56554320358639, 10.56079389334097, 9.692420571382254, 8.787174791576568, 7.752230932196795, 6.908927885354983, 6.048852700216205, 6.975666528729548, 7.928626558856695, 8.914742822976113, 8.855081730008203, 9.77540162609415, 10.828786620570883, 11.813045713227408, 12.716045879246296, 13.723930307870734, 14.495310328796297, 13.5156369623552, 12.546620246311916, 11.52680959956416, 10.558782961335874, 9.633256631196245, 8.646179299671736, 7.7915164589298005, 6.721085445171546, 5.837847056810258, 5.026722638381478, 5.973966555835701, 6.942294148735017, 7.911863503982583, 7.855739266893246, 8.8351340565203, 9.855716399810474, 10.823835899569326, 11.763226317155944, 12.777888435727917, 13.53038679147732, 12.592712395378989, 11.72115088157756, 10.728472338044782, 9.70101821187791, 8.736596327709282, 7.709993573716113, 6.771796398684235, 5.785142564277981, 4.830208584602744, 3.972466688924026, 4.9230697535834995, 5.963614372326234, 6.910183812860188, 6.882857315992007, 7.824382696837567, 8.870843977856836, 9.867038807095765, 10.792400303080797, 11.788446561004562, 12.636806832514749, 11.612311873224547, 10.657021982125935, 9.68834415933251, 8.729699160261353, 7.708627708622588, 6.685900170441552, 5.7477759150851, 4.820976467432844, 3.904300631490355, 2.955703452454661, 3.960804487971031, 4.904710267260155, 5.935838103119306, 5.966678947905608, 6.957328112311782, 7.9176875921811, 8.980697474600888, 9.954228724987768, 11.020134374587762, 11.776457498684794, 10.7770396031176, 9.830439122557047, 8.766858781266679, 7.726283303710666, 6.77942256357022, 5.748602317911024, 4.810398466151559, 3.869537573492819, 2.8769644261514133, 1.9544808279498556, 2.9134374601833746, 3.94147181350817, 4.92792081166935, 4.9663442778525155, 5.912165106949962, 6.959791224303966, 8.018619291139373, 8.9504812830524, 9.96928184566093, 10.836603841943065, 9.813692987140923, 8.841249136257204, 7.840846891636961, 6.772718668423988, 5.750585854379135, 4.790061381037201, 3.8663803354451893, 2.866346394840982, 1.9040280637035685, 0.9551819075352239, 1.9850757832203165, 2.970391323090077, 3.9456147373469665, 4.0002376295832365, 5.060890879810499, 6.088774845342872, 7.0357953699683415, 8.079627663489228, 9.074862816584211, 9.88486373484787, 8.863046952071214, 7.858015212072481, 6.92759377985055, 5.880644182404884, 4.917911442035942, 3.8585796179076475, 2.8979223833636123, 1.9267980098465476, 0.9511623610404495, 0.0, 1.055703111062993, 2.104286973172928, 3.0502403210285616, 4.868239533172019, 5.9263530039485826, 6.9497412065777215, 7.932359694065133, 8.957388712479645, 9.931873440189442, 10.858431229356556, 9.85911153786145, 8.88897738776306, 7.881412494835393, 6.80981623619145, 5.816420013015305, 4.871409889962723, 3.9122516630888846, 2.9064222150540635, 1.9066324775463843, 1.0220218654361861, 1.962874194879581, 2.9074411112139398, 3.8734393155888185, 5.8591247363582815, 6.870809722093458, 7.831461686759374, 8.87846965827942, 9.826764840383436, 10.874189341451617, 11.793351049502672, 10.829711170640385, 9.915396322350002, 8.869990834174795, 7.798423684309521, 6.773677731698977, 5.799384708909174, 4.887668317213865, 3.8487174089071985, 2.8751748343999948, 2.0966408617695023, 2.9748610784906404, 3.9738657087312794, 4.800277756310662], [4.838787386633232, 4.050838522414868, 3.0753438736903056, 4.066219015162886, 4.963440492459829, 5.9185543035066885, 6.945898117124666, 7.89773489299004, 8.83739203018914, 9.861818307934744, 10.915130984115747, 11.905548338467003, 12.808374242842003, 11.799981809906194, 10.82950826928318, 9.843522386039135, 8.886136907065543, 7.861764309837268, 6.875702614943379, 5.8489650185932724, 5.857693164279809, 5.085355814653273, 4.065856751994309, 5.014393973198, 5.9934699216389875, 6.897756221823943, 7.896024820744855, 8.8880206345385, 9.89293783658223, 10.898625905122572, 11.85202159355245, 12.8120636672576, 13.72576970071967, 12.7093425283024, 11.756636264853833, 10.825413895268277, 9.811584584554847, 8.892089146301547, 7.923792610775909, 6.903473508540134, 6.901415817313535, 6.0019908051535635, 5.045231213324973, 6.004181051542492, 6.921123188282412, 7.933936832625826, 8.898754920080375, 9.920643429507319, 10.909375028288334, 11.916629748819329, 12.872867287016895, 13.803660275806065, 14.675202452146118, 13.679227617708424, 12.704928844446663, 11.807906424550769, 10.884518851074631, 9.8643937313475, 8.849190761859075, 7.941506018795401, 7.919763862310821, 7.013080744274767, 6.029075134635052, 6.957684154139702, 7.982960454685295, 8.917265979317202, 9.865746756769774, 10.856855291171996, 11.842405641330277, 12.81913103216474, 13.819582077861646, 14.792025141626713, 15.62951235728093, 14.66696391692518, 13.724834800388257, 12.6922408056119, 11.763722179171769, 10.828604103365059, 9.83502495020352, 8.942393576256974, 8.845339513734434, 7.952094666252417, 7.085056774179987, 8.022202589837276, 8.965222376445634, 9.973224672481205, 10.919716827829527, 11.860420227111401, 12.83453175145465, 13.778776224568619, 14.728416193956786, 15.731394842039263, 16.617848153438604, 15.639117117260373, 14.703664046617838, 13.689870138278266, 12.72816071607053, 11.799297366293327, 10.78088773206644, 9.899082333326408, 9.853441607130456, 8.980294771594926, 8.0310568751599, 8.95644379280374, 9.907785213066012, 10.935365000241298, 11.872540454032361, 12.822727094245865, 13.766485109089835, 14.69401892071955, 15.640165812375024, 16.592567213632666, 16.579042123370712, 15.650083175035586, 14.672272805110456, 13.94711024692569, 13.019777246040698, 12.277363850927795, 11.728569759524001, 10.803784666391133, 10.797472349925505, 9.979130107680898, 9.104876956072502, 9.983861453819234, 10.878556950716902, 11.905678442320417, 12.847300003515773, 13.861367857046648, 14.786990385031496, 15.635772828641512, 16.661629898342497, 16.43565467181558, 15.582981630410226, 14.678289653183962, 13.719792881681418, 12.92408606382688, 12.05752360140564, 11.3015019135279, 12.075699059219932, 11.733214996153974, 11.808703723210096, 10.9614127816013, 10.087188033223939, 11.014938399400716, 11.903912799596299, 12.931829269257413, 13.823591450406653, 14.842749840979813, 15.749910149916817, 16.57724686525217, 16.504191719260437, 15.503725265849965, 14.549820659697383, 13.674603946069466, 12.646434413566311, 11.870026878771107, 11.000949336637298, 10.239456376414262, 11.025137359782446, 11.876426797520605, 11.794536073555014, 11.982009576049197, 11.124337713467753, 12.052375304645778, 12.83467342809533, 13.839217960590146, 14.775499057820785, 15.8027572472055, 16.767327883225004, 16.42527041271977, 15.492148527548665, 14.524581233994372, 13.58593439846164, 12.646535793403908, 11.720560608481986, 10.841605456785866, 9.942799662079649, 9.16809106541523, 10.036722526137456, 10.908988194035523, 10.856456370794788, 11.706023833004258, 12.157312679453048, 13.047970406718804, 13.798405879782642, 14.782856424884145, 15.75600035610825, 16.698135149712666, 16.389709731588713, 15.500765069644839, 14.523557530736033, 13.598384071998991, 12.659423836920123, 11.712815296589591, 10.725828704356664, 9.879487752321458, 8.940104317019546, 8.173803154240165, 8.999825782333268, 9.928299668852494, 9.810234394003881, 10.696824615438535, 11.64094428152146, 12.71030994271269, 13.710977981627565, 14.684605851263688, 15.58635490009312, 16.426625386195568, 15.460745934311616, 14.574060875216867, 13.57259587294691, 12.671466043153245, 11.817807718594906, 10.834307037508331, 9.768595475066526, 8.940979276320133, 7.976054723791533, 7.143093532456604, 7.933542782616893, 8.911594936180135, 8.854176557357276, 9.750403055797227, 10.76829593027217, 11.806915687790369, 12.719259176780827, 13.768735897139718, 14.624517333162611, 15.541082698020139, 14.509981928681613, 13.584860598429607, 12.621246314649381, 11.61649700440396, 10.748123682445245, 9.842877902639561, 8.807934043259788, 7.964630996417976, 7.037255964053136, 6.1104421355397935, 6.998189859508762, 7.98430612362818, 7.860519576788927, 8.780839472874874, 9.834224467351607, 10.81691928443746, 11.701837548939915, 12.709721977564353, 13.677255366340193, 14.57134007341819, 13.602323357374905, 12.58251271062715, 11.614486072398865, 10.688959742259236, 9.701882410734727, 8.847219569992793, 7.776788556234539, 6.893550167873251, 6.075508747322507, 5.104839400309691, 6.011857449387084, 6.98142680463465, 6.86117711367397, 7.840571903301024, 8.859589971020526, 9.827709470779379, 10.749017986849562, 11.763680105421535, 12.712331829021215, 13.648415506441982, 12.776853992640552, 11.784175449107774, 10.756721322940903, 9.792299438772275, 8.765696684779105, 7.827499509747228, 6.840845675340974, 5.885911695665737, 5.021252797865055, 4.05394259805749, 5.033177672978301, 5.979747113512255, 5.888295162772732, 6.8298205436182915, 7.856635647550455, 8.852830476789384, 9.778191972774415, 10.774238230698181, 11.737161363562215, 12.66801498428754, 11.712725093188928, 10.744047270395503, 9.785402271324346, 8.764330819685581, 7.741603281504545, 6.803479026148093, 5.876679578495837, 4.960003742553348, 4.00448956139569, 3.091677332445022, 3.966009334153015, 4.941275949900031, 4.910975836842615, 5.901625001248789, 6.861984481118107, 7.924994363537896, 8.898525613924773, 9.964431263524768, 10.852826351892894, 11.832742714180593, 10.88614223362004, 9.822561892329672, 8.781986414773659, 7.835125674633213, 6.804305428974017, 5.866101577214552, 4.925240684555812, 3.9326675372144067, 3.0032669368908844, 2.0443103046573654, 2.946909660288894, 3.933358658450074, 3.9106411667895227, 4.856461995886969, 5.904088113240973, 6.9629161800763795, 7.8947781719894055, 8.913578734597936, 9.848115615711807, 10.869396098203916, 9.896952247320197, 8.896550002699954, 7.828421779486981, 6.8062889654421275, 5.845764492100193, 4.922083446508182, 3.9220495059039755, 2.959731174766562, 2.0108850185982172, 1.0251345393269098, 1.975829169870801, 2.9510525841276904, 2.944534518520243, 4.005187768747505, 5.033071734279878, 5.980092258905348, 7.0239245524262355, 8.019159705521218, 8.963447903851588, 9.918750063134205, 8.913718323135473, 7.983296890913543, 6.936347293467877, 5.973614553098935, 4.91428272897064, 3.953625494426605, 2.9825011209095407, 2.0068654721034425, 1.055703111062993, 0.0, 1.048583862109935, 1.9945372099655683, 3.9445703512766204, 4.984170020663823, 6.007558223292962, 6.984113182975468, 8.00914220138998, 8.946291902698285, 9.937015398360273, 10.914814648924441, 9.944680498826052, 8.937115605898386, 7.865519347254443, 6.872123124078298, 5.927113001025716, 4.9679547741518775, 3.9621253261170564, 2.962335588609377, 2.0107319816412637, 1.0698796521978688, 2.0144465685322275, 2.94977013369342, 4.935455554462883, 5.94714054019806, 6.907792504863975, 7.954800476384021, 8.903095658488038, 9.88860780396046, 10.871935218506389, 11.885414281703376, 10.971099433412995, 9.925693945237787, 8.854126795372514, 7.82938084276197, 6.855087819972167, 5.9433714282768575, 4.904420519970191, 3.9308779454629876, 3.0853509779745796, 2.0818665358089286, 3.080871166049567, 3.876608574415263], [3.7902035245232977, 3.0556636374247144, 3.9693028213688692, 4.960177962841451, 5.925022817144308, 6.880136628191168, 7.907480441809145, 8.896645888993195, 9.836303026192295, 10.8607293039379, 11.914041980118903, 12.824843105182246, 11.759790380732069, 10.75139794779626, 9.780924407173243, 8.794938523929199, 7.837553044955607, 6.813180447727332, 5.827118752833445, 4.800381156483338, 4.809109302169874, 4.110967983414738, 4.959815699672873, 5.908352920876564, 6.955052246323467, 7.859338546508423, 8.857607145429334, 9.849602959222981, 10.891848832585385, 11.897536901125726, 12.850932589555605, 13.735995778336754, 12.677185838609734, 11.660758666192464, 10.708052402743897, 9.77683003315834, 8.763000722444911, 7.843505284191612, 6.875208748665974, 5.8548896464302, 5.852831955203601, 5.144819436652627, 5.939190161003538, 6.898139999221057, 7.882705512966891, 8.895519157310305, 9.860337244764853, 10.882225754191797, 11.897888742974176, 12.905143463505171, 13.87177828302005, 14.678888819607424, 13.626618590036182, 12.630643755598488, 11.656344982336726, 10.759322562440833, 9.835934988964695, 8.815809869237565, 7.800606899749141, 6.892922156685467, 6.871180000200886, 6.15590937577383, 6.923034082313617, 7.851643101818267, 8.890902613367642, 9.878848304001682, 10.827329081454254, 11.818437615856476, 12.803987966014757, 13.780713356849223, 14.781164402546128, 15.54483177626712, 14.580928495170994, 13.618380054815244, 12.67625093827832, 11.643656943501966, 10.715138317061834, 9.780020241255125, 8.786441088093586, 7.893809714147039, 7.7967556516245, 7.09492329775148, 7.979015721858551, 8.91616153751584, 9.873164535127982, 10.934806997165685, 11.881299152514007, 12.822002551795881, 13.79611407613913, 14.740358549253099, 15.689998518641266, 16.48420147667967, 15.569264291328668, 14.590533255150437, 13.655080184507902, 12.64128627616833, 11.679576853960594, 10.750713504183391, 9.732303869956505, 8.850498471216476, 8.804857745020524, 8.1358904119959, 8.925015822838464, 9.850402740482304, 10.815727371748359, 11.843307158923647, 12.78048261271471, 13.749012373911532, 14.728067433774315, 15.65560124540403, 16.601748137059502, 17.44513110053325, 16.48771111778564, 15.558752169450514, 14.580941799525384, 13.61017274493674, 12.699817226852739, 11.73298246815381, 10.679985897414067, 9.7552008042812, 9.748888487815572, 9.134725748081873, 9.998835903751067, 10.8778204014978, 11.78649910939925, 12.813620601002766, 13.755242162198122, 14.787653136712315, 15.748572709715976, 16.597355153325992, 17.623212223026975, 17.3478897868454, 16.495216745440043, 15.578741836094833, 14.598168875331604, 13.693739982714064, 12.827177520292823, 12.008312149432243, 11.02711519711, 10.684631134044041, 10.760119861100163, 10.117008422002275, 10.981146980902503, 11.908897347079282, 12.811854958278646, 13.839771427939763, 14.731533609089002, 15.76903512064548, 16.711492474601297, 17.53882918993665, 17.416426834290256, 16.415960380879785, 15.462055774727201, 14.575056128980338, 13.524810407216497, 12.63968079765829, 11.770603255524481, 10.946266612318604, 9.976553497672514, 10.827842935410668, 10.74595221144508, 11.137605216450172, 12.018296661146318, 12.946334252324343, 13.742615586777678, 14.747160119272493, 15.683441216503132, 16.710699405887848, 17.675270041907353, 17.337505527749588, 16.404383642578484, 15.436816349024188, 14.498169513491458, 13.558770908433726, 12.598936602132172, 11.611259375673049, 10.712453580966832, 9.874901301319571, 8.988138664027524, 9.860404331925587, 9.807872508684854, 10.657439970894323, 11.574326264708146, 12.555451341207341, 13.513340223801217, 14.524220111315442, 15.497364042539548, 16.439498836143965, 17.343655120094137, 16.413000184674654, 15.43579264576585, 14.510619187028809, 13.57165895194994, 12.625050411619409, 11.638063819386481, 10.64914167120864, 9.70975823590673, 8.880613390144507, 7.9512419202233335, 8.879715806742558, 8.761650531893947, 9.6482407533286, 10.592360419411527, 11.661726080602758, 12.662394119517632, 13.636021989153756, 14.537771037983187, 15.51108695876805, 16.474983701003335, 15.588298641908583, 14.586833639638625, 13.685703809844961, 12.81822567126555, 11.74654215253815, 10.680830590096344, 9.730022043401238, 8.745708642678716, 7.849903768360946, 6.884958920506958, 7.863011074070199, 7.805592695247341, 8.701819193687292, 9.719712068162236, 10.758331825680433, 11.670675314670895, 12.720152035029786, 13.575933471052679, 14.521379258824584, 15.524219695373331, 14.599098365121325, 13.635484081341097, 12.630734771095677, 11.76236144913696, 10.780527923656923, 9.74558406427715, 8.848264340961743, 7.806909882940319, 6.880096054426977, 5.949605997398827, 6.935722261518245, 6.811935714678992, 7.732255610764939, 8.785640605241673, 9.768335422327526, 10.653253686829983, 11.66113811545442, 12.62867150423026, 13.55516852553635, 14.524185241579636, 13.596750477318867, 12.628723839090581, 11.703197508950952, 10.716120177426443, 9.784869591010155, 8.7144385772519, 7.803629873175434, 6.863193702491553, 5.8744933191968745, 4.963273587277149, 5.932842942524715, 5.812593251564035, 6.79198804119109, 7.811006108910591, 8.779125608669444, 9.70043412473963, 10.715096243311603, 11.663747966911282, 12.601422363009613, 13.653596792241025, 12.832759311217709, 11.805305185050837, 10.81580343511409, 9.77993445147082, 8.765149530764589, 7.778495696358336, 6.79599140096792, 5.812283894029252, 4.823596516944673, 3.984593810868366, 4.931163251402321, 4.839711300662796, 5.781236681508357, 6.80805178544052, 7.80424661467945, 8.729608110664483, 9.725654368588248, 10.688577501452283, 11.713072460742485, 12.668362351841097, 11.792631132505438, 10.83398613343428, 9.812914681795515, 8.790187143614478, 7.741129047165455, 6.814329599513199, 5.890024688404519, 4.875871977778861, 3.8613312513322047, 2.9174254720430803, 3.8926920877900955, 3.8623919747326805, 4.853041139138853, 5.8134006190081715, 6.87641050142796, 7.849941751814838, 8.915847401414831, 9.804242489782958, 10.785789224380691, 11.789277194198197, 10.871145754439606, 9.830570276883593, 8.883709536743147, 7.852889291083951, 6.86103581969396, 5.862890705573173, 4.870317558231768, 3.8906932451946012, 2.9317366129610822, 1.898325798178959, 2.884774796340139, 2.8620573046795874, 3.807878133777033, 4.855504251131038, 5.914332317966444, 6.84619430987947, 7.864994872488001, 8.799531753601872, 9.822442608404014, 10.794886459287733, 9.945133864809886, 8.877005641596915, 7.854872827552062, 6.894348354210128, 5.941367816018758, 4.941333875414551, 3.979015544277137, 2.942454723315719, 1.9125608476306264, 0.9272453077608659, 1.9024687220177552, 1.8959506564103081, 2.9566039066375702, 3.9844878721699435, 4.9315083967954125, 5.975340690316299, 6.970575843411282, 7.9148640417416525, 8.936680824518309, 9.94171256451704, 9.031880753023477, 7.9849311555778115, 7.0221984152088694, 5.962866591080575, 5.0022093565365395, 4.0310849830194755, 3.0554493342133777, 2.104286973172928, 1.048583862109935, 0.0, 0.9459533478556332, 2.8959864891666856, 3.9355861585538885, 4.958974361183027, 5.935529320865533, 6.960558339280045, 7.897708040588348, 8.888431536250339, 9.932745410308545, 10.945973605712517, 9.93840871278485, 8.866812454140907, 7.873416230964763, 6.92840610791218, 5.9491633253785965, 4.943333877343775, 3.923917913293857, 2.9046909293198273, 1.9638385998764325, 1.0192716835420739, 1.901186271583485, 3.8868716923529476, 4.898556678088124, 5.859208642754039, 6.906216614274085, 7.854511796378102, 8.840023941850523, 9.823351356396454, 10.843250492536514, 11.785005898022014, 10.924604941240943, 9.85303779137567, 8.828291838765125, 7.853998815975322, 6.9245799795035765, 5.88562907119691, 4.892460270147467, 3.9793099256531432, 2.975825483487492, 2.0856962810594135, 2.828024712305328], [2.844250176667664, 3.8032254319405947, 4.782562445377807, 5.773437586850388, 6.801672226481436, 7.756786037528296, 8.784129851146274, 9.798605333553853, 10.738262470752954, 11.762688748498558, 12.81600142467956, 11.878889757326615, 10.813837032876437, 9.805444599940628, 8.834971059317612, 7.848985176073566, 6.891599697099975, 5.867227099871699, 4.8811654049778115, 3.8544278086277046, 3.8631559543142404, 4.8585297779306185, 5.773075323681811, 6.7216125448855015, 7.781462938663335, 8.735987955845552, 9.734256554766462, 10.72625236856011, 11.77801499435352, 12.799496345686386, 13.750084504186272, 12.790042430481122, 11.731232490754103, 10.714805318336833, 9.762099054888266, 8.830876685302709, 7.817047374589279, 6.897551936335979, 5.929255400810341, 4.908936298574567, 4.906878607347966, 5.848033747170858, 6.752449785012475, 7.711399623229994, 8.70911620530676, 9.721929849650174, 10.736986654101981, 11.758875163528925, 12.774538152311305, 13.7817928728423, 14.663728460540963, 13.732935471751793, 12.68066524218055, 11.684690407742856, 10.710391634481095, 9.813369214585201, 8.889981641109063, 7.869856521381932, 6.854653551893508, 5.946968808829833, 5.925226652345252, 6.859123686292061, 7.736293706322554, 8.664902725827204, 9.704162237376579, 10.70525899634155, 11.653739773794122, 12.644848308196345, 13.630398658354625, 14.607124049189089, 15.607575094885995, 14.598878428411489, 13.634975147315362, 12.672426706959612, 11.730297590422689, 10.697703595646333, 9.7691849692062, 8.834066893399491, 7.840487740237952, 6.947856366291405, 6.850802303768866, 7.798137608269711, 8.792275345867488, 9.729421161524778, 10.68642415913692, 11.752232329052124, 12.707709844853875, 13.64841324413575, 14.622524768478998, 15.566769241592967, 16.516409210981134, 15.538248128824039, 14.623310943473037, 13.644579907294805, 12.70912683665227, 11.695332928312698, 10.733623506104962, 9.80476015632776, 8.786350522100872, 7.90454512336084, 7.858904397164888, 8.839104722514131, 9.738275446847402, 10.663662364491241, 11.628986995757296, 12.656566782932583, 13.593742236723646, 14.562271997920467, 15.554478126114184, 16.4820119377439, 17.428158829399372, 16.49917775267762, 15.541757769930006, 14.612798821594883, 13.634988451669752, 12.664219397081109, 11.753863878997107, 10.787029120298177, 9.734032549558433, 8.809247456425565, 8.802935139959937, 9.817107188915756, 10.778289665507874, 11.691080025506736, 12.599758733408187, 13.626880225011702, 14.568501786207058, 15.60091276072125, 16.574983402055846, 17.423765845665862, 18.449622915366845, 17.523063359624135, 16.607461540884564, 15.61724232880405, 14.58746837509879, 13.731433203799876, 12.716117523632166, 11.679625001311871, 10.671232707755479, 9.738677786188406, 9.814166513244528, 10.799389862836158, 11.76060074265931, 12.722156971088218, 13.625114582287583, 14.653031051948698, 15.544793233097938, 16.582294744654416, 17.537903166941167, 18.36523988227652, 18.36238018214589, 17.36191372873542, 16.408009122582836, 15.521009476835971, 14.47076375507213, 13.585634145513923, 12.716556603380116, 11.892219960174238, 10.922506845528146, 10.10419263272974, 9.881924170002513, 10.780174495716157, 11.743273189250875, 12.6713107804289, 13.613044634045963, 14.603830534166875, 15.540111631397513, 16.552150401769413, 17.51672103778892, 18.283458875605223, 17.35033699043412, 16.382769696879823, 15.444122861347092, 14.504724256289359, 13.544889949987805, 12.557212723528682, 11.658406928822465, 10.820854649175205, 9.934092011883155, 9.136754029244658, 8.943844467242288, 9.793411929451757, 10.71029822326558, 11.691423299764775, 12.649312182358651, 13.660192069872876, 14.633336001096982, 15.575470794701399, 16.459976860073464, 17.35895353253029, 16.381745993621486, 15.456572534884442, 14.517612299805574, 13.571003759475042, 12.584017167242115, 11.595095019064274, 10.655711583762363, 9.82656673800014, 8.897195268078967, 8.15606550406163, 7.897622490451381, 8.784212711886035, 9.728332377968961, 10.797698039160192, 11.764291630063347, 12.730232362722095, 13.591817690127552, 14.565133610912415, 15.531013062796365, 16.528146275574873, 15.53278698749426, 14.631657157700596, 13.764179019121181, 12.692495500393782, 11.626783937951977, 10.675975391256872, 9.69166199053435, 8.79585711621658, 7.830912268362591, 7.139360771389271, 6.941564653804775, 7.837791152244726, 8.85568402671967, 9.855688967950067, 10.72472196681526, 11.77419868717415, 12.629980123197043, 13.57542591096895, 14.603429035035663, 15.52855036528767, 14.581437429196733, 13.576688118951312, 12.708314796992596, 11.726481271512556, 10.691537412132783, 9.794217688817376, 8.752863230795953, 7.82604940228261, 6.89555934525446, 6.209073523595769, 5.9479076732364256, 6.868227569322373, 7.905728230146004, 8.822382074471891, 9.707300338974347, 10.715184767598785, 11.682718156374625, 12.609215177680715, 13.578231893724, 14.542703825174502, 13.574677186946216, 12.649150856806587, 11.662073525282079, 10.730822938865789, 9.660391925107534, 8.749583221031067, 7.809147050347186, 6.820446667052508, 5.909226935132782, 5.206194204602239, 4.948565210121469, 5.9279599997485235, 6.865052761054957, 7.83317226081381, 8.754480776883995, 9.769142895455968, 10.717794619055647, 11.655469015153978, 12.70764344438539, 13.736834178133787, 12.751258532906473, 11.761756782969725, 10.725887799326456, 9.711102878620224, 8.72444904421397, 7.7419447488235535, 6.758237241884886, 5.7695498648003065, 4.930547158723999, 4.150618030634484, 3.9756832592202302, 4.917208640065791, 5.862098437584886, 6.858293266823816, 7.783654762808848, 8.779701020732615, 9.74262415359665, 10.767119112886851, 11.722409003985463, 12.691086826778887, 11.779939481289915, 10.75886802965115, 9.736140491470113, 8.687082395021088, 7.760282947368832, 6.835978036260152, 5.821825325634494, 4.807284599187838, 3.8633788198987133, 3.0955098800565333, 2.9164386268770475, 3.9070877912832196, 4.867447271152538, 5.930457153572327, 6.903988403959205, 7.969894053559198, 8.858289141927326, 9.839835876525058, 10.843323846342564, 11.817099102295241, 10.776523624739228, 9.82966288459878, 8.798842638939584, 7.8069891675495935, 6.808844053428807, 5.816270906087402, 4.836646593050234, 3.8776899608167152, 2.844279146034592, 2.087592588606577, 1.9161039568239542, 2.8619247859214, 3.909550903275404, 4.968378970110811, 5.900240962023837, 6.919041524632368, 7.853578405746239, 8.87648926054838, 9.8489331114321, 10.849335356052343, 9.82295898945255, 8.800826175407696, 7.840301702065761, 6.887321163874391, 5.887287223270184, 4.924968892132771, 3.8884080711713525, 2.8585141954862596, 1.8731986556164992, 1.038780903878538, 0.9499973085546749, 2.010650558781937, 3.0385345243143105, 3.9855550489397795, 5.029387342460667, 6.02462249555565, 6.96891069388602, 7.990727476662677, 8.995759216661408, 9.926180648883339, 8.930884503433445, 7.968151763064503, 6.908819938936208, 5.948162704392173, 4.977038330875109, 4.001402682069011, 3.0502403210285616, 1.9945372099655683, 0.9459533478556332, 0.0, 1.9500331413110525, 2.9896328106982555, 4.0130210133273945, 4.9895759730099005, 6.014604991424411, 6.951754692732716, 7.942478188394706, 8.986792062452913, 10.037897789112165, 10.840368157345507, 9.768771898701564, 8.775375675525419, 7.830365552472838, 6.851122769939254, 5.845293321904433, 4.825877357854514, 3.806650373880484, 2.8657980444370894, 1.9212311281027308, 0.9552329237278518, 2.9409183444973146, 3.952603330232491, 4.9132552948984065, 5.960263266418452, 6.908558448522469, 7.894070593994892, 8.877398008540823, 9.897297144680882, 10.839052550166382, 11.826564385801602, 10.754997235936328, 9.730251283325783, 8.75595826053598, 7.826539424064234, 6.787588515757568, 5.794419714708124, 4.881269370213801, 3.8777849280481487, 2.9406908754015104, 1.882071364449695], [2.883817470523013, 3.8427927257959436, 4.822129739233156, 5.813004880705737, 6.841239520336785, 7.796353331383645, 8.823697145001622, 9.838172627409202, 10.777829764608303, 11.802256042353907, 10.979440561311888, 9.989023206960631, 8.922959692849124, 7.914567259913316, 6.907771349590362, 5.919293729469467, 4.961908250495876, 3.9375356532675996, 2.960448323004501, 2.0130014465969372, 3.9027232481695893, 4.898097071785967, 5.8126426175371595, 6.76117983874085, 7.821030232518684, 8.7755552497009, 9.773823848621811, 10.765819662415458, 11.817582288208868, 12.776280482888904, 11.822884794459025, 10.862842720753875, 9.804032781026855, 8.787605608609585, 7.834899345161017, 6.90118523869861, 5.88735592798518, 4.96786048973188, 4.00853831883703, 3.0717630544841823, 4.946445901203315, 5.8876010410262065, 6.792017078867824, 7.750966917085343, 8.748683499162109, 9.761497143505522, 10.77655394795733, 11.798442457384274, 12.814105446166653, 13.756742020565985, 12.736528750813715, 11.805735762024545, 10.753465532453303, 9.757490698015609, 8.783191924753847, 7.883677767981101, 6.960290194504964, 5.949139439408621, 4.933936469920197, 4.109795564739449, 5.964793946200601, 6.89869098014741, 7.775861000177903, 8.704470019682553, 9.743729531231928, 10.7448262901969, 11.69330706764947, 12.684415602051693, 13.669965952209974, 14.646691343044438, 13.739854048708741, 12.671678718684241, 11.707775437588115, 10.745226997232365, 9.803097880695441, 8.776986513673021, 7.848467887232889, 6.913349811426181, 5.919770658264642, 5.170335172672383, 6.890369597624215, 7.8377049021250595, 8.831842639722836, 9.768988455380127, 10.725991452992268, 11.791799622907472, 12.747277138709224, 13.687980537991098, 14.662092062334347, 15.606336535448316, 14.678167743428173, 13.611048419096791, 12.696111233745789, 11.717380197567557, 10.781927126925023, 9.774615846339387, 8.81290642413165, 7.884043074354448, 6.865633440127561, 6.140553988618414, 7.898471691020237, 8.87867201636948, 9.77784274070275, 10.70322965834659, 11.668554289612645, 12.696134076787931, 13.633309530578995, 14.601839291775816, 15.594045419969532, 16.47052633586349, 15.524379444208018, 14.571978042950374, 13.614558060202759, 12.685599111867635, 11.707788741942505, 10.743502315107797, 9.833146797023796, 8.866312038324866, 7.813315467585123, 7.201225488671981, 8.842502433815286, 9.856674482771105, 10.817856959363223, 11.730647319362085, 12.639326027263536, 13.66644751886705, 14.608069080062407, 15.6404800545766, 16.614550695911195, 17.412280243785453, 16.52497127296794, 15.595863649896888, 14.680261831157317, 13.690042619076802, 12.660268665371543, 11.810716121826564, 10.795400441658854, 9.841263186837907, 8.832870893281514, 8.130655818434823, 9.853733807099877, 10.838957156691507, 11.800168036514659, 12.761724264943567, 13.664681876142932, 14.692598345804047, 15.584360526953287, 16.621862038509764, 17.577470460796516, 18.35375428039611, 17.486276977942058, 16.527793055862503, 15.71342280187016, 14.693728326191298, 13.73362713348665, 12.771850648404207, 11.84226404830357, 10.903308723951547, 9.883432592719, 9.067742048309368, 9.944784766053179, 10.843035091766822, 11.80613378530154, 12.734171376479566, 13.675905230096628, 14.66669113021754, 15.602972227448179, 16.61501099782008, 17.579581633839584, 18.399252868856667, 18.49832016965383, 17.550155888480496, 16.628210712535683, 15.68881210747795, 14.659500938570975, 13.800272070389449, 12.90041372286122, 11.938665043181203, 10.87184742636399, 10.03518065179445, 9.006705063292953, 9.856272525502423, 10.773158819316246, 11.75428389581544, 12.712172778409316, 13.723052665923541, 14.696196597147647, 15.638331390752064, 16.52283745612413, 17.453492391543612, 18.331779134932535, 17.406605676195493, 16.467645441116627, 15.521036900786095, 14.534050308553168, 13.545128160375327, 12.605744725073416, 11.776599879311194, 10.84722840939002, 9.907022608714218, 7.960483086502047, 8.8470733079367, 9.791192974019626, 10.860558635210857, 11.827152226114013, 12.79309295877276, 13.654678286178218, 14.62799420696308, 15.59387365884703, 16.591006871625538, 17.385132295055932, 16.48400246526227, 15.630344140703931, 14.642528641704835, 13.57681707926303, 12.626008532567925, 11.641695131845402, 10.745890257527632, 9.780945409673645, 8.890317876041859, 7.004425249855442, 7.900651748295392, 8.918544622770336, 9.918549564000735, 10.787582562865925, 11.837059283224816, 12.692840719247709, 13.638286507019615, 14.666289631086329, 15.591410961338335, 16.433782736758406, 15.429033426512985, 14.56066010455427, 13.655414324748588, 12.620470465368815, 11.74425083012843, 10.702896372107006, 9.776082543593663, 8.845592486565513, 7.960030628248357, 6.010768269287092, 6.931088165373039, 7.968588826196671, 8.885242670522558, 9.770160935025013, 10.77804536364945, 11.74557875242529, 12.67207577373138, 13.641092489774666, 14.660903136522421, 15.42702249450789, 14.50149616436826, 13.514418832843752, 12.65975599210182, 11.589324978343566, 10.699616362342121, 9.75918019165824, 8.770479808363561, 7.859260076443835, 7.044478429636604, 5.011425806172135, 5.990820595799189, 6.9279133571056235, 7.896032856864476, 8.81734137293466, 9.832003491506633, 10.780655215106313, 11.718329611204643, 12.770504040436055, 13.799694774184452, 14.56925774504993, 13.6048358608813, 12.57823310688813, 11.640035931856254, 10.65338209745, 9.691977890134607, 8.70827038319594, 7.7195830061113595, 6.880580300035052, 5.988902255668849, 4.0385438552708965, 4.9800692361164565, 5.924959033635552, 6.9211538628744815, 7.846515358859514, 8.84256161678328, 9.805484749647315, 10.829979708937516, 11.785269600036129, 12.753947422829553, 13.597938693433372, 12.576867241794606, 11.554139703613568, 10.61601544825712, 9.689216000604864, 8.772540164662374, 7.771858466945547, 6.757317740498891, 5.813411961209766, 4.985563068143597, 2.9792992229277138, 3.969948387333886, 4.930307867203204, 5.993317749622993, 6.966849000009871, 8.032754649609865, 8.903228061098726, 9.88477479569646, 10.888262765513966, 11.893348011186895, 12.594522836882685, 11.647662096742238, 10.616841851083041, 9.678637999323577, 8.737777106664838, 7.745203959323432, 6.786679734361286, 5.827723102127767, 4.794312287345645, 4.025142919503571, 1.9789645528746205, 2.9247853819720664, 3.9724114993260704, 5.031239566161477, 5.963101558074503, 6.96398044380377, 7.898517324917641, 8.921428179719783, 9.893872030603502, 10.894274275223745, 11.640958201596007, 10.618825387551153, 9.658300914209219, 8.734619868617207, 7.734585928013001, 6.772267596875587, 5.823421440707243, 4.808547336797312, 3.8232317969275513, 2.9888140451895904, 1.0128579046053412, 2.037095722692882, 3.064979688225255, 4.012000212850724, 5.055832506371612, 5.990766104194488, 6.9350543025248585, 7.956871085301516, 8.961902825300248, 9.892324257522178, 10.736813368547466, 9.774080628178524, 8.726819151079667, 7.766161916535632, 6.795037543018567, 5.819401894212469, 4.868239533172019, 3.944570351276621, 2.8959864891666856, 1.9500331413110525, 0.0, 1.0581134707765634, 2.081501673405702, 3.064120160893114, 4.089149179307626, 5.063633907017422, 6.081542136422278, 7.153333103520311, 8.204438830179564, 9.21200372310723, 9.808339192556913, 8.814942969380768, 7.869932846328187, 6.890690063794603, 5.884860615759782, 4.865444651709863, 3.846217667735833, 2.9053653382924383, 1.9607984219580794, 0.9948002175832006, 1.0112268978932153, 2.0229118836283915, 2.983563848294307, 4.0305718198143525, 4.97886700191837, 6.005949808279598, 6.9957331607552, 8.015632296895259, 8.957387702380759, 10.002793190555966, 10.794564529791677, 9.769818577181132, 8.795525554391329, 7.866106717919583, 6.827155809612917, 5.833987008563473, 4.920836664069149, 3.9173522219034975, 2.9802581692568593, 1.9216386583050435], [3.941930941299576, 4.900906196572507, 5.880243210009719, 6.8711183514823, 7.899352991113348, 8.854466802160207, 9.881810615778186, 10.896286098185765, 11.835943235384866, 10.982841469296687, 9.929528793115685, 8.939111438764428, 7.87405871431425, 6.865666281378441, 5.888736802825754, 4.963680067703177, 4.006294588729586, 2.98192199150131, 2.0048346612382115, 3.0315722575883184, 4.960836718946153, 5.9562105425625305, 6.870756088313723, 7.8192933095174135, 8.879143703295247, 9.833668720477462, 10.831937319398374, 11.823933133192021, 12.829632240507651, 11.757245936124296, 10.803850247694417, 9.843808173989267, 8.784998234262247, 7.768571061844976, 6.815864798396409, 5.945571576932321, 4.93174226621889, 4.0122468279655905, 3.052924657070741, 4.090333865475563, 5.975601491409317, 6.916756631232208, 7.850130549644387, 8.809080387861906, 9.806796969938672, 10.819610614282087, 11.834667418733893, 12.856555928160837, 13.744962194332372, 12.737707473801377, 11.717494204049107, 10.786701215259937, 9.734430985688695, 8.738456151251, 7.764157377989239, 6.928064106214812, 6.004676532738674, 4.993525777642332, 3.9783228081539077, 4.930152137825742, 6.993949536406602, 7.927846570353411, 8.833974470954466, 9.762583490459116, 10.801843002008491, 11.802939760973464, 12.751420538426036, 13.742529072828258, 14.697995938475504, 13.72127054764104, 12.720819501944133, 11.652644171919633, 10.688740890823507, 9.726192450467757, 8.784063333930833, 7.821372851906732, 6.8928542254666, 5.957736149659891, 4.964156996498352, 5.972739680420432, 7.919525187830216, 8.86686049233106, 9.889956110499401, 10.82710192615669, 11.784104923768831, 12.849913093684034, 13.805390609485789, 14.746094008767663, 15.5530176391657, 14.608773166051732, 13.659133196663564, 12.592013872332183, 11.67707668698118, 10.698345650802949, 9.762892580160415, 8.819002184573097, 7.85729276236536, 6.928429412588159, 5.910019778361272, 6.9429584963664635, 8.770788144500077, 9.832527834979233, 10.781765731414259, 11.707152649058099, 12.726667760389208, 13.754247547564496, 14.69142300135556, 15.659952762552381, 16.3790256007286, 15.451491789098883, 14.50534489744341, 13.552943496185765, 12.59552351343815, 11.666564565103027, 10.688754195177896, 9.787888653341508, 8.877533135257504, 7.910698376558576, 6.8577018058188335, 7.820445085239402, 9.714818887295126, 10.728990936250945, 11.690173412843063, 12.697167890750638, 13.697439498040099, 14.724560989643615, 15.666182550838972, 16.698593525353164, 17.36653468815888, 16.393245697020845, 15.505936726203329, 14.57682910313228, 13.661227284392709, 12.671008072312194, 11.641234118606935, 10.855102460060275, 9.839786779892563, 8.885649525071617, 7.877257231515225, 8.749875415002244, 10.714925205184024, 10.87314976296986, 11.852801342300491, 12.797330357358485, 13.616183735350797, 14.666178764966665, 15.645483261629131, 16.61137611249627, 17.59126253915151, 17.334719733631502, 16.467242431177446, 15.508758509097895, 14.694388255105551, 13.67469377942669, 12.714592586722041, 11.816236986637918, 10.88665038653728, 9.947695062185257, 8.92781893095271, 9.686961644876789, 10.778482253193909, 9.85255296852196, 10.815651662056677, 11.743689253234702, 12.685423106851765, 13.676209006972677, 14.612490104203316, 15.607328090488682, 16.571898726508188, 17.384669073151702, 17.47928562288922, 16.531121341715888, 15.609176165771075, 14.669777560713342, 13.640466391806367, 12.84465840862316, 11.94480006109493, 10.983051381414914, 9.9162337645977, 10.65440024836187, 9.840402550433684, 8.865790402257561, 9.782676696071382, 10.763801772570577, 11.721690655164453, 12.732570542678678, 13.688513689816252, 14.63064848342067, 15.508253660419165, 16.438908595838647, 17.41611613474745, 17.489066832937056, 16.55010659785819, 15.60349805752766, 14.635198295931689, 13.806776113087567, 12.947495406155033, 11.977339292589978, 10.953130508401891, 10.74072009585495, 8.794180573642777, 7.856591184691839, 8.800710850774763, 9.870076511965994, 10.812568430409048, 11.778509163067795, 12.640094490473253, 13.613410411258116, 14.579289863142066, 15.576423075920575, 16.50804610179942, 17.486872273219387, 16.688457611480494, 15.618241155759392, 14.552529593317585, 13.60172104662248, 12.617407645899958, 11.66701236459982, 10.702067516745833, 9.724015363182591, 7.838122736996172, 6.910169625050529, 7.928062499525472, 8.90396576829577, 9.77299876716096, 10.822475487519851, 11.678256923542744, 12.62370271131465, 13.651705835381364, 14.57682716563337, 15.556696543501893, 16.467409571330094, 15.618773575330835, 14.704099468947406, 13.669155609567634, 12.719963344182984, 11.67860888616156, 10.751795057648218, 9.777541745223191, 8.793728115389088, 6.887826131777018, 5.940606042128176, 6.954005030491706, 7.870658874817593, 8.755577139320048, 9.763461567944486, 10.730994956720325, 11.657491978026416, 12.6265086940697, 13.646319340817456, 14.61434597904574, 15.53987230918537, 14.572532303620317, 13.710568334780593, 12.640137321022339, 11.729328616945873, 10.788892446261993, 9.800192062967314, 8.791209335101513, 7.921536292126531, 5.888483668662062, 5.0003384725543265, 5.9133295614006585, 6.881449061159511, 7.802757577229695, 8.817419695801668, 9.766071419401348, 10.703745815499678, 11.75592024473109, 12.772907270761968, 13.640755634108064, 14.662949331657865, 13.636346577664694, 12.690848274535028, 11.704194440128774, 10.721690144738359, 9.737982637799691, 8.749295260715112, 7.812529558692731, 6.8659601181587755, 4.915601717760823, 3.9895871128715945, 4.910375237930587, 5.9065700671695165, 6.831931563154549, 7.827977821078315, 8.79090095394235, 9.786823869528313, 10.742113760626925, 11.710791583420349, 12.669436582491507, 13.63498071257117, 12.612253174390133, 11.666827790935892, 10.740028343283637, 9.81572343217496, 8.8015707215493, 7.787029995102644, 6.8431242158135195, 5.862620930633524, 3.8563570854176397, 2.9553645916289204, 3.9157240714982393, 4.978733953918028, 5.952265204304906, 6.980670610590967, 7.845114590322162, 8.826661324919895, 9.830149294737401, 10.83523454041033, 11.850573918674726, 12.7057755675188, 11.674955321859604, 10.73675147010014, 9.788589449343611, 8.796016302002206, 7.816391988965039, 6.8574353567315205, 5.824024541949398, 4.902200781993496, 2.8560224153645466, 1.910201586267101, 2.957827703621105, 4.016655770456512, 4.948517762369538, 5.905866973027206, 6.840403854141076, 7.863314708943217, 8.835758559826937, 9.83616080444718, 10.897009283388048, 11.676938858327716, 10.716414384985782, 9.79273333939377, 8.792699398789564, 7.830381067652151, 6.868153467086158, 5.838259591401065, 4.8529440515313045, 3.8777206372744155, 2.0396355021435806, 0.9789822519163184, 2.0068662174486915, 2.9538867420741606, 3.997719035595048, 4.932652633417924, 5.8769408317482945, 6.898757614524952, 7.903789354523683, 8.834210786745613, 9.88116038419128, 10.832194098955089, 9.78493262185623, 8.824275387312195, 7.85315101379513, 6.877515364989032, 5.9263530039485826, 4.984170020663824, 3.935586158553889, 2.9896328106982555, 1.0581134707765634, 0.0, 1.0233882026291385, 2.0060066901165503, 3.0310357085310615, 4.005520436240858, 5.023428665645714, 6.095219632743747, 7.146325359402999, 8.153890252330665, 9.225486510974608, 9.873056440157331, 8.92804631710475, 7.948803534571166, 6.942974086536345, 5.923558122486426, 4.904331138512396, 3.9634788090690014, 3.0189118927346428, 2.052913688359764, 2.0693403686697787, 1.067298221862102, 2.0279501865280176, 3.006977095547564, 3.9552722776515816, 4.947836337503034, 5.937619689978636, 6.957518826118695, 7.8992742316041955, 8.944679719779403, 10.016246869644677, 10.827932047957695, 9.853639025167892, 8.924220188696147, 7.88526928038948, 6.892100479340036, 5.978950134845713, 4.975465692680061, 4.038371640033423, 2.979752129081607], [4.945241096882598, 5.904216352155529, 6.883553365592741, 7.874428507065322, 8.902663146696371, 9.85777695774323, 10.885120771361208, 11.90000487608884, 10.983879544413153, 9.959453266667548, 8.906140590486546, 7.915723236135288, 6.850670511685112, 5.8422780787493025, 4.865348600196616, 3.9416985109123637, 2.988481866731994, 1.9641092695037183, 2.908325868572451, 3.9350634649225578, 5.964146874529174, 6.959520698145552, 7.874066243896745, 8.822603465100435, 9.882453858878268, 10.836978876060485, 11.835247474981397, 12.827243288775044, 11.806244037878512, 10.733857733495157, 9.780462045065278, 8.820419971360128, 7.761610031633108, 6.745182859215838, 5.792476595767271, 4.927758854934728, 3.913929544221298, 2.9944341059679984, 3.9564158644049803, 4.993825072809803, 6.879092698743556, 7.820247838566448, 8.777007430395038, 9.743173150558691, 10.742013583366022, 11.754827227709438, 12.786029830207159, 13.737236980485614, 12.721573991703234, 11.71431927117224, 10.69410600141997, 9.7633130126308, 8.711042783059558, 7.715067948621863, 6.740769175360101, 5.91025138421722, 4.986863810741082, 4.007835950993266, 4.881814015488147, 5.833643345159981, 7.897440743740842, 8.83133777768765, 9.760851351705117, 10.689460371209767, 11.728719882759142, 12.738156374400814, 13.686637151853386, 14.660158086004646, 13.674607735846365, 12.697882345011902, 11.697431299314996, 10.629255969290496, 9.66535268819437, 8.70280424783862, 7.760675131301694, 6.8444163476838735, 5.915897721243741, 5.035543984786495, 5.867648203832592, 6.876230887754671, 8.823016395164455, 9.770351699665301, 10.798656755694944, 11.753978806907341, 12.710981804519482, 13.776789974434685, 14.74060722291314, 15.600636633914984, 14.529629436536565, 13.585384963422596, 12.635744994034429, 11.568625669703046, 10.653688484352044, 9.674957448173812, 8.739504377531276, 7.876703005205292, 6.914993582997556, 6.085195610908817, 6.813510985695511, 7.846449703700703, 9.674279351834317, 10.736019042313472, 11.685256938748498, 12.610643856392338, 13.649473317426194, 14.67705310460148, 15.614228558392544, 16.365616950899582, 15.35563739809946, 14.428103586469746, 13.481956694814272, 12.529555293556628, 11.572135310809012, 10.643176362473888, 9.665365992548757, 8.845589473973703, 7.9352339558897, 7.083620597316431, 7.761193013153073, 8.72393629257364, 10.618310094629365, 11.632482143585184, 12.075260010931416, 13.037441606581563, 13.70455309053277, 14.755343098206238, 15.684788214822587, 16.63115118019501, 16.34314648552974, 15.369857494391708, 14.482548523574192, 13.553440900503142, 12.63783908176357, 11.647619869683055, 10.617845915977796, 9.91280328069247, 8.897487600524759, 8.059482534716325, 8.780748438849464, 9.653366622336481, 11.618416412518261, 11.854507052454043, 11.09294893377998, 12.006364661000081, 12.679197241653373, 13.729192271269241, 14.708496767931708, 15.649769196261845, 16.629655622917085, 16.311331531002367, 15.443854228548311, 14.485370306468758, 13.671000052476412, 12.65130557679755, 11.691204384092902, 10.883648465393739, 9.9540618652931, 9.121528071829964, 9.83131013828695, 10.590452852211026, 11.759839542678094, 10.833910258006144, 10.055799253536165, 10.952723556876299, 11.748436613154341, 12.739222513275253, 13.675503610505892, 14.645721174254255, 15.610291810273761, 16.423062156917272, 16.455897420260083, 15.507733139086753, 14.585787963141936, 13.646389358084203, 12.617078189177228, 11.91206988737898, 11.01221153985075, 10.192893382828997, 10.81972497193194, 11.557891455696108, 10.821759839917869, 9.847147691741744, 9.02282428755087, 9.957128454803273, 10.78470416146703, 11.795584048981254, 12.726906773581826, 13.669041567186243, 14.546646744184736, 15.477301679604217, 16.45450921851302, 16.46567863030792, 15.526718395229052, 14.58010985489852, 13.61181009330255, 12.874187591843388, 12.014906884910852, 11.187181294004061, 11.856621715736129, 11.722077385339134, 9.775537863126962, 8.837948474176022, 8.040858442254251, 8.929383600082, 9.850961514174617, 10.816902246833367, 11.678487574238826, 12.651803495023687, 13.617682946907637, 14.614816159686146, 15.546439185564994, 16.525265356984963, 16.550738979759213, 15.634754885034493, 14.569043322592687, 13.936897236984555, 12.978956478138866, 12.217890915787622, 11.683424806230017, 10.705372652666775, 8.819480026480356, 7.8915269145347136, 7.060514571409985, 7.951749625643448, 8.811391850926531, 9.860868571285422, 10.716650007308315, 11.662095795080221, 12.690098919146937, 13.615220249398943, 14.595089627267466, 15.501733757269516, 16.572728333126843, 15.727487671576544, 14.69254381219677, 13.743351546812121, 12.701997088790698, 11.775183260277355, 10.800929947852328, 9.775085404873272, 7.911214334406156, 6.9219633316123605, 6.001788887839384, 6.918442732165271, 7.793970223085619, 8.801854651710057, 9.769388040485897, 10.695885061791987, 11.664901777835272, 12.680643526756878, 13.648670164985163, 14.574196495124792, 15.5612738266493, 14.733956537409732, 13.663525523651478, 12.752716819575012, 11.812280648891132, 10.823580265596453, 9.81459753773065, 8.944924494755668, 6.9118718712912, 5.981695762038511, 4.961113418748337, 5.929232918507189, 6.841150660995266, 7.8558127795672394, 8.804464503166919, 9.74213889926525, 10.782854457449412, 11.74951906813283, 12.617367431478927, 13.660808797069544, 14.65973478029383, 13.714236477164167, 12.727582642757913, 11.745078347367498, 10.76137084042883, 9.77268346334425, 8.835917761321868, 7.889348320787914, 5.938989920389961, 5.004620376297535, 3.958159095278266, 4.944963150935088, 5.87032464692012, 6.866370904843887, 7.795790307759933, 8.763435666899175, 9.718725557997788, 10.687403380791212, 11.64604837986237, 12.697654972068037, 13.635641377019269, 12.690215993565031, 11.763416545912776, 10.839111634804098, 9.82495892417844, 8.810418197731783, 7.8665124184426585, 6.886009133262662, 4.879745288046778, 3.978752794258059, 2.9635079288459183, 4.014092835722263, 4.97703636666353, 5.957282407961829, 6.821726387693025, 7.803273122290758, 8.806761092108264, 9.81184633778119, 10.827185716045589, 11.8755866237629, 12.698343524488742, 11.76013967272928, 10.81197765197275, 9.819404504631345, 8.839780191594178, 7.8808235593606595, 6.847412744578537, 5.925588984622635, 3.879410617993685, 2.9335897888962394, 2.0056115609687843, 3.0414269328151358, 3.9732889247281618, 4.882478770398068, 5.817015651511939, 6.83992650631408, 7.812370357197799, 8.812772601818041, 9.87362108075891, 10.832465859077226, 11.73980258761492, 10.81612154202291, 9.816087601418705, 8.85376927028129, 7.891541669715297, 6.861647794030204, 5.8763322541604435, 4.901108839903554, 3.0630237047727187, 2.002370454545457, 1.0204639907358934, 1.9674845153613627, 3.01131680888225, 3.9092644307887863, 4.853552629119156, 5.8753694118958135, 6.880401151894546, 7.810822584116477, 8.857772181562142, 9.820504921931084, 10.808320824485367, 9.847663589941332, 8.876539216424268, 7.900903567618171, 6.9497412065777215, 6.007558223292962, 4.958974361183027, 4.013021013327394, 2.081501673405702, 1.0233882026291385, 0.0, 0.9826184874874117, 2.007647505901923, 2.98213223361172, 4.000040463016576, 5.071831430114609, 6.122937156773861, 7.130502049701528, 8.202098308345471, 9.195494531521616, 9.951434519733889, 8.972191737200305, 7.966362289165484, 6.946946325115565, 5.927719341141535, 4.98686701169814, 4.042300095363782, 3.0763018909889026, 2.982474414931518, 1.9707894291963415, 1.010137464530426, 1.9835888929184256, 2.9318840750224426, 3.924448134873896, 4.914231487349498, 5.9341306234895566, 6.8758860289750565, 7.921291517150264, 8.992858667015538, 10.017604619626082, 10.877027227797031, 9.947608391325286, 8.908657483018619, 7.915488681969175, 7.002338337474852, 5.9988538953092, 5.061759842662562, 4.003140331710746], [5.92785958437001, 6.88683483964294, 7.866171853080153, 8.857046994552734, 9.885281634183782, 10.84039544523064, 11.86773925884862, 10.94091819412484, 10.00126105692574, 8.976834779180136, 7.923522102999133, 6.933104748647875, 5.8680520241976994, 4.85965959126189, 3.8827301127092038, 2.959080023424952, 2.0302785864919715, 2.9467277569911303, 3.8909443560598627, 4.9176819524099695, 6.946765362016587, 7.942139185632964, 8.856684731384156, 9.805221952587848, 10.86507234636568, 11.819597363547896, 12.817865962468808, 11.875388176184511, 10.823625550391101, 9.751239246007746, 8.797843557577867, 7.837801483872716, 6.778991544145695, 5.762564371728425, 4.809858108279858, 3.9649608279735884, 2.9557262639812754, 3.8840481086454535, 4.939034351892392, 5.976443560297215, 7.861711186230968, 8.80286632605386, 9.759625917882449, 10.725791638046102, 11.724632070853433, 12.737445715196849, 13.76864831769457, 12.754618492998201, 11.738955504215822, 10.731700783684827, 9.711487513932557, 8.780694525143387, 7.728424295572145, 6.7324494611344505, 5.758150687872688, 4.94745335725608, 4.028660530501059, 4.897449953670722, 5.864432502975559, 6.816261832647393, 8.880059231228254, 9.813956265175062, 10.743469839192528, 11.672078858697178, 12.711338370246553, 13.720774861888225, 14.668648132919458, 13.677539598517235, 12.691989248358954, 11.71526385752449, 10.714812811827583, 9.646637481803083, 8.682734200706957, 7.720185760351207, 6.778056643814281, 5.886213067443851, 4.957694441003719, 5.892812516810428, 6.850266691320003, 7.858849375242084, 9.805634882651868, 10.752970187152712, 11.781275243182355, 12.736597294394752, 13.693600292006893, 14.759408461922096, 15.558721545709444, 14.61801814642757, 13.54701094904915, 12.602766475935182, 11.653126506547014, 10.586007182215633, 9.671069996864631, 8.6923389606864, 7.756885890043864, 6.91849972496527, 5.9567903027575335, 6.885653652534735, 7.796129473182923, 8.829068191188115, 10.65689783932173, 11.718637529800885, 12.667875426235911, 13.11342273896468, 13.71186123689242, 14.739441024067705, 15.676616477858769, 15.382998463412171, 14.373018910612048, 13.445485098982333, 12.49933820732686, 11.546936806069215, 10.5895168233216, 9.660557874986477, 8.682747505061347, 7.887386193733681, 6.977030675649678, 7.8840786389423485, 8.743811500640485, 9.706554780061053, 11.600928582116778, 12.615100631072597, 12.948785376817197, 12.086005077949185, 12.741089499241529, 13.791879506914997, 14.721324623531347, 15.667687588903766, 15.360527998042327, 14.387239006904295, 13.499930036086779, 12.57082241301573, 11.655220594276159, 10.665001382195644, 9.635227428490385, 8.954600000452448, 7.939284320284735, 8.859940576342243, 9.763366926336875, 10.635985109823894, 12.601034900005674, 12.78508451041374, 11.96647429966576, 11.054928132367703, 11.715733650362132, 12.765728679978, 13.745033176640467, 14.6863056049706, 15.66619203162584, 15.328713043514952, 14.461235741060898, 13.502751818981345, 12.688381564989001, 11.66868708931014, 10.708585896605491, 9.925445185153714, 8.995858585053076, 9.921986113455883, 10.813928625774361, 11.573071339698439, 12.69041700063779, 11.76448771596584, 10.929324619421946, 10.00128702824392, 10.7849730218631, 11.775758921984012, 12.712040019214651, 13.682257582963011, 14.646828218982517, 15.459598565626031, 15.47327893277267, 14.52511465159934, 13.603169475654525, 12.663770870596792, 11.634459701689817, 10.953866607138956, 10.054008259610725, 10.993351424454916, 11.802343459419351, 12.54050994318352, 11.752337297877565, 10.77772514970144, 9.953401745510568, 9.005691926170895, 9.821240570175789, 10.832120457690014, 11.763443182290581, 12.705577975894998, 13.583183152893493, 14.513838088312976, 15.491045627221782, 15.48306014282051, 14.544099907741641, 13.59749136741111, 12.629191605815139, 11.915984311603363, 11.056703604670828, 11.98763933562998, 12.83924020322354, 12.65265484329883, 10.706115321086658, 9.768525932135718, 8.97143590021395, 7.977947071449621, 8.887497922883377, 9.853438655542123, 10.715023982947582, 11.688339903732444, 12.654219355616394, 13.651352568394904, 14.565517987865947, 15.544344159285915, 15.568120492271802, 14.652136397547082, 13.586424835105277, 12.97869395674453, 12.020753197898841, 13.018348957413542, 12.614002264189713, 11.63595011062647, 9.750057484440052, 8.82210437249441, 7.991092029369682, 7.000313097011068, 7.84792825963529, 8.897404979994178, 9.753186416017073, 10.698632203788979, 11.70917772144789, 12.634299051699896, 13.61416842956842, 14.519115269782102, 15.590109845639429, 15.582030126291787, 14.547086266912014, 13.955042236646687, 12.959551957637238, 12.707333540441496, 11.733080228016469, 10.705662862832968, 8.848947629118989, 7.852540789572058, 6.932366345799081, 5.967006203532892, 6.8305066317943774, 7.838391060418814, 8.805924449194654, 9.714963864092942, 10.683980580136227, 11.698025039269464, 12.666051677497748, 13.591578007637377, 14.578655339161886, 15.621397462427183, 14.640080483333985, 13.729271779257518, 12.788835608573638, 11.800135225278959, 10.752330832443482, 9.8826577894685, 7.849605166004031, 6.912273219998208, 5.891690876708034, 4.97779638987481, 5.877687069704025, 6.892349188275997, 7.8410009118756765, 8.761217701566204, 9.800235969962, 10.766900580645418, 11.634748943991514, 12.678190309582131, 13.7140592932254, 14.690791436846673, 13.70413760244042, 12.721633307050004, 11.737925800111336, 10.749238423026757, 9.7736510560347, 8.827081615500745, 6.876723215102793, 5.935197834257233, 4.888736553237963, 3.9814995596438463, 4.9068610556288785, 5.902907313552645, 6.813171820272521, 7.780817179411763, 8.736107070510375, 9.704784893303799, 10.663429892374957, 11.715036484580624, 12.706210634336099, 13.66677095324754, 12.739971505595284, 11.815666594486604, 10.801513883860945, 9.78697315741429, 8.843067378125165, 7.8237424279754935, 5.856300247729283, 4.946562033742464, 3.8940853868056147, 3.050629244431021, 4.013572775372288, 4.974663920474416, 5.8391079002056125, 6.820654634803345, 7.824142604620851, 8.82922785029378, 9.844567228558176, 10.892968136275487, 11.76891278180557, 12.742758160216693, 11.788532611655258, 10.795959464313853, 9.816335151276686, 8.857378519043166, 7.823967704261043, 6.90214394430514, 4.855965577676191, 3.9101447485787455, 2.9361890189284807, 2.077963341523894, 3.00982533343692, 3.8998602829106557, 4.8343971640245265, 5.857308018826667, 6.829751869710386, 7.830154114330629, 8.891002593271498, 9.849847371589814, 10.810371844931748, 11.798740029510324, 10.798706088906117, 9.836387757768703, 8.868096629397803, 7.83820275371271, 6.8528872138429495, 5.87766379958606, 4.039578664455226, 2.9789254142279633, 1.95104144869559, 1.0040209240701208, 2.0478532175910082, 2.9266459433013745, 3.870934141631744, 4.892750924408402, 5.897782664407133, 6.828204096629064, 7.87515369407473, 8.837886434443671, 9.897218258571966, 10.830282077428745, 9.85915770391168, 8.883522055105583, 7.932359694065133, 6.984113182975469, 5.935529320865534, 4.9895759730099005, 3.064120160893114, 2.0060066901165503, 0.9826184874874117, 0.0, 1.0250290184145112, 1.9995137461243082, 3.017421975529164, 4.0892129426271975, 5.140318669286449, 6.147883562214116, 7.219479820858059, 8.212876044034203, 9.157886167086785, 9.954810224687716, 8.948980776652895, 7.929564812602976, 6.910337828628947, 5.969485499185552, 5.0249185828511935, 4.058920378476315, 3.9650929024189296, 2.9534079166837532, 1.9927559520178377, 1.0009704054310138, 1.949265587535031, 2.941829647386484, 3.931612999862085, 4.951512136002144, 5.893267541487644, 6.938673029662851, 8.010240179528125, 9.03498613213867, 10.009279154928473, 10.930226878812697, 9.89127597050603, 8.898107169456587, 7.984956824962263, 6.981472382796611, 6.044378330149973, 4.985758819198158], [6.8919041102968555, 7.850879365569786, 8.830216379006998, 9.82109152047958, 10.849326160110628, 11.804439971157487, 10.930773280437961, 9.915889175710332, 8.976232038511231, 7.951805760765626, 6.898493084584622, 5.908075730233365, 4.843023005783189, 3.834630572847379, 2.8577010942946925, 1.9713117602105417, 2.928697239184133, 3.910772282917976, 4.854988881986708, 5.881726478336815, 7.910809887943431, 8.906183711559809, 9.820729257311001, 10.769266478514693, 11.829116872292525, 12.783641889474742, 11.842354971563648, 10.85035915777, 9.79859653197659, 8.726210227593235, 7.772814539163356, 6.812772465458205, 5.753962525731184, 4.737535353313914, 3.7848290898653474, 2.977192564759178, 3.854144916673437, 4.782466761337615, 5.83771768558413, 6.88284293273738, 8.760394519922707, 9.701549659745599, 10.658309251574188, 11.624474971737841, 12.623315404545172, 13.636129048888588, 12.751477984010634, 11.72958947458369, 10.713926485801311, 9.706671765270316, 8.686458495518046, 7.755665506728875, 6.703395277157634, 5.70742044271994, 4.7331216694581775, 3.95968509404167, 4.909543827246416, 5.795868606362883, 6.763115836667297, 7.714945166339131, 9.778742564919993, 10.7126395988668, 11.642153172884267, 12.570762192388917, 13.610021703938292, 14.592099891957519, 13.643619114504947, 12.652510580102724, 11.666960229944443, 10.69023483910998, 9.689783793413072, 8.621608463388572, 7.657705182292446, 6.695156741936696, 5.7530276253997705, 4.97076136262805, 5.838577737749075, 6.7736958135557845, 7.748950025011742, 8.757532708933821, 10.704318216343607, 11.651653520844452, 12.679958576874094, 13.635280628086491, 13.822190600242623, 14.887998770157825, 14.533692527294933, 13.592989128013059, 12.52198193063464, 11.577737457520671, 10.628097488132504, 9.560978163801122, 8.64604097845012, 7.6673099422718884, 6.731856871629353, 6.031906224733837, 6.83767359950289, 7.766536949280091, 8.694812806874662, 9.727751524879853, 11.555581173013469, 12.617320863492624, 13.56655875992765, 13.913551258671543, 12.879627763622246, 13.907207550797533, 14.838358640433105, 14.35796944499766, 13.347989892197537, 12.420456080567822, 11.474309188912349, 10.521907787654705, 9.56448780490709, 8.635528856571966, 7.657718486646836, 7.000792693502248, 7.857913972395034, 8.764961935687705, 9.642494834332224, 10.605238113752792, 12.499611915808517, 13.513783964764336, 13.847245232191911, 12.886133597656048, 11.908856025971355, 12.959646033644823, 13.776147964218165, 14.654364867789374, 14.335498979627816, 13.362209988489784, 12.474901017672268, 11.545793394601219, 10.630191575861648, 9.639972363781133, 8.610198410075874, 8.068006500221015, 8.820167617030092, 9.7408238730876, 10.662050260028614, 11.534668443515633, 13.499718233697413, 13.73815993961854, 12.864934155040475, 11.855056652074566, 10.883500177091959, 11.933495206707827, 12.799856517327285, 13.672982883856209, 14.652046118058916, 14.303684025100441, 13.436206722646387, 12.477722800566834, 11.66335254657449, 10.64365807089563, 9.68355687819098, 9.12206568527679, 9.876741881798434, 10.80286941020124, 11.7126119594661, 12.471754673390178, 13.643492429842592, 12.717563145170642, 11.828041457264922, 10.900003866086896, 9.952739548592927, 10.902904803677309, 11.7333276253173, 12.66893486184862, 13.632682305415592, 14.440291918673019, 14.44824991435816, 13.50008563318483, 12.578140457240014, 11.638741852182282, 10.609430683275306, 10.15048710726203, 10.934891556356085, 11.874234721200272, 12.70102679311109, 13.43919327687526, 12.705412727082367, 11.730800578906242, 10.88566741894926, 9.904542342450066, 8.989007096905615, 9.95926633938331, 10.75012046117619, 11.692255254780607, 12.563876505940481, 13.494531441359964, 14.47173898026877, 14.458031124405998, 13.51907088932713, 12.572462348996599, 11.604162587400628, 11.112604811726438, 11.937586901416188, 12.868522632375337, 13.737923536915279, 13.605730272503632, 11.65919075029146, 10.72160136134052, 9.918127141652706, 8.876797487728792, 8.055264449613203, 8.895502358474443, 9.70170126183319, 10.67501718261805, 11.634912708663382, 12.63126571375334, 13.540488969451436, 14.519315140871404, 14.543091473857292, 13.627107379132571, 12.561395816690766, 12.175314456867605, 12.901636494644201, 13.899232254158898, 13.567077693394515, 12.589025539831272, 10.703132913644854, 9.775179801699212, 8.937783270808438, 7.89916351329024, 7.015694786365116, 7.939468682926498, 8.73986369490268, 9.685309482674585, 10.68414870303338, 11.609270033285386, 12.589139411153909, 13.494086251367591, 14.565080827224918, 14.557001107877277, 13.522057248497504, 13.151662736769762, 13.840435254382598, 13.660408969646298, 12.68615565722127, 11.65873829203777, 9.811580775680742, 8.805616218776859, 7.885441775003882, 6.865856619812064, 5.998273158524204, 6.880454763351134, 7.7926017280802595, 8.689934845678431, 9.658951561721716, 10.672996020854953, 11.641022659083237, 12.566548989222866, 13.553626320747375, 14.596368444012672, 14.553202735522753, 14.222743565314488, 13.778558590611555, 12.789858207316875, 11.740139084367463, 10.85449221118234, 8.837413417928014, 7.865348649203009, 6.8447663059128345, 5.876646806153982, 5.045453596433851, 5.934412891208317, 6.827678190761283, 7.736188683151694, 8.775206951547487, 9.741871562230907, 10.609719925577004, 11.65316129116762, 12.68903027481089, 13.703815195517121, 14.640058064590079, 13.727277262597887, 12.74356975565922, 11.75488237857464, 10.761459307958681, 9.814889867424727, 7.864531467026776, 6.923006086181216, 5.876544805161947, 4.880349975923018, 4.074627582358705, 4.881661271779493, 5.788142801858009, 6.755788160997252, 7.711078052095863, 8.679755874889288, 9.638400873960446, 10.690007466166113, 11.681181615921588, 12.749092520092686, 13.675891967744942, 12.821310550034488, 11.807157839408829, 10.792617112962173, 9.848711333673048, 8.811550679899478, 6.881329266143796, 5.971591052156976, 4.919114405220126, 3.9494796607101925, 3.0486992078254076, 3.9496349020599055, 4.814078881791101, 5.7956256163888344, 6.7991135862063405, 7.804198831879268, 8.819538210143666, 9.867939117860976, 10.743883763391059, 11.741781863957016, 12.739926978077802, 11.820988482728366, 10.841364169691198, 9.882407537457679, 8.848996722675555, 7.927172962719653, 5.880994596090703, 4.935173766993257, 3.9612180373429924, 2.9768137578030656, 2.0449517658900396, 2.8748312644961445, 3.8093681456100152, 4.832279000412156, 5.8047228512958755, 6.805125095916118, 7.865973574856987, 8.824818353175303, 9.785342826517237, 10.797763733250646, 11.797797673854852, 10.861416776183212, 9.893125647812315, 8.863231772127223, 7.877916232257462, 6.902692818000572, 5.064607682869737, 4.003954432642475, 2.9760704671101013, 2.029049942484632, 1.063592582040879, 1.901616924886863, 2.845905123217233, 3.86772190599389, 4.872753645992622, 5.8031750782145535, 6.850124675660219, 7.8128574160291615, 8.872189240157455, 9.83284647470149, 10.803970848218555, 9.908551073520092, 8.957388712479643, 8.009142201389981, 6.960558339280046, 6.014604991424412, 4.089149179307625, 3.0310357085310615, 2.007647505901923, 1.0250290184145112, 0.0, 0.974484727709797, 1.9923929571146526, 3.0641839242126867, 4.115289650871938, 5.122854543799606, 6.194450802443548, 7.187847025619693, 8.132857148672274, 9.112099931205858, 9.974009795067406, 8.954593831017487, 7.935366847043458, 6.994514517600063, 6.049947601265704, 5.083949396890826, 4.929137428345776, 3.917452442610599, 2.9568004779446837, 1.909792506424638, 0.9614973243206206, 1.9168006289719726, 2.9065839814475742, 3.926483117587633, 4.868238523073133, 5.913644011248341, 6.9852111611136145, 8.009957113724159, 8.984250136513962, 9.913668972985707, 10.91630498892054, 9.923136187871098, 9.009985843376773, 8.006501401211123, 7.046603919345211, 5.9879844083933955], [7.866388838006653, 8.825364093279584, 9.804701106716795, 10.795576248189377, 11.823810887820425, 10.983632366346143, 9.956288552728164, 8.941404448000535, 8.001747310801434, 6.97732103305583, 5.924008356874826, 4.933591002523569, 3.868538278073392, 2.8601458451375823, 1.8832163665848958, 2.871693986705792, 3.829079465679383, 4.8534520629076585, 5.829473609696506, 6.856211206046613, 8.829005503492956, 9.880668439269607, 10.795213985020798, 11.74375120622449, 12.803601600002322, 11.931298948352113, 10.86787024385385, 9.875874430060204, 8.824111804266794, 7.751725499883438, 6.798329811453559, 5.838287737748408, 4.779477798021388, 3.7630506256041176, 2.8103443621555506, 3.8775747912544283, 4.754527143168687, 5.682848987832865, 6.738099912079381, 7.7832251592326305, 9.660776746417957, 10.601931886240848, 11.558691478069438, 12.524857198233091, 13.523697631040422, 12.808195858798559, 11.776993256300836, 10.755104746873892, 9.739441758091512, 8.732187037560518, 7.711973767808248, 6.781180779019078, 5.7289105494478365, 4.732935715010142, 3.7586369417483803, 4.6972699772745035, 5.647128710479249, 6.696250832858134, 7.663498063162548, 8.61532739283438, 10.53607224781839, 11.473486312838688, 12.496343658740468, 13.424952678245118, 14.464212189794493, 13.617615164247722, 12.66913438679515, 11.678025852392928, 10.692475502234647, 9.715750111400183, 8.715299065703276, 7.647123735678775, 6.683220454582649, 5.720672014226898, 4.778542897689974, 5.7083462458608825, 6.576162620981908, 7.511280696788617, 8.504859849950156, 9.513442533872237, 11.461647899242005, 12.41060951910553, 13.438914575135172, 14.467970404275295, 14.650785819877381, 14.018019980803071, 13.559207799585137, 12.618504400303262, 11.547497202924843, 10.603252729810874, 9.653612760422707, 8.586493436091326, 7.6715562507403225, 6.69282521456209, 5.757372143919556, 6.76949110796667, 7.575258482735722, 8.504121832512924, 9.450722631813075, 10.483661349818268, 12.311490997951882, 13.373230688431038, 14.322468584866064, 14.742146478306303, 13.708222983257004, 12.967215454458712, 13.863873912723308, 13.383484717287864, 12.37350516448774, 11.445971352858026, 10.499824461202552, 9.547423059944908, 8.590003077197293, 7.661044128862169, 6.683233758937039, 7.662471281634844, 8.589804282519836, 9.502546818920537, 10.398404659270637, 11.361147938691206, 13.25552174074693, 14.26969378970275, 14.67584045182667, 13.714728817290807, 12.737451245606113, 11.996902012379593, 12.801663236508368, 13.679880140079577, 13.36101425191802, 12.387725260779987, 11.500416289962471, 10.571308666891422, 9.655706848151851, 8.665487636071337, 7.635713682366077, 8.589892829622794, 9.552057927154895, 10.478408756320432, 11.417960084967028, 12.290578268454047, 14.255628058635827, 14.596934707849709, 13.693529374675233, 12.683651871709325, 11.712095396726717, 10.970751185442596, 11.825371789617488, 12.698498156146412, 13.677561390349119, 13.329199297390645, 12.46172199493659, 11.503238072857037, 10.688867818864694, 9.669173343185832, 8.709072150481184, 9.643952014678568, 10.573538614779206, 11.512493939131229, 12.468521784404514, 13.227664498328592, 14.502267198073762, 13.576337913401812, 12.65663667689968, 11.728599085721655, 10.781334768227685, 9.92842007596751, 10.758842897607503, 11.694450134138823, 12.658197577705796, 13.465807190963222, 13.473765186648363, 12.525600905475033, 11.603655729530217, 10.664257124472485, 9.63494595556551, 10.622623182024633, 11.550340764720197, 12.583859250130262, 13.456936618049504, 14.195103101813674, 13.564187495313536, 12.589575347137412, 11.744442187180429, 10.763317110681236, 9.817602316540373, 8.984781611673512, 9.775635733466393, 10.71777052707081, 11.589391778230684, 12.520046713650167, 13.497254252558973, 13.483546396696202, 12.544586161617334, 11.597977621286802, 10.629677859690831, 11.58474088648904, 12.524124321790952, 13.578147161305326, 14.493833361853692, 14.4645050407348, 12.51796551852263, 11.58037612957169, 10.776901909883874, 9.735572255959962, 8.883859669247961, 7.921017630764645, 8.727216534123393, 9.700532454908254, 10.660427980953585, 11.656780986043543, 12.56600424174164, 13.544830413161607, 13.568606746147495, 12.652622651422774, 11.586911088980969, 12.537719635676075, 13.488173915018965, 14.499795991146017, 14.425852461625682, 13.44780030806244, 11.561907681876024, 10.633954569930381, 9.796558039039606, 8.75793828152141, 7.8442900059998735, 6.9649839552167006, 7.765378967192882, 8.710824754964788, 9.709663975323583, 10.634785305575589, 11.614654683444112, 12.519601523657794, 13.590596099515121, 13.58251638016748, 12.547572520787707, 13.496764786172356, 14.426972674757362, 14.519183737877468, 13.54493042545244, 12.51751306026894, 10.670355543911912, 9.664390987008028, 8.744216543235051, 7.724631388043234, 6.826868378158961, 5.905970035641336, 6.818117000370463, 7.715450117968635, 8.68446683401192, 9.698511293145156, 10.66653793137344, 11.59206426151307, 12.579141593037578, 13.621883716302875, 13.578718007812956, 14.567845614717083, 14.637333358842724, 13.648632975548045, 12.598913852598633, 11.71326697941351, 9.696188186159183, 8.724123417434178, 7.703541074144004, 6.7354215743851515, 5.874048816068608, 4.959928163498519, 5.853193463051486, 6.761703955441897, 7.800722223837689, 8.767386834521108, 9.635235197867205, 10.678676563457822, 11.71454554710109, 12.729330467807323, 13.665573336880282, 14.586052030829057, 13.60234452389039, 12.61365714680581, 11.62023407618985, 10.673664635655896, 8.723306235257946, 7.781780854412386, 6.735319573393117, 5.7391247441541875, 4.903222801993462, 3.9071765440696957, 4.813658074148212, 5.781303433287454, 6.736593324386066, 7.705271147179491, 8.663916146250648, 9.715522738456315, 10.706696888211791, 11.77460779238289, 12.701407240035145, 13.680085318265657, 12.665932607639999, 11.651391881193343, 10.707486101904218, 9.670325448130647, 7.8184789674521, 6.904789607683625, 5.852312960746776, 4.808254428941362, 3.9074739760565773, 2.9751501743501083, 3.839594154081304, 4.821140888679037, 5.824628858496543, 6.8297141041694704, 7.845053482433867, 8.893454390151177, 9.769399035681262, 10.767297136247219, 11.765442250368006, 12.73092383442582, 11.778513870999502, 10.819557238765983, 9.786146423983858, 8.864322664027956, 6.818144297399007, 5.872323468301561, 4.894416592869642, 3.8355885260342353, 2.9037265341212093, 1.9003465367863472, 2.834883417900218, 3.8577942727023586, 4.830238123586078, 5.83064036820632, 6.89148884714719, 7.850333625465506, 8.81085809880744, 9.823279005540849, 10.823312946145055, 11.757987471977975, 10.830275349120619, 9.800381473435527, 8.815065933565766, 7.839842519308876, 6.001757384178041, 4.941104133950779, 3.9132201684184054, 2.9661996437929363, 1.922367350272049, 0.9271321971770661, 1.8714203955074358, 2.893237178284093, 3.8982689182828247, 4.828690350504756, 5.875639947950422, 6.838372688319364, 7.897704512447659, 8.858361746991694, 9.829486120508758, 10.805121769314855, 9.93187344018944, 8.946291902698285, 7.897708040588349, 6.951754692732716, 5.063633907017421, 4.005520436240858, 2.9821322336117198, 1.9995137461243082, 0.974484727709797, 0.0, 1.0179082294048556, 2.0896991965028895, 3.1408049231621415, 4.148369816089809, 5.219966074733751, 6.213362297909896, 7.158372420962478, 8.137615203496063, 9.143444651530883, 9.929078558727284, 8.909851574753255, 7.96899924530986, 7.024432328975501, 6.058434124600622, 5.903622156055572, 4.891937170320396, 3.931285205654481, 2.884277234134435, 1.9359820520304176, 0.9423159012621757, 1.932099253737777, 2.9519983898778364, 3.8937537953633368, 4.939159283538545, 6.0107264334038195, 7.035472386014363, 8.009765408804165, 8.93918424527591, 10.007222327496892, 10.897620915580895, 9.98447057108657, 8.98098612892092, 8.021088647055008, 6.962469136103192], [8.873680690186205, 9.832655945459136, 10.811992958896347, 11.80286810036893, 10.94156674380134, 9.986452932754482, 8.959109119136503, 7.9442250144088735, 7.004567877209773, 5.980141599464168, 4.926828923283164, 3.9364115689319066, 2.87135884448173, 1.8629664115459208, 2.865603637944437, 3.854081258065333, 4.811466737038924, 5.835839334267201, 6.836765461876057, 7.863503058226164, 9.811392774852497, 10.88084978104651, 11.80250583720035, 12.751043058404042, 11.954889477581546, 10.965654851071736, 9.909235822756692, 8.938253806329378, 7.88649118053597, 6.814104876152614, 5.860709187722735, 4.900667114017584, 3.8418571742905634, 2.8254300018732934, 3.7781362653218604, 4.846640811389145, 5.736914414528228, 6.665236259192406, 7.720487183438922, 8.76561243059217, 10.643164017777497, 11.584319157600389, 12.54107874942898, 13.507244469592633, 12.88254274422497, 11.912710875566244, 10.88150827306852, 9.859619763641577, 8.843956774859198, 7.836702054328202, 6.831245412746613, 5.900452423957443, 4.857072799966096, 3.881305923521179, 4.7264288449146905, 5.665061880440814, 6.61492061364556, 7.667616207239755, 8.645885334522088, 9.597714664193921, 11.503864150984702, 12.441278216005, 13.46413556190678, 14.39274458141143, 13.776432358481884, 12.750990399559177, 11.802509622106605, 10.811401087704382, 9.825850737546101, 8.849125346711638, 7.84867430101473, 6.78049897099023, 5.816595689894104, 4.869042222737935, 5.746334800856284, 6.676138149027194, 7.543954524148219, 8.479072599954929, 9.472651753116468, 10.481234437038548, 12.429439802408316, 13.37840142227184, 14.406706478301484, 15.435762307441607, 14.758694280242224, 13.737880531920704, 12.692583034896591, 11.751879635614717, 10.680872438236298, 9.736627965122329, 8.786987995734162, 7.71986867140278, 6.804931486051777, 5.841195423073128, 6.725164047085866, 7.737283011132981, 8.543050385902035, 9.471913735679237, 10.418514534979387, 11.45145325298458, 13.279282901118194, 14.34102259159735, 15.290260488032375, 15.698531084110613, 14.664607589061315, 13.912814229110216, 13.076414540867557, 12.516859952599319, 11.506880399799195, 10.57934658816948, 9.633199696514007, 8.680798295256363, 7.78829388665643, 6.8593349383213065, 7.651025662103349, 8.630263184801153, 9.557596185686144, 10.47033872208685, 11.366196562436949, 12.328939841857517, 14.223313643913242, 15.237485692869061, 15.632225057630981, 14.671113423095118, 13.693835851410425, 12.942500787031097, 12.014203864652616, 12.892420768223825, 12.494389487229475, 11.521100496091442, 10.633791525273926, 9.704683902202877, 8.85399765761099, 7.87300410679609, 8.603505585532387, 9.557684732789102, 10.519849830321203, 11.446200659486745, 12.38575198813334, 13.258370171620358, 15.223419961802138, 15.587658203511701, 14.649913980479544, 13.640036477513636, 12.668480002531028, 11.9163499600941, 11.037912417761737, 11.91103878429066, 12.87758437556288, 12.4625745327021, 11.595097230248046, 10.636613308168492, 9.887158628323832, 8.876689813910586, 9.676864053647494, 10.611743917844876, 11.541330517945514, 12.480285842297537, 13.436313687570825, 14.195456401494903, 15.492990693735752, 14.567061409063802, 13.613021282703992, 12.684983691525966, 11.737719374031997, 10.874018850619015, 9.971383525751751, 10.90699076228307, 11.858220562919556, 12.665830176176982, 12.607140421959818, 11.658976140786487, 10.844156571633876, 9.904757966576144, 10.60273785873182, 11.590415085190942, 12.518132667886507, 13.55165115329657, 14.424728521215815, 15.162895004979985, 14.554910990975527, 13.580298842799403, 12.713000881437754, 11.73187580493856, 10.773986922344685, 9.930380386325016, 8.988176361610641, 9.930311155215058, 10.789414763444444, 11.720069698863927, 12.697277237772733, 12.64848589416212, 11.785087003720992, 10.83847846339046, 11.597469762857141, 12.55253278965535, 13.491916224957262, 14.545939064471634, 15.461625265020004, 15.455228536396792, 13.50868901418462, 12.57109962523368, 11.767625405545866, 10.726295751621953, 9.840244275052273, 8.86661640541615, 7.93975716226764, 8.913073083052502, 9.860450966167345, 10.856803971257303, 11.7660272269554, 12.744853398375367, 12.809107588251155, 11.910135787457504, 12.554702992147279, 13.505511538842384, 14.455965818185275, 15.467587894312327, 15.416575957287675, 14.438523803724433, 12.552631177538014, 11.624678065592372, 10.787281534701599, 9.7486617771834, 8.835013501661864, 7.910582729868204, 6.977919595337131, 7.9233653831090365, 8.909686960537343, 9.834808290789349, 10.814677668657872, 11.719624508871554, 12.790619084728881, 12.96444125307041, 13.515364423954017, 14.464556689338666, 15.394764577923672, 15.509907233539458, 14.53565392111443, 13.50823655593093, 11.661079039573902, 10.655114482670019, 9.734940038897042, 8.715354883705224, 7.817591873820952, 6.896693531303327, 6.030657628514711, 6.915473103182395, 7.88448981922568, 8.898534278358916, 9.8665609165872, 10.79208724672683, 11.769123116443225, 12.811865239708522, 13.703663316775097, 14.747066263087826, 15.628056854504715, 14.639356471210036, 13.589637348260624, 12.7039904750755, 10.686911681821174, 9.714846913096169, 8.694264569805995, 7.726145070047142, 6.864772311730599, 5.95065165916051, 5.0657340911957345, 5.961726940655657, 7.00074520905145, 7.96740981973487, 8.835258183080967, 9.878699548671584, 10.832937390487603, 11.847722311193834, 12.767720435881532, 13.7863150918784, 14.59306801955238, 13.6043806424678, 12.610957571851841, 11.664388131317887, 9.714029730919936, 8.772504350074376, 7.726043069055107, 6.729848239816178, 5.893946297655453, 4.897900039731686, 4.026198702292461, 4.981326418501215, 5.936616309599827, 6.9052941323932515, 7.863939131464409, 8.915545723670077, 9.808843987213042, 10.87675489138414, 11.803554339036396, 12.86040713876601, 13.656656103301989, 12.642115376855333, 11.698209597566208, 10.661048943792638, 8.80920246311409, 7.895513103345616, 6.8430364564087665, 5.798977924603353, 4.898197471718568, 3.9658736700120985, 3.0521347822255525, 4.021163873892798, 5.024651843710304, 5.99623905097408, 6.947200581435117, 7.995601489152428, 8.871546134682513, 9.86944423524847, 10.867589349369256, 11.83307093342707, 12.769237366661493, 11.810280734427973, 10.776869919645849, 9.855046159689946, 7.8088677930609975, 6.863046963963551, 5.8851400885316325, 4.826312021696226, 3.8944500297832, 2.8910700324483374, 2.0474240460444664, 3.0578172579161196, 4.030261108799839, 4.99716531501093, 5.99363594614844, 6.952480724466756, 7.91300519780869, 8.9254261045421, 9.925460045146306, 10.860134570979225, 11.813613136891778, 10.791104969097518, 9.805789429227756, 8.830566014970866, 6.9924808798400315, 5.931827629612769, 4.903943664080396, 3.9569231394549265, 2.913090845934039, 1.9178556928390562, 0.9735674945086864, 1.9953842772853436, 3.0004160172840755, 3.930837449506006, 4.977787046951672, 5.940519787320614, 6.999851611448909, 7.960508845992944, 8.931633219510008, 9.907268868316105, 10.858431229356555, 9.937015398360273, 8.888431536250339, 7.942478188394706, 6.081542136422277, 5.023428665645714, 4.000040463016576, 3.017421975529164, 1.9923929571146526, 1.0179082294048556, 0.0, 1.071790967098034, 2.1228966937572857, 3.130461586684953, 4.202057845328896, 5.1954540685050405, 6.140464191557623, 7.119706974091207, 8.125536422126027, 9.144952386175946, 9.92775980415811, 8.986907474714716, 8.042340558380356, 7.076342354005478, 6.921530385460429, 5.909845399725252, 4.949193435059336, 3.9021854635392907, 2.953890281435273, 1.9247031726217172, 0.9349198201461157, 1.9548189562861749, 2.896574361771675, 3.941979849946883, 5.013546999812157, 6.038292952422701, 7.012585975212504, 7.942004811684249, 9.010042893905231, 10.057672414035379, 11.002378800491426, 9.998894358325776, 9.038996876459864, 7.9803773655080485], [9.929259638959081, 10.888234894232012, 11.867571907669223, 10.961308182831589, 9.93307354320054, 8.977959732153682, 7.9506159185357035, 6.9600056909016335, 6.020348553702533, 4.995922275956928, 3.942609599775924, 2.9521922454246665, 1.922783690514735, 2.9185453603187987, 3.921182586717315, 4.909660206838211, 5.867045685811802, 6.891418283040078, 7.892344410648935, 8.91908200699904, 10.866971723625376, 11.93642872981939, 12.858084785973226, 12.003109583811135, 10.946396276980746, 9.957161650470937, 8.900742622155892, 7.963222071145206, 6.911459445351797, 5.839073140968441, 4.8856774525385624, 4.014472034237729, 2.9598578146251375, 3.8810089506461716, 4.833715214094739, 5.9022197601620245, 6.792493363301106, 7.720815207965284, 8.7760661322118, 9.82119137936505, 11.698742966550377, 12.639898106373268, 13.59665769820186, 12.872889976431502, 11.87404954362417, 10.934675323989133, 9.903472721491411, 8.884588028457403, 7.868925039675024, 6.86167031914403, 5.906523146003007, 5.0142573441775875, 3.9750734403006702, 4.9368848722940575, 5.782007793687569, 6.720640829213693, 7.670499562418438, 8.723195156012634, 9.701464283294968, 10.6532936129668, 12.55944309975758, 13.496857164777877, 14.519714510679657, 13.874684625951476, 12.835425114402101, 11.809983155479394, 10.861502378026822, 9.8703938436246, 8.884843493466319, 7.9203460387888445, 6.965581958756381, 5.898499611324805, 4.934596330228679, 5.897144770584429, 6.801913749629163, 7.731717097800072, 8.599533472921097, 9.534651548727807, 10.528230701889346, 11.536813385811426, 13.485018751181194, 14.433980371044719, 15.462285427074361, 14.827189482418538, 13.817687036162441, 12.855881172255279, 11.810583675231166, 10.869880275949292, 9.798873078570873, 8.854628605456904, 7.904988636068738, 6.8378693117373555, 5.922932126386352, 6.869297970919622, 7.780742995858746, 8.79286195990586, 9.59862933467491, 10.527492684452113, 11.474093483752265, 12.507032201757458, 14.334861849891071, 15.396601540370227, 16.345839436805253, 15.60697505613092, 14.568145595097064, 13.540565807921778, 12.603390354130715, 11.634860592933894, 10.62488104013377, 9.697347228504055, 8.751200336848582, 7.798798935590938, 6.949705095109513, 7.878664043444637, 8.706604610876228, 9.685842133574033, 10.613175134459023, 11.525917670859727, 12.421775511209827, 13.384518790630395, 15.27889259268612, 16.29306464164194, 16.466572611694126, 15.505460977158263, 14.52818340547357, 13.776848341094242, 12.848551418715761, 11.962195650762974, 11.61239012756405, 10.639101136426017, 9.751792165608501, 8.822684542537452, 8.015408866064071, 8.892333211919421, 9.659084534305267, 10.613263681561982, 11.575428779094082, 12.501779608259621, 13.441330936906219, 14.313949120393236, 16.278998910575016, 16.461666314374472, 15.48426153454269, 14.47438403157678, 13.502827556594173, 12.750697514157245, 11.872259971824882, 10.980813666829809, 11.878264684067775, 11.580575173036674, 10.71309787058262, 9.754613948503067, 9.048569836776913, 9.896018919033917, 10.732443002420373, 11.667322866617756, 12.596909466718394, 13.535864791070416, 14.491892636343705, 15.251035350267781, 16.461270846883743, 15.441069519926574, 14.447368836767136, 13.519331245589111, 12.572066928095142, 11.70836640468216, 10.805731079814896, 9.976765644822219, 10.858900871424451, 11.666510484681876, 11.725141062294393, 10.776976781121062, 10.012456098012656, 10.924087071699475, 11.658316807504699, 12.645994033963822, 13.573711616659386, 14.60723010206945, 15.480307469988695, 16.218473953752863, 15.523191144123517, 14.518052068861326, 13.5473484355009, 12.566223359001706, 11.60833447640783, 10.76472794038816, 9.822523915673786, 9.000086037754206, 9.79009507194934, 10.720750007368821, 11.697957546277626, 11.766486534496694, 10.998163341368622, 11.857807568513792, 12.65304871163002, 13.60811173842823, 14.547495173730141, 15.601518013244513, 16.517204213792883, 16.499542410454996, 14.553002888242826, 13.615413499291886, 12.744625529221523, 11.675259868030292, 10.674591829115418, 9.700963959479294, 8.774104716330786, 7.948276985312356, 8.86113127467224, 9.857484279762199, 10.766707535460295, 11.745533706880263, 12.022183925898783, 12.929464892580835, 13.610281940920158, 14.561090487615264, 15.511544766958155, 16.523166843085207, 16.460889831345877, 15.482837677782637, 13.59694505159622, 12.668991939650578, 11.831595408759803, 10.792975651241607, 9.814678051612574, 8.74493028393135, 7.812267149400277, 6.958569285368889, 7.910367269042237, 8.835488599294244, 9.815357977162767, 10.720304817376448, 11.791299393233775, 12.796909148607039, 13.73548911230524, 14.68468137768989, 15.722475908010752, 16.554221107597662, 15.579967795172637, 14.552550429989136, 12.705392913632108, 11.699428356728225, 10.779253912955248, 9.75966875776343, 8.804526796378081, 7.7947752410013775, 6.865005182577858, 5.916153411687288, 6.885170127730573, 7.89921458686381, 8.867241225092094, 9.792767555231723, 10.769803424948119, 11.812545548213416, 12.704343625279991, 13.74774657159272, 14.700345846176024, 15.683670345268242, 14.63395122231883, 13.748304349133706, 11.73122555587938, 10.759160787154375, 9.738578443864201, 8.770458944105348, 7.863395487430534, 6.848733368858561, 5.900081645258881, 4.962407249160551, 6.001425517556343, 6.968090128239763, 7.83593849158586, 8.879379857176477, 9.833617698992496, 10.848402619698728, 11.768400744386426, 12.786995400383294, 13.770702907321962, 14.648694516526007, 13.655271445910047, 12.708702005376093, 10.758343604978142, 9.816818224132582, 8.770356943113313, 7.774162113874384, 6.93826017171366, 5.942213913789893, 4.995325998031793, 3.982006727006108, 4.937296618104719, 5.905974440898144, 6.864619439969302, 7.916226032174969, 8.809524295717935, 9.877435199889034, 10.80423464754129, 11.861087447270904, 12.814598179473935, 13.68642925091354, 12.742523471624414, 11.705362817850844, 9.853516337172296, 8.939826977403822, 7.8873503304669725, 6.843291798661559, 5.942511345776774, 5.010187544070305, 4.021262077964884, 3.0218441823976905, 4.025332152215197, 4.996919359478973, 5.947880889940011, 6.996281797657321, 7.872226443187406, 8.870124543753361, 9.868269657874148, 10.833751241931962, 11.813375554969129, 12.772332187202649, 11.821183793704055, 10.899360033748152, 8.853181667119204, 7.907360838021758, 6.929453962589839, 5.870625895754432, 4.938763903841406, 3.935383906506544, 3.081408421223153, 2.0584975664210123, 3.030941417304732, 3.997845623515823, 4.994316254653333, 5.953161032971649, 6.913685506313583, 7.926106413046991, 8.926140353651197, 9.860814879484117, 10.81429344539667, 11.835418843155724, 10.850103303285962, 9.874879889029073, 8.036794753898238, 6.976141503670976, 5.948257538138603, 5.001237013513133, 3.9574047199922457, 2.9621695668972627, 2.017881368566893, 0.9960645857902359, 2.001096325788968, 2.931517758010899, 3.978467355456565, 4.941200095825507, 6.000531919953801, 6.961189154497836, 7.9323135280149, 8.907949176820997, 9.859111537861446, 10.91481464892444, 9.932745410308547, 8.986792062452913, 7.1533331035203105, 6.095219632743747, 5.071831430114609, 4.0892129426271975, 3.0641839242126867, 2.0896991965028895, 1.071790967098034, 0.0, 1.0511057266592518, 2.058670619586919, 3.1302668782308616, 4.123663101407006, 5.068673224459588, 6.047916006993172, 7.053745455027993, 8.073161419077913, 9.092388403051942, 10.033240732495337, 9.11413152547839, 8.148133321103511, 7.993321352558462, 6.9816363668232855, 6.02098440215737, 4.973976430637324, 4.025681248533307, 2.980282121394595, 1.9904987689189937, 0.9705996327789346, 1.912355038264435, 2.957760526439643, 4.029327676304917, 5.054073628915461, 5.996648043406039, 6.9260668798777845, 7.994104962098766, 9.041703775931524, 10.030969115017763, 11.045227616106397, 10.110787843557898, 9.052168332606081], [10.930708841632683, 11.880414611082129, 10.901077597644917, 9.910202456172337, 8.88196781654129, 7.926854005494429, 6.899510191876452, 5.988189389764661, 5.121689710232617, 4.113860667659527, 3.060547991478523, 2.0701306371272654, 2.9242328931883343, 3.9199945629923976, 4.922631789390914, 5.911109409511811, 6.868494888485402, 7.892867485713678, 8.893793613322535, 9.920531209672642, 11.868420926298976, 12.911089538607884, 11.89159047594892, 10.952003857151883, 9.895290550321494, 8.906055923811685, 7.849636895496641, 7.037837345626651, 6.029397837054397, 4.957011532671041, 4.003615844241161, 3.1324104259403276, 3.961307017298737, 4.88245815331977, 5.835164416768337, 6.9036689628356225, 7.793942565974706, 8.722264410638884, 9.7775153348854, 10.82264058203865, 12.700192169223977, 13.641347309046868, 12.787949969935903, 11.82178424977225, 10.82294381696492, 9.883569597329881, 8.85236699483216, 8.002526420160002, 6.986863431377624, 5.979608710846629, 5.024461537705606, 4.132195735880186, 4.9765226429742695, 5.938334074967655, 6.783456996361167, 7.722090031887291, 8.671948765092036, 9.724644358686232, 10.702913485968567, 11.6547428156404, 13.560892302431178, 14.498306367451475, 13.771793891245983, 12.872138524267227, 11.832879012717852, 10.807437053795145, 9.858956276342573, 8.9883322353272, 8.002781885168918, 7.038284430491444, 6.083520350458981, 5.120560601700834, 5.936045532902278, 6.898593973258029, 7.803362952302761, 8.73316630047367, 9.600982675594695, 10.536100751401404, 11.529679904562943, 12.538262588485024, 14.486467953854792, 15.435429573718316, 14.827775530790916, 13.824643380734289, 12.815140934478192, 11.863395746959148, 10.912926347402326, 10.052199808029858, 8.99490799529329, 8.076689595832933, 7.127049626444767, 6.059930302113385, 6.924381329059951, 7.870747173593221, 8.782192198532343, 9.794311162579458, 10.600078537348509, 11.528941887125711, 12.475542686425863, 13.508481404431055, 15.33631105256467, 16.398050743043825, 15.721920149776265, 14.796533232132425, 13.75770377109857, 12.762626798297807, 11.825451344506744, 10.856921583309923, 9.8469420305098, 8.919408218880085, 7.973261327224611, 7.020859925966967, 7.951154297783113, 8.880113246118237, 9.708053813549824, 10.687291336247629, 11.61462433713262, 12.527366873533325, 13.423224713883425, 14.385967993303993, 16.280341795359718, 17.29451384431554, 16.795740230688867, 15.797368574398726, 14.72847550874946, 13.732940240376927, 12.887662020721685, 11.844416783663405, 10.834451117940079, 9.861162126802046, 8.97385315598453, 8.044745532913481, 9.01685806873767, 9.893782414593021, 10.660533736978863, 11.61471288423558, 12.576877981767678, 13.50322881093322, 14.442780139579817, 15.315398323066834, 17.280448113248614, 17.490594222935133, 16.513189443103354, 15.503311940137444, 14.531755465154836, 13.779625422717908, 12.901187880385546, 12.009741575390471, 11.213612340172382, 10.802636163412703, 9.93515886095865, 8.976674938879096, 9.93057954503168, 10.897468121707517, 11.73389220509397, 12.668772069291354, 13.598358669391992, 14.537313993744014, 15.493341839017303, 16.25248455294138, 17.490198755444407, 16.469997428487236, 15.476296745327799, 14.548259154149774, 13.600994836655804, 12.737294313242822, 11.83465898837556, 11.005693553382882, 10.194248527529059, 10.97796681671921, 10.947202052670422, 9.999037771497091, 10.894465806267423, 11.833864411325155, 12.659766010178295, 13.647443236637418, 14.575160819332982, 15.608679304743047, 16.481756672662293, 17.21992315642646, 16.55211905268418, 15.546979977421987, 14.576276344061561, 13.595151267562368, 12.637262384968492, 11.793655848948823, 10.85145182423445, 10.029013946314869, 9.125442728053947, 10.032206339406155, 10.956111034412164, 10.988547524872724, 11.880173049623389, 12.767584908139472, 13.654497914303617, 14.609560941101826, 15.548944376403737, 16.602967215918113, 17.51865341646648, 17.550648137114248, 15.604108614902078, 14.666519225951138, 13.773553437782184, 12.704187776590953, 11.70351973767608, 10.729891868039957, 9.80303262489145, 8.977204893873019, 8.196478930776848, 9.071497977654783, 9.98072123335288, 10.923213678646293, 11.869429448811845, 12.924153944316188, 13.744344570783358, 14.695153117478464, 15.679466518200986, 16.69108859432804, 17.51199555800513, 16.53394340444189, 14.648050778255472, 13.72009766630983, 12.882701135419055, 11.844081377900858, 10.843605960173237, 9.773858192492012, 8.84119505796094, 7.987497193929552, 7.245714925146845, 8.049502297186828, 9.029371675055351, 9.868244639897009, 10.864238723330017, 11.869848478703283, 12.78368313897662, 13.73287540436127, 14.770669934682132, 15.697483763195475, 16.631073521831887, 15.603656156648388, 13.75649864029136, 12.750534083387477, 11.8303596396145, 10.810774484422682, 9.833454704938745, 8.823703149562041, 7.89393309113852, 6.945081320247951, 6.220517783835181, 7.04715440938437, 8.015181047612655, 8.940707377752284, 9.8179974516195, 10.860739574884796, 11.752537651951371, 12.7959405982641, 13.748539872847404, 14.737240256142083, 15.685056948978081, 14.799410075792958, 12.782331282538632, 11.810266513813627, 10.789684170523453, 9.8215646707646, 8.892323395991196, 7.877661277419223, 6.929009553819544, 5.991335157721213, 5.233546073868013, 6.116029950760323, 6.974454897298909, 8.017896262889526, 8.881811725663876, 9.896596646370108, 10.816594771057806, 11.816861250284905, 12.800568757223573, 13.789256134308152, 14.706377172569299, 13.759807732035345, 11.809449331637394, 10.867923950791834, 9.821462669772565, 8.825267840533636, 7.983223297380255, 6.987177039456489, 6.024253906592455, 5.0109346355667705, 4.169417174416389, 5.053914263418704, 6.003135845682351, 7.031694305542891, 7.857718322389316, 8.925629226560414, 9.85242867421267, 10.890953297172516, 11.844464029375546, 12.849565064891916, 13.79347084418104, 12.756468544510096, 10.90462206383155, 9.990932704063075, 8.938456057126226, 7.894397525320811, 6.9936170724360265, 6.061293270729558, 5.050189986525547, 4.050772090958353, 3.109372359008421, 4.048758458670627, 4.999719989131664, 6.048120896848975, 6.920420469858788, 7.918318570424743, 8.91646368454553, 9.863617091833573, 10.84324140487074, 11.80219803710426, 12.830449201271229, 11.950465760407406, 9.904287393778457, 8.95846656468101, 7.980559689249091, 6.9217316224136844, 5.9898696305006585, 4.986489633165797, 4.1103363297838165, 3.0874254749816754, 2.1149816240979558, 3.049684722707477, 4.046155353844987, 5.005000132163302, 5.961879532984965, 6.974300439718373, 7.97433438032258, 8.890680729385728, 9.844159295298283, 10.874053170983375, 11.859368710853136, 10.925985615688326, 9.08790048055749, 8.027247230330229, 6.9993632647978545, 6.052342740172385, 5.008510446651498, 4.013275293556515, 3.068987095226145, 2.047170312449488, 1.052935424980622, 1.9833568572025528, 3.0303064546482186, 3.99303919501716, 5.030397769855412, 5.991055004399447, 6.962179377916511, 7.9378150267226095, 8.88897738776306, 9.944680498826052, 10.945973605712519, 10.037897789112165, 8.204438830179562, 7.146325359402999, 6.122937156773861, 5.140318669286449, 4.115289650871938, 3.1408049231621415, 2.1228966937572857, 1.0511057266592518, 0.0, 1.0075648929276673, 2.07916115157161, 3.0725573747477544, 4.017567497800337, 4.9968102803339205, 6.002639728368742, 7.02205569241866, 8.04128267639269, 8.982135005836085, 9.926701922170444, 9.199239047762763, 9.008241806993892, 7.996556821258716, 7.035904856592801, 5.988896885072755, 5.040601702968738, 3.9817313240681944, 2.9919479715925927, 1.9720488354525338, 1.0302934299670334, 2.0756989181422414, 3.0986445248191483, 4.059541229481362, 4.945542316746788, 5.874961153218533, 6.9429992354395145, 7.99059804927227, 8.97986338835851, 9.994121889447145, 10.993126519687785, 10.067088787041511], [11.774152486557467, 10.872849718154464, 9.893512704717253, 8.90263756324467, 7.874402923613622, 6.919289112566762, 5.891945298948785, 4.9806244968369935, 4.114124817304949, 3.1354186838412224, 2.0821060076602187, 3.0725233620114762, 3.9317977861160016, 4.927559455920065, 5.930196682318582, 6.918674302439477, 7.876059781413068, 8.900432378641344, 9.901358506250201, 10.928096102600307, 12.793058264204044, 11.90352464568022, 10.884025583021256, 9.944438964224217, 8.887725657393826, 7.898491030884017, 6.842072002568973, 6.030272452698984, 5.0509558532360925, 3.978569548852737, 3.0251738604228575, 3.9852159341280085, 4.9688719102264045, 5.890023046247437, 6.842729309696004, 7.911233855763289, 8.801507458902371, 9.729829303566548, 10.785080227813065, 11.830205474966315, 13.678299808659718, 12.737144668836827, 11.780385077008235, 10.814219356844582, 9.815378924037251, 8.876004704402217, 7.844802101904493, 7.024084436341699, 6.00842144755932, 5.001166727028325, 4.046019553887302, 4.9768125426764716, 5.984087535901937, 6.945898967895323, 7.791021889288834, 8.729654924814959, 9.679513658019705, 10.7322092516139, 11.710478378896232, 12.662307708568065, 14.568457195358846, 13.748234607958029, 12.764228998318314, 11.86457363133956, 10.825314119790185, 9.799872160867478, 8.851391383414906, 8.009890251508894, 7.024339901350613, 6.05984244667314, 5.105078366640676, 5.965177408497119, 6.9290806895932455, 7.891629129948996, 8.810927845230427, 9.740731193401338, 10.608547568522363, 11.543665644329073, 12.537244797490612, 13.545827481412692, 15.49403284678246, 14.68724852993568, 13.820210637863248, 12.817078487806622, 11.807576041550526, 10.855830854031481, 9.90536145447466, 9.073757824211553, 8.016466011474986, 7.109934063360895, 6.160294093972728, 6.90454710890967, 7.917416485750919, 8.863782330284188, 9.78975709146001, 10.801876055507126, 11.607643430276177, 12.53650678005338, 13.48310757935353, 14.516046297358724, 16.343875945492336, 15.663593153283625, 14.714355256848599, 13.788968339204759, 12.750138878170903, 11.86410413689818, 10.926928683107116, 9.958398921910295, 8.948419369110171, 8.078405878213633, 7.132258986558161, 7.865476732763252, 8.855995704301414, 9.784954652636538, 10.71561870647749, 11.694856229175295, 12.622189230060286, 13.534931766460993, 14.430789606811093, 15.393532886231661, 17.287906688287386, 16.662428489369596, 15.788175337761201, 14.78980368147106, 13.720910615821793, 12.834417578977298, 11.989139359322056, 10.978890310775158, 9.968924645051832, 9.020159786135595, 8.153723072525635, 8.889362339709766, 9.871530180881331, 10.798623821111322, 11.66809862990653, 12.622277777163244, 13.584442874695345, 14.510793703860887, 15.450345032507485, 16.322963215994502, 18.288013006176282, 17.644711163289998, 16.727700442649706, 15.717822939683797, 14.74626646470119, 13.860568405914295, 12.965430806212936, 11.960272294708323, 10.926634706971566, 9.961633822746252, 9.115028777499754, 9.821291745675381, 10.775196351827965, 11.802309528225818, 12.741457098021636, 13.676336962219018, 14.605923562319656, 15.544878886671679, 16.500906731944973, 17.260049445869047, 18.40363500173579, 17.383433674778615, 16.38973299161918, 15.461695400441156, 14.514431082947187, 13.650730559534205, 12.748095234666943, 11.919129799674264, 10.97050952889081, 10.030560198566732, 10.127071969211526, 10.843654578293377, 11.739082613063708, 12.67848121812144, 13.667330903105961, 14.655008129565084, 15.582725712260649, 16.61624419767071, 17.48932156558996, 18.22748804935413, 17.465555298975563, 16.46041622371337, 15.489712590352944, 14.508587513853751, 13.550698631259875, 12.707092095240206, 11.764888070525833, 10.942450192606252, 9.906944812193458, 9.084799721253678, 10.008704416259684, 10.933877874996726, 11.872838110075595, 12.819446650406126, 13.694012907145828, 14.689839344849691, 15.629222780151602, 16.703481408501123, 17.66580810551734, 18.4748812359355, 16.52834171372333, 15.590752324772389, 14.686989684073566, 13.617624022882335, 12.616955983967463, 11.64332811433134, 10.716468871182833, 9.890641140164401, 8.97798101491636, 8.124091359502305, 9.0333146152004, 9.975807060493814, 10.922022830659365, 11.91658905138852, 12.73677967785569, 13.687588224550796, 14.671901625273318, 15.68352370140037, 16.599525105800964, 17.45817650326314, 15.572283877076723, 14.64433076513108, 13.806934234240305, 12.768314476722109, 11.75704220646462, 10.687294438783395, 9.754631304252323, 8.900933440220935, 8.027217009286357, 7.10209567903435, 8.081965056902872, 8.92083802174453, 9.85667383040235, 10.862283585775614, 11.776118246048952, 12.725310511433602, 13.763105041754464, 14.689918870267807, 15.664172182692834, 16.52788925546964, 14.68073173911261, 13.674767182208727, 12.75459273843575, 11.735007583243933, 10.746890951230128, 9.737139395853424, 8.807369337429904, 7.858517566539334, 7.119558437979647, 6.099747791231891, 7.067774429460177, 7.993300759599806, 8.810432558691833, 9.85317468195713, 10.744972759023703, 11.788375705336431, 12.740974979919736, 13.729675363214415, 14.779394486163827, 15.723643174614208, 13.706564381359883, 12.734499612634878, 11.713917269344703, 10.74579776958585, 9.80575964228258, 8.791097523710606, 7.8424458001109265, 6.904771404012596, 6.1393143675112745, 5.168623332607845, 6.027048279146431, 7.070489644737048, 7.874246832736209, 8.889031753442442, 9.809029878130138, 10.809296357357237, 11.793003864295905, 12.781691241380484, 13.822235860123218, 14.684040830856596, 12.733682430458645, 11.792157049613085, 10.745695768593816, 9.749500939354887, 8.896659543671639, 7.900613285747873, 6.937690152883839, 5.924370881858154, 5.075185468059651, 4.106507645266226, 5.0557292275298735, 6.063318158283988, 6.850153429461648, 7.918064333632746, 8.844863781285001, 9.883388404244847, 10.836899136447878, 11.842000171964248, 12.785905951253373, 13.680701643331346, 11.8288551626528, 10.915165802884326, 9.862689155947477, 8.818630624142061, 7.917850171257276, 6.985526369550808, 5.963626232816931, 4.964208337249737, 4.022808605299804, 3.101351840518149, 4.052313370979187, 5.079744749590072, 5.91285557693112, 6.910753677497075, 7.908898791617862, 8.856052198905905, 9.835676511943072, 10.794633144176592, 11.82288430834356, 12.80933330650474, 10.828520492599708, 9.882699663502262, 8.904792788070342, 7.845964721234934, 6.914102729321908, 5.910722731987047, 5.023772576075199, 4.000861721273059, 3.0284178703893394, 2.102278104554999, 3.0987487356925083, 4.036091077763986, 4.954314640057297, 5.966735546790705, 6.966769487394912, 7.88311583645806, 8.836594402370615, 9.866488278055707, 10.851803817925468, 11.827027232182358, 10.012133579378741, 8.95148032915148, 7.923596363619105, 6.976575838993636, 5.932743545472748, 4.937508392377765, 3.993220194047395, 2.971403411270738, 1.9663716712720058, 1.035950239050075, 2.0828998364957405, 3.024130140617844, 4.022832876927744, 4.983490111471779, 5.954614484988843, 6.930250133794941, 7.8814124948353905, 8.937115605898384, 9.93840871278485, 10.840368157345507, 9.212003723107228, 8.153890252330665, 7.130502049701527, 6.1478835622141155, 5.122854543799605, 4.148369816089808, 3.1304615866849526, 2.058670619586919, 1.0075648929276673, 0.0, 1.0715962586439427, 2.064992481820087, 3.010002604872669, 3.989245387406253, 4.9950748354410734, 6.014490799490992, 7.033717783465022, 7.974570112908417, 8.919137029242776, 9.885135233617655, 10.015806699921558, 9.004121714186383, 8.043469749520467, 6.9964617780004215, 6.048166595896404, 4.989296216995862, 3.99951286452026, 2.979613728380201, 2.0378583228947007, 1.0729186574829326, 2.091079631891481, 3.051976336553695, 3.9379774238191203, 4.867396260290866, 5.935434342511847, 6.983033156344602, 7.972298495430842, 8.986556996519477, 9.985561626760116, 10.811973674339498], [10.702556227913524, 9.801253459510521, 8.82191644607331, 7.831041304600728, 6.80280666496968, 5.84769285392282, 4.820349040304842, 3.9090282381930512, 3.042528558661007, 2.089647518614841, 3.100237873290099, 4.090655227641356, 5.003394044759944, 5.999155714564008, 7.001792940962525, 7.99027056108342, 8.947656040057012, 9.972028637285288, 10.972954764894144, 11.712733859873564, 11.7214620055601, 10.831928387036276, 9.812429324377312, 8.872842705580274, 7.816129398749885, 6.826894772240075, 5.770475743925031, 4.958676194055042, 4.098074365054097, 3.126455115802668, 4.043305726052737, 5.003347799757888, 6.040468168870347, 6.96161930489138, 7.914325568339947, 8.982830114407232, 9.873103717546316, 10.801425562210493, 11.85667648645701, 12.767242349820426, 12.606703550015775, 11.665548410192883, 10.708788818364294, 9.74262309820064, 8.74378266539331, 7.804408445758273, 6.773205843260551, 6.017969077529783, 5.114511556760202, 4.149052293978256, 5.064151419517182, 5.994944408306352, 7.047214637877593, 8.017495226539266, 8.862618147932777, 9.8012511834589, 10.751109916663646, 11.803805510257842, 12.782074637540177, 13.652152903599351, 13.614052414334383, 12.676638349314086, 11.692632739674373, 10.792977372695617, 9.753717861146242, 8.728275902223535, 7.779795124770963, 7.085037237519338, 6.130430010551495, 5.207728013623071, 6.123210232270557, 6.9833092741269995, 7.947212555223126, 8.909760995578877, 9.88252410387437, 10.81232745204528, 11.680143827166305, 12.615261902973014, 13.608841056134553, 14.617423740056633, 14.539628065757997, 13.615652271291736, 12.748614379219308, 11.745482229162679, 10.735979782906583, 9.784234595387538, 8.833765195830717, 8.148904810221996, 7.122556120675868, 6.274266649467766, 7.178425959602609, 7.922678974539549, 8.935548351380799, 9.881914195914069, 10.861353350103952, 11.873472314151067, 12.67923968892012, 13.608103038697323, 14.554703837997472, 15.587642556002665, 15.54773015915402, 14.591996894639681, 13.642758998204656, 12.717372080560816, 11.67854261952696, 10.815616386483384, 9.878440932692321, 9.064489031111178, 8.054509478311054, 7.323208037395681, 8.150390852188043, 8.883608598393131, 9.874127569931293, 10.803086518266417, 11.780896888191547, 12.760134410889352, 13.687467411774342, 14.606528025104936, 15.502385865455034, 16.4651291448756, 16.491760901949068, 15.590832230725654, 14.716579079117258, 13.718207422827117, 12.64931435717785, 11.785929828562503, 10.940651608907261, 10.084980419976041, 9.075014754252715, 8.264961945317644, 9.171854938155517, 9.907494205339646, 10.88966204651121, 11.816755686741201, 12.733376811620586, 13.6875559588773, 14.649721056409401, 15.58238996250483, 16.521941291151425, 17.39455947463844, 17.50299227523366, 16.573114904646054, 15.656104184005763, 14.646226681039854, 13.674670206057247, 12.8120806554995, 11.916943055798141, 11.066362403909206, 10.037934519138036, 9.206435981928301, 10.133160643129637, 10.83942361130526, 11.793328217457844, 12.820441393855697, 13.806735279735692, 14.741615143933075, 15.671201744033713, 16.610157068385735, 17.57250299058891, 18.331645704512987, 18.472411415870532, 17.47443342638771, 16.480732743228273, 15.552695152050248, 14.605430834556278, 13.854411764974586, 12.983471947808127, 12.021868967800865, 11.05729833178136, 10.244650481978383, 9.963142880335868, 10.90923509563591, 11.844392820695113, 12.739014614483995, 13.617148552627208, 14.580360790670158, 15.508078373365722, 16.581653411699694, 17.631108590677588, 18.503374258575654, 18.4113712298483, 17.406232154586107, 16.43552852122568, 15.454403444726488, 14.496514562132612, 13.652908026112943, 12.71028143874837, 11.768146645143952, 10.724668757136739, 9.902523666196958, 8.994551883523236, 9.919725342260278, 10.858685577339147, 11.805294117669678, 12.622416648501886, 13.61824308620575, 14.557626521507661, 15.63188514985718, 16.5942118468734, 17.522685733392624, 17.448365801708043, 16.57692528102923, 15.632805614946303, 14.563439953755072, 13.5627719148402, 12.589144045204076, 11.66228480205557, 10.76158441174359, 9.79570495985964, 8.941815304445585, 8.019162082463952, 8.926377704133966, 9.85476160790807, 10.84499279274458, 11.665183419211749, 12.615991965906854, 13.600305366629376, 14.611927442756429, 15.527928847157025, 16.505981000720265, 16.57559866762531, 15.670074832260234, 14.78886562072929, 13.750245863211092, 12.702858137337357, 11.633110369656132, 10.70044723512506, 9.846749371093672, 8.844940954229637, 7.919819623977631, 7.067812524166424, 7.871408665384681, 8.785077571758409, 9.790687327131675, 10.70452198740501, 11.65371425278966, 12.691508783110523, 13.618322611623865, 14.592575924048893, 15.619993289232394, 15.664897966199652, 14.70051124933788, 13.780336805564904, 12.75801567026064, 11.692706882102865, 10.68295532672616, 9.75318526830264, 8.80433349741207, 7.937282382922928, 6.917471736175172, 6.0183450731003285, 6.9438714032399576, 7.738836300047891, 8.781578423313187, 9.673376500379762, 10.71677944669249, 11.669378721275795, 12.658079104570474, 13.707798227519886, 14.677367582767452, 14.665555503084695, 13.76024367976403, 12.739661336473857, 11.771541836715004, 10.751575573155316, 9.736913454583343, 8.788261730983663, 7.850587334885333, 6.979025821083902, 5.9863472775511255, 4.958893151384253, 6.00233451697487, 6.802650574092267, 7.817435494798499, 8.737433619486197, 9.737700098713294, 10.721407605651962, 11.71009498273654, 12.750639601479275, 13.69720904201323, 13.692673552183457, 12.817901116742238, 11.771439835722969, 10.77524500648404, 9.853651162808893, 8.857604904885127, 7.894681772021093, 6.87018681273089, 5.914896921632279, 4.946219098838854, 3.987574099767696, 4.991721899640046, 5.778557170817706, 6.846468074988804, 7.77326752264106, 8.811792145600904, 9.765302877803936, 10.770403913320306, 11.714309692609431, 12.745654339310756, 12.685210525578611, 11.94090987001348, 10.88843322307663, 9.844374691271215, 8.943594238386432, 8.011270436679961, 6.989370299946085, 5.989952404378891, 5.048552672428959, 4.024733720773022, 2.984158243217009, 4.008148490946129, 4.841259318287178, 5.839157418853134, 6.83730253297392, 7.784455940261964, 8.76408025329913, 9.72303688553265, 10.75128804969962, 11.737737047860799, 11.684875855525519, 10.908443730631413, 9.930536855199495, 8.871708788364089, 7.939846796451063, 6.936466799116201, 6.0495166432043534, 5.026605788402213, 4.054161937518494, 3.098721831143303, 2.030593607930331, 2.964494819120044, 3.882718381413355, 4.895139288146764, 5.895173228750971, 6.811519577814119, 7.7649981437266735, 8.794892019411765, 9.780207559281527, 10.755430973538417, 10.718769207256239, 9.977224396280631, 8.949340430748258, 8.00231990612279, 6.958487612601902, 5.963252459506919, 5.018964261176549, 3.9971474783998917, 2.99211573840116, 2.0616943061792288, 1.014744708733563, 1.9525338819739015, 2.9512366182838017, 3.911893852827837, 4.883018226344902, 5.858653875151, 6.809816236191449, 7.865519347254442, 8.866812454140906, 9.768771898701564, 9.808339192556913, 9.225486510974608, 8.20209830834547, 7.219479820858059, 6.194450802443548, 5.219966074733751, 4.202057845328896, 3.130266878230862, 2.07916115157161, 1.0715962586439427, 0.0, 0.9933962231761446, 1.9384063462287267, 2.9176491287623105, 3.923478576797131, 4.94289454084705, 5.962121524821079, 6.902973854264474, 7.847540770598832, 8.813538974973712, 10.799224395743174, 10.075717972830326, 9.11506600816441, 8.068058036644365, 7.1197628545403475, 6.060892475639805, 5.071109123164203, 4.051209987024144, 3.1094545815386434, 2.0910505231128127, 1.0194833732475381, 1.9803800779097525, 2.866381165175178, 3.7958000016469233, 4.863838083867905, 5.91143689770066, 6.900702236786898, 7.914960737875533, 8.913965368116171, 9.740377415695555], [9.70916000473738, 8.807857236334376, 7.828520222897164, 6.837645081424583, 5.809410441793535, 4.854296630746675, 3.8269528171286975, 2.9156320150169064, 2.0491323354848623, 3.0735586132304675, 4.092484307386712, 5.08290166173797, 5.996790267936087, 6.992551937740151, 7.995189164138668, 8.983666784259563, 9.941052263233155, 10.96542486046143, 11.746075233047527, 10.71933763669742, 10.728065782383956, 9.838532163860132, 8.819033101201168, 7.879446482404129, 6.82273317557374, 5.83349854906393, 4.777079520748886, 3.965279970878897, 3.104678141877952, 4.110366210418294, 5.035552160149351, 5.995594233854502, 7.03386439204649, 7.955015528067523, 8.90772179151609, 9.976226337583375, 10.86649994072246, 11.794821785386636, 12.794165228880056, 11.773846126644282, 11.61330732683963, 10.672152187016739, 9.715392595188147, 8.749226875024494, 7.750386442217164, 6.811012222582129, 5.779809620084406, 5.0245728543536385, 4.121115333584057, 5.128370054115051, 6.056397853613795, 6.987190842402965, 8.039461071974207, 9.010891449715409, 9.85601437110892, 10.794647406635043, 11.744506139839789, 12.797201733433985, 13.610586010095039, 12.658756680423206, 12.620656191158238, 11.68324212613794, 10.699236516498226, 9.799581149519472, 8.760321637970097, 7.73487967904739, 6.7863989015948185, 6.091641014343193, 5.13703378737535, 6.113759178209815, 7.1142102239067215, 7.975555708223613, 8.93945898931974, 9.90200742967549, 10.875920327050514, 11.805723675221422, 12.673540050342448, 13.608658126149157, 14.596420198439484, 13.643285905104392, 13.546231842581852, 12.622256048115592, 11.75521815604316, 10.752086005986534, 9.742583559730438, 8.790838372211393, 7.840368972654572, 7.155508587045851, 6.129159897499723, 7.073404370613691, 8.023044340001858, 8.914925408636163, 9.927794785477413, 10.874160630010682, 11.854749573280095, 12.86686853732721, 13.672635912096261, 14.601499261873464, 15.542282980302403, 14.599974662173826, 14.554333935977875, 13.598600671463537, 12.64936277502851, 11.723975857384671, 10.685146396350815, 9.82222016330724, 8.885044709516176, 8.071092807935031, 7.0611132551349085, 7.988647066764623, 8.934793958420096, 9.875855032489746, 10.866374004027907, 11.795332952363031, 12.773143322288162, 13.752380844985966, 14.679713845870957, 15.599924248281077, 16.46742027465912, 15.504676995238551, 15.498364678772923, 14.59743600754951, 13.723182855941113, 12.724811199650972, 11.655918134001706, 10.792533605386359, 9.947255385731117, 9.091584196799896, 8.08161853107657, 8.930400974686586, 9.956258044387571, 10.88536566745862, 11.867533508630185, 12.809002120837816, 13.7256232457172, 14.679802392973915, 15.641967490506016, 16.575786185680972, 17.366662246568467, 16.434107325001392, 16.509596052057514, 15.579718681469911, 14.662707960829618, 13.65283045786371, 12.681273982881102, 11.818684432323355, 10.923546832621996, 10.072966180733061, 9.04453829596189, 9.871875011297243, 10.828476064656758, 11.059621342821078, 11.834979473853798, 12.793783159072495, 13.549626134535389, 14.52062329944353, 15.450209899544168, 16.389165223896192, 17.440219439053376, 17.371193554875937, 17.479015192694387, 16.481037203211564, 15.487336520052128, 14.559298928874103, 13.612034611380134, 12.86101554179844, 11.990075724631982, 11.02847274462472, 10.063902108605214, 10.910089511347323, 10.834485683487522, 10.037258510203083, 10.871093212618055, 11.765715006406937, 12.623752329451063, 13.586964567494013, 14.514682150189577, 15.58825718852355, 16.637712367501443, 17.50997803539951, 17.50119155532281, 17.467799769475963, 16.514781022160516, 15.533655945661321, 14.575767063067445, 13.80465400609244, 12.94728714529715, 12.005152351692733, 11.132707908080326, 10.809649356630093, 9.86589468667489, 9.04774875682745, 9.885385969262089, 10.83199450959262, 11.629020425325741, 12.624846863029605, 13.564230298331516, 14.638488926681035, 15.600815623697255, 16.52928951021648, 16.4549695785319, 17.456577116036115, 16.53993130537944, 15.47056564418821, 14.469897605273335, 13.496269735637211, 12.569410492488704, 11.668710102176725, 10.702830650292775, 9.84894099487872, 8.890504885615606, 7.989375055821943, 8.861365384731926, 9.851596569568436, 10.671787196035604, 11.62259574273071, 12.606909143453231, 13.618531219580284, 14.53453262398088, 15.512584777544122, 15.582202444449164, 16.510155556394807, 15.695991311162423, 14.657371553644227, 13.609983827770492, 12.540236060089267, 11.607572925558195, 10.753875061526807, 9.752066644662772, 8.826945314410766, 7.939155327318079, 6.934406017072659, 7.791681348582264, 8.79729110395553, 9.711125764228866, 10.660318029613515, 11.698112559934378, 12.62492638844772, 13.599179700872748, 14.626597066056249, 14.671501743023505, 15.591821639109453, 14.687462495998039, 13.665141360693777, 12.599832572536, 11.590081017159296, 10.660310958735776, 9.711459187845206, 8.844408073356062, 7.824597426608308, 6.925470763533464, 6.006868754927935, 6.745440076871746, 7.788182200137042, 8.679980277203617, 9.723383223516345, 10.67598249809965, 11.664682881394329, 12.714402004343741, 13.683971359591308, 13.672159279908549, 14.651554069535603, 13.646787026906992, 12.67866752714814, 11.658701263588451, 10.644039145016478, 9.695387421416799, 8.757713025318468, 7.8861515115170375, 6.893472967984261, 5.866018841817389, 5.026294295550596, 5.809254350916122, 6.824039271622354, 7.744037396310052, 8.744303875537149, 9.728011382475817, 10.716698759560396, 11.75724337830313, 12.703812818837084, 12.69927732900731, 13.64080270985287, 12.678565526156104, 11.682370696917175, 10.760776853242028, 9.764730595318262, 8.801807462454228, 7.777312503164025, 6.822022612065414, 5.853344789271989, 4.894699790200831, 3.9983256764639012, 4.785160947641561, 5.853071851812659, 6.779871299464915, 7.8183959224247594, 8.771906654627792, 9.777007690144162, 10.720913469433286, 11.752258116134609, 11.691814302402467, 12.68246346680864, 11.795558913509765, 10.75150038170435, 9.850719928819567, 8.918396127113098, 7.89649599037922, 6.897078094812026, 5.955678362862094, 4.931859411206158, 3.891283933650145, 3.0147522677699845, 3.847863095111033, 4.845761195676989, 5.8439063097977755, 6.791059717085818, 7.770684030122986, 8.729640662356505, 9.757891826523473, 10.744340824684652, 10.691479632349374, 11.63730046144682, 10.83766254563263, 9.778834478797224, 8.846972486884198, 7.843592489549336, 6.956642333637489, 5.933731478835348, 4.961287627951629, 4.005847521576438, 2.937719298363467, 1.9710985959438991, 2.88932215823721, 3.9017430649706184, 4.901777005574825, 5.818123354637973, 6.771601920550527, 7.80149579623562, 8.78681133610538, 9.76203475036227, 9.725372984080094, 10.786026234307355, 9.856466121181393, 8.909445596555924, 7.865613303035038, 6.870378149940055, 5.9260899516096845, 4.904273168833027, 3.899241428834295, 2.9688199966123645, 1.9218703991666988, 0.9591376587977569, 1.9578403951076573, 2.918497629651692, 3.8896220031687565, 4.865257651974854, 5.816420013015303, 6.872123124078296, 7.873416230964763, 8.775375675525419, 8.814942969380768, 9.873056440157331, 9.195494531521614, 8.212876044034203, 7.187847025619692, 6.213362297909895, 5.19545406850504, 4.123663101407006, 3.0725573747477544, 2.064992481820087, 0.9933962231761446, 0.0, 0.9450101230525819, 1.924252905586166, 2.930082353620987, 3.9494983176709058, 4.968725301644936, 5.909577631088331, 6.854144547422689, 7.820142751797568, 9.805828172567029, 10.817513158302205, 10.108462231340553, 9.061454259820508, 8.11315907771649, 7.054288698815948, 6.064505346340346, 5.044606210200287, 4.102850804714787, 3.0832969572094258, 2.0117298073441514, 0.9869838547336078, 1.8729849419990332, 2.8024037784707785, 3.87044186069176, 4.918040674524516, 5.907306013610755, 6.92156451469939, 7.920569144940028, 8.74698119251941], [8.764149881684798, 7.862847113281795, 6.883510099844583, 5.8926349583720015, 4.864400318740953, 3.9092865076940932, 2.8819426940761157, 1.9706218919643241, 2.9102790291634246, 3.93470530690903, 4.9880179830900335, 5.978435337441291, 6.93792589560858, 7.933687565412644, 8.93632479181116, 9.924802411932056, 10.882187890905648, 11.787126804888832, 10.801065109994944, 9.774327513644838, 9.783055659331374, 8.89352204080755, 7.874022978148586, 6.9344363593515475, 5.877723052521159, 4.888488426011349, 3.8320693976963045, 3.020269847826315, 3.965824835556514, 4.971512904096857, 5.9249085925267355, 6.8849506662318865, 7.943760605958907, 8.896151155740016, 9.848857419188583, 10.917361965255868, 11.807635568394952, 12.735957413059129, 11.849155105827473, 10.8288360035917, 10.668297203787047, 9.727142063964155, 8.770382472135566, 7.804216751971913, 6.805376319164583, 5.866002099529546, 4.834799497031824, 4.079562731301056, 4.982262027262619, 5.989516747793614, 6.94575428599118, 7.87654727478035, 8.928817504351592, 9.924792338789286, 10.797149998781412, 11.735783034307536, 12.685641767512282, 13.68077885653088, 12.665575887042456, 11.713746557370623, 11.675646068105655, 10.738232003085358, 9.754226393445645, 8.854571026466889, 7.815311514917514, 6.789869555994808, 5.841388778542236, 5.146630891290611, 5.998180481053913, 6.974905871888377, 7.975356917585284, 8.864912140600998, 9.828815421697124, 10.791363862052874, 11.817055954723006, 12.746859302893915, 13.61467567801494, 14.54979375382165, 13.6514100753869, 12.698275782051809, 12.601221719529269, 11.677245925063009, 10.81020803299058, 9.807075882933951, 8.797573436677855, 7.84582824915881, 6.8953588496019895, 6.21049846399327, 6.990306591178285, 7.934551064292253, 8.88419103368042, 9.804281841013548, 10.817151217854798, 11.763517062388066, 12.783852420158867, 13.808004164999703, 14.613771539768756, 15.542634889545958, 14.59727285724982, 13.654964539121243, 13.609323812925291, 12.653590548410953, 11.704352651975928, 10.778965734332088, 9.740136273298232, 8.877210040254658, 7.940034586463594, 7.1728053311277336, 7.922259948813471, 8.849793760443186, 9.79594065209866, 10.748342053356303, 11.738861024894465, 12.667819973229589, 13.64563034315472, 14.624867865852524, 15.552200866737515, 16.54105987595357, 15.522410151606536, 14.559666872185968, 14.55335455572034, 13.652425884496926, 12.77817273288853, 11.779801076598389, 10.710908010949122, 9.847523482333777, 9.002245262678533, 8.211446093928517, 8.942765224755131, 9.791547668365148, 10.817404738066134, 11.746512361137183, 11.923130321514057, 12.852458743134408, 13.677974479597914, 14.629672361446723, 15.561774041259929, 16.50620063795725, 16.421652123515884, 15.489097201948809, 15.56458592900493, 14.634708558417328, 13.717697837777035, 12.707820334811126, 11.736263859828519, 10.873674309270774, 9.978536709569413, 9.192828077861682, 9.905684989640452, 10.733021704975805, 11.68962275833532, 11.840259873236816, 10.889969350801215, 11.848773036019912, 12.604616011482808, 13.575613176390949, 14.505199776491587, 15.44415510084361, 16.495209316000793, 16.426183431823354, 16.534005069641804, 15.536027080158982, 14.542326396999545, 13.61428880582152, 12.66702448832755, 11.91600541874586, 11.045065601579399, 10.196876099869272, 10.925048802283776, 11.771236205025886, 11.615124213903261, 10.81789704061882, 9.926083089565472, 10.820704883354354, 11.678742206398482, 12.641954444441431, 13.569672027136995, 14.643247065470968, 15.69270224444886, 16.564967912346926, 16.556181432270222, 16.522789646423384, 15.569770899107933, 14.588645822608738, 13.630756940014862, 12.859643883039858, 12.028272765720509, 11.173555706937284, 11.993854601758887, 11.623740755999435, 10.64653321709063, 9.828387287243189, 8.940375846209506, 9.886984386540037, 10.68401030227316, 11.679836739977024, 12.619220175278935, 13.693478803628455, 14.655805500644671, 15.584279387163898, 15.509959455479317, 16.511566992983536, 16.551736744404554, 15.565167626222149, 14.564499587307274, 13.923407863948725, 13.076691965063509, 12.225364759379135, 11.559293477396054, 10.672608418301303, 9.671143416031345, 8.770013586237681, 7.916355261679344, 8.906586446515854, 9.726777072983023, 10.677585619678128, 11.66189902040065, 12.673521096527702, 13.589522500928297, 14.567574654491539, 14.637192321396583, 15.565145433342225, 16.58303830781717, 15.602381676696808, 14.554993950823073, 13.485246183141848, 12.552583048610776, 11.639630241104577, 10.608529471766051, 9.683408141514045, 8.719793857733817, 7.715044547488397, 6.846671225529683, 7.852280980902948, 8.766115641176285, 9.715307906560934, 10.753102436881797, 11.67991626539514, 12.654169577820166, 13.681586943003667, 13.726491619970924, 14.646811516056871, 15.63247261905062, 14.610151483746357, 13.544842695588581, 12.535091140211877, 11.605321081788357, 10.656469310897787, 9.700870900459343, 8.681060253711587, 7.713033615483302, 6.787507285343673, 5.800429953819164, 6.843172077084461, 7.734970154151036, 8.778373100463764, 9.730972375047068, 10.719672758341748, 11.76939188129116, 12.738961236538726, 12.727149156855967, 13.706543946483022, 14.591797149959573, 13.62367765020072, 12.603711386641033, 11.58904926806906, 10.64039754446938, 9.70272314837105, 8.83116163456962, 7.838483091036842, 6.811028964869971, 5.89084698185671, 4.864244227863541, 5.8790291485697725, 6.799027273257471, 7.799293752484567, 8.783001259423235, 9.771688636507815, 10.812233255250549, 11.758802695784503, 11.75426720595473, 12.69579258680029, 13.623575649208686, 12.627380819969757, 11.70578697629461, 10.709740718370844, 9.74681758550681, 8.722322626216608, 7.767032735117996, 6.798354912324571, 5.839709913253413, 4.862878362770016, 3.8401508245889793, 4.908061728760077, 5.834861176412333, 6.873385799372178, 7.82689653157521, 8.83199756709158, 9.775903346380705, 10.807247993082028, 10.746804179349885, 11.737453343756059, 12.697812823625378, 11.696510504756931, 10.795730051872148, 9.863406250165678, 8.841506113431802, 7.8420882178646085, 6.900688485914676, 5.87686953425874, 4.836294056702727, 3.933673217717647, 2.9028529720584513, 3.9007510726244066, 4.898896186745193, 5.846049594033237, 6.825673907070405, 7.784630539303923, 8.812881703470891, 9.799330701632071, 9.746469509296793, 10.692290338394239, 11.739916455748244, 10.723844601849805, 9.79198260993678, 8.788602612601917, 7.901652456690071, 6.87874160188793, 5.906297751004211, 4.95085764462902, 3.882729421416048, 2.9048365085265626, 1.9443120351846281, 2.9567329419180366, 3.9567668825222437, 4.873113231585392, 5.8265917974979455, 6.856485673183038, 7.841801213052799, 8.817024627309689, 8.780362861027513, 9.841016111254774, 10.801476244233974, 9.854455719608506, 8.810623426087618, 7.815388272992636, 6.871100074662266, 5.849283291885609, 4.844251551886877, 3.9138301196649463, 2.8668805222192804, 1.9041477818503387, 1.0128302720550753, 1.9734875065991102, 2.9446118801161747, 3.920247528922273, 4.871409889962722, 5.927113001025715, 6.9284061079121795, 7.830365552472837, 7.869932846328186, 8.92804631710475, 9.951434519733889, 9.157886167086785, 8.132857148672274, 7.158372420962477, 6.140464191557622, 5.068673224459588, 4.017567497800337, 3.0100026048726694, 1.9384063462287267, 0.9450101230525819, 0.0, 0.979242782533584, 1.985072230568405, 3.0044881946183235, 4.023715178592353, 4.964567508035747, 5.909134424370106, 6.875132628744985, 8.860818049514448, 9.872503035249624, 10.83315499991554, 10.002589887493, 9.054294705388983, 7.995424326488441, 7.005640974012839, 5.98574183787278, 5.04398643238728, 3.998580944212072, 2.9270137943467978, 1.9022678417362542, 0.9279748189464512, 1.8573936554181965, 2.925431737639178, 3.9730305514719335, 4.962295890558172, 5.976554391646807, 6.975559021887445, 7.801971069466828], [7.784907099151214, 6.920414161780805, 5.9410771483435925, 4.950202006871011, 3.9219673672399624, 2.9668535561931026, 1.9999656927828995, 2.9474825636145985, 3.887139700813699, 4.911565978559304, 5.964878654740308, 6.955296009091565, 7.9147865672588535, 8.910548237062917, 9.913185463461433, 10.90166308358233, 11.832256619583525, 10.80788402235525, 9.821822327461362, 8.795084731111254, 8.80381287679779, 7.95108908930656, 6.931590026647596, 5.992003407850557, 4.9352901010201675, 3.9460554745103575, 2.9500923964030883, 3.9420882101967347, 4.942685507206789, 5.948373575747131, 6.901769264177011, 7.861811337882162, 8.920621277609182, 9.87301182739029, 10.825718090838857, 11.894222636906141, 12.757704297072829, 11.83820885881953, 10.86991232329389, 9.849593221058116, 9.725864252286057, 8.784709112463165, 7.827949520634576, 6.861783800470922, 5.862943367663592, 4.98402509823633, 3.9528224957386078, 4.974711005165552, 5.959122698912894, 6.966377419443888, 7.922614957641455, 8.853407946430625, 9.905678176001867, 10.901653010439562, 11.774010670431686, 12.71264370595781, 13.662502439162555, 12.73834590502989, 11.723142935541466, 10.771313605869633, 10.733213116604665, 9.795799051584368, 8.811793441944655, 7.926338167576647, 6.924780634066475, 5.907892554701592, 4.95941177724902, 5.950520311651242, 6.936070661809522, 7.912796052643986, 8.913247098340893, 9.841772812251273, 10.8056760933474, 11.76822453370315, 12.79391662637328, 13.723719974544188, 14.591536349665214, 13.70255627704745, 12.70897712388591, 11.755842830550819, 11.658788768028279, 10.734812973562018, 9.86777508148959, 8.916545002082913, 7.907042555826815, 6.963851247865594, 6.013381848308773, 6.954085247590648, 7.928196771933894, 8.872441245047863, 9.82208121443603, 10.781142512663823, 11.794011889505073, 12.740377734038342, 13.760713091809142, 14.784864836649977, 15.590632211419027, 14.673249539975718, 13.65483990574883, 12.712531587620253, 12.666890861424301, 11.76301307890453, 10.813775182469504, 9.888434853481048, 8.849605392447192, 7.995233038961441, 7.058057585170378, 7.916392114725111, 8.86015012956908, 9.787683941198795, 10.733830832854268, 11.686232234111912, 12.676751205650074, 13.321581187663737, 13.74857207743178, 14.727809600129584, 15.642145360299814, 15.63297377084529, 14.579977200105546, 13.617233920684978, 13.61092160421935, 12.761848414990503, 11.887595263382106, 10.889270195747349, 9.820377130098082, 8.96554648104056, 8.120268261385318, 8.955032877525895, 9.88065540551074, 10.729437849120757, 11.755294918821743, 12.684402541892792, 12.902373104047642, 12.307912019188953, 12.796092154002741, 13.74779003585155, 14.679891715664755, 15.624318312362075, 15.479219172014892, 14.546664250447819, 14.62215297750394, 13.744131088910905, 12.827166956925995, 11.817289453960086, 10.845732978977479, 9.991697307977557, 9.096559708276198, 9.93641486145906, 10.843575170396061, 11.670911885731414, 12.627512939090929, 12.8195026557704, 11.8692121333348, 11.304226312074457, 11.722733685887635, 12.693730850795776, 13.623317450896414, 14.562272775248436, 15.613326990405618, 15.483750480322364, 15.591572118140816, 14.645496199307942, 13.651795516148505, 12.72375792497048, 11.77649360747651, 11.034028417452642, 10.163088600286184, 10.94046288346665, 11.862938983039385, 12.709126385781495, 12.594366996436845, 11.797139823152405, 10.905325872099057, 10.276158159408899, 10.796859880803309, 11.760072118846258, 12.687789701541822, 13.761364739875795, 14.76210314180334, 15.634368809701407, 15.625582329624704, 15.632258765572342, 14.679240018256891, 13.698114941757698, 12.740226059163822, 11.977666881746641, 11.146295764427293, 11.917142490534662, 12.931744782514496, 12.60298353853302, 11.625775999624214, 10.807630069776772, 9.919618628743091, 9.342437662594582, 9.802127976677987, 10.79795441438185, 11.725351687202686, 12.799610315552204, 13.725206397999152, 14.653680284518378, 14.579360352833797, 15.580967890338012, 15.66120586355351, 14.674636745371107, 13.673968706456234, 13.041430862655508, 12.194714963770293, 12.968951542976512, 12.538536259929637, 11.651851200834887, 10.650386198564929, 9.749256368771265, 8.895598044212928, 8.270780338527539, 8.84489474738785, 9.795703294082955, 10.761302093974672, 11.772924170101724, 12.658923398282777, 13.63697555184602, 13.706593218751062, 14.634546330696704, 15.652439205171648, 15.652270719809659, 14.71353836970432, 13.997464538203452, 13.156552530700804, 12.61887302363816, 11.587772254299635, 10.662650924047629, 9.699036640267401, 8.69428733002198, 7.8259140080632665, 7.216474872914633, 7.8842333155811115, 8.833425580965761, 9.822503334236275, 10.749317162749618, 11.723570475174645, 12.750987840358146, 12.761099040057589, 13.681418936143537, 14.73480393062027, 15.589394266279943, 14.524085478122165, 13.514333922745461, 12.584563864321941, 11.635712093431371, 10.680113682992927, 9.660303036245171, 8.692276398016887, 7.766750067877257, 6.779672736352748, 6.15076152729341, 6.8530878285558625, 7.847773997818243, 8.800373272401547, 9.789073655696226, 10.831754804785493, 11.80132416003306, 11.761756576942632, 12.741151366569687, 13.716175530994212, 14.602920432734306, 13.582954169174617, 12.568292050602643, 11.619640327002964, 10.681965930904633, 9.810404417103204, 8.817725873570426, 7.790271747403555, 6.870089764390295, 5.843487010397125, 5.102295573293454, 5.9171449476622975, 6.840135525610729, 7.823843032549397, 8.812530409633977, 9.853075028376711, 10.799644468910666, 10.788874626041395, 11.730400006886955, 12.71322120752414, 13.606623602503342, 12.685029758828193, 11.688983500904428, 10.726060368040393, 9.701565408750191, 8.74627551765158, 7.777597694858155, 6.818952695786997, 5.842121145303601, 4.819393607122564, 4.078275089694319, 4.952978850817161, 5.914227572498341, 6.867738304701373, 7.872839340217743, 8.816745119506868, 9.841855413168693, 9.767561396816301, 10.758210561222475, 11.718570041091793, 12.675753287290517, 11.774972834405734, 10.842649032699264, 9.820748895965385, 8.821331000398192, 7.879931268448261, 6.8561123167923235, 5.8155368392363105, 4.912916000251231, 3.8820957545920356, 3.0033948427563484, 4.001539956877135, 4.886891367159399, 5.866515680196567, 6.825472312430086, 7.847489123557557, 8.833938121718736, 8.767226726763209, 9.713047555860655, 10.760673673214658, 11.703087384383391, 10.771225392470365, 9.767845395135502, 8.880895239223657, 7.857984384421515, 6.885540533537796, 5.930100427162605, 4.861972203949633, 3.884079291060147, 2.9235548177182125, 2.059376712049978, 3.024996122484006, 3.9139550047115543, 4.867433570624108, 5.897327446309201, 6.876408633139463, 7.851632047396352, 7.801120078493929, 8.86177332872119, 9.889657294253563, 10.833698502142092, 9.789866208621204, 8.79463105552622, 7.850342857195852, 6.8285260744191945, 5.823494334420462, 4.893072902198531, 3.846123304752865, 2.883390564383923, 1.9920730545886594, 1.0512264723083538, 1.9854536532423368, 2.961089302048435, 3.9122516630888846, 4.9679547741518775, 5.949163325378597, 6.851122769939254, 6.890690063794603, 7.948803534571166, 8.972191737200305, 9.954810224687716, 9.112099931205858, 8.137615203496061, 7.119706974091206, 6.047916006993172, 4.9968102803339205, 3.9892453874062532, 2.9176491287623105, 1.924252905586166, 0.979242782533584, 0.0, 1.0058294480348209, 2.0252454120847396, 3.044472396058769, 3.985324725502164, 4.929891641836523, 5.895889846211402, 7.881575266980865, 8.893260252716042, 9.853912217381957, 10.900920188902003, 10.031155377039257, 8.972284998138713, 7.982501645663112, 6.9626025095230535, 6.0208471040375535, 4.975441615862346, 3.903874465997072, 2.8791285133865285, 1.9048354905967253, 0.9754166541249801, 1.9481246418879556, 2.9937877689383496, 3.983053108024589, 4.997311609113224, 5.996316239353863, 6.822728286933245], [6.779077651116393, 5.914584713745984, 4.935247700308771, 3.9443725588361898, 2.9161379192051413, 1.9610241081582818, 2.988367921776259, 3.9533120116494196, 4.89296914884852, 5.917395426594125, 6.970708102775129, 7.9611254571263865, 8.920616015293676, 9.916377685097741, 10.919014911496257, 11.783812650522295, 10.826427171548703, 9.802054574320428, 8.81599287942654, 7.789255283076433, 7.797983428762969, 6.945259641271738, 5.925760578612775, 4.986173959815736, 3.929460652985347, 2.940226026475537, 3.938494625396448, 4.930490439190094, 5.94851495524161, 6.954203023781952, 7.907598712211831, 8.867640785916983, 9.926450725644003, 10.878841275425113, 11.83154753887368, 12.765704159751436, 11.751874849038007, 10.832379410784707, 9.864082875259069, 8.843763773023294, 8.720034804251238, 7.778879664428346, 6.8221200725997555, 5.855954352436102, 4.857113919628771, 3.979825755375084, 4.941224724731968, 5.963113234158912, 6.964952146947715, 7.972206867478709, 8.928444405676276, 9.859237394465445, 10.911507624036688, 11.907482458474382, 12.77984011846651, 13.718473153992633, 12.785212050589267, 11.732516456995072, 10.717313487506647, 9.765484157834814, 9.727383668569846, 8.78996960354955, 7.805963993909835, 6.920508719541827, 5.918951186031655, 4.96315490206646, 5.911635679519032, 6.902744213921253, 7.8882945640795334, 8.865019954913997, 9.865471000610903, 10.847602260286093, 11.81150554138222, 12.77405398173797, 13.799746074408104, 14.560363531259473, 13.63184490481934, 12.696726829012631, 11.703147675851092, 10.750013382516, 10.65295931999346, 9.728983525527198, 8.86194563345477, 7.910715554048092, 6.901213107791995, 6.019113595230462, 6.965605750578785, 7.906309149860659, 8.880420674203906, 9.824665147317875, 10.774305116706042, 11.786971960698644, 12.799841337539894, 13.746207182073162, 13.706863184828398, 14.729125561277131, 14.5962834417181, 13.667420091940897, 12.649010457714011, 11.706702139585435, 11.661061413389483, 10.75718363086971, 9.807945734434684, 8.88260540544623, 7.843775944412372, 7.069918121574821, 8.007093575365884, 8.868616016995123, 9.812374031839092, 10.739907843468806, 11.68605473512428, 12.638456136381924, 13.628975107920086, 13.758811939736047, 12.781001569810917, 13.760239092508721, 14.674574852678951, 14.627144322810471, 13.574147752070727, 12.61140447265016, 12.605092156184531, 11.756018966955683, 10.881765815347286, 9.88344074771253, 8.814547682063264, 8.04023156365394, 8.981853124849296, 9.907256779795906, 10.832879307780752, 11.681661751390768, 12.707518821091755, 13.636626444162804, 13.691710395110686, 12.787018417884422, 11.828521646381878, 12.780219528230687, 13.712321208043893, 14.656747804741212, 14.473389723980073, 13.540834802413, 13.616323529469122, 12.738301640876085, 11.821337508891176, 10.811460005925268, 9.83990353094266, 9.066382390590936, 9.958144571740176, 10.888638763729071, 11.795799072666073, 12.623135788001425, 13.57973684136094, 13.612454030550428, 12.658549424397844, 11.783332710769926, 10.755163178266772, 11.726160343174913, 12.65574694327555, 13.594702267627573, 14.645756482784755, 14.477921032287545, 14.585742670105997, 13.639666751273124, 12.645966068113687, 11.717928476935661, 10.770664159441692, 10.108713500066022, 11.024673463750162, 11.892686785736661, 12.815162885309396, 13.661350288051505, 13.513699755116802, 12.63330999869483, 11.694663163162101, 10.755264558104368, 9.829289373182446, 10.792501611225395, 11.72021919392096, 12.788068778692448, 13.756273693768517, 14.628539361666583, 14.61975288158988, 14.626429317537523, 13.673410570222075, 12.69228549372288, 11.734396611129004, 11.052351964360021, 12.007880627891272, 12.869366392804674, 13.883968684784508, 13.522316297212976, 12.54510875830417, 11.707112836699451, 10.768152601620583, 9.821544061290052, 8.834557469057124, 9.830383906760988, 10.719522239167864, 11.793780867517384, 12.719376949964328, 13.647850836483554, 13.573530904798973, 14.57513844230319, 14.655376415518694, 13.66880729733629, 12.668139258421416, 12.116115945268888, 13.056299827234271, 13.921175445246524, 13.457869018609594, 12.571183959514844, 11.569718957244886, 10.668589127451222, 9.814930802892883, 8.943035802208794, 7.877324239766987, 8.828132786462092, 9.75547264593985, 10.767094722066902, 11.653093950247953, 12.631146103811195, 12.70076377071624, 13.628716882661882, 14.646609757136826, 14.646441271774842, 13.707708921669504, 13.072149620816832, 14.004812755347904, 13.538205782318117, 12.507105012979592, 11.581983682727586, 10.618369398947358, 9.613620088701937, 8.745246766743222, 7.951606667340023, 6.91666280796025, 7.865855073344899, 8.816673886201453, 9.743487714714796, 10.717741027139823, 11.745158392323324, 11.755269592022767, 12.675589488108715, 13.728974482585448, 14.667675396376326, 14.725130549510416, 14.131163540392198, 13.548136524157265, 12.568463157716169, 11.599446441672884, 10.579635794925128, 9.611609156696842, 8.686082826557213, 7.699005495032704, 6.955948334693256, 5.885517320935001, 6.841944549783422, 7.794543824366726, 8.783244207661404, 9.825925356750671, 10.795494711998238, 10.75592712890781, 11.735321918534865, 12.710346082959392, 13.678465582718244, 14.54652682900994, 13.531864710437967, 12.583212986838287, 11.645538590739957, 10.773977076938527, 9.78129853340575, 8.753844407238878, 7.78942252307025, 6.762819769077081, 5.936228274447688, 4.949574440041435, 5.834306077575908, 6.818013584514576, 7.806700961599155, 8.84724558034189, 9.793815020875844, 9.783045178006573, 10.724570558852133, 11.70739175948932, 12.70358658872825, 13.628948084713283, 12.652556160739751, 11.689633027875717, 10.665138068585515, 9.709848177486903, 8.741170354693478, 7.782525355622321, 6.761453903983556, 5.73872636580252, 4.912207790848553, 3.985408343196298, 4.9083981244635195, 5.861908856666551, 6.867009892182921, 7.810915671472046, 8.83602596513387, 8.76173194878148, 9.752381113187653, 10.712740593056973, 11.775750475476762, 12.74928172586364, 11.848478480734084, 10.826578344000206, 9.827160448433013, 8.883265317918015, 7.819684976627647, 6.779109499071634, 5.832248758931188, 4.801428513271992, 3.9029169491725746, 3.033969449256272, 3.881061919124578, 4.860686232161745, 5.819642864395264, 6.841659675522735, 7.828108673683914, 7.761397278728387, 8.707218107825833, 9.754844225179838, 10.813672292015244, 11.74553428392827, 10.773674843170323, 9.886724687258477, 8.863813832456335, 7.891369981572616, 6.893673086997929, 5.825544863784956, 4.8034120497401025, 3.8428875763981685, 2.9588988184662046, 2.019166674449185, 2.9081255566767332, 3.8616041225892874, 4.89149799827438, 5.870579185104641, 6.84580259936153, 6.795290630459108, 7.85594388068637, 8.883827846218743, 9.830848370844212, 10.795695656656024, 9.800460503561041, 8.856172305230672, 7.834355522454015, 6.829323782455282, 5.898902350233351, 4.851952752787685, 3.8892200124187437, 2.9114058132686154, 1.9507485787245804, 0.9796242052075159, 1.955259854013614, 2.9064222150540635, 3.9621253261170564, 4.943333877343775, 5.845293321904433, 5.884860615759782, 6.942974086536345, 7.966362289165483, 8.948980776652894, 9.974009795067404, 9.143444651530883, 8.125536422126027, 7.053745455027992, 6.002639728368741, 4.9950748354410734, 3.923478576797131, 2.930082353620987, 1.985072230568405, 1.0058294480348209, 0.0, 1.0194159640499187, 2.0386429480239485, 2.9794952774673433, 3.924062193801702, 4.890060398176581, 6.875745818946044, 7.88743080468122, 8.848082769347135, 9.89509074086718, 10.843385922971198, 9.978114446173537, 8.988331093697935, 7.9684319575578755, 7.0266765520723755, 5.981271063897168, 4.909703914031893, 3.8849579614213496, 2.9106649386315464, 1.9812461021598011, 0.9422951938531348, 1.987958320903529, 2.977223659989768, 3.9914821610784026, 4.990486791319041, 5.816898838898424], [5.759661687066474, 4.941038183634424, 3.965543534909861, 3.0173596667288427, 2.001104903850451, 2.956218714897311, 3.9835625285152885, 4.972727975699338, 5.912385112898439, 6.936811390644044, 7.9901240668250475, 8.980541421176305, 9.940031979343594, 10.935793649147659, 11.752874306593274, 10.764396686472377, 9.807011207498785, 8.78263861027051, 7.796576915376622, 6.769839319026515, 6.778567464713051, 5.975555475872829, 4.956056413213865, 4.05916106770839, 3.03113433302961, 3.935420633214566, 4.933689232135477, 5.925685045929123, 6.967930919291528, 7.973618987831871, 8.92701467626175, 9.887056749966902, 10.945866689693922, 11.898257239475031, 12.680002302163928, 11.746288195701519, 10.73245888498809, 9.81296344673479, 8.844666911209151, 7.824347808973377, 7.8217084842955, 6.880553344472609, 5.923793752644018, 4.957628032480365, 3.958787599673034, 4.9716012440164485, 5.936419331470997, 6.958307840897941, 7.9739708296803204, 8.981225550211315, 9.947860369726195, 10.878653358515365, 11.930923588086607, 12.926898422524301, 13.628294881756757, 12.728780724984011, 11.805393151507873, 10.785268031780742, 9.770065062292318, 8.862380319228643, 8.829057348614109, 7.891643283593812, 6.907637673954097, 6.0221823995860895, 5.020624866075917, 5.954930390707824, 6.903411168160396, 7.894519702562618, 8.880070052720898, 9.856795443555363, 10.857246489252269, 11.867018224336013, 12.830921505432139, 13.793469945787889, 14.64820083769835, 13.613115106045143, 12.68459647960501, 11.749478403798301, 10.755899250636762, 9.851687062560263, 9.754633000037723, 8.830657205571462, 7.963619313499032, 7.012389234092354, 6.002886787836258, 7.0108890838718265, 7.957381239220149, 8.898084638502024, 9.87219616284527, 10.816440635959239, 11.766080605347407, 12.806387924748563, 13.819257301589813, 14.765623146123081, 14.546739064530431, 14.032992152856393, 13.64903501650377, 12.720171666726568, 11.701762032499682, 10.808375819629697, 10.762735093433745, 9.85885731091397, 8.909619414478945, 7.984279085490491, 6.945449624456635, 7.973029411631922, 8.910204865422985, 9.860391505636487, 10.804149520480456, 11.73168333211017, 12.677830223765644, 13.630231625023288, 14.62075059656145, 14.59868781943808, 13.62087744951295, 13.064105684087982, 13.799405430681338, 13.702440630696987, 12.649444059957244, 11.713078152694422, 11.706765836228794, 10.857692646999944, 9.983439495391547, 8.985114427756793, 7.916221362107526, 8.94334285371104, 9.884964414906397, 10.89903226843727, 11.824654796422116, 12.673437240032133, 13.69929430973312, 14.628401932804168, 14.53158627481272, 13.626894297586455, 12.668397526083911, 11.996891877369215, 12.83715178604628, 13.7815783827436, 13.575063404024336, 12.642508482457263, 12.717997209513385, 11.839975320920345, 10.923011188935439, 9.91313368596953, 8.941577210986923, 9.969493680648037, 10.861255861797277, 11.880414252370436, 12.787574561307437, 13.61491127664279, 14.571512330002305, 14.452329910252459, 13.498425304099877, 12.62320859047196, 11.595039057968805, 10.942832692313441, 11.780577521277937, 12.71953284562996, 13.74489878990583, 13.579594712331808, 13.68741635015026, 12.741340431317386, 11.74763974815795, 10.819602156979924, 9.872337839485954, 10.87688237198077, 11.813163469211409, 12.840421658596124, 13.80499229461563, 14.653125776692871, 14.440753171951158, 13.473185878396865, 12.534539042864134, 11.595140437806402, 10.66916525288448, 9.9144112703282, 10.722427846720288, 11.788279041184769, 12.75648395626084, 13.628749624158907, 13.619963144082204, 13.728102997581786, 12.775084250266335, 11.793959173767142, 10.836070291173266, 11.820520836274769, 12.793664767498875, 13.735799561103292, 14.779277449110506, 14.449369714047332, 13.472162175138527, 12.546988716401485, 11.608028481322616, 10.661419940992085, 9.674433348759157, 8.952293565863792, 9.719732501660186, 10.793991130009704, 11.719587212456652, 12.648061098975878, 12.573741167291297, 13.572158666622457, 13.757050095562954, 12.77048097738055, 11.769812938465678, 12.743440808101802, 13.81190083981752, 14.787608613545142, 14.40935057871411, 13.52266551961936, 12.521200517349403, 11.620070687555739, 10.7664123629974, 9.782911681910825, 8.71720011946902, 7.889583920722625, 8.755682908432172, 9.767304984559225, 10.653304212740277, 11.63135636630352, 11.700974033208562, 12.625737106981148, 13.643629981456092, 13.748114951819103, 12.809382601713764, 13.699474483649746, 14.632137618180819, 14.489687342422632, 13.458586573084107, 12.5334652428321, 11.569850959051875, 10.565101648806454, 9.696728326847738, 8.791482547042055, 7.756538687662282, 6.913235640820469, 7.8168841486937755, 8.743697977207118, 9.717951289632145, 10.745368654815646, 10.735853627972848, 11.656173524058795, 12.709558518535529, 13.648259432326407, 13.826804229554677, 14.758488403225112, 14.499618084261781, 13.519944717820684, 12.550928001777399, 11.531117355029643, 10.563090716801359, 9.63756438666173, 8.650487055137221, 7.795824214395287, 6.725393200637033, 5.842154812275743, 6.794754086859047, 7.783454470153726, 8.826135619242994, 9.79570497449056, 9.736511164857891, 10.715905954484946, 11.690930118909472, 12.659049618668325, 13.58035813473851, 14.483346270542484, 13.534694546942804, 12.597020150844473, 11.725458637043044, 10.732780093510266, 9.705325967343395, 8.740904083174767, 7.714301329181597, 6.776104154149722, 5.789450319743468, 4.834516340068229, 5.818223847006897, 6.806911224091476, 7.8474558428342105, 8.794025283368166, 8.763629213956653, 9.705154594802213, 10.687975795439401, 11.68417062467833, 12.609532120663363, 13.604037720844268, 12.641114587980233, 11.616619628690032, 10.66132973759142, 9.692651914797995, 8.734006915726837, 7.712935464088073, 6.690207925907036, 5.7520836705505864, 4.825284222898331, 3.9086083869558403, 4.862119119158872, 5.867220154675241, 6.811125933964366, 7.816610001083952, 7.74231598473156, 8.732965149137733, 9.693324629007053, 10.756334511426843, 11.72986576181372, 12.795771411413714, 11.780765254150278, 10.781347358583085, 9.834746878022532, 8.771166536732164, 7.730591059176151, 6.783730319035705, 5.752910073376508, 4.814706221617045, 3.8738453289583044, 2.881272181616899, 3.8608964946540665, 4.819853126887585, 5.822243711472816, 6.808692709633996, 6.741981314678467, 7.687802143775913, 8.735428261129918, 9.794256327965325, 10.726118319878351, 11.744918882486882, 10.84091159740855, 9.818000742606408, 8.845556891722689, 7.845154647102445, 6.777026423889473, 5.754893609844619, 4.794369136502685, 3.870688090910675, 2.8706541503064678, 1.908335819169054, 2.8618143850816082, 3.891708260766701, 4.851163221054723, 5.8263866353116125, 5.775874666409188, 6.8365279166364505, 7.864411882168824, 8.811432406794292, 9.85526470031518, 10.81987646761096, 9.875588269280591, 8.853771486503934, 7.848739746505202, 6.918318314283271, 5.871368716837605, 4.908635976468663, 3.862887373373132, 2.9022301388290974, 1.931105765312033, 0.9554701165059348, 1.9066324775463843, 2.9623355886093776, 3.923917913293857, 4.825877357854513, 4.865444651709862, 5.923558122486425, 6.946946325115563, 7.929564812602975, 8.954593831017487, 9.929078558727284, 9.144952386175946, 8.073161419077913, 7.02205569241866, 6.014490799490993, 4.94289454084705, 3.9494983176709053, 3.0044881946183235, 2.0252454120847396, 1.0194159640499187, 0.0, 1.0192269839740296, 1.9600793134174244, 2.904646229751783, 3.8706444341266617, 5.856329854896125, 6.868014840631302, 7.8286668052972175, 8.875674776817263, 9.82396995892128, 10.871394459989459, 10.007747057747853, 8.987847921607793, 8.046092516122293, 7.000687027947086, 5.929119878081812, 4.904373925471268, 3.930080902681465, 3.0006620662097196, 1.9617111579030535, 0.9685423568536102, 1.9578076959398494, 2.972066197028484, 3.9710708272691226, 4.797482874848505], [4.740434703092444, 3.921811199660394, 2.9463165509358316, 2.1341709671223095, 3.020331887824481, 3.975445698871341, 5.0027895124893185, 5.991954959673368, 6.931612096872469, 7.956038374618074, 9.009351050799077, 9.999768405150334, 10.959258963317625, 11.740443232942196, 10.733647322619243, 9.745169702498346, 8.787784223524755, 7.763411626296479, 6.777349931402592, 5.750612335052485, 5.75934048073902, 4.956328491898798, 3.936829429239835, 3.175972368101856, 4.05036131700364, 4.954647617188596, 5.952916216109507, 6.944912029903153, 7.987157903265558, 8.9928459718059, 9.94624166023578, 10.906283733940931, 11.965093673667951, 12.613481581638464, 11.660775318189897, 10.727061211727488, 9.713231901014058, 8.793736462760759, 7.825439927235121, 6.805120824999346, 6.8030631337727465, 5.87296348239909, 4.9162038905704994, 4.165759446446348, 4.978014583647064, 5.9908282279904785, 6.955646315445027, 7.977534824871971, 8.99319781365435, 10.000452534185344, 10.967087353700224, 11.897880342489394, 12.950150572060636, 13.583366671044487, 12.609067897782726, 11.70955374100998, 10.786166167533842, 9.766041047806711, 8.750838078318287, 7.843153335254613, 7.821411178770032, 6.884053421520293, 5.900047811880579, 5.230313813552073, 6.039851850049947, 6.974157374681854, 7.922638152134426, 8.913746686536648, 9.899297036694929, 10.876022427529392, 11.876473473226298, 12.886245208310042, 13.850148489406168, 14.571102970261244, 13.62897385372432, 12.593888122071112, 11.66536949563098, 10.73025141982427, 9.736672266662731, 8.844040892716185, 8.746986830193645, 7.823067343497943, 6.956029451425513, 6.294832249249646, 7.022113771810288, 8.030116067845857, 8.97660822319418, 9.917311622476054, 10.891423146819301, 11.83566761993327, 12.785307589321437, 13.825614908722592, 14.838484285563842, 15.543256170596436, 14.607803099953902, 13.591517454737478, 12.629808032529741, 11.700944682752539, 10.68253504852565, 9.80072964978562, 9.755088923589668, 8.851267448840453, 7.902029552405427, 7.349878987240716, 7.964676608430665, 8.992256395605953, 9.929431849397016, 10.879618489610518, 11.823376504454487, 12.750910316084202, 13.697057207739675, 14.64945860899732, 15.639977580535481, 15.616401929408779, 14.638591559483649, 13.980728848524947, 13.053395847639957, 12.683213646722956, 11.630217075983213, 10.705431982850344, 10.699119666384716, 9.850102784926426, 8.97584963331803, 8.377296648256213, 8.935448346081555, 9.962569837685072, 10.904191398880428, 11.918259252411302, 12.843881780396147, 13.692664224006164, 14.71852129370715, 15.6476289167782, 15.549300384783418, 14.644608407557154, 13.68611163605461, 12.957704665426137, 12.091142203004898, 13.035568799702219, 12.567417234180258, 11.634862312613185, 11.710351039669307, 10.832385458846828, 9.958160710469466, 9.408373593837695, 9.960804194960952, 10.988720664622068, 11.880482845771308, 12.899641236344467, 13.806801545281468, 14.63413826061682, 15.590739313976336, 15.47004402022316, 14.516139414070576, 13.640922700442658, 12.612753167939504, 11.903645480370363, 11.034567938236556, 11.973523262588579, 12.88124442699234, 12.57194854248773, 12.679770180306182, 11.852982253294726, 10.99531039071328, 10.462014697961477, 10.891564823459984, 11.896109355954799, 12.832390453185438, 13.859648642570153, 14.82421927858966, 15.6723527606669, 15.458467281921857, 14.490899988367563, 13.552253152834833, 12.6128545477771, 11.686879362855178, 10.875224058385122, 9.976418263678905, 11.042269458143387, 11.89282959334735, 12.765095261245417, 12.71256343800468, 12.839744819559126, 12.028285356698575, 11.457609800034502, 11.855297275147295, 12.839747820248798, 13.812891751472904, 14.755026545077321, 15.798504433084535, 15.467083824018031, 14.489876285109226, 13.564702826372184, 12.625742591293315, 11.679134050962784, 10.692147458729856, 9.913106353920714, 8.973722918618803, 10.047981546968323, 10.855932849543162, 11.784406736062389, 11.666341461213774, 12.552931682648428, 13.010251201995194, 12.485354654755776, 12.789039922439708, 13.762667792075831, 14.83112782379155, 15.806835597519171, 15.42706468868481, 14.540379629590062, 13.538914627320104, 12.63778479752644, 11.7841264729681, 10.800625791881526, 9.734914229439719, 8.907298030693326, 8.00967332539079, 9.021295401517841, 9.789649849826787, 10.76770200339003, 10.710283624567168, 11.60651012300712, 12.624402997482063, 13.462988629194328, 13.828609585687794, 14.718701467623776, 15.651364602154848, 15.507401452393333, 14.476300683054808, 13.551179352802802, 12.587565069022576, 11.582815758777155, 10.71444243681844, 9.809196657012754, 8.77425279763298, 7.930949750791169, 7.070874565652392, 7.997688394165735, 8.854296926718655, 9.84041319083807, 9.716626643998818, 10.636946540084766, 11.6903315345615, 12.629032448352376, 13.51395071285483, 14.521835141479269, 15.489368530255108, 14.537658827791384, 13.5686421117481, 12.548831465000344, 11.58080482677206, 10.65527849663243, 9.668201165107922, 8.813538324365986, 7.743107310607732, 6.859868922246443, 6.048744503817664, 6.995988421271887, 7.8679645165969765, 8.837533871844542, 8.717284180883862, 9.696678970510916, 10.671703134935441, 11.639822634694294, 12.561131150764478, 13.575793269336451, 14.52444499293613, 13.614734260815174, 12.743172747013745, 11.750494203480967, 10.723040077314096, 9.758618193145468, 8.732015439152299, 7.793818264120421, 6.807164429714167, 5.852230450038929, 4.994488554360212, 5.945091619019686, 6.889284740188193, 7.835854180722148, 7.744402229982623, 8.685927610828184, 9.66874881146537, 10.6649436407043, 11.59030513668933, 12.586351394613096, 13.549274527477131, 12.634333738660732, 11.67904384756212, 10.710366024768696, 9.751721025697538, 8.730649574058774, 7.707922035877737, 6.7697977805212854, 5.84299833286903, 4.926322496926541, 3.9777253178908474, 4.9828263534072175, 5.822116401362908, 6.797383017109922, 6.723089000757531, 7.713738165163704, 8.674097645033022, 9.73710752745281, 10.71063877783969, 11.776544427439685, 12.66493951580781, 11.799061468553786, 10.852460987993233, 9.788880646702864, 8.748305169146851, 7.801444429006406, 6.770624183347209, 5.832420331587745, 4.891559438929004, 3.8989862915875992, 2.976502693386042, 3.935459325619561, 4.803016727498786, 5.789465725659966, 5.722754330704438, 6.668575159801884, 7.716201277155888, 8.775029343991296, 9.706891335904322, 10.725691898512853, 11.660228779626724, 10.835714852577109, 9.86327100169339, 8.862868757073146, 7.794740533860174, 6.77260771981532, 5.812083246473386, 4.888402200881375, 3.888368260277168, 2.9260499291397544, 1.97720377297141, 3.0070976486565026, 3.831936237080693, 4.8071596513375825, 4.756647682435159, 5.817300932662421, 6.845184898194795, 7.792205422820264, 8.836037716341151, 9.831272869436134, 10.775561067766503, 9.872998470477963, 8.867966730479232, 7.937545298257301, 6.890595700811635, 5.927862960442693, 4.880601483343833, 3.919944248799798, 2.9488198752827337, 1.9731842264766355, 1.0220218654361861, 2.0107319816412637, 2.9046909293198273, 3.806650373880484, 3.8462176677358326, 4.904331138512396, 5.927719341141534, 6.910337828628946, 7.935366847043458, 8.909851574753255, 9.92775980415811, 9.092388403051942, 8.04128267639269, 7.033717783465024, 5.962121524821081, 4.968725301644936, 4.0237151785923535, 3.0444723960587696, 2.0386429480239485, 1.0192269839740296, 0.0, 0.9408523294433948, 1.8854192457777534, 2.851417450152632, 4.837102870922095, 5.848787856657271, 6.809439821323187, 7.856447792843232, 8.80474297494725, 9.85216747601543, 10.841950828491031, 10.007074905581824, 9.065319500096324, 8.019914011921117, 6.948346862055842, 5.923600909445298, 4.949307886655495, 4.01988905018375, 2.9809381418770835, 1.9877693408276398, 1.0746189963333161, 1.9528392130544543, 2.951843843295093, 3.778255890874475], [3.7995823736490495, 2.980958870216999, 2.0054642214924367, 2.996339362965018, 3.961184217267876, 4.916298028314736, 5.943641841932713, 6.932807289116763, 7.872464426315863, 8.896890704061468, 9.95020338024247, 10.940620734593727, 11.80798333643461, 10.799590903498801, 9.792794993175848, 8.804317373054952, 7.84693189408136, 6.822559296853084, 5.836497601959197, 4.80976000560909, 4.818488151295625, 4.015476162455403, 2.9959770997964403, 3.944514321000131, 4.991213646447035, 5.895499946631991, 6.893768545552902, 7.885764359346548, 8.928010232708953, 9.933698301249294, 10.887093989679173, 11.847136063384323, 12.689056424612339, 11.672629252195069, 10.719922988746502, 9.786208882284093, 8.772379571570664, 7.852884133317365, 6.884587597791726, 5.864268495555951, 5.862210804329352, 4.932111152955695, 3.9753515611271046, 4.934301399344624, 5.918866913090459, 6.931680557433873, 7.896498644888422, 8.918387154315367, 9.934050143097746, 10.94130486362874, 11.907939683143617, 12.838732671932787, 13.638489176038787, 12.642514341601093, 11.668215568339331, 10.768701411566585, 9.845313838090448, 8.825188718363318, 7.809985748874893, 6.902301005811218, 6.880558849326637, 5.943201092076898, 4.959195482437184, 5.887804501941834, 6.927064013491209, 7.915009704125249, 8.863490481577822, 9.854599015980044, 10.840149366138325, 11.81687475697279, 12.817325802669696, 13.827097537753435, 14.592799081173599, 13.630250640817849, 12.688121524280925, 11.653035792627719, 10.724517166187587, 9.789399090380877, 8.795819937219338, 7.90318856327279, 7.806134500750251, 6.882215014054548, 6.015177121982118, 6.9523229376394085, 7.909325935251549, 8.970968397289251, 9.917460552637575, 10.85816395191945, 11.832275476262698, 12.776519949376667, 13.726159918764834, 14.766467238165985, 15.581134877331273, 14.602403841153041, 13.666950770510507, 12.650665125294083, 11.688955703086346, 10.760092353309144, 9.741682719082258, 8.859877320342227, 8.814236594146275, 7.910415119397057, 6.961177222962032, 7.886564140605872, 8.851888771871927, 9.879468559047215, 10.816644012838278, 11.7851737740351, 12.764228833897883, 13.691762645527598, 14.637909537183072, 15.590310938440716, 16.499581703788245, 15.570622755453119, 14.592812385527989, 13.619551594062493, 12.709196075978491, 11.742361317279563, 10.68936474653982, 9.764579653406951, 9.758267336941323, 8.90925045548303, 8.034997303874635, 8.913981801621368, 9.822660509522818, 10.849782001126334, 11.79140356232169, 12.823814536835883, 13.784734109839544, 14.63351655344956, 15.659373623150547, 16.588481246221598, 16.490152714226813, 15.585460737000549, 14.626963965498005, 13.898556994869532, 13.031994532448293, 12.37138156572577, 11.626564904736865, 10.694009983169792, 10.769498710225914, 9.891533129403431, 9.017308381026071, 9.94505874720285, 10.848016358402214, 11.87593282806333, 12.76769500921257, 13.805196520769048, 14.747653874724865, 15.574990590060217, 16.53159164341973, 16.410896349666555, 15.45699174351397, 14.581775029886053, 13.553605497382899, 12.844497809813758, 11.97542026767995, 11.309336028612131, 11.940392097548946, 11.631096213044337, 11.738917850862789, 10.912129923851328, 10.054458061269886, 10.982495652447911, 11.778776986901246, 12.783321519396061, 13.7196026166267, 14.746860806011416, 15.711431442030921, 16.6132050901103, 16.399319611365254, 15.431752317810957, 14.493105482278228, 13.553706877220495, 12.627731692298573, 11.816076387828517, 10.9172705931223, 10.237970717613099, 10.951977263903956, 11.82424293180202, 11.771711108561286, 11.898892490115728, 11.08743302725518, 11.978090754520936, 12.742509438588558, 13.72695998369006, 14.700103914914166, 15.642238708518583, 16.685716596525797, 16.407936153461424, 15.43072861455262, 14.505555155815578, 13.56659492073671, 12.619986380406178, 11.632999788173251, 10.853958683364109, 9.914575248062198, 9.243682806438034, 9.915080520099767, 10.843554406618992, 10.725489131770379, 11.612079353205033, 12.0693988725518, 13.00583560924221, 13.67625208588097, 14.649879955517093, 15.718339987232811, 16.694047760960434, 16.367917018128207, 15.481231959033455, 14.479766956763497, 13.578637126969832, 12.724978802411494, 11.74147812132492, 10.675766558883113, 9.84815036013672, 8.950525654834184, 8.212973184654473, 8.84879752038339, 9.826849673946633, 9.769431295123773, 10.665657793563724, 11.683550668038668, 12.721487012387158, 13.590520011252348, 14.63999673161124, 15.495778167634132, 16.441223955406038, 15.417153012498202, 14.492031682246196, 13.528417398465969, 12.523668088220548, 11.655294766261832, 10.750048986456148, 9.715105127076376, 8.871802080234565, 8.011726895095787, 7.180321787737663, 7.91344459727526, 8.899560861394678, 8.775774314555424, 9.696094210641371, 10.749479205118105, 11.688180118908981, 12.573098383411436, 13.580982812035874, 14.548516200811713, 15.475013222117804, 14.509494441191494, 13.489683794443739, 12.521657156215452, 11.596130826075823, 10.609053494551315, 9.75439065380938, 8.683959640051127, 7.800721251689838, 6.989596833261059, 6.174719052507561, 6.927112187153582, 7.896681542401148, 7.776431851440467, 8.755826641067522, 9.730850805492047, 10.6989703052509, 11.620278821321083, 12.634940939893056, 13.583592663492736, 14.521267059591066, 13.68402507645714, 12.691346532924362, 11.66389240675749, 10.699470522588863, 9.672867768595692, 8.734670593563816, 7.7480167591575615, 6.793082779482324, 5.935340883803607, 5.123822250255359, 5.948432410744799, 6.895001851278753, 6.803549900539228, 7.745075281384789, 8.727896482021976, 9.724091311260905, 10.649452807245936, 11.645499065169702, 12.608422198033736, 13.575186068104127, 12.619896177005515, 11.65121835421209, 10.692573355140933, 9.671501903502168, 8.648774365321131, 7.71065010996468, 6.783850662312425, 5.8671748263699355, 4.918577647334242, 4.161556984642891, 4.881264071919513, 5.8565306876665275, 5.782236671314136, 6.7728858357203094, 7.7332453155896275, 8.796255198009415, 9.769786448396294, 10.835692097996288, 11.724087186364414, 12.705633920962146, 11.793313317436628, 10.72973297614626, 9.689157498590246, 8.7422967584498, 7.711476512790604, 6.77327266103114, 5.832411768372399, 4.839838621030994, 3.9173550228294363, 3.1141899568552347, 3.8621643980553912, 4.848613396216571, 4.781902001261043, 5.7277228303584895, 6.7753489477124935, 7.8341770145479, 8.766039006460925, 9.784839569069456, 10.719376450183328, 11.742287304985469, 10.804123331136783, 9.80372108651654, 8.735592863303568, 7.713460049258715, 6.752935575916781, 5.82925453032477, 4.8292205897205625, 3.866902258583149, 2.9180561024148046, 2.0950141915247786, 2.8910839076372983, 3.8663073218941877, 3.8157953529917643, 4.876448603219027, 5.9043325687514, 6.851353093376869, 7.895185386897756, 8.89042053999274, 9.834708738323108, 10.813850799921356, 9.808819059922625, 8.878397627700695, 7.83144803025503, 6.8687152898860875, 5.821453812787228, 4.860796578243193, 3.8896722047261285, 2.9140365559200303, 1.962874194879581, 1.0698796521978688, 1.9638385998764325, 2.8657980444370894, 2.9053653382924383, 3.9634788090690014, 4.9868670116981395, 5.969485499185551, 6.994514517600063, 7.96899924530986, 8.986907474714716, 10.033240732495337, 8.982135005836085, 7.9745701129084186, 6.902973854264475, 5.909577631088331, 4.964567508035748, 3.9853247255021644, 2.9794952774673433, 1.9600793134174244, 0.9408523294433948, 0.0, 0.9445669163343587, 1.9105651207092376, 3.8962505414787003, 4.907935527213876, 5.868587491879792, 6.915595463399837, 7.863890645503854, 8.911315146572035, 9.901098499047636, 10.920997635187696, 10.006171829539719, 8.960766341364511, 7.8891991914992365, 6.864453238888693, 5.89016021609889, 4.9607413796271445, 3.9217904713204783, 2.928621670271035, 2.015471325776711, 1.0119868836110595, 2.0109915138516983, 2.8374035614310804], [2.855015457314691, 2.0363919538826405, 2.9500311378267954, 3.9409062792993765, 4.905751133602235, 5.860864944649094, 6.888208758267072, 7.8773742054511215, 8.817031342650221, 9.841457620395826, 10.894770296576828, 11.885187650928085, 10.86341642010025, 9.855023987164442, 8.848228076841488, 7.859750456720593, 6.902364977747002, 5.877992380518727, 4.891930685624838, 3.8651930892747313, 3.873921234961267, 3.0916962998726643, 3.940544016130799, 4.88908123733449, 5.935780562781393, 6.840066862966349, 7.838335461887261, 8.830331275680907, 9.87257714904331, 10.878265217583653, 11.831660906013532, 12.791702979718682, 11.74448950827798, 10.72806233586071, 9.775356072412142, 8.841641965949735, 7.827812655236306, 6.908317216983007, 5.9400206814573675, 4.919701579221593, 4.917643887994993, 4.1255477531105536, 4.919918477461463, 5.878868315678982, 6.863433829424817, 7.876247473768232, 8.84106556122278, 9.862954070649725, 10.878617059432104, 11.885871779963098, 12.852506599477977, 13.74619248927567, 12.693922259704427, 11.697947425266733, 10.723648652004972, 9.824134495232228, 8.90074692175609, 7.8806218020289585, 6.865418832540534, 5.95773408947686, 5.935991932992279, 5.136637692231757, 5.903762398771542, 6.8323714182761925, 7.871630929825567, 8.859576620459608, 9.80805739791218, 10.799165932314402, 11.784716282472683, 12.761441673307147, 13.761892719004052, 14.612135445935365, 13.64823216483924, 12.68568372448349, 11.743554607946566, 10.70846887629336, 9.779950249853227, 8.844832174046518, 7.851253020884979, 6.958621646938432, 6.8615675844158925, 6.075651614209407, 6.959744038316477, 7.896889853973766, 8.853892851585908, 9.91553531362361, 10.862027468971933, 11.802730868253807, 12.776842392597056, 13.721086865711024, 14.670726835099192, 15.551505146347916, 14.636567960996913, 13.657836924818682, 12.722383854176147, 11.706098208959723, 10.744388786751987, 9.815525436974784, 8.797115802747898, 7.915310404007867, 7.869669677811915, 7.116618728453828, 7.905744139296391, 8.831131056940231, 9.796455688206285, 10.82403547538157, 11.761210929172634, 12.729740690369455, 13.708795750232241, 14.636329561861956, 15.58247645351743, 16.512434770201498, 15.555014787453883, 14.62605583911876, 13.648245469193629, 12.674984677728133, 11.764629159644132, 10.797794400945204, 9.74479783020546, 8.820012737072592, 8.813700420606963, 8.1154540645398, 8.979564220208992, 9.858548717955728, 10.767227425857175, 11.79434891746069, 12.735970478656046, 13.768381453170239, 14.729301026173902, 15.578083469783918, 16.603940539484903, 17.533048162555954, 16.62071855840844, 15.630499346327927, 14.600725392622667, 13.7421984844469, 12.72688280427919, 11.690390281958898, 10.681997988402506, 9.749443066835433, 9.824931793891555, 9.097736738460203, 9.961875297360429, 10.88962566353721, 11.792583274736572, 12.820499744397686, 13.712261925546926, 14.749763437103404, 15.692220791059222, 16.519557506394577, 17.47615855975409, 17.355463266000914, 16.40155865984833, 15.526341946220413, 14.498172413717258, 13.658952481200364, 12.789874939066557, 11.965538295860679, 10.995825181214586, 10.686529296709978, 10.79435093452843, 10.1183335329081, 10.999024977604243, 11.927062568782269, 12.723343903235603, 13.727888435730419, 14.664169532961058, 15.691427722345773, 16.655998358365277, 17.557772006444658, 17.343886527699613, 16.376319234145317, 15.437672398612587, 14.498273793554855, 13.572298608632932, 12.630531059215123, 11.731725264508906, 10.894172984861646, 10.007410347569596, 10.87967601546766, 10.827144192226926, 11.1050960991725, 12.031999943589538, 12.922657670855294, 13.687076354922915, 14.671526900024418, 15.644670831248524, 16.58680562485294, 17.630283512860153, 17.352503069795784, 16.37529553088698, 15.450122072149938, 14.51116183707107, 13.564553296740538, 12.57756670450761, 11.668413354750715, 10.729029919448804, 9.899885073686582, 8.970513603765408, 9.898987490284632, 9.78092221543602, 10.667512436870673, 11.6116321029536, 12.68099776414483, 13.681665803059705, 14.651463490824824, 15.513048818230281, 16.486364739015144, 17.312483934462566, 16.425798875367814, 15.424333873097856, 14.523204043304192, 13.669545718745853, 12.68604503765928, 11.620333475217473, 10.749293726943312, 9.76498032622079, 8.86917545190302, 7.904230604049032, 8.882282757612273, 8.824864378789414, 9.721090877229365, 10.738983751704309, 11.776920096052798, 12.645953094917989, 13.69542981527688, 14.551211251299772, 15.496657039071678, 16.361719928832564, 15.436598598580556, 14.472984314800328, 13.468235004554908, 12.599861682596192, 11.694615902790508, 10.659672043410735, 9.816368996568924, 8.826181566482393, 7.899367737969051, 6.968877680940901, 7.954993945060319, 7.831207398221065, 8.751527294307012, 9.804912288783745, 10.743613202574622, 11.628531467077076, 12.636415895701514, 13.603949284477354, 14.530446305783444, 15.454061357525854, 14.434250710778098, 13.466224072549812, 12.540697742410183, 11.553620410885674, 10.69895757014374, 9.628526556385486, 8.745288168024198, 7.882465386033627, 6.893765002738949, 5.982545270819223, 6.952114626066789, 6.8318649351061085, 7.811259724733162, 8.786283889157687, 9.75440338891654, 10.675711904986724, 11.690374023558697, 12.639025747158376, 13.576700143256707, 14.6285919927915, 13.635913449258723, 12.608459323091852, 11.644037438923222, 10.617434684930052, 9.679237509898176, 8.692583675491921, 7.737649695816684, 6.831555577571327, 5.842868200486747, 5.00386549441044, 5.950434934944395, 5.85898298420487, 6.80050836505043, 7.783329565687616, 8.779524394926545, 9.704885890911576, 10.700932148835342, 11.663855281699377, 12.688350240989578, 13.564463093339876, 12.595785270546452, 11.637140271475294, 10.616068819836528, 9.59334128165549, 8.65521702629904, 7.728417578646784, 6.811741742704295, 5.863144563668601, 4.880602934874279, 3.936697155585154, 4.911963771332169, 4.837669754979778, 5.82831891938595, 6.788678399255268, 7.851688281675057, 8.825219532061935, 9.891125181661929, 10.779520270030055, 11.761067004627787, 12.737880233770989, 11.67429989248062, 10.633724414924608, 9.68686367478416, 8.656043429124963, 7.717839577365499, 6.776978684706759, 5.784405537365354, 4.861921939163795, 3.951008296503156, 2.9175974817210326, 3.9040464798822123, 3.8373350849266847, 4.78315591402413, 5.830782031378134, 6.889610098213541, 7.821472090126567, 8.840272652735097, 9.774809533848968, 10.79772038865111, 11.748690247471144, 10.7482880028509, 9.680159779637929, 8.658026965593075, 7.69750249225114, 6.773821446659129, 5.773787506054922, 4.811469174917509, 3.8626230187491637, 2.9318325311727, 1.9465169913029396, 2.921740405559829, 2.8712284366574057, 3.931881686884668, 4.959765652417041, 5.906786177042511, 6.950618470563398, 7.945853623658381, 8.89014182198875, 9.911958604765408, 10.753385976256984, 9.822964544035054, 8.776014946589388, 7.813282206220446, 6.766020729121587, 5.805363494577552, 4.834239121060487, 3.8586034722543894, 2.9074411112139398, 2.0144465685322275, 1.0192716835420739, 1.9212311281027308, 1.9607984219580794, 3.0189118927346428, 4.042300095363782, 5.0249185828511935, 6.049947601265705, 7.024432328975502, 8.042340558380358, 9.114131525478392, 9.926701922170444, 8.919137029242776, 7.847540770598834, 6.854144547422689, 5.909134424370107, 4.929891641836523, 3.924062193801702, 2.904646229751783, 1.8854192457777534, 0.9445669163343587, 0.0, 0.9659982043748788, 2.9516836251443417, 3.963368610879518, 4.924020575545434, 5.97102854706548, 6.919323729169497, 7.966748230237678, 8.956531582713279, 9.976430718853338, 10.918186124338838, 9.905333257698869, 8.833766107833595, 7.809020155223052, 6.834727132433248, 5.905308295961503, 4.866357387654837, 3.8731885866053934, 2.96003824211107, 1.9565537999454183, 1.0664245975173396, 1.8928366450967218], [1.8890172529398124, 2.8479925082127426, 3.827329521649955, 4.818204663122536, 5.846439302753584, 6.801553113800444, 7.8288969274184215, 8.843372409826, 9.7830295470251, 10.807455824770704, 11.860768500951707, 10.963481729836879, 9.897418215725372, 8.889025782789563, 7.88222987246661, 6.893752252345714, 5.936366773372123, 4.911994176143847, 3.9259324812499594, 2.8991948848998526, 2.907923030586389, 3.9032968542027664, 4.817842399953959, 5.7663796211576495, 6.826230014935483, 7.780755032117699, 8.77902363103861, 9.771019444832257, 10.822782070625667, 11.84426342195853, 12.797343317335272, 11.837301243630122, 10.7784913039031, 9.76206413148583, 8.809357868037264, 7.875643761574858, 6.861814450861427, 5.942319012608127, 4.974022477082489, 3.9537033748467145, 3.9516456836201153, 4.8928008234430065, 5.797216861284623, 6.756166699502142, 7.753883281578907, 8.766696925922322, 9.78175373037413, 10.803642239801073, 11.819305228583453, 12.826559949114447, 13.71098727368996, 12.78019428490079, 11.727924055329549, 10.731949220891854, 9.757650447630093, 8.858136290857349, 7.934748717381211, 6.91462359765408, 5.899420628165656, 4.991735885101981, 4.969993728617401, 5.90389076256421, 6.781060782594702, 7.709669802099352, 8.748929313648727, 9.750026072613698, 10.69850685006627, 11.689615384468492, 12.675165734626773, 13.651891125461237, 14.652342171158143, 13.646137241560487, 12.68223396046436, 11.71968552010861, 10.777556403571687, 9.74247067191848, 8.813952045478349, 7.878833969671639, 6.8852548165101, 5.992623442563554, 5.895569380041015, 6.8429046845418595, 7.837042422139636, 8.774188237796926, 9.731191235409067, 10.796999405324271, 11.752476921126023, 12.693180320407897, 13.667291844751146, 14.611536317865115, 15.561176287253282, 14.585506941973037, 13.670569756622035, 12.691838720443803, 11.756385649801269, 10.740100004584846, 9.77839058237711, 8.849527232599907, 7.8311175983730195, 6.949312199632989, 6.903671473437037, 7.883871798786281, 8.78304252311955, 9.708429440763389, 10.673754072029444, 11.70133385920473, 12.638509312995794, 13.607039074192615, 14.599245202386331, 15.526779014016046, 16.47292590567152, 15.54643656582662, 14.589016583079005, 13.66005763474388, 12.68224726481875, 11.708986473353256, 10.798630955269255, 9.831796196570325, 8.778799625830581, 7.854014532697713, 7.8477022162320855, 8.861874265187904, 9.823056741780022, 10.735847101778884, 11.644525809680335, 12.67164730128385, 13.613268862479206, 14.645679836993398, 15.619750478327992, 16.46853292193801, 17.494389991638993, 16.570322172773132, 15.654720354033563, 14.664501141953048, 13.634727188247789, 12.776200280072024, 11.760884599904314, 10.72439207758402, 9.715999784027627, 8.783444862460554, 8.858933589516678, 9.844156939108306, 10.805367818931458, 11.766924047360366, 12.669881658559731, 13.697798128220846, 14.589560309370086, 15.627061820926563, 16.58267024321331, 17.410006958548667, 18.36660801190818, 17.502251578738747, 16.687881324746407, 15.647367026026608, 14.597121304262767, 13.626124139354626, 12.696537539253988, 11.757582214901966, 10.706527999744784, 9.720531092335099, 9.828352730153552, 10.864753733556203, 11.842517499175273, 12.770555090353298, 13.600642287058763, 14.605186819553579, 15.541467916784217, 16.568726106168935, 17.53329674218844, 18.44822145859875, 18.305569914161968, 17.338002620607675, 16.399355785074945, 15.459957180017211, 14.500122873715657, 13.512445647256534, 12.613639852550317, 11.776087572903057, 10.889324935611008, 10.09198695297251, 9.89907739097014, 10.74864485317961, 11.665531146993432, 12.646656223492627, 13.604545106086503, 14.615424993600728, 15.588568924824834, 16.53070371842925, 17.415209783801316, 18.31418645625814, 17.336978917349334, 16.411805458612292, 15.472845223533426, 14.526236683202894, 13.539250090969967, 12.550327942792126, 11.610944507490215, 10.781799661727993, 9.852428191806819, 9.111298427789482, 8.852855414179233, 9.739445635613887, 10.683565301696813, 11.752930962888044, 12.7195245537912, 13.685465286449947, 14.547050613855404, 15.520366534640267, 16.486245986524217, 17.391797079742688, 16.39033207747273, 15.489202247679069, 14.63554392312073, 13.647728424121635, 12.58201686167983, 11.631208314984724, 10.646894914262202, 9.751090039944431, 8.786145192090444, 8.094593695117123, 7.896797577532627, 8.793024075972578, 9.810916950447522, 10.810921891677921, 11.679954890543112, 12.729431610902003, 13.585213046924896, 14.530658834696801, 15.558661958763516, 16.402596802955433, 15.438982519175205, 14.434233208929784, 13.565859886971069, 12.660614107165387, 11.625670247785614, 10.749450612545228, 9.708096154523805, 8.781282326010462, 7.850792268982312, 7.164306447323621, 6.903140596964278, 7.823460493050225, 8.860961153873856, 9.777614998199745, 10.6625332627022, 11.670417691326637, 12.637951080102477, 13.564448101408567, 14.533464817451852, 15.400248915152975, 14.432222276924689, 13.50669594678506, 12.519618615260551, 11.664955774518619, 10.594524760760365, 9.70481614475892, 8.76437997407504, 7.77567959078036, 6.864459858860634, 6.161427128330091, 5.903798133849321, 6.883192923476376, 7.820285684782809, 8.788405184541663, 9.709713700611847, 10.72437581918382, 11.6730275427835, 12.61070193888183, 13.662876368113242, 14.6019116536336, 13.574457527466729, 12.6100356432981, 11.583432889304929, 10.645235714273053, 9.6585818798668, 8.697177672551407, 7.713470165612738, 6.724782788528159, 5.885780082451851, 5.105850954362336, 4.930916182948082, 5.872441563793643, 6.817331361312738, 7.813526190551668, 8.7388876865367, 9.734933944460465, 10.6978570773245, 11.722352036614701, 12.677641927713314, 13.561783474921329, 12.603138475850171, 11.582067024211405, 10.559339486030368, 9.621215230673918, 8.694415783021663, 7.777739947079173, 6.777058249362346, 5.76251752291569, 4.818611743626565, 4.050742803784385, 3.871671550604899, 4.862320715011071, 5.82268019488039, 6.885690077300179, 7.859221327687057, 8.92512697728705, 9.813522065655178, 10.79506880025291, 11.798556770070416, 12.640298096855497, 11.599722619299484, 10.652861879159037, 9.62204163349984, 8.683837781740378, 7.742976889081636, 6.750403741740231, 5.791879516778086, 4.832922884544567, 3.799512069762444, 3.0428255123344288, 2.871336880551806, 3.8171577096492517, 4.864783827003256, 5.923611893838663, 6.855473885751689, 7.87427444836022, 8.808811329474091, 9.831722184276233, 10.804166035159952, 11.714286207225777, 10.646157984012806, 9.624025169967952, 8.663500696626018, 7.739819651034007, 6.7397857104298, 5.7774673792923865, 4.828621223124042, 3.8137471192141112, 2.828431579344351, 1.99401382760639, 1.9052302322825267, 2.965883482509789, 3.993767448042162, 4.940787972667631, 5.984620266188518, 6.979855419283501, 7.924143617613871, 8.945960400390529, 9.95099214038926, 10.788962748409933, 9.742013150964267, 8.779280410595325, 7.732018933496466, 6.771361698952431, 5.800237325435366, 4.824601676629268, 3.8734393155888185, 2.94977013369342, 1.901186271583485, 0.9552329237278518, 0.9948002175832006, 2.052913688359764, 3.0763018909889026, 4.058920378476314, 5.083949396890825, 6.0584341246006215, 7.076342354005477, 8.148133321103511, 9.199239047762763, 9.885135233617655, 8.813538974973712, 7.820142751797568, 6.875132628744986, 5.895889846211402, 4.890060398176581, 3.8706444341266617, 2.851417450152632, 1.9105651207092376, 0.9659982043748788, 0.0, 1.9856854207694628, 2.997370406504639, 3.9580223711705544, 5.0050303426906, 5.953325524794617, 7.000750025862797, 7.990533378338399, 9.010432514478458, 9.952187919963958, 10.871331462073748, 9.799764312208474, 8.77501835959793, 7.800725336808127, 6.871306500336382, 5.832355592029716, 4.839186790980272, 3.9260364464859485, 2.922552004320297, 1.9854579516736588, 0.9268384407218431], [2.011952180663762, 2.9709274359366926, 3.950264449373905, 4.941139590846486, 5.969374230477534, 6.924488041524394, 7.9518318551423715, 8.966715959870001, 9.906373097069102, 10.930799374814706, 9.968213663418675, 8.977796309067418, 7.911732794955911, 6.903340362020101, 5.896544451697148, 4.908066831576251, 3.95068135260266, 2.926308755374384, 1.9492214251112856, 1.001774548703722, 3.0308579583103383, 4.026231781926716, 4.940777327677909, 5.889314548881599, 6.949164942659433, 7.903689959841649, 8.90195855876256, 9.893954372556207, 10.945716998349617, 11.765053584995687, 10.811657896565809, 9.851615822860659, 8.792805883133639, 7.7763787107163695, 6.8236724472678025, 5.889958340805394, 4.876129030091963, 3.9566335918386644, 2.9973114209438148, 2.0605361565909672, 4.074580611344064, 5.015735751166956, 5.920151789008573, 6.879101627226092, 7.876818209302857, 8.889631853646272, 9.90468865809808, 10.926577167525023, 11.942240156307403, 12.74551512267277, 11.7253018529205, 10.79450886413133, 9.742238634560088, 8.746263800122394, 7.771965026860633, 6.872450870087885, 5.949063296611747, 4.937912541515406, 3.9227095720269816, 3.098568666846234, 5.09292865634135, 6.026825690288159, 6.903995710318652, 7.832604729823302, 8.871864241372677, 9.872961000337648, 10.82144177779022, 11.812550312192442, 12.798100662350723, 13.729078196512432, 12.728627150815527, 11.660451820791026, 10.6965485396949, 9.73400009933915, 8.791870982802227, 7.765759615779807, 6.837240989339675, 5.902122913532965, 4.908543760371426, 4.159108274779168, 6.018504307764964, 6.965839612265809, 7.959977349863586, 8.897123165520876, 9.854126163133017, 10.919934333048221, 11.875411848849973, 12.816115248131847, 13.790226772475096, 14.616580814923127, 13.66694084553496, 12.599821521203577, 11.684884335852574, 10.706153299674343, 9.770700229031808, 8.76338894844617, 7.801679526238434, 6.8728161764612326, 5.854406542234345, 5.1293270907252, 7.026606401160986, 8.006806726510229, 8.9059774508435, 9.831364368487339, 10.796688999753394, 11.82426878692868, 12.761444240719744, 13.729974001916565, 14.722180130110281, 15.459299437970277, 14.513152546314803, 13.560751145057159, 12.603331162309544, 11.67437221397442, 10.69656184404929, 9.73227541721458, 8.82191989913058, 7.855085140431651, 6.802088569691907, 6.1899985907787665, 7.970637143956035, 8.984809192911854, 9.945991669503972, 10.858782029502834, 11.767460737404285, 12.7945822290078, 13.736203790203156, 14.768614764717348, 15.742685406051942, 16.40105334589224, 15.513744375074722, 14.584636752003673, 13.669034933264102, 12.678815721183588, 11.649041767478328, 10.799489223933348, 9.784173543765638, 8.83003628894469, 7.821643995388299, 7.1194289205416075, 8.981868517240626, 9.967091866832256, 10.928302746655408, 11.889858975084316, 12.792816586283681, 13.820733055944796, 14.712495237094036, 15.749996748650513, 16.70560517093726, 17.342527382502897, 16.47505008004884, 15.516566157969288, 14.702195903976945, 13.682501428298083, 12.722400235593435, 11.760623750510991, 10.831037150410353, 9.89208182605833, 8.872205694825784, 8.056515150416152, 9.9512876578775, 10.987688661280153, 11.965452426899223, 12.893490018077248, 13.723577214782713, 14.728121747277529, 15.664402844508167, 16.691661033892885, 17.65623166991239, 18.38074188255298, 17.487093271760614, 16.538928990587284, 15.616983814642468, 14.677585209584736, 13.64827404067776, 12.789045172496232, 11.889186824968004, 10.927438145287987, 9.860620528470774, 9.023953753901234, 10.01793196118617, 10.867499423395639, 11.784385717209462, 12.765510793708657, 13.723399676302533, 14.734279563816758, 15.679257889521965, 16.62139268312638, 17.493013934286257, 18.42366886970574, 18.422047940545493, 17.49687448180845, 16.557914246729585, 15.611305706399053, 14.643005944803082, 13.75116287696064, 12.891882170028106, 11.92172605646305, 10.897517272274964, 10.004642279084262, 8.971709984395263, 9.858300205829917, 10.802419871912843, 11.871785533104074, 12.833435929106138, 13.799376661764885, 14.630838690178965, 15.604154610963826, 16.564050137009158, 17.56040314209912, 18.37601749824219, 17.47488766844853, 16.621229343890192, 15.633413844891098, 14.567702282449291, 13.616893735754186, 12.632580335031664, 11.736775460713892, 10.771830612859905, 9.901544773935075, 8.015652147748657, 8.911878646188608, 9.929771520663552, 10.929776461893951, 11.79386626585805, 12.84334298621694, 13.669001123248455, 14.61444691102036, 15.613286131379155, 16.538407461631163, 17.424667939944666, 16.419918629699247, 15.551545307740533, 14.646299527934849, 13.611355668555076, 12.73513603331469, 11.693781575293267, 10.766967746779924, 9.836477689751774, 8.971257526141573, 7.021995167180307, 7.942315063266255, 8.979815724089885, 9.896469568415775, 10.776444638017137, 11.784329066641575, 12.721739156426036, 13.619072274024207, 14.588088990067492, 15.602133449200728, 16.417907697694154, 15.492381367554524, 14.505304036030015, 13.650641195288081, 12.580210181529827, 11.69050156552838, 10.750065394844501, 9.761365011549822, 8.850145279630096, 8.05570532752982, 6.022652704065351, 7.002047493692405, 7.939140254998839, 8.907259754757693, 9.823625075926785, 10.838287194498758, 11.756815619107059, 12.66532611149747, 13.704344379893264, 14.671008990576683, 15.53885735392278, 14.595721064067563, 13.569118310074392, 12.630921135042517, 11.644267300636262, 10.682863093320867, 9.699155586382199, 8.71046820929762, 7.871465503221314, 7.000129153562065, 5.049770753164112, 5.991296134009673, 6.936185931528768, 7.927437565866606, 8.852799061851638, 9.810798700125268, 10.717280230203784, 11.684925589343027, 12.64021548044164, 13.608893303235064, 14.567538302306222, 13.567752444980869, 12.545024906799831, 11.60690065144338, 10.680101203791125, 9.763425367848637, 8.762743670131808, 7.748202943685152, 6.804297164396028, 5.996789966036813, 3.990526120820929, 4.981175285227101, 5.94153476509642, 6.996567250653781, 7.959510781595048, 8.878772330405681, 9.743216310136877, 10.72476304473461, 11.728251014552116, 12.733336260225045, 13.585408040068947, 12.638547299928499, 11.607727054269303, 10.66952320250984, 9.7286623098511, 8.736089162509694, 7.777564937547548, 6.818608305314029, 5.785197490531907, 5.028510933103892, 2.9901914507678358, 3.9360122798652815, 4.983638397219286, 6.023901347746654, 6.95576333965968, 7.80396869284192, 8.738505573955791, 9.761416428757933, 10.733860279641652, 11.734262524261895, 12.631843404782268, 11.609710590737414, 10.64918611739548, 9.72550507180347, 8.725471131199264, 7.7631528000618495, 6.814306643893506, 5.799432539983574, 4.814117000113813, 3.9796992483758524, 2.0240848024985567, 3.048322620586097, 4.002938405667411, 4.949958930292881, 5.992730010386655, 6.8307543532326385, 7.775042551563009, 8.796859334339665, 9.801891074338396, 10.732312506560326, 11.727698571733729, 10.764965831364787, 9.717704354265928, 8.757047119721893, 7.785922746204829, 6.810287097398731, 5.8591247363582815, 4.935455554462883, 3.8868716923529476, 2.9409183444973146, 1.0112268978932153, 2.0693403686697787, 2.982474414931518, 3.9650929024189296, 4.929137428345776, 5.903622156055572, 6.921530385460428, 7.993321352558461, 9.008241806993892, 10.015806699921558, 10.799224395743174, 9.805828172567029, 8.860818049514448, 7.881575266980864, 6.875745818946043, 5.856329854896124, 4.837102870922095, 3.8962505414787003, 2.9516836251443417, 1.9856854207694628, 0.0, 1.0116849857351764, 1.972336950401092, 3.019344921921138, 3.967640104025155, 5.026510482925698, 6.016293835401299, 7.036192971541358, 7.977948377026859, 9.023353865202067, 10.09492101506734, 9.230740491814775, 8.256447469024971, 7.327028632553226, 6.2589905503322445, 5.211361030202097, 4.222095691115858, 3.157461094641662, 2.117466490999435, 1.0588469800476197], [2.9744516676862567, 3.933426922959187, 4.9127639363963995, 5.903639077868981, 6.931873717500029, 7.8869875285468884, 8.914331342164866, 9.929215446892496, 10.868872584091596, 10.0098413538645, 8.956528677683497, 7.96611132333224, 6.900047809220733, 5.891655376284923, 4.884859465961971, 3.896381845841075, 2.9389963668674834, 1.9146237696392079, 0.9375364393761092, 1.964274035726216, 3.993357445332833, 4.988731268949211, 5.903276814700403, 6.851814035904094, 7.911664429681927, 8.866189446864144, 9.864458045785055, 10.856453859578702, 11.825754903643867, 10.753368599260511, 9.799972910830633, 8.839930837125483, 7.781120897398463, 6.764693724981193, 5.811987461532626, 4.878273355070218, 3.8644440443567873, 2.944948606103488, 1.9856264352086384, 3.0230356436134613, 4.908303269547215, 5.849458409370106, 6.806218001198697, 7.77238372136235, 8.77122415416968, 9.784037798513094, 10.815240401010815, 11.837128910437759, 12.74108485746859, 11.733830136937595, 10.713616867185324, 9.782823878396155, 8.730553648824912, 7.734578814387218, 6.760280041125456, 5.860765884352709, 4.937378310876571, 3.9262275557802297, 2.911024586291805, 3.862853915963639, 5.9266513145445, 6.860548348491309, 7.790061922508776, 8.718670942013425, 9.7579304535628, 10.76736694520447, 11.715847722657042, 12.706956257059264, 13.692506607217545, 12.717393210777256, 11.71694216508035, 10.64876683505585, 9.684863553959724, 8.722315113603974, 7.780185997067049, 6.754074630044631, 5.825556003604499, 4.890437927797789, 3.89685877463625, 4.905441458558331, 6.852226965968114, 7.799562270468959, 8.827867326498602, 9.783189377710999, 10.74019237532314, 11.806000545238344, 12.769817793716795, 13.71052119299867, 14.54914030230192, 13.604895829187951, 12.655255859799784, 11.5881365354684, 10.673199350117399, 9.694468313939167, 8.75901524329663, 7.7517039627109945, 6.789994540503258, 5.861131190726057, 4.8427215564991695, 5.875660274504362, 7.703489922637976, 8.765229613117132, 9.714467509552158, 10.639854427195997, 11.678683888229854, 12.70626367540514, 13.643439129196203, 14.611968890393024, 15.375148263864816, 14.4476144522351, 13.501467560579627, 12.549066159321983, 11.591646176574367, 10.662687228239243, 9.684876858314112, 8.720590431479405, 7.810234913395403, 6.843400154696475, 5.790403583956731, 6.7531468633772995, 8.647520665433024, 9.661692714388844, 10.622875190980961, 11.629869668888537, 12.649455625880744, 13.676577117484259, 14.618198678679615, 15.650609653193808, 16.362657351295095, 15.389368360157063, 14.502059389339546, 13.572951766268497, 12.657349947528925, 11.66713073544841, 10.63735678174315, 9.787804238198172, 8.772488558030462, 7.818351303209514, 6.809959009653123, 7.6825771931401405, 9.64762698332192, 10.643975388309245, 11.605186268132398, 12.615063771098306, 13.586620246080914, 14.636615275696782, 15.594490125570495, 16.631991637126973, 17.295843280993033, 16.33084239676772, 15.463365094313666, 14.504881172234112, 13.690510918241767, 12.670816442562906, 11.710715249858257, 10.748938764775815, 9.819352164675177, 8.880396840323154, 7.860520709090609, 8.619663423014686, 10.617046123958795, 10.919851190384062, 11.88294988391878, 12.810987475096805, 13.719226042350686, 14.710011942471597, 15.646293039702236, 16.58638730445922, 17.550134748026192, 17.369056896817803, 16.475408286025438, 15.527244004852108, 14.60529882890729, 13.665900223849558, 12.636589054942583, 11.777360186761056, 10.877501839232828, 9.91575315955281, 8.848935542735598, 9.587102026499768, 10.907700772295787, 9.933088624119662, 10.849974917933485, 11.83109999443268, 12.755493590663374, 13.766373478177599, 14.66757290378679, 15.609707697391206, 16.48132894855108, 17.411983883970564, 17.410362954810317, 16.485189496073275, 15.546229260994407, 14.599620720663875, 13.631320959067905, 12.739477891225464, 11.88019718429293, 10.910041070727875, 9.885832286539788, 10.567790551682796, 9.86147879550488, 8.92388940655394, 9.868009072636866, 10.900173029278342, 11.821750943370962, 12.78769167602971, 13.61915370444379, 14.59246962522865, 15.552365151273982, 16.54871815636394, 17.457941412062034, 17.51646561569012, 16.570249845524568, 15.654265750799848, 14.588554188358042, 13.802187536366631, 12.844246777520944, 11.91706013411015, 10.952115286256163, 10.79131358504469, 8.905420958858274, 7.977467846912631, 8.995360721387575, 9.92253905483979, 10.782181280122874, 11.831658000481765, 12.657316137513279, 13.602761925285185, 14.60160114564398, 15.526722475895985, 16.506591853764508, 17.41153869397819, 16.56323029347571, 15.657984513670025, 14.623040654290252, 13.746821019049868, 12.705466561028445, 11.778652732515102, 10.844839967085292, 9.86102633725119, 7.955124353639119, 7.007904263990278, 7.972578317035726, 8.889232161361614, 9.764759652281962, 10.7726440809064, 11.71005417069086, 12.60738728828903, 13.576404004332314, 14.590448463465552, 15.558475101693837, 16.484001431833466, 15.516989021765191, 14.662326181023257, 13.591895167265003, 12.702186551263559, 11.761750380579679, 10.773049997285, 9.858507556963614, 8.988834513988632, 6.955781890524163, 6.067636694416429, 6.931902847944679, 7.900022347703532, 8.811940090191609, 9.826602208763582, 10.745130633371883, 11.653641125762292, 12.692659394158087, 13.659324004841505, 14.527172368187601, 15.570613733778218, 14.580803295809568, 13.642606120777693, 12.655952286371438, 11.694548079056045, 10.710840572117377, 9.722153195032798, 8.879827780554832, 7.933258340020877, 5.982899939622924, 5.056885334733696, 5.928948524474608, 6.9157525801314295, 7.841114076116462, 8.799113714390092, 9.705595244468608, 10.67324060360785, 11.628530494706462, 12.597208317499886, 13.555853316571044, 14.579437430716045, 13.556709892535007, 12.618585637178557, 11.6917861895263, 10.775110353583813, 9.774428655866986, 8.75988792942033, 7.815982150131205, 6.929919152495625, 4.923655307279741, 4.0226628134910225, 4.93429735804226, 5.984882264918604, 6.947825795859871, 7.867087344670504, 8.7315313244017, 9.713078058999432, 10.716566028816938, 11.721651274489869, 12.736990652754264, 13.650232285663675, 12.619412040004478, 11.681208188245016, 10.740347295586275, 9.74777414824487, 8.789249923282725, 7.830293291049206, 6.796882476267084, 5.969499003855598, 3.9233206372266483, 2.9774998081292026, 3.976400990165126, 5.012216362011477, 5.944078353924503, 6.792283707106743, 7.726820588220614, 8.749731443022755, 9.722175293906474, 10.722577538526718, 11.783426017467585, 12.62139557647259, 11.660871103130656, 10.737190057538646, 9.73715611693444, 8.774837785797025, 7.825991629628682, 6.811117525718751, 5.82580198584899, 4.945018859136517, 3.0357697882337327, 2.0462804737784204, 2.991253419932235, 3.938273944557704, 4.981045024651477, 5.819069367497462, 6.763357565827832, 7.785174348604489, 8.79020608860322, 9.72062752082515, 10.767577118270816, 11.730309858639759, 10.729389340001104, 9.768732105457069, 8.797607731940005, 7.821972083133907, 6.870809722093457, 5.94714054019806, 4.8985566780881244, 3.952603330232491, 2.0229118836283915, 1.067298221862102, 1.9707894291963415, 2.9534079166837532, 3.9174524426105988, 4.8919371703203955, 5.909845399725251, 6.981636366823285, 7.996556821258716, 9.004121714186383, 10.075717972830326, 10.817513158302205, 9.872503035249624, 8.89326025271604, 7.887430804681219, 6.8680148406313, 5.848787856657271, 4.907935527213876, 3.9633686108795176, 2.997370406504639, 1.0116849857351764, 0.0, 0.9606519646659155, 2.007659936185961, 2.955955118289978, 4.014825497190522, 5.004608849666123, 6.024507985806182, 6.966263391291683, 8.01166887946689, 9.083236029332165, 10.107981981942709, 9.26813245476015, 8.338713618288404, 7.270675536067422, 6.223046015937275, 5.233780676851035, 4.169146080376839, 3.1291514767346116, 2.070531965782796], [3.935103632352172, 4.894078887625103, 5.873415901062315, 6.864291042534896, 7.892525682165944, 8.847639493212803, 9.874983306830782, 10.889867411558413, 10.073615666944189, 9.049189389198585, 7.995876713017582, 7.005459358666324, 5.939395844554817, 4.931003411619008, 3.9242075012960553, 2.9357298811751593, 1.9783444022015682, 0.9539718049732924, 1.8981884040420247, 2.924926000392132, 4.954009409998749, 5.949383233615126, 6.863928779366319, 7.8124660005700095, 8.872316394347843, 9.826841411530058, 10.82511001045097, 11.817105824244617, 10.865102938977953, 9.792716634594598, 8.839320946164719, 7.879278872459568, 6.820468932732547, 5.804041760315277, 4.85133549686671, 3.9176213904043022, 2.903792079690872, 1.9842966414375725, 2.946278399874554, 3.983687608279377, 5.8689552342131295, 6.810110374036021, 7.766869965864611, 8.733035686028265, 9.731876118835595, 10.74468976317901, 11.775892365676732, 12.796095881585053, 11.780432892802674, 10.77317817227168, 9.752964902519409, 8.822171913730239, 7.769901684158997, 6.7739268497213025, 5.79962807645954, 4.9001139196867936, 3.976726346210656, 2.9976984864628404, 3.8716765509577207, 4.823505880629554, 6.887303279210415, 7.821200313157224, 8.75071388717469, 9.67932290667934, 10.718582418228715, 11.728018909870388, 12.67649968732296, 13.667608221725182, 12.733466636945806, 11.756741246111343, 10.756290200414435, 9.688114870389935, 8.724211589293809, 7.761663148938059, 6.819534032401133, 5.834278883153447, 4.9057602567133145, 4.025406520256068, 4.857510739302166, 5.866093423224246, 7.812878930634029, 8.760214235134875, 9.788519291164517, 10.743841342376914, 11.700844339989056, 12.766652509904258, 13.730469758382712, 14.659495535014422, 13.588488337636003, 12.644243864522034, 11.694603895133866, 10.627484570802485, 9.712547385451483, 8.733816349273251, 7.798363278630716, 6.866565540674865, 5.904856118467129, 5.075058146378391, 5.803373521165085, 6.836312239170278, 8.664141887303892, 9.725881577783047, 10.675119474218073, 11.600506391861913, 12.639335852895769, 13.666915640071057, 14.60409109386212, 15.424475851999023, 14.4144962991989, 13.486962487569185, 12.540815595913712, 11.588414194656067, 10.630994211908453, 9.702035263573329, 8.724224893648199, 7.8354520094432765, 6.925096491359273, 6.073483132786004, 6.751055548622647, 7.713798828043215, 9.60817263009894, 10.622344679054759, 11.583527155646877, 12.590521633554452, 13.61010759054666, 14.637229082150176, 15.578850643345532, 16.411971052352506, 15.40200538662918, 14.428716395491147, 13.541407424673631, 12.612299801602582, 11.69669798286301, 10.706478770782496, 9.676704817077237, 8.902665816162044, 7.887350135994331, 7.049345070185899, 7.770610974319038, 8.643229157806056, 10.608278947987836, 11.604627352975161, 12.103086398310406, 13.016502125530508, 13.6893347061838, 14.739329735799668, 15.718634232462135, 16.629783361800893, 16.335191316327116, 15.370190432101804, 14.50271312964775, 13.544229207568197, 12.729858953575853, 11.710164477896992, 10.750063285192343, 9.87351100086331, 8.943924400762672, 8.111390607299537, 8.821172673756525, 9.580315387680601, 11.577698088624711, 11.84404772253657, 11.065936718066592, 11.962861021406725, 12.758574077684768, 13.74935997780568, 14.685641075036319, 15.625735339793305, 16.58948278336028, 16.408404932151885, 15.514756321359522, 14.566592040186192, 13.644646864241377, 12.705248259183644, 11.675937090276669, 10.901932422848551, 10.002074075320323, 9.18275591829857, 9.809587507401515, 10.547753991165683, 11.831897304448296, 10.857285156272171, 10.032961752081297, 10.9672659193337, 11.794841625997456, 12.805721513511681, 13.706920939120876, 14.649055732725293, 15.520676983885167, 16.45133191930465, 16.449710990144403, 15.524537531407361, 14.585577296328493, 13.638968755997961, 12.670668994401991, 11.864050127312959, 11.004769420380425, 10.177043829473634, 10.846484251205705, 11.528442516348711, 10.785675327657389, 9.848085938706449, 9.050995906784678, 9.939521064612427, 10.861098978705044, 11.827039711363792, 12.658501739777876, 13.631817660562737, 14.591713186608068, 15.588066191698026, 16.49728944739612, 16.555813651024206, 15.609597880858654, 14.693613786133934, 13.627902223692129, 12.926759772454126, 11.968819013608439, 11.207753451257195, 11.91276725092208, 11.715510117197201, 9.829617491010783, 8.90166437906514, 8.07065203594041, 8.961887090173875, 9.821529315456958, 10.871006035815848, 11.696664172847365, 12.64210996061927, 13.640949180978065, 14.566070511230071, 15.545939889098594, 16.450886729312277, 16.629117270251903, 15.62350751487864, 14.588563655498866, 13.903108052356282, 12.907617773346836, 12.240404848174006, 11.805491931751206, 10.785222869403698, 8.915776318305035, 7.932100796142787, 7.0119263523698105, 7.928580196695698, 8.804107687616046, 9.811992116240482, 10.749402206024946, 11.646735323623115, 12.6157520396664, 13.629796498799639, 14.597823137027923, 15.523349467167552, 16.477640986431105, 15.622978145689174, 14.55254713193092, 13.662838515929474, 12.722402345245595, 11.733701961950915, 10.819159521629528, 9.949486478654546, 7.916433855190078, 6.991833226568938, 5.971250883278763, 6.939370383037616, 7.851288125525692, 8.865950244097665, 9.784478668705969, 10.692989161096378, 11.732007429492173, 12.698672040175591, 13.566520403521688, 14.609961769112305, 15.541455260475482, 14.60325808544361, 13.616604251037355, 12.65520004372196, 11.671492536783292, 10.682805159698713, 9.840479745220746, 8.893910304686791, 6.94355190428884, 6.014757840827961, 4.968296559808692, 5.955100615465514, 6.880462111450546, 7.8384617497241775, 8.744943279802694, 9.712588638941936, 10.667878530040548, 11.636556352833972, 12.59520135190513, 13.646807944110797, 14.517361857200921, 13.579237601844474, 12.652438154192218, 11.73576231824973, 10.735080620532901, 9.720539894086246, 8.77663411479712, 7.8905711171615405, 5.884307271945657, 4.983314778156938, 3.9736453933763443, 5.024230300252689, 5.987173831193956, 6.90643538000459, 7.770879359735786, 8.752426094333519, 9.755914064151025, 10.760999309823955, 11.77633868808835, 12.82473959580566, 13.580064004670394, 12.641860152910933, 11.700999260252193, 10.708426112910788, 9.749901887948642, 8.790945255715123, 7.757534440932999, 6.930150968521514, 4.883972601892564, 3.938151772795118, 3.0157490254992103, 4.051564397345562, 4.983426389258588, 5.831631742440829, 6.7661686235547, 7.7890794783568404, 8.76152332924056, 9.761925573860804, 10.822774052801671, 11.781618831119987, 12.621523067796572, 11.697842022204563, 10.697808081600357, 9.735489750462943, 8.786643594294597, 7.771769490384666, 6.786453950514906, 5.905670823802433, 3.996421752899648, 3.006932438444336, 2.0306014552663196, 2.9776219798917887, 4.020393059985563, 4.858417402831547, 5.802705601161917, 6.824522383938574, 7.8295541239373065, 8.759975556159237, 9.806925153604903, 10.769657893973845, 11.69004130466702, 10.729384070122984, 9.75825969660592, 8.782624047799823, 7.831461686759373, 6.907792504863975, 5.85920864275404, 4.9132552948984065, 2.983563848294307, 2.0279501865280176, 1.010137464530426, 1.9927559520178377, 2.9568004779446837, 3.931285205654481, 4.949193435059336, 6.02098440215737, 7.035904856592801, 8.043469749520469, 9.115066008164412, 10.108462231340557, 10.83315499991554, 9.853912217381955, 8.848082769347135, 7.828666805297216, 6.809439821323187, 5.868587491879792, 4.924020575545433, 3.9580223711705544, 1.972336950401092, 0.9606519646659155, 0.0, 1.0470079715200458, 1.995303153624063, 3.054173532524606, 4.043956885000208, 5.063856021140267, 6.005611426625768, 7.051016914800975, 8.122584064666249, 9.147330017276794, 10.121623040066597, 9.299365582954318, 8.231327500733336, 7.183697980603188, 6.19443264151695, 5.129798045042754, 4.089803441400527, 3.0311839304487114], [4.982111603872218, 5.941086859145148, 6.920423872582361, 7.911299014054942, 8.93953365368599, 9.894647464732849, 10.921991278350827, 10.006254107742919, 9.066596970543818, 8.042170692798214, 6.988858016617211, 5.998440662265954, 4.933387937815777, 3.924995504879967, 2.9465872381148346, 1.9581096179939383, 1.029308181060958, 2.000979776493338, 2.9451963755620705, 3.9719339719121773, 6.001017381518794, 6.996391205135172, 7.910936750886364, 8.859473972090056, 9.919324365867888, 10.873849383050104, 11.872117981971016, 10.939245301590141, 9.887482675796733, 8.815096371413377, 7.861700682983498, 6.901658609278347, 5.842848669551326, 4.826421497134056, 3.8737152336854894, 2.963990422542575, 1.9547558585502618, 2.8830777032144397, 3.9383286274609555, 4.983453874614205, 6.8610054617995315, 7.802160601622423, 8.758920193451013, 9.725085913614667, 10.723926346421997, 11.736739990765411, 12.767942593263133, 11.818475618403832, 10.802812629621453, 9.795557909090459, 8.775344639338188, 7.844551650549017, 6.792281420977776, 5.796306586540082, 4.8220078132783195, 3.946482951825067, 3.027690125070046, 3.896479548239708, 4.863726778544122, 5.815556108215956, 7.879353506796817, 8.813250540743626, 9.742764114761092, 10.671373134265743, 11.710632645815117, 12.720069137456788, 13.66854991490936, 12.741396723922865, 11.755846373764584, 10.77912098293012, 9.778669937233214, 8.710494607208714, 7.746591326112588, 6.784042885756838, 5.841913769219913, 4.885242662012837, 3.956724035572705, 4.891842111379415, 5.849560966888567, 6.858143650810646, 8.80492915822043, 9.752264462721275, 10.780569518750918, 11.735891569963316, 12.692894567575458, 13.758702737490662, 14.622578671115077, 13.681875271833203, 12.610868074454784, 11.666623601340815, 10.716983631952647, 9.649864307621264, 8.734927122270262, 7.7561960860920305, 6.820743015449495, 5.917529319534256, 4.95581989732652, 5.884683247103721, 6.795423748751486, 7.828362466756678, 9.656192114890292, 10.717931805369448, 11.667169701804474, 12.592556619448313, 13.63138608048217, 14.658965867657457, 15.415385350014624, 14.446855588817803, 13.43687603601768, 12.509342224387964, 11.56319533273249, 10.610793931474847, 9.653373948727232, 8.724415000392108, 7.746604630466978, 6.886415788302667, 5.976060270218664, 6.883108233511335, 7.743105776209048, 8.705849055629615, 10.60022285768534, 11.61439490664116, 12.575577383233277, 13.086975483380197, 13.74205990467254, 14.792849912346009, 15.685940470642802, 15.434350789171285, 14.424385123447959, 13.451096132309926, 12.56378716149241, 11.634679538421361, 10.71907771968179, 9.728858507601275, 8.699084553896016, 7.953629595021434, 6.938313914853722, 7.858970170911229, 8.76266120190544, 9.635279385392456, 11.600329175574236, 12.596677580561561, 12.967444705096772, 12.055898537798715, 12.716704055793144, 13.766699085409012, 14.709649023751922, 15.582775390280846, 15.357571053145897, 14.392570168920583, 13.52509286646653, 12.566608944386976, 11.752238690394632, 10.732544214715771, 9.772443022011123, 8.924474779722702, 7.994888179622063, 8.921015708024868, 9.813222901342925, 10.572365615267001, 12.569748316211111, 12.765458121396854, 11.930295024852958, 11.002257433674933, 11.785943427294113, 12.776729327415024, 13.643120131741936, 14.578727368273256, 15.54247481184023, 15.430784668970663, 14.537136058178302, 13.588971777004971, 12.667026601060156, 11.727627996002424, 10.698316827095448, 9.952896201707944, 9.053037854179713, 9.9923810190239, 10.801637734987915, 11.539804218752083, 12.753307703308579, 11.778695555132455, 10.954372150941582, 10.006662331601907, 10.8222109756068, 11.833090863121026, 12.659912967600826, 13.602047761205244, 14.473669012365118, 15.4043239477846, 15.472090726963183, 14.54691726822614, 13.607957033147272, 12.66134849281674, 11.69304873122077, 10.915013906172351, 10.055733199239816, 10.986668930198965, 11.838534478792106, 12.520492743935112, 11.707085726517672, 10.769496337566732, 9.972406305644963, 8.978917476880634, 9.888468328314389, 10.805294864899082, 11.611493768257827, 12.58480968904269, 13.544705215088019, 14.541058220177977, 15.450281475876073, 15.578193387842987, 14.631977617677435, 13.715993522952715, 12.650281960510908, 11.977723551313519, 11.01978279246783, 12.017378551982526, 12.90481747850848, 12.636920516057483, 10.751027889871066, 9.823074777925424, 8.992062434800696, 8.001283502442082, 8.848898665066303, 9.849261189351138, 10.649656201327318, 11.595101989099224, 12.593941209458016, 13.519062539710022, 14.498931917578545, 15.403878757792228, 15.651497007070684, 14.645887251697419, 13.610943392317646, 12.954071831215675, 11.958581552206226, 12.885395380719569, 12.734050633447483, 11.706633268263982, 9.84991803455, 8.85351119500307, 7.933336751230095, 6.967976608963906, 7.831477037225391, 8.790247269775772, 9.702394234504899, 10.599727352103068, 11.568744068146353, 12.58278852727959, 13.550815165507874, 14.476341495647503, 15.463418827172012, 15.711600597318641, 14.642088879342895, 13.93331088862426, 12.980711614040954, 12.780709933470959, 11.753301237874494, 10.883628194899511, 8.850575571435044, 7.913243625429222, 6.892661282139048, 5.978766795305824, 6.8786574751350384, 7.844205397632955, 8.737470697185922, 9.64598118957633, 10.684999457972125, 11.651664068655544, 12.51951243200164, 13.562953797592257, 14.598822781235526, 15.613607701941758, 14.663612222557399, 13.702208015242004, 12.718500508303336, 11.729813131218757, 10.774621461465712, 9.828052020931757, 7.877693620533806, 6.9361682396882465, 5.8897069586689765, 4.98246996507486, 5.907831461059892, 6.791453778204131, 7.697935308282647, 8.665580667421889, 9.620870558520501, 10.589548381313925, 11.548193380385083, 12.59979997259075, 13.590974122346225, 14.626245573364518, 13.699446125712262, 12.782770289769772, 11.782088592052945, 10.76754786560629, 9.823642086317165, 8.824712833406508, 6.857270653160297, 5.947532439173478, 4.8950557922366285, 4.051599649862035, 4.958491714250045, 5.859427408484543, 6.723871388215739, 7.705418122813471, 8.708906092630977, 9.713991338303906, 10.729330716568303, 11.777731624285613, 12.653676269815696, 13.651574370381653, 12.748007231772236, 11.755434084430831, 10.796909859468688, 9.837953227235168, 8.804542412453044, 7.903114349736154, 5.8569359831072045, 4.911115154009759, 3.9371594243594945, 3.078933746954908, 3.9547442723146773, 4.784623770920782, 5.7191606520346525, 6.742071506836793, 7.714515357720512, 8.714917602340755, 9.775766081281624, 10.73461085959994, 11.695135332941874, 12.707556239675283, 11.7448160531204, 10.782497721982987, 9.833651565814641, 8.818777461904713, 7.833461922034951, 6.8786342050170735, 5.0405490698862385, 3.9798958196589767, 2.9520118541266034, 2.0049913295011343, 2.973385088465517, 3.811409431311501, 4.755697629641871, 5.777514412418528, 6.782546152417259, 7.71296758463919, 8.759917182084855, 9.722649922453797, 10.781981746582092, 11.742638981126127, 10.805267668125964, 9.829632019319867, 8.878469658279418, 7.954800476384021, 6.9062166142740855, 5.960263266418452, 4.0305718198143525, 3.006977095547564, 1.9835888929184256, 1.0009704054310138, 1.909792506424638, 2.884277234134435, 3.9021854635392907, 4.973976430637324, 5.988896885072755, 6.996461778000422, 8.068058036644365, 9.06145425982051, 10.002589887493002, 10.900920188902, 9.89509074086718, 8.875674776817261, 7.856447792843232, 6.915595463399837, 5.971028547065479, 5.0050303426906, 3.0193449219211375, 2.007659936185961, 1.0470079715200458, 0.0, 0.9482951821040173, 2.0071655610045607, 2.9969489134801623, 4.016848049620221, 4.958603455105722, 6.00400894328093, 7.0755760931462035, 8.100322045756748, 9.074615068546551, 10.004033905018296, 9.278335472253382, 8.230705952123234, 7.241440613036995, 6.176806016562799, 5.136811412920572, 4.078191901968757], [5.930406785976235, 6.889382041249165, 7.868719054686378, 8.859594196158959, 9.887828835790007, 10.842942646836866, 10.072843030366531, 9.057958925638902, 8.118301788439801, 7.093875510694196, 6.040562834513192, 5.050145480161935, 3.985092755711759, 2.976700322775949, 1.998292056010817, 1.009814435889921, 1.9671999148635124, 2.9492749585973552, 3.8934915576660876, 4.920229154016194, 6.9493125636228115, 7.944686387239189, 8.859231932990381, 9.807769154194073, 10.867619547971906, 11.82214456515412, 10.982945933279773, 9.990950119486126, 8.939187493692716, 7.86680118930936, 6.913405500879481, 5.95336342717433, 4.894553487447309, 3.8781263150300394, 2.925420051581472, 2.0156952404385575, 2.8926475923528163, 3.820969437016994, 4.87622036126351, 5.921345608416759, 7.798897195602086, 8.740052335424977, 9.696811927253567, 10.66297764741722, 11.66181808022455, 12.674631724567966, 11.892068945726757, 10.870180436299814, 9.854517447517434, 8.84726272698644, 7.827049457234169, 6.896256468444999, 5.843986238873758, 4.848011404436064, 3.8737126311743015, 2.9981877697210493, 3.948046502925795, 4.834371282042262, 5.801618512346677, 6.7534478420185104, 8.817245240599371, 9.75114227454618, 10.680655848563646, 11.609264868068296, 12.64852437961767, 13.657960871259343, 12.784210076221072, 11.79310154181885, 10.807551191660568, 9.830825800826105, 8.830374755129197, 7.762199425104697, 6.798296144008571, 5.83574770365282, 4.8936185871158955, 4.009264038307428, 4.8770804134284536, 5.812198489235163, 6.787452700691121, 7.796035384613202, 9.742820892022985, 10.69015619652383, 11.718461252553473, 12.67378330376587, 13.630786301378011, 14.696594471293214, 13.674283489011058, 12.733580089729184, 11.662572892350765, 10.718328419236796, 9.768688449848629, 8.701569125517247, 7.786631940166244, 6.807900903988012, 5.872447833345478, 5.070408900413216, 5.876176275182268, 6.80503962495947, 7.73331548255404, 8.766254200559233, 10.594083848692847, 11.655823539172003, 12.605061435607029, 13.530448353250868, 13.841125087942867, 14.868704875118155, 14.467090167910607, 13.498560406713786, 12.488580853913662, 11.561047042283947, 10.614900150628474, 9.66249874937083, 8.705078766623215, 7.776119818288091, 6.798309448362961, 6.039295369181627, 6.896416648074412, 7.803464611367083, 8.680997510011602, 9.64374078943217, 11.538114591487895, 12.552286640443715, 13.513469117035832, 13.84763092197667, 12.870353350291976, 13.921143357965445, 14.737645288538783, 14.486055607067268, 13.476089941343941, 12.50280095020591, 11.615491979388393, 10.686384356317344, 9.770782537577773, 8.780563325497258, 7.750789371791999, 7.106509175900394, 7.85867029270947, 8.779326548766978, 9.700552935707993, 10.573171119195012, 12.538220909376792, 13.534569314364116, 13.826431479361096, 12.816553976395188, 11.84499750141258, 12.894992531028448, 13.761353841647903, 14.634480208176827, 14.40927587104188, 13.444274986816566, 12.576797684362512, 11.618313762282959, 10.803943508290615, 9.784249032611754, 8.824147839907106, 8.160568360956168, 8.915244557477811, 9.841372085880618, 10.751114635145479, 11.510257349069557, 13.507640050013666, 13.679060469491262, 12.789538781585543, 11.861501190407518, 10.914236872913548, 11.864402127997929, 12.694824949637917, 13.630432186169237, 14.594179629736214, 14.482489486866648, 13.588840876074284, 12.640676594900954, 11.71873141895614, 10.779332813898407, 9.750021644991431, 9.188989782941409, 9.97339423203546, 10.91273739687965, 11.739529468790469, 12.477695952554638, 13.666910051402986, 12.692297903226862, 11.847164743269879, 10.866039666770686, 9.950504421226237, 10.92076366370393, 11.711617785496808, 12.653752579101225, 13.525373830261103, 14.456028765680585, 14.523795544859166, 13.598622086122123, 12.659661851043255, 11.713053310712723, 10.744753549116753, 10.151107487405817, 10.976089577095562, 11.907025308054715, 12.776426212594657, 13.458384477737667, 12.62068807461208, 11.68309868566114, 10.879624465973324, 9.838294812049412, 9.016761773933824, 9.856999682795063, 10.663198586153808, 11.63651450693867, 12.596410032984004, 13.592763038073961, 14.501986293772058, 14.629898205738968, 13.683682435573417, 12.767698340848696, 11.70198677840689, 11.213817132546984, 11.940139170323576, 12.937734929838276, 13.842709212311032, 13.55052286415189, 11.664630237965474, 10.736677126019831, 9.899280595129056, 8.86066083761086, 7.9771921106857375, 8.900966007247119, 9.701361019223299, 10.646806806995205, 11.645646027354001, 12.570767357606007, 13.55063673547453, 14.455583575688213, 14.703201824966666, 13.697592069593401, 12.662648210213629, 12.19016541244914, 12.878937930061973, 13.805751758575315, 13.64765298154189, 12.62023561635839, 10.773078100001362, 9.767113543097478, 8.846939099324501, 7.8273539441326845, 6.959770482844825, 7.8419520876717534, 8.75409905240088, 9.651432169999051, 10.620448886042336, 11.634493345175574, 12.602519983403859, 13.528046313543488, 14.515123645067996, 14.763305415214624, 13.693793697238878, 13.261246240993867, 13.901067991896701, 13.729005115574978, 12.701596419978511, 11.81598953550296, 9.798870753539061, 8.826845973523628, 7.806263630233455, 6.8381441304746025, 6.0069509207544725, 6.895910215528937, 7.7891755150819035, 8.697686007472313, 9.736704275868108, 10.703368886551527, 11.571217249897623, 12.61465861548824, 13.65052759913151, 14.665312519837741, 14.629736578132443, 14.26888471320138, 13.666795690407355, 12.678108313322776, 11.722916643569729, 10.776347203035774, 8.825988802637823, 7.884463421792264, 6.838002140772994, 5.841847300243638, 5.036124906679326, 5.843158596100113, 6.74964012617863, 7.717285485317872, 8.672575376416484, 9.641253199209908, 10.599898198281066, 11.651504790486733, 12.642678940242206, 13.710589844413304, 14.63738929206556, 13.73106547187379, 12.730383774156964, 11.715843047710308, 10.771937268421183, 9.773008015510525, 7.805565835264314, 6.895827621277495, 5.8433509743406455, 4.910976985030813, 4.010196532146028, 4.911132226380525, 5.7755762061117215, 6.757122940709454, 7.76061091052696, 8.765696156199887, 9.781035534464285, 10.829436442181596, 11.705381087711679, 12.703279188277635, 13.696302413876253, 12.703729266534848, 11.745205041572707, 10.786248409339187, 9.752837594557063, 8.85140953184017, 6.805231165211222, 5.859410336113776, 4.885454606463512, 3.938311082123686, 3.00644909021066, 3.8363285888167646, 4.770865469930635, 5.793776324732776, 6.766220175616495, 7.766622420236738, 8.827470899177607, 9.786315677495923, 10.746840150837857, 11.759261057571265, 12.693111235224418, 11.730792904087004, 10.781946747918658, 9.767072644008731, 8.78175710413897, 7.8269293871210905, 5.9888442519902565, 4.928191001762994, 3.900307036230621, 2.953286511605152, 2.0250899063614995, 2.8631142492074835, 3.807402447537853, 4.829219230314511, 5.834250970313242, 6.764672402535173, 7.811621999980839, 8.77435474034978, 9.833686564478075, 10.79434379902211, 11.753562850229981, 10.777927201423884, 9.826764840383435, 8.903095658488038, 7.8545117963781035, 6.90855844852247, 4.9788670019183705, 3.955272277651581, 2.9318840750224426, 1.949265587535031, 0.9614973243206206, 1.9359820520304176, 2.953890281435273, 4.025681248533307, 5.040601702968736, 6.0481665958964035, 7.119762854540346, 8.11315907771649, 9.054294705388982, 10.031155377039257, 10.843385922971198, 9.823969958921278, 8.80474297494725, 7.863890645503855, 6.919323729169497, 5.953325524794618, 3.967640104025155, 2.9559551182899786, 1.995303153624063, 0.9482951821040173, 0.0, 1.0588703789005431, 2.0486537313761444, 3.0685528675162033, 4.010308273001703, 5.055713761176911, 6.127280911042185, 7.152026863652728, 8.12631988644253, 9.055738722914276, 10.123776805135257, 9.179001134227255, 8.189735795141015, 7.125101198666818, 6.085106595024591, 5.026487084072775], [6.948977517564487, 7.907952772837417, 8.887289786274629, 9.87816492774721, 10.906399567378259, 10.04131646508397, 9.013972651465991, 7.99908854673836, 7.059431409539259, 6.035005131793654, 4.9816924556126505, 3.991275101261393, 2.926222376811216, 1.9178299438754065, 0.94090046532272, 1.929378085443616, 2.8867635644172074, 3.911136161645483, 4.912062289254339, 5.938799885604446, 7.88668960223078, 8.956146608424795, 9.877802664578631, 10.826339885782323, 11.886190279560156, 10.988983047089937, 9.925554342591674, 8.933558528798027, 7.881795903004619, 6.809409598621263, 5.8560139101913835, 4.895971836486233, 3.837161896759212, 2.820734724341942, 1.8680284608933748, 2.9352588899922525, 3.8122112419065113, 4.740533086570689, 5.795784010817205, 6.840909257970455, 8.718460845155782, 9.659615984978673, 10.616375576807265, 11.582541296970918, 12.581381729778249, 11.865879957536382, 10.834677355038659, 9.812788845611715, 8.797125856829336, 7.789871136298342, 6.769657866546072, 5.838864877756902, 4.786594648185661, 3.7906198137479663, 2.8163210404862045, 3.754954076012328, 4.704812809217073, 5.753934931595958, 6.721182161900372, 7.673011491572206, 9.593756346556216, 10.531170411576513, 11.554027757478293, 12.482636776982943, 13.521896288532318, 12.675299262985545, 11.726818485532974, 10.735709951130751, 9.75015960097247, 8.773434210138007, 7.772983164441099, 6.704807834416599, 5.740904553320473, 4.7783561129647225, 3.836226996427798, 4.766030344598708, 5.633846719719733, 6.568964795526442, 7.562543948687981, 8.571126632610062, 10.51933199797983, 11.468293617843354, 12.496598673872997, 13.52565450301312, 14.504158210292658, 13.662189395347072, 12.61689189832296, 11.676188499041086, 10.605181301662666, 9.660936828548698, 8.71129685916053, 7.644177534829149, 6.729240349478146, 5.750509313299915, 4.815056242657381, 5.827175206704495, 6.632942581473547, 7.561805931250749, 8.5084067305509, 9.541345448556093, 11.369175096689707, 12.430914787168863, 13.380152683603889, 14.305539601247728, 14.650538884519177, 13.909531355720889, 13.409698577222509, 12.441168816025687, 11.431189263225564, 10.503655451595849, 9.557508559940375, 8.605107158682731, 7.647687175935117, 6.718728227599993, 5.740917857674862, 6.720155380372668, 7.647488381257659, 8.560230917658362, 9.456088758008462, 10.41883203742903, 12.313205839484755, 13.327377888440575, 14.288560365032692, 14.65704471855298, 13.679767146868286, 12.93921791364177, 13.743979137770541, 13.42866401637917, 12.418698350655843, 11.44540935951781, 10.558100388700295, 9.628992765629246, 8.713390946889675, 7.72317173480916, 6.693397781103901, 7.647576928360617, 8.609742025892718, 9.536092855058257, 10.475644183704855, 11.348262367191872, 13.313312157373652, 14.309660562360976, 14.635845275937406, 13.625967772971498, 12.65441129798889, 11.913067086704773, 12.767687690879661, 13.640814057408585, 13.351884280353781, 12.386883396128468, 11.519406093674414, 10.56092217159486, 9.746551917602517, 8.726857441923656, 7.766756249219007, 8.70163611341639, 9.631222713517028, 10.57017803786905, 11.52620588314234, 12.285348597066417, 14.282731298010527, 14.518653814663988, 13.598952578161853, 12.670914986983828, 11.723650669489858, 10.870735977229687, 11.701158798869676, 12.636766035400996, 13.600513478967972, 13.42509789617855, 12.531449285386186, 11.583285004212856, 10.66133982826804, 9.721941223210308, 8.692630054303333, 9.680307280762456, 10.60802486345802, 11.641543348868083, 12.51462071678733, 13.252787200551499, 14.506503396575713, 13.531891248399589, 12.686758088442605, 11.70563301194341, 10.759918217802547, 9.927097512935688, 10.717951634728566, 11.660086428332983, 12.531707679492861, 13.462362614912344, 13.466403954171067, 12.541230495434025, 11.602270260355157, 10.655661720024625, 9.687361958428655, 10.642424985226864, 11.581808420528775, 12.635831260043147, 13.55151746059152, 14.233475725734527, 13.460281419784806, 12.522692030833866, 11.71921781114605, 10.677888157222137, 9.826175570510134, 8.863333532026822, 9.669532435385566, 10.642848356170429, 11.602743882215762, 12.59909688730572, 13.508320143003816, 13.57250661505087, 12.626290844885318, 11.710306750160598, 10.644595187718792, 11.595403734413898, 12.545858013756789, 13.55748008988384, 14.522424937737828, 14.390116209324617, 12.5042235831382, 11.576270471192558, 10.738873940301783, 9.700254182783585, 8.786605907262048, 7.907299856478876, 8.707694868455057, 9.653140656226963, 10.65197987658576, 11.577101206837765, 12.556970584706288, 13.461917424919971, 13.645810234278567, 12.640200478905303, 11.60525661952553, 12.55444888491018, 13.484656773495185, 14.411470602008528, 14.487246326714617, 13.459828961531116, 11.612671445174088, 10.606706888270205, 9.686532444497228, 8.666947289305408, 7.769184279421137, 6.848285936903512, 7.7604329016326385, 8.65776601923081, 9.626782735274094, 10.640827194407333, 11.608853832635617, 12.534380162775246, 13.521457494299755, 13.705913824526526, 12.63640210655078, 13.625529713454906, 14.506786835329914, 14.590948876810222, 13.54122975386081, 12.655582880675686, 10.63850408742136, 9.666439318696355, 8.645856975406181, 7.677737475647327, 6.816364717330784, 5.902244064760695, 6.795509364313662, 7.704019856704072, 8.743038125099865, 9.709702735783285, 10.577551099129382, 11.620992464719999, 12.656861448363268, 13.6716463690695, 13.572344987444344, 14.596609931503657, 14.544660425152566, 13.555973048067987, 12.562549977452028, 11.615980536918073, 9.665622136520122, 8.724096755674562, 7.677635474655293, 6.681440645416363, 5.845538703255638, 4.8494924453318715, 5.755973975410388, 6.72361933454963, 7.678909225648241, 8.647587048441666, 9.606232047512824, 10.657838639718491, 11.649012789473968, 12.716923693645066, 13.643723141297322, 14.622401219527834, 13.608248508902175, 12.59370778245552, 11.649802003166394, 10.612641349392824, 8.760794868714274, 7.847105508945801, 6.794628862008952, 5.750570330203538, 4.849789877318753, 3.917466075612284, 4.78191005534348, 5.763456789941213, 6.766944759758719, 7.772030005431646, 8.787369383696044, 9.835770291413354, 10.711714936943439, 11.709613037509396, 12.707758151630182, 13.673239735687995, 12.720829772261677, 11.761873140028158, 10.728462325246033, 9.80663856529013, 7.760460198661182, 6.814639369563737, 5.836732494131818, 4.777904427296411, 3.846042435383385, 2.842662438048523, 3.777199319162394, 4.800110173964534, 5.772554024848254, 6.772956269468496, 7.833804748409365, 8.792649526727683, 9.753174000069617, 10.765594906803026, 11.765628847407232, 12.70030337324015, 11.772591250382794, 10.742697374697702, 9.75738183482794, 8.78215842057105, 6.944073285440217, 5.883420035212954, 4.855536069680581, 3.908515545055112, 2.864683251534225, 1.8694480984392419, 2.8137362967696116, 3.8355530795462687, 4.8405848195450005, 5.771006251766932, 6.817955849212598, 7.78068858958154, 8.840020413709833, 9.800677648253869, 10.771802021770933, 11.74743767057703, 10.874189341451617, 9.88860780396046, 8.840023941850525, 7.894070593994892, 6.005949808279597, 4.947836337503034, 3.9244481348738955, 2.941829647386484, 1.9168006289719726, 0.9423159012621757, 1.9247031726217172, 2.980282121394595, 3.9817313240681944, 4.989296216995862, 6.060892475639804, 7.054288698815949, 7.995424326488441, 8.972284998138715, 9.978114446173535, 10.87139445998946, 9.852167476015431, 8.911315146572036, 7.966748230237677, 7.000750025862798, 5.026510482925698, 4.014825497190522, 3.054173532524606, 2.0071655610045607, 1.0588703789005431, 0.0, 0.9897833524756015, 2.0096824886156606, 2.951437894101161, 3.996843382276369, 5.068410532141643, 6.093156484752186, 7.06744950754199, 7.996868344013735, 9.064906426234717, 10.112535946364865, 9.248606174041557, 8.18397157756736, 7.143976973925133, 6.085357462973318], [7.938760870040087, 8.897736125313017, 9.877073138750228, 10.867948280222809, 10.006646923655227, 9.051533112608368, 8.02418929899039, 7.009305194262758, 6.069648057063658, 5.0452217793180525, 3.991909103137049, 3.0014917487857913, 1.9364390243356144, 0.928046591399805, 1.9306838177983214, 2.9191614379192172, 3.8765469168928086, 4.900919514121084, 5.90184564172994, 6.928583238080047, 8.876472954706381, 9.945929960900395, 10.867586017054233, 11.816123238257925, 11.019969657435432, 10.030735030925623, 8.974316002610578, 8.003333986183264, 6.951571360389854, 5.879185056006499, 4.92578936757662, 3.9657472938714684, 2.9069373541444476, 1.8905101817271777, 2.843216445175745, 3.91172099124303, 4.801994594382112, 5.73031643904629, 6.785567363292806, 7.8306926104460555, 9.708244197631382, 10.649399337454273, 11.606158929282863, 12.572324649446516, 11.947622924078857, 10.977791055420127, 9.946588452922404, 8.92469994349546, 7.909036954713081, 6.901782234182087, 5.896325592600498, 4.965532603811328, 3.9221529798199803, 2.9463861033750636, 3.7915090247685748, 4.730142060294698, 5.680000793499444, 6.732696387093639, 7.710965514375973, 8.662794844047806, 10.568944330838585, 11.506358395858882, 12.529215741760662, 13.457824761265313, 12.841512538335769, 11.816070579413061, 10.86758980196049, 9.876481267558267, 8.890930917399986, 7.914205526565522, 6.913754480868615, 5.845579150844115, 4.881675869747989, 3.9341224025918202, 4.811414980710168, 5.741218328881077, 6.609034704002102, 7.544152779808812, 8.53773193297035, 9.546314616892431, 11.494519982262199, 12.443481602125724, 13.471786658155366, 14.50084248729549, 13.823774460096109, 12.80296071177459, 11.757663214750478, 10.816959815468604, 9.745952618090183, 8.801708144976214, 7.852068175588047, 6.784948851256665, 5.870011665905662, 4.906275602927012, 5.790244226939751, 6.802363190986864, 7.608130565755917, 8.536993915533118, 9.48359471483327, 10.516533432838463, 12.344363080972077, 13.406102771451232, 14.355340667886258, 15.280727585530098, 14.515225134616376, 13.487645347441088, 12.550469893650025, 11.581940132453203, 10.57196057965308, 9.644426768023365, 8.698279876367891, 7.745878475110247, 6.853374066510315, 5.924415118175191, 6.7161058419572335, 7.695343364655039, 8.62267636554003, 9.535418901940732, 10.431276742290832, 11.3940200217114, 13.288393823767125, 14.302565872722944, 15.263748349315062, 15.606033243241233, 14.62875567155654, 13.877420607177212, 12.949123684798732, 12.569435332806686, 11.55946966708336, 10.586180675945327, 9.69887170512781, 8.769764082056762, 7.919077837464874, 6.938084286649975, 7.668585765386272, 8.622764912642989, 9.58493001017509, 10.511280839340627, 11.450832167987222, 12.323450351474241, 14.288500141656021, 15.284848546643346, 15.58483380062566, 14.574956297659751, 13.603399822677144, 12.851269780240216, 11.972832237907852, 12.845958604436776, 12.492655596781297, 11.527654712555984, 10.66017741010193, 9.701693488022377, 8.952238808177716, 7.941769993764471, 8.741944233501378, 9.676824097698763, 10.6064106977994, 11.545366022151423, 12.501393867424708, 13.260536581348786, 15.257919282292896, 15.501981229209918, 14.547941102850107, 13.619903511672081, 12.672639194178112, 11.80893867076513, 10.906303345897866, 11.841910582429186, 12.793140383065673, 12.565869212606064, 11.672220601813702, 10.724056320640372, 9.90923675148776, 8.969838146430028, 9.667818038585704, 10.655495265044827, 11.583212847740391, 12.616731333150456, 13.489808701069698, 14.227975184833868, 15.489830811121642, 14.515218662945518, 13.647920701583871, 12.666795625084676, 11.7089067424908, 10.865300206471131, 9.923096181756756, 10.865230975361174, 11.724334583590561, 12.654989519010044, 12.638739532753046, 11.713566074016004, 10.850167183574877, 9.903558643244345, 10.662549942711026, 11.617612969509235, 12.556996404811146, 13.61101924432552, 14.526705444873887, 15.208663710016896, 14.443608834330735, 13.506019445379795, 12.70254522569198, 11.661215571768068, 10.775164095198388, 9.801536225562264, 8.874676982413757, 9.847992903198618, 10.795370786313462, 11.79172379140342, 12.700947047101517, 12.771939775021512, 11.874187768105038, 10.975215967311389, 11.619783172001164, 12.570591718696269, 13.52104599803916, 14.532668074166212, 15.497612922020199, 15.373443623870546, 13.48755099768413, 12.559597885738487, 11.722201354847712, 10.683581597329516, 9.769933321807981, 8.84550255001432, 7.912839415483247, 8.858285203255152, 9.84460678068346, 10.769728110935466, 11.749597488803989, 12.654544329017671, 12.9438718042547, 12.029521432924295, 12.580444603807901, 13.52963686919255, 14.459844757777557, 15.386658586290899, 15.470573741260546, 14.443156376077045, 12.595998859720018, 11.590034302816134, 10.669859859043157, 9.65027470385134, 8.752511693967069, 7.831613351449443, 6.965577448660827, 7.850392923328512, 8.819409639371797, 9.833454098505033, 10.801480736733318, 11.727007066872947, 12.704042936589342, 13.095234778545517, 13.61159009083315, 14.600717697737277, 15.481974819612285, 15.574276291356151, 14.524557168406739, 13.638910295221615, 11.62183150196729, 10.649766733242284, 9.62918438995211, 8.661064890193257, 7.799692131876715, 6.885571479306626, 6.000653911341851, 6.896646760801774, 7.935665029197566, 8.902329639880985, 9.770178003227082, 10.8136193688177, 11.76785721063372, 12.782642131339951, 13.70264025602765, 14.721234912024517, 15.527987839698495, 14.539300462613916, 13.545877391997957, 12.599307951464002, 10.648949551066051, 9.707424170220492, 8.660962889201222, 7.664768059962293, 6.828866117801569, 5.8328198598778025, 4.961118522438577, 5.916246238647331, 6.871536129745943, 7.840213952539368, 8.798858951610525, 9.850465543816192, 10.743763807359159, 11.811674711530257, 12.738474159182513, 13.795326958912128, 14.591575923448104, 13.577035197001448, 12.633129417712324, 11.595968763938753, 9.744122283260205, 8.830432923491731, 7.777956276554882, 6.733897744749468, 5.833117291864683, 4.900793490158215, 3.987054602371668, 4.956083694038914, 5.95957166385642, 6.931158871120196, 7.8821204015812345, 8.930521309298545, 9.80646595482863, 10.804364055394586, 11.802509169515373, 12.767990753573185, 13.704157186807608, 12.745200554574089, 11.711789739791964, 10.789965979836062, 8.743787613207113, 7.797966784109668, 6.820059908677748, 5.761231841842341, 4.829369849929315, 3.825989852594453, 2.982343866190582, 3.9927370780622358, 4.965180928945955, 5.932085135157046, 6.928555766294556, 7.8874005446128725, 8.847925017954807, 9.860345924688216, 10.860379865292423, 11.79505439112534, 12.748532957037893, 11.726024789243633, 10.740709249373872, 9.765485835116982, 7.927400699986148, 6.866747449758885, 5.838863484226512, 4.891842959601043, 3.848010666080155, 2.852775512985172, 1.9084873146548023, 2.9303040974314594, 3.935335837430191, 4.865757269652122, 5.912706867097788, 6.87543960746673, 7.934771431595024, 8.89542866613906, 9.866553039656123, 10.84218868846222, 11.79335104950267, 10.87193521850639, 9.823351356396456, 8.877398008540823, 6.995733160755199, 5.937619689978636, 4.914231487349497, 3.9316129998620855, 2.9065839814475742, 1.932099253737777, 0.9349198201461157, 1.9904987689189937, 2.9919479715925927, 3.99951286452026, 5.071109123164202, 6.064505346340347, 7.005640974012839, 7.982501645663113, 8.988331093697933, 10.007747057747853, 10.841950828491033, 9.901098499047638, 8.956531582713279, 7.9905333783384, 6.016293835401299, 5.0046088496661225, 4.043956885000207, 2.9969489134801615, 2.0486537313761444, 0.9897833524756015, 0.0, 1.0198991361400591, 1.9616545416255595, 3.0070600298007673, 4.078627179666041, 5.103373132276585, 6.077666155066388, 7.007084991538133, 8.075123073759116, 9.122752593889263, 10.112017932975503, 9.173754930042962, 8.133760326400735, 7.075140815448919], [8.958660006180146, 9.917635261453077, 10.896972274890288, 10.014982427146213, 8.986747787515165, 8.031633976468306, 7.004290162850329, 5.989406058122698, 5.049748920923598, 4.025322643177993, 2.9720099669969895, 1.9815926126457322, 0.9521840577358004, 1.9479457275398642, 2.9505829539383805, 3.9390605740592766, 4.896446053032868, 5.920818650261143, 6.92174477787, 7.948482374220107, 9.896372090846441, 10.965829097040455, 11.88748515319429, 11.05678382812576, 10.00007052129537, 9.010835894785561, 7.954416866470518, 6.992622438366273, 5.940859812572864, 4.868473508189508, 3.9150778197596283, 3.0438724014587946, 1.989258181846203, 2.910409317867237, 3.863115581315804, 4.9316201273830895, 5.821893730522172, 6.75021557518635, 7.805466499432866, 8.850591746586115, 10.728143333771442, 11.669298473594333, 12.626058065422924, 11.926564220746126, 10.927723787938795, 9.967079507603135, 8.935876905105413, 7.913988395678469, 6.898325406896091, 5.891070686365096, 4.935923513224073, 4.043657711398653, 3.0044738075217357, 3.9662852395151225, 4.811408160908634, 5.750041196434758, 6.699899929639503, 7.7525955232336985, 8.730864650516033, 9.682693980187866, 11.588843466978645, 12.526257531998942, 13.549114877900722, 12.90408499317254, 11.864825481623166, 10.839383522700459, 9.890902745247887, 8.899794210845664, 7.914243860687384, 6.949746406009911, 5.994982325977448, 4.92789997854587, 3.963996697449744, 4.926545137805494, 5.831314116850228, 6.761117465021137, 7.628933840142162, 8.564051915948871, 9.55763106911041, 10.56621375303249, 12.514419118402259, 13.463380738265784, 14.491685794295426, 13.856589849639603, 12.847087403383506, 11.885281539476344, 10.839984042452231, 9.899280643170357, 8.828273445791938, 7.88402897267797, 6.934389003289803, 5.86726967895842, 4.952332493607417, 5.898698338140687, 6.810143363079811, 7.822262327126924, 8.628029701895976, 9.556893051673178, 10.50349385097333, 11.536432568978523, 13.364262217112136, 14.426001907591292, 15.375239804026318, 14.636375423351986, 13.59754596231813, 12.569966175142843, 11.63279072135178, 10.664260960154959, 9.654281407354835, 8.72674759572512, 7.780600704069647, 6.828199302812003, 5.979105462330578, 6.908064410665702, 7.736004978097293, 8.715242500795098, 9.642575501680088, 10.555318038080792, 11.451175878430892, 12.41391915785146, 14.308292959907185, 15.322465008863004, 16.283647485455123, 15.637210765618287, 14.56831769996902, 13.540279617221962, 12.69500139756672, 11.651756160508441, 10.641790494785115, 9.668501503647082, 8.781192532829566, 7.852084909758517, 7.044809233285137, 7.9217335791404855, 8.688484901526332, 9.642664048783047, 10.604829146315147, 11.531179975480686, 12.470731304127284, 13.3433494876143, 15.308399277796081, 16.304747682783404, 16.454861167321624, 15.444983664355714, 14.473427189373107, 13.721297146936179, 12.842859604603817, 11.951413299608742, 11.574976424483053, 10.60997554025774, 9.742498237803686, 8.784014315724132, 8.07797020399798, 8.925419286254982, 9.761843369641438, 10.69672323383882, 11.626309833939459, 12.565265158291481, 13.52129300356477, 14.280435717488846, 16.277818418432954, 16.411669152705507, 15.41796846954607, 14.489930878368044, 13.542666560874075, 12.678966037461093, 11.77633071259383, 10.947365277601152, 11.829500504203384, 11.64819004030782, 10.754541429515458, 9.806377148342127, 9.041856465233723, 9.95348743892054, 10.687717174725764, 11.675394401184887, 12.603111983880451, 13.636630469290514, 14.50970783720976, 15.247874320973928, 16.49379077690245, 15.488651701640258, 14.517948068279832, 13.536822991780639, 12.578934109186763, 11.735327573167094, 10.793123548452721, 9.97068567053314, 10.760694704728273, 11.691349640147756, 11.721060360454802, 10.79588690171776, 10.027563708589689, 10.887207935734857, 11.682449078851086, 12.637512105649295, 13.576895540951206, 14.630918380465578, 15.546604581013948, 16.228562846156958, 15.463507970470793, 14.525918581519853, 13.715225162000454, 12.645859500809223, 11.64519146189435, 10.671563592258227, 9.744704349109721, 8.91887661809129, 9.831730907451174, 10.828083912541132, 11.737307168239228, 11.854260602723267, 11.051584293119852, 11.9588652598019, 12.639682308141223, 13.590490854836329, 14.54094513417922, 15.552567210306272, 16.51751205816026, 16.393342760010604, 14.507450133824188, 13.579497021878545, 12.74210049098777, 11.703480733469574, 10.785277684391508, 9.715529916710283, 8.78286678217921, 7.929168918147822, 8.880966901821171, 9.806088232073177, 10.7859576099417, 11.690904450155383, 12.121268329269514, 13.013170725414806, 13.600343739947961, 14.54953600533261, 15.479743893917616, 16.40655772243096, 16.490472877400602, 15.463055512217103, 13.615897995860076, 12.609933438956192, 11.689758995183215, 10.670173839991397, 9.772410830107127, 8.765374873780312, 7.835604815356791, 6.8867530444662215, 7.8557697605095065, 8.869814219642745, 9.83784085787103, 10.763367188010658, 11.74040305772705, 12.783145180992348, 13.674943258058923, 14.71834620437165, 15.670945478954955, 16.594175427496207, 15.544456304546797, 14.658809431361673, 12.641730638107347, 11.669665869382342, 10.649083526092168, 9.680964026333315, 8.819591268016774, 7.819333001637494, 6.870681278037814, 5.933006881939484, 6.972025150335277, 7.938689761018697, 8.806538124364794, 9.84997948995541, 10.804217331771428, 11.81900225247766, 12.739000377165357, 13.757595033162229, 14.741302540100897, 15.559199598753974, 14.565776528138015, 13.61920708760406, 11.66884868720611, 10.72732330636055, 9.68086202534128, 8.684667196102351, 7.848765253941628, 6.852718996017861, 5.965925630810727, 4.952606359785042, 5.907896250883653, 6.876574073677078, 7.835219072748236, 8.886825664953903, 9.780123928496867, 10.848034832667965, 11.77483428032022, 12.83168708004984, 13.78519781225287, 14.596934333141506, 13.653028553852382, 12.615867900078811, 10.764021419400265, 9.850332059631791, 8.797855412694942, 7.753796880889527, 6.853016428004742, 5.9206926262982735, 4.991861710743819, 3.9924438151766246, 4.995931784994131, 5.967518992257907, 6.918480522718944, 7.9668814304362545, 8.84282607596634, 9.840724176532296, 10.838869290653083, 11.804350874710897, 12.783975187748064, 13.742931819981584, 12.731688875932024, 11.809865115976121, 9.763686749347173, 8.817865920249726, 7.839959044817807, 6.7811309779824, 5.849268986069374, 4.8458889887345125, 4.002243002330641, 3.0290971991999465, 4.001541050083666, 4.968445256294757, 5.964915887432267, 6.923760665750583, 7.884285139092517, 8.896706045825926, 9.896739986430132, 10.831414512263052, 11.784893078175605, 12.745923925383693, 11.760608385513931, 10.785384971257042, 8.947299836126206, 7.886646585898943, 6.85876262036657, 5.911742095741101, 4.867909802220214, 3.872674649125231, 2.928386450794861, 1.9666642185691705, 2.9716959585679024, 3.902117390789833, 4.949066988235499, 5.911799728604441, 6.971131552732736, 7.931788787276771, 8.902913160793835, 9.878548809599932, 10.829711170640381, 11.885414281703374, 10.843250492536514, 9.89729714468088, 8.015632296895257, 6.957518826118694, 5.934130623489556, 4.951512136002144, 3.926483117587633, 2.9519983898778364, 1.9548189562861749, 0.9705996327789346, 1.9720488354525338, 2.979613728380201, 4.051209987024144, 5.044606210200289, 5.985741837872781, 6.962602509523055, 7.968431957557876, 8.987847921607795, 10.007074905581824, 10.920997635187696, 9.976430718853337, 9.010432514478458, 7.036192971541359, 6.024507985806182, 5.063856021140267, 4.016848049620221, 3.0685528675162037, 2.0096824886156606, 1.0198991361400591, 0.0, 0.9417554054855004, 1.9871608936607084, 3.0587280435259827, 4.083473996136527, 5.05776701892633, 5.987185855398075, 7.055223937619057, 8.102853457749205, 9.092118796835445, 10.156753393309641, 9.153659462540794, 8.095039951588978], [9.900415411665648, 10.859390666938578, 10.064102163133295, 9.073227021660713, 8.044992382029665, 7.0898785709828065, 6.062534757364829, 5.0476506526371985, 4.107993515438098, 3.0835672376924927, 2.030254561511489, 1.0398372071602318, 1.893939463221301, 2.8897011330253646, 3.892338359423881, 4.880815979544777, 5.838201458518368, 6.862574055746643, 7.8635001833555, 8.890237779705608, 10.838127496331941, 11.907584502525955, 11.054615041437298, 10.11502842264026, 9.058315115809872, 8.069080489300061, 7.012661460985018, 6.050867032880772, 4.999104407087363, 3.9267181027040072, 2.973322414274128, 2.1021169959732937, 2.9310135873317034, 3.8521647233527374, 4.804870986801305, 5.8733755328685895, 6.763649136007672, 7.69197098067185, 8.747221904918366, 9.792347152071615, 11.669898739256942, 12.611053879079833, 11.950974535424281, 10.984808815260628, 9.985968382453297, 9.025324102117636, 7.994121499619913, 6.972232990192969, 5.95657000141059, 4.9493152808795955, 3.9941681077385724, 3.101902305913153, 3.946229213007236, 4.908040645000623, 5.753163566394135, 6.691796601920259, 7.641655335125004, 8.6943509287192, 9.672620056001533, 10.624449385673365, 12.530598872464147, 13.468012937484444, 12.89093860719169, 11.962329587687039, 10.923070076137664, 9.897628117214957, 8.949147339762385, 7.958038805360164, 6.9724884552018835, 6.00799100052441, 5.053226920491947, 4.0902671717338, 4.905752102935245, 5.868300543290996, 6.773069522335728, 7.7028728705066385, 8.570689245627664, 9.505807321434373, 10.499386474595912, 11.507969158517993, 13.45617452388776, 14.405136143751285, 13.943890273294224, 12.914834444154101, 11.905331997898005, 10.95358681037896, 9.962609777344696, 9.021906378062821, 7.964614565326256, 7.046396165865899, 6.096756196477732, 5.02963687214635, 5.894087899092918, 6.840453743626188, 7.751898768565311, 8.764017732612427, 9.569785107381477, 10.49864845715868, 11.445249256458832, 12.478187974464024, 14.306017622597638, 15.367757313076794, 14.724129534183755, 13.798742616539915, 12.759913155506059, 11.732333368330773, 10.79515791453971, 9.826628153342888, 8.816648600542765, 7.88911478891305, 6.942967897257576, 5.990566495999932, 6.92086086781608, 7.849819816151204, 8.677760383582793, 9.656997906280598, 10.584330907165588, 11.497073443566293, 12.392931283916393, 13.355674563336962, 15.250048365392686, 16.264220414348507, 15.797949615096357, 14.799577958806216, 13.73068489315695, 12.702646810409892, 11.85736859075465, 10.81412335369637, 9.804157687973044, 8.830868696835012, 7.943559726017496, 7.014452102946446, 7.986564638770639, 8.863488984625988, 9.630240307011832, 10.584419454268549, 11.546584551800647, 12.472935380966188, 13.412486709612786, 14.285104893099803, 16.250154683281583, 17.24650308826891, 16.737474719984863, 15.727597217018953, 14.756040742036346, 13.728797637346888, 12.83366003764553, 11.795505337629535, 10.737343617670982, 9.772342733445669, 8.904865430991615, 7.946381508912061, 8.900286115064644, 9.867174691740484, 10.703598775126938, 11.638478639324322, 12.56806523942496, 13.507020563776983, 14.463048409050272, 15.222191122974348, 17.219573823918456, 17.353424558191005, 16.35972387503157, 15.431686283853546, 14.484421966359577, 13.620721442946595, 12.718086118079333, 11.889120683086654, 11.22454195749609, 10.81055723349575, 9.916908622703387, 8.968744341530055, 9.864172376300386, 10.803570981358119, 11.629472580211264, 12.617149806670387, 13.544867389365951, 14.578385874776016, 15.451463242695262, 16.18962972645943, 17.435546182387952, 16.43040710712576, 15.459703473765334, 14.47857839726614, 13.520689514672265, 12.677082978652596, 11.734878953938223, 10.912441076018641, 10.155736158020979, 11.062499769373188, 10.88342755364273, 9.958254094905687, 10.849879619656353, 11.737291478172436, 12.624204484336586, 13.579267511134795, 14.518650946436706, 15.57267378595108, 16.48835998649945, 17.17031825164246, 16.405263375956295, 15.467673987005355, 14.656980567485956, 13.587614906294725, 12.586946867379853, 11.613318997743729, 10.686459754595223, 9.860632023576791, 9.22677236074388, 10.101791407621816, 11.011014663319912, 11.016627795911194, 11.873900204186516, 12.80894880223948, 13.581437713626723, 14.532246260321829, 15.48270053966472, 16.494322615791774, 17.459267463645762, 17.335098165496106, 15.44920553930969, 14.521252427364047, 13.683855896473272, 12.645236138955076, 11.72703308987701, 10.657285322195785, 9.724622187664712, 8.870924323633325, 8.276008355113877, 9.079795727153861, 10.059665105022384, 10.898538069864042, 11.890657657916961, 12.896267413290225, 13.810102073563565, 14.759294338948214, 15.797088869269077, 16.72390269778242, 17.432228282886104, 16.404810917702605, 14.557653401345577, 13.551688844441694, 12.631514400668717, 11.6119292454769, 10.714166235592629, 9.707130279265813, 8.777360220842294, 7.828508449951723, 7.250811213802214, 8.077447839351404, 9.045474477579688, 9.971000807719317, 10.844416386206444, 11.88715850947174, 12.778956586538316, 13.822359532851044, 14.774958807434349, 15.763659190729028, 16.4862117100323, 15.600564836847175, 13.583486043592849, 12.611421274867844, 11.59083893157767, 10.622719431818817, 9.761346673502276, 8.761088407122996, 7.812436683523316, 6.874762287424986, 6.263839503835046, 7.146323380727356, 8.004748327265942, 9.048189692856559, 9.90823066025082, 10.923015580957053, 11.84301370564475, 12.843280184871848, 13.826987691810515, 14.815675068895095, 15.507531933623516, 14.560962493089562, 12.610604092691611, 11.669078711846051, 10.622617430826782, 9.626422601587853, 8.790520659427129, 7.794474401503362, 6.9076810362962275, 5.894361765270543, 5.199710604383422, 6.084207693385737, 7.033429275649384, 8.061987735509923, 8.88413725697626, 9.952048161147358, 10.878847608799614, 11.917372231759458, 12.87088296396249, 13.87598399947886, 14.594783959337883, 13.557623305564313, 11.705776824885767, 10.792087465117293, 9.739610818180443, 8.695552286375028, 7.794771833490243, 6.862448031783774, 5.933617116229319, 4.9341992206621255, 4.139665788975454, 5.07905188863766, 6.030013419098697, 7.078414326816008, 7.946839404445732, 8.944737505011688, 9.942882619132474, 10.890036026420518, 11.869660339457685, 12.828616971691204, 13.673444281417526, 12.751620521461623, 10.705442154832674, 9.759621325735228, 8.781714450303308, 7.722886383467901, 6.791024391554875, 5.787644394220013, 4.943998407816141, 3.9708526046854473, 3.145275054064989, 4.07997815267451, 5.07644878381202, 6.035293562130336, 6.988298467571909, 8.000719374305318, 9.000753314909524, 9.917099663972673, 10.870578229885226, 11.900472105570318, 12.702363790999433, 11.727140376742543, 9.889055241611707, 8.828401991384446, 7.800518025852072, 6.853497501226602, 5.809665207705715, 4.814430054610732, 3.8701418562803616, 2.908419624054671, 2.0832288549476554, 3.013650287169586, 4.060599884615252, 5.023332624984194, 6.0568167044423555, 7.017473938986391, 7.988598312503456, 8.964233961309553, 9.915396322350002, 10.971099433412995, 11.785005898022016, 10.839052550166382, 8.957387702380759, 7.8992742316041955, 6.875886028975057, 5.893267541487646, 4.868238523073134, 3.8937537953633368, 2.896574361771675, 1.912355038264435, 1.0302934299670334, 2.0378583228947007, 3.1094545815386434, 4.102850804714788, 5.04398643238728, 6.020847104037554, 7.0266765520723755, 8.046092516122295, 9.065319500096324, 10.006171829539719, 10.918186124338838, 9.95218791996396, 7.977948377026859, 6.966263391291682, 6.005611426625767, 4.958603455105721, 4.010308273001704, 2.951437894101161, 1.9616545416255595, 0.9417554054855004, 0.0, 1.045405488175208, 2.1169726380404823, 3.141718590651026, 4.116011613440829, 5.045430449912574, 6.113468532133556, 7.1610980522637036, 8.150363391349943, 9.21499798782414, 10.095414868026294, 9.036795357074478], [10.945820899840857, 10.005478419600964, 9.026141406163752, 8.035266264691172, 7.007031625060123, 6.0519178140132635, 5.024574000395286, 4.0265834413029955, 3.086926304103895, 2.0625000263582898, 1.0091873501772861, 1.9996047045285434, 2.939344951396509, 3.935106621200572, 4.937743847599089, 5.926221467719985, 6.883606946693576, 7.9079795439218525, 8.90890567153071, 9.935643267880817, 11.88353298450715, 11.036153347126719, 10.016654284467755, 9.077067665670718, 8.02035435884033, 7.031119732330518, 5.974700704015475, 5.029799821546569, 3.97803719575316, 2.9056508913698043, 1.952255202939925, 2.912297276645076, 3.9711072163720966, 4.8975702115279445, 5.8502764749765115, 6.918781021043797, 7.80905462418288, 8.737376468847058, 9.792627393093575, 10.837752640246824, 12.715304227432151, 11.86977337028333, 10.913013778454738, 9.946848058291085, 8.948007625483754, 8.00425689078343, 6.973054288285709, 5.9511657788587655, 4.935502790076387, 3.9282480695453925, 2.9731008964043695, 3.90389388519354, 4.956164114764781, 5.952138949202475, 6.798569054569342, 7.737202090095465, 8.687060823300211, 9.739756416894407, 10.718025544176742, 11.669854873848575, 13.576004360639352, 12.880863309404532, 11.869871395857487, 10.941262376352837, 9.902002864803462, 8.876560905880755, 7.928080128428182, 6.936971594025961, 5.951421243867681, 4.986923789190207, 4.032159709157744, 4.892258751014188, 5.856162032110314, 6.818710472466064, 7.8184750105109355, 8.748278358681844, 9.61609473380287, 10.551212809609579, 11.544791962771118, 12.553374646693198, 14.501580012062966, 13.819877231382183, 12.922823061960022, 11.893767232819899, 10.884264786563802, 9.932519599044758, 8.941542566010494, 8.00083916672862, 6.943547353992053, 6.0370154058779635, 5.087375436489796, 5.831628451426738, 6.844497828267987, 7.790863672801256, 8.797304256740517, 9.809423220787632, 10.615190595556683, 11.544053945333886, 12.490654744634037, 13.52359346263923, 15.351423110772844, 14.732219541703254, 13.782981645268228, 12.857594727624388, 11.818765266590532, 10.791185479415246, 9.854010025624182, 8.885480264427361, 7.875500711627239, 7.005487220730702, 6.059340329075229, 6.79255807528032, 7.783077046818481, 8.712035995153606, 9.689846365078736, 10.66908388777654, 11.596416888661532, 12.542478931741499, 13.4383367720916, 14.401080051512167, 16.295453853567892, 15.731054877789227, 14.85680172618083, 13.858430069890689, 12.789537004241422, 11.761498921494365, 10.916220701839123, 9.905971653292227, 8.8960059875689, 7.9472411286526645, 7.080804415042704, 7.816443682226835, 8.7986115233984, 9.72570516362839, 10.642326288507775, 11.596505435764492, 12.55867053329659, 13.518340869141394, 14.457892197787992, 15.330510381275008, 17.29556017145679, 16.71333755170963, 15.796326831069335, 14.786449328103426, 13.814892853120819, 12.787649748431361, 11.892512148730003, 10.887353637225392, 9.853716049488636, 8.888715165263323, 8.042110120016822, 8.74837308819245, 9.702277694345032, 10.729390870742886, 11.715684756622881, 12.650564620820266, 13.580151220920904, 14.519106545272926, 15.508453897225477, 16.267596611149553, 18.26497931209366, 17.61465607345128, 16.620955390291844, 15.69291779911382, 14.74565348161985, 13.79498891827234, 12.858707821041701, 11.831449631656985, 10.86687899563748, 9.926929665313402, 9.054153311728594, 9.770735920810445, 10.666163955580775, 11.605562560638507, 12.634873729545482, 13.622550956004606, 14.55026853870017, 15.590471856271959, 16.496868730870467, 17.235035214634635, 18.48095167056316, 17.47581259530097, 16.505108961940543, 15.523983885441348, 14.566095002847472, 13.722488466827803, 12.780284442113429, 11.957846564193849, 10.97986346967639, 10.15771837873661, 10.022744308541226, 10.760245674186077, 11.65187119893674, 12.539283057452824, 13.526269649685752, 14.522096087389615, 15.461479522691526, 16.535738151041045, 17.533765474674656, 18.215723739817665, 17.4506688641315, 16.51307947518056, 15.702386055661165, 14.633020394469934, 13.63235235555506, 12.658724485918937, 11.731865242770429, 10.906037511751999, 10.050899672399291, 9.197010016985237, 10.106233272683333, 11.017428227246779, 11.914936205891415, 12.905167390727925, 13.725358017195095, 14.6761665638902, 15.660479964612723, 16.672102040739777, 17.58810344514037, 18.380503653671312, 16.494611027484893, 15.566657915539253, 14.729261384648478, 13.690641627130281, 12.772438578052217, 11.702690810370992, 10.77002767583992, 9.916329811808533, 9.100135666769289, 8.175014336517282, 9.154883714385806, 9.962459188497494, 10.845252169741753, 11.85086192511502, 12.764696585388357, 13.713888850773007, 14.75168338109387, 15.678497209607212, 16.65275052203224, 17.45021640587781, 15.603058889520783, 14.5970943326169, 13.676919888843923, 12.657334733652105, 11.759571723767834, 10.752535767441021, 9.822765709017501, 8.87391393812693, 8.19247709546258, 7.172666448714825, 8.10939559621314, 9.03492192635277, 9.799010898031236, 10.841753021296533, 11.733551098363108, 12.776954044675836, 13.729553319259141, 14.71825370255382, 15.767972825503232, 16.64597032502238, 14.628891531768055, 13.65682676304305, 12.636244419752876, 11.668124919994023, 10.806752161677482, 9.806493895298203, 8.857842171698524, 7.920167775600193, 7.212233024994208, 6.241541990090778, 7.049943674497065, 8.093385040087682, 8.862825172075613, 9.877610092781845, 10.797608217469543, 11.797874696696642, 12.78158220363531, 13.770269580719889, 14.810814199462623, 15.606367981264768, 13.656009580866817, 12.714484200021257, 11.668022919001988, 10.671828089763059, 9.835926147602335, 8.839879889678569, 7.953086524471435, 6.93976725344575, 6.148104125542584, 5.179426302749159, 6.078624622880508, 7.0816226336733274, 7.838731768801052, 8.90664267297215, 9.833442120624406, 10.871966743584252, 11.825477475787283, 12.830578511303653, 13.774484290592778, 14.603028793739519, 12.751182313060973, 11.837492953292498, 10.785016306355649, 9.740957774550234, 8.84017732166545, 7.907853519958982, 6.979022604404527, 5.979604708837333, 5.095727262782737, 4.174270498001082, 5.075208766329821, 6.098049224979411, 6.901433916270524, 7.89933201683648, 8.897477130957267, 9.84463053824531, 10.824254851282477, 11.783211483515997, 12.811462647682966, 13.797026009636829, 11.75084764300788, 10.805026813910434, 9.827119938478514, 8.768291871643108, 7.836429879730082, 6.833049882395221, 5.989403895991349, 5.016258092860655, 4.101336527872272, 3.1751967620379316, 4.121644131043143, 5.054395553153325, 5.942892979396701, 6.95531388613011, 7.955347826734317, 8.871694175797465, 9.82517274171002, 10.855066617395112, 11.840382157264873, 12.772545864917749, 10.934460729786913, 9.873807479559652, 8.845923514027279, 7.89890298940181, 6.855070695880922, 5.859835542785939, 4.915547344455569, 3.953825112229879, 3.039290328754938, 2.1088688965330076, 3.1057952318463755, 4.042434616007183, 5.011411216267148, 5.972068450811183, 6.943192824328248, 7.918828473134346, 8.869990834174796, 9.92569394523779, 10.924604941240945, 11.826564385801602, 10.002793190555966, 8.944679719779403, 7.921291517150265, 6.938673029662853, 5.9136440112483415, 4.939159283538545, 3.941979849946883, 2.957760526439643, 2.0756989181422414, 1.0729186574829326, 2.0910505231128127, 3.083296957209426, 3.9985809442120726, 4.975441615862347, 5.981271063897168, 7.0006870279470865, 8.019914011921117, 8.960766341364511, 9.90533325769887, 10.87133146207375, 9.023353865202067, 8.01166887946689, 7.051016914800975, 6.00400894328093, 5.0557137611769125, 3.996843382276369, 3.0070600298007673, 1.9871608936607084, 1.045405488175208, 0.0, 1.0715671498652743, 2.0963131024758184, 3.0706061252656216, 4.000024961737367, 5.0680630439583485, 6.115692564088496, 7.104957903174736, 8.169592499648932, 9.20958710329116, 10.082200845249686], [9.89288652500862, 8.93391126973569, 7.954574256298478, 6.963699114825896, 5.935464475194848, 4.980350664147989, 3.953006850530011, 3.0265515705608985, 2.086894433361798, 1.070164145367303, 2.0807545000425605, 3.0711718543938176, 4.010912101261783, 5.006673771065847, 6.009310997464364, 6.997788617585259, 7.95517409655885, 8.979546693787126, 9.980472821395983, 10.90306415696866, 10.911792302655197, 9.964586197261445, 8.945087134602481, 8.005500515805442, 6.9487872089750535, 5.9595525824652436, 4.9031335541502, 4.076199526422889, 3.1424402397548876, 2.10697174255513, 3.0238223528051993, 3.98386442651035, 5.042674366237371, 5.969137361393219, 6.921843624841786, 7.990348170909071, 8.880621774048155, 9.808943618712332, 10.864194542958849, 11.909319790112098, 11.739361360240943, 10.798206220418052, 9.84144662858946, 8.875280908425808, 7.876440475618478, 6.937066255983442, 5.90586365348572, 5.135492409897631, 4.136823641261713, 3.1295689207307182, 4.044668046269644, 4.975461035058814, 6.027731264630055, 7.023706099067749, 7.870136204434616, 8.80876923996074, 9.758627973165485, 10.81132356675968, 11.789592694042016, 12.741422023713849, 12.746710224559552, 11.809296159539254, 10.82529054989954, 9.925635182920786, 8.886375671371411, 7.860933712448704, 6.912452934996132, 6.138292445211286, 5.152742095053006, 4.188244640375533, 5.103726859023018, 5.963825900879462, 6.927729181975588, 7.890277622331338, 8.89004216037621, 9.819845508547118, 10.687661883668143, 11.622779959474853, 12.616359112636392, 13.624941796558472, 13.672285875983166, 12.748310081516905, 11.881272189444473, 10.878140039387848, 9.868637593131751, 8.916892405612707, 7.966423006055885, 7.202160017913945, 6.144868205177379, 5.254783276220229, 6.15894258635507, 6.903195601292012, 7.916064978133261, 8.86243082266653, 9.868871406605791, 10.880990370652906, 11.686757745421957, 12.61562109519916, 13.562221894499311, 14.595160612504504, 14.680387969379188, 13.72465470486485, 12.775416808429824, 11.850029890785985, 10.811200429752128, 9.948274196708553, 9.01109874291749, 8.086801115612687, 7.076821562812564, 6.303724664148144, 7.130907478940503, 7.864125225145594, 8.854644196683756, 9.78360314501888, 10.76141351494401, 11.740651037641815, 12.667984038526805, 13.614046081606773, 14.509903921956873, 15.472647201377441, 15.624418712174236, 14.723490040950823, 13.849236889342427, 12.850865233052286, 11.78197216740302, 10.918587638787672, 10.07330941913243, 9.107292504477552, 8.097326838754226, 7.245478572070107, 8.152371564907977, 8.888010832092109, 9.870178673263673, 10.797272313493664, 11.713893438373049, 12.668072585629766, 13.630237683161864, 14.589908019006668, 15.529459347653265, 16.402077531140282, 16.635650085458828, 15.705772714871225, 14.788761994230931, 13.778884491265023, 12.807328016282415, 11.944738465724669, 11.04960086602331, 10.088674488410717, 9.060246603639547, 8.186952608680764, 9.113677269882096, 9.819940238057724, 10.773844844210306, 11.80095802060816, 12.787251906488155, 13.72213177068554, 14.651718370786178, 15.5906736951382, 16.580021047090753, 17.339163761014827, 17.6050692260957, 16.607091236612877, 15.613390553453442, 14.685352962275417, 13.738088644781447, 12.987069575199754, 12.071439241687091, 11.044181052302376, 10.07961041628287, 9.225167108730844, 10.125720461593868, 10.842303070675719, 11.737731105446048, 12.677129710503781, 13.706440879410756, 14.69411810586988, 15.621835688565444, 16.66203900613723, 17.56843588073574, 18.30660236449991, 18.543148928855928, 17.593853802877277, 16.64083505556183, 15.659709979062635, 14.701821096468759, 13.930708039493753, 12.962995452974805, 12.020860659370388, 11.101582521463381, 10.170927586043899, 10.014035256770773, 10.939208715507815, 11.867389640556304, 12.813998180886836, 13.611024096619957, 14.60685053432382, 15.546233969625732, 16.62049259797525, 17.58281929499147, 18.511293181510695, 18.436973249826114, 17.58464662504584, 16.652288988193842, 15.58292332700261, 14.582255288087737, 13.608627418451613, 12.681768175303105, 11.781067784991127, 10.815188333107177, 9.961298677693122, 9.038645455711489, 9.945861077381505, 10.843369056026141, 11.833600240862651, 12.65379086732982, 13.604599414024925, 14.588912814747447, 15.6005348908745, 16.516536295275095, 17.494588448838336, 17.56420611574338, 16.63822506540453, 15.800828534513755, 14.762208776995559, 13.722341510584894, 12.652593742903669, 11.719930608372596, 10.86623274434121, 9.864424327477174, 8.939302997225168, 8.087295897413961, 8.89089203863222, 9.77368501987648, 10.779294775249745, 11.693129435523081, 12.64232170090773, 13.680116231228594, 14.606930059741936, 15.581183372166963, 16.608600737350464, 16.653505414317724, 15.668661482482177, 14.7484870387092, 13.728901883517382, 12.712190255350402, 11.702438699973698, 10.772668641550178, 9.823816870659607, 8.956765756170464, 7.936955109422709, 7.037828446347866, 7.9633547764874955, 8.727443748165962, 9.77018587143126, 10.661983948497832, 11.70538689481056, 12.657986169393865, 13.646686552688545, 14.696405675637957, 15.665975030885523, 15.654162951202766, 14.728393912908327, 13.707811569618153, 12.7396920698593, 11.771058946402853, 10.75639682783088, 9.8077451042312, 8.87007070813287, 7.99850919433144, 7.0058306507986625, 5.978376524631791, 7.021817890222408, 7.7912580222103385, 8.806042942916571, 9.726041067604267, 10.726307546831364, 11.710015053770032, 12.698702430854611, 13.739247049597346, 14.6858164901313, 14.681281000301528, 13.786051349886534, 12.739590068867265, 11.743395239628336, 10.87313453605643, 9.877088278132664, 8.91416514526863, 7.889670185978428, 6.9343802948798166, 5.965702472086392, 5.007057473015234, 6.010055483808053, 6.7671646189357775, 7.835075523106875, 8.76187497075913, 9.800399593718975, 10.753910325922007, 11.759011361438377, 12.702917140727502, 13.734261787428826, 13.671435862813373, 12.909060103157776, 11.856583456220926, 10.812524924415511, 9.911744471530728, 8.979420669824258, 8.008853673193622, 7.009435777626429, 6.068036045676497, 5.04421709402056, 4.003641616464547, 5.026482075114136, 5.8298667664052495, 6.827764866971204, 7.825909981091991, 8.773063388380034, 9.752687701417202, 10.711644333650721, 11.73989549781769, 12.72634449597887, 12.67110119276028, 11.87659396377571, 10.898687088343792, 9.839859021508385, 8.907997029595359, 7.9046170322604965, 7.060971045856625, 6.046089161649751, 5.0736453107660315, 4.118205204390842, 3.0500769811778694, 3.9828284032880505, 4.871325829531426, 5.883746736264834, 6.8837806768690415, 7.8001270259321895, 8.753605591844744, 9.783499467529836, 10.768815007399597, 11.744038421656487, 11.704994544491, 10.945374629424927, 9.917490663892554, 8.970470139267086, 7.926637845746198, 6.931402692651215, 5.987114494320845, 5.016630851647429, 4.011599111648698, 3.0811776794267667, 2.034228081981101, 2.9708674661419083, 3.9398440664018732, 4.900501300945908, 5.8716256744629725, 6.847261323269071, 7.79842368430952, 8.854126795372514, 9.85303779137567, 10.754997235936326, 10.794564529791675, 10.016246869644677, 8.992858667015538, 8.010240179528127, 6.985211161113616, 6.0107264334038195, 5.013546999812158, 4.029327676304917, 3.0986445248191483, 2.091079631891481, 1.0194833732475381, 2.0117298073441514, 2.9270137943467978, 3.903874465997072, 4.909703914031893, 5.929119878081812, 6.948346862055841, 7.889199191499236, 8.833766107833595, 9.799764312208474, 10.09492101506734, 9.083236029332165, 8.122584064666249, 7.0755760931462035, 6.127280911042186, 5.068410532141644, 4.078627179666042, 3.0587280435259827, 2.1169726380404823, 1.0715671498652743, 0.0, 1.0247459526105438, 1.9990389754003468, 2.928457811872092, 3.9964958940930737, 5.044125414223221, 6.03339075330946, 7.098025349783656, 8.138019953425884, 9.1966394643777], [8.868140572398078, 7.909165317125147, 6.929828303687935, 5.938953162215354, 4.910718522584305, 3.955604711537445, 2.9282608979194675, 2.001805617950355, 1.0621484807512545, 2.0865747584968597, 3.1055004526531045, 4.095917807004362, 5.035658053872327, 6.0314197236763905, 7.034056950074907, 8.022534570195804, 8.979920049169396, 10.004292646397671, 10.905055800708226, 9.878318204358118, 9.887046350044654, 8.939840244650902, 7.9203411819919385, 6.9807545631949, 5.92404125636451, 4.9348066298547, 3.8783876015396563, 3.0514535738123456, 2.117694287144344, 3.1233823556846865, 4.048568305415743, 5.008610379120894, 6.0674203188479146, 6.993883314003763, 7.94658957745233, 9.015094123519615, 9.9053677266587, 10.833689571322877, 11.888940495569393, 10.93282669430498, 10.714615407630399, 9.773460267807508, 8.816700675978918, 7.850534955815265, 6.851694523007934, 5.912320303372899, 4.881117700875176, 4.110746457287087, 3.134131478850449, 4.141386199381444, 5.069413998880187, 6.000206987669357, 7.0524772172405985, 8.048452051678293, 8.89488215704516, 9.833515192571284, 10.78337392577603, 11.836069519370225, 12.711894090885808, 11.760064761213975, 11.721964271949007, 10.78455020692871, 9.800544597288997, 8.900889230310241, 7.861629718760867, 6.83618775983816, 5.8877069823855885, 5.135600282800023, 4.150049932641743, 5.126775323476207, 6.127226369173114, 6.988571853490005, 7.952475134586131, 8.915023574941882, 9.914788112986754, 10.844591461157663, 11.712407836278688, 12.647525912085397, 13.641105065246936, 12.744593985895161, 12.647539923372621, 11.72356412890636, 10.856526236833933, 9.853394086777303, 8.843891640521207, 7.892146453002162, 6.941677053445342, 6.1994678555026805, 5.142176042766115, 6.086420515880083, 7.0360604852682505, 7.927941553902555, 8.940810930743805, 9.887176775277075, 10.893617359216336, 11.90573632326345, 12.711503698032502, 13.640367047809704, 14.586967847109856, 13.701282742964596, 13.655642016768644, 12.699908752254306, 11.75067085581928, 10.82528393817544, 9.786454477141584, 8.92352824409801, 7.986352790306946, 7.084108953201423, 6.074129400401301, 7.001663212031016, 7.947810103686489, 8.888871177756137, 9.879390149294299, 10.808349097629423, 11.786159467554553, 12.765396990252357, 13.692729991137348, 14.638792034217317, 15.534649874567418, 14.60598507602932, 14.599672759563692, 13.698744088340279, 12.824490936731882, 11.826119280441741, 10.757226214792475, 9.89384168617713, 9.048563466521886, 8.104600342066288, 7.094634676342961, 7.943417119952978, 8.969274189653964, 9.898381812725013, 10.880549653896578, 11.822018266104207, 12.738639390983591, 13.692818538240306, 14.654983635772407, 15.614653971617212, 16.467970327359236, 15.535415405792161, 15.610904132848283, 14.68102676226068, 13.764016041620387, 12.754138538654479, 11.782582063671871, 10.919992513114126, 10.024854913412765, 9.085982325999453, 8.057554441228282, 8.884891156563636, 9.841492209923151, 10.830311218690628, 11.784215824843212, 12.825703973218703, 13.811997859098698, 14.74687772329608, 15.676464323396718, 16.61541964774874, 17.45849854307639, 16.472501635666706, 16.580323273485156, 15.582345284002335, 14.588644600842898, 13.660607009664872, 12.713342692170903, 11.962323622589212, 11.068747079275827, 10.041488889891111, 9.076918253871606, 9.923105656613718, 10.853535401634923, 11.024242364936692, 11.828350931301726, 12.722972725090608, 13.581010048134736, 14.544222286177686, 15.47193986887325, 16.54551490720722, 17.594970086185114, 17.439940239151788, 17.518402976245383, 16.569107850266736, 15.616089102951285, 14.63496402645209, 13.677075143858215, 12.90596208688321, 11.960303290563541, 11.018168496959124, 10.145724053346717, 10.868866133926772, 10.852878541408499, 10.03473261156106, 10.84264368794576, 11.789252228276291, 12.586278144009414, 13.582104581713278, 14.521488017015189, 15.59574664536471, 16.558073342380926, 17.48654722890015, 17.41222729721557, 17.542174614330833, 16.598054948247906, 15.6114858300655, 14.610817791150627, 13.969726067792077, 13.00872248990654, 12.040567302507766, 11.074687850623816, 10.835924849612327, 9.877488740349214, 8.976358910555552, 9.818623103415598, 10.808854288252107, 11.629044914719277, 12.579853461414382, 13.564166862136904, 14.575788938263956, 15.491790342664551, 16.46984249622779, 16.539460163132837, 17.467413275078478, 16.682975165896032, 15.644355408377834, 14.596967682504099, 13.527219914822874, 12.594556780291802, 11.740858916260414, 10.73905049939638, 9.813929169144373, 8.926139182051687, 7.921389871806267, 8.748939067265937, 9.754548822639201, 10.668383482912539, 11.617575748297188, 12.65537027861805, 13.582184107131393, 14.55643741955642, 15.583854784739922, 15.62875946170718, 16.549079357793126, 15.674446350731648, 14.652125215427382, 13.586816427269607, 12.577064871892903, 11.647294813469383, 10.698443042578813, 9.83139192808967, 8.811581281341915, 7.912454618267072, 6.993852609661543, 7.702697795555419, 8.745439918820715, 9.63723799588729, 10.680640942200018, 11.633240216783323, 12.621940600078002, 13.671659723027414, 14.64122907827498, 14.629416998592223, 15.608811788219278, 14.6337708816406, 13.665651381881748, 12.645685118322058, 11.631022999750085, 10.682371276150405, 9.744696880052075, 8.873135366250645, 7.880456822717868, 6.8530026965509965, 6.013278150284203, 6.766512069599795, 7.781296990306027, 8.701295114993725, 9.701561594220824, 10.685269101159491, 11.67395647824407, 12.714501096986805, 13.661070537520759, 13.656535047690985, 14.598060428536545, 13.665549380889713, 12.669354551650784, 11.747760707975635, 10.75171445005187, 9.788791317187835, 8.764296357897633, 7.809006466799022, 6.840328644005597, 5.881683644934439, 4.985309531197509, 5.742418666325234, 6.810329570496332, 7.737129018148588, 8.775653641108434, 9.729164373311464, 10.734265408827834, 11.67817118811696, 12.709515834818284, 12.64668991020283, 13.637339074609004, 12.782542768243374, 11.738484236437959, 10.837703783553176, 9.905379981846705, 8.883479845112829, 7.884061949545635, 6.942662217595703, 5.918843265939765, 4.878267788383752, 4.001736122503592, 4.805120813794706, 5.803018914360662, 6.801164028481448, 7.748317435769492, 8.727941748806659, 9.686898381040178, 10.715149545207147, 11.701598543368327, 11.646355240149738, 12.592176069247184, 11.82464640036624, 10.765818333530833, 9.833956341617807, 8.830576344282944, 7.9436261883710975, 6.920715333568957, 5.948271482685238, 4.992831376310047, 3.9247031530970746, 2.958082450677507, 3.8465798769208828, 4.859000783654292, 5.859034724258499, 6.775381073321647, 7.7288596392342015, 8.758753514919293, 9.744069054789055, 10.719292469045945, 10.680248591880458, 11.74090184210772, 10.843449975915002, 9.896429451289533, 8.852597157768646, 7.857362004673663, 6.913073806343293, 5.891257023566636, 4.886225283567904, 3.955803851345973, 2.908854253900307, 1.9461215135313648, 2.9150981137913297, 3.875755348335365, 4.84687972185243, 5.822515370658528, 6.773677731698977, 7.82938084276197, 8.828291838765125, 9.730251283325783, 9.769818577181132, 10.827932047957695, 10.017604619626082, 9.034986132138672, 8.00995711372416, 7.035472386014363, 6.038292952422701, 5.054073628915461, 4.059541229481362, 3.051976336553695, 1.9803800779097525, 0.9869838547336078, 1.9022678417362542, 2.8791285133865285, 3.8849579614213496, 4.904373925471268, 5.923600909445298, 6.864453238888693, 7.809020155223052, 8.775018359597931, 9.230740491814775, 10.107981981942709, 9.147330017276794, 8.100322045756748, 7.152026863652731, 6.093156484752187, 5.103373132276586, 4.083473996136527, 3.1417185906510263, 2.0963131024758184, 1.0247459526105438, 0.0, 0.974293022789803, 1.9037118592615483, 2.97174994148253, 4.019379461612678, 5.008644800698917, 6.073279397173113, 7.11327400081534, 8.171893511767156], [7.8938475496082745, 6.934872294335344, 5.955535280898132, 4.9646601394255505, 3.9364254997945016, 2.981311688747642, 1.9539678751296645, 1.042647073017873, 1.9823042102169735, 3.0067304879625785, 4.060043164143582, 5.050460518494839, 6.009951076662129, 7.005712746466193, 8.00834997286471, 8.996827592985607, 9.954213071959199, 10.931688905527277, 9.93076277791842, 8.904025181568315, 8.912753327254851, 7.965547221861099, 6.946048159202135, 6.0064615404050965, 4.949748233574707, 3.9605136070648967, 2.9040945787498536, 2.092295028879864, 3.037850016610063, 4.043538085150406, 4.996933773580285, 5.9569758472854355, 7.015785787012456, 7.968176336793565, 8.920882600242132, 9.989387146309417, 10.879660749448503, 11.80798259411268, 10.97885277375095, 9.958533671515177, 9.740322384840598, 8.799167245017706, 7.842407653189115, 6.876241933025462, 5.877401500218131, 4.938027280583095, 3.906824678085373, 3.1515879123546053, 4.054287208316168, 5.061541928847163, 6.017779467044729, 6.948572455833899, 8.000842685405141, 8.996817519842836, 9.869175179834961, 10.807808215361085, 11.75766694856583, 12.752804037584431, 11.737601068096007, 10.785771738424174, 10.747671249159206, 9.810257184138909, 8.826251574499194, 7.926596207520438, 6.887336695971063, 5.861894737048357, 4.913413959595785, 4.21865607234416, 5.070205662107462, 6.046931052941926, 7.047382098638833, 7.936937321654547, 8.900840602750673, 9.863389043106423, 10.889081135776555, 11.818884483947464, 12.68670085906849, 13.621818934875199, 12.723435256440451, 11.77030096310536, 11.67324690058282, 10.74927110611656, 9.882233214044128, 8.8791010639875, 7.869598617731404, 6.917853430212359, 5.967384030655539, 5.282523645046819, 6.062331772231834, 7.006576245345802, 7.95621621473397, 8.876307022067097, 9.889176398908347, 10.835542243441616, 11.855877601212416, 12.880029346053252, 13.685796720822303, 14.614660070599506, 13.66929803830337, 12.726989720174794, 12.681348993978842, 11.725615729464502, 10.776377833029477, 9.850990915385637, 8.81216145435178, 7.949235221308207, 7.012059767517143, 6.244830512181283, 6.99428512986702, 7.921818941496735, 8.867965833152208, 9.820367234409852, 10.810886205948014, 11.739845154283138, 12.717655524208269, 13.696893046906073, 14.624226047791064, 15.613085057007119, 14.594435332660087, 13.631692053239519, 13.62537973677389, 12.724451065550475, 11.850197913942079, 10.851826257651938, 9.782933192002671, 8.919548663387326, 8.074270443732082, 7.283471274982066, 8.01479040580868, 8.863572849418697, 9.889429919119683, 10.818537542190732, 11.800705383362297, 12.753514322757923, 13.670135447637307, 14.624314594894024, 15.586479692426122, 16.502069598125825, 15.493677304569433, 14.56112238300236, 14.636611110058482, 13.706733739470877, 12.789723018830584, 11.779845515864675, 10.808289040882068, 9.945699490324323, 9.050561890622962, 8.264853258915231, 8.977710170694001, 9.805046886029354, 10.761647939388869, 11.750466948156348, 11.817944169747667, 12.776747854966365, 13.532590830429259, 14.5035879953374, 15.433174595438038, 16.372129919790062, 16.48420552028659, 15.498208612876905, 15.606030250695357, 14.608052261212531, 13.614351578053094, 12.686313986875069, 11.7390496693811, 10.988030599799409, 10.117090782632948, 9.26890128092282, 9.997073983337325, 10.843261386079433, 11.773691131100641, 11.745871859565272, 10.854057908511924, 11.748679702300807, 12.606717025344933, 13.569929263387882, 14.497646846083446, 15.571221884417419, 16.620677063395313, 16.465647216361987, 16.54410995345558, 15.594814827476931, 14.64179608016148, 13.660671003662287, 12.702782121068411, 11.931669064093407, 11.100297946774058, 10.245580887990833, 11.065879782812436, 11.789021863392488, 11.57450803603708, 10.75636210618964, 9.868350665155958, 10.81495920548649, 11.611985121219611, 12.607811558923474, 13.547194994225386, 14.621453622574904, 15.583780319591124, 16.51225420611035, 16.43793427442577, 16.567881591541024, 15.6237619254581, 14.637192807275696, 13.636524768360824, 12.995433045002274, 12.148717146117058, 11.297389940432684, 11.994843580089535, 11.600583237247754, 10.599118234977796, 9.697988405184132, 8.844330080625795, 9.834561265462305, 10.654751891929473, 11.605560438624579, 12.589873839347101, 13.601495915474153, 14.51749731987475, 15.495549473437991, 15.565167140343034, 16.493120252288676, 16.604105796302367, 15.614826781714248, 14.67609443160891, 13.951466720550219, 13.110554713047566, 12.28709764037615, 11.536504290712502, 10.611382960460496, 9.647768676680268, 8.643019366434848, 7.774646044476134, 8.7802557998494, 9.694090460122736, 10.643282725507385, 11.681077255828248, 12.60789108434159, 13.582144396766617, 14.609561761950118, 14.654466438917375, 15.574786335003322, 16.560447437997073, 15.53812630269281, 14.472817514535032, 13.463065959158328, 12.533295900734808, 11.584444129844238, 10.628845719405794, 9.609035072658038, 8.641008434429754, 7.715482104290124, 6.728404772765615, 7.771146896030912, 8.662944973097487, 9.706347919410215, 10.65894719399352, 11.647647577288199, 12.69736670023761, 13.666936055485177, 13.655123975802418, 14.634518765429473, 15.519771968906026, 14.551652469147173, 13.531686205587484, 12.51702408701551, 11.56837236341583, 10.6306979673175, 9.75913645351607, 8.766457909983293, 7.739003783816422, 6.818821800803162, 5.792219046809992, 6.8070039675162235, 7.7270020922039215, 8.727268571431019, 9.710976078369686, 10.699663455454266, 11.740208074197, 12.686777514730954, 12.68224202490118, 13.62376740574674, 14.551550468155138, 13.55535563891621, 12.63376179524106, 11.637715537317295, 10.67479240445326, 9.650297445163059, 8.695007554064446, 7.726329731271022, 6.767684732199864, 5.790853181716468, 4.768125643535431, 5.836036547706529, 6.762835995358785, 7.801360618318629, 8.754871350521661, 9.759972386038031, 10.703878165327156, 11.735222812028479, 11.672396887413026, 12.6630460518192, 13.623405531688517, 12.624485323703384, 11.723704870818601, 10.79138106911213, 9.769480932378253, 8.77006303681106, 7.828663304861128, 6.8048443532051905, 5.764268875649178, 4.861648036664098, 3.8308277910049027, 4.828725891570858, 5.826871005691645, 6.774024412979688, 7.753648726016856, 8.712605358250375, 9.740856522417342, 10.727305520578522, 10.672062217359933, 11.61788304645738, 12.665509163811382, 11.651819420796258, 10.719957428883232, 9.71657743154837, 8.829627275636524, 7.806716420834382, 6.834272569950663, 5.878832463575472, 4.8107042403625, 3.832811327473014, 2.8722868541310795, 3.884707760864488, 4.884741701468695, 5.801088050531843, 6.7545666164443965, 7.784460492129489, 8.76977603199925, 9.74499944625614, 9.705955569090653, 10.766608819317915, 11.729451063180427, 10.782430538554959, 9.738598245034071, 8.743363091939088, 7.799074893608719, 6.7772581108320615, 5.772226370833329, 4.841804938611398, 3.794855341165732, 2.83212260079679, 1.9408050910015264, 2.9014623255455616, 3.872586699062626, 4.848222347868724, 5.799384708909173, 6.855087819972166, 7.853998815975322, 8.755958260535978, 8.795525554391327, 9.85363902516789, 10.87702722779703, 10.009279154928473, 8.984250136513962, 8.009765408804165, 7.012585975212504, 5.99664804340604, 4.9455423167467885, 3.9379774238191207, 2.866381165175178, 1.8729849419990332, 0.9279748189464512, 1.9048354905967253, 2.9106649386315464, 3.930080902681465, 4.949307886655495, 5.89016021609889, 6.834727132433248, 7.800725336808127, 8.256447469024971, 9.268132454760147, 10.121623040066595, 9.07461506854655, 8.126319886442532, 7.06744950754199, 6.077666155066388, 5.057767018926329, 4.116011613440829, 3.070606125265621, 1.9990389754003468, 0.974293022789803, 0.0, 0.9294188364717453, 1.997456918692727, 3.0450864388228744, 4.034351777909114, 5.09898637438331, 6.138980978025537, 7.197600488977352], [6.964428713136529, 6.005453457863599, 5.026116444426386, 4.035241302953805, 3.0070066633227563, 2.0518928522758966, 1.0245490386579192, 1.9720659094896182, 2.911723046688719, 3.936149324434324, 4.989462000615328, 5.979879354966585, 6.939369913133874, 7.935131582937938, 8.937768809336454, 9.92624642945735, 10.883631908430942, 10.002270069055534, 9.001343941446677, 7.97460634509657, 7.983334490783106, 7.036128385389354, 6.01662932273039, 5.077042703933351, 4.020329397102961, 3.0310947705931515, 1.9746757422781083, 2.9666715560717547, 3.9672688530818085, 4.972956921622151, 5.92635261005203, 6.886394683757181, 7.9452046234842015, 8.89759517326531, 9.850301436713877, 10.918805982781162, 11.809079585920246, 11.032594905519813, 10.049433937279206, 9.029114835043432, 8.810903548368852, 7.86974840854596, 6.91298881671737, 5.946823096553716, 4.9479826637463855, 4.00860844411135, 2.9774058416136278, 3.9992943510405716, 4.983706044787914, 5.990960765318908, 6.947198303516474, 7.877991292305644, 8.930261521876886, 9.92623635631458, 10.798594016306707, 11.73722705183283, 12.687085785037576, 11.823385201112686, 10.808182231624262, 9.856352901952429, 9.81825241268746, 8.880838347667163, 7.896832738027449, 6.997177371048693, 5.957917859499318, 4.932475900576612, 3.98399512312404, 4.975103657526262, 5.960654007684542, 6.937379398519006, 7.937830444215913, 8.866356158126292, 9.830259439222418, 10.792807879578168, 11.8184999722483, 12.74830332041921, 13.616119695540235, 12.787595573130245, 11.794016419968706, 10.840882126633614, 10.743828064111074, 9.819852269644812, 8.952814377572384, 7.949682227515755, 6.940179781259658, 5.988434593740614, 5.037965194183793, 5.978668593465668, 6.952780117808914, 7.897024590922882, 8.84666456031105, 9.805725858538842, 10.818595235380092, 11.76496107991336, 12.785296437684162, 13.809448182524998, 14.61521555729405, 13.758288836058512, 12.739879201831625, 11.797570883703049, 11.751930157507097, 10.796196892992757, 9.846958996557731, 8.921572078913892, 7.8827426178800355, 7.019816384836462, 6.082640931045398, 6.940975460600131, 7.8847334754441, 8.812267287073816, 9.75841417872929, 10.710815579986933, 11.701334551525095, 12.630293499860219, 13.60810386978535, 14.587341392483154, 15.514674393368145, 14.718013066928085, 13.665016496188342, 12.702273216767773, 12.695960900302145, 11.79503222907873, 10.920779077470334, 9.922407421180193, 8.853514355530926, 7.99012982691558, 7.144851607260337, 7.979616223400915, 8.905238751385761, 9.754021194995778, 10.779878264696764, 11.708985887767813, 12.691153728939378, 13.283328673313932, 13.771508808127722, 14.72320668997653, 15.655308369789736, 15.57265076165408, 14.564258468097687, 13.631703546530614, 13.707192273586736, 12.777314902999132, 11.860304182358838, 10.85042667939293, 9.878870204410322, 9.016280653852576, 8.121143054151217, 8.960998207334079, 9.868158516271082, 10.695495231606435, 11.65209628496595, 12.640915293733428, 12.74736300621941, 12.279642966199436, 12.698150340012615, 13.669147504920756, 14.598734105021395, 15.537689429373417, 15.554786683814845, 14.56878977640516, 14.676611414223611, 13.678633424740786, 12.684932741581349, 11.756895150403324, 10.809630832909354, 10.058611763327661, 9.187671946161203, 9.965046229341668, 10.887522328914406, 11.733709731656514, 12.664139476677722, 12.675290696037019, 11.783476744983668, 11.251574813533878, 11.77227653492829, 12.73548877297124, 13.663206355666803, 14.736781394000776, 15.737519795928321, 15.536228379890241, 15.614691116983836, 14.665395991005186, 13.712377243689737, 12.731252167190542, 11.773363284596666, 11.00225022762166, 10.170879110302312, 10.941725836409681, 11.956328128389517, 12.679470208969569, 12.503926872508828, 11.685780942661387, 10.797769501627702, 10.317854316719561, 10.777544630802968, 11.773371068506831, 12.700768341327667, 13.775026969677185, 14.700623052124133, 15.62909693864336, 15.554777006958778, 15.63846275506928, 14.694343088986356, 13.707773970803952, 12.707105931889078, 12.066014208530527, 11.219298309645312, 11.993534888851531, 12.885291925666616, 12.530002073719501, 11.528537071449543, 10.62740724165588, 9.77374891709754, 9.246196992652518, 9.82031140151283, 10.771119948207936, 11.736718748099653, 12.748340824226705, 13.634340052407758, 14.612392205971, 14.682009872876042, 15.609962984821685, 15.674686959830623, 14.685407945242504, 13.746675595137166, 13.022047884078471, 12.181135876575823, 12.983242588794997, 12.465923127184249, 11.540801796932243, 10.577187513152015, 9.572438202906595, 8.704064880947879, 8.191891527039612, 8.859649969706092, 9.808842235090742, 10.797919988361256, 11.724733816874599, 12.698987129299626, 13.726404494483127, 13.736515694182568, 14.656835590268516, 15.71022058474525, 15.71871483872068, 14.764097222978078, 14.081061803653837, 13.128397843398242, 12.513862966315983, 11.55826455587754, 10.538453909129785, 9.570427270901499, 8.64490094076187, 7.657823609237361, 7.12617818141839, 7.828504482680843, 8.823190651943223, 9.775789926526528, 10.764490309821207, 11.807171458910473, 12.776740814158039, 12.737173231067612, 13.716568020694666, 14.691592185119193, 15.481071305618919, 14.461105042059229, 13.446442923487256, 12.497791199887576, 11.560116803789246, 10.688555289987816, 9.695876746455038, 8.668422620288167, 7.7482406372749075, 6.721637883281737, 6.077712227418434, 6.892561601787278, 7.815552179735709, 8.799259686674377, 9.787947063758956, 10.82849168250169, 11.775061123035645, 11.764291280166374, 12.705816661011934, 13.688637861649122, 14.484774475387955, 13.563180631712806, 12.56713437378904, 11.604211240925006, 10.579716281634804, 9.624426390536192, 8.655748567742767, 7.69710356867161, 6.720272018188213, 5.697544480007176, 5.053691743819299, 5.9283955049421415, 6.889644226623321, 7.843154958826352, 8.848255994342722, 9.792161773631847, 10.817272067293672, 10.74297805094128, 11.733627215347454, 12.693986695216774, 13.55390416017513, 12.653123707290346, 11.720799905583876, 10.698899768849998, 9.699481873282805, 8.758082141332872, 7.734263189676936, 6.693687712120923, 5.7910668731358435, 4.760246627476648, 3.9788114968813284, 4.976956611002115, 5.862308021284379, 6.841932334321546, 7.800888966555065, 8.822905777682536, 9.809354775843715, 9.742643380888188, 10.688464209985634, 11.736090327339639, 12.581238257268003, 11.649376265354977, 10.645996268020115, 9.759046112108269, 8.736135257306127, 7.763691406422408, 6.808251300047218, 5.740123076834245, 4.762230163944759, 3.801705690602825, 3.0347933661749584, 4.000412776608987, 4.889371658836534, 5.842850224749089, 6.872744100434182, 7.851825287264442, 8.827048701521331, 8.776536732618908, 9.83718998284617, 10.865073948378543, 11.711849375026704, 10.668017081505816, 9.672781928410833, 8.728493730080464, 7.706676947303807, 6.7016452073050745, 5.771223775083143, 4.7242741776374775, 3.7615414372685354, 2.8702239274732717, 2.026643126433334, 2.9608703073673173, 3.9365059561734155, 4.887668317213865, 5.9433714282768575, 6.9245799795035765, 7.826539424064234, 7.866106717919583, 8.924220188696147, 9.947608391325286, 10.930226878812697, 9.913668972985707, 8.93918424527591, 7.942004811684249, 6.9260668798777845, 5.874961153218533, 4.867396260290866, 3.7958000016469233, 2.8024037784707785, 1.8573936554181965, 0.9754166541249801, 1.9812461021598011, 3.0006620662097196, 4.01988905018375, 4.9607413796271445, 5.905308295961503, 6.871306500336382, 7.327028632553227, 8.338713618288404, 9.29936558295432, 10.004033905018295, 9.055738722914278, 7.996868344013735, 7.007084991538133, 5.987185855398074, 5.045430449912574, 4.000024961737367, 2.928457811872092, 1.9037118592615483, 0.9294188364717453, 0.0, 1.0680380822209816, 2.115667602351129, 3.1049329414373683, 4.169567537911565, 5.209562141553792, 6.268181652505607], [5.931264775165779, 4.972289519892849, 3.9929525064556364, 3.002077364983055, 1.9738427253520068, 1.018728914305147, 2.0460727279231246, 3.0401039917106, 3.9797611289097006, 5.004187406655306, 6.0575000828363095, 7.047917437187567, 8.007407995354857, 9.003169665158921, 10.005806891557437, 10.95086420728665, 9.993478728313058, 8.969106131084782, 7.9681800034759265, 6.94144240712582, 6.950170552812356, 6.002964447418604, 4.98346538475964, 4.043878765962601, 2.987165459132212, 1.997930832622402, 2.9961994315433134, 3.98819524533696, 5.03530693530279, 6.040995003843133, 6.9943906922730115, 7.954432765978162, 9.013242705705183, 9.965633255486294, 10.91833951893486, 11.932755716515791, 10.918926405802361, 9.999430967549062, 9.016269999308456, 7.995950897072682, 7.777739610398101, 6.83658447057521, 5.87982487874662, 4.913659158582966, 3.914818725775636, 3.0375305615219492, 3.998929530878833, 5.020818040305777, 6.036481029088156, 7.043735749619151, 8.015236385737456, 8.946029374526626, 9.998299604097868, 10.994274438535562, 11.86663209852769, 12.792775589940875, 11.84291685673613, 10.790221263141934, 9.77501829365351, 8.823188963981677, 8.78508847471671, 7.847674409696413, 6.863668800056699, 5.978213525688691, 4.97665599217852, 4.020859708213325, 4.969340485665897, 5.960449020068118, 6.9459993702263985, 7.922724761060863, 8.923175806757769, 9.934394240347274, 10.8982975214434, 11.86084596179915, 12.886538054469284, 13.618068337406335, 12.689549710966203, 11.754431635159493, 10.760852481997954, 9.807718188662864, 9.710664126140324, 8.786688331674064, 7.919650439601633, 6.968420360194957, 5.95891791393886, 5.076818401377327, 6.02331055672565, 6.964013956007524, 7.938125480350771, 8.882369953464739, 9.832009922852906, 10.873763940759824, 11.886633317601074, 12.832999162134342, 13.853334519905143, 14.615697670072699, 13.653988247864962, 12.72512489808776, 11.706715263860874, 10.764406945732299, 10.718766219536347, 9.814888437016572, 8.865650540581546, 7.9403102115930935, 6.901480750559237, 6.127622927721687, 7.06479838151275, 7.926320823141988, 8.870078837985957, 9.797612649615672, 10.743759541271146, 11.69616094252879, 12.686679914066952, 13.615638862402076, 13.72329676366405, 14.702534286361855, 14.674228620757107, 13.684849128957335, 12.631852558217592, 11.669109278797023, 11.662796962331395, 10.813723773102545, 9.939470621494149, 8.941145553859394, 7.872252488210128, 7.097936369800805, 8.039557930996162, 8.964961585942772, 9.890584113927618, 10.739366557537634, 11.76522362723862, 12.69433125030967, 13.676499091481235, 13.729313611737556, 12.770816840235012, 13.72251472208382, 14.654616401897027, 14.53948682368333, 13.531094530126937, 12.598539608559864, 12.674028335615986, 11.796006447022947, 10.87904231503804, 9.869164812072132, 8.897608337089524, 8.1240871967378, 9.015849377887042, 9.946343569875937, 10.853503878812939, 11.680840594148291, 12.637441647507806, 13.626260656275285, 13.600844618250978, 12.72562790462306, 11.697458372119906, 12.668455537028047, 13.598042137128685, 14.536997461480707, 14.521622745844095, 13.53562583843441, 13.643447476252861, 12.697371557419988, 11.70367087426055, 10.775633283082525, 9.828368965588556, 9.166418306212886, 10.082378269897028, 10.950391591883527, 11.872867691456262, 12.71905509419837, 13.649484839219578, 13.575605192547965, 12.636958357015235, 11.697559751957503, 10.77158456703558, 11.73479680507853, 12.662514387774094, 13.730363972545582, 14.698568887621654, 14.503064441919491, 14.581527179013086, 13.684134123684387, 12.731115376368937, 11.749990299869744, 10.792101417275868, 10.110056770506885, 11.065585434038137, 11.92707119895154, 12.941673490931374, 13.664815571511426, 13.487403952157305, 12.649408030552586, 11.710447795473717, 10.763839255143186, 9.776852662910258, 10.772679100614122, 11.661817433021, 12.736076061370518, 13.661672143817466, 14.590146030336692, 14.515826098652111, 14.65720088774848, 13.713081221665556, 12.726512103483152, 11.72584406456828, 11.173820751415752, 12.114004633381137, 12.97888025139339, 13.870637288208473, 13.513479153367978, 12.51201415109802, 11.610884321304356, 10.757225996746017, 9.885330996061928, 8.81961943362012, 9.770427980315226, 10.697767839792986, 11.709389915920038, 12.595389144101091, 13.573441297664333, 13.643058964569375, 14.571012076515018, 14.693425092509823, 13.704146077921704, 12.765413727816366, 12.129854426963696, 13.062517561494769, 13.968587951336856, 13.449400206832726, 12.52427887658072, 11.560664592800492, 10.555915282555071, 9.687541960596356, 8.893901861193156, 7.858958001813383, 8.808150267198032, 9.75896908005459, 10.685782908567932, 11.660036220992959, 12.68745358617646, 12.697564785875903, 13.61788468196185, 14.671269676438584, 14.73745297139988, 13.782835355657278, 13.188868346539062, 14.009779528317187, 13.510758351569303, 12.541741635526018, 11.521930988778262, 10.553904350549976, 9.628378020410347, 8.641300688885838, 7.898243528546388, 6.827812514788134, 7.784239743636557, 8.736839018219861, 9.72553940151454, 10.768220550603807, 11.737789905851374, 11.698222322760946, 12.677617112388, 13.652641276812526, 14.620760776571379, 14.735654917747631, 14.13491021868188, 13.525508180691423, 12.587833784593093, 11.716272270791663, 10.723593727258885, 9.696139601092014, 8.731717716923386, 7.705114962930216, 6.8785234683008225, 5.891869633894569, 6.776601271429043, 7.760308778367711, 8.748996155452291, 9.789540774195025, 10.73611021472898, 10.725340371859708, 11.666865752705268, 12.649686953342455, 13.645881782581384, 14.571243278566417, 13.594851354592887, 12.631928221728852, 11.60743326243865, 10.652143371340038, 9.683465548546614, 8.724820549475456, 7.703749097836692, 6.681021559655655, 5.854502984701687, 4.927703537049432, 5.8506933183166545, 6.804204050519687, 7.809305086036057, 8.753210865325181, 9.778321158987007, 9.704027142634615, 10.694676307040789, 11.655035786910107, 12.718045669329896, 13.691576919716773, 12.788837987804857, 11.76693785107098, 10.767519955503786, 9.825560511771151, 8.761980170480783, 7.72140469292477, 6.774543952784322, 5.743723707125127, 4.84521214302571, 3.976264643109406, 4.823357112977713, 5.802981426014881, 6.7619380582484, 7.7839548693758704, 8.77040386753705, 8.703692472581523, 9.649513301678969, 10.697139419032972, 11.755967485868378, 12.687829477781404, 11.714034350241096, 10.82708419432925, 9.80417333952711, 8.83172948864339, 7.835968280851063, 6.767840057638091, 5.7457072435932375, 4.7851827702513035, 3.9011940123193396, 2.9614618683023197, 3.850420750529868, 4.803899316442422, 5.833793192127515, 6.812874378957777, 7.788097793214666, 7.737585824312243, 8.798239074539504, 9.826123040071877, 10.773143564697346, 11.736055163726798, 10.740820010631815, 9.796531812301446, 8.774715029524788, 7.769683289526056, 6.839261857304125, 5.792312259858459, 4.829579519489517, 3.8537010071217503, 2.893043772577715, 1.9219193990606507, 2.897555047866749, 3.8487174089071985, 4.904420519970191, 5.885629071196911, 6.787588515757568, 6.827155809612917, 7.88526928038948, 8.908657483018619, 9.89127597050603, 10.91630498892054, 10.007222327496892, 9.010042893905231, 7.994104962098766, 6.9429992354395145, 5.935434342511847, 4.863838083867904, 3.8704418606917597, 2.925431737639178, 1.9481246418879556, 0.9422951938531348, 1.9617111579030535, 2.980938141877083, 3.921790471320478, 4.866357387654837, 5.832355592029716, 6.258990550332245, 7.270675536067422, 8.231327500733338, 9.278335472253383, 10.123776805135261, 9.064906426234717, 8.075123073759116, 7.055223937619056, 6.113468532133556, 5.0680630439583485, 3.9964958940930737, 2.97174994148253, 1.997456918692727, 1.0680380822209816, 0.0, 1.0476295201301478, 2.036894859216387, 3.1015294556905832, 4.14152405933281, 5.2001435702846255], [4.978004720057957, 4.019029464785026, 3.039692451347814, 2.0488173098752327, 1.0325625469968411, 1.987676358043701, 3.0150201716616785, 4.029904276389309, 4.969561413588409, 5.993987691334015, 7.047300367515018, 8.037717721866276, 9.055037515485004, 10.050799185289069, 10.986081772299723, 9.997604152178827, 9.040218673205235, 8.01584607597696, 7.014919948368104, 5.988182352017997, 5.996910497704533, 5.049704392310781, 4.030205329651817, 3.090618710854779, 2.062591976176, 2.966878276360956, 3.9651468752818673, 4.957142689075513, 6.008905314868922, 7.030795288521841, 7.984190976951721, 8.944233050656873, 10.003042990383893, 11.013262775616441, 11.913209767870377, 10.979495661407968, 9.965666350694539, 9.046170912441239, 8.063009944200633, 7.042690841964859, 6.85316612744189, 5.912010987618999, 4.955251395790408, 3.9890856756267543, 2.990245242819424, 4.0030588871628385, 4.967876974617387, 5.989765484044331, 7.0054284728267096, 8.012683193357704, 9.005036670416166, 9.935829659205336, 10.988099888776578, 11.984074723214272, 12.806835142510788, 11.868202106984665, 10.91834337377992, 9.865647780185723, 8.850444810697299, 7.898615481025465, 7.860514991760499, 6.923100926740202, 5.939095317100487, 5.0536400427324795, 4.052082509222307, 4.986388033854214, 5.934868811306786, 6.925977345709008, 7.911527695867288, 8.888253086701752, 9.888704132398658, 10.924194525025984, 11.88809780612211, 12.85064624647786, 13.737525183419002, 12.693494854450124, 11.764976228009992, 10.829858152203283, 9.836278999041744, 8.883144705706652, 8.786090643184112, 7.862114848717852, 6.995076956645422, 6.043846877238744, 5.034344430982648, 6.0423467270182165, 6.988838882366539, 7.929542281648414, 8.903653805991661, 9.84789827910563, 10.797538248493797, 11.863564225438534, 12.876433602279784, 13.822799446813052, 14.716354429648584, 13.69112418711649, 12.729414764908753, 11.800551415131551, 10.782141780904663, 9.839833462776086, 9.794192736580134, 8.890314954060361, 7.9410770576253356, 7.015736728636881, 5.976907267603025, 7.004487054778312, 7.941662508569376, 8.891849148782876, 9.835607163626847, 10.763140975256562, 11.709287866912035, 12.66168926816968, 13.652208239707841, 14.581167188042965, 14.589419806366559, 14.032648040941593, 13.749655137800898, 12.760275646001123, 11.70727907526138, 10.744535795840811, 10.738223479375183, 9.889150290146334, 9.014897138537938, 8.016572070903182, 6.9476790052539155, 7.97480049685743, 8.916422058052786, 9.93048991158366, 10.856112439568507, 11.704894883178524, 12.73075195287951, 13.65985957595056, 14.642027417122124, 14.595436654440064, 13.63693988293752, 12.965434234222826, 13.80569414289989, 13.614913340727117, 12.606521047170725, 11.673966125603652, 11.749454852659774, 10.871432964066736, 9.954468832081828, 8.94459132911592, 7.973034854133312, 9.000951323794427, 9.892713504943666, 10.911871895516825, 11.819032204453828, 12.64636891978918, 13.602969973148696, 14.591788981916174, 14.466967660953486, 13.591750947325568, 12.563581414822414, 11.911375049167052, 12.749119878131548, 13.68807520248357, 13.597049262887882, 12.611052355478197, 12.718873993296649, 11.772798074463775, 10.779097391304338, 9.851059800126313, 8.903795482632344, 9.908340015127159, 10.844621112357798, 11.871879301742513, 12.83644993776202, 13.68458341983926, 14.615013164860468, 14.441728235250473, 13.503081399717743, 12.56368279466001, 11.637707609738088, 10.882953627181811, 11.690970203573897, 12.75682139803838, 13.725026313114448, 13.578490958963279, 13.656953696056874, 12.759560640728175, 11.806541893412724, 10.825416816913531, 9.867527934319655, 10.851978479421158, 11.825122410645264, 12.767257204249681, 13.810735092256895, 14.630343897152315, 14.440704531992136, 13.515531073255094, 12.576570838176226, 11.629962297845694, 10.642975705612766, 9.920835922717403, 10.688274858513795, 11.762533486863315, 12.68812956931026, 13.616603455829486, 13.542283524144905, 13.732627404792268, 12.788507738709344, 11.80193862052694, 10.801270581612068, 11.774898451248191, 12.84335848296391, 13.819066256691531, 14.739698889533994, 14.491207876472972, 13.489742874203014, 12.58861304440935, 11.734954719851011, 10.751454038764436, 9.685742476322629, 8.858126277576236, 9.724225265285781, 10.735847341412834, 11.621846569593885, 12.599898723157127, 12.66951639006217, 13.59427946383476, 13.76885160955361, 12.779572594965492, 11.840840244860154, 12.730932126796136, 13.663595261327208, 14.609041049099114, 14.427128929937718, 13.502007599685712, 12.538393315905486, 11.533644005660065, 10.66527068370135, 9.760024903895664, 8.72508104451589, 7.881777997674079, 8.785426505547385, 9.712240334060727, 10.686493646485754, 11.713911011669255, 11.704395984826458, 12.624715880912406, 13.67810087538914, 13.812879488443668, 12.858261872701066, 13.789946046371501, 14.610857228149627, 14.488487074674294, 13.51947035863101, 12.499659711883254, 11.53163307365497, 10.60610674351534, 9.619029411990832, 8.764366571248896, 7.693935557490642, 6.810697169129353, 7.763296443712657, 8.751996827007336, 9.794677976096603, 10.76424733134417, 10.705053521711502, 11.684448311338556, 12.659472475763083, 13.627591975521936, 13.811081434791419, 14.735987918514319, 14.503236903796415, 13.565562507698084, 12.694000993896655, 11.701322450363877, 10.673868324197006, 9.709446440028378, 8.68284368603521, 7.744646511003331, 6.757992676597077, 5.803058696921839, 6.786766203860507, 7.775453580945086, 8.81599819968782, 9.762567640221775, 9.732171570810264, 10.673696951655824, 11.656518152293012, 12.652712981531941, 13.578074477516974, 14.572580077697879, 13.609656944833844, 12.585161985543643, 11.62987209444503, 10.661194271651606, 9.702549272580448, 8.681477820941684, 7.658750282760647, 6.720626027404196, 5.79382657975194, 4.877150743809451, 5.830661476012482, 6.835762511528852, 7.779668290817977, 8.785152357937562, 8.71085834158517, 9.701507505991344, 10.661866985860664, 11.724876868280454, 12.69840811866733, 13.764313768267325, 12.74930761100389, 11.749889715436696, 10.803289234876143, 9.739708893585775, 8.699133416029762, 7.752272675889316, 6.721452430230119, 5.783248578470655, 4.842387685811914, 3.8498145384705094, 4.8294388515076765, 5.788395483741195, 6.790786068326426, 7.777235066487606, 7.710523671532078, 8.656344500629524, 9.70397061798353, 10.762798684818936, 11.694660676731962, 12.713461239340493, 11.80945395426216, 10.786543099460019, 9.8140992485763, 8.813697003956056, 7.745568780743084, 6.72343596669823, 5.762911493356296, 4.839230447764285, 3.839196507160078, 2.8768781760226645, 3.8303567419352187, 4.860250617620311, 5.819705577908333, 6.794928992165222, 6.744417023262799, 7.805070273490061, 8.832954239022435, 9.779974763647903, 10.823807057168791, 11.78841882446457, 10.8441306261342, 9.822313843357543, 8.817282103358812, 7.886860671136881, 6.839911073691215, 5.877178333322273, 4.831429730226743, 3.870772495682708, 2.8996481221656434, 1.9240124733595452, 2.8751748343999948, 3.9308779454629876, 4.892460270147467, 5.794419714708124, 5.833987008563473, 6.892100479340036, 7.915488681969174, 8.898107169456585, 9.923136187871096, 10.897620915580893, 10.057672414035379, 9.041703775931524, 7.990598049272271, 6.983033156344604, 5.911436897700661, 4.918040674524516, 3.9730305514719335, 2.9937877689383496, 1.987958320903529, 0.9685423568536102, 1.9877693408276398, 2.928621670271035, 3.8731885866053934, 4.839186790980272, 5.211361030202098, 6.223046015937275, 7.18369798060319, 8.230705952123236, 9.179001134227253, 10.112535946364865, 9.122752593889263, 8.102853457749204, 7.1610980522637036, 6.115692564088496, 5.044125414223221, 4.019379461612678, 3.0450864388228744, 2.115667602351129, 1.0476295201301478, 0.0, 0.9892653390862391, 2.0538999355604353, 3.0938945392026627, 4.152514050154478], [3.988739380971717, 3.0297641256987866, 2.0504271122615743, 1.0595519707889933, 2.0218278860830803, 2.97694169712994, 4.004285510747918, 5.0191696154755485, 5.958826752674649, 6.983253030420254, 8.036565706601257, 9.026983060952514, 10.044302854571244, 11.003612343536437, 9.996816433213484, 9.008338813092587, 8.050953334118995, 7.02658073689072, 6.025654609281864, 4.9989170129317575, 5.007645158618294, 4.060439053224542, 3.040939990565578, 2.10135337176854, 3.051857315262239, 3.956143615447195, 4.954412214368107, 5.946408028161753, 6.998170653955162, 8.020060627608082, 8.97345631603796, 9.93349838974311, 10.99230832947013, 11.876650692232705, 10.923944428784138, 9.990230322321729, 8.9764010116083, 8.056905573355, 7.073744605114394, 6.0534255028786195, 5.918229183547724, 4.977074043724833, 4.020314451896242, 3.091140450113032, 3.979510581905663, 4.992324226249078, 5.957142313703627, 6.979030823130571, 7.994693811912949, 9.001948532443944, 9.994302009502405, 10.925094998291575, 11.977365227862817, 12.846196971878385, 11.871898198616623, 10.9332651630905, 9.983406429885754, 8.930710836291558, 7.915507866803133, 6.963678537131299, 6.925578047866333, 5.988163982846036, 5.004158373206321, 4.155694817218757, 5.041347848308547, 5.975653372940454, 6.924134150393026, 7.915242684795247, 8.900793034953528, 9.877518425787994, 10.8779694714849, 11.913459864112223, 12.87736314520835, 13.833038545640914, 12.802588239524837, 11.75855791055596, 10.830039284115827, 9.894921208309118, 8.901342055147579, 7.948207761812486, 7.851153699289947, 6.927177904823686, 6.060140012751256, 5.220213252916331, 6.023609770068887, 7.031612066104456, 7.978104221452779, 8.918807620734654, 9.8929191450779, 10.83716361819187, 11.786803587580037, 12.852829564524773, 13.865698941366023, 14.80175284352522, 13.78141748575442, 12.756187243222325, 11.794477821014588, 10.865614471237386, 9.847204837010498, 8.904896518881921, 8.85925579268597, 7.955378010166195, 7.00614011373117, 6.275259990907401, 6.966172606689264, 7.993752393864551, 8.930927847655616, 9.881114487869118, 10.824872502713086, 11.752406314342801, 12.698553205998275, 13.650954607255919, 14.64147357879408, 15.570432527129205, 14.70431123468854, 13.725073711990735, 12.814718193906733, 11.825338702106958, 10.772342131367214, 9.809598851946646, 9.803286535481018, 8.954213346252168, 8.079960194643771, 7.302677651922896, 7.936944344340155, 8.96406583594367, 9.905687397139026, 10.919755250669901, 11.845377778654747, 12.694160222264763, 13.72001729196575, 14.649124915036799, 15.631292756208364, 15.584701993526304, 14.62620522202376, 13.954699573309064, 13.165761199338212, 12.679976396832952, 11.67158410327656, 10.739029181709487, 10.814517908765609, 9.93649602017257, 9.062271271795208, 8.33375459750438, 8.962300193219551, 9.990216662880666, 10.881978844029906, 11.901137234603066, 12.808297543540068, 13.63563425887542, 14.592235312234935, 15.581054321002414, 15.456233000039726, 14.581016286411808, 13.552846753908653, 12.90064038825329, 12.10918693456987, 13.048142258921892, 12.662112318993717, 11.676115411584032, 11.783937049402484, 10.957092814620466, 10.099420952039022, 9.387395701628162, 9.893060821718583, 10.897605354213399, 11.833886451444037, 12.861144640828753, 13.825715276848259, 14.673848758925502, 15.604278503946707, 15.430993574336714, 14.492346738803983, 13.55294813374625, 12.626972948824328, 11.872218966268049, 11.05103726001222, 12.116888454476701, 12.967448589680664, 12.643554015069114, 12.722016752162709, 11.943855380884866, 11.132395918024317, 10.382990803701187, 10.856793273405895, 11.841243818507397, 12.814387749731504, 13.75652254333592, 14.800000431343134, 15.619609236238556, 15.429969871078375, 14.504796412341333, 13.565836177262465, 12.619227636931933, 11.632241044699006, 10.910101261803641, 10.048341914952118, 11.122600543301637, 11.930551845876476, 12.859025732395702, 12.740960457547091, 12.953054598450588, 12.114361763320936, 11.41073565842246, 11.790535920698307, 12.76416379033443, 13.832623822050149, 14.808331595777771, 15.728964228620233, 15.480473215559211, 14.479008213289253, 13.57787838349559, 12.72422005893725, 11.740719377850674, 10.675007815408868, 9.847391616662474, 9.084292321724105, 10.095914397851157, 10.864268846160101, 11.842320999723343, 11.784902620900485, 12.681129119340437, 13.094705634165203, 12.388369632861012, 12.830105583946395, 13.720197465882375, 14.652860600413447, 15.598306388185353, 15.416394269023959, 14.491272938771953, 13.527658654991725, 12.522909344746305, 11.654536022787589, 10.749290242981903, 9.71434638360213, 8.871043336760318, 8.145493561985708, 9.07230739049905, 9.92891592305197, 10.915032187171388, 10.791245640332136, 11.711565536418084, 12.764950530894817, 13.421676526339189, 13.847527211787307, 14.77921138545774, 15.600122567235866, 15.477752413760536, 14.50873569771725, 13.488925050969495, 12.520898412741209, 11.59537208260158, 10.608294751077072, 9.753631910335136, 8.683200896576881, 7.799962508215592, 7.1233635001509805, 8.070607417605203, 8.942583512930293, 9.91215286817786, 9.79190317721718, 10.771297966844234, 11.746322131268757, 12.71444163102761, 13.635750147097795, 14.650412265669768, 15.492502242882654, 14.554827846784324, 13.683266332982894, 12.690587789450117, 11.663133663283245, 10.69871177911462, 9.672109025121449, 8.73391185008957, 7.747258015683316, 6.792324036008078, 6.069107550693529, 7.019710615353001, 7.963903736521511, 8.910473177055465, 8.819021226315941, 9.760546607161501, 10.743367807798686, 11.739562637037615, 12.664924133022648, 13.660970390946414, 14.598922283920084, 13.574427324629882, 12.61913743353127, 11.650459610737846, 10.691814611666688, 9.670743160027925, 8.648015621846888, 7.709891366490435, 6.7830919188381795, 5.8664160828956895, 5.052344314224164, 6.057445349740533, 6.896735397696225, 7.87200201344324, 7.797707997090848, 8.78835716149702, 9.748716641366338, 10.811726523786128, 11.785257774173004, 12.851163423772999, 13.738572950090127, 12.739155054522934, 11.792554573962382, 10.728974232672014, 9.688398755116001, 8.741538014975555, 7.710717769316359, 6.772513917556894, 5.831653024898153, 4.839079877556748, 4.051121689719358, 5.010078321952877, 5.877635723832103, 6.864084721993283, 6.7973733270377545, 7.7431941561352, 8.790820273489203, 9.84964834032461, 10.781510332237636, 11.800310894846167, 12.734847775960038, 11.775808438546257, 10.803364587662537, 9.802962343042294, 8.734834119829323, 7.71270130578447, 6.752176832442536, 5.828495786850524, 4.8284618462463165, 3.866143515108903, 3.051822769304726, 4.081716644989819, 4.90655523341401, 5.881778647670899, 5.8312666787684755, 6.891919928995738, 7.919803894528111, 8.86682441915358, 9.910656712674468, 10.905891865769451, 11.833395965220438, 10.811579182443781, 9.80654744244505, 8.87612601022312, 7.829176412777454, 6.866443672408512, 5.820695069312983, 4.8600378347689475, 3.8889134612518825, 2.9132778124457843, 2.0966408617695023, 3.08535097797458, 3.9793099256531437, 4.881269370213801, 4.920836664069149, 5.978950134845713, 7.002338337474852, 7.984956824962263, 9.009985843376775, 9.984470571086572, 11.002378800491428, 10.030969115017761, 8.97986338835851, 7.972298495430843, 6.9007022367869, 5.907306013610755, 4.962295890558173, 3.9830531080245892, 2.977223659989768, 1.9578076959398494, 1.0746189963333161, 2.015471325776711, 2.96003824211107, 3.9260364464859485, 4.222095691115858, 5.233780676851035, 6.194432641516951, 7.241440613036996, 8.189735795141013, 9.248606174041557, 10.112017932975503, 9.092118796835443, 8.150363391349943, 7.104957903174736, 6.033390753309461, 5.008644800698917, 4.034351777909114, 3.1049329414373688, 2.036894859216387, 0.9892653390862391, 0.0, 1.0646345964741961, 2.104629200116423, 3.163248711068239], [2.93178960659152, 1.9728143513185894, 0.9934773378813772, 1.9843524793539582, 3.0125871189850066, 3.9677009300318664, 4.995044743649844, 6.009928848377474, 6.949585985576575, 7.97401226332218, 9.027324939503183, 10.01774229385444, 10.955055002092047, 9.946662569156238, 8.939866658833285, 7.95138903871239, 6.994003559738799, 5.969630962510523, 4.968704834901667, 3.9419672385515603, 3.950695384238096, 3.003489278844344, 1.9839902161853806, 2.932527437389072, 3.992377831166905, 4.946902848349121, 5.945171447270033, 6.937167261063679, 7.988929886857088, 9.010819860510008, 9.964215548939887, 10.924257622645037, 11.836128090269776, 10.819700917852506, 9.866994654403939, 8.933280547941532, 7.9194512372281025, 6.999955798974804, 6.016794830734196, 4.996475728498422, 4.861279409167526, 3.920124269344635, 2.9633646775160445, 3.922314515733564, 4.920031097810329, 5.932844742153744, 6.947901546605553, 7.969790056032497, 8.985453044814875, 9.99270776534587, 10.985061242404331, 11.915854231193501, 12.78522203193588, 11.789247197498186, 10.814948424236425, 9.876315388710301, 8.926456655505556, 7.87376106191136, 6.8585580924229355, 5.906728762751102, 5.868628273486135, 4.931214208465838, 3.947208598826124, 4.875817618330775, 5.915077129880149, 6.91617388884512, 7.8646546662976915, 8.855763200699913, 9.841313550858194, 10.81803894169266, 11.818489987389565, 12.886665317414066, 13.738637211616465, 12.776088771260715, 11.745638465144639, 10.70160813617576, 9.773089509735629, 8.837971433928919, 7.84439228076738, 6.891257987432288, 6.794203924909749, 5.870228130443488, 5.003190238371058, 5.940336054028348, 6.89733905164049, 7.963147221555693, 8.918624737357446, 9.85932813663932, 10.833439660982567, 11.777684134096535, 12.727324103484703, 13.794443427816084, 14.72697300777414, 13.744803069145021, 12.72446771137422, 11.699237468842124, 10.737528046634388, 9.808664696857186, 8.7902550626303, 7.847946744501724, 7.802306018305772, 6.898428235785997, 5.949190339350972, 6.874577256994812, 7.839901888260867, 8.867481675436153, 9.804657129227216, 10.773186890424038, 11.765393018617752, 12.692926830247467, 13.63907372190294, 14.591475123160585, 15.554130778568593, 14.62517183023347, 13.647361460308339, 12.668123937610535, 11.757768419526533, 10.76838892772676, 9.715392356987016, 8.752649077566447, 8.746336761100821, 7.89726357187197, 7.023010420263574, 7.901994918010307, 8.810673625911758, 9.837795117515272, 10.779416678710628, 11.811827653224821, 12.785898294559413, 13.634680738169429, 14.660537807870416, 15.589645430941465, 16.57181327211303, 15.629615337442637, 14.599841383737377, 13.688087004692253, 12.664097235563226, 11.623026622452754, 10.614634328896361, 9.682079407329288, 9.757568134385412, 8.87954624579237, 8.00532149741501, 8.93307186359179, 9.836029474791154, 10.863945944452269, 11.755708125601508, 12.793209637157986, 13.748818059444734, 14.576154774780086, 15.532755828139601, 16.521574836907078, 16.468978627125033, 15.593761913497113, 14.565592380993959, 13.856484693424816, 12.98740715129101, 12.321322912223192, 11.605162544613519, 10.619165637203833, 10.726987275022287, 9.90014304024027, 9.042471177658825, 9.97050876883685, 10.766790103290186, 11.771334635785001, 12.70761573301564, 13.734873922400356, 14.699444558419861, 15.614369274830167, 16.54479901985137, 16.44373920142202, 15.505092365889288, 14.565693760831556, 13.639718575909633, 12.828063271439575, 11.929257476733358, 11.249957601224159, 11.963964147515014, 11.586604240688915, 11.665066977782512, 10.88690560650467, 10.07544614364412, 10.966103870909876, 11.730522554977497, 12.714973100079, 13.688117031303106, 14.630251824907523, 15.673729712914737, 16.560129752143222, 16.442715498163682, 15.517542039426639, 14.57858180434777, 13.631973264017239, 12.644986671784311, 11.865945566975167, 10.926562131673256, 10.255669690049094, 10.927067403710826, 11.855541290230052, 11.73747601538144, 11.896104824070392, 11.05741198894074, 11.99384872563115, 12.66426520226991, 13.637893071906033, 14.706353103621751, 15.682060877349373, 16.602693510191834, 16.493218842644517, 15.491753840374558, 14.590624010580894, 13.736965686022556, 12.753465004935979, 11.687753442494174, 10.860137243747781, 9.962512538445242, 9.224960068265533, 9.860784403994451, 10.838836557557693, 10.781418178734834, 11.677644677174785, 12.037755859785007, 12.971482700069702, 13.703834865517997, 14.593926747453978, 15.52658988198505, 16.472035669756956, 16.429139896109266, 15.504018565857258, 14.54040428207703, 13.53565497183161, 12.667281649872894, 11.762035870067209, 10.727092010687436, 9.883788963845625, 9.023713778706846, 8.192308671348723, 8.92543148088632, 9.911547745005738, 9.787761198166484, 10.708081094252432, 11.761466088729165, 12.70016700252004, 13.585085267022494, 14.592969695646932, 15.560503084422772, 16.48700010572886, 15.521481324802556, 14.5016706780548, 13.533644039826514, 12.608117709686885, 11.621040378162377, 10.766377537420441, 9.695946523662187, 8.812708135300898, 8.001583716872117, 7.186705936118621, 7.939099070764642, 8.908668426012207, 8.788418735051527, 9.767813524678582, 10.742837689103105, 11.710957188861958, 12.632265704932141, 13.646927823504114, 14.595579547103794, 15.533253943202125, 14.696011960068201, 13.703333416535424, 12.675879290368552, 11.711457406199925, 10.684854652206754, 9.746657477174875, 8.760003642768622, 7.805069663093384, 6.9473277674146665, 6.135809133866419, 6.960419294355859, 7.906988734889813, 7.8155367841502885, 8.75706216499585, 9.739883365633034, 10.736078194871963, 11.661439690856994, 12.65748594878076, 13.620409081644794, 14.58717295171519, 13.631883060616577, 12.663205237823153, 11.704560238751995, 10.68348878711323, 9.660761248932193, 8.72263699357574, 7.795837545923485, 6.879161709980996, 5.9305645309453014, 5.173543868253951, 5.893250955530573, 6.868517571277588, 6.794223554925196, 7.784872719331368, 8.745232199200686, 9.808242081620474, 10.781773332007354, 11.847678981607348, 12.736074069975473, 13.717620804573206, 12.80530020104769, 11.741719859757321, 10.701144382201308, 9.75428364206086, 8.723463396401664, 7.7852595446422, 6.844398651983459, 5.851825504642054, 4.929341906440496, 4.126176840466294, 4.874151281666451, 5.860600279827631, 5.793888884872103, 6.739709713969548, 7.787335831323552, 8.84616389815896, 9.778025890071985, 10.796826452680516, 11.731363333794388, 12.75427418859653, 11.816110214747845, 10.815707970127601, 9.74757974691463, 8.725446932869776, 7.764922459527841, 6.84124141393583, 5.841207473331623, 4.878889142194209, 3.9300429860258643, 3.1070010751358383, 3.903070791248358, 4.878294205505247, 4.827782236602824, 5.888435486830086, 6.916319452362459, 7.863339976987929, 8.907172270508816, 9.9024074236038, 10.846695621934169, 11.825837683532416, 10.820805943533685, 9.890384511311755, 8.843434913866089, 7.880702173497147, 6.833440696398288, 5.872783461854253, 4.901659088337188, 3.92602343953109, 2.9748610784906404, 2.0818665358089286, 2.975825483487492, 3.8777849280481487, 3.9173522219034975, 4.975465692680061, 5.9988538953092, 6.981472382796611, 8.006501401211123, 8.98098612892092, 9.998894358325776, 11.045227616106395, 9.994121889447143, 8.986556996519477, 7.914960737875535, 6.92156451469939, 5.976554391646808, 4.997311609113224, 3.9914821610784026, 2.972066197028484, 1.9528392130544543, 1.0119868836110595, 1.9565537999454183, 2.922552004320297, 3.157461094641663, 4.169146080376839, 5.1297980450427545, 6.1768060165628, 7.125101198666817, 8.18397157756736, 9.173754930042962, 10.15675339330964, 9.21499798782414, 8.169592499648932, 7.098025349783657, 6.073279397173113, 5.09898637438331, 4.169567537911565, 3.1015294556905832, 2.0538999355604353, 1.0646345964741961, 0.0, 1.0399946036422272, 2.098614114594043], [1.9289426116382313, 0.969967356365301, 1.9493043698025132, 2.9401795112750944, 3.968414150906143, 4.923527961953003, 5.95087177557098, 6.965755880298611, 7.905413017497711, 8.929839295243315, 9.983151971424318, 10.973569325775575, 9.95220800713876, 8.94381557420295, 7.9370196638799975, 6.948542043759102, 5.991156564785511, 4.966783967557235, 3.9658578399483786, 2.9391202435982717, 2.9478483892848075, 2.0252717023553246, 2.939817248106517, 3.888354469310208, 4.948204863088041, 5.9027298802702575, 6.900998479191169, 7.892994292984815, 8.944756918778225, 9.966646892431143, 10.920042580861022, 11.880084654566172, 10.833281095316488, 9.816853922899218, 8.864147659450651, 7.930433552988245, 6.916604242274815, 5.997108804021515, 5.0139478357809075, 3.9936287335451333, 3.991571042318534, 3.0591231555932143, 3.9191917094371806, 4.8781415476547005, 5.875858129731465, 6.888671774074879, 7.903728578526689, 8.925617087953633, 9.941280076736012, 10.948534797267007, 11.940888274325467, 12.834984076314178, 11.782713846742936, 10.786739012305242, 9.81244023904348, 8.912926082270737, 7.989538508794599, 6.9545489563524985, 5.939345986864074, 5.0316612438004, 5.007627159734715, 4.0702130947144175, 4.90303563074726, 5.83164465025191, 6.870904161801285, 7.872000920766255, 8.820481698218828, 9.81159023262105, 10.797140582779331, 11.773865973613795, 12.7743170193107, 13.700927032973874, 12.737023751877748, 11.774475311521998, 10.826426359585778, 9.7823960306169, 8.853877404176767, 7.918759328370058, 6.925180175208519, 6.030256873680868, 5.933202811158329, 5.009227016692067, 5.959017270292194, 6.896163085949484, 7.853166083561625, 8.91897425347683, 9.874451769278581, 10.815155168560455, 11.789266692903704, 12.733511166017673, 13.68315113540584, 14.640296733386425, 13.725359548035422, 12.74662851185719, 11.80525560581536, 10.780025363283265, 9.818315941075529, 8.889452591298326, 7.871042957071438, 6.986945630750303, 6.941304904554351, 6.050194130936488, 6.905017371272108, 7.830404288915948, 8.795728920182002, 9.823308707357288, 10.760484161148351, 11.729013922345173, 12.72122005053889, 13.648753862168604, 14.594900753824078, 15.547302155081722, 14.634918673009734, 13.70595972467461, 12.72814935474948, 11.748911832051675, 10.838556313967674, 9.871721555268744, 8.818724984529, 7.891647963815027, 7.885335647349399, 7.049029467022461, 7.97883745218471, 8.857821949931443, 9.766500657832893, 10.793622149436407, 11.735243710631764, 12.767654685145956, 13.74172532648055, 14.590507770090566, 15.616364839791553, 16.5454724628626, 15.700622443964292, 14.710403231883777, 13.680629278178518, 12.816125638770442, 11.800809958602732, 10.762025508701333, 9.75363321514494, 8.821078293577868, 8.896567020633992, 8.031312140942862, 8.961148529336146, 9.888898895512925, 10.79185650671229, 11.819772976373404, 12.711535157522643, 13.749036669079121, 14.70464509136587, 15.531981806701223, 16.48858286006074, 17.477401868828217, 16.733783414677134, 15.685000457143921, 14.634754735380081, 13.66375757047194, 12.734170970371302, 11.79521564601928, 10.744161430862098, 9.758164523452413, 9.865986161270866, 9.05190893539076, 9.99829820957996, 10.926335800757986, 11.72261713521132, 12.727161667706136, 13.663442764936775, 14.69070095432149, 15.655271590340996, 16.570196306751303, 17.50062605177251, 17.442743831662657, 16.504096996129928, 15.564698391072193, 14.63872320615027, 13.696955656732461, 12.798149862026245, 11.960597582378986, 11.073834945086936, 10.725603126937495, 10.804065864031092, 10.038671501655159, 11.009375135015585, 11.921930902831011, 12.686349586898633, 13.670800132000135, 14.643944063224241, 15.586078856828658, 16.629556744835874, 17.515956784064358, 17.441720128404317, 16.516546669667274, 15.577586434588408, 14.630977894257876, 13.643991302024949, 12.734837952268053, 11.795454516966142, 10.966309671203922, 10.036938201282748, 10.965412087801974, 10.83831336585289, 11.047870719220882, 11.991340980312204, 12.949675757552285, 13.620092234191045, 14.593720103827168, 15.662180135542886, 16.637887909270507, 17.558520542112973, 17.492223472885147, 16.49075847061519, 15.589628640821529, 14.73597031626319, 13.752469635176617, 12.686758072734811, 11.81571832446065, 10.831404923738129, 9.93560004942036, 8.970655201566373, 9.948707355129615, 9.882255529206285, 10.778482027646236, 11.79637490212118, 12.796379843351579, 13.66541284221677, 14.714889562575662, 15.570670998598555, 16.51611678637046, 17.4281445263499, 16.503023196097892, 15.539408912317665, 14.534659602072244, 13.666286280113528, 12.761040500307846, 11.726096640928073, 10.882793594086262, 9.892606163999732, 8.96579233548639, 8.035302278458241, 9.021418542577656, 8.888598548637935, 9.808918444723883, 10.846419105547515, 11.763072949873402, 12.647991214375859, 13.655875643000297, 14.623409031776136, 15.549906053082227, 16.51892276912551, 15.500675308295435, 14.532648670067148, 13.60712233992752, 12.620045008403011, 11.765382167661079, 10.694951153902824, 9.811712765541536, 8.948889983550966, 7.960189600256287, 7.048969868336562, 8.018539223584128, 7.8892560855229785, 8.868650875150033, 9.805743636456468, 10.77386313621532, 11.695171652285506, 12.709833770857479, 13.658485494457159, 14.596159890555489, 15.648334319786901, 14.70233804677606, 13.674883920609188, 12.710462036440559, 11.683859282447388, 10.745662107415512, 9.75900827300926, 8.804074293334022, 7.897980175088665, 6.909292798004086, 6.070290091927779, 7.0168595324617336, 6.91637413462174, 7.857899515467301, 8.802789312986397, 9.798984142225326, 10.724345638210359, 11.720391896134124, 12.683315028998159, 13.70780998828836, 14.630887690857213, 13.662209868063789, 12.70356486899263, 11.682493417353864, 10.659765879172827, 9.721641623816378, 8.794842176164122, 7.878166340221633, 6.929569161185941, 5.947027532391617, 5.003121753102493, 5.978388368849509, 5.857129502278557, 6.8477786666847305, 7.8081381465540485, 8.871148028973838, 9.844679279360715, 10.91058492896071, 11.798980017328834, 12.780526751926567, 13.784014721744073, 12.740724489997957, 11.700149012441944, 10.753288272301496, 9.7224680266423, 8.784264174882837, 7.843403282224097, 6.850830134882692, 5.928346536681135, 5.017432894020495, 3.9840220792383723, 4.970471077399552, 4.856794832225464, 5.8026156613229105, 6.8502417786769145, 7.909069845512321, 8.840931837425346, 9.859732400033877, 10.794269281147749, 11.81718013594989, 12.78962398683361, 11.814712600368237, 10.746584377155266, 9.724451563110412, 8.763927089768478, 7.840246044176467, 6.84021210357226, 5.877893772434847, 4.929047616266503, 3.9982571286900397, 3.0129415888202793, 3.9794717792800487, 3.8906881839561853, 4.951341434183448, 5.979225399715821, 6.92624592434129, 7.970078217862177, 8.948220844232074, 9.892509042562443, 10.9143258253391, 11.819810573774324, 10.889389141552394, 9.842439544106728, 8.879706803737786, 7.832445326638926, 6.87178809209489, 5.900663718577826, 4.925028069771728, 3.973865708731279, 3.080871166049567, 2.0856962810594135, 2.9406908754015104, 2.9802581692568593, 4.038371640033422, 5.0617598426625605, 6.044378330149972, 7.04660391934521, 8.021088647055008, 9.038996876459864, 10.110787843557898, 10.993126519687785, 9.985561626760116, 8.913965368116173, 7.920569144940028, 6.975559021887446, 5.996316239353862, 4.990486791319041, 3.9710708272691226, 2.951843843295093, 2.0109915138516983, 1.0664245975173396, 1.9854579516736588, 2.117466490999435, 3.1291514767346116, 4.089803441400527, 5.136811412920572, 6.085106595024589, 7.143976973925133, 8.133760326400735, 9.153659462540794, 10.095414868026294, 9.209587103291158, 8.138019953425884, 7.11327400081534, 6.138980978025537, 5.209562141553792, 4.14152405933281, 3.093894539202662, 2.104629200116423, 1.0399946036422272, 0.0, 1.0586195109518157], [0.9621788122179693, 1.9211540674908998, 2.900491080928112, 3.891366222400693, 4.919600862031741, 5.874714673078601, 6.902058486696578, 7.916942591424209, 8.856599728623308, 9.881026006368913, 10.934338682549916, 10.036643289115036, 8.970579775003529, 7.96218734206772, 6.955391431744767, 5.966913811623871, 5.00952833265028, 3.985155735422004, 2.9990940405281163, 1.9723564441780097, 1.9810845898645455, 2.9764584134809233, 3.8910039592321155, 4.839541180435806, 5.89939157421364, 6.853916591395856, 7.852185190316767, 8.844181004110414, 9.895943629903822, 10.91783360355674, 11.870504876613431, 10.910462802908281, 9.85165286318126, 8.83522569076399, 7.8825194273154215, 6.9488053208530145, 5.934976010139584, 5.015480571886284, 4.047184036360646, 3.0268649341248715, 3.024807242898272, 3.9659623827211634, 4.87037842056278, 5.829328258780299, 6.827044840857064, 7.8398584852004785, 8.854915289652286, 9.87680379907923, 10.89246678786161, 11.899721508392604, 12.78414883296812, 11.85335584417895, 10.801085614607707, 9.805110780170013, 8.830812006908252, 7.931297850135506, 7.007910276659368, 5.987785156932237, 4.9725821874438125, 4.064897444380138, 4.043155287895558, 4.977052321842367, 5.854222341872859, 6.782831361377509, 7.822090872926884, 8.823187631891855, 9.771668409344427, 10.76277694374665, 11.74832729390493, 12.725052684739396, 13.725503730436301, 12.719298800838645, 11.75539551974252, 10.79284707938677, 9.850717962849846, 8.815632231196638, 7.887113604756506, 6.951995528949796, 5.958416375788257, 5.065785001841711, 4.968730939319172, 5.9160662438200164, 6.910203981417793, 7.847349797075083, 8.804352794687224, 9.870160964602427, 10.82563848040418, 11.766341879686054, 12.740453404029303, 13.684697877143272, 14.634337846531439, 13.658668501251196, 12.743731315900193, 11.765000279721962, 10.829547209079427, 9.813261563863001, 8.851552141655265, 7.9226887918780635, 6.904279157651176, 6.022473758911146, 5.976833032715194, 6.957033358064438, 7.856204082397707, 8.781591000041548, 9.746915631307601, 10.77449541848289, 11.711670872273952, 12.680200633470774, 13.672406761664488, 14.599940573294203, 15.546087464949677, 14.619598125104778, 13.662178142357163, 12.73321919402204, 11.755408824096909, 10.782148032631412, 9.87179251454741, 8.904957755848482, 7.851961185108738, 6.92717609197587, 6.9208637755102425, 7.935035824466062, 8.89621830105818, 9.809008661057042, 10.717687368958492, 11.744808860562008, 12.686430421757365, 13.718841396271557, 14.692912037606149, 15.541694481216165, 16.567551550917152, 15.643483732051292, 14.727881913311721, 13.737662701231207, 12.707888747525947, 11.849361839350179, 10.834046159182469, 9.797553636862176, 8.789161343305784, 7.856606421738711, 7.932095148794835, 8.917318498386463, 9.878529378209617, 10.840085606638524, 11.743043217837888, 12.770959687499005, 13.662721868648244, 14.700223380204722, 15.65583180249147, 16.483168517826822, 17.439769571186336, 16.575413138016906, 15.761042884024564, 14.720528585304764, 13.670282863540924, 12.699285698632783, 11.769699098532145, 10.830743774180123, 9.779689559022941, 8.793692651613256, 8.90151428943171, 9.937915292834361, 10.915679058453431, 11.843716649631457, 12.67380384633692, 13.678348378831735, 14.614629476062374, 15.64188766544709, 16.606458301466596, 17.521383017876904, 18.451812762898108, 17.50351327812269, 16.56486644258996, 15.625467837532225, 14.59615666862525, 13.727707120618025, 12.827848773089794, 11.834922009485144, 10.768104392667931, 9.761131255098338, 9.839593992191935, 10.844733067454126, 11.815436700814551, 12.796561777313745, 13.637536298024232, 14.621986843125734, 15.59513077434984, 16.537265567954258, 17.58074345596147, 18.46714349518996, 18.263817358071176, 17.338643899334134, 16.399683664255267, 15.453075123924737, 14.46608853169181, 13.47716638351397, 12.537782948212058, 11.708638102449834, 10.77926663252866, 10.038136868511323, 9.779693854901076, 10.66628407633573, 11.610403742418654, 12.679769403609885, 13.64636299451304, 14.612303727171788, 15.473889054577246, 16.44720497536211, 17.41308442724606, 18.318635520464532, 17.317170518194576, 16.416040688400916, 15.562382363842575, 14.57456686484348, 13.508855302401672, 12.558046755706567, 11.573733354984045, 10.677928480666273, 9.712983632812286, 9.021432135838964, 8.82363601825447, 9.719862516694421, 10.737755391169365, 11.737760332399763, 12.606793331264953, 13.656270051623844, 14.512051487646737, 15.457497275418643, 16.485500399485357, 17.329435243677278, 16.36582095989705, 15.36107164965163, 14.492698327692914, 13.58745254788723, 12.552508688507457, 11.676289053267071, 10.634934595245648, 9.708120766732305, 8.777630709704155, 8.091144888045463, 7.829979037686121, 8.750298933772068, 9.787799594595699, 10.704453438921586, 11.58937170342404, 12.597256132048479, 13.564789520824318, 14.491286542130409, 15.460303258173694, 16.32708735587482, 15.359060717646534, 14.433534387506905, 13.446457055982396, 12.591794215240462, 11.521363201482208, 10.631654585480764, 9.691218414796882, 8.702518031502203, 7.791298299582477, 7.088265569051934, 6.830636574571164, 7.810031364198219, 8.747124125504651, 9.715243625263504, 10.636552141333688, 11.651214259905661, 12.59986598350534, 13.537540379603671, 14.589714808835083, 15.528750094355443, 14.501295968188572, 13.536874084019944, 12.510271330026773, 11.572074154994898, 10.585420320588643, 9.62401611327325, 8.640308606334582, 7.651621229250002, 6.812618523173694, 6.032689395084179, 5.857754623669925, 6.799280004515486, 7.74416980203458, 8.74036463127351, 9.66572612725854, 10.661772385182307, 11.624695518046341, 12.649190477336543, 13.604480368435155, 14.488621915643172, 13.529976916572014, 12.50890546493325, 11.486177926752212, 10.548053671395762, 9.621254223743506, 8.704578387801016, 7.703896690084189, 6.689355963637533, 5.7454501843484085, 4.977581244506228, 4.798509991326743, 5.789159155732914, 6.749518635602232, 7.812528518022021, 8.786059768408899, 9.851965418008893, 10.74036050637702, 11.721907240974751, 12.725395210792257, 13.56713653757734, 12.526561060021328, 11.57970031988088, 10.548880074221684, 9.610676222462219, 8.66981532980348, 7.6772421824620745, 6.718717957499929, 5.75976132526641, 4.726350510484287, 3.969663953056272, 3.798175321273649, 4.743996150371094, 5.791622267725098, 6.850450334560505, 7.782312326473531, 8.801112889082061, 9.735649770195932, 10.758560624998074, 11.731004475881793, 12.64112464794762, 11.572996424734649, 10.550863610689795, 9.590339137347861, 8.66665809175585, 7.666624151151643, 6.70430582001423, 5.755459663845885, 4.740585559935955, 3.755270020066194, 2.920852268328233, 2.83206867300437, 3.8927219232316324, 4.920605888764006, 5.867626413389475, 6.911458706910363, 7.8896013332802575, 8.833889531610627, 9.855706314387284, 10.860738054386015, 11.715801189131776, 10.66885159168611, 9.706118851317168, 8.658857374218309, 7.698200139674274, 6.727075766157209, 5.751440117351111, 4.800277756310662, 3.876608574415263, 2.828024712305328, 1.882071364449695, 1.9216386583050435, 2.979752129081607, 4.003140331710746, 4.985758819198158, 5.987984408393395, 6.962469136103191, 7.980377365508047, 9.052168332606081, 10.067088787041511, 10.811973674339498, 9.740377415695555, 8.74698119251941, 7.801971069466829, 6.822728286933245, 5.816898838898424, 4.797482874848505, 3.778255890874475, 2.8374035614310804, 1.8928366450967218, 0.9268384407218431, 1.0588469800476197, 2.070531965782796, 3.0311839304487114, 4.078191901968757, 5.026487084072774, 6.085357462973317, 7.075140815448918, 8.095039951588978, 9.036795357074478, 10.082200845249686, 9.1966394643777, 8.171893511767156, 7.197600488977352, 6.268181652505607, 5.2001435702846255, 4.152514050154478, 3.1632487110682392, 2.098614114594043, 1.0586195109518157, 0.0]]}],
                            {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('5caa447f-2b4c-4a56-a498-d7d279f96877');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Saving the results into an array
    topological_spaces_mat = np.asarray([rp2, klein])

Computing persistent homology
-----------------------------

In the next section we will use ``giotto-tda`` to compute the persistent
homology groups of the topological spaces we just constructed.

.. code:: ipython3

    # the homology ranks we choose to consider
    homology_dimensions = (0, 1, 2)
    VR = VietorisRipsPersistence(
        metric='precomputed', max_edge_length=np.inf, homology_dimensions=homology_dimensions)
    
    # List of all the time-ordered persistence diagrams obtained from the list of correlation matrices
    diagrams = VR.fit_transform(topological_spaces_mat)

Persistence diagrams
--------------------

The topological information of the point cloud is synthesised in the
persistence diagram. The horizontal axis corresponds to the moment in
which an homological generator is born, while the vertical axis
corresponds to the moments in which an homological generator dies.

The generators of the homology groups (at given rank) are colored
differently.

.. code:: ipython3

    # Plotting the persistence diagram of the projective space
    plot_diagram(diagrams[0])



.. raw:: html

    <div>
    
    
                <div id="fd6d2240-40c4-4700-8c42-089aae5510f2" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("fd6d2240-40c4-4700-8c42-089aae5510f2")) {
                        Plotly.newPlot(
                            'fd6d2240-40c4-4700-8c42-089aae5510f2',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-961.4501953125, 961.4501953125], "y": [-961.4501953125, 961.4501953125]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.9250820279121399, 0.9252181053161621, 0.92535799741745, 0.925370454788208, 0.9258236289024353, 0.9265007972717285, 0.9266461730003357, 0.9268370866775513, 0.9271825551986694, 0.9273419976234436, 0.9274498820304871, 0.9275789856910706, 0.9276269674301147, 0.9278449416160583, 0.9281511902809143, 0.9283654689788818, 0.9284840822219849, 0.9287029504776001, 0.9287394881248474, 0.9290658235549927, 0.929151177406311, 0.9291542172431946, 0.9292755126953125, 0.9293935894966125, 0.9296362996101379, 0.9296779036521912, 0.9298014640808105, 0.9298378229141235, 0.9299599528312683, 0.9300564527511597, 0.9306286573410034, 0.930695116519928, 0.9309842586517334, 0.9312213063240051, 0.9313085079193115, 0.9313716292381287, 0.9314976334571838, 0.9317435622215271, 0.9318716526031494, 0.9319761395454407, 0.9323217272758484, 0.9324185848236084, 0.9325985908508301, 0.9327967166900635, 0.9328019022941589, 0.9328213930130005, 0.9330316185951233, 0.9330482482910156, 0.9331815838813782, 0.9332399964332581, 0.9332674145698547, 0.933297872543335, 0.9333069920539856, 0.9340137839317322, 0.9340351819992065, 0.9341117739677429, 0.934418261051178, 0.9346744418144226, 0.9347884058952332, 0.9348834753036499, 0.9355239272117615, 0.9355469346046448, 0.9357665777206421, 0.9357972145080566, 0.9360410571098328, 0.9362891316413879, 0.9370412826538086, 0.9371533393859863, 0.9372113347053528, 0.937555730342865, 0.938168466091156, 0.9382046461105347, 0.9386339783668518, 0.9387147426605225, 0.9388952851295471, 0.9394498467445374, 0.9395124316215515, 0.9395173788070679, 0.9397362470626831, 0.9397639632225037, 0.9397815465927124, 0.939935028553009, 0.9399568438529968, 0.9399658441543579, 0.9401993155479431, 0.940345823764801, 0.9406648874282837, 0.9407273530960083, 0.9407338500022888, 0.9407719969749451, 0.9408005475997925, 0.9412076473236084, 0.9413003325462341, 0.9417880773544312, 0.9423360228538513, 0.9428263306617737, 0.9428693056106567, 0.9429531693458557, 0.9429821372032166, 0.9431580305099487, 0.9435992240905762, 0.9440577626228333, 0.9441950917243958, 0.9445558190345764, 0.9447271227836609, 0.9448081851005554, 0.9449620842933655, 0.9449715614318848, 0.9450463652610779, 0.9450786709785461, 0.9452682137489319, 0.9453790783882141, 0.9453886151313782, 0.9454402327537537, 0.9456532001495361, 0.9458446502685547, 0.9459902048110962, 0.9460933804512024, 0.9463049173355103, 0.9463180899620056, 0.9463798999786377, 0.9463845491409302, 0.9465435743331909, 0.9465695023536682, 0.9467476010322571, 0.9467583894729614, 0.9473141431808472, 0.9473904967308044, 0.9474199414253235, 0.9474624991416931, 0.9478566646575928, 0.9481943249702454, 0.9490094184875488, 0.9490250945091248, 0.9492350816726685, 0.9494480490684509, 0.9494817852973938, 0.9496158957481384, 0.9496888518333435, 0.9497437477111816, 0.9502279162406921, 0.9502649903297424, 0.950646162033081, 0.9512642025947571, 0.9512734413146973, 0.9514336585998535, 0.9516856670379639, 0.9518143534660339, 0.9520308375358582, 0.9520444273948669, 0.9525545239448547, 0.9529438018798828, 0.9531117677688599, 0.9535430073738098, 0.9536195993423462, 0.9538556337356567, 0.9540865421295166, 0.9541871547698975, 0.9542094469070435, 0.9542188048362732, 0.9542850255966187, 0.9544840455055237, 0.9545415043830872, 0.9546201825141907, 0.9546247720718384, 0.9547406435012817, 0.9547763466835022, 0.955245852470398, 0.9553428888320923, 0.9555802941322327, 0.9556581377983093, 0.9556941390037537, 0.9558629989624023, 0.9563899636268616, 0.9568111300468445, 0.9568129777908325, 0.9570452570915222, 0.9572625160217285, 0.9573251605033875, 0.9573785662651062, 0.9573810696601868, 0.9574320912361145, 0.9576976895332336, 0.957754373550415, 0.9581354260444641, 0.9582840800285339, 0.958483099937439, 0.9584954977035522, 0.9586639404296875, 0.958818256855011, 0.9588205814361572, 0.9588545560836792, 0.9589454531669617, 0.959267795085907, 0.9592844843864441, 0.9600477814674377, 0.9606627821922302, 0.9617153406143188, 0.9618639945983887, 0.9622476696968079, 0.9622920155525208, 0.9624321460723877, 0.9625465869903564, 0.9627285003662109, 0.9629933834075928, 0.9633327126502991, 0.9633426666259766, 0.9634855389595032, 0.9638368487358093, 0.963959276676178, 0.9639962315559387, 0.9640815854072571, 0.964283287525177, 0.9644320011138916, 0.9646838307380676, 0.9647530317306519, 0.9647566080093384, 0.9650437831878662, 0.9650885462760925, 0.9651604890823364, 0.9655962586402893, 0.9658215641975403, 0.965939462184906, 0.9660015106201172, 0.9663968682289124, 0.9664729833602905, 0.9665167331695557, 0.9667133092880249, 0.9668509364128113, 0.9669117331504822, 0.9672463536262512, 0.9672697186470032, 0.9675155282020569, 0.9676700234413147, 0.9678067564964294, 0.9678940176963806, 0.9679561257362366, 0.9680407047271729, 0.9680628180503845, 0.9684856534004211, 0.9690641760826111, 0.9692676663398743, 0.9694408774375916, 0.9697132706642151, 0.9697349667549133, 0.9697794914245605, 0.9698458909988403, 0.9699351191520691, 0.9705044031143188, 0.9706609845161438, 0.9706734418869019, 0.9707437753677368, 0.9708079099655151, 0.9710495471954346, 0.9711940288543701, 0.9711989164352417, 0.9712408185005188, 0.971563994884491, 0.9716268181800842, 0.9718380570411682, 0.9725034236907959, 0.9726405739784241, 0.9726623892784119, 0.9729363322257996, 0.9733614921569824, 0.9734695553779602, 0.9735686779022217, 0.9739916324615479, 0.9743447303771973, 0.9744296073913574, 0.9744899868965149, 0.9749584794044495, 0.9752256274223328, 0.9757100343704224, 0.9757394790649414, 0.9759513735771179, 0.976107120513916, 0.9761967658996582, 0.9763600826263428, 0.9767886400222778, 0.9771700501441956, 0.9772747159004211, 0.9775474071502686, 0.9777727723121643, 0.9778038859367371, 0.9778390526771545, 0.9782416224479675, 0.9785803556442261, 0.9787262082099915, 0.9795563817024231, 0.979573130607605, 0.979942798614502, 0.9800001382827759, 0.9801088571548462, 0.9802663922309875, 0.980268657207489, 0.9803075790405273, 0.9803751111030579, 0.9804524183273315, 0.9807729721069336, 0.9812710285186768, 0.9813079833984375, 0.9829217791557312, 0.9831119179725647, 0.9838079810142517, 0.9842855930328369, 0.9845901727676392, 0.9845975637435913, 0.9851586222648621, 0.9852633476257324, 0.9855760931968689, 0.9857368469238281, 0.9861283302307129, 0.9861734509468079, 0.987608790397644, 0.9876127243041992, 0.9879345297813416, 0.9886529445648193, 0.989045262336731, 0.9894288778305054, 0.9897499680519104, 0.9907771348953247, 0.9910454154014587, 0.9910823702812195, 0.9913252592086792, 0.9913950562477112, 0.9923120141029358, 0.9923719167709351, 0.9924460053443909, 0.9925208687782288, 0.9926394820213318, 0.992769718170166, 0.9930190443992615, 0.9930500984191895, 0.993528425693512, 0.9937280416488647, 0.993762731552124, 0.9939886331558228, 0.9940099120140076, 0.9945932626724243, 0.9946362972259521, 0.9946877956390381, 0.9947713017463684, 0.9947991371154785, 0.9949918985366821, 0.9954843521118164, 0.9961800575256348, 0.9963473677635193, 0.9969361424446106, 0.9970802068710327, 0.9971674680709839, 0.9973635673522949, 0.997391939163208, 0.9978465437889099, 0.9981546998023987, 0.9983550906181335, 0.9992867112159729, 1.0005210638046265, 1.0005946159362793, 1.0011296272277832, 1.0014104843139648, 1.0015780925750732, 1.0019882917404175, 1.0024633407592773, 1.002849817276001, 1.003248929977417, 1.0036710500717163, 1.004843831062317, 1.0053656101226807, 1.0058807134628296, 1.0070282220840454, 1.0071054697036743, 1.0073429346084595, 1.0091248750686646, 1.0092660188674927, 1.0095399618148804, 1.0099232196807861, 1.0106247663497925, 1.0107791423797607, 1.0108146667480469, 1.0123190879821777, 1.0129677057266235, 1.013559103012085, 1.0141888856887817, 1.0154138803482056, 1.017500400543213, 1.0176700353622437, 1.017913818359375, 1.0189985036849976, 1.0211025476455688, 1.0230154991149902, 1.023661732673645, 1.0260398387908936, 1.030273675918579, 1.036198377609253, 1.0371887683868408, 1.0406875610351562, 1.0414024591445923, 1.045291543006897]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [1.0749262571334839, 1.0748262405395508, 1.0748082399368286, 1.0745781660079956, 1.0734561681747437, 1.0734472274780273, 1.0731219053268433, 1.073017954826355, 1.0729864835739136, 1.0729445219039917, 1.0725719928741455, 1.0725716352462769, 1.0725122690200806, 1.0723094940185547, 1.0721547603607178, 1.0719027519226074, 1.0716638565063477, 1.0714936256408691, 1.071172833442688, 1.0711678266525269, 1.070893406867981, 1.0707863569259644, 1.0705121755599976, 1.070082426071167, 1.0699976682662964, 1.0698847770690918, 1.0697073936462402, 1.0696022510528564, 1.0694551467895508, 1.0694198608398438, 1.06920325756073, 1.0689623355865479, 1.0683209896087646, 1.0683001279830933, 1.0682289600372314, 1.0680700540542603, 1.0679619312286377, 1.067869782447815, 1.0678160190582275, 1.0677186250686646, 1.0676649808883667, 1.0668407678604126, 1.0664783716201782, 1.0663150548934937, 1.066249966621399, 1.066148042678833, 1.0660361051559448, 1.0660346746444702, 1.0658363103866577, 1.0657095909118652, 1.0655533075332642, 1.0650997161865234, 1.065061092376709, 1.0650438070297241, 1.064918041229248, 1.064874291419983, 1.0647014379501343, 1.0641885995864868, 1.0640802383422852, 1.063736081123352, 1.0636848211288452, 1.0635194778442383, 1.0634568929672241, 1.0633631944656372, 1.06334388256073, 1.063246250152588, 1.0626047849655151, 1.0621097087860107, 1.0620139837265015, 1.0619198083877563, 1.0618600845336914, 1.0615525245666504, 1.0614444017410278, 1.061179518699646, 1.0611661672592163, 1.0604850053787231, 1.0603843927383423, 1.0602236986160278, 1.059846043586731, 1.0596855878829956, 1.0595996379852295, 1.059545636177063, 1.0592297315597534, 1.0588477849960327, 1.0585793256759644, 1.058524489402771, 1.0582904815673828, 1.057571530342102, 1.0575567483901978, 1.0572545528411865, 1.056862235069275, 1.0566530227661133, 1.0565409660339355, 1.0564528703689575, 1.0563055276870728, 1.056244969367981, 1.0561810731887817, 1.0561338663101196, 1.056075930595398, 1.0556577444076538, 1.0556418895721436, 1.054677128791809, 1.0540220737457275, 1.0538859367370605, 1.0537419319152832, 1.053691029548645, 1.0534435510635376, 1.0533276796340942, 1.052975058555603, 1.0529576539993286, 1.0528548955917358, 1.052702784538269, 1.052685022354126, 1.05256986618042, 1.0524020195007324, 1.052372694015503, 1.0520051717758179, 1.0519216060638428, 1.0516669750213623, 1.0514134168624878, 1.051342487335205, 1.0512810945510864, 1.0512278079986572, 1.0512192249298096, 1.051163911819458, 1.0508415699005127, 1.0508188009262085, 1.0506666898727417, 1.0506068468093872, 1.0504581928253174, 1.0504539012908936, 1.0504406690597534, 1.0504018068313599, 1.0502804517745972, 1.0502756834030151, 1.0502513647079468, 1.0500777959823608, 1.0499870777130127, 1.0498244762420654, 1.0493742227554321, 1.0493415594100952, 1.0491987466812134, 1.0486857891082764, 1.048671841621399, 1.0478678941726685, 1.0478259325027466, 1.0475174188613892, 1.046742558479309, 1.0464423894882202, 1.0461294651031494, 1.0460010766983032, 1.0459415912628174, 1.0459074974060059, 1.0457558631896973, 1.045745611190796, 1.045190453529358, 1.0451148748397827, 1.0449479818344116, 1.0449281930923462, 1.0449049472808838, 1.0447241067886353, 1.0441921949386597, 1.0441111326217651, 1.0437864065170288, 1.0431777238845825, 1.0429657697677612, 1.0429446697235107, 1.0425511598587036, 1.0425344705581665, 1.0423743724822998, 1.0423502922058105, 1.042278528213501, 1.0419820547103882, 1.0417373180389404, 1.0414210557937622, 1.0413473844528198, 1.0412876605987549, 1.0407766103744507, 1.0407612323760986, 1.0407065153121948, 1.0406367778778076, 1.0403530597686768, 1.0399364233016968, 1.039699673652649, 1.0396435260772705, 1.039617896080017, 1.0394724607467651, 1.0394015312194824, 1.0393540859222412, 1.039220929145813, 1.0389610528945923, 1.038839340209961, 1.0387998819351196, 1.0387462377548218, 1.0386826992034912, 1.0384571552276611, 1.038427472114563, 1.0383933782577515, 1.0382323265075684, 1.0378292798995972, 1.0374318361282349, 1.037430763244629, 1.0373919010162354, 1.0372623205184937, 1.0369669198989868, 1.036929726600647, 1.0368366241455078, 1.0366911888122559, 1.0365707874298096, 1.0363661050796509, 1.0363240242004395, 1.036318302154541, 1.0363057851791382, 1.036014437675476, 1.0359705686569214, 1.0356059074401855, 1.035483956336975, 1.0350408554077148, 1.0343643426895142, 1.034362554550171, 1.0337347984313965, 1.0332261323928833, 1.0331463813781738, 1.032769799232483, 1.0323905944824219, 1.0317938327789307, 1.0317691564559937, 1.031392216682434, 1.0311014652252197, 1.0309017896652222, 1.0307328701019287, 1.030633568763733, 1.0304267406463623, 1.030218243598938, 1.030210018157959, 1.0300770998001099, 1.0296335220336914, 1.0292305946350098, 1.0290911197662354, 1.028505802154541, 1.0284607410430908, 1.027801275253296, 1.0276408195495605, 1.0276402235031128, 1.02761971950531, 1.0275168418884277, 1.0274935960769653, 1.027478575706482, 1.0270299911499023, 1.0267421007156372, 1.0262395143508911, 1.0261248350143433, 1.026015281677246, 1.0258435010910034, 1.0255799293518066, 1.0254521369934082, 1.0253338813781738, 1.0249133110046387, 1.0244860649108887, 1.0244770050048828, 1.0242915153503418, 1.0242111682891846, 1.0241092443466187, 1.0234003067016602, 1.0233484506607056, 1.0232704877853394, 1.0229911804199219, 1.0227510929107666, 1.0221773386001587, 1.0216530561447144, 1.0214931964874268, 1.0214632749557495, 1.0210566520690918, 1.0209962129592896, 1.0205415487289429, 1.02045476436615, 1.0204041004180908, 1.0201976299285889, 1.0198383331298828, 1.0198107957839966, 1.0197831392288208, 1.0194247961044312, 1.0192968845367432, 1.019229531288147, 1.0191045999526978, 1.0186493396759033, 1.0186238288879395, 1.0185415744781494, 1.0180749893188477, 1.0180598497390747, 1.0175658464431763, 1.0175188779830933, 1.0173187255859375, 1.0171663761138916, 1.0171078443527222, 1.0166922807693481, 1.0166090726852417, 1.0163626670837402, 1.016129493713379, 1.0157781839370728, 1.0157345533370972, 1.0155993700027466, 1.0153837203979492, 1.015042781829834, 1.0148375034332275, 1.0146235227584839, 1.0144848823547363, 1.0142879486083984, 1.0142453908920288, 1.0142329931259155, 1.0134913921356201, 1.0133459568023682, 1.0125958919525146, 1.0119510889053345, 1.0116523504257202, 1.0114978551864624, 1.011422872543335, 1.0113742351531982, 1.0109689235687256, 1.010857343673706, 1.0107301473617554, 1.0105719566345215, 1.010069727897644, 1.009925127029419, 1.0098706483840942, 1.009857416152954, 1.0098525285720825, 1.0097501277923584, 1.009545922279358, 1.0089600086212158, 1.0082875490188599, 1.008256196975708, 1.0079987049102783, 1.0079927444458008, 1.0071783065795898, 1.0068198442459106, 1.0063536167144775, 1.0062313079833984, 1.0055036544799805, 1.0050549507141113, 1.0048338174819946, 1.0046695470809937, 1.0040860176086426, 1.0038750171661377, 1.0032974481582642, 1.003283143043518, 1.0029901266098022, 1.0029710531234741, 1.002824306488037, 1.0025177001953125, 1.0021082162857056, 1.00178062915802, 1.0016733407974243, 1.001509666442871, 1.0014203786849976, 1.001213550567627, 1.001099944114685, 1.0010422468185425, 1.000717043876648, 1.0006219148635864, 1.0003913640975952, 1.0001477003097534, 0.999773383140564, 0.9988721013069153, 0.9979472756385803, 0.9978463053703308, 0.996076226234436, 0.9944919943809509, 0.9940761923789978, 0.992322564125061, 0.9921184182167053, 0.9916822910308838, 0.9914684295654297, 0.9903353452682495, 0.9892264604568481, 0.9889990091323853, 0.9888314604759216, 0.9884849786758423, 0.985633373260498, 0.9855661988258362, 0.9855124354362488, 0.9851529002189636, 0.9845740795135498, 0.9823822379112244, 0.9822536110877991, 0.9819133281707764, 0.9810752868652344, 0.9807616472244263, 0.9800147414207458, 0.9793034195899963, 0.9786050915718079, 0.9776425957679749, 0.9730100631713867, 0.9716687202453613, 0.9701341986656189, 0.969606339931488, 0.9657256603240967, 0.9633874297142029, 0.9611796140670776], "y": [1.893343448638916, 1.969058871269226, 1.992140769958496, 1.995801329612732, 1.8667104244232178, 1.929904818534851, 1.8705854415893555, 1.9021810293197632, 2.028249502182007, 1.88307785987854, 1.9645065069198608, 1.9566186666488647, 1.913570523262024, 1.92635977268219, 1.8801769018173218, 1.9796773195266724, 1.9900485277175903, 1.9366466999053955, 1.876822829246521, 1.9503700733184814, 2.1037209033966064, 1.9765231609344482, 1.9217383861541748, 1.9141331911087036, 1.9192705154418945, 1.855576515197754, 1.9163117408752441, 1.9643181562423706, 1.9116380214691162, 1.9437620639801025, 1.9207779169082642, 1.8968284130096436, 1.9400674104690552, 1.878245234489441, 1.985405683517456, 2.002329111099243, 1.9298415184020996, 1.9715431928634644, 1.9642139673233032, 1.9047974348068237, 1.9430404901504517, 1.9905095100402832, 2.0110342502593994, 1.8990249633789062, 2.0488195419311523, 1.9477049112319946, 2.021815299987793, 1.972676396369934, 2.007276773452759, 1.9678772687911987, 1.9730406999588013, 1.9145307540893555, 1.9118801355361938, 1.9528565406799316, 1.9879074096679688, 2.0838823318481445, 1.9300434589385986, 1.8646202087402344, 1.9211534261703491, 1.9786661863327026, 1.9749594926834106, 1.951999545097351, 2.0023739337921143, 1.9968764781951904, 1.9048771858215332, 1.9022701978683472, 1.9775867462158203, 2.0252532958984375, 1.9012631177902222, 1.9846142530441284, 1.9422390460968018, 1.8949975967407227, 1.9193040132522583, 2.049785614013672, 1.892024040222168, 1.9784883260726929, 1.9916057586669922, 1.9771549701690674, 1.9597558975219727, 1.9787311553955078, 1.9548943042755127, 1.9080158472061157, 1.8805088996887207, 2.0731964111328125, 1.927477240562439, 1.8806780576705933, 1.9367314577102661, 1.859442949295044, 1.9465699195861816, 1.997707486152649, 1.9390193223953247, 1.8857825994491577, 2.001303195953369, 2.049055337905884, 1.9887242317199707, 1.9098888635635376, 1.9920542240142822, 2.0035805702209473, 1.8915557861328125, 1.8884174823760986, 1.937442421913147, 1.9531272649765015, 1.9314159154891968, 1.951380968093872, 1.970581293106079, 1.99525785446167, 1.9242403507232666, 1.8874493837356567, 2.03763484954834, 1.8760942220687866, 1.9496612548828125, 1.9933518171310425, 2.010986089706421, 1.935225009918213, 1.9376027584075928, 1.9196372032165527, 1.9349137544631958, 1.8873296976089478, 1.9056721925735474, 1.9999842643737793, 1.920362114906311, 2.00917911529541, 2.0088367462158203, 1.897757649421692, 2.026073932647705, 1.9181010723114014, 1.9694820642471313, 1.9213095903396606, 1.8906561136245728, 1.932125210762024, 1.9111506938934326, 1.8865867853164673, 1.9006959199905396, 1.8868939876556396, 1.9393205642700195, 2.0309042930603027, 1.9482336044311523, 2.0132110118865967, 1.963562250137329, 1.9570775032043457, 1.8710365295410156, 2.0382018089294434, 1.9729623794555664, 2.0270111560821533, 1.9459766149520874, 1.9203498363494873, 1.9212746620178223, 1.8878408670425415, 1.8571205139160156, 1.9576812982559204, 1.8874270915985107, 1.8746750354766846, 1.8963249921798706, 1.9583489894866943, 1.9622136354446411, 2.017850637435913, 1.8907458782196045, 1.9613538980484009, 2.0019733905792236, 1.951120376586914, 2.0303001403808594, 1.9039530754089355, 1.9695686101913452, 2.0002658367156982, 1.9822708368301392, 1.884543776512146, 1.9832441806793213, 1.9494941234588623, 1.9519412517547607, 1.8912392854690552, 1.975301742553711, 1.9941059350967407, 1.9608005285263062, 2.003331422805786, 1.9546014070510864, 1.9556118249893188, 1.8987791538238525, 1.9332200288772583, 1.8707319498062134, 1.9831881523132324, 2.1022346019744873, 1.9671576023101807, 2.027278184890747, 1.8792786598205566, 1.9434089660644531, 1.9401535987854004, 2.019472599029541, 2.017587661743164, 2.051673173904419, 1.9823614358901978, 1.996035099029541, 2.004591941833496, 1.9048616886138916, 1.97221839427948, 1.914784550666809, 1.9886888265609741, 1.9157299995422363, 2.0027291774749756, 1.960913062095642, 1.8945742845535278, 1.935190200805664, 1.9669986963272095, 1.904729962348938, 1.9258049726486206, 1.8734666109085083, 1.8907840251922607, 1.945430040359497, 1.927160382270813, 1.8655599355697632, 1.920863151550293, 2.0286359786987305, 1.9351712465286255, 1.9171963930130005, 1.9974769353866577, 1.9029768705368042, 1.965959906578064, 1.9292398691177368, 1.8836363554000854, 1.9777804613113403, 1.941860318183899, 1.932409644126892, 1.971953272819519, 1.951037049293518, 2.0309128761291504, 2.0103845596313477, 2.0721960067749023, 2.007096767425537, 1.8891774415969849, 1.8900654315948486, 1.922776222229004, 1.9001296758651733, 1.9267809391021729, 1.9531558752059937, 1.8952288627624512, 1.9140979051589966, 2.043248414993286, 1.9879906177520752, 1.9021592140197754, 2.020136594772339, 1.9869608879089355, 1.9415161609649658, 1.9088853597640991, 1.9388301372528076, 1.9340776205062866, 2.034383773803711, 1.9750785827636719, 1.9255757331848145, 2.0009963512420654, 1.9286803007125854, 1.9983689785003662, 1.919023871421814, 2.0056979656219482, 1.9253466129302979, 1.9731920957565308, 1.9590322971343994, 1.960412859916687, 1.9477472305297852, 1.9118176698684692, 1.946739673614502, 1.9523303508758545, 1.923467993736267, 2.0147435665130615, 1.984976053237915, 1.965518832206726, 1.8762223720550537, 1.9020637273788452, 2.015651226043701, 2.003058671951294, 1.9053877592086792, 1.9563363790512085, 1.8684499263763428, 1.9206678867340088, 1.9443202018737793, 1.8786767721176147, 2.0113186836242676, 1.9280353784561157, 1.9775736331939697, 1.8679965734481812, 2.001145124435425, 1.9952149391174316, 1.9052537679672241, 1.8785606622695923, 1.9473859071731567, 1.9465714693069458, 1.902597427368164, 1.9530304670333862, 1.9397231340408325, 2.010805368423462, 1.99049711227417, 1.9112733602523804, 1.9232043027877808, 1.9404056072235107, 1.9708892107009888, 1.8851443529129028, 1.9431248903274536, 2.010220766067505, 1.9676923751831055, 1.9341779947280884, 1.953773856163025, 1.9464025497436523, 1.9742300510406494, 1.9895703792572021, 1.8746122121810913, 1.999803900718689, 2.023650646209717, 2.0527451038360596, 1.9459455013275146, 1.9432101249694824, 1.9500458240509033, 1.9901844263076782, 1.9456630945205688, 1.8913931846618652, 1.9858845472335815, 1.9289230108261108, 1.958083987236023, 2.0226657390594482, 1.8859832286834717, 1.9315605163574219, 1.9019505977630615, 1.962990641593933, 2.0752384662628174, 1.947577714920044, 1.9333261251449585, 1.908503770828247, 1.9421496391296387, 1.9390902519226074, 2.10194993019104, 2.0043864250183105, 1.8786817789077759, 2.0275015830993652, 1.928932785987854, 1.866856575012207, 1.99852454662323, 1.8794275522232056, 2.077747344970703, 2.0941739082336426, 1.8630880117416382, 1.9755940437316895, 1.9407715797424316, 2.0788686275482178, 1.8655518293380737, 1.9095395803451538, 6.9430646896362305, 2.012601613998413, 1.8794646263122559, 1.979462742805481, 2.075273275375366, 1.9168521165847778, 1.9046363830566406, 2.030174732208252, 1.9316455125808716, 1.9340438842773438, 1.9572038650512695, 1.9708003997802734, 1.9475103616714478, 1.9057776927947998, 1.9552251100540161, 1.9704830646514893, 1.910580039024353, 2.1098179817199707, 1.9785587787628174, 1.8923155069351196, 1.877388834953308, 1.9144397974014282, 1.8814817667007446, 2.0564162731170654, 1.889583706855774, 1.9295597076416016, 1.9143134355545044, 1.9974559545516968, 2.0029757022857666, 1.9434828758239746, 1.8975920677185059, 1.9084075689315796, 1.926653265953064, 2.013833522796631, 1.9717532396316528, 1.9259339570999146, 1.9128159284591675, 1.9116036891937256, 1.9275496006011963, 1.8703012466430664, 1.8843330144882202, 1.8686715364456177, 1.9262425899505615, 1.9350531101226807, 1.898698329925537, 1.898894190788269, 1.9174193143844604, 1.8835701942443848, 1.8633455038070679, 2.008199453353882, 1.888649821281433, 1.9294497966766357, 1.9154024124145508, 1.911227822303772, 1.8826594352722168, 1.9103189706802368, 1.8625751733779907]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [9.607304573059082, 9.595351219177246, 8.712955474853516, 8.61319351196289, 8.54297161102295, 8.53618335723877, 7.862848281860352, 7.834064960479736, 7.812878131866455, 7.810812950134277, 7.764464378356934, 7.756471157073975, 7.75575065612793, 7.747067928314209, 7.742404460906982, 7.737483024597168, 7.727008819580078, 7.043456554412842, 7.039206027984619, 7.028012752532959, 7.027675628662109, 7.009524822235107, 7.0070576667785645, 7.0060648918151855, 6.994263648986816, 6.9926018714904785, 6.984502792358398, 6.982027530670166, 6.9492316246032715, 6.947925567626953, 2.865694522857666, 2.111530303955078, 2.026352643966675], "y": [9.614501953125, 9.603538513183594, 8.717291831970215, 8.632652282714844, 8.567755699157715, 8.543522834777832, 7.8890180587768555, 7.859074592590332, 7.813796043395996, 7.826608657836914, 7.777784824371338, 7.7952494621276855, 7.772519111633301, 7.795312881469727, 7.780298709869385, 7.809229373931885, 7.7484002113342285, 7.104521751403809, 7.120750904083252, 7.1427483558654785, 7.1156182289123535, 7.109660625457764, 7.076550483703613, 7.121230602264404, 7.1648783683776855, 7.119625568389893, 7.0899739265441895, 7.136695861816406, 8.966444969177246, 7.162206649780273, 2.8752148151397705, 8.98491382598877, 2.0786876678466797]}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 10.575952148437501], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 10.575952148437501], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('fd6d2240-40c4-4700-8c42-089aae5510f2');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


.. code:: ipython3

    # Plotting the persistence diagram of the Klein bottle
    plot_diagram(diagrams[1])



.. raw:: html

    <div>
    
    
                <div id="1e5f4ae6-fb19-43cf-82c5-f3591f85719d" class="plotly-graph-div" style="height:500px; width:500px;"></div>
                <script type="text/javascript">
                    require(["plotly"], function(Plotly) {
                        window.PLOTLYENV=window.PLOTLYENV || {};
    
                    if (document.getElementById("1e5f4ae6-fb19-43cf-82c5-f3591f85719d")) {
                        Plotly.newPlot(
                            '1e5f4ae6-fb19-43cf-82c5-f3591f85719d',
                            [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-1037.785530090332, 1037.785530090332], "y": [-1037.785530090332, 1037.785530090332]}, {"mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.9251213073730469, 0.9251734614372253, 0.9253615140914917, 0.925386905670166, 0.9253981709480286, 0.9254477024078369, 0.9255263209342957, 0.9255756735801697, 0.9258615970611572, 0.9258738160133362, 0.9259079694747925, 0.926799476146698, 0.9268138408660889, 0.9268384575843811, 0.9271280169487, 0.9271321892738342, 0.9272453188896179, 0.9273329973220825, 0.9275338053703308, 0.9275372624397278, 0.9276532530784607, 0.9277175664901733, 0.9279531240463257, 0.9279748201370239, 0.9280375838279724, 0.9280465841293335, 0.9283218383789062, 0.9285186529159546, 0.9286090135574341, 0.9288633465766907, 0.9289589524269104, 0.9289637804031372, 0.9290339350700378, 0.9291076064109802, 0.9294188618659973, 0.9294303059577942, 0.9295865893363953, 0.93028724193573, 0.9304214119911194, 0.9306549429893494, 0.9307606220245361, 0.9307929873466492, 0.9308702945709229, 0.9311244487762451, 0.9312193393707275, 0.9314817786216736, 0.9318619966506958, 0.9319294095039368, 0.9319533705711365, 0.9320263862609863, 0.9325549006462097, 0.9326631426811218, 0.9331218600273132, 0.9337204694747925, 0.9337426424026489, 0.934536874294281, 0.9349198341369629, 0.9351180791854858, 0.9353529214859009, 0.9359428882598877, 0.9361857175827026, 0.9362810850143433, 0.9370862245559692, 0.937175452709198, 0.9372978806495667, 0.9374140501022339, 0.9375364184379578, 0.9376744031906128, 0.9380797147750854, 0.9386330246925354, 0.9386468529701233, 0.9387987852096558, 0.9389553070068359, 0.9389602541923523, 0.9390138983726501, 0.9393696784973145, 0.9393834471702576, 0.9393985867500305, 0.9396571516990662, 0.9399493336677551, 0.9402675628662109, 0.9407033920288086, 0.9408523440361023, 0.940900444984436, 0.9411551356315613, 0.9414740204811096, 0.941525399684906, 0.9416215419769287, 0.9417539238929749, 0.9417554140090942, 0.9421347975730896, 0.9422951936721802, 0.9423158764839172, 0.9423847794532776, 0.9425628185272217, 0.9430678486824036, 0.9436384439468384, 0.943905770778656, 0.9440181255340576, 0.94403076171875, 0.9441196918487549, 0.9442444443702698, 0.9442881941795349, 0.9445669054985046, 0.9450101256370544, 0.9454457759857178, 0.9457604885101318, 0.9458208084106445, 0.9458627700805664, 0.945953369140625, 0.9460000991821289, 0.9460418820381165, 0.9461469054222107, 0.9462157487869263, 0.9464215636253357, 0.9465694427490234, 0.9466085433959961, 0.9470192193984985, 0.9470205307006836, 0.9472619891166687, 0.9472643136978149, 0.9476820230484009, 0.9482925534248352, 0.9482951760292053, 0.9484807848930359, 0.9485372304916382, 0.9486517310142517, 0.9491922855377197, 0.9492378830909729, 0.9496399760246277, 0.9498587250709534, 0.9499973058700562, 0.9501267075538635, 0.9503430724143982, 0.950764000415802, 0.9508085250854492, 0.9511623382568359, 0.9513495564460754, 0.9514389038085938, 0.9518293142318726, 0.9521840810775757, 0.9524013996124268, 0.952479898929596, 0.952599287033081, 0.9527062773704529, 0.9528195858001709, 0.952865719795227, 0.953395664691925, 0.9535646438598633, 0.9537461400032043, 0.9539046287536621, 0.953971803188324, 0.9541791677474976, 0.9551138281822205, 0.955181896686554, 0.9552329182624817, 0.955289900302887, 0.9554701447486877, 0.9556053876876831, 0.9560336470603943, 0.9566010236740112, 0.9567595720291138, 0.9572332501411438, 0.9573854804039001, 0.9578889012336731, 0.95789635181427, 0.9585409164428711, 0.9586449861526489, 0.9589566588401794, 0.9589752554893494, 0.9591376781463623, 0.9595229029655457, 0.9600420594215393, 0.9601625204086304, 0.9605244994163513, 0.9606519937515259, 0.9606572389602661, 0.9606614112854004, 0.9607083797454834, 0.9609296321868896, 0.9611824750900269, 0.9613056778907776, 0.9614973068237305, 0.9617094397544861, 0.9618375897407532, 0.9621177315711975, 0.9621788263320923, 0.9622536301612854, 0.9622652530670166, 0.9623068571090698, 0.9623183608055115, 0.9624636173248291, 0.9625484347343445, 0.96273273229599, 0.9627432823181152, 0.9629197716712952, 0.9629231095314026, 0.9633466005325317, 0.9637324810028076, 0.9638862609863281, 0.9639033079147339, 0.9640495777130127, 0.9641661047935486, 0.9645706415176392, 0.9649235606193542, 0.9649448394775391, 0.9650008678436279, 0.9658794403076172, 0.9659982323646545, 0.966106653213501, 0.9661657214164734, 0.9674385786056519, 0.9680266380310059, 0.9681195020675659, 0.9685297608375549, 0.9685423374176025, 0.9685909748077393, 0.968677818775177, 0.9688864946365356, 0.9690167307853699, 0.9694191217422485, 0.9695636034011841, 0.9695693254470825, 0.9699673652648926, 0.9702188372612, 0.9703134298324585, 0.9705996513366699, 0.970703661441803, 0.9707717299461365, 0.9708260297775269, 0.970997154712677, 0.971080482006073, 0.9711243510246277, 0.9713190793991089, 0.9715564846992493, 0.9721531867980957, 0.9724438786506653, 0.9726659059524536, 0.9728819727897644, 0.9729363918304443, 0.9731439352035522, 0.973214328289032, 0.9736278653144836, 0.9740639328956604, 0.9742532968521118, 0.9742929935455322, 0.9742987751960754, 0.9744847416877747, 0.9752234220504761, 0.9753897786140442, 0.9754166603088379, 0.9756356477737427, 0.9758619666099548, 0.9762914180755615, 0.9766796231269836, 0.9767253994941711, 0.9774764776229858, 0.9776339530944824, 0.9778103828430176, 0.9780521392822266, 0.9786797761917114, 0.9788261651992798, 0.9788292646408081, 0.9789822697639465, 0.9792019128799438, 0.9792374968528748, 0.9793044924736023, 0.9793370366096497, 0.9793744683265686, 0.9796242117881775, 0.979624330997467, 0.9803438782691956, 0.9804005026817322, 0.9805744886398315, 0.9806885123252869, 0.9811250567436218, 0.9813591837882996, 0.9813820123672485, 0.9819658398628235, 0.9821678400039673, 0.9822618961334229, 0.9822826981544495, 0.9823110699653625, 0.9824925065040588, 0.982618510723114, 0.9833291172981262, 0.9835734367370605, 0.9837074875831604, 0.9838439226150513, 0.984313428401947, 0.9851475954055786, 0.9853155612945557, 0.9855503439903259, 0.9858341813087463, 0.9859969019889832, 0.9863324165344238, 0.9864490032196045, 0.9867625832557678, 0.9869717359542847, 0.9869865775108337, 0.9870773553848267, 0.9876772165298462, 0.9877362847328186, 0.9883357882499695, 0.9883648753166199, 0.9884148240089417, 0.9884776473045349, 0.9886873960494995, 0.9887003898620605, 0.9892098307609558, 0.9892346262931824, 0.9892653226852417, 0.9904173612594604, 0.9905129075050354, 0.9905189871788025, 0.9908751249313354, 0.9911085367202759, 0.9919958114624023, 0.9921261072158813, 0.9925731420516968, 0.9933962225914001, 0.9934773445129395, 0.9935791492462158, 0.9936569929122925, 0.99428790807724, 0.9943907260894775, 0.9946511387825012, 0.9948002099990845, 0.9952351450920105, 0.996046245098114, 0.9960646033287048, 0.9961948394775391, 0.9962968230247498, 0.9981451034545898, 0.9984250068664551, 0.9988353252410889, 0.9988404512405396, 0.9990737438201904, 0.999785304069519, 1.000334620475769, 1.0004022121429443, 1.0004510879516602, 1.0004589557647705, 1.0006680488586426, 1.0009703636169434, 1.0012226104736328, 1.001774549484253, 1.0023479461669922, 1.002730131149292, 1.003415822982788, 1.003685712814331, 1.0037474632263184, 1.0040479898452759, 1.005031704902649, 1.0051391124725342, 1.0056027173995972, 1.0056097507476807, 1.0058294534683228, 1.0065892934799194, 1.0069944858551025, 1.007254719734192, 1.007564902305603, 1.0076384544372559, 1.0079172849655151, 1.0081020593643188, 1.0083924531936646, 1.0085827112197876, 1.0091873407363892, 1.0095024108886719, 1.0099796056747437, 1.0101374387741089, 1.0101776123046875, 1.0134018659591675, 1.0136691331863403, 1.0141527652740479, 1.0147677659988403, 1.0147849321365356, 1.014884114265442, 1.0152156352996826, 1.0156630277633667, 1.015918493270874, 1.0164371728897095, 1.0174216032028198, 1.018905758857727, 1.0194833278656006, 1.0194990634918213, 1.0227274894714355, 1.0244262218475342, 1.0246931314468384, 1.025134563446045, 1.0253558158874512, 1.0289685726165771, 1.0302934646606445, 1.0349438190460205, 1.0380325317382812, 1.0406755208969116, 1.042742133140564, 1.0452975034713745, 1.0543054342269897]}, {"mode": "markers", "name": "H1", "type": "scatter", "x": [1.0748802423477173, 1.0748035907745361, 1.0746190547943115, 1.0742586851119995, 1.0739424228668213, 1.0738565921783447, 1.0738201141357422, 1.0735750198364258, 1.073358416557312, 1.0732531547546387, 1.0729342699050903, 1.0729186534881592, 1.0723862648010254, 1.0719120502471924, 1.0717909336090088, 1.0716835260391235, 1.0716572999954224, 1.0715962648391724, 1.071567177772522, 1.0713653564453125, 1.07125985622406, 1.0710808038711548, 1.071007251739502, 1.0709946155548096, 1.0704309940338135, 1.0701642036437988, 1.0698796510696411, 1.069747805595398, 1.0696840286254883, 1.0694570541381836, 1.0693656206130981, 1.0688930749893188, 1.0688058137893677, 1.0687379837036133, 1.0685045719146729, 1.0684599876403809, 1.0681753158569336, 1.068128228187561, 1.0680381059646606, 1.06791090965271, 1.0673779249191284, 1.067349910736084, 1.067298173904419, 1.067213773727417, 1.0671683549880981, 1.0671193599700928, 1.0670682191848755, 1.0669647455215454, 1.0668176412582397, 1.066538691520691, 1.0665289163589478, 1.0664246082305908, 1.0663278102874756, 1.0662829875946045, 1.066120982170105, 1.0660635232925415, 1.0659056901931763, 1.0658081769943237, 1.0657132863998413, 1.0657116174697876, 1.0657037496566772, 1.0653088092803955, 1.0646345615386963, 1.0645543336868286, 1.0645184516906738, 1.0641288757324219, 1.0638675689697266, 1.063763976097107, 1.063592553138733, 1.0635803937911987, 1.0634287595748901, 1.0631847381591797, 1.0630098581314087, 1.0627096891403198, 1.0624330043792725, 1.0622798204421997, 1.0622106790542603, 1.0621484518051147, 1.0621156692504883, 1.0620461702346802, 1.0620455741882324, 1.0618373155593872, 1.0617396831512451, 1.0611448287963867, 1.0606917142868042, 1.0606714487075806, 1.060666799545288, 1.0606532096862793, 1.0605396032333374, 1.060339093208313, 1.060044765472412, 1.0598503351211548, 1.0595519542694092, 1.059451937675476, 1.0593317747116089, 1.0592929124832153, 1.0592446327209473, 1.0590587854385376, 1.0590139627456665, 1.0588704347610474, 1.0588469505310059, 1.0588281154632568, 1.0588099956512451, 1.0587615966796875, 1.0587257146835327, 1.058675765991211, 1.058619499206543, 1.0583736896514893, 1.0581496953964233, 1.0581134557724, 1.0573962926864624, 1.0565742254257202, 1.056361198425293, 1.0559816360473633, 1.0559587478637695, 1.0558758974075317, 1.0557031631469727, 1.055576205253601, 1.0555458068847656, 1.0553042888641357, 1.055250883102417, 1.0552157163619995, 1.0551081895828247, 1.055046796798706, 1.054969072341919, 1.0548688173294067, 1.0542559623718262, 1.0540591478347778, 1.0539700984954834, 1.05374276638031, 1.0536410808563232, 1.0533850193023682, 1.0533126592636108, 1.0529965162277222, 1.0529354810714722, 1.0527516603469849, 1.052695631980896, 1.0524766445159912, 1.0522701740264893, 1.05217444896698, 1.0518090724945068, 1.051762580871582, 1.05160653591156, 1.0512264966964722, 1.0511057376861572, 1.0510542392730713, 1.0508967638015747, 1.0508044958114624, 1.0507898330688477, 1.0505616664886475, 1.050245761871338, 1.0499950647354126, 1.0497190952301025, 1.0496516227722168, 1.0496479272842407, 1.0494674444198608, 1.0493634939193726, 1.0489413738250732, 1.048811674118042, 1.0485838651657104, 1.0484659671783447, 1.0484192371368408, 1.04840087890625, 1.0480899810791016, 1.047629475593567, 1.0476261377334595, 1.047387719154358, 1.047366976737976, 1.0470958948135376, 1.0470079183578491, 1.0469496250152588, 1.0464612245559692, 1.046241283416748, 1.0462219715118408, 1.0458437204360962, 1.0457803010940552, 1.0454493761062622, 1.0454055070877075, 1.0451630353927612, 1.0451252460479736, 1.0446757078170776, 1.0440303087234497, 1.0438323020935059, 1.0437226295471191, 1.0436537265777588, 1.0434778928756714, 1.0434414148330688, 1.043402910232544, 1.042911410331726, 1.042647123336792, 1.0424158573150635, 1.0423310995101929, 1.0418014526367188, 1.0413544178009033, 1.0412688255310059, 1.041070580482483, 1.0409671068191528, 1.0405755043029785, 1.0405446290969849, 1.0399945974349976, 1.0398372411727905, 1.0398287773132324, 1.0395997762680054, 1.039569616317749, 1.0395424365997314, 1.039535403251648, 1.0392595529556274, 1.0388294458389282, 1.038780927658081, 1.0386407375335693, 1.0386197566986084, 1.0382144451141357, 1.0371606349945068, 1.0371496677398682, 1.037074089050293, 1.0368967056274414, 1.036807656288147, 1.0365607738494873, 1.0363284349441528, 1.0359501838684082, 1.0358690023422241, 1.034672498703003, 1.0346181392669678, 1.0342224836349487, 1.0338515043258667, 1.0336081981658936, 1.0334070920944214, 1.0333068370819092, 1.033160924911499, 1.0329749584197998, 1.032651424407959, 1.032562494277954, 1.0312025547027588, 1.031145453453064, 1.0311007499694824, 1.0310769081115723, 1.0308202505111694, 1.0307096242904663, 1.0304503440856934, 1.0303248167037964, 1.0300294160842896, 1.0298938751220703, 1.0297739505767822, 1.029311180114746, 1.0293081998825073, 1.0291907787322998, 1.0290558338165283, 1.028421401977539, 1.0283050537109375, 1.028234601020813, 1.0280681848526, 1.0280040502548218, 1.0279686450958252, 1.0279635190963745, 1.0278840065002441, 1.0278282165527344, 1.0277448892593384, 1.0277080535888672, 1.0275797843933105, 1.027454137802124, 1.0274176597595215, 1.0274174213409424, 1.0273438692092896, 1.0273362398147583, 1.0272581577301025, 1.0271503925323486, 1.0267729759216309, 1.0267375707626343, 1.0261508226394653, 1.0259283781051636, 1.0254420042037964, 1.025197148323059, 1.0250290632247925, 1.0247459411621094, 1.0245490074157715, 1.024495005607605, 1.0243725776672363, 1.024264931678772, 1.0240933895111084, 1.0240205526351929, 1.0240204334259033, 1.0239897966384888, 1.0239335298538208, 1.0238856077194214, 1.023388147354126, 1.0229108333587646, 1.0228573083877563, 1.022629737854004, 1.0225971937179565, 1.0223628282546997, 1.0221328735351562, 1.022130012512207, 1.0220218896865845, 1.0219956636428833, 1.0218884944915771, 1.0218167304992676, 1.021698236465454, 1.0214641094207764, 1.020845651626587, 1.0205967426300049, 1.0205823183059692, 1.0205053091049194, 1.0204639434814453, 1.02033531665802, 1.0202404260635376, 1.02021324634552, 1.019905924797058, 1.0198991298675537, 1.019810676574707, 1.0195554494857788, 1.0194159746170044, 1.0193637609481812, 1.019271731376648, 1.0192270278930664, 1.0191757678985596, 1.0190997123718262, 1.0188006162643433, 1.0187289714813232, 1.0184096097946167, 1.0183480978012085, 1.0181394815444946, 1.0179082155227661, 1.017892837524414, 1.0167632102966309, 1.0167046785354614, 1.0164271593093872, 1.0158488750457764, 1.0152029991149902, 1.0148028135299683, 1.014744758605957, 1.0146621465682983, 1.014540672302246, 1.014172077178955, 1.0138293504714966, 1.0130822658538818, 1.0128579139709473, 1.0128302574157715, 1.012813687324524, 1.012420892715454, 1.0120432376861572, 1.0119868516921997, 1.0119609832763672, 1.0116850137710571, 1.0116220712661743, 1.0112314224243164, 1.0112268924713135, 1.0110899209976196, 1.0110762119293213, 1.0108798742294312, 1.0107513666152954, 1.0099656581878662, 1.0098775625228882, 1.0098143815994263, 1.009751558303833, 1.0091992616653442, 1.008392333984375, 1.0081502199172974, 1.006795883178711, 1.0059645175933838, 1.0058808326721191, 1.0051558017730713, 1.0047492980957031, 1.0047107934951782, 1.0045444965362549, 1.0040209293365479, 1.002954363822937, 1.00287926197052, 1.0026953220367432, 1.0014649629592896, 1.00092613697052, 1.000033974647522, 0.9994179010391235, 0.9993424415588379, 0.9992989301681519, 0.9991413950920105, 0.9990958571434021, 0.997133195400238, 0.9962521195411682, 0.9959748387336731, 0.9958264231681824, 0.9955950975418091, 0.9947319030761719, 0.9937006831169128, 0.9915428161621094, 0.9897871017456055, 0.9897833466529846, 0.9897077083587646, 0.9895097613334656, 0.9869838356971741, 0.9857072234153748, 0.9833089709281921, 0.9832071661949158, 0.9798693656921387, 0.9792428016662598, 0.9772075414657593, 0.9763482809066772, 0.9735674858093262, 0.9732890129089355, 0.9719648957252502, 0.9560578465461731, 0.948961615562439], "y": [1.878238320350647, 1.9392476081848145, 1.9528392553329468, 1.975671648979187, 1.9132211208343506, 1.907751202583313, 1.9480732679367065, 1.9971050024032593, 2.0082383155822754, 1.8961875438690186, 1.9323512315750122, 2.037858247756958, 2.0236918926239014, 1.957329273223877, 1.9548189640045166, 1.970629096031189, 1.9442198276519775, 2.061694383621216, 2.0625, 2.039469003677368, 1.9563959836959839, 1.974729299545288, 1.9419329166412354, 1.9146145582199097, 1.9598764181137085, 2.0865747928619385, 1.962874174118042, 1.929661512374878, 2.0011847019195557, 1.9750065803527832, 1.9630908966064453, 1.9969123601913452, 1.8764153718948364, 1.997893214225769, 1.8869255781173706, 1.8886967897415161, 1.919157862663269, 1.9941401481628418, 1.948124647140503, 1.9771265983581543, 2.0233874320983887, 1.968618631362915, 1.9707894325256348, 1.8895866870880127, 1.9061710834503174, 1.9133310317993164, 1.9976978302001953, 1.8879008293151855, 2.0189809799194336, 1.936370611190796, 1.9786121845245361, 1.8928366899490356, 1.9924676418304443, 1.9947569370269775, 1.9104253053665161, 1.89393949508667, 1.9280725717544556, 1.9701426029205322, 2.0518510341644287, 1.9956053495407104, 1.9426281452178955, 2.0181283950805664, 1.9578076601028442, 1.9124529361724854, 1.9845906496047974, 1.9356904029846191, 1.977676510810852, 1.9073705673217773, 1.9016169309616089, 1.973833680152893, 1.9774705171585083, 1.9432188272476196, 1.927065134048462, 1.903433084487915, 2.0344901084899902, 1.9031099081039429, 1.9074889421463013, 1.9823042154312134, 1.9299640655517578, 2.062798500061035, 1.9955295324325562, 1.9961427450180054, 1.9570636749267578, 1.927614450454712, 1.9590895175933838, 1.954445481300354, 1.9440120458602905, 1.877040147781372, 1.9376635551452637, 1.8937644958496094, 1.915452480316162, 1.9264936447143555, 1.984352469444275, 1.899151086807251, 1.892006278038025, 1.9947259426116943, 1.9549365043640137, 2.0064890384674072, 1.8799251317977905, 1.916800618171692, 1.9216386079788208, 1.9321681261062622, 2.052055597305298, 2.029083490371704, 1.9874564409255981, 1.9926438331604004, 1.9211540222167969, 1.9005632400512695, 1.9561389684677124, 2.022911787033081, 1.9357904195785522, 1.9836457967758179, 1.927288293838501, 1.9618712663650513, 2.002450942993164, 1.900998830795288, 1.9638385772705078, 1.9252492189407349, 1.9893051385879517, 1.969849944114685, 1.940601110458374, 2.0048556327819824, 1.9199011325836182, 1.871387004852295, 1.93017578125, 1.9032849073410034, 1.960237741470337, 2.0334596633911133, 1.994673490524292, 1.9482053518295288, 1.878024935722351, 1.9608498811721802, 1.8964635133743286, 1.9660916328430176, 1.9663716554641724, 1.966872215270996, 1.864151954650879, 2.0055224895477295, 1.9234261512756348, 1.9227628707885742, 1.8948432207107544, 2.032100200653076, 2.0147604942321777, 1.9507485628128052, 1.9123550653457642, 2.0589540004730225, 2.0192244052886963, 1.9818512201309204, 1.9144073724746704, 1.8696411848068237, 1.9551849365234375, 1.935305118560791, 1.9605857133865356, 1.9279592037200928, 1.942122459411621, 1.8530635833740234, 1.987443208694458, 1.8594871759414673, 1.9463039636611938, 1.9125608205795288, 1.9509706497192383, 1.9905539751052856, 1.97569739818573, 2.0312509536743164, 1.9617111682891846, 1.9591033458709717, 1.978302001953125, 1.9601792097091675, 2.0071704387664795, 1.978344440460205, 2.08424973487854, 2.0235366821289062, 2.05991530418396, 1.995402216911316, 1.9757479429244995, 2.0748276710510254, 2.040977716445923, 1.9996047019958496, 1.9461555480957031, 1.8772274255752563, 1.9030102491378784, 1.9497092962265015, 2.0167243480682373, 1.9778810739517212, 1.9190653562545776, 1.941250205039978, 1.9061007499694824, 1.9602078199386597, 1.9492623805999756, 1.9539679288864136, 1.8927077054977417, 2.031306266784668, 1.9390500783920288, 1.923112154006958, 1.861037015914917, 2.003324270248413, 1.8952380418777466, 1.962060809135437, 2.0016775131225586, 1.9493043422698975, 2.091050624847412, 1.9564390182495117, 1.916887879371643, 2.0271732807159424, 1.9151840209960938, 1.9180749654769897, 1.9917644262313843, 1.9520652294158936, 1.8731986284255981, 2.030470848083496, 2.016253709793091, 1.9451650381088257, 1.9943662881851196, 1.9651873111724854, 1.9708560705184937, 1.9954562187194824, 2.0612337589263916, 1.904028058052063, 1.934701681137085, 2.001096248626709, 1.9232630729675293, 1.8743746280670166, 1.9032729864120483, 2.0220329761505127, 1.9361340999603271, 2.0060534477233887, 1.9534355401992798, 2.0648093223571777, 1.885833978652954, 1.9236327409744263, 1.8656126260757446, 1.973842740058899, 1.931809902191162, 1.9803377389907837, 1.916643500328064, 1.9893054962158203, 1.960025429725647, 1.9956544637680054, 1.962035059928894, 1.8537695407867432, 1.9343156814575195, 1.9582555294036865, 1.9302903413772583, 1.920707106590271, 1.9581096172332764, 1.9509351253509521, 2.00960111618042, 1.8968709707260132, 1.958202838897705, 2.0218279361724854, 2.0372939109802246, 1.9050991535186768, 2.0319743156433105, 1.9362276792526245, 2.0023703575134277, 1.8949495553970337, 1.8916314840316772, 1.9417237043380737, 2.0077037811279297, 2.0307934284210205, 1.9528045654296875, 1.9083393812179565, 2.033932685852051, 1.9501729011535645, 1.9188144207000732, 1.891420602798462, 1.9470984935760498, 1.9492213726043701, 1.9179129600524902, 1.8562318086624146, 2.0606777667999268, 1.927469253540039, 1.9097925424575806, 1.9803800582885742, 2.0460727214813232, 1.959580421447754, 1.9835889339447021, 1.980846881866455, 2.0388054847717285, 1.96298086643219, 1.8909655809402466, 1.9066591262817383, 2.046820878982544, 1.9505716562271118, 2.037095785140991, 1.9627645015716553, 1.940603494644165, 1.9584451913833618, 1.9742413759231567, 1.9025330543518066, 1.9746936559677124, 1.932416558265686, 1.906632423400879, 1.8758853673934937, 2.0014688968658447, 1.9953843355178833, 1.9161039590835571, 1.8980751037597656, 1.930578351020813, 1.9698781967163086, 2.0411124229431152, 1.8692877292633057, 1.9510414600372314, 1.9036719799041748, 1.8962194919586182, 2.059126853942871, 1.9924885034561157, 1.936439037322998, 1.9942138195037842, 1.861985206604004, 1.9311057329177856, 1.959313154220581, 1.901186227798462, 1.985075831413269, 1.9630054235458374, 2.039584159851074, 1.9684494733810425, 2.0582640171051025, 1.9394419193267822, 1.9485039710998535, 1.9514485597610474, 1.8714203834533691, 1.8905411958694458, 1.9096155166625977, 2.014338254928589, 2.011190414428711, 2.066089391708374, 1.979413390159607, 1.935254693031311, 1.9218703508377075, 1.9557933807373047, 1.9509526491165161, 1.9827417135238647, 1.8828331232070923, 1.9045279026031494, 1.9052302837371826, 1.904147744178772, 2.075350761413574, 1.892138957977295, 1.9728854894638062, 1.9565538167953491, 1.9734874963760376, 2.0719265937805176, 1.90029776096344, 2.0678629875183105, 1.9723564386367798, 2.083481788635254, 1.8575525283813477, 1.9481829404830933, 1.9462320804595947, 2.053312063217163, 2.0142974853515625, 1.9293780326843262, 1.9881870746612549, 1.9260854721069336, 1.984254240989685, 1.9792746305465698, 1.8798342943191528, 1.8975167274475098, 1.9156056642532349, 1.9947929382324219, 1.970374584197998, 2.022547960281372, 2.0215630531311035, 2.029049873352051, 1.9644163846969604, 1.9559017419815063, 1.889835238456726, 1.9312189817428589, 1.8981883525848389, 1.9421632289886475, 6.9036712646484375, 1.9768189191818237, 1.9525606632232666, 1.8797733783721924, 2.00683331489563, 1.8596187829971313, 1.9434651136398315, 1.9220713376998901, 1.9080418348312378, 1.9109967947006226, 1.949794888496399, 1.9574662446975708, 1.9072833061218262, 1.927911639213562, 1.917829990386963, 6.8162126541137695, 1.924354076385498, 1.8729848861694336, 1.8731191158294678, 1.8946936130523682, 1.8799195289611816, 1.9379159212112427, 1.8573936223983765, 1.8788824081420898, 1.9098536968231201, 1.9247031211853027, 1.9064749479293823, 1.918111801147461, 1.8726720809936523, 1.8629896640777588]}, {"mode": "markers", "name": "H2", "type": "scatter", "x": [9.752909660339355, 9.68686294555664, 9.656800270080566, 9.627045631408691, 9.56275463104248, 8.876689910888672, 8.631645202636719, 8.61971664428711, 8.59968376159668, 7.93143892288208, 7.892485618591309, 7.867807865142822, 7.825088024139404, 7.824597358703613, 7.822742462158203, 7.819733619689941, 7.814791679382324, 7.81381368637085, 7.805411338806152, 7.791031360626221, 7.785355567932129, 7.731821537017822, 7.688508987426758, 7.685327529907227, 7.26108980178833, 7.255735874176025, 7.2506890296936035, 7.213923931121826, 7.206964015960693, 7.1784257888793945, 7.161098003387451, 7.151821136474609, 7.143977165222168, 7.1379547119140625, 7.134672164916992, 7.1309075355529785, 7.1243085861206055, 7.11733341217041, 7.117164134979248, 7.116788387298584, 7.111971855163574, 7.109933853149414, 7.109518527984619, 7.1049580574035645, 7.103445053100586, 7.101898193359375, 7.098025321960449, 7.095792770385742, 7.09474515914917, 7.093850135803223, 7.0878119468688965, 7.08381986618042, 7.0830607414245605, 7.080804347991943, 7.080289840698242, 7.077335357666016, 7.07718563079834, 7.076342582702637, 7.075140953063965, 7.074822425842285, 7.073459148406982, 7.062849044799805, 7.0597710609436035, 7.0552239418029785, 7.053745269775391, 7.053534984588623, 7.0528669357299805, 7.0431599617004395, 7.0423736572265625, 7.04219913482666, 7.033717632293701, 7.030807971954346, 7.024877071380615, 7.024432182312012, 7.023885250091553, 7.023725986480713, 7.023568630218506, 7.022055625915527, 7.019791126251221, 7.015117645263672, 7.014873027801514, 7.01373291015625, 7.013087749481201, 7.011843681335449, 7.011044025421143, 7.010558605194092, 7.005155086517334, 6.99985933303833, 6.998776435852051, 6.994514465332031, 6.994471073150635, 6.993896961212158, 6.992887020111084, 6.989129543304443, 6.987575054168701, 6.987008094787598, 6.985108852386475, 6.98053503036499, 6.980503559112549, 6.978934288024902, 6.976934432983398, 6.970480442047119, 6.969916343688965, 6.9689106941223145, 6.967052459716797, 6.963144302368164, 6.962891101837158, 6.959584712982178, 6.9595723152160645, 6.95866584777832, 6.956665515899658, 6.9529314041137695, 6.9527459144592285, 6.952386379241943, 6.949522495269775, 6.947625160217285, 6.944765567779541, 6.94436502456665, 6.944245338439941, 6.941564559936523, 6.941307544708252, 6.931335926055908, 6.929257869720459, 6.928825855255127, 6.92759370803833, 6.926807880401611, 6.924692153930664, 6.92237663269043, 6.920863628387451, 6.919437885284424, 6.9176836013793945, 6.913216590881348, 6.906716823577881, 6.900271415710449, 6.895175457000732, 6.894524097442627, 6.885440826416016, 6.879354000091553, 6.856719017028809, 6.855774879455566, 6.841015338897705, 6.839305400848389, 6.835387706756592, 6.835014820098877, 6.828444004058838, 2.095884084701538], "y": [9.758405685424805, 9.691119194030762, 9.677420616149902, 9.656749725341797, 9.575116157531738, 8.882546424865723, 8.6496000289917, 8.650084495544434, 8.62071704864502, 7.941115856170654, 7.914725303649902, 7.9198198318481445, 7.838839054107666, 7.875500679016113, 7.898924350738525, 7.871930122375488, 7.856137275695801, 7.820179462432861, 7.864125728607178, 7.869217395782471, 7.823117733001709, 7.761458873748779, 7.810031414031982, 7.780810356140137, 7.267786026000977, 7.297114849090576, 7.279117107391357, 7.290220737457275, 7.722309112548828, 7.196244239807129, 7.1836981773376465, 7.177484035491943, 7.152026653289795, 7.2073564529418945, 7.218802452087402, 7.132258892059326, 7.1772637367248535, 7.216781139373779, 7.232542514801025, 7.118752479553223, 7.226269245147705, 7.250729560852051, 7.19578742980957, 7.241440773010254, 7.1332106590271, 7.131681442260742, 7.197600364685059, 7.238321781158447, 7.147371292114258, 7.77032995223999, 7.289011478424072, 7.1540985107421875, 7.114688873291016, 10.37785530090332, 7.105618953704834, 7.111792087554932, 7.180673599243164, 7.1533331871032715, 7.2706756591796875, 7.106372356414795, 7.1896796226501465, 7.17983341217041, 7.634561061859131, 7.80072546005249, 7.146325588226318, 7.140588760375977, 7.182161808013916, 7.057185649871826, 7.709529876708984, 7.0607428550720215, 7.130502223968506, 7.126898288726807, 7.104491233825684, 7.158372402191162, 7.039355278015137, 7.1534552574157715, 7.073181629180908, 7.187847137451172, 7.116597652435303, 7.198938846588135, 7.089065074920654, 7.71730899810791, 7.097153663635254, 7.066677093505859, 7.036086559295654, 7.110462188720703, 7.070845127105713, 7.058963298797607, 7.009181022644043, 7.732018947601318, 7.110306739807129, 7.108697414398193, 7.708042621612549, 7.033658027648926, 7.023924350738525, 7.804194450378418, 7.0399370193481445, 7.116105079650879, 7.630029678344727, 7.039828777313232, 6.995299816131592, 7.082857608795166, 7.119429111480713, 7.035795211791992, 7.8143720626831055, 7.057904243469238, 6.989869594573975, 7.08462381362915, 7.001195907592773, 7.0547404289245605, 7.081775665283203, 6.995933532714844, 7.033298492431641, 7.044057369232178, 7.60043478012085, 7.117284774780273, 7.057034015655518, 7.050704002380371, 7.065136909484863, 7.149299621582031, 6.987803936004639, 7.6859636306762695, 7.053828716278076, 7.003333568572998, 7.863500118255615, 7.102509021759033, 6.998077392578125, 7.1678690910339355, 7.164306640625, 7.079285144805908, 7.762757778167725, 6.915860176086426, 7.01500940322876, 7.201743125915527, 7.7059807777404785, 7.791270732879639, 6.941277027130127, 7.089637279510498, 6.960754871368408, 6.958808422088623, 7.096607685089111, 7.114760398864746, 7.60396146774292, 7.7595953941345215, 7.207766532897949, 7.8683953285217285]}],
                            {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 11.415640830993654], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [0, 11.415640830993654], "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},
                            {"responsive": true}
                        ).then(function(){
    
    var gd = document.getElementById('1e5f4ae6-fb19-43cf-82c5-f3591f85719d');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })
                    };
                    });
                </script>
            </div>


Conclusion
----------

As you can see from the persistence diagrams, all the Betti numbers were
found. Some other persistent generators are also appearing, depending on
how dense the sampling is and how much noise there is.

For example, we see a rather neat persistence diagram over the Klein
bottle (we see two persistent generators for :math:`H_1` and one
persistent generator for :math:`H_2`). Notice that all these homology
groups are computed over the field :math:`\mathbb{F}_2`.
